(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   8112476,     144664]
NotebookOptionsPosition[   7590157,     132723]
NotebookOutlinePosition[   8012614,     142236]
CellTagsIndexPosition[   8008656,     142122]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["4. Customization", "Subtitle",
 CellTags->{
  "chapter 4 topics", "Aperture Shapes", "Light Sources", 
   "Custom Surface Shapes", "Gratings", "CustomDeflections", 
   "Generic Building Blocks"}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.1 How to Specify Different Aperture Shapes",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.1"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"Aperture Shapes"],

Cell[TextData[{
 ButtonBox["4.1.1 The Circular and Elliptical Apertures",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.1.1"],
 "\n",
 ButtonBox["4.1.2 The Rectangular Aperture",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.1.2"],
 "\n",
 ButtonBox["4.1.3 The Polygonal Aperture",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.1.3"],
 "\n",
 ButtonBox["4.1.4 Aperture Stops",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.1.4"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"Aperture Shapes"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.2 Light Sources",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.2"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Light Sources"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.2.1 Maintaining Constant Pupil Illumination",
 BaseStyle->"Hyperlink",
 ButtonData:>"Maintaining Constant Pupil Illumination"]], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Light Sources"],

Cell[TextData[{
 ButtonBox["Constant Illumination with BirthPoint",
  BaseStyle->"Hyperlink",
  ButtonData:>"Constant Illumination with BirthPoint"],
 "\n",
 ButtonBox["Constant Illumination with ReadRays",
  BaseStyle->"Hyperlink",
  ButtonData:>"Constant Illumination with ReadRays"]
}], "Outline4",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Light Sources"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["4.2.2 Distant Sources, Lasers, and Beam Divergence",
  BaseStyle->"Hyperlink",
  ButtonData:>"Distant Sources"],
 "\n",
 ButtonBox["4.2.3 Laser Cavities and MoveAligned",
  BaseStyle->"Hyperlink",
  ButtonData:>"Laser Cavities and MoveAligned"],
 "\n",
 ButtonBox["4.2.4 Chromatic Sources",
  BaseStyle->"Hyperlink",
  ButtonData:>"Chromatic Sources"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Light Sources"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.3 Custom Surface Shapes",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.3"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Custom Surface Shapes"],

Cell[TextData[{
 ButtonBox["4.3.1 Working from a Derived Symbolic Surface Equation",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.1"],
 "\n",
 ButtonBox["4.3.2 ModelSurfaceShape",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.2"],
 "\n",
 ButtonBox["4.3.3 SurfaceRayIntersections",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.3"],
 "\n",
 ButtonBox["4.3.4 Building a \"Black Hole\"",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.4"],
 "\n",
 ButtonBox["4.3.5 SurfaceApproximation and SurfacePoints",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.5"],
 "\n",
 ButtonBox["4.3.6 SurfaceApproximation -> {TriangleNet -> surfacefunction}",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.6"],
 "\n",
 ButtonBox["4.3.7 SurfaceApproximation -> PlanarShape",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.7"],
 "\n",
 ButtonBox["4.3.8 SurfaceApproximation -> {SphericalShape -> radius}",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.8"],
 "\n",
 ButtonBox["4.3.9 Interpolated Surface Functions",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.9"],
 "\n",
 ButtonBox["4.3.10 SurfaceIntersectionFunction",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.3.10"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Custom Surface Shapes"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.4 Holograms and Diffraction Gratings",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.4"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"Gratings"],

Cell[TextData[{
 ButtonBox["4.4.1 Variable Pitch Grating",
  BaseStyle->"Hyperlink",
  ButtonData:>"Variable Pitch Grating"],
 "\n",
 ButtonBox["4.4.2 Holographic Optical Element",
  BaseStyle->"Hyperlink",
  ButtonData:>"Holographic Optical Element"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"Gratings"]
}, Open  ]],

Cell[TextData[ButtonBox["4.5 Generic Building Blocks: The Language of \
Components",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.5"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.6 CustomDeflections",
 BaseStyle->"Hyperlink",
 ButtonData:>"4.6"]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"CustomDeflections"],

Cell[CellGroupData[{

Cell[TextData[{
 ButtonBox["4.6.1 Getting a Ray to Change Color",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.6.1"],
 "\n",
 ButtonBox["4.6.2 Using Information from a Ray Parameter",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.6.2"],
 "\n",
 ButtonBox["4.6.3 AddTo, TakeFrom, and ReplaceFor",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.6.3"],
 "\n",
 ButtonBox["4.6.4 Redirecting RayTilt with CustomDeflections",
  BaseStyle->"Hyperlink",
  ButtonData:>"4.6.4"],
 "\n",
 ButtonBox["4.6.5 Optimizing CustomDeflections for TurboTrace",
  BaseStyle->"Hyperlink",
  ButtonData:>"Optimizing CustomDeflections"],
 "\n",
 ButtonBox["4.6.6 AffectedSurfaces",
  BaseStyle->"Hyperlink",
  ButtonData:>"AffectedSurfaces"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CustomDeflections"],

Cell[TextData[{
 ButtonBox["RemoveDeflection",
  BaseStyle->"Hyperlink",
  ButtonData:>"RemoveDeflection"],
 "\n",
 ButtonBox["LabelSurfaces",
  BaseStyle->"Hyperlink",
  ButtonData:>"LabelSurfaces"]
}], "Outline4",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->"CustomDeflections"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1 How to Specify Different Aperture Shapes", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[TextData[{
 StyleBox["The edges of most lenses, mirrors, and baffles can be specified  \
as either circular, rectangular, elliptical, or polygonal, depending on the  \
type and number of elements used in the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["aperture",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" parameter of the component function.  ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Rayica",
  FontSlant->"Italic"],
 StyleBox[" uses the same shape-pattern convention with both outside  \
aperture edges and inside aperture holes.  In this section, we examine how  \
these various types of edge shapes are specified.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[CellGroupData[{

Cell["4.1.1 The Circular and Elliptical Apertures", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[TextData[{
 StyleBox["You can specify a circular aperture by using a single number in  \
the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["aperture",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" parameter of the component function.  Here we denote a circular  \
aperture with a a diameter of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["50", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" for a cylindrical lens.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[BiConvexCylindricalLens[100,50,15], Boxed->False];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"In[120]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.1392449578870583`, -25., 0.}, {
      11.860755042112942`, -25., 6.123233995736766*^-15}, {
      13.616979849399343`, -16.66666666666667, 5.102694996447306*^-15}, {
      1.3830201506006574`, -16.666666666666668`, 0.}, {
      3.1392449578870583`, -25., 0.}}], 
     Polygon3DBox[{{1.3830201506006574`, -16.666666666666668`, 0.}, {
      13.616979849399343`, -16.66666666666667, 5.102694996447306*^-15}, {
      14.656024440991942`, -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.343975559008058, -8.333333333333336, 0.}, {
      1.3830201506006574`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.343975559008058, -8.333333333333336, 0.}, {
      14.656024440991942`, -8.333333333333336, 4.0821559971578446`*^-15}, {
      15., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.343975559008058, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {15., 0., 3.061616997868383*^-15}, {
      14.656024440991942`, 8.333333333333332, 2.0410779985789223`*^-15}, {
      0.343975559008058, 8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.343975559008058, 8.333333333333329, 0.}, {
      14.656024440991942`, 8.333333333333332, 2.0410779985789223`*^-15}, {
      13.616979849399343`, 16.666666666666664`, 1.0205389992894613`*^-15}, {
      1.3830201506006574`, 16.666666666666664`, 0.}, {0.343975559008058, 
      8.333333333333329, 0.}}], 
     Polygon3DBox[{{1.3830201506006574`, 16.666666666666664`, 0.}, {
      13.616979849399343`, 16.666666666666664`, 1.0205389992894615`*^-15}, {
      11.860755042112942`, 24.999999999999996`, 5.098616525425841*^-31}, {
      3.1392449578870583`, 24.999999999999993`, 0.}, {1.3830201506006574`, 
      16.666666666666664`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYQeFSqI8vpwAAGlgcYYGD+iT03Fb7Zr14FAgYI
cXYVgU3M1+zXgMUVEOIo4MMedPUrIOod0M2HiBsgxKHu+fcfBCwQ4jXtj7bs
UIe5Ey6u8CbtxBNrbYfVaOacuF+X/8hf12ENur1goAflf7BBV78CzV8w81eg
hwPUPVB3IsRxhCcAHCJj4g==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0., 0., -25.}, {15., 3.061616997868383*^-15, -25.}, {
        15., 2.551347498223653*^-15, -16.66666666666667}, {0., 
        5.102694996447305*^-16, -16.666666666666668`}, {0., 0., -25.}}], 
       Polygon3DBox[{{0., 5.102694996447305*^-16, -16.666666666666668`}, {15.,
         2.551347498223653*^-15, -16.66666666666667}, {15., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0., 
        1.020538999289461*^-15, -8.333333333333336}, {0., 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0., 1.020538999289461*^-15, -8.333333333333336}, {15., 
        2.0410779985789223`*^-15, -8.333333333333336}, {15., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0., 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {15., 
        1.5308084989341915`*^-15, 0.}, {15., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0., 2.041077998578922*^-15, 8.333333333333329}, {
        0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0., 2.041077998578922*^-15, 8.333333333333329}, {15., 
        1.0205389992894611`*^-15, 8.333333333333332}, {15., 
        5.102694996447307*^-16, 16.666666666666664`}, {0., 
        2.5513474982236525`*^-15, 16.666666666666664`}, {0., 
        2.041077998578922*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{0., 2.5513474982236525`*^-15, 16.666666666666664`}, {
        15., 5.102694996447308*^-16, 16.666666666666664`}, {15., 
        2.5493082627129206`*^-31, 24.999999999999996`}, {0., 
        3.0616169978683826`*^-15, 24.999999999999993`}, {0., 
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBlzA8gC6yOpVIGCAIb4GLK6AIQ4BH/agi6yAqHfA
Lm6AIf7vPwhYQMX10OQtMcRXo5iDEF+DYi+6OR9s0MVXoPgLXdwAQxzqzgPo
7oe68wAAO0w8gw==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.1392449578870583`, 25., 0.}, {11.860755042112942`, 25., 
       0.}, {12.074181041443126`, 24.148145657226706`, 6.4704761275630185`}, {
       2.9258189585568743`, 24.148145657226706`, 6.4704761275630185`}, {
       3.1392449578870583`, 25., 0.}}], 
      Line3DBox[{{2.9258189585568743`, 24.148145657226706`, 
       6.4704761275630185`}, {12.074181041443126`, 24.148145657226706`, 
       6.4704761275630185`}, {12.654920635580709`, 21.65063509461097, 
       12.499999999999998`}, {2.3450793644192913`, 21.65063509461097, 
       12.499999999999998`}, {2.9258189585568743`, 24.148145657226706`, 
       6.4704761275630185`}}], 
      Line3DBox[{{2.3450793644192913`, 21.65063509461097, 
       12.499999999999998`}, {12.654920635580709`, 21.65063509461097, 
       12.499999999999998`}, {13.442751478444649`, 17.67766952966369, 
       17.677669529663685`}, {1.5572485215553513`, 17.67766952966369, 
       17.677669529663685`}, {2.3450793644192913`, 21.65063509461097, 
       12.499999999999998`}}], 
      Line3DBox[{{1.5572485215553513`, 17.67766952966369, 
       17.677669529663685`}, {13.442751478444649`, 17.67766952966369, 
       17.677669529663685`}, {14.224396784474848`, 12.500000000000004`, 
       21.650635094610966`}, {0.7756032155251518, 12.500000000000004`, 
       21.650635094610966`}, {1.5572485215553513`, 17.67766952966369, 
       17.677669529663685`}}], 
      Line3DBox[{{0.7756032155251518, 12.500000000000004`, 
       21.650635094610966`}, {14.224396784474848`, 12.500000000000004`, 
       21.650635094610966`}, {14.792762421600713`, 6.470476127563024, 
       24.148145657226706`}, {0.2072375783992868, 6.470476127563024, 
       24.148145657226706`}, {0.7756032155251518, 12.500000000000004`, 
       21.650635094610966`}}], 
      Line3DBox[{{0.2072375783992868, 6.470476127563024, 
       24.148145657226706`}, {14.792762421600713`, 6.470476127563024, 
       24.148145657226706`}, {15., 7.0819236220599744`*^-15, 25.}, {0., 
       7.0819236220599744`*^-15, 25.}, {0.2072375783992868, 6.470476127563024,
        24.148145657226706`}}], 
      Line3DBox[{{0., 1.5308084989341915`*^-15, 25.}, {15., 
       1.5308084989341915`*^-15, 25.}, {
       14.792762421600713`, -6.470476127563016, 24.148145657226706`}, {
       0.2072375783992868, -6.470476127563016, 24.148145657226706`}, {0., 
       1.5308084989341915`*^-15, 25.}}], 
      Line3DBox[{{0.2072375783992868, -6.470476127563016, 
       24.148145657226706`}, {14.792762421600713`, -6.470476127563016, 
       24.148145657226706`}, {14.224396784474848`, -12.499999999999995`, 
       21.65063509461097}, {0.7756032155251518, -12.499999999999995`, 
       21.65063509461097}, {0.2072375783992868, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{0.7756032155251518, -12.499999999999995`, 
       21.65063509461097}, {14.224396784474848`, -12.499999999999995`, 
       21.65063509461097}, {13.442751478444649`, -17.677669529663685`, 
       17.67766952966369}, {1.5572485215553513`, -17.677669529663685`, 
       17.67766952966369}, {0.7756032155251518, -12.499999999999995`, 
       21.65063509461097}}], 
      Line3DBox[{{1.5572485215553513`, -17.677669529663685`, 
       17.67766952966369}, {13.442751478444649`, -17.677669529663685`, 
       17.67766952966369}, {12.654920635580709`, -21.65063509461097, 
       12.499999999999998`}, {2.3450793644192913`, -21.65063509461097, 
       12.499999999999998`}, {1.5572485215553513`, -17.677669529663685`, 
       17.67766952966369}}], 
      Line3DBox[{{2.3450793644192913`, -21.650635094610962`, 
       12.500000000000009`}, {12.654920635580709`, -21.650635094610962`, 
       12.500000000000009`}, {12.074181041443126`, -24.148145657226706`, 
       6.470476127563026}, {2.9258189585568743`, -24.148145657226706`, 
       6.470476127563026}, {2.3450793644192913`, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{2.9258189585568743`, -24.148145657226706`, 
       6.470476127563026}, {12.074181041443126`, -24.148145657226706`, 
       6.470476127563026}, {11.860755042112942`, -25., 
       3.061616997868383*^-15}, {3.1392449578870583`, -25., 
       3.061616997868383*^-15}, {2.9258189585568743`, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{3.1392449578870583`, -25., 3.061616997868383*^-15}, {
       11.860755042112942`, -25., 3.061616997868383*^-15}, {
       12.074181041443126`, -24.148145657226706`, -6.47047612756302}, {
       2.9258189585568743`, -24.148145657226706`, -6.47047612756302}, {
       3.1392449578870583`, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       2.9258189585568743`, -24.14814565722671, -6.470476127563009}, {
       12.074181041443126`, -24.14814565722671, -6.470476127563009}, {
       12.654920635580709`, -21.65063509461097, -12.499999999999993`}, {
       2.3450793644192913`, -21.65063509461097, -12.499999999999993`}, {
       2.9258189585568743`, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       2.3450793644192913`, -21.65063509461097, -12.499999999999993`}, {
       12.654920635580709`, -21.65063509461097, -12.499999999999993`}, {
       13.442751478444649`, -17.677669529663692`, -17.677669529663685`}, {
       1.5572485215553513`, -17.677669529663692`, -17.677669529663685`}, {
       2.3450793644192913`, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       1.5572485215553513`, -17.677669529663696`, -17.677669529663678`}, {
       13.442751478444649`, -17.677669529663696`, -17.677669529663678`}, {
       14.224396784474848`, -12.50000000000001, -21.65063509461096}, {
       0.7756032155251518, -12.50000000000001, -21.65063509461096}, {
       1.5572485215553513`, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       0.7756032155251518, -12.50000000000001, -21.65063509461096}, {
       14.224396784474848`, -12.50000000000001, -21.65063509461096}, {
       14.792762421600713`, -6.470476127563038, -24.148145657226703`}, {
       0.2072375783992868, -6.470476127563038, -24.148145657226703`}, {
       0.7756032155251518, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       0.2072375783992868, -6.470476127563038, -24.148145657226703`}, {
       14.792762421600713`, -6.470476127563038, -24.148145657226703`}, {
       15., -2.6796885989305705`*^-14, -25.}, {
       0., -2.6796885989305705`*^-14, -25.}, {
       0.2072375783992868, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{0., -4.592425496802574*^-15, -25.}, {
       15., -4.592425496802574*^-15, -25.}, {14.792762421600713`, 
       6.470476127563007, -24.14814565722671}, {0.2072375783992868, 
       6.470476127563007, -24.14814565722671}, {
       0., -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{0.2072375783992868, 
       6.470476127563007, -24.14814565722671}, {14.792762421600713`, 
       6.470476127563007, -24.14814565722671}, {14.224396784474848`, 
       12.499999999999984`, -21.650635094610976`}, {0.7756032155251518, 
       12.499999999999984`, -21.650635094610976`}, {0.2072375783992868, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{0.7756032155251518, 
       12.499999999999984`, -21.650635094610976`}, {14.224396784474848`, 
       12.499999999999984`, -21.650635094610976`}, {13.442751478444649`, 
       17.67766952966367, -17.67766952966371}, {1.5572485215553513`, 
       17.67766952966367, -17.67766952966371}, {0.7756032155251518, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{1.5572485215553513`, 
       17.677669529663685`, -17.677669529663692`}, {13.442751478444649`, 
       17.677669529663685`, -17.677669529663692`}, {12.654920635580709`, 
       21.65063509461096, -12.50000000000001}, {2.3450793644192913`, 
       21.65063509461096, -12.50000000000001}, {1.5572485215553513`, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{2.3450793644192913`, 
       21.65063509461096, -12.50000000000001}, {12.654920635580709`, 
       21.65063509461096, -12.50000000000001}, {12.074181041443126`, 
       24.148145657226703`, -6.470476127563039}, {2.9258189585568743`, 
       24.148145657226703`, -6.470476127563039}, {2.3450793644192913`, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{2.9258189585568743`, 
       24.148145657226703`, -6.470476127563039}, {12.074181041443126`, 
       24.148145657226703`, -6.470476127563039}, {11.860755042112942`, 
       25., -2.8327694488239898`*^-14}, {3.1392449578870583`, 
       25., -2.8327694488239898`*^-14}, {2.9258189585568743`, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013014694850903`*^9, 3.6147092349009237`*^9, 
  3.6147290914726753`*^9},
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"During evaluation of In[120]:="]
}, Open  ]],

Cell["A circular aperture shape.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[TextData[{
 StyleBox["You can indicate an elliptical shape instead by denoting the  \
major and minor ellipse dimensions with two negative numbers in the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["aperture",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" parameter.  Here is an example using an elliptical shape of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["{-100, 50}", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" for the  outer dimensions of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["PinHole",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" with a circular hole of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["30", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[PinHole[{-100,-50},30],Boxed->False];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"In[121]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0, 15., 0.}, {0, 26.666666666666664`, 0.}, {
       0, 25.758022034375152`, 4.745015826879546}, {
       0, 14.488887394336022`, 3.88228567653781}, {0, 15., 0.}}], 
     Polygon3DBox[{{0, 14.488887394336022`, 3.88228567653781}, {
       0, 25.758022034375152`, 4.745015826879546}, {
       0, 23.094010767585026`, 9.166666666666666}, {
       0, 12.990381056766578`, 7.5}, {
       0, 14.488887394336022`, 3.88228567653781}}], 
     Polygon3DBox[{{0, 12.990381056766578`, 7.5}, {
       0, 23.094010767585026`, 9.166666666666666}, {
       0, 18.856180831641264`, 12.96362432175337}, {
       0, 10.606601717798211`, 10.606601717798211`}, {
       0, 12.990381056766578`, 7.5}}], 
     Polygon3DBox[{{0, 10.606601717798211`, 10.606601717798211`}, {
       0, 18.856180831641264`, 12.96362432175337}, {
       0, 13.333333333333332`, 15.877132402714707`}, {
       0, 7.5, 12.990381056766578`}, {
       0, 10.606601717798211`, 10.606601717798211`}}], 
     Polygon3DBox[{{0, 7.5, 12.990381056766578`}, {
       0, 13.333333333333332`, 15.877132402714707`}, {
       0, 6.901841202733885, 17.708640148632917`}, {
       0, 3.88228567653781, 14.488887394336022`}, {
       0, 7.5, 12.990381056766578`}}], 
     Polygon3DBox[{{0, 3.88228567653781, 14.488887394336022`}, {
       0, 6.901841202733885, 17.708640148632917`}, {
       0, 0., 18.333333333333332`}, {0, 0., 15.}, {
       0, 3.88228567653781, 14.488887394336022`}}], 
     Polygon3DBox[{{0, 0., 15.}, {0, 0., 18.333333333333332`}, {
       0, -6.901841202733885, 17.708640148632917`}, {
       0, -3.88228567653781, 14.488887394336022`}, {0, 0., 15.}}], 
     Polygon3DBox[{{0, -3.88228567653781, 14.488887394336022`}, {
       0, -6.901841202733885, 17.708640148632917`}, {
       0, -13.333333333333332`, 15.877132402714707`}, {
       0, -7.5, 12.990381056766578`}, {
       0, -3.88228567653781, 14.488887394336022`}}], 
     Polygon3DBox[{{0, -7.5, 12.990381056766578`}, {
       0, -13.333333333333332`, 15.877132402714707`}, {
       0, -18.856180831641264`, 12.96362432175337}, {
       0, -10.606601717798211`, 10.606601717798211`}, {
       0, -7.5, 12.990381056766578`}}], 
     Polygon3DBox[{{0, -10.606601717798211`, 10.606601717798211`}, {
       0, -18.856180831641264`, 12.96362432175337}, {
       0, -23.094010767585026`, 9.166666666666666}, {
       0, -12.990381056766578`, 7.5}, {
       0, -10.606601717798211`, 10.606601717798211`}}], 
     Polygon3DBox[{{0, -12.990381056766578`, 7.5}, {
       0, -23.094010767585026`, 9.166666666666666}, {
       0, -25.758022034375152`, 4.745015826879546}, {
       0, -14.488887394336022`, 3.88228567653781}, {
       0, -12.990381056766578`, 7.5}}], 
     Polygon3DBox[{{0, -14.488887394336022`, 3.88228567653781}, {
       0, -25.758022034375152`, 4.745015826879546}, {
       0, -26.666666666666664`, 0.}, {0, -15., 0.}, {
       0, -14.488887394336022`, 3.88228567653781}}], 
     Polygon3DBox[{{0, -15., 0.}, {0, -26.666666666666664`, 0.}, {
       0, -25.758022034375152`, -4.745015826879546}, {
       0, -14.488887394336022`, -3.88228567653781}, {0, -15., 0.}}], 
     Polygon3DBox[{{0, -14.488887394336022`, -3.88228567653781}, {
       0, -25.758022034375152`, -4.745015826879546}, {
       0, -23.094010767585026`, -9.166666666666666}, {
       0, -12.990381056766578`, -7.5}, {
       0, -14.488887394336022`, -3.88228567653781}}], 
     Polygon3DBox[{{0, -12.990381056766578`, -7.5}, {
       0, -23.094010767585026`, -9.166666666666666}, {
       0, -18.856180831641264`, -12.96362432175337}, {
       0, -10.606601717798211`, -10.606601717798211`}, {
       0, -12.990381056766578`, -7.5}}], 
     Polygon3DBox[{{0, -10.606601717798211`, -10.606601717798211`}, {
       0, -18.856180831641264`, -12.96362432175337}, {
       0, -13.333333333333332`, -15.877132402714707`}, {
       0, -7.5, -12.990381056766578`}, {
       0, -10.606601717798211`, -10.606601717798211`}}], 
     Polygon3DBox[{{0, -7.5, -12.990381056766578`}, {
       0, -13.333333333333332`, -15.877132402714707`}, {
       0, -6.901841202733885, -17.708640148632917`}, {
       0, -3.88228567653781, -14.488887394336022`}, {
       0, -7.5, -12.990381056766578`}}], 
     Polygon3DBox[{{0, -3.88228567653781, -14.488887394336022`}, {
       0, -6.901841202733885, -17.708640148632917`}, {
       0, 0., -18.333333333333332`}, {0, 0., -15.}, {
       0, -3.88228567653781, -14.488887394336022`}}], 
     Polygon3DBox[{{0, 0., -15.}, {0, 0., -18.333333333333332`}, {
       0, 6.901841202733885, -17.708640148632917`}, {
       0, 3.88228567653781, -14.488887394336022`}, {0, 0., -15.}}], 
     Polygon3DBox[{{0, 3.88228567653781, -14.488887394336022`}, {
       0, 6.901841202733885, -17.708640148632917`}, {
       0, 13.333333333333332`, -15.877132402714707`}, {
       0, 7.5, -12.990381056766578`}, {
       0, 3.88228567653781, -14.488887394336022`}}], 
     Polygon3DBox[{{0, 7.5, -12.990381056766578`}, {
       0, 13.333333333333332`, -15.877132402714707`}, {
       0, 18.856180831641264`, -12.96362432175337}, {
       0, 10.606601717798211`, -10.606601717798211`}, {
       0, 7.5, -12.990381056766578`}}], 
     Polygon3DBox[{{0, 10.606601717798211`, -10.606601717798211`}, {
       0, 18.856180831641264`, -12.96362432175337}, {
       0, 23.094010767585026`, -9.166666666666666}, {
       0, 12.990381056766578`, -7.5}, {
       0, 10.606601717798211`, -10.606601717798211`}}], 
     Polygon3DBox[{{0, 12.990381056766578`, -7.5}, {
       0, 23.094010767585026`, -9.166666666666666}, {
       0, 25.758022034375152`, -4.745015826879546}, {
       0, 14.488887394336022`, -3.88228567653781}, {
       0, 12.990381056766578`, -7.5}}], 
     Polygon3DBox[{{0, 14.488887394336022`, -3.88228567653781}, {
       0, 25.758022034375152`, -4.745015826879546}, {
       0, 26.666666666666664`, 0.}, {0, 15., 0.}, {
       0, 14.488887394336022`, -3.88228567653781}}], 
     Polygon3DBox[{{0, 26.666666666666664`, 0.}, {0, 38.33333333333333, 0.}, {
       0, 37.02715667441428, 5.607745977221281}, {
       0, 25.758022034375152`, 4.745015826879546}, {
       0, 26.666666666666664`, 0.}}], 
     Polygon3DBox[{{0, 25.758022034375152`, 4.745015826879546}, {
       0, 37.02715667441428, 5.607745977221281}, {
       0, 33.19764047840348, 10.833333333333332`}, {
       0, 23.094010767585026`, 9.166666666666666}, {
       0, 25.758022034375152`, 4.745015826879546}}], 
     Polygon3DBox[{{0, 23.094010767585026`, 9.166666666666666}, {
       0, 33.19764047840348, 10.833333333333332`}, {
       0, 27.105759945484316`, 15.320646925708527`}, {
       0, 18.856180831641264`, 12.96362432175337}, {
       0, 23.094010767585026`, 9.166666666666666}}], 
     Polygon3DBox[{{0, 18.856180831641264`, 12.96362432175337}, {
       0, 27.105759945484316`, 15.320646925708527`}, {
       0, 19.166666666666664`, 18.763883748662835`}, {
       0, 13.333333333333332`, 15.877132402714707`}, {
       0, 18.856180831641264`, 12.96362432175337}}], 
     Polygon3DBox[{{0, 13.333333333333332`, 15.877132402714707`}, {
       0, 19.166666666666664`, 18.763883748662835`}, {
       0, 9.92139672892996, 20.928392902929808`}, {
       0, 6.901841202733885, 17.708640148632917`}, {
       0, 13.333333333333332`, 15.877132402714707`}}], 
     Polygon3DBox[{{0, 6.901841202733885, 17.708640148632917`}, {
       0, 9.92139672892996, 20.928392902929808`}, {
       0, 0., 21.666666666666664`}, {0, 0., 18.333333333333332`}, {
       0, 6.901841202733885, 17.708640148632917`}}], 
     Polygon3DBox[{{0, 0., 18.333333333333332`}, {
       0, 0., 21.666666666666664`}, {
       0, -9.92139672892996, 20.928392902929808`}, {
       0, -6.901841202733885, 17.708640148632917`}, {
       0, 0., 18.333333333333332`}}], 
     Polygon3DBox[{{0, -6.901841202733885, 17.708640148632917`}, {
       0, -9.92139672892996, 20.928392902929808`}, {
       0, -19.166666666666664`, 18.763883748662835`}, {
       0, -13.333333333333332`, 15.877132402714707`}, {
       0, -6.901841202733885, 17.708640148632917`}}], 
     Polygon3DBox[{{0, -13.333333333333332`, 15.877132402714707`}, {
       0, -19.166666666666664`, 18.763883748662835`}, {
       0, -27.105759945484316`, 15.320646925708527`}, {
       0, -18.856180831641264`, 12.96362432175337}, {
       0, -13.333333333333332`, 15.877132402714707`}}], 
     Polygon3DBox[{{0, -18.856180831641264`, 12.96362432175337}, {
       0, -27.105759945484316`, 15.320646925708527`}, {
       0, -33.19764047840348, 10.833333333333332`}, {
       0, -23.094010767585026`, 9.166666666666666}, {
       0, -18.856180831641264`, 12.96362432175337}}], 
     Polygon3DBox[{{0, -23.094010767585026`, 9.166666666666666}, {
       0, -33.19764047840348, 10.833333333333332`}, {
       0, -37.02715667441428, 5.607745977221281}, {
       0, -25.758022034375152`, 4.745015826879546}, {
       0, -23.094010767585026`, 9.166666666666666}}], 
     Polygon3DBox[{{0, -25.758022034375152`, 4.745015826879546}, {
       0, -37.02715667441428, 5.607745977221281}, {
       0, -38.33333333333333, 0.}, {0, -26.666666666666664`, 0.}, {
       0, -25.758022034375152`, 4.745015826879546}}], 
     Polygon3DBox[{{0, -26.666666666666664`, 0.}, {
       0, -38.33333333333333, 0.}, {
       0, -37.02715667441428, -5.607745977221281}, {
       0, -25.758022034375152`, -4.745015826879546}, {
       0, -26.666666666666664`, 0.}}], 
     Polygon3DBox[{{0, -25.758022034375152`, -4.745015826879546}, {
       0, -37.02715667441428, -5.607745977221281}, {
       0, -33.19764047840348, -10.833333333333332`}, {
       0, -23.094010767585026`, -9.166666666666666}, {
       0, -25.758022034375152`, -4.745015826879546}}], 
     Polygon3DBox[{{0, -23.094010767585026`, -9.166666666666666}, {
       0, -33.19764047840348, -10.833333333333332`}, {
       0, -27.105759945484316`, -15.320646925708527`}, {
       0, -18.856180831641264`, -12.96362432175337}, {
       0, -23.094010767585026`, -9.166666666666666}}], 
     Polygon3DBox[{{0, -18.856180831641264`, -12.96362432175337}, {
       0, -27.105759945484316`, -15.320646925708527`}, {
       0, -19.166666666666664`, -18.763883748662835`}, {
       0, -13.333333333333332`, -15.877132402714707`}, {
       0, -18.856180831641264`, -12.96362432175337}}], 
     Polygon3DBox[{{0, -13.333333333333332`, -15.877132402714707`}, {
       0, -19.166666666666664`, -18.763883748662835`}, {
       0, -9.92139672892996, -20.928392902929808`}, {
       0, -6.901841202733885, -17.708640148632917`}, {
       0, -13.333333333333332`, -15.877132402714707`}}], 
     Polygon3DBox[{{0, -6.901841202733885, -17.708640148632917`}, {
       0, -9.92139672892996, -20.928392902929808`}, {
       0, 0., -21.666666666666664`}, {0, 0., -18.333333333333332`}, {
       0, -6.901841202733885, -17.708640148632917`}}], 
     Polygon3DBox[{{0, 0., -18.333333333333332`}, {
       0, 0., -21.666666666666664`}, {
       0, 9.92139672892996, -20.928392902929808`}, {
       0, 6.901841202733885, -17.708640148632917`}, {
       0, 0., -18.333333333333332`}}], 
     Polygon3DBox[{{0, 6.901841202733885, -17.708640148632917`}, {
       0, 9.92139672892996, -20.928392902929808`}, {
       0, 19.166666666666664`, -18.763883748662835`}, {
       0, 13.333333333333332`, -15.877132402714707`}, {
       0, 6.901841202733885, -17.708640148632917`}}], 
     Polygon3DBox[{{0, 13.333333333333332`, -15.877132402714707`}, {
       0, 19.166666666666664`, -18.763883748662835`}, {
       0, 27.105759945484316`, -15.320646925708527`}, {
       0, 18.856180831641264`, -12.96362432175337}, {
       0, 13.333333333333332`, -15.877132402714707`}}], 
     Polygon3DBox[{{0, 18.856180831641264`, -12.96362432175337}, {
       0, 27.105759945484316`, -15.320646925708527`}, {
       0, 33.19764047840348, -10.833333333333332`}, {
       0, 23.094010767585026`, -9.166666666666666}, {
       0, 18.856180831641264`, -12.96362432175337}}], 
     Polygon3DBox[{{0, 23.094010767585026`, -9.166666666666666}, {
       0, 33.19764047840348, -10.833333333333332`}, {
       0, 37.02715667441428, -5.607745977221281}, {
       0, 25.758022034375152`, -4.745015826879546}, {
       0, 23.094010767585026`, -9.166666666666666}}], 
     Polygon3DBox[{{0, 25.758022034375152`, -4.745015826879546}, {
       0, 37.02715667441428, -5.607745977221281}, {
       0, 38.33333333333333, 0.}, {0, 26.666666666666664`, 0.}, {
       0, 25.758022034375152`, -4.745015826879546}}], 
     Polygon3DBox[{{0, 38.33333333333333, 0.}, {0, 50., 0.}, {
       0, 48.29629131445341, 6.470476127563018}, {
       0, 37.02715667441428, 5.607745977221281}, {0, 38.33333333333333, 0.}}],
      Polygon3DBox[{{0, 37.02715667441428, 5.607745977221281}, {
       0, 48.29629131445341, 6.470476127563018}, {
       0, 43.30127018922193, 12.5}, {
       0, 33.19764047840348, 10.833333333333332`}, {
       0, 37.02715667441428, 5.607745977221281}}], 
     Polygon3DBox[{{0, 33.19764047840348, 10.833333333333332`}, {
       0, 43.30127018922193, 12.5}, {
       0, 35.35533905932737, 17.677669529663685`}, {
       0, 27.105759945484316`, 15.320646925708527`}, {
       0, 33.19764047840348, 10.833333333333332`}}], 
     Polygon3DBox[{{0, 27.105759945484316`, 15.320646925708527`}, {
       0, 35.35533905932737, 17.677669529663685`}, {
       0, 25., 21.650635094610962`}, {
       0, 19.166666666666664`, 18.763883748662835`}, {
       0, 27.105759945484316`, 15.320646925708527`}}], 
     Polygon3DBox[{{0, 19.166666666666664`, 18.763883748662835`}, {
       0, 25., 21.650635094610962`}, {
       0, 12.940952255126035`, 24.148145657226703`}, {
       0, 9.92139672892996, 20.928392902929808`}, {
       0, 19.166666666666664`, 18.763883748662835`}}], 
     Polygon3DBox[{{0, 9.92139672892996, 20.928392902929808`}, {
       0, 12.940952255126035`, 24.148145657226703`}, {0, 0., 25.}, {
       0, 0., 21.666666666666664`}, {
       0, 9.92139672892996, 20.928392902929808`}}], 
     Polygon3DBox[{{0, 0., 21.666666666666664`}, {0, 0., 25.}, {
       0, -12.940952255126035`, 24.148145657226703`}, {
       0, -9.92139672892996, 20.928392902929808`}, {
       0, 0., 21.666666666666664`}}], 
     Polygon3DBox[{{0, -9.92139672892996, 20.928392902929808`}, {
       0, -12.940952255126035`, 24.148145657226703`}, {
       0, -25., 21.650635094610962`}, {
       0, -19.166666666666664`, 18.763883748662835`}, {
       0, -9.92139672892996, 20.928392902929808`}}], 
     Polygon3DBox[{{0, -19.166666666666664`, 18.763883748662835`}, {
       0, -25., 21.650635094610962`}, {
       0, -35.35533905932737, 17.677669529663685`}, {
       0, -27.105759945484316`, 15.320646925708527`}, {
       0, -19.166666666666664`, 18.763883748662835`}}], 
     Polygon3DBox[{{0, -27.105759945484316`, 15.320646925708527`}, {
       0, -35.35533905932737, 17.677669529663685`}, {
       0, -43.30127018922193, 12.5}, {
       0, -33.19764047840348, 10.833333333333332`}, {
       0, -27.105759945484316`, 15.320646925708527`}}], 
     Polygon3DBox[{{0, -33.19764047840348, 10.833333333333332`}, {
       0, -43.30127018922193, 12.5}, {
       0, -48.29629131445341, 6.470476127563018}, {
       0, -37.02715667441428, 5.607745977221281}, {
       0, -33.19764047840348, 10.833333333333332`}}], 
     Polygon3DBox[{{0, -37.02715667441428, 5.607745977221281}, {
       0, -48.29629131445341, 6.470476127563018}, {0, -50., 0.}, {
       0, -38.33333333333333, 0.}, {
       0, -37.02715667441428, 5.607745977221281}}], 
     Polygon3DBox[{{0, -38.33333333333333, 0.}, {0, -50., 0.}, {
       0, -48.29629131445341, -6.470476127563018}, {
       0, -37.02715667441428, -5.607745977221281}, {
       0, -38.33333333333333, 0.}}], 
     Polygon3DBox[{{0, -37.02715667441428, -5.607745977221281}, {
       0, -48.29629131445341, -6.470476127563018}, {
       0, -43.30127018922193, -12.5}, {
       0, -33.19764047840348, -10.833333333333332`}, {
       0, -37.02715667441428, -5.607745977221281}}], 
     Polygon3DBox[{{0, -33.19764047840348, -10.833333333333332`}, {
       0, -43.30127018922193, -12.5}, {
       0, -35.35533905932737, -17.677669529663685`}, {
       0, -27.105759945484316`, -15.320646925708527`}, {
       0, -33.19764047840348, -10.833333333333332`}}], 
     Polygon3DBox[{{0, -27.105759945484316`, -15.320646925708527`}, {
       0, -35.35533905932737, -17.677669529663685`}, {
       0, -25., -21.650635094610962`}, {
       0, -19.166666666666664`, -18.763883748662835`}, {
       0, -27.105759945484316`, -15.320646925708527`}}], 
     Polygon3DBox[{{0, -19.166666666666664`, -18.763883748662835`}, {
       0, -25., -21.650635094610962`}, {
       0, -12.940952255126035`, -24.148145657226703`}, {
       0, -9.92139672892996, -20.928392902929808`}, {
       0, -19.166666666666664`, -18.763883748662835`}}], 
     Polygon3DBox[{{0, -9.92139672892996, -20.928392902929808`}, {
       0, -12.940952255126035`, -24.148145657226703`}, {0, 0., -25.}, {
       0, 0., -21.666666666666664`}, {
       0, -9.92139672892996, -20.928392902929808`}}], 
     Polygon3DBox[{{0, 0., -21.666666666666664`}, {0, 0., -25.}, {
       0, 12.940952255126035`, -24.148145657226703`}, {
       0, 9.92139672892996, -20.928392902929808`}, {
       0, 0., -21.666666666666664`}}], 
     Polygon3DBox[{{0, 9.92139672892996, -20.928392902929808`}, {
       0, 12.940952255126035`, -24.148145657226703`}, {
       0, 25., -21.650635094610962`}, {
       0, 19.166666666666664`, -18.763883748662835`}, {
       0, 9.92139672892996, -20.928392902929808`}}], 
     Polygon3DBox[{{0, 19.166666666666664`, -18.763883748662835`}, {
       0, 25., -21.650635094610962`}, {
       0, 35.35533905932737, -17.677669529663685`}, {
       0, 27.105759945484316`, -15.320646925708527`}, {
       0, 19.166666666666664`, -18.763883748662835`}}], 
     Polygon3DBox[{{0, 27.105759945484316`, -15.320646925708527`}, {
       0, 35.35533905932737, -17.677669529663685`}, {
       0, 43.30127018922193, -12.5}, {
       0, 33.19764047840348, -10.833333333333332`}, {
       0, 27.105759945484316`, -15.320646925708527`}}], 
     Polygon3DBox[{{0, 33.19764047840348, -10.833333333333332`}, {
       0, 43.30127018922193, -12.5}, {
       0, 48.29629131445341, -6.470476127563018}, {
       0, 37.02715667441428, -5.607745977221281}, {
       0, 33.19764047840348, -10.833333333333332`}}], 
     Polygon3DBox[{{0, 37.02715667441428, -5.607745977221281}, {
       0, 48.29629131445341, -6.470476127563018}, {0, 50., 0.}, {
       0, 38.33333333333333, 0.}, {
       0, 37.02715667441428, -5.607745977221281}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, 15., 0.}, {0, 14.488887394336025`, 3.882285676537811}, {
        0, 12.99038105676658, 7.499999999999999}, {
        0, 10.606601717798213`, 10.606601717798211`}, {
        0, 7.500000000000002, 12.990381056766578`}, {
        0, 3.8822856765378146`, 14.488887394336023`}, {
        0, 9.18485099360515*^-16, 15.}, {
        0, -3.8822856765378093`, 14.488887394336025`}, {
        0, -7.4999999999999964`, 12.99038105676658}, {
        0, -10.606601717798211`, 10.606601717798213`}, {
        0, -12.990381056766577`, 7.500000000000005}, {
        0, -14.488887394336023`, 3.882285676537815}, {
        0, -15., 1.83697019872103*^-15}, {
        0, -14.488887394336027`, -3.8822856765378053`}, {
        0, -12.990381056766582`, -7.499999999999996}, {
        0, -10.606601717798219`, -10.606601717798206`}, {
        0, -7.500000000000007, -12.990381056766577`}, {
        0, -3.8822856765378226`, -14.488887394336022`}, {
        0, -2.7554552980815444`*^-15, -15.}, {
        0, 3.8822856765378044`, -14.488887394336027`}, {
        0, 7.49999999999999, -12.990381056766585`}, {
        0, 10.60660171779821, -10.606601717798215`}, {
        0, 12.990381056766577`, -7.500000000000007}, {
        0, 14.488887394336022`, -3.8822856765378235`}, {
        0, 15., -3.67394039744206*^-15}}], 
      Line3DBox[{{0, 50., 0.}, {0, 48.29629131445341, 6.4704761275630185`}, {
        0, 43.30127018922194, 12.499999999999998`}, {
        0, 35.35533905932738, 17.677669529663685`}, {
        0, 25.000000000000007`, 21.650635094610966`}, {
        0, 12.940952255126048`, 24.148145657226706`}, {
        0, 3.061616997868383*^-15, 25.}, {
        0, -12.940952255126032`, 24.148145657226706`}, {
        0, -24.99999999999999, 21.65063509461097}, {
        0, -35.35533905932737, 17.67766952966369}, {
        0, -43.301270189221924`, 12.500000000000009`}, {
        0, -48.29629131445341, 6.470476127563026}, {
        0, -50., 3.061616997868383*^-15}, {
        0, -48.29629131445342, -6.470476127563009}, {
        0, -43.30127018922194, -12.499999999999993`}, {
        0, -35.35533905932739, -17.677669529663678`}, {
        0, -25.00000000000002, -21.65063509461096}, {
        0, -12.940952255126076`, -24.148145657226703`}, {
        0, -9.184850993605149*^-15, -25.}, {
        0, 12.940952255126014`, -24.14814565722671}, {
        0, 24.999999999999968`, -21.650635094610976`}, {
        0, 35.35533905932737, -17.677669529663692`}, {
        0, 43.30127018922192, -12.50000000000001}, {
        0, 48.296291314453406`, -6.470476127563039}, {
        0, 50., -6.123233995736766*^-15}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301469684018*^9, 3.6147092350862637`*^9, 
  3.614729091664864*^9},
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"During evaluation of In[121]:="]
}, Open  ]],

Cell["An elliptical aperture shape with a circular hole.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[TextData[{
 StyleBox["Similarly, you can list two negative numbers to designate an  \
elliptical hole.  Here we use an elliptical hole of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["{-50, -10}", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ParabolicMirror",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" with the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Hole", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" option.  We also use the ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["HoleOffset",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" option to position the hole away from the surface center by a \
distance of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["{15, 20}", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" units.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\tParabolicMirror[1000,100,30, Hole->{-30,-10}, HoleOffset->{15,20}],
\t\tBoxed->False];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"In[122]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.625, -50., 0.}, {30., -50., -3.552713678800501*^-15}, {
      30., -41.666666666666664`, 
      3.3333333333333286`}, {-0.43680555555555567`, -41.66666666666667, 
      3.333333333333333}, {-0.625, -50., 0.}}], 
     Polygon3DBox[{{-0.43680555555555567`, -41.66666666666667, 
      3.333333333333333}, {30., -41.666666666666664`, 3.3333333333333286`}, {
      30., -33.333333333333336`, 
      6.666666666666661}, {-0.2888888888888889, -33.333333333333336`, 
      6.666666666666666}, {-0.43680555555555567`, -41.66666666666667, 
      3.333333333333333}}], 
     Polygon3DBox[{{-0.2888888888888889, -33.333333333333336`, 
      6.666666666666666}, {30., -33.333333333333336`, 6.666666666666661}, {
      30., -25.000000000000007`, 9.999999999999995}, {-0.18125, -25., 
      10.}, {-0.2888888888888889, -33.333333333333336`, 6.666666666666666}}], 
     Polygon3DBox[{{-0.18125, -25., 10.}, {30., -25., 9.999999999999998}, {
      30., -16.666666666666668`, 
      13.33333333333333}, {-0.11388888888888891`, -16.66666666666667, 
      13.333333333333332`}, {-0.18125, -25., 10.}}], 
     Polygon3DBox[{{-0.11388888888888891`, -16.66666666666667, 
      13.333333333333332`}, {30., -16.666666666666668`, 13.33333333333333}, {
      30., -8.333333333333336, 
      16.666666666666664`}, {-0.08680555555555554, -8.333333333333336, 
      16.666666666666664`}, {-0.11388888888888891`, -16.66666666666667, 
      13.333333333333332`}}], 
     Polygon3DBox[{{-0.08680555555555554, -8.333333333333336, 
      16.666666666666664`}, {30., -8.333333333333337, 16.666666666666664`}, {
      30., -4.163336342344337*^-15, 
      20.}, {-0.09999999999999998, -7.105427357601002*^-15, 
      19.999999999999996`}, {-0.08680555555555554, -8.333333333333336, 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhh4sh9Cex6AifjM/+I5/8vt/WGhQHDV5cAqMOBy
uKxeewmI9q8G8x2g4lIOxmBwHGqOJdQcFYd6kGr1vfvXgNUZQNVrOfQ+tuh7
bLENKq4AFTdwmDUTBHbuZ0ABJg4Q2s4Bl/gqNHNQxRH2oppjeeA/GCijqXc4
sALqL5h4KDQcVkDDAdUcWLh92IMrPAFZtnkM
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.325, 30., 20.}, {30., 30., 20.000000000000004`}, {
        30., 33.333333333333336`, 
        16.666666666666668`}, {-0.34722222222222227`, 33.333333333333336`, 
        16.666666666666668`}, {-0.325, 30., 20.}}], 
       Polygon3DBox[{{-0.34722222222222227`, 33.333333333333336`, 
        16.666666666666668`}, {30., 33.333333333333336`, 
        16.666666666666668`}, {30., 36.666666666666664`, 
        13.333333333333337`}, {-0.38055555555555554`, 36.666666666666664`, 
        13.333333333333334`}, {-0.34722222222222227`, 33.333333333333336`, 
        16.666666666666668`}}], 
       Polygon3DBox[{{-0.38055555555555554`, 36.666666666666664`, 
        13.333333333333334`}, {30., 36.666666666666664`, 
        13.333333333333337`}, {30., 40., 10.000000000000004`}, {-0.425, 40., 
        10.}, {-0.38055555555555554`, 36.666666666666664`, 
        13.333333333333334`}}], 
       Polygon3DBox[{{-0.425, 40., 10.}, {30., 40., 10.000000000000002`}, {
        30., 43.33333333333333, 6.666666666666669}, {-0.4805555555555557, 
        43.333333333333336`, 6.666666666666668}, {-0.425, 40., 10.}}], 
       Polygon3DBox[{{-0.4805555555555557, 43.333333333333336`, 
        6.666666666666668}, {30., 43.33333333333333, 6.666666666666669}, {30.,
         46.666666666666664`, 3.3333333333333344`}, {-0.5472222222222222, 
        46.666666666666664`, 3.3333333333333357`}, {-0.4805555555555557, 
        43.333333333333336`, 6.666666666666668}}], 
       Polygon3DBox[{{-0.5472222222222222, 46.666666666666664`, 
        3.3333333333333357`}, {30., 46.666666666666664`, 3.333333333333335}, {
        30., 50., 1.665334536937735*^-15}, {-0.625, 50., 
        3.552713678800501*^-15}, {-0.5472222222222222, 46.666666666666664`, 
        3.3333333333333357`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID57BgSu7GcAAzsHCG3i0P/You+xxbX9q1eBgIMD
hDZw2MAaDUQ39oeCgRNUXMvBGAxuQ81xgZqj4iCZc1As5+A9qDmuDmvAtJSD
/o0m3RtND/eHgc1xd9gAFueC6nsCNccTyocBmPswxUOh5qxGMcfOAWbvaqi9
qOa4ODBC3QkTD0PzF6o5iHBANccOao6JA67wBAAmP2x6
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{-0.625, 0., -50.}, {30., 
          5.329070518200751*^-15, -50.}, {30., 
          2.5000000000000036`, -39.16666666666667}, {-0.3850694444444445, 
          2.5, -39.16666666666667}, {-0.625, 0., -50.}}], 
         Polygon3DBox[{{-0.3850694444444445, 2.5, -39.16666666666667}, {30., 
          2.5000000000000036`, -39.16666666666667}, {30., 
          5.0000000000000036`, -28.333333333333336`}, {-0.2069444444444445, 
          5., -28.333333333333336`}, {-0.3850694444444445, 
          2.5, -39.16666666666667}}], 
         Polygon3DBox[{{-0.2069444444444445, 5., -28.333333333333336`}, {30., 
          5.0000000000000036`, -28.333333333333336`}, {30., 
          7.500000000000001, -17.500000000000007`}, {-0.090625, 
          7.500000000000001, -17.5}, {-0.2069444444444445, 
          5., -28.333333333333336`}}], 
         Polygon3DBox[{{-0.090625, 7.500000000000001, -17.5}, {30., 
          7.500000000000003, -17.5}, {30., 
          10.000000000000002`, -6.666666666666668}, {-0.03611111111111113, 
          10., -6.666666666666671}, {-0.090625, 7.500000000000001, -17.5}}], 
         Polygon3DBox[{{-0.03611111111111113, 10., -6.666666666666671}, {30., 
          10.000000000000002`, -6.666666666666668}, {30., 12.5, 
          4.166666666666664}, {-0.04340277777777778, 12.500000000000002`, 
          4.166666666666664}, {-0.03611111111111113, 
          10., -6.666666666666671}}], 
         Polygon3DBox[{{-0.04340277777777778, 12.500000000000002`, 
          4.166666666666664}, {30., 12.5, 4.1666666666666625`}, {30., 
          14.999999999999998`, 14.999999999999995`}, {-0.11249999999999989`, 
          14.999999999999998`, 14.999999999999986`}, {-0.04340277777777778, 
          12.500000000000002`, 4.166666666666664}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhh4sp8BBXgeCPy1xP/XkhtQcRaHsFAgmOp84Ip6
7SX12lNQcRGIeKjNAXNjENi+/z8YyDqA7GBoMDxwFax+EVS9isOGVSAgdaD/
sUXfY4tl+xnB4poOK8DiAg5Hz4DAHqg5ug4/oDREvx2U1kOj7Rxg5qyBmgMT
Z4LauwJqL0ycFUzLOfwDGV9vCBdng/orBOovmDgPNBxCoeGA6h4WW7A5/z0O
4ApPAPHIa30=
           "]], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{-0.2125, 15., 25.}, {30., 14.999999999999998`, 
            25.}, {30., 12.499999999999998`, 
            29.166666666666664`}, {-0.2517361111111111, 12.5, 
            29.166666666666668`}, {-0.2125, 15., 25.}}], 
           Polygon3DBox[{{-0.2517361111111111, 12.5, 29.166666666666668`}, {
            30., 12.499999999999998`, 29.166666666666664`}, {30., 10., 
            33.33333333333333}, {-0.3027777777777778, 10.000000000000002`, 
            33.333333333333336`}, {-0.2517361111111111, 12.5, 
            29.166666666666668`}}], 
           Polygon3DBox[{{-0.3027777777777778, 10.000000000000002`, 
            33.333333333333336`}, {30., 10., 33.33333333333333}, {30., 
            7.500000000000001, 37.5}, {-0.36562500000000003`, 
            7.500000000000003, 37.5}, {-0.3027777777777778, 
            10.000000000000002`, 33.333333333333336`}}], 
           Polygon3DBox[{{-0.36562500000000003`, 7.500000000000003, 37.5}, {
            30., 7.499999999999999, 37.5}, {30., 5., 
            41.666666666666664`}, {-0.4402777777777779, 5.0000000000000036`, 
            41.66666666666667}, {-0.36562500000000003`, 7.500000000000003, 
            37.5}}], 
           Polygon3DBox[{{-0.4402777777777779, 5.0000000000000036`, 
            41.66666666666667}, {30., 5., 41.666666666666664`}, {30., 
            2.5000000000000004`, 45.83333333333333}, {-0.5267361111111112, 
            2.5000000000000053`, 45.833333333333336`}, {-0.4402777777777779, 
            5.0000000000000036`, 41.66666666666667}}], 
           Polygon3DBox[{{-0.5267361111111112, 2.5000000000000053`, 
            45.833333333333336`}, {30., 2.500000000000001, 
            45.83333333333333}, {30., 1.2490009027033011`*^-15, 50.}, {-0.625,
             7.105427357601002*^-15, 50.}, {-0.5267361111111112, 
            2.5000000000000053`, 45.833333333333336`}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDYGg9P7GcBAzwFCWzocL5QBogtQcU2H1auAQMvW
gWdbAve2hMv7GcHiKhDxVQ4O6WkgcH0/M1hcDmLOASeHW026N5p07+xnAQuI
OISFAsFVF4eNrNEbWG8/2M8DFmeBmPPKDWr/E6i9P2wgtCdU3A5KwwBC/D8Y
MKOZAxMXhtuLKi4LdyequDLcXzDxf2BxDXg4oKrXhYcbrvAEADUdcKU=
             
             "]]}}}}}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.325, 30., 20.}, {-0.38055555555555554`, 
      36.666666666666664`, 13.333333333333334`}, {-0.40531141522160663`, 
      35.75802203437515, 18.509714235383747`}, {-0.33075824280725713`, 
      29.48888739433602, 21.294095225512603`}, {-0.325, 30., 20.}}], 
     Polygon3DBox[{{-0.33075824280725713`, 29.48888739433602, 
      21.294095225512603`}, {-0.40531141522160663`, 35.75802203437515, 
      18.509714235383747`}, {-0.4099144982823696, 33.09401076758503, 
      23.333333333333332`}, {-0.32242785792574935`, 27.99038105676658, 
      22.5}, {-0.33075824280725713`, 29.48888739433602, 
      21.294095225512603`}}], 
     Polygon3DBox[{{-0.32242785792574935`, 27.99038105676658, 
      22.5}, {-0.4099144982823696, 33.09401076758503, 
      23.333333333333332`}, {-0.39689514164974593`, 28.856180831641264`, 
      27.475468957064283`}, {-0.302404851942814, 25.606601717798213`, 
      23.535533905932738`}, {-0.32242785792574935`, 27.99038105676658, 
      22.5}}], Polygon3DBox[{{-0.302404851942814, 25.606601717798213`, 
      23.535533905932738`}, {-0.39689514164974593`, 28.856180831641264`, 
      27.475468957064283`}, {-0.3710256093934808, 23.333333333333336`, 
      30.653841409022107`}, {-0.2745512701892219, 22.5, 
      24.33012701892219}, {-0.302404851942814, 25.606601717798213`, 
      23.535533905932738`}}], 
     Polygon3DBox[{{-0.2745512701892219, 22.5, 
      24.33012701892219}, {-0.3710256093934808, 23.333333333333336`, 
      30.653841409022107`}, {-0.3379538838161503, 16.901841202733884`, 
      32.6518498591147}, {-0.24326279879387602`, 18.882285676537812`, 
      24.82962913144534}, {-0.2745512701892219, 22.5, 24.33012701892219}}], 
     Polygon3DBox[{{-0.24326279879387602`, 18.882285676537812`, 
      24.82962913144534}, {-0.3379538838161503, 16.901841202733884`, 
      32.6518498591147}, {-0.3027777777777777, 10., 
      33.33333333333333}, {-0.2125, 15., 25.}, {-0.24326279879387602`, 
      18.882285676537812`, 24.82962913144534}}], 
     Polygon3DBox[{{-0.2125, 15., 25.}, {-0.3027777777777777, 10., 
      33.33333333333333}, {-0.2689354717888115, 3.098158797266116, 
      32.6518498591147}, {-0.18502851364580886`, 11.11771432346219, 
      24.82962913144534}, {-0.2125, 15., 25.}}], 
     Polygon3DBox[{{-0.18502851364580886`, 11.11771432346219, 
      24.82962913144534}, {-0.2689354717888115, 3.098158797266116, 
      32.6518498591147}, {-0.2376922760601474, -3.333333333333332, 
      30.653841409022107`}, {-0.16205127018922189`, 7.5, 
      24.33012701892219}, {-0.18502851364580886`, 11.11771432346219, 
      24.82962913144534}}], 
     Polygon3DBox[{{-0.16205127018922189`, 7.5, 
      24.33012701892219}, {-0.2376922760601474, -3.333333333333332, 
      30.653841409022107`}, {-0.20833333333333331`, -8.856180831641268, 
      27.475468957064283`}, {-0.14330582617584078`, 4.3933982822017885`, 
      23.535533905932738`}, {-0.16205127018922189`, 7.5, 24.33012701892219}}],
      Polygon3DBox[{{-0.14330582617584078`, 4.3933982822017885`, 
      23.535533905932738`}, {-0.20833333333333331`, -8.856180831641268, 
      27.475468957064283`}, {-0.17897439060651926`, -13.094010767585026`, 
      23.333333333333332`}, {-0.12757214207425066`, 2.0096189432334217`, 
      22.5}, {-0.14330582617584078`, 4.3933982822017885`, 
      23.535533905932738`}}], 
     Polygon3DBox[{{-0.12757214207425066`, 2.0096189432334217`, 
      22.5}, {-0.17897439060651926`, -13.094010767585026`, 
      23.333333333333332`}, {-0.1477311948778551, -15.758022034375148`, 
      18.509714235383747`}, {-0.11342493189221681`, 0.5111126056639783, 
      21.294095225512603`}, {-0.12757214207425066`, 2.0096189432334217`, 
      22.5}}], Polygon3DBox[{{-0.11342493189221681`, 0.5111126056639783, 
      21.294095225512603`}, {-0.1477311948778551, -15.758022034375148`, 
      18.509714235383747`}, {-0.11388888888888889`, -16.666666666666664`, 
      13.333333333333334`}, {-0.1, 0., 20.}, {-0.11342493189221681`, 
      0.5111126056639783, 21.294095225512603`}}], 
     Polygon3DBox[{{-0.1, 0., 
      20.}, {-0.11388888888888889`, -16.666666666666664`, 
      13.333333333333334`}, {-0.07871278285051626, -15.758022034375148`, 
      8.156952431282921}, {-0.08754302738196475, 0.5111126056639783, 
      18.705904774487397`}, {-0.1, 0., 20.}}], 
     Polygon3DBox[{{-0.08754302738196475, 0.5111126056639783, 
      18.705904774487397`}, {-0.07871278285051626, -15.758022034375148`, 
      8.156952431282921}, {-0.04564105727318593, -13.094010767585026`, 
      3.3333333333333357`}, {-0.07757214207425066, 2.0096189432334217`, 
      17.5}, {-0.08754302738196475, 0.5111126056639783, 
      18.705904774487397`}}], 
     Polygon3DBox[{{-0.07757214207425066, 2.0096189432334217`, 
      17.5}, {-0.04564105727318593, -13.094010767585026`, 
      3.3333333333333357`}, {-0.019771525016920664`, -8.856180831641268, \
-0.8088022903976153}, {-0.07259514805718602, 4.3933982822017885`, 
      16.464466094067262`}, {-0.07757214207425066, 2.0096189432334217`, 
      17.5}}], Polygon3DBox[{{-0.07259514805718602, 4.3933982822017885`, 
      16.464466094067262`}, {-0.019771525016920664`, -8.856180831641268, \
-0.8088022903976153}, {-0.00675216838429706, -3.333333333333332, \
-3.9871747423554353`}, {-0.07544872981077808, 7.5, 
      15.669872981077807`}, {-0.07259514805718602, 4.3933982822017885`, 
      16.464466094067262`}}], 
     Polygon3DBox[{{-0.07544872981077808, 7.5, 
      15.669872981077807`}, {-0.00675216838429706, -3.333333333333332, \
-3.9871747423554353`}, {-0.011355251445059954`, 
      3.098158797266116, -5.98518319244803}, {-0.08843593101690204, 
      11.11771432346219, 15.17037086855466}, {-0.07544872981077808, 7.5, 
      15.669872981077807`}}], 
     Polygon3DBox[{{-0.08843593101690204, 11.11771432346219, 
      15.17037086855466}, {-0.011355251445059954`, 
      3.098158797266116, -5.98518319244803}, {-0.0361111111111111, 
      10., -6.666666666666664}, {-0.1125, 15., 15.}, {-0.08843593101690204, 
      11.11771432346219, 15.17037086855466}}], 
     Polygon3DBox[{{-0.1125, 15., 15.}, {-0.0361111111111111, 
      10., -6.666666666666664}, {-0.0803736634723988, 
      16.901841202733884`, -5.98518319244803}, {-0.14667021616496922`, 
      18.882285676537812`, 15.17037086855466}, {-0.1125, 15., 15.}}], 
     Polygon3DBox[{{-0.14667021616496922`, 18.882285676537812`, 
      15.17037086855466}, {-0.0803736634723988, 
      16.901841202733884`, -5.98518319244803}, {-0.14008550171763043`, 
      23.333333333333336`, -3.9871747423554353`}, {-0.1879487298107781, 22.5, 
      15.669872981077807`}, {-0.14667021616496922`, 18.882285676537812`, 
      15.17037086855466}}], 
     Polygon3DBox[{{-0.1879487298107781, 22.5, 
      15.669872981077807`}, {-0.14008550171763043`, 
      23.333333333333336`, -3.9871747423554353`}, {-0.20833333333333331`, 
      28.856180831641264`, -0.8088022903976153}, {-0.23169417382415924`, 
      25.606601717798213`, 16.464466094067262`}, {-0.1879487298107781, 22.5, 
      15.669872981077807`}}], 
     Polygon3DBox[{{-0.23169417382415924`, 25.606601717798213`, 
      16.464466094067262`}, {-0.20833333333333331`, 
      28.856180831641264`, -0.8088022903976153}, {-0.2765811649490363, 
      33.09401076758503, 3.3333333333333357`}, {-0.2724278579257493, 
      27.99038105676658, 17.5}, {-0.23169417382415924`, 25.606601717798213`, 
      16.464466094067262`}}], 
     Polygon3DBox[{{-0.2724278579257493, 27.99038105676658, 
      17.5}, {-0.2765811649490363, 33.09401076758503, 
      3.3333333333333357`}, {-0.3362930031942678, 35.75802203437515, 
      8.156952431282921}, {-0.30487633829700506`, 29.48888739433602, 
      18.705904774487397`}, {-0.2724278579257493, 27.99038105676658, 17.5}}], 
     Polygon3DBox[{{-0.30487633829700506`, 29.48888739433602, 
      18.705904774487397`}, {-0.3362930031942678, 35.75802203437515, 
      8.156952431282921}, {-0.38055555555555554`, 36.666666666666664`, 
      13.333333333333334`}, {-0.325, 30., 20.}, {-0.30487633829700506`, 
      29.48888739433602, 18.705904774487397`}}], 
     Polygon3DBox[{{-0.38055555555555554`, 36.666666666666664`, 
      13.333333333333334`}, {-0.48055555555555546`, 43.33333333333333, 
      6.666666666666668}, {-0.5033920009525209, 42.02715667441428, 
      15.725333245254891`}, {-0.40531141522160663`, 35.75802203437515, 
      18.509714235383747`}, {-0.38055555555555554`, 36.666666666666664`, 
      13.333333333333334`}}], 
     Polygon3DBox[{{-0.40531141522160663`, 35.75802203437515, 
      18.509714235383747`}, {-0.5033920009525209, 42.02715667441428, 
      15.725333245254891`}, {-0.5107718789737865, 38.19764047840348, 
      24.166666666666664`}, {-0.4099144982823696, 33.09401076758503, 
      23.333333333333332`}, {-0.40531141522160663`, 35.75802203437515, 
      18.509714235383747`}}], 
     Polygon3DBox[{{-0.4099144982823696, 33.09401076758503, 
      23.333333333333332`}, {-0.5107718789737865, 38.19764047840348, 
      24.166666666666664`}, {-0.504426857668808, 32.10575994548432, 
      31.41540400819583}, {-0.39689514164974593`, 28.856180831641264`, 
      27.475468957064283`}, {-0.4099144982823696, 33.09401076758503, 
      23.333333333333332`}}], 
     Polygon3DBox[{{-0.39689514164974593`, 28.856180831641264`, 
      27.475468957064283`}, {-0.504426857668808, 32.10575994548432, 
      31.41540400819583}, {-0.4878418526637399, 24.166666666666664`, 
      36.977555799122015`}, {-0.3710256093934808, 23.333333333333336`, 
      30.653841409022107`}, {-0.39689514164974593`, 28.856180831641264`, 
      27.475468957064283`}}], 
     Polygon3DBox[{{-0.3710256093934808, 23.333333333333336`, 
      30.653841409022107`}, {-0.4878418526637399, 24.166666666666664`, 
      36.977555799122015`}, {-0.46519961755152484`, 14.92139672892996, 
      40.47407058678405}, {-0.3379538838161503, 16.901841202733884`, 
      32.6518498591147}, {-0.3710256093934808, 23.333333333333336`, 
      30.653841409022107`}}], 
     Polygon3DBox[{{-0.3379538838161503, 16.901841202733884`, 
      32.6518498591147}, {-0.46519961755152484`, 14.92139672892996, 
      40.47407058678405}, {-0.4402777777777777, 5., 
      41.666666666666664`}, {-0.3027777777777777, 10., 
      33.33333333333333}, {-0.3379538838161503, 16.901841202733884`, 
      32.6518498591147}}], 
     Polygon3DBox[{{-0.3027777777777777, 10., 
      33.33333333333333}, {-0.4402777777777777, 5., 
      41.666666666666664`}, {-0.41559263390687506`, -4.921396728929956, 
      40.47407058678405}, {-0.2689354717888115, 3.098158797266116, 
      32.6518498591147}, {-0.3027777777777777, 10., 33.33333333333333}}], 
     Polygon3DBox[{{-0.2689354717888115, 3.098158797266116, 
      32.6518498591147}, {-0.41559263390687506`, -4.921396728929956, 
      40.47407058678405}, {-0.39200851933040665`, -14.166666666666664`, 
      36.977555799122015`}, {-0.2376922760601474, -3.333333333333332, 
      30.653841409022107`}, {-0.2689354717888115, 3.098158797266116, 
      32.6518498591147}}], 
     Polygon3DBox[{{-0.2376922760601474, -3.333333333333332, 
      30.653841409022107`}, {-0.39200851933040665`, -14.166666666666664`, 
      36.977555799122015`}, {-0.3688980579413864, -22.105759945484323`, 
      31.41540400819583}, {-0.20833333333333331`, -8.856180831641268, 
      27.475468957064283`}, {-0.2376922760601474, -3.333333333333332, 
      30.653841409022107`}}], 
     Polygon3DBox[{{-0.20833333333333331`, -8.856180831641268, 
      27.475468957064283`}, {-0.3688980579413864, -22.105759945484323`, 
      31.41540400819583}, {-0.344783676581769, -28.19764047840348, 
      24.166666666666664`}, {-0.17897439060651926`, -13.094010767585026`, 
      23.333333333333332`}, {-0.20833333333333331`, -8.856180831641268, 
      27.475468957064283`}}], 
     Polygon3DBox[{{-0.17897439060651926`, -13.094010767585026`, 
      23.333333333333332`}, {-0.344783676581769, -28.19764047840348, 
      24.166666666666664`}, {-0.3182562175804493, -32.02715667441427, 
      15.725333245254891`}, {-0.1477311948778551, -15.758022034375148`, 
      18.509714235383747`}, {-0.17897439060651926`, -13.094010767585026`, 
      23.333333333333332`}}], 
     Polygon3DBox[{{-0.1477311948778551, -15.758022034375148`, 
      18.509714235383747`}, {-0.3182562175804493, -32.02715667441427, 
      15.725333245254891`}, {-0.2888888888888888, -33.33333333333333, 
      6.666666666666668}, {-0.11388888888888889`, -16.666666666666664`, 
      13.333333333333334`}, {-0.1477311948778551, -15.758022034375148`, 
      18.509714235383747`}}], 
     Polygon3DBox[{{-0.11388888888888889`, -16.666666666666664`, 
      13.333333333333334`}, {-0.2888888888888888, -33.33333333333333, 
      6.666666666666668}, {-0.2578651070565278, -32.02715667441427, \
-2.3919999119215554`}, {-0.07871278285051626, -15.758022034375148`, 
      8.156952431282921}, {-0.11388888888888889`, -16.666666666666664`, 
      13.333333333333334`}}], 
     Polygon3DBox[{{-0.07871278285051626, -15.758022034375148`, 
      8.156952431282921}, {-0.2578651070565278, -32.02715667441427, \
-2.3919999119215554`}, {-0.22811700991510236`, -28.19764047840348, \
-10.833333333333332`}, {-0.04564105727318593, -13.094010767585026`, 
      3.3333333333333357`}, {-0.07871278285051626, -15.758022034375148`, 
      8.156952431282921}}], 
     Polygon3DBox[{{-0.04564105727318593, -13.094010767585026`, 
      3.3333333333333357`}, {-0.22811700991510236`, -28.19764047840348, \
-10.833333333333332`}, {-0.20390647566452533`, -22.105759945484323`, \
-18.082070674862493`}, {-0.019771525016920664`, -8.856180831641268, \
-0.8088022903976153}, {-0.04564105727318593, -13.094010767585026`, 
      3.3333333333333357`}}], 
     Polygon3DBox[{{-0.019771525016920664`, -8.856180831641268, \
-0.8088022903976153}, {-0.20390647566452533`, -22.105759945484323`, \
-18.082070674862493`}, {-0.18993592511403762`, -14.166666666666664`, \
-23.64422246578868}, {-0.00675216838429706, -3.333333333333332, \
-3.9871747423554353`}, {-0.019771525016920664`, -8.856180831641268, \
-0.8088022903976153}}], 
     Polygon3DBox[{{-0.00675216838429706, -3.333333333333332, \
-3.9871747423554353`}, {-0.18993592511403762`, -14.166666666666664`, \
-23.64422246578868}, {-0.1902099411060926, -4.921396728929956, \
-27.140737253450723`}, {-0.011355251445059954`, 
      3.098158797266116, -5.98518319244803}, {-0.00675216838429706, \
-3.333333333333332, -3.9871747423554353`}}], 
     Polygon3DBox[{{-0.011355251445059954`, 
      3.098158797266116, -5.98518319244803}, {-0.1902099411060926, \
-4.921396728929956, -27.140737253450723`}, {-0.20694444444444438`, 
      5., -28.33333333333333}, {-0.0361111111111111, 
      10., -6.666666666666664}, {-0.011355251445059954`, 
      3.098158797266116, -5.98518319244803}}], 
     Polygon3DBox[{{-0.0361111111111111, 
      10., -6.666666666666664}, {-0.20694444444444438`, 
      5., -28.33333333333333}, {-0.2398169247507424, 
      14.92139672892996, -27.140737253450723`}, {-0.0803736634723988, 
      16.901841202733884`, -5.98518319244803}, {-0.0361111111111111, 
      10., -6.666666666666664}}], 
     Polygon3DBox[{{-0.0803736634723988, 
      16.901841202733884`, -5.98518319244803}, {-0.2398169247507424, 
      14.92139672892996, -27.140737253450723`}, {-0.28576925844737094`, 
      24.166666666666664`, -23.64422246578868}, {-0.14008550171763043`, 
      23.333333333333336`, -3.9871747423554353`}, {-0.0803736634723988, 
      16.901841202733884`, -5.98518319244803}}], 
     Polygon3DBox[{{-0.14008550171763043`, 
      23.333333333333336`, -3.9871747423554353`}, {-0.28576925844737094`, 
      24.166666666666664`, -23.64422246578868}, {-0.3394352753919469, 
      32.10575994548432, -18.082070674862493`}, {-0.20833333333333331`, 
      28.856180831641264`, -0.8088022903976153}, {-0.14008550171763043`, 
      23.333333333333336`, -3.9871747423554353`}}], 
     Polygon3DBox[{{-0.20833333333333331`, 
      28.856180831641264`, -0.8088022903976153}, {-0.3394352753919469, 
      32.10575994548432, -18.082070674862493`}, {-0.39410521230711976`, 
      38.19764047840348, -10.833333333333332`}, {-0.2765811649490363, 
      33.09401076758503, 3.3333333333333357`}, {-0.20833333333333331`, 
      28.856180831641264`, -0.8088022903976153}}], 
     Polygon3DBox[{{-0.2765811649490363, 33.09401076758503, 
      3.3333333333333357`}, {-0.39410521230711976`, 
      38.19764047840348, -10.833333333333332`}, {-0.4430008904285994, 
      42.02715667441428, -2.3919999119215554`}, {-0.3362930031942678, 
      35.75802203437515, 8.156952431282921}, {-0.2765811649490363, 
      33.09401076758503, 3.3333333333333357`}}], 
     Polygon3DBox[{{-0.3362930031942678, 35.75802203437515, 
      8.156952431282921}, {-0.4430008904285994, 
      42.02715667441428, -2.3919999119215554`}, {-0.48055555555555546`, 
      43.33333333333333, 6.666666666666668}, {-0.38055555555555554`, 
      36.666666666666664`, 13.333333333333334`}, {-0.3362930031942678, 
      35.75802203437515, 8.156952431282921}}], 
     Polygon3DBox[{{-0.48055555555555546`, 43.33333333333333, 
      6.666666666666668}, {-0.625, 50., 0.}, {-0.6249999999999999, 
      48.29629131445341, 12.940952255126035`}, {-0.5033920009525209, 
      42.02715667441428, 15.725333245254891`}, {-0.48055555555555546`, 
      43.33333333333333, 6.666666666666668}}], 
     Polygon3DBox[{{-0.5033920009525209, 42.02715667441428, 
      15.725333245254891`}, {-0.6249999999999999, 48.29629131445341, 
      12.940952255126035`}, {-0.625, 43.30127018922193, 
      25.}, {-0.5107718789737865, 38.19764047840348, 
      24.166666666666664`}, {-0.5033920009525209, 42.02715667441428, 
      15.725333245254891`}}], 
     Polygon3DBox[{{-0.5107718789737865, 38.19764047840348, 
      24.166666666666664`}, {-0.625, 43.30127018922193, 
      25.}, {-0.6249999999999999, 35.35533905932737, 
      35.35533905932738}, {-0.504426857668808, 32.10575994548432, 
      31.41540400819583}, {-0.5107718789737865, 38.19764047840348, 
      24.166666666666664`}}], 
     Polygon3DBox[{{-0.504426857668808, 32.10575994548432, 
      31.41540400819583}, {-0.6249999999999999, 35.35533905932737, 
      35.35533905932738}, {-0.625, 25., 
      43.30127018922193}, {-0.4878418526637399, 24.166666666666664`, 
      36.977555799122015`}, {-0.504426857668808, 32.10575994548432, 
      31.41540400819583}}], 
     Polygon3DBox[{{-0.4878418526637399, 24.166666666666664`, 
      36.977555799122015`}, {-0.625, 25., 
      43.30127018922193}, {-0.6249999999999999, 12.940952255126035`, 
      48.29629131445341}, {-0.46519961755152484`, 14.92139672892996, 
      40.47407058678405}, {-0.4878418526637399, 24.166666666666664`, 
      36.977555799122015`}}], 
     Polygon3DBox[{{-0.46519961755152484`, 14.92139672892996, 
      40.47407058678405}, {-0.6249999999999999, 12.940952255126035`, 
      48.29629131445341}, {-0.625, 0., 50.}, {-0.4402777777777777, 5., 
      41.666666666666664`}, {-0.46519961755152484`, 14.92139672892996, 
      40.47407058678405}}], 
     Polygon3DBox[{{-0.4402777777777777, 5., 41.666666666666664`}, {-0.625, 
      0., 50.}, {-0.6249999999999999, -12.940952255126035`, 
      48.29629131445341}, {-0.41559263390687506`, -4.921396728929956, 
      40.47407058678405}, {-0.4402777777777777, 5., 41.666666666666664`}}], 
     Polygon3DBox[{{-0.41559263390687506`, -4.921396728929956, 
      40.47407058678405}, {-0.6249999999999999, -12.940952255126035`, 
      48.29629131445341}, {-0.625, -25., 
      43.30127018922193}, {-0.39200851933040665`, -14.166666666666664`, 
      36.977555799122015`}, {-0.41559263390687506`, -4.921396728929956, 
      40.47407058678405}}], 
     Polygon3DBox[{{-0.39200851933040665`, -14.166666666666664`, 
      36.977555799122015`}, {-0.625, -25., 
      43.30127018922193}, {-0.625, -35.35533905932738, 
      35.35533905932738}, {-0.3688980579413864, -22.105759945484323`, 
      31.41540400819583}, {-0.39200851933040665`, -14.166666666666664`, 
      36.977555799122015`}}], 
     Polygon3DBox[{{-0.3688980579413864, -22.105759945484323`, 
      31.41540400819583}, {-0.625, -35.35533905932738, 
      35.35533905932738}, {-0.625, -43.30127018922193, 
      25.}, {-0.344783676581769, -28.19764047840348, 
      24.166666666666664`}, {-0.3688980579413864, -22.105759945484323`, 
      31.41540400819583}}], 
     Polygon3DBox[{{-0.344783676581769, -28.19764047840348, 
      24.166666666666664`}, {-0.625, -43.30127018922193, 
      25.}, {-0.6249999999999999, -48.29629131445341, 
      12.940952255126035`}, {-0.3182562175804493, -32.02715667441427, 
      15.725333245254891`}, {-0.344783676581769, -28.19764047840348, 
      24.166666666666664`}}], 
     Polygon3DBox[{{-0.3182562175804493, -32.02715667441427, 
      15.725333245254891`}, {-0.6249999999999999, -48.29629131445341, 
      12.940952255126035`}, {-0.625, -50., 
      0.}, {-0.2888888888888888, -33.33333333333333, 
      6.666666666666668}, {-0.3182562175804493, -32.02715667441427, 
      15.725333245254891`}}], 
     Polygon3DBox[{{-0.2888888888888888, -33.33333333333333, 
      6.666666666666668}, {-0.625, -50., 
      0.}, {-0.6249999999999999, -48.29629131445341, -12.940952255126035`}, \
{-0.2578651070565278, -32.02715667441427, -2.3919999119215554`}, \
{-0.2888888888888888, -33.33333333333333, 6.666666666666668}}], 
     Polygon3DBox[{{-0.2578651070565278, -32.02715667441427, \
-2.3919999119215554`}, {-0.6249999999999999, -48.29629131445341, \
-12.940952255126035`}, {-0.625, -43.30127018922193, -25.}, \
{-0.22811700991510236`, -28.19764047840348, -10.833333333333332`}, \
{-0.2578651070565278, -32.02715667441427, -2.3919999119215554`}}], 
     Polygon3DBox[{{-0.22811700991510236`, -28.19764047840348, \
-10.833333333333332`}, {-0.625, -43.30127018922193, -25.}, {-0.625, \
-35.35533905932738, -35.35533905932738}, {-0.20390647566452533`, \
-22.105759945484323`, -18.082070674862493`}, {-0.22811700991510236`, \
-28.19764047840348, -10.833333333333332`}}], 
     Polygon3DBox[{{-0.20390647566452533`, -22.105759945484323`, \
-18.082070674862493`}, {-0.625, -35.35533905932738, -35.35533905932738}, \
{-0.625, -25., -43.30127018922193}, {-0.18993592511403762`, \
-14.166666666666664`, -23.64422246578868}, {-0.20390647566452533`, \
-22.105759945484323`, -18.082070674862493`}}], 
     Polygon3DBox[{{-0.18993592511403762`, -14.166666666666664`, \
-23.64422246578868}, {-0.625, -25., -43.30127018922193}, \
{-0.6249999999999999, -12.940952255126035`, -48.29629131445341}, \
{-0.1902099411060926, -4.921396728929956, -27.140737253450723`}, \
{-0.18993592511403762`, -14.166666666666664`, -23.64422246578868}}], 
     Polygon3DBox[{{-0.1902099411060926, -4.921396728929956, \
-27.140737253450723`}, {-0.6249999999999999, -12.940952255126035`, \
-48.29629131445341}, {-0.625, 0., -50.}, {-0.20694444444444438`, 
      5., -28.33333333333333}, {-0.1902099411060926, -4.921396728929956, \
-27.140737253450723`}}], 
     Polygon3DBox[{{-0.20694444444444438`, 5., -28.33333333333333}, {-0.625, 
      0., -50.}, {-0.6249999999999999, 
      12.940952255126035`, -48.29629131445341}, {-0.2398169247507424, 
      14.92139672892996, -27.140737253450723`}, {-0.20694444444444438`, 
      5., -28.33333333333333}}], 
     Polygon3DBox[{{-0.2398169247507424, 
      14.92139672892996, -27.140737253450723`}, {-0.6249999999999999, 
      12.940952255126035`, -48.29629131445341}, {-0.625, 
      25., -43.30127018922193}, {-0.28576925844737094`, 
      24.166666666666664`, -23.64422246578868}, {-0.2398169247507424, 
      14.92139672892996, -27.140737253450723`}}], 
     Polygon3DBox[{{-0.28576925844737094`, 
      24.166666666666664`, -23.64422246578868}, {-0.625, 
      25., -43.30127018922193}, {-0.6249999999999999, 
      35.35533905932737, -35.35533905932738}, {-0.3394352753919469, 
      32.10575994548432, -18.082070674862493`}, {-0.28576925844737094`, 
      24.166666666666664`, -23.64422246578868}}], 
     Polygon3DBox[{{-0.3394352753919469, 
      32.10575994548432, -18.082070674862493`}, {-0.6249999999999999, 
      35.35533905932737, -35.35533905932738}, {-0.625, 
      43.30127018922193, -25.}, {-0.39410521230711976`, 
      38.19764047840348, -10.833333333333332`}, {-0.3394352753919469, 
      32.10575994548432, -18.082070674862493`}}], 
     Polygon3DBox[{{-0.39410521230711976`, 
      38.19764047840348, -10.833333333333332`}, {-0.625, 
      43.30127018922193, -25.}, {-0.6249999999999999, 
      48.29629131445341, -12.940952255126035`}, {-0.4430008904285994, 
      42.02715667441428, -2.3919999119215554`}, {-0.39410521230711976`, 
      38.19764047840348, -10.833333333333332`}}], 
     Polygon3DBox[{{-0.4430008904285994, 
      42.02715667441428, -2.3919999119215554`}, {-0.6249999999999999, 
      48.29629131445341, -12.940952255126035`}, {-0.625, 50., 
      0.}, {-0.48055555555555546`, 43.33333333333333, 
      6.666666666666668}, {-0.4430008904285994, 
      42.02715667441428, -2.3919999119215554`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmID57BgSu7GcAAzsHCG3i0Bv6fp6K9tX9kySzdqrX
2jo018hf9vQ2dXAQdC9ZsejK/g/JL+d0/rWGqG8wc7A94P9wZtTl/RxLuB28
Zls6RDxkPiDRae4gkLeo1n7Sxf0wdb9O+5o0h1g4LJo52clG+fz+7tK4yrsP
jRxuxypPTrpi4WAMBqf3M4I16EHdY+mw5lr5aub1x/e/E3HmdbVRg6vfW3pv
isS+I/tZwOrkHH5Dzec1TEi7EX5o/6P8i/+vTRKEu0eqnHujR8iB/R0Ptkhs
FmaAu7/akH1qFufe/RfO7rnEEf3AvgXq31kzQWAnNHxgwMThpt5Md4vMbfs3
QNXXNj/Q2bbFyCFd0Wvqkdub99egmG/oIPD/QNWMqZv234K6Z6XcH/vnZQYO
oQ/5F88O2Lz/x38QkHXgyUiZ/jNM32GVe9P2PYu37X8G9a+Xy86bVuF6DqfB
8bVn/z+wel1o+Og5nHx255PYsUP7O6Dh6QlVzxP+znwL34n9f0HK680cuKDm
fzo3f6b6irP72aHxtQLqHu57wo6l+Rf3v4fGL9iaekOHJ1cmc0s0X94/EZoe
aqD+xZV+AML1BG4=
       "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhh4sh9CezrARP6DweP9Hlc33H+j6uHguKu07shD
TQeY+me/W1gnLHN1gKizcICp35EmfKB6raPDdijNCFXPBKYtHZ5C9cHMcYea
C7MHJn76/Pn1sye/toG5C2a+HUT9AXT1fyHuOIDqrsf7oe44AHMXTP0TiLoD
rFB3wcSh5h7wRPMv1B0HIO76bQMT94SqN4O6Cy18DvyBugsmvgvqnq1QGuZO
Nog7DjyG6oOFWzjUXHeoPTBzbty+fXjLOpa9MHfBxE2g7vZEU/8dGk8voObD
xGHxtBPNPVB3OMDcBXMP1B0OEWj+hcUTJHy49wIA9p4NfA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwc0ClTeD8SZJZO9VrbR2aa+Qve3qbwsU/JL+c
0/nXGsJvMIOLcyzhdvCabekQ8ZD5gESnOaq5QHW/TvuaNIdYwMW7S+Mq7z40
crgdqzw56QpCnBFM60H5lnDxdyLOvK42ahjqWcC0nMNvNPMf5V/8f22SIIZ7
Oh5skdgszIDh/gtn91ziiH5g34LmXwYUgAifDVD1tc0PdLZtMYKL16CYbwgX
vwV1z0q5P/bPywzg4j/+g4CsA09GyvSfYfpw8WdQ/3q57LxpFa4HF/8HVq8L
5SPEO6Dh6Ymm/i9Ieb2ZAxea+ezQ+FqB5p730PgFW1OPcP9EaHqoQfMvKm3i
AACUTp8D
       "]], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwc4DQng4MKMDOwePqhvtvVD0cHHeV1h15qOkA
E3/2u4V1wjJXh/9gYAEX35EmfKB6raPDdigNE2cC05YOT6H6YOLuUHNh9sDE
T58/v3725Nc2qO6yc7CDqD+Arv4vxB0HnqGZD3XHgR1o7nkCUXeAFeouNP8e
8ETzL9QdByDu+m0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZxx4HHUH0w
8XCoue5Qe2DiN27fPrxlHctemLtg4iZQd3uiqf8OjacXaObD4mknmnug7oC7
Cx5f0HCPQPMvLJ4g4cO9FwCdWsz3
       "]], {
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{-0.625, 50., 0.}, {30., 50., 0.}, {30., 48.29629131445341,
          12.940952255126037`}, {-0.6249999999999999, 48.29629131445341, 
         12.940952255126037`}, {-0.625, 50., 0.}}], 
        Line3DBox[{{-0.6249999999999999, 48.29629131445341, 
         12.940952255126037`}, {30., 48.29629131445341, 
         12.940952255126037`}, {30., 43.30127018922194, 
         24.999999999999996`}, {-0.625, 43.30127018922194, 
         24.999999999999996`}, {-0.6249999999999999, 48.29629131445341, 
         12.940952255126037`}}], 
        Line3DBox[{{-0.625, 43.30127018922194, 24.999999999999996`}, {30., 
         43.30127018922194, 24.999999999999996`}, {30., 35.35533905932738, 
         35.35533905932737}, {-0.6249999999999999, 35.35533905932738, 
         35.35533905932737}, {-0.625, 43.30127018922194, 
         24.999999999999996`}}], 
        Line3DBox[{{-0.6249999999999999, 35.35533905932738, 
         35.35533905932737}, {30., 35.35533905932738, 35.35533905932737}, {
         30., 25.000000000000007`, 43.30127018922193}, {-0.6250000000000001, 
         25.000000000000007`, 43.30127018922193}, {-0.6249999999999999, 
         35.35533905932738, 35.35533905932737}}], 
        Line3DBox[{{-0.6250000000000001, 25.000000000000007`, 
         43.30127018922193}, {30., 25.000000000000007`, 43.30127018922193}, {
         30., 12.940952255126048`, 48.29629131445341}, {-0.625, 
         12.940952255126048`, 48.29629131445341}, {-0.6250000000000001, 
         25.000000000000007`, 43.30127018922193}}], 
        Line3DBox[{{-0.625, 12.940952255126048`, 48.29629131445341}, {30., 
         12.940952255126048`, 48.29629131445341}, {30., 
         1.4163847244119949`*^-14, 50.}, {-0.625, 1.4163847244119949`*^-14, 
         50.}, {-0.625, 12.940952255126048`, 48.29629131445341}}], 
        Line3DBox[{{-0.625, 3.061616997868383*^-15, 50.}, {30., 
         3.061616997868383*^-15, 50.}, {30., -12.940952255126032`, 
         48.29629131445341}, {-0.6249999999999999, -12.940952255126032`, 
         48.29629131445341}, {-0.625, 3.061616997868383*^-15, 50.}}], 
        Line3DBox[{{-0.6249999999999999, -12.940952255126032`, 
         48.29629131445341}, {30., -12.940952255126032`, 48.29629131445341}, {
         30., -24.99999999999999, 
         43.30127018922194}, {-0.625, -24.99999999999999, 
         43.30127018922194}, {-0.6249999999999999, -12.940952255126032`, 
         48.29629131445341}}], 
        Line3DBox[{{-0.625, -24.99999999999999, 43.30127018922194}, {
         30., -24.99999999999999, 43.30127018922194}, {
         30., -35.35533905932737, 
         35.35533905932738}, {-0.6249999999999999, -35.35533905932737, 
         35.35533905932738}, {-0.625, -24.99999999999999, 
         43.30127018922194}}], 
        Line3DBox[{{-0.6249999999999999, -35.35533905932737, 
         35.35533905932738}, {30., -35.35533905932737, 35.35533905932738}, {
         30., -43.30127018922194, 
         24.999999999999996`}, {-0.625, -43.30127018922194, 
         24.999999999999996`}, {-0.6249999999999999, -35.35533905932737, 
         35.35533905932738}}], 
        Line3DBox[{{-0.625, -43.301270189221924`, 25.000000000000018`}, {
         30., -43.301270189221924`, 25.000000000000018`}, {
         30., -48.29629131445341, 
         12.940952255126051`}, {-0.625, -48.29629131445341, 
         12.940952255126051`}, {-0.625, -43.301270189221924`, 
         25.000000000000018`}}], 
        Line3DBox[{{-0.625, -48.29629131445341, 12.940952255126051`}, {
         30., -48.29629131445341, 12.940952255126051`}, {30., -50., 
         6.123233995736766*^-15}, {-0.625, -50., 
         6.123233995736766*^-15}, {-0.625, -48.29629131445341, 
         12.940952255126051`}}], 
        Line3DBox[{{-0.625, -50., 6.123233995736766*^-15}, {30., -50., 
         6.123233995736766*^-15}, {
         30., -48.29629131445341, -12.94095225512604}, {-0.625, \
-48.29629131445341, -12.94095225512604}, {-0.625, -50., 
         6.123233995736766*^-15}}], 
        Line3DBox[{{-0.625, -48.29629131445342, -12.940952255126017`}, {
         30., -48.29629131445342, -12.940952255126017`}, {
         30., -43.30127018922194, -24.999999999999986`}, {-0.625, \
-43.30127018922194, -24.999999999999986`}, {-0.625, -48.29629131445342, \
-12.940952255126017`}}], 
        Line3DBox[{{-0.625, -43.30127018922194, -24.999999999999986`}, {
         30., -43.30127018922194, -24.999999999999986`}, {
         30., -35.355339059327385`, -35.35533905932737}, {-0.625, \
-35.355339059327385`, -35.35533905932737}, {-0.625, -43.30127018922194, \
-24.999999999999986`}}], 
        Line3DBox[{{-0.625, -35.35533905932739, -35.355339059327356`}, {
         30., -35.35533905932739, -35.355339059327356`}, {
         30., -25.00000000000002, -43.30127018922192}, {-0.6249999999999999, \
-25.00000000000002, -43.30127018922192}, {-0.625, -35.35533905932739, \
-35.355339059327356`}}], 
        Line3DBox[{{-0.6249999999999999, -25.00000000000002, \
-43.30127018922192}, {30., -25.00000000000002, -43.30127018922192}, {
         30., -12.940952255126076`, -48.296291314453406`}, \
{-0.6250000000000001, -12.940952255126076`, -48.296291314453406`}, \
{-0.6249999999999999, -25.00000000000002, -43.30127018922192}}], 
        Line3DBox[{{-0.6250000000000001, -12.940952255126076`, \
-48.296291314453406`}, {30., -12.940952255126076`, -48.296291314453406`}, {
         30., -5.359377197861141*^-14, -50.}, {-0.625, \
-5.359377197861141*^-14, -50.}, {-0.6250000000000001, -12.940952255126076`, \
-48.296291314453406`}}], 
        Line3DBox[{{-0.625, -9.184850993605149*^-15, -50.}, {
         30., -9.184850993605149*^-15, -50.}, {30., 
         12.940952255126014`, -48.29629131445342}, {-0.625, 
         12.940952255126014`, -48.29629131445342}, {-0.625, \
-9.184850993605149*^-15, -50.}}], 
        Line3DBox[{{-0.625, 12.940952255126014`, -48.29629131445342}, {30., 
         12.940952255126014`, -48.29629131445342}, {30., 
         24.999999999999968`, -43.30127018922195}, {-0.625, 
         24.999999999999968`, -43.30127018922195}, {-0.625, 
         12.940952255126014`, -48.29629131445342}}], 
        Line3DBox[{{-0.625, 24.999999999999968`, -43.30127018922195}, {30., 
         24.999999999999968`, -43.30127018922195}, {30., 
         35.35533905932734, -35.35533905932742}, {-0.6250000000000002, 
         35.35533905932734, -35.35533905932742}, {-0.625, 
         24.999999999999968`, -43.30127018922195}}], 
        Line3DBox[{{-0.625, 35.35533905932737, -35.355339059327385`}, {30., 
         35.35533905932737, -35.355339059327385`}, {30., 
         43.30127018922192, -25.00000000000002}, {-0.6249999999999999, 
         43.30127018922192, -25.00000000000002}, {-0.625, 
         35.35533905932737, -35.355339059327385`}}], 
        Line3DBox[{{-0.6249999999999999, 
         43.30127018922192, -25.00000000000002}, {30., 
         43.30127018922192, -25.00000000000002}, {30., 
         48.296291314453406`, -12.940952255126078`}, {-0.6250000000000001, 
         48.296291314453406`, -12.940952255126078`}, {-0.6249999999999999, 
         43.30127018922192, -25.00000000000002}}], 
        Line3DBox[{{-0.6250000000000001, 
         48.296291314453406`, -12.940952255126078`}, {30., 
         48.296291314453406`, -12.940952255126078`}, {30., 
         50., -5.6655388976479795`*^-14}, {-0.625, 
         50., -5.6655388976479795`*^-14}, {-0.6250000000000001, 
         48.296291314453406`, -12.940952255126078`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{-0.325, 30., 20.}, {30., 30., 20.}, {30., 
         29.488887394336025`, 21.294095225512603`}, {-0.33075824280725713`, 
         29.488887394336025`, 21.294095225512603`}, {-0.325, 30., 20.}}], 
        Line3DBox[{{-0.33075824280725713`, 29.488887394336025`, 
         21.294095225512603`}, {30., 29.488887394336025`, 
         21.294095225512603`}, {30., 27.99038105676658, 
         22.5}, {-0.32242785792574935`, 27.99038105676658, 
         22.5}, {-0.33075824280725713`, 29.488887394336025`, 
         21.294095225512603`}}], 
        Line3DBox[{{-0.32242785792574935`, 27.99038105676658, 22.5}, {30., 
         27.99038105676658, 22.5}, {30., 25.606601717798213`, 
         23.535533905932738`}, {-0.302404851942814, 25.606601717798213`, 
         23.535533905932738`}, {-0.32242785792574935`, 27.99038105676658, 
         22.5}}], 
        Line3DBox[{{-0.302404851942814, 25.606601717798213`, 
         23.535533905932738`}, {30., 25.606601717798213`, 
         23.535533905932738`}, {30., 22.5, 
         24.33012701892219}, {-0.2745512701892219, 22.5, 
         24.33012701892219}, {-0.302404851942814, 25.606601717798213`, 
         23.535533905932738`}}], 
        Line3DBox[{{-0.2745512701892219, 22.5, 24.33012701892219}, {30., 22.5,
          24.33012701892219}, {30., 18.882285676537816`, 
         24.82962913144534}, {-0.24326279879387608`, 18.882285676537816`, 
         24.82962913144534}, {-0.2745512701892219, 22.5, 24.33012701892219}}],
         Line3DBox[{{-0.24326279879387608`, 18.882285676537816`, 
         24.82962913144534}, {30., 18.882285676537816`, 24.82962913144534}, {
         30., 15.000000000000004`, 25.}, {-0.21250000000000002`, 
         15.000000000000004`, 25.}, {-0.24326279879387608`, 
         18.882285676537816`, 24.82962913144534}}], 
        Line3DBox[{{-0.2125, 15.000000000000002`, 25.}, {30., 
         15.000000000000002`, 25.}, {30., 11.117714323462192`, 
         24.82962913144534}, {-0.18502851364580886`, 11.117714323462192`, 
         24.82962913144534}, {-0.2125, 15.000000000000002`, 25.}}], 
        Line3DBox[{{-0.18502851364580886`, 11.117714323462192`, 
         24.82962913144534}, {30., 11.117714323462192`, 24.82962913144534}, {
         30., 7.5000000000000036`, 
         24.330127018922195`}, {-0.16205127018922197`, 7.5000000000000036`, 
         24.330127018922195`}, {-0.18502851364580886`, 11.117714323462192`, 
         24.82962913144534}}], 
        Line3DBox[{{-0.16205127018922197`, 7.5000000000000036`, 
         24.330127018922195`}, {30., 7.5000000000000036`, 
         24.330127018922195`}, {30., 4.3933982822017885`, 
         23.535533905932738`}, {-0.14330582617584078`, 4.3933982822017885`, 
         23.535533905932738`}, {-0.16205127018922197`, 7.5000000000000036`, 
         24.330127018922195`}}], 
        Line3DBox[{{-0.14330582617584078`, 4.3933982822017885`, 
         23.535533905932738`}, {30., 4.3933982822017885`, 
         23.535533905932738`}, {30., 2.00961894323342, 
         22.5}, {-0.12757214207425066`, 2.00961894323342, 
         22.5}, {-0.14330582617584078`, 4.3933982822017885`, 
         23.535533905932738`}}], 
        Line3DBox[{{-0.12757214207425066`, 2.0096189432334235`, 22.5}, {30., 
         2.0096189432334235`, 22.5}, {30., 0.5111126056639765, 
         21.294095225512606`}, {-0.11342493189221685`, 0.5111126056639765, 
         21.294095225512606`}, {-0.12757214207425066`, 2.0096189432334235`, 
         22.5}}], 
        Line3DBox[{{-0.11342493189221685`, 0.5111126056639765, 
         21.294095225512606`}, {30., 0.5111126056639765, 
         21.294095225512606`}, {30., 0., 20.}, {-0.1, 0., 
         20.}, {-0.11342493189221685`, 0.5111126056639765, 
         21.294095225512606`}}], 
        Line3DBox[{{-0.1, 0., 20.}, {30., 0., 20.}, {30., 0.5111126056639748, 
         18.705904774487397`}, {-0.08754302738196475, 0.5111126056639748, 
         18.705904774487397`}, {-0.1, 0., 20.}}], 
        Line3DBox[{{-0.08754302738196475, 0.511112605663973, 
         18.705904774487397`}, {30., 0.511112605663973, 
         18.705904774487397`}, {30., 2.009618943233418, 
         17.5}, {-0.07757214207425066, 2.009618943233418, 
         17.5}, {-0.08754302738196475, 0.511112605663973, 
         18.705904774487397`}}], 
        Line3DBox[{{-0.07757214207425066, 2.009618943233418, 17.5}, {30., 
         2.009618943233418, 17.5}, {30., 4.393398282201785, 
         16.464466094067262`}, {-0.07259514805718602, 4.393398282201785, 
         16.464466094067262`}, {-0.07757214207425066, 2.009618943233418, 
         17.5}}], 
        Line3DBox[{{-0.07259514805718603, 4.393398282201781, 
         16.464466094067266`}, {30., 4.393398282201781, 
         16.464466094067266`}, {30., 7.499999999999993, 
         15.669872981077809`}, {-0.07544872981077806, 7.499999999999993, 
         15.669872981077809`}, {-0.07259514805718603, 4.393398282201781, 
         16.464466094067266`}}], 
        Line3DBox[{{-0.07544872981077806, 7.499999999999993, 
         15.669872981077809`}, {30., 7.499999999999993, 
         15.669872981077809`}, {30., 11.117714323462177`, 
         15.17037086855466}, {-0.08843593101690198, 11.117714323462177`, 
         15.17037086855466}, {-0.07544872981077806, 7.499999999999993, 
         15.669872981077809`}}], 
        Line3DBox[{{-0.08843593101690198, 11.117714323462177`, 
         15.17037086855466}, {30., 11.117714323462177`, 15.17037086855466}, {
         30., 14.999999999999984`, 15.}, {-0.11249999999999989`, 
         14.999999999999984`, 15.}, {-0.08843593101690198, 
         11.117714323462177`, 15.17037086855466}}], 
        Line3DBox[{{-0.11249999999999998`, 14.999999999999996`, 15.}, {30., 
         14.999999999999996`, 15.}, {30., 18.882285676537805`, 
         15.170370868554658`}, {-0.14667021616496914`, 18.882285676537805`, 
         15.170370868554658`}, {-0.11249999999999998`, 14.999999999999996`, 
         15.}}], Line3DBox[{{-0.14667021616496914`, 18.882285676537805`, 
         15.170370868554658`}, {30., 18.882285676537805`, 
         15.170370868554658`}, {30., 22.49999999999999, 
         15.669872981077805`}, {-0.18794872981077793`, 22.49999999999999, 
         15.669872981077805`}, {-0.14667021616496914`, 18.882285676537805`, 
         15.170370868554658`}}], 
        Line3DBox[{{-0.18794872981077793`, 22.49999999999999, 
         15.669872981077805`}, {30., 22.49999999999999, 
         15.669872981077805`}, {30., 25.606601717798203`, 
         16.46446609406726}, {-0.23169417382415908`, 25.606601717798203`, 
         16.46446609406726}, {-0.18794872981077793`, 22.49999999999999, 
         15.669872981077805`}}], 
        Line3DBox[{{-0.2316941738241592, 25.60660171779821, 
         16.464466094067262`}, {30., 25.60660171779821, 
         16.464466094067262`}, {30., 27.990381056766577`, 
         17.499999999999996`}, {-0.27242785792574925`, 27.990381056766577`, 
         17.499999999999996`}, {-0.2316941738241592, 25.60660171779821, 
         16.464466094067262`}}], 
        Line3DBox[{{-0.27242785792574925`, 27.990381056766577`, 
         17.499999999999996`}, {30., 27.990381056766577`, 
         17.499999999999996`}, {30., 29.48888739433602, 
         18.705904774487394`}, {-0.304876338297005, 29.48888739433602, 
         18.705904774487394`}, {-0.27242785792574925`, 27.990381056766577`, 
         17.499999999999996`}}], 
        Line3DBox[{{-0.304876338297005, 29.48888739433602, 
         18.705904774487394`}, {30., 29.48888739433602, 
         18.705904774487394`}, {30., 30., 
         19.999999999999993`}, {-0.32499999999999996`, 30., 
         19.999999999999993`}, {-0.304876338297005, 29.48888739433602, 
         18.705904774487394`}}]}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301469970372*^9, 3.614709235309146*^9, 
  3.6147290919797983`*^9},
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"},
 CellLabel->"During evaluation of In[122]:="]
}, Open  ]],

Cell["An elliptical hole that is placed offset from the center.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell["\<\
You can also specify polygon-edged holes by lising the corner coordinates of \
the polygon.  This is shown in Section 4.4.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1.2 The Rectangular Aperture", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
   "PR4.1", "PR4.1.2"}],

Cell[TextData[{
 StyleBox["You can specify a rectangular shape by indicating the major and  \
minor dimensions with a list of two positive rather than negative numbers.  \
Here we use a  rectangular aperture of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["{100, 50}", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" with ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["SphericalMirror",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[SphericalMirror[500,{100,50},30], Boxed->False];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"},
 CellLabel->"In[123]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.506281446690025, -50., 0.}, {30., -50., 
      1.2246467991473532`*^-14}, {30., -33.33333333333334, 
      1.0205389992894611`*^-14}, {1.1123484301411395`, -33.333333333333336`, 
      0.}, {2.506281446690025, -50., 0.}}], 
     Polygon3DBox[{{1.1123484301411395`, -33.333333333333336`, 0.}, {
      30., -33.33333333333334, 1.0205389992894611`*^-14}, {
      30., -16.66666666666667, 8.164311994315689*^-15}, {
      0.27785498116833196`, -16.66666666666667, 0.}, {
      1.1123484301411395`, -33.333333333333336`, 0.}}], 
     Polygon3DBox[{{0.27785498116833196`, -16.66666666666667, 0.}, {
      30., -16.66666666666667, 8.164311994315689*^-15}, {
      30., -1.4210854715202004`*^-14, 6.123233995736768*^-15}, {0., 0., 0.}, {
      0.27785498116833196`, -16.66666666666667, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {30., 0., 6.123233995736766*^-15}, {30., 
      16.666666666666664`, 4.0821559971578446`*^-15}, {0.27785498116833196`, 
      16.666666666666657`, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.27785498116833196`, 16.666666666666657`, 0.}, {30., 
      16.666666666666664`, 4.0821559971578446`*^-15}, {30., 33.33333333333333,
       2.0410779985789227`*^-15}, {1.1123484301411395`, 33.33333333333333, 
      0.}, {0.27785498116833196`, 16.666666666666657`, 0.}}], 
     Polygon3DBox[{{1.1123484301411395`, 33.33333333333333, 0.}, {30., 
      33.33333333333333, 2.041077998578923*^-15}, {30., 49.99999999999999, 
      1.0197233050851683`*^-30}, {2.506281446690025, 49.999999999999986`, 
      0.}, {1.1123484301411395`, 33.33333333333333, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG643uB5l4fFgQEMPA8wwECm8D3dMx/tV68CAQeE
eIunU8KJi/ZrwOIGCHFUsBdd/QqIegd08yHiDnBxmHv+/QcBDwcGFGAHcyeG
+Go0c2Dia9DtRTGHwRZdfAVWf8HEHTDEoe6Ei+MKTwAJGlNg
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.6253911140454989, 0., -25.}, {30., 
        3.061616997868383*^-15, -25.}, {30., 
        2.551347498223653*^-15, -16.66666666666667}, {0.27785498116833196`, 
        5.102694996447305*^-16, -16.666666666666668`}, {0.6253911140454989, 
        0., -25.}}], 
       Polygon3DBox[{{0.27785498116833196`, 
        5.102694996447305*^-16, -16.666666666666668`}, {30., 
        2.551347498223653*^-15, -16.66666666666667}, {30., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.06944926764521142, 
        1.020538999289461*^-15, -8.333333333333336}, {0.27785498116833196`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.06944926764521142, 
        1.020538999289461*^-15, -8.333333333333336}, {30., 
        2.0410779985789223`*^-15, -8.333333333333336}, {30., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.06944926764521142, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {30., 
        1.5308084989341915`*^-15, 0.}, {30., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.06944926764521142, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.06944926764521142, 2.041077998578922*^-15, 
        8.333333333333329}, {30., 1.0205389992894611`*^-15, 
        8.333333333333332}, {30., 5.102694996447307*^-16, 
        16.666666666666664`}, {0.27785498116833196`, 2.5513474982236525`*^-15,
         16.666666666666664`}, {0.06944926764521142, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{0.27785498116833196`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {30., 5.102694996447308*^-16, 
        16.666666666666664`}, {30., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {0.6253911140454989, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {0.27785498116833196`, 2.5513474982236525`*^-15,
         16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGaQOmhpwvzEngEFWB5gaPF0SjhxES6+ehUIGBxg
KHCJzT2+ES6+BiyucIABK/iwB139Coh6B3TzIeIGDuju+fcfBCwcIDw7BzR3
YoivhpmDJr4GZi9Wcz7YoIuvQPEXurgBhjjUnQdwhScAYbNRNQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.1348271412052213`, -50., -25.}, {
      1.7391357041084348`, -33.33333333333333, -25.}, {
      1.3908232782803225`, -33.33333333333333, -16.666666666666664`}, {
      2.7855369941233903`, -50., -16.666666666666664`}, {
      3.1348271412052213`, -50., -25.}}], 
     Polygon3DBox[{{2.7855369941233903`, -50., -16.666666666666664`}, {
      1.3908232782803225`, -33.33333333333333, -16.666666666666664`}, {
      1.1819525674272313`, -33.33333333333333, -8.33333333333333}, {
      2.576080635887024, -50., -8.33333333333333}, {
      2.7855369941233903`, -50., -16.666666666666664`}}], 
     Polygon3DBox[{{2.576080635887024, -50., -8.333333333333332}, {
      1.1819525674272313`, -33.33333333333333, -8.333333333333332}, {
      1.1123484301411395`, -33.33333333333333, 1.7763568394002505`*^-15}, {
      2.506281446690025, -50., 1.7763568394002505`*^-15}, {
      2.576080635887024, -50., -8.333333333333332}}], 
     Polygon3DBox[{{2.506281446690025, -50., 0.}, {
      1.1123484301411395`, -33.33333333333333, 0.}, {
      1.1819525674272313`, -33.33333333333333, 8.333333333333334}, {
      2.576080635887024, -50., 8.333333333333334}, {2.506281446690025, -50., 
      0.}}], Polygon3DBox[{{2.576080635887024, -50., 8.333333333333336}, {
      1.1819525674272313`, -33.33333333333333, 8.333333333333336}, {
      1.3908232782803225`, -33.33333333333333, 16.66666666666667}, {
      2.7855369941233903`, -50., 16.66666666666667}, {2.576080635887024, -50.,
       8.333333333333336}}], 
     Polygon3DBox[{{2.7855369941233903`, -50., 16.66666666666667}, {
      1.3908232782803225`, -33.33333333333333, 16.66666666666667}, {
      1.7391357041084348`, -33.33333333333333, 25.000000000000007`}, {
      3.1348271412052213`, -50., 25.000000000000007`}, {
      2.7855369941233903`, -50., 16.66666666666667}}], 
     Polygon3DBox[{{1.7391357041084348`, -33.33333333333333, -25.}, {
      0.9035942603651392, -16.66666666666666, -25.}, {
      0.5558645409434462, -16.66666666666666, -16.666666666666664`}, {
      1.3908232782803225`, -33.33333333333333, -16.666666666666664`}, {
      1.7391357041084348`, -33.33333333333333, -25.}}], 
     Polygon3DBox[{{
      1.3908232782803225`, -33.33333333333333, -16.666666666666664`}, {
      0.5558645409434462, -16.66666666666666, -16.666666666666664`}, {
      0.34734286929108293`, -16.66666666666666, -8.33333333333333}, {
      1.1819525674272313`, -33.33333333333333, -8.33333333333333}, {
      1.3908232782803225`, -33.33333333333333, -16.666666666666664`}}], 
     Polygon3DBox[{{
      1.1819525674272313`, -33.33333333333333, -8.333333333333332}, {
      0.34734286929108293`, -16.66666666666666, -8.333333333333332}, {
      0.27785498116833196`, -16.66666666666666, 1.7763568394002505`*^-15}, {
      1.1123484301411395`, -33.33333333333333, 1.7763568394002505`*^-15}, {
      1.1819525674272313`, -33.33333333333333, -8.333333333333332}}], 
     Polygon3DBox[{{1.1123484301411395`, -33.33333333333333, 0.}, {
      0.27785498116833196`, -16.66666666666666, 0.}, {
      0.34734286929108293`, -16.66666666666666, 8.333333333333334}, {
      1.1819525674272313`, -33.33333333333333, 8.333333333333334}, {
      1.1123484301411395`, -33.33333333333333, 0.}}], 
     Polygon3DBox[{{1.1819525674272313`, -33.33333333333333, 
      8.333333333333336}, {0.34734286929108293`, -16.66666666666666, 
      8.333333333333336}, {0.5558645409434462, -16.66666666666666, 
      16.66666666666667}, {1.3908232782803225`, -33.33333333333333, 
      16.66666666666667}, {1.1819525674272313`, -33.33333333333333, 
      8.333333333333336}}], 
     Polygon3DBox[{{1.3908232782803225`, -33.33333333333333, 
      16.66666666666667}, {0.5558645409434462, -16.66666666666666, 
      16.66666666666667}, {0.9035942603651392, -16.66666666666666, 
      25.000000000000007`}, {1.7391357041084348`, -33.33333333333333, 
      25.000000000000007`}, {1.3908232782803225`, -33.33333333333333, 
      16.66666666666667}}], 
     Polygon3DBox[{{0.9035942603651392, -16.666666666666664`, -25.}, {
      0.6253911140454989, 3.552713678800501*^-15, -25.}, {
      0.27785498116833196`, 3.552713678800501*^-15, -16.666666666666664`}, {
      0.5558645409434462, -16.666666666666664`, -16.666666666666664`}, {
      0.9035942603651392, -16.666666666666664`, -25.}}], 
     Polygon3DBox[{{
      0.5558645409434462, -16.666666666666664`, -16.666666666666664`}, {
      0.27785498116833196`, 3.552713678800501*^-15, -16.666666666666664`}, {
      0.06944926764521142, 3.552713678800501*^-15, -8.33333333333333}, {
      0.34734286929108293`, -16.666666666666664`, -8.33333333333333}, {
      0.5558645409434462, -16.666666666666664`, -16.666666666666664`}}], 
     Polygon3DBox[{{
      0.34734286929108293`, -16.666666666666664`, -8.333333333333332}, {
      0.06944926764521142, 3.552713678800501*^-15, -8.333333333333332}, {0., 
      3.552713678800501*^-15, 1.7763568394002505`*^-15}, {
      0.27785498116833196`, -16.666666666666664`, 1.7763568394002505`*^-15}, {
      0.34734286929108293`, -16.666666666666664`, -8.333333333333332}}], 
     Polygon3DBox[{{0.27785498116833196`, -16.666666666666664`, 0.}, {0., 
      3.552713678800501*^-15, 0.}, {0.06944926764521142, 
      3.552713678800501*^-15, 8.333333333333334}, {
      0.34734286929108293`, -16.666666666666664`, 8.333333333333334}, {
      0.27785498116833196`, -16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0.34734286929108293`, -16.666666666666664`, 
      8.333333333333336}, {0.06944926764521142, 3.552713678800501*^-15, 
      8.333333333333336}, {0.27785498116833196`, 3.552713678800501*^-15, 
      16.66666666666667}, {0.5558645409434462, -16.666666666666664`, 
      16.66666666666667}, {0.34734286929108293`, -16.666666666666664`, 
      8.333333333333336}}], 
     Polygon3DBox[{{0.5558645409434462, -16.666666666666664`, 
      16.66666666666667}, {0.27785498116833196`, 3.552713678800501*^-15, 
      16.66666666666667}, {0.6253911140454989, 3.552713678800501*^-15, 
      25.000000000000007`}, {0.9035942603651392, -16.666666666666664`, 
      25.000000000000007`}, {0.5558645409434462, -16.666666666666664`, 
      16.66666666666667}}], 
     Polygon3DBox[{{0.6253911140454989, 0., -25.}, {0.9035942603651392, 
      16.666666666666668`, -25.}, {0.5558645409434462, 
      16.666666666666668`, -16.666666666666664`}, {0.27785498116833196`, 
      0., -16.666666666666664`}, {0.6253911140454989, 0., -25.}}], 
     Polygon3DBox[{{0.27785498116833196`, 0., -16.666666666666664`}, {
      0.5558645409434462, 16.666666666666668`, -16.666666666666664`}, {
      0.34734286929108293`, 16.666666666666668`, -8.33333333333333}, {
      0.06944926764521142, 0., -8.33333333333333}, {0.27785498116833196`, 
      0., -16.666666666666664`}}], 
     Polygon3DBox[{{0.06944926764521142, 0., -8.333333333333332}, {
      0.34734286929108293`, 16.666666666666668`, -8.333333333333332}, {
      0.27785498116833196`, 16.666666666666668`, 1.7763568394002505`*^-15}, {
      0., 0., 1.7763568394002505`*^-15}, {0.06944926764521142, 
      0., -8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.27785498116833196`, 16.666666666666668`, 
      0.}, {0.34734286929108293`, 16.666666666666668`, 8.333333333333334}, {
      0.06944926764521142, 0., 8.333333333333334}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.06944926764521142, 0., 8.333333333333336}, {
      0.34734286929108293`, 16.666666666666668`, 8.333333333333336}, {
      0.5558645409434462, 16.666666666666668`, 16.66666666666667}, {
      0.27785498116833196`, 0., 16.66666666666667}, {0.06944926764521142, 0., 
      8.333333333333336}}], 
     Polygon3DBox[{{0.27785498116833196`, 0., 16.66666666666667}, {
      0.5558645409434462, 16.666666666666668`, 16.66666666666667}, {
      0.9035942603651392, 16.666666666666668`, 25.000000000000007`}, {
      0.6253911140454989, 0., 25.000000000000007`}, {0.27785498116833196`, 0.,
       16.66666666666667}}], 
     Polygon3DBox[{{0.9035942603651392, 16.66666666666667, -25.}, {
      1.7391357041084348`, 33.33333333333334, -25.}, {1.3908232782803225`, 
      33.33333333333334, -16.666666666666664`}, {0.5558645409434462, 
      16.66666666666667, -16.666666666666664`}, {0.9035942603651392, 
      16.66666666666667, -25.}}], 
     Polygon3DBox[{{0.5558645409434462, 
      16.66666666666667, -16.666666666666664`}, {1.3908232782803225`, 
      33.33333333333334, -16.666666666666664`}, {1.1819525674272313`, 
      33.33333333333334, -8.33333333333333}, {0.34734286929108293`, 
      16.66666666666667, -8.33333333333333}, {0.5558645409434462, 
      16.66666666666667, -16.666666666666664`}}], 
     Polygon3DBox[{{0.34734286929108293`, 
      16.66666666666667, -8.333333333333332}, {1.1819525674272313`, 
      33.33333333333334, -8.333333333333332}, {1.1123484301411395`, 
      33.33333333333334, 1.7763568394002505`*^-15}, {0.27785498116833196`, 
      16.66666666666667, 1.7763568394002505`*^-15}, {0.34734286929108293`, 
      16.66666666666667, -8.333333333333332}}], 
     Polygon3DBox[{{0.27785498116833196`, 16.66666666666667, 0.}, {
      1.1123484301411395`, 33.33333333333334, 0.}, {1.1819525674272313`, 
      33.33333333333334, 8.333333333333334}, {0.34734286929108293`, 
      16.66666666666667, 8.333333333333334}, {0.27785498116833196`, 
      16.66666666666667, 0.}}], 
     Polygon3DBox[{{0.34734286929108293`, 16.66666666666667, 
      8.333333333333336}, {1.1819525674272313`, 33.33333333333334, 
      8.333333333333336}, {1.3908232782803225`, 33.33333333333334, 
      16.66666666666667}, {0.5558645409434462, 16.66666666666667, 
      16.66666666666667}, {0.34734286929108293`, 16.66666666666667, 
      8.333333333333336}}], 
     Polygon3DBox[{{0.5558645409434462, 16.66666666666667, 
      16.66666666666667}, {1.3908232782803225`, 33.33333333333334, 
      16.66666666666667}, {1.7391357041084348`, 33.33333333333334, 
      25.000000000000007`}, {0.9035942603651392, 16.66666666666667, 
      25.000000000000007`}, {0.5558645409434462, 16.66666666666667, 
      16.66666666666667}}], 
     Polygon3DBox[{{1.7391357041084348`, 33.33333333333334, -25.}, {
      3.1348271412052213`, 50.000000000000014`, -25.}, {2.7855369941233903`, 
      50.000000000000014`, -16.666666666666664`}, {1.3908232782803225`, 
      33.33333333333334, -16.666666666666664`}, {1.7391357041084348`, 
      33.33333333333334, -25.}}], 
     Polygon3DBox[{{1.3908232782803225`, 
      33.33333333333334, -16.666666666666664`}, {2.7855369941233903`, 
      50.000000000000014`, -16.666666666666664`}, {2.576080635887024, 
      50.000000000000014`, -8.33333333333333}, {1.1819525674272313`, 
      33.33333333333334, -8.33333333333333}, {1.3908232782803225`, 
      33.33333333333334, -16.666666666666664`}}], 
     Polygon3DBox[{{1.1819525674272313`, 
      33.33333333333334, -8.333333333333332}, {2.576080635887024, 
      50.000000000000014`, -8.333333333333332}, {2.506281446690025, 
      50.000000000000014`, 1.7763568394002505`*^-15}, {1.1123484301411395`, 
      33.33333333333334, 1.7763568394002505`*^-15}, {1.1819525674272313`, 
      33.33333333333334, -8.333333333333332}}], 
     Polygon3DBox[{{1.1123484301411395`, 33.33333333333334, 0.}, {
      2.506281446690025, 50.000000000000014`, 0.}, {2.576080635887024, 
      50.000000000000014`, 8.333333333333334}, {1.1819525674272313`, 
      33.33333333333334, 8.333333333333334}, {1.1123484301411395`, 
      33.33333333333334, 0.}}], 
     Polygon3DBox[{{1.1819525674272313`, 33.33333333333334, 
      8.333333333333336}, {2.576080635887024, 50.000000000000014`, 
      8.333333333333336}, {2.7855369941233903`, 50.000000000000014`, 
      16.66666666666667}, {1.3908232782803225`, 33.33333333333334, 
      16.66666666666667}, {1.1819525674272313`, 33.33333333333334, 
      8.333333333333336}}], 
     Polygon3DBox[{{1.3908232782803225`, 33.33333333333334, 
      16.66666666666667}, {2.7855369941233903`, 50.000000000000014`, 
      16.66666666666667}, {3.1348271412052213`, 50.000000000000014`, 
      25.000000000000007`}, {1.7391357041084348`, 33.33333333333334, 
      25.000000000000007`}, {1.3908232782803225`, 33.33333333333334, 
      16.66666666666667}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIG7YPsFBQYTTgQEMPA9AaEsHBqvjX+sv/7ZfBQYO
CPEni5vsXr2BihsgxKUOWpowP7FnQAEI9Wsg6h3QzYeIO8DF0dxDUJyhfM68
4x5scPFVMHs+i2tdmM2CJq7g0HC9wfMuDwuaOUCAph7iLoUD6OZD/XEAh3tw
iqOFJ0IcNTwR4tjD8wBaeB5AN38Nanyhu4egOJp/D8DjGTV8oOIKB9DC8wCO
8DwADU/0+DoASxe40iEA3+XCcQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{30., -50., -25.}, {30., 50., -25.}, {30., 50., 25.}, {
       30., -50., 25.}, {30., -50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.1348271412052213`, -50., 25.}, {30., -50., 25.}, {
       30., -33.333333333333336`, 25.}, {
       1.7391357041084348`, -33.333333333333336`, 25.}, {
       3.1348271412052213`, -50., 25.}}], 
      Line3DBox[{{1.7391357041084348`, -33.333333333333336`, 25.}, {
       30., -33.333333333333336`, 25.}, {30., -16.66666666666667, 25.}, {
       0.9035942603651392, -16.66666666666667, 25.}, {
       1.7391357041084348`, -33.333333333333336`, 25.}}], 
      Line3DBox[{{0.9035942603651392, -16.666666666666668`, 25.}, {
       30., -16.666666666666668`, 25.}, {30., -2.7755575615628914`*^-15, 
       25.}, {0.6253911140454989, -2.7755575615628914`*^-15, 25.}, {
       0.9035942603651392, -16.666666666666668`, 25.}}], 
      Line3DBox[{{0.6253911140454989, 0., 25.}, {30., 0., 25.}, {30., 
       16.666666666666664`, 25.}, {0.9035942603651392, 16.666666666666664`, 
       25.}, {0.6253911140454989, 0., 25.}}], 
      Line3DBox[{{0.9035942603651392, 16.666666666666664`, 25.}, {30., 
       16.666666666666664`, 25.}, {30., 33.33333333333333, 25.}, {
       1.7391357041084348`, 33.33333333333333, 25.}, {0.9035942603651392, 
       16.666666666666664`, 25.}}], 
      Line3DBox[{{1.7391357041084348`, 33.33333333333333, 25.}, {30., 
       33.33333333333333, 25.}, {30., 49.999999999999986`, 25.}, {
       3.1348271412052213`, 49.999999999999986`, 25.}, {1.7391357041084348`, 
       33.33333333333333, 25.}}], 
      Line3DBox[{{3.1348271412052213`, 50., 25.}, {30., 50., 25.}, {30., 50., 
       16.666666666666668`}, {2.7855369941233903`, 50., 
       16.666666666666668`}, {3.1348271412052213`, 50., 25.}}], 
      Line3DBox[{{2.7855369941233903`, 50., 16.666666666666668`}, {30., 50., 
       16.666666666666668`}, {30., 50., 8.333333333333336}, {
       2.576080635887024, 50., 8.333333333333336}, {2.7855369941233903`, 50., 
       16.666666666666668`}}], 
      Line3DBox[{{2.576080635887024, 50., 8.333333333333334}, {30., 50., 
       8.333333333333334}, {30., 50., 1.3877787807814457`*^-15}, {
       2.506281446690025, 50., 1.3877787807814457`*^-15}, {2.576080635887024, 
       50., 8.333333333333334}}], 
      Line3DBox[{{2.506281446690025, 50., 0.}, {30., 50., 0.}, {30., 
       50., -8.333333333333332}, {2.576080635887024, 
       50., -8.333333333333332}, {2.506281446690025, 50., 0.}}], 
      Line3DBox[{{2.576080635887024, 50., -8.333333333333332}, {30., 
       50., -8.333333333333332}, {30., 50., -16.666666666666664`}, {
       2.7855369941233903`, 50., -16.666666666666664`}, {2.576080635887024, 
       50., -8.333333333333332}}], 
      Line3DBox[{{2.7855369941233903`, 50., -16.666666666666664`}, {30., 
       50., -16.666666666666664`}, {30., 50., -24.999999999999993`}, {
       3.1348271412052213`, 50., -24.999999999999993`}, {2.7855369941233903`, 
       50., -16.666666666666664`}}], 
      Line3DBox[{{3.1348271412052213`, 50., -25.}, {30., 50., -25.}, {30., 
       33.333333333333336`, -25.}, {1.7391357041084348`, 
       33.333333333333336`, -25.}, {3.1348271412052213`, 50., -25.}}], 
      Line3DBox[{{1.7391357041084348`, 33.333333333333336`, -25.}, {30., 
       33.333333333333336`, -25.}, {30., 16.66666666666667, -25.}, {
       0.9035942603651392, 16.66666666666667, -25.}, {1.7391357041084348`, 
       33.333333333333336`, -25.}}], 
      Line3DBox[{{0.9035942603651392, 16.666666666666668`, -25.}, {30., 
       16.666666666666668`, -25.}, {30., 2.7755575615628914`*^-15, -25.}, {
       0.6253911140454989, 2.7755575615628914`*^-15, -25.}, {
       0.9035942603651392, 16.666666666666668`, -25.}}], 
      Line3DBox[{{0.6253911140454989, 0., -25.}, {30., 0., -25.}, {
       30., -16.666666666666664`, -25.}, {
       0.9035942603651392, -16.666666666666664`, -25.}, {0.6253911140454989, 
       0., -25.}}], 
      Line3DBox[{{0.9035942603651392, -16.666666666666664`, -25.}, {
       30., -16.666666666666664`, -25.}, {30., -33.33333333333333, -25.}, {
       1.7391357041084348`, -33.33333333333333, -25.}, {
       0.9035942603651392, -16.666666666666664`, -25.}}], 
      Line3DBox[{{1.7391357041084348`, -33.33333333333333, -25.}, {
       30., -33.33333333333333, -25.}, {30., -49.999999999999986`, -25.}, {
       3.1348271412052213`, -49.999999999999986`, -25.}, {
       1.7391357041084348`, -33.33333333333333, -25.}}], 
      Line3DBox[{{3.1348271412052213`, -50., -25.}, {30., -50., -25.}, {
       30., -50., -16.666666666666668`}, {
       2.7855369941233903`, -50., -16.666666666666668`}, {
       3.1348271412052213`, -50., -25.}}], 
      Line3DBox[{{2.7855369941233903`, -50., -16.666666666666668`}, {
       30., -50., -16.666666666666668`}, {30., -50., -8.333333333333336}, {
       2.576080635887024, -50., -8.333333333333336}, {
       2.7855369941233903`, -50., -16.666666666666668`}}], 
      Line3DBox[{{2.576080635887024, -50., -8.333333333333334}, {
       30., -50., -8.333333333333334}, {
       30., -50., -1.3877787807814457`*^-15}, {
       2.506281446690025, -50., -1.3877787807814457`*^-15}, {
       2.576080635887024, -50., -8.333333333333334}}], 
      Line3DBox[{{2.506281446690025, -50., 0.}, {30., -50., 0.}, {30., -50., 
       8.333333333333332}, {2.576080635887024, -50., 8.333333333333332}, {
       2.506281446690025, -50., 0.}}], 
      Line3DBox[{{2.576080635887024, -50., 8.333333333333332}, {30., -50., 
       8.333333333333332}, {30., -50., 16.666666666666664`}, {
       2.7855369941233903`, -50., 16.666666666666664`}, {
       2.576080635887024, -50., 8.333333333333332}}], 
      Line3DBox[{{2.7855369941233903`, -50., 16.666666666666664`}, {30., -50.,
        16.666666666666664`}, {30., -50., 24.999999999999993`}, {
       3.1348271412052213`, -50., 24.999999999999993`}, {
       2.7855369941233903`, -50., 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301470124158*^9, 3.614709235467688*^9, 
  3.614729092136365*^9},
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"},
 CellLabel->"During evaluation of In[123]:="]
}, Open  ]],

Cell["A rectangular aperture.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1.3 The Polygonal Aperture", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
   "PR4.1", "PR4.1.3"}],

Cell[TextData[{
 "You can specify a polygon-edged component by using a list of coordinates \
that denote the corners of the polygon.  Here we create a triangular-edged \
lens that have vertices at ",
 StyleBox["{{-25,-25},{0,25}, {25,0}}", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[PlanoConvexLens[100,{{-25,-25},{0,25},{25,0}},15],Boxed->False];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"},
 CellLabel->"In[124]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {15., 3.552713678800501*^-15, 0.}, {
      15., -4.166666666666664, -4.166666666666668}, {
      0.3357779413114059, -4.166666666666666, -4.166666666666667}, {0., 0., 
      0.}}], Polygon3DBox[{{
      0.3357779413114059, -4.166666666666666, -4.166666666666667}, {
      15., -4.166666666666664, -4.166666666666668}, {
      15., -8.333333333333329, -8.333333333333332}, {
      1.356501534486604, -8.333333333333332, -8.333333333333334}, {
      0.3357779413114059, -4.166666666666666, -4.166666666666667}}], 
     Polygon3DBox[{{
      1.356501534486604, -8.333333333333332, -8.333333333333334}, {
      15., -8.333333333333329, -8.333333333333332}, {
      15., -12.499999999999996`, -12.499999999999998`}, {
      3.105160956791785, -12.5, -12.500000000000002`}, {
      1.356501534486604, -8.333333333333332, -8.333333333333334}}], 
     Polygon3DBox[{{3.105160956791785, -12.5, -12.500000000000002`}, {
      15., -12.499999999999998`, -12.5}, {
      15., -16.666666666666664`, -16.666666666666664`}, {
      5.664325261836204, -16.666666666666664`, -16.666666666666668`}, {
      3.105160956791785, -12.5, -12.500000000000002`}}], 
     Polygon3DBox[{{
      5.664325261836204, -16.666666666666664`, -16.666666666666668`}, {
      15., -16.666666666666664`, -16.666666666666664`}, {
      15., -20.833333333333332`, -20.833333333333332`}, {
      9.179501382442496, -20.83333333333333, -20.833333333333332`}, {
      5.664325261836204, -16.666666666666664`, -16.666666666666668`}}], 
     Polygon3DBox[{{
      9.179501382442496, -20.83333333333333, -20.833333333333332`}, {
      15., -20.833333333333332`, -20.833333333333332`}, {
      15., -24.999999999999996`, -24.999999999999996`}, {
      13.915375962091765`, -24.999999999999993`, -24.999999999999996`}, {
      9.179501382442496, -20.83333333333333, -20.833333333333332`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjxgqebhpNqr9qvAQODAaiit0PDzs9WWr1BxBai4
woEPTzYuiLvO4QDRrHmAEUr/+LH0ocsKMQeIegOoeoMDJ6LezXoereQQCgJX
TQ6EQWmZ0kqNNVe0oeZYQs2xPADh68HFGdDE0c2BiaPbCxP/DwYaB2DuRVWv
cGANlIaJr4D6fw2URnXPBxt8QQkCAPLCdIY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0., 0., 0.}, {15., 1.5308084989341915`*^-15, 0.}, {15., 
        1.2756737491118264`*^-15, 4.166666666666664}, {0.16761639451521404`, 
        2.5513474982236524`*^-16, 4.166666666666666}, {0., 0., 0.}}], 
       Polygon3DBox[{{0.16761639451521404`, 2.5513474982236524`*^-16, 
        4.166666666666666}, {15., 1.2756737491118264`*^-15, 
        4.166666666666664}, {15., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 5.102694996447305*^-16, 
        8.333333333333332}, {0.16761639451521404`, 2.5513474982236524`*^-16, 
        4.166666666666666}}], 
       Polygon3DBox[{{0.6737579958920605, 5.102694996447305*^-16, 
        8.333333333333332}, {15., 1.0205389992894611`*^-15, 
        8.333333333333332}, {15., 7.65404249467096*^-16, 
        12.499999999999996`}, {1.5286341456750776`, 7.654042494670958*^-16, 
        12.5}, {0.6737579958920605, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{1.5286341456750776`, 7.654042494670958*^-16, 12.5}, {
        15., 7.654042494670958*^-16, 12.5}, {15., 5.102694996447306*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 1.020538999289461*^-15, 
        16.666666666666664`}, {1.5286341456750776`, 7.654042494670958*^-16, 
        12.5}}], 
       Polygon3DBox[{{2.7504488342847893`, 1.020538999289461*^-15, 
        16.666666666666664`}, {15., 5.102694996447306*^-16, 
        16.666666666666664`}, {15., 2.5513474982236534`*^-16, 
        20.833333333333332`}, {4.3675065668300235`, 1.2756737491118262`*^-15, 
        20.833333333333332`}, {2.7504488342847893`, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{4.3675065668300235`, 1.2756737491118262`*^-15, 
        20.833333333333332`}, {15., 2.551347498223654*^-16, 
        20.833333333333332`}, {15., 1.2746541313564603`*^-31, 
        24.999999999999996`}, {6.421974580955592, 1.5308084989341913`*^-15, 
        24.999999999999996`}, {4.3675065668300235`, 1.2756737491118262`*^-15, 
        20.833333333333332`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjxgfbRVSclRexh3FRgIODCc2fE2p/8pmriCw4NJ
n4U9S3/Axf+DgYbDhBktga8Z2BxQ1Rs4zEgzWxJcIQgXDwkFgqsmDgGnDktJ
bZB0QDXHAsrXg4tDgCWGeBjUHHTx1VB70cUZwaQmhvgaqL/QxTfAwgGrez7Y
MOAAAHOtSSE=
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{0., 0., 0.}, {15., 0., 3.061616997868383*^-15}, {15., 
          4.166666666666664, 2.551347498223653*^-15}, {0.16761639451521404`, 
          4.166666666666666, 0.}, {0., 0., 0.}}], 
         Polygon3DBox[{{0.16761639451521404`, 4.166666666666666, 0.}, {15., 
          4.166666666666664, 2.551347498223653*^-15}, {15., 8.333333333333332,
           2.0410779985789223`*^-15}, {0.6737579958920605, 8.333333333333332, 
          0.}, {0.16761639451521404`, 4.166666666666666, 0.}}], 
         Polygon3DBox[{{0.6737579958920605, 8.333333333333332, 0.}, {15., 
          8.333333333333332, 2.0410779985789223`*^-15}, {15., 
          12.499999999999996`, 1.530808498934192*^-15}, {1.5286341456750776`, 
          12.5, 0.}, {0.6737579958920605, 8.333333333333332, 0.}}], 
         Polygon3DBox[{{1.5286341456750776`, 12.5, 0.}, {15., 12.5, 
          1.5308084989341915`*^-15}, {15., 16.666666666666664`, 
          1.0205389992894611`*^-15}, {2.7504488342847893`, 
          16.666666666666664`, 0.}, {1.5286341456750776`, 12.5, 0.}}], 
         Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {15., 
          16.666666666666664`, 1.0205389992894611`*^-15}, {15., 
          20.833333333333332`, 5.102694996447307*^-16}, {4.3675065668300235`, 
          20.833333333333332`, 0.}, {2.7504488342847893`, 16.666666666666664`,
           0.}}], Polygon3DBox[{{4.3675065668300235`, 20.833333333333332`, 
          0.}, {15., 20.833333333333332`, 5.102694996447308*^-16}, {15., 
          24.999999999999996`, 2.5493082627129206`*^-31}, {6.421974580955592, 
          24.999999999999996`, 0.}, {4.3675065668300235`, 20.833333333333332`,
           0.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjxgfbRVSclR+1VgIOAAFz+z421O/1OouAJc/MGk
z8KepT/s/4OBBlx8woyWwNcMbA4Q9QZw8RlpZkuCKwQdQkKB4KoJXDzg1GEp
qQ2SDhBzLBD2goEelG+JIR6GZg5MfDWavTBxRjCtiSG+Bs1fMPEN6OGA4p4P
NgwEAADrfEkh
           "]]}}}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {2.9274835597006685`, 
       16.666666666666668`, -4.166666666666668}, {15., 
       16.666666666666668`, -4.166666666666668}, {15., 25., 0.}, {
       6.421974580955592, 25., 0.}}], 
      Line3DBox[{{2.9274835597006685`, 
       16.666666666666668`, -4.166666666666668}, {1.356501534486604, 
       8.333333333333336, -8.333333333333336}, {15., 
       8.333333333333336, -8.333333333333336}, {15., 
       16.666666666666668`, -4.166666666666668}, {2.9274835597006685`, 
       16.666666666666668`, -4.166666666666668}}], 
      Line3DBox[{{1.356501534486604, 8.333333333333336, -8.333333333333336}, {
       1.5286341456750776`, 0., -12.500000000000004`}, {15., 
       0., -12.500000000000004`}, {15., 
       8.333333333333336, -8.333333333333336}, {1.356501534486604, 
       8.333333333333336, -8.333333333333336}}], 
      Line3DBox[{{1.5286341456750776`, 0., -12.500000000000004`}, {
       3.4624720971271827`, -8.333333333333329, -16.66666666666667}, {
       15., -8.333333333333329, -16.66666666666667}, {15., 
       0., -12.500000000000004`}, {1.5286341456750776`, 
       0., -12.500000000000004`}}], 
      Line3DBox[{{
       3.4624720971271827`, -8.333333333333329, -16.66666666666667}, {
       7.387178778017578, -16.666666666666657`, -20.83333333333334}, {
       15., -16.666666666666657`, -20.83333333333334}, {
       15., -8.333333333333329, -16.66666666666667}, {
       3.4624720971271827`, -8.333333333333329, -16.66666666666667}}], 
      Line3DBox[{{
       7.387178778017578, -16.666666666666657`, -20.83333333333334}, {
       13.915375962091773`, -24.999999999999993`, -25.000000000000004`}, {
       15., -24.999999999999993`, -25.000000000000004`}, {
       15., -16.666666666666657`, -20.83333333333334}, {
       7.387178778017578, -16.666666666666657`, -20.83333333333334}}], 
      Line3DBox[{{13.915375962091773`, -25., -25.}, {
       7.387178778017578, -20.833333333333332`, -16.666666666666668`}, {
       15., -20.833333333333332`, -16.666666666666668`}, {15., -25., -25.}, {
       13.915375962091773`, -25., -25.}}], 
      Line3DBox[{{
       7.387178778017578, -20.833333333333332`, -16.666666666666668`}, {
       3.4624720971271827`, -16.666666666666664`, -8.333333333333336}, {
       15., -16.666666666666664`, -8.333333333333336}, {
       15., -20.833333333333332`, -16.666666666666668`}, {
       7.387178778017578, -20.833333333333332`, -16.666666666666668`}}], 
      Line3DBox[{{
       3.4624720971271827`, -16.666666666666664`, -8.333333333333336}, {
       1.5286341456750776`, -12.499999999999998`, 0.}, {
       15., -12.499999999999998`, 0.}, {
       15., -16.666666666666664`, -8.333333333333336}, {
       3.4624720971271827`, -16.666666666666664`, -8.333333333333336}}], 
      Line3DBox[{{1.5286341456750776`, -12.499999999999998`, 0.}, {
       1.356501534486604, -8.333333333333332, 8.333333333333329}, {
       15., -8.333333333333332, 8.333333333333329}, {
       15., -12.499999999999998`, 0.}, {
       1.5286341456750776`, -12.499999999999998`, 0.}}], 
      Line3DBox[{{1.356501534486604, -8.333333333333332, 8.333333333333329}, {
       2.9274835597006614`, -4.166666666666664, 16.666666666666657`}, {
       15., -4.166666666666664, 16.666666666666657`}, {
       15., -8.333333333333332, 8.333333333333329}, {
       1.356501534486604, -8.333333333333332, 8.333333333333329}}], 
      Line3DBox[{{2.9274835597006614`, -4.166666666666664, 
       16.666666666666657`}, {6.421974580955592, 3.552713678800501*^-15, 
       24.999999999999993`}, {15., 3.552713678800501*^-15, 
       24.999999999999993`}, {15., -4.166666666666664, 16.666666666666657`}, {
       2.9274835597006614`, -4.166666666666664, 16.666666666666657`}}], 
      Line3DBox[{{6.421974580955592, 0., 25.}, {4.55059049655565, 
       4.166666666666667, 20.833333333333336`}, {15., 4.166666666666667, 
       20.833333333333336`}, {15., 0., 25.}, {6.421974580955592, 0., 25.}}], 
      Line3DBox[{{4.55059049655565, 4.166666666666667, 20.833333333333336`}, {
       3.4624720971271827`, 8.333333333333334, 16.666666666666668`}, {15., 
       8.333333333333334, 16.666666666666668`}, {15., 4.166666666666667, 
       20.833333333333336`}, {4.55059049655565, 4.166666666666667, 
       20.833333333333336`}}], 
      Line3DBox[{{3.4624720971271827`, 8.333333333333334, 
       16.666666666666668`}, {3.105160956791785, 12.500000000000002`, 12.5}, {
       15., 12.500000000000002`, 12.5}, {15., 8.333333333333334, 
       16.666666666666668`}, {3.4624720971271827`, 8.333333333333334, 
       16.666666666666668`}}], 
      Line3DBox[{{3.105160956791785, 12.500000000000002`, 12.5}, {
       3.4624720971271827`, 16.666666666666668`, 8.333333333333336}, {15., 
       16.666666666666668`, 8.333333333333336}, {15., 12.500000000000002`, 
       12.5}, {3.105160956791785, 12.500000000000002`, 12.5}}], 
      Line3DBox[{{3.4624720971271827`, 16.666666666666668`, 
       8.333333333333336}, {4.55059049655565, 20.833333333333336`, 
       4.166666666666668}, {15., 20.833333333333336`, 4.166666666666668}, {
       15., 16.666666666666668`, 8.333333333333336}, {3.4624720971271827`, 
       16.666666666666668`, 8.333333333333336}}], 
      Line3DBox[{{4.55059049655565, 20.833333333333336`, 4.166666666666668}, {
       6.421974580955599, 25.000000000000004`, 0.}, {15., 25.000000000000004`,
        0.}, {15., 20.833333333333336`, 4.166666666666668}, {4.55059049655565,
        20.833333333333336`, 4.166666666666668}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013014702827168`*^9, 3.6147092356302147`*^9, 
  3.614729092289873*^9},
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"},
 CellLabel->"During evaluation of In[124]:="]
}, Open  ]],

Cell["A triangular aperture.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],

Cell[TextData[{
 StyleBox["You can also use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Table",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to create a polygon-edged component.  Here we create a \
hexagon-shaped mirror.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\tMirror[
\t\tTable[50*N[{Sin[x Degree],Cos[x Degree]}],{x,0,300,60}],
\t\t10
\t]
];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"},
 CellLabel->"In[125]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {10., 3.061616997868383*^-15, 0.}, {10., 
      2.551347498223653*^-15, 8.333333333333329}, {0., 5.102694996447305*^-16,
       8.333333333333332}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.102694996447305*^-16, 8.333333333333332}, {10., 
      2.551347498223653*^-15, 8.333333333333329}, {10., 
      2.0410779985789223`*^-15, 16.666666666666664`}, {0., 
      1.020538999289461*^-15, 16.666666666666664`}, {0., 
      5.102694996447305*^-16, 8.333333333333332}}], 
     Polygon3DBox[{{0., 1.020538999289461*^-15, 16.666666666666664`}, {10., 
      2.0410779985789223`*^-15, 16.666666666666664`}, {10., 
      1.530808498934192*^-15, 24.999999999999993`}, {0., 
      1.5308084989341915`*^-15, 25.}, {0., 1.020538999289461*^-15, 
      16.666666666666664`}}], 
     Polygon3DBox[{{0., 1.5308084989341915`*^-15, 25.}, {10., 
      1.5308084989341915`*^-15, 25.}, {10., 1.0205389992894611`*^-15, 
      33.33333333333333}, {0., 2.041077998578922*^-15, 33.33333333333333}, {
      0., 1.5308084989341915`*^-15, 25.}}], 
     Polygon3DBox[{{0., 2.041077998578922*^-15, 33.33333333333333}, {10., 
      1.0205389992894611`*^-15, 33.33333333333333}, {10., 
      5.102694996447307*^-16, 41.666666666666664`}, {0., 
      2.5513474982236525`*^-15, 41.666666666666664`}, {0., 
      2.041077998578922*^-15, 33.33333333333333}}], 
     Polygon3DBox[{{0., 2.5513474982236525`*^-15, 41.666666666666664`}, {10., 
      5.102694996447308*^-16, 41.666666666666664`}, {10., 
      2.5493082627129206`*^-31, 49.99999999999999}, {0., 
      3.0616169978683826`*^-15, 49.99999999999999}, {0., 
      2.5513474982236525`*^-15, 41.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBuLBKjBQcMAuboAh/h8MLHCod8AQDwkFgqsuOMzx
gIqroMl7YoiHoZiDEF+NYi9CnBFMWmKIr0HxF0J8A0o4oLuHwRbd/TAAAKRS
M0M=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0., 0., 0.}, {10., -7.105427357601002*^-15, 
        3.552713678800501*^-15}, {10., 7.216878364870311, 
        4.166666666666668}, {0., 7.216878364870321, 4.166666666666666}, {0., 
        0., 0.}}], 
       Polygon3DBox[{{0., 7.216878364870321, 4.166666666666666}, {10., 
        7.216878364870311, 4.166666666666668}, {10., 14.43375672974064, 
        8.333333333333336}, {0., 14.433756729740642`, 8.333333333333332}, {0.,
         7.216878364870321, 4.166666666666666}}], 
       Polygon3DBox[{{0., 14.433756729740642`, 8.333333333333332}, {10., 
        14.43375672974064, 8.333333333333336}, {10., 21.65063509461096, 
        12.499999999999998`}, {0., 21.650635094610966`, 12.5}, {0., 
        14.433756729740642`, 8.333333333333332}}], 
       Polygon3DBox[{{0., 21.650635094610966`, 12.5}, {10., 
        21.650635094610962`, 12.500000000000002`}, {10., 28.867513459481287`, 
        16.666666666666668`}, {0., 28.867513459481284`, 
        16.666666666666664`}, {0., 21.650635094610966`, 12.5}}], 
       Polygon3DBox[{{0., 28.867513459481284`, 16.666666666666664`}, {10., 
        28.867513459481287`, 16.666666666666668`}, {10., 36.084391824351606`, 
        20.833333333333332`}, {0., 36.084391824351606`, 
        20.833333333333332`}, {0., 28.867513459481284`, 
        16.666666666666664`}}], 
       Polygon3DBox[{{0., 36.084391824351606`, 20.833333333333332`}, {10., 
        36.084391824351606`, 20.833333333333332`}, {10., 43.301270189221924`, 
        24.999999999999996`}, {0., 43.301270189221924`, 
        24.999999999999996`}, {0., 36.084391824351606`, 
        20.833333333333332`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBsLgtv/GGNF7Mg6rwEDAAVVcByquABd/8ruFdcIy
U4f/YKCBpt4Gqt4ALv7i4rvIs1xODiGhQHDVBM0cV6g5FlBxFYenUHEI3xIu
/gpqThiKOSoOd6D2rkGxF2aOqQMTmK+Jpl7HYR2Kv1QcHkDDYQtKOKjA3QsF
trjCEQBbwWE4
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{0., 0., 0.}, {
          10., -7.105427357601002*^-15, -3.552713678800501*^-15}, {10., 
          7.216878364870311, -4.166666666666668}, {0., 
          7.216878364870321, -4.166666666666666}, {0., 0., 0.}}], 
         Polygon3DBox[{{0., 7.216878364870321, -4.166666666666666}, {10., 
          7.216878364870311, -4.166666666666668}, {10., 
          14.43375672974064, -8.333333333333336}, {0., 
          14.433756729740642`, -8.333333333333332}, {0., 
          7.216878364870321, -4.166666666666666}}], 
         Polygon3DBox[{{0., 14.433756729740642`, -8.333333333333332}, {10., 
          14.43375672974064, -8.333333333333336}, {10., 
          21.65063509461096, -12.499999999999998`}, {0., 
          21.650635094610966`, -12.5}, {0., 
          14.433756729740642`, -8.333333333333332}}], 
         Polygon3DBox[{{0., 21.650635094610966`, -12.5}, {10., 
          21.650635094610962`, -12.500000000000002`}, {10., 
          28.867513459481287`, -16.666666666666668`}, {0., 
          28.867513459481284`, -16.666666666666664`}, {0., 
          21.650635094610966`, -12.5}}], 
         Polygon3DBox[{{0., 28.867513459481284`, -16.666666666666664`}, {10., 
          28.867513459481287`, -16.666666666666668`}, {10., 
          36.084391824351606`, -20.833333333333332`}, {0., 
          36.084391824351606`, -20.833333333333332`}, {0., 
          28.867513459481284`, -16.666666666666664`}}], 
         Polygon3DBox[{{0., 36.084391824351606`, -20.833333333333332`}, {10., 
          36.084391824351606`, -20.833333333333332`}, {10., 
          43.301270189221924`, -24.999999999999996`}, {0., 
          43.301270189221924`, -24.999999999999996`}, {0., 
          36.084391824351606`, -20.833333333333332`}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBsLgtv/GGNF7Mg6rwEDgAKq4DlRcAS7+5HcL64Rl
pg7/wUADTb0NVL0BXPzFxXeRZ7mcHEJCgeCqCZo5rlBzLKDiKg5PoeIQviVc
/BXUnDAUc1Qc7kDtXYNiL8wcUwcmMF8TTb2OwzoUf6k4PICGwxaUcFBxQAuu
vbjCEQCmfWe4
           "]], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{0., 0., 0.}, {10., 3.061616997868383*^-15, 0.}, {
            10., 2.551347498223653*^-15, -8.333333333333329}, {0., 
            5.102694996447305*^-16, -8.333333333333332}, {0., 0., 0.}}], 
           Polygon3DBox[{{0., 5.102694996447305*^-16, -8.333333333333332}, {
            10., 2.551347498223653*^-15, -8.333333333333329}, {10., 
            2.0410779985789223`*^-15, -16.666666666666664`}, {0., 
            1.020538999289461*^-15, -16.666666666666664`}, {0., 
            5.102694996447305*^-16, -8.333333333333332}}], 
           Polygon3DBox[{{0., 1.020538999289461*^-15, -16.666666666666664`}, {
            10., 2.0410779985789223`*^-15, -16.666666666666664`}, {10., 
            1.530808498934192*^-15, -24.999999999999993`}, {0., 
            1.5308084989341915`*^-15, -25.}, {0., 
            1.020538999289461*^-15, -16.666666666666664`}}], 
           Polygon3DBox[{{0., 1.5308084989341915`*^-15, -25.}, {10., 
            1.5308084989341915`*^-15, -25.}, {10., 
            1.0205389992894611`*^-15, -33.33333333333333}, {0., 
            2.041077998578922*^-15, -33.33333333333333}, {0., 
            1.5308084989341915`*^-15, -25.}}], 
           Polygon3DBox[{{0., 2.041077998578922*^-15, -33.33333333333333}, {
            10., 1.0205389992894611`*^-15, -33.33333333333333}, {10., 
            5.102694996447307*^-16, -41.666666666666664`}, {0., 
            2.5513474982236525`*^-15, -41.666666666666664`}, {0., 
            2.041077998578922*^-15, -33.33333333333333}}], 
           Polygon3DBox[{{0., 
            2.5513474982236525`*^-15, -41.666666666666664`}, {10., 
            5.102694996447308*^-16, -41.666666666666664`}, {10., 
            2.5493082627129206`*^-31, -49.99999999999999}, {0., 
            3.0616169978683826`*^-15, -49.99999999999999}, {0., 
            2.5513474982236525`*^-15, -41.666666666666664`}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBuLBKjBQOIBd3ABD/D8YWOBQ74AhHhIKBFddcJjj
ARVXcUCV9cQQD0MxByG+GsVehDgjmLTEEF+D4i+E+AaUcEB3D8NedPfDAADv
DjnD
             "]], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{0., 0., 0.}, {10., 0., 0.}, {
              10., -7.216878364870318, -4.166666666666664}, {
              0., -7.216878364870322, -4.166666666666665}, {0., 0., 0.}}], 
             Polygon3DBox[{{0., -7.216878364870322, -4.166666666666665}, {
              10., -7.216878364870318, -4.166666666666664}, {
              10., -14.433756729740644`, -8.333333333333332}, {
              0., -14.433756729740644`, -8.33333333333333}, {
              0., -7.216878364870322, -4.166666666666665}}], 
             Polygon3DBox[{{0., -14.433756729740644`, -8.33333333333333}, {
              10., -14.433756729740644`, -8.333333333333332}, {
              10., -21.65063509461096, -12.499999999999996`}, {
              0., -21.65063509461097, -12.499999999999998`}, {
              0., -14.433756729740644`, -8.33333333333333}}], 
             Polygon3DBox[{{0., -21.65063509461097, -12.499999999999998`}, {
              10., -21.650635094610966`, -12.5}, {
              10., -28.867513459481287`, -16.666666666666664`}, {
              0., -28.867513459481287`, -16.66666666666666}, {
              0., -21.65063509461097, -12.499999999999998`}}], 
             Polygon3DBox[{{0., -28.867513459481287`, -16.66666666666666}, {
              10., -28.867513459481287`, -16.666666666666664`}, {
              10., -36.084391824351606`, -20.833333333333332`}, {
              0., -36.08439182435161, -20.83333333333333}, {
              0., -28.867513459481287`, -16.66666666666666}}], 
             Polygon3DBox[{{0., -36.08439182435161, -20.83333333333333}, {
              10., -36.084391824351606`, -20.833333333333332`}, {
              10., -43.301270189221924`, -24.999999999999996`}, {
              0., -43.30127018922193, -24.999999999999993`}, {
              0., -36.08439182435161, -20.83333333333333}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["

1:eJxTTMoPSmViYGDgB2JmBsLgjv/GGNF7MgdWrgIBgQOo4jpQcQW4+NPfLawT
lpke+PcfBDTQ1NtA1RvAxV9efBd5lsvpQHAoEFw1QTPHFWqOBVRcxQEmDuFb
wsVfQc0JQzFHxQFm72oUe1UcnkHdyQjma8LF70H9tQbFXyoOL6DhsAElHFQc
oM7dC6E+7MEVjgBGVG9n
               "]], 
              {GrayLevel[0.5], EdgeForm[None], 
               Polygon3DBox[{{0., 0., 0.}, {10., 0., 0.}, {
                10., -7.216878364870318, 4.166666666666664}, {
                0., -7.216878364870322, 4.166666666666665}, {0., 0., 0.}}], 
               Polygon3DBox[{{0., -7.216878364870322, 4.166666666666665}, {
                10., -7.216878364870318, 4.166666666666664}, {
                10., -14.433756729740644`, 8.333333333333332}, {
                0., -14.433756729740644`, 8.33333333333333}, {
                0., -7.216878364870322, 4.166666666666665}}], 
               Polygon3DBox[{{0., -14.433756729740644`, 8.33333333333333}, {
                10., -14.433756729740644`, 8.333333333333332}, {
                10., -21.65063509461096, 12.499999999999996`}, {
                0., -21.65063509461097, 12.499999999999998`}, {
                0., -14.433756729740644`, 8.33333333333333}}], 
               Polygon3DBox[{{0., -21.65063509461097, 12.499999999999998`}, {
                10., -21.650635094610966`, 12.5}, {10., -28.867513459481287`, 
                16.666666666666664`}, {0., -28.867513459481287`, 
                16.66666666666666}, {0., -21.65063509461097, 
                12.499999999999998`}}], 
               Polygon3DBox[{{0., -28.867513459481287`, 16.66666666666666}, {
                10., -28.867513459481287`, 16.666666666666664`}, {
                10., -36.084391824351606`, 20.833333333333332`}, {
                0., -36.08439182435161, 20.83333333333333}, {
                0., -28.867513459481287`, 16.66666666666666}}], 
               Polygon3DBox[{{0., -36.08439182435161, 20.83333333333333}, {
                10., -36.084391824351606`, 20.833333333333332`}, {
                10., -43.301270189221924`, 24.999999999999996`}, {
                0., -43.30127018922193, 24.999999999999993`}, {
                0., -36.08439182435161, 20.83333333333333}}], 
               {GrayLevel[0], AbsoluteThickness[0.5], 
                Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBsLgjv/GGNF7MgdWrgIBAQdUcR2ouAJc/OnvFtYJ
y0wP/PsPAhpo6m2g6g3g4i8vvos8y+V0IDgUCK6aoJnjCjXHAiqu4gATh/At
4eKvoOaEoZij4gCzdzWKvSoOz6DuZATzNeHi96D+WoPiLxWHF9Bw2IASDiow
9+6FUB9scIUjAPuJaOc=
                 "]]}}}}}}}}}}}}, 
    {GrayLevel[0.5], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJxTTMoPSmVmYGBggWIQGwae/m5hnbDM9QCEZ3kAh7gDA1bgCRcn0hy4OJo5
uMQJmk+mOQ60MgdNHK4e3RwA5Jox6A==
      "]], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 0., 50.}, {0., 43.30127018922193, 25.}, {0., 
       43.30127018922193, -25.}, {0., 0., -50.}, {
       0., -43.30127018922193, -25.}, {0., -43.30127018922193, 25.}, {0., 0., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{10., 0., 50.}, {10., 43.30127018922193, 25.}, {10., 
       43.30127018922193, -25.}, {10., 0., -50.}, {
       10., -43.30127018922193, -25.}, {10., -43.30127018922193, 25.}, {10., 
       0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., -43.30127018922193, 25.}, {0., -36.08439182435161, 
       29.166666666666664`}, {10., -36.08439182435161, 29.166666666666664`}, {
       10., -43.30127018922193, 25.}, {0., -43.30127018922193, 25.}}], 
      Line3DBox[{{0., -36.08439182435161, 29.166666666666664`}, {
       0., -28.867513459481287`, 33.33333333333333}, {
       10., -28.867513459481287`, 33.33333333333333}, {
       10., -36.08439182435161, 29.166666666666664`}, {0., -36.08439182435161,
        29.166666666666664`}}], 
      Line3DBox[{{0., -28.867513459481287`, 33.33333333333333}, {
       0., -21.65063509461097, 37.5}, {10., -21.65063509461097, 37.5}, {
       10., -28.867513459481287`, 33.33333333333333}, {
       0., -28.867513459481287`, 33.33333333333333}}], 
      Line3DBox[{{0., -21.65063509461097, 37.5}, {0., -14.433756729740647`, 
       41.666666666666664`}, {10., -14.433756729740647`, 
       41.666666666666664`}, {10., -21.65063509461097, 37.5}, {
       0., -21.65063509461097, 37.5}}], 
      Line3DBox[{{0., -14.433756729740647`, 41.666666666666664`}, {
       0., -7.2168783648703325`, 45.83333333333333}, {
       10., -7.2168783648703325`, 45.83333333333333}, {
       10., -14.433756729740647`, 41.666666666666664`}, {
       0., -14.433756729740647`, 41.666666666666664`}}], 
      Line3DBox[{{0., -7.2168783648703325`, 45.83333333333333}, {
       0., -1.4210854715202004`*^-14, 49.99999999999999}, {
       10., -1.4210854715202004`*^-14, 49.99999999999999}, {
       10., -7.2168783648703325`, 45.83333333333333}, {
       0., -7.2168783648703325`, 45.83333333333333}}], 
      Line3DBox[{{0., 0., 50.}, {0., 7.216878364870321, 
       45.833333333333336`}, {10., 7.216878364870321, 45.833333333333336`}, {
       10., 0., 50.}, {0., 0., 50.}}], 
      Line3DBox[{{0., 7.216878364870321, 45.833333333333336`}, {0., 
       14.433756729740642`, 41.66666666666667}, {10., 14.433756729740642`, 
       41.66666666666667}, {10., 7.216878364870321, 45.833333333333336`}, {0.,
        7.216878364870321, 45.833333333333336`}}], 
      Line3DBox[{{0., 14.433756729740642`, 41.66666666666667}, {0., 
       21.650635094610962`, 37.5}, {10., 21.650635094610962`, 37.5}, {10., 
       14.433756729740642`, 41.66666666666667}, {0., 14.433756729740642`, 
       41.66666666666667}}], 
      Line3DBox[{{0., 21.650635094610962`, 37.5}, {0., 28.867513459481284`, 
       33.333333333333336`}, {10., 28.867513459481284`, 
       33.333333333333336`}, {10., 21.650635094610962`, 37.5}, {0., 
       21.650635094610962`, 37.5}}], 
      Line3DBox[{{0., 28.867513459481284`, 33.333333333333336`}, {0., 
       36.0843918243516, 29.16666666666667}, {10., 36.0843918243516, 
       29.16666666666667}, {10., 28.867513459481284`, 33.333333333333336`}, {
       0., 28.867513459481284`, 33.333333333333336`}}], 
      Line3DBox[{{0., 36.0843918243516, 29.16666666666667}, {0., 
       43.30127018922192, 25.000000000000007`}, {10., 43.30127018922192, 
       25.000000000000007`}, {10., 36.0843918243516, 29.16666666666667}, {0., 
       36.0843918243516, 29.16666666666667}}], 
      Line3DBox[{{0., 43.30127018922193, 25.}, {0., 43.30127018922193, 
       16.666666666666668`}, {10., 43.30127018922193, 16.666666666666668`}, {
       10., 43.30127018922193, 25.}, {0., 43.30127018922193, 25.}}], 
      Line3DBox[{{0., 43.30127018922193, 16.666666666666668`}, {0., 
       43.30127018922193, 8.333333333333336}, {10., 43.30127018922193, 
       8.333333333333336}, {10., 43.30127018922193, 16.666666666666668`}, {0.,
        43.30127018922193, 16.666666666666668`}}], 
      Line3DBox[{{0., 43.30127018922193, 8.333333333333336}, {0., 
       43.30127018922193, 3.552713678800501*^-15}, {10., 43.30127018922193, 
       3.552713678800501*^-15}, {10., 43.30127018922193, 8.333333333333336}, {
       0., 43.30127018922193, 8.333333333333336}}], 
      Line3DBox[{{0., 43.30127018922193, 3.552713678800501*^-15}, {0., 
       43.30127018922193, -8.333333333333329}, {10., 
       43.30127018922193, -8.333333333333329}, {10., 43.30127018922193, 
       3.552713678800501*^-15}, {0., 43.30127018922193, 
       3.552713678800501*^-15}}], 
      Line3DBox[{{0., 43.30127018922193, -8.333333333333329}, {0., 
       43.30127018922193, -16.666666666666657`}, {10., 
       43.30127018922193, -16.666666666666657`}, {10., 
       43.30127018922193, -8.333333333333329}, {0., 
       43.30127018922193, -8.333333333333329}}], 
      Line3DBox[{{0., 43.30127018922193, -16.666666666666657`}, {0., 
       43.30127018922193, -24.999999999999986`}, {10., 
       43.30127018922193, -24.999999999999986`}, {10., 
       43.30127018922193, -16.666666666666657`}, {0., 
       43.30127018922193, -16.666666666666657`}}], 
      Line3DBox[{{0., 43.30127018922193, -25.}, {0., 
       36.08439182435161, -29.166666666666664`}, {10., 
       36.08439182435161, -29.166666666666664`}, {10., 
       43.30127018922193, -25.}, {0., 43.30127018922193, -25.}}], 
      Line3DBox[{{0., 36.08439182435161, -29.166666666666664`}, {0., 
       28.867513459481287`, -33.33333333333333}, {10., 
       28.867513459481287`, -33.33333333333333}, {10., 
       36.08439182435161, -29.166666666666664`}, {0., 
       36.08439182435161, -29.166666666666664`}}], 
      Line3DBox[{{0., 28.867513459481287`, -33.33333333333333}, {0., 
       21.650635094610966`, -37.5}, {10., 21.650635094610966`, -37.5}, {10., 
       28.867513459481287`, -33.33333333333333}, {0., 
       28.867513459481287`, -33.33333333333333}}], 
      Line3DBox[{{0., 21.650635094610966`, -37.5}, {0., 
       14.433756729740644`, -41.66666666666666}, {10., 
       14.433756729740644`, -41.66666666666666}, {10., 
       21.650635094610966`, -37.5}, {0., 21.650635094610966`, -37.5}}], 
      Line3DBox[{{0., 14.433756729740644`, -41.66666666666666}, {0., 
       7.216878364870325, -45.83333333333333}, {10., 
       7.216878364870325, -45.83333333333333}, {10., 
       14.433756729740644`, -41.66666666666666}, {0., 
       14.433756729740644`, -41.66666666666666}}], 
      Line3DBox[{{0., 7.216878364870325, -45.83333333333333}, {0., 
       7.105427357601002*^-15, -49.999999999999986`}, {10., 
       7.105427357601002*^-15, -49.999999999999986`}, {10., 
       7.216878364870325, -45.83333333333333}, {0., 
       7.216878364870325, -45.83333333333333}}], 
      Line3DBox[{{0., 0., -50.}, {
       0., -7.216878364870322, -45.833333333333336`}, {
       10., -7.216878364870322, -45.833333333333336`}, {10., 0., -50.}, {0., 
       0., -50.}}], 
      Line3DBox[{{0., -7.216878364870322, -45.833333333333336`}, {
       0., -14.433756729740644`, -41.66666666666667}, {
       10., -14.433756729740644`, -41.66666666666667}, {
       10., -7.216878364870322, -45.833333333333336`}, {
       0., -7.216878364870322, -45.833333333333336`}}], 
      Line3DBox[{{0., -14.433756729740644`, -41.66666666666667}, {
       0., -21.650635094610966`, -37.5}, {10., -21.650635094610966`, -37.5}, {
       10., -14.433756729740644`, -41.66666666666667}, {
       0., -14.433756729740644`, -41.66666666666667}}], 
      Line3DBox[{{0., -21.650635094610966`, -37.5}, {
       0., -28.867513459481287`, -33.33333333333334}, {
       10., -28.867513459481287`, -33.33333333333334}, {
       10., -21.650635094610966`, -37.5}, {0., -21.650635094610966`, -37.5}}],
       Line3DBox[{{0., -28.867513459481287`, -33.33333333333334}, {
       0., -36.084391824351606`, -29.166666666666675`}, {
       10., -36.084391824351606`, -29.166666666666675`}, {
       10., -28.867513459481287`, -33.33333333333334}, {
       0., -28.867513459481287`, -33.33333333333334}}], 
      Line3DBox[{{0., -36.084391824351606`, -29.166666666666675`}, {
       0., -43.301270189221924`, -25.00000000000001}, {
       10., -43.301270189221924`, -25.00000000000001}, {
       10., -36.084391824351606`, -29.166666666666675`}, {
       0., -36.084391824351606`, -29.166666666666675`}}], 
      Line3DBox[{{0., -43.30127018922193, -25.}, {
       0., -43.30127018922193, -16.666666666666668`}, {
       10., -43.30127018922193, -16.666666666666668`}, {
       10., -43.30127018922193, -25.}, {0., -43.30127018922193, -25.}}], 
      Line3DBox[{{0., -43.30127018922193, -16.666666666666668`}, {
       0., -43.30127018922193, -8.333333333333336}, {
       10., -43.30127018922193, -8.333333333333336}, {
       10., -43.30127018922193, -16.666666666666668`}, {
       0., -43.30127018922193, -16.666666666666668`}}], 
      Line3DBox[{{0., -43.30127018922193, -8.333333333333336}, {
       0., -43.30127018922193, -3.552713678800501*^-15}, {
       10., -43.30127018922193, -3.552713678800501*^-15}, {
       10., -43.30127018922193, -8.333333333333336}, {
       0., -43.30127018922193, -8.333333333333336}}], 
      Line3DBox[{{0., -43.30127018922193, -3.552713678800501*^-15}, {
       0., -43.30127018922193, 8.333333333333329}, {10., -43.30127018922193, 
       8.333333333333329}, {
       10., -43.30127018922193, -3.552713678800501*^-15}, {
       0., -43.30127018922193, -3.552713678800501*^-15}}], 
      Line3DBox[{{0., -43.30127018922193, 8.333333333333329}, {
       0., -43.30127018922193, 16.666666666666657`}, {10., -43.30127018922193,
        16.666666666666657`}, {10., -43.30127018922193, 8.333333333333329}, {
       0., -43.30127018922193, 8.333333333333329}}], 
      Line3DBox[{{0., -43.30127018922193, 16.666666666666657`}, {
       0., -43.30127018922193, 24.999999999999986`}, {10., -43.30127018922193,
        24.999999999999986`}, {10., -43.30127018922193, 
       16.666666666666657`}, {0., -43.30127018922193, 
       16.666666666666657`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301470613492*^9, 3.61470923593349*^9, 
  3.61472909258246*^9},
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"},
 CellLabel->"During evaluation of In[125]:="]
}, Open  ]],

Cell["A regular polygon aperture.", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],

Cell["\<\
You will learn more about using polygonal-shapes in the next section.\
\>", "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1.4 Aperture Stops", "Subsection",
 CellTags->{"4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[{
 "We have now examined the most basic forms of apertures supported by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 StyleBox[",",
  FontSlant->"Italic"],
 " but more complicated apertures are also possible.  Generally speaking, \
custom  apertures require a piecewise-linear definition.  In this section, we \
examine  one such custom aperture."
}], "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[{
 "The ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["ApertureStop", "MB"],
 " defines a planar stop with an aperture in the middle.  It is very  \
straightforward to define custom apertures with this function.  Here is an  \
array of two-dimensional points.  ",
 StyleBox["ApertureStop", "MB"],
 " will accept these directly to create a custom aperture."
}], "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"holeaperture", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "26.3236"}], ",", "19.2792"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "22.2992"}], ",", "22.5719"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "16.8113"}], ",", "26.9622"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.5918"}], ",", "31.3525"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4.738"}], ",", "30.9867"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.0795"}], ",", "26.9622"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.9088"}], ",", "20.7427"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.2746"}], ",", "14.5231"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.9088"}], ",", "8.30348"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.384", ",", "3.54738"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.3352", ",", "5.01078"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12.0914", ",", "7.57178"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18.6768", ",", "9.40108"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23.7988", ",", "7.57178"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27.8233", ",", "3.54738"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30.0184", ",", 
       RowBox[{"-", "3.03809"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"29.2867", ",", 
       RowBox[{"-", "9.62352"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"26.7257", ",", 
       RowBox[{"-", "15.1114"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"22.3354", ",", 
       RowBox[{"-", "18.7699"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14.6524", ",", 
       RowBox[{"-", "22.4285"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.628", ",", 
       RowBox[{"-", "23.5261"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.4084", ",", 
       RowBox[{"-", "24.9895"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.5429"}], ",", 
       RowBox[{"-", "26.0871"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8.0308"}], ",", 
       RowBox[{"-", "26.0871"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "11.6893"}], ",", 
       RowBox[{"-", "23.1602"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10.9576"}], ",", 
       RowBox[{"-", "18.7699"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "8.3966"}], ",", 
       RowBox[{"-", "17.6724"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.2746"}], ",", 
       RowBox[{"-", "15.4772"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.6767", ",", 
       RowBox[{"-", "14.7455"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.6035", ",", 
       RowBox[{"-", "11.4528"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.1401", ",", 
       RowBox[{"-", "7.79423"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.2132", ",", 
       RowBox[{"-", "5.96495"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.2746"}], ",", 
       RowBox[{"-", "6.3308"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9.4942"}], ",", 
       RowBox[{"-", "7.42838"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "14.6162"}], ",", 
       RowBox[{"-", "9.98938"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "19.7382"}], ",", 
       RowBox[{"-", "9.98938"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "23.7626"}], ",", 
       RowBox[{"-", "8.16009"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "27.4212"}], ",", 
       RowBox[{"-", "4.86738"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "30.3481"}], ",", 
       RowBox[{"-", "0.47709"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "31.4456"}], ",", "5.74248"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "29.6163"}], ",", "13.7914"}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"In[126]:="],

Cell["ListPlot[holeaperture,Frame->True,Axes->False];", "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"In[127]:="],

Cell[TextData[{
 "An array of two-dimensional points and their visualization with ",
 StyleBox["ListPlot", "MB"],
 "."
}], "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[{
 "These points may come from any number of sources.  For example, you could  \
read them in from a data file.  The points above define a piecewise-linear  \
approximation to a closed curve in the plane.  We now use them with ",
 StyleBox["ApertureStop", "MB"],
 " and perform a test trace with ",
 StyleBox["GridOfRays", "MB"],
 " as the source."
}], "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"polygonAperture", "=", 
   RowBox[{"ApertureStop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", "100"}], "}"}], ",", "holeaperture"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"output", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"GridOfRays", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"70", ",", "70"}], "}"}], ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "16"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Move", "[", 
       RowBox[{"polygonAperture", ",", "25"}], "]"}], ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"100", ",", "100"}], "}"}], "]"}], ",", " ", "100"}], "]"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"Boundary", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "50"}], ",", 
          RowBox[{"-", "50"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"100", ",", "50", ",", "50"}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.566100908275902*^9, 3.56610097346321*^9}},
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"In[128]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{25., -50., -50.}, {25., 50., -50.}, {25., 50., 50.}, {
       25., -50., 50.}, {25., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAmJmBhiwdAj4I1F8PcjqAD/31mWV7sYOMPEp39jiZ/iY
HZCYeoUzY5IZXHy1XXj0xvMGBwTNbPYGfbOCi6/pvp3BoK96gOv64gLbKHu4
+MFTC123fRY6ADbvjx1cXKj5AFDm4350cxZeM3lv4cp+ACg6TXGfCVw88JZ0
TaIR1wEH4cTDl7l1MdS/+cW6O3G2Alz8R13WnpLJN+wtHnw+zJHIAxcXqDID
ekHWYfPZ3pec3CJw8ZKtor9P62k48LA7bWrwlIOLn3l38rDTWiOHMxrToqPO
KsHFK7hVNOrOmGOo/30aqOGStQO6vSL2x+5sZbFzeJ7vpMjkx3EAJg70jXaq
p63DibMFzHb2ynBxUHQc32nlUNezM5vTUg8uLgQyKNTMYZ/BTC2Jo0ZwcYVL
+fHsfroOLGF8uptyzeDiK455m3c6qjp8yQmrXddmDhd/sI9vjvEiQYeoFOv7
/n8t4OI7/rR/uR3OcsCrulnfR8wKLs6Q38hylF8BQ/yf86+3rxPUD2y/yHCP
SRNh/gwf0R6vV6oH0N35Rn+3Ov9phQOgZKW0xhAuHgCN3yzfz33BXxD+VV/Q
ueFhJi/EX7W6cHGX7pznvzOlHD45nk+7+lwNLr5m7Y34sn4RB0UmvoVeuvJw
8f0g725hdDgnCUxJd8Th4rB0ZQJOiJJw8TOx3ifY/yod2M2lab9ymyxcXGX6
/wl11roHuBa9Y57wCxFfdi9urvm1xxhDHBg6BywPmx8IusoS+D1QAS4OTsfZ
1geSL5aUGVUIw8Uv73ksIhtpd2DDy/N1Szru7YeJg7KpUJH9gbo94Wt9fojB
01Vkm8W1o3NtD4C9MVUbLo6erwGj0EVh
       "]], 
      {GrayLevel[0.5], EdgeForm[None], Polygon3DBox[CompressedData["
1:eJxTTMoPSmVmYGBQAWIWIAaxIcDSAUJ7HkClMcQdYOKRbRbXjs61PXBLuibR
aKq2Aw71uMyBi/+RKL4uVGR/oH5P+FqfH2Jwcy7veSwiG2l3YMfL83VLOu7t
p7b51HI/Lnc6CCcevpxtfSD5YkmZUYUwQXNwieMy59fb1wcsD5sfCLrKEvg9
UIFs83GZY/fi5ppfe4wPcC16xzzhlzLZ5uMyR2X6/wl11roUm4/LnH/OQJ8l
qB/YfpHhHpOmOdnm4zQnv5HlKL/CAa/qZn0fMSuyzcdlzs4/7V9uh7NQbD4u
cx7s45tjvEjQISrF+r7/Xwuyzcdlzopj3uadjqoOX3LCate1kR/+uMxRuJQf
z+6n68ASxqe7KdeMbPMJmOOArp5I8x1g4lO+scXP8DE7IDH1CmfGJDO4+Gq7
8OiN5w0OCJrZ7A36ZuVAyBxc4mu6b2cw6Kse4Lq+uMA2yh5dvQO6elzmkJqP
ZviI9ni9Uj2wz2CmlsRRowOEzMEljsucM7HeJ9j/Kh3YzaVpv3KbLNXNCQQX
/FwHTMARIEnQHFzib/R3q/OfVjgAil6lNYZw8f2gbLGF0eGcJNCmO+Jkm4/L
naSajyudHDy10HXbZ6ED4HT6xw49naDRuM3BFQ4w92f5fu4L/qJH0P3UMkd9
QeeGh5m8kHxdq0vQHJg4uL7l1oX7a+E1k/cWruwH3vxi3Z04WwEu/qsua0/J
5Bv25g8+H+ZI5HEgZA4h84GRO01xnwnZ5uMyR6j5ADCGP+5HL2cEqsyARZCs
w+azvS85uUUImkOqO0k1n1R3lmwV/X1aT8OBh91pU4OnHEFzcInjMufMu5OH
ndYaOZzRmBYddVaJbPNxmVPBraJRd8acYvfjMgdCY+ZfXOaQmo9cunOe/86U
cvjkeD7t6nO1A4TMwSW+Zu2N+LJ+EQdFJr6FXrryZJuPqx4XErE/difUzAG9
PEQLH4Lm/D4NjMhL1g7o6RyXObjCH90cAPUohY0=
        "]]}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiIdIDQngcYUECkw+pVIOCAIb4GLG6AIQ5l7EUX
XwFR74Bd3AFD/N9/EPDAEIe6E0N8NQ5z1uCwF8qwxeHOAzjciSEOdSeGONSd
cHEAUKpBag==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiIdGBAAZ4H0MVXrwIBBwzxNWBxAwxxKNiLLr4C
ot4Bu7gDhvi//yDggSEOdSeG+Goc5qzBYS8U2OJwJ4a/VuAIB6g7McSh7jwA
AJrkQWo=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{100., -50., -50.}, {100., 50., -50.}, {100., 50., 50.}, {
      100., -50., 50.}, {100., -50., -50.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100., 50., -50.}, {100., -50., -50.}, {100., -50., 50.}, {
       100., 50., 50.}, {100., 50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100., -50., -50.}, {0., -50., -50.}, {0., -50., 50.}, {
       100., -50., 50.}, {100., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -50, -50}, {0, 50, -50}, {0, 50, 50}, {0, -50, 50}, {
       0, -50, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 50., -50.}, {100., 50., -50.}, {100., 50., 50.}, {0., 
       50., 50.}, {0., 50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100., -50., -50.}, {100., 50., -50.}, {0., 50., -50.}, {
       0., -50., -50.}, {100., -50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100., 50., 50.}, {100., -50., 50.}, {0., -50., 50.}, {0., 
       50., 50.}, {100., 50., 50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyVmjGOZEUQRIvlGt/Bwh2njHVGvVdYsYhxkbC5wh4FG2FwhH80PtOVGb8i
IzRV6Qz7eFJH/44dkq766fc/v/7xY2vt6w+tfbp+/v/P03z/ck4/2+eH5q19
e5/X4mve2t/v87n4msd0nafwyPNi8jBv7Zd3/nPxNY85TB7mrf31/r4+FV/z
1v598gf7mmee4mve2m/P91V8zVv79fnciq95TDd5mLf2z/NzL77mkf/V5Gc+
5vsXnafw9M+pv7f+zxz9Z19z9J99zWO6zlM4+q/zMEf/2dc85jB5mKP/7GuO
/rOveeYpvuboP/uao//sax7TTR7m6D/7mqP/Oj/zMVfPZZ7C0z+n38e3/s8c
/Wdfc/Sffc3zeeo8haP/Og9z9J99zWMO4m8PzdF/9jVH/zmP5pmn+Jqj/+xr
jv6zr3lMN3mYo//sa47+6/zMx1w9l3kKT3/8ubNPnPafm6857T83X/OYXnzN
af8peZjT/nPzNY85iKP/7E97zs3XnPafm6955im+5rT/3HzNaf+5+ZrHdOK0
/9z8ac+5+ZrT/nPzNR8Te07ts/PPuS+8/7ykHz1nX3Pef+BrHtN1nsJ5/+E8
zHn/ga95zGHyMOf9J/jbQ3Pef+BrnnmKrznvP/A15/0HvuYx3eRhzvsPnqfm
vP/A13xM7jmlz84/599/6P/M0X/2NUf/2dc8n6fOUzj6r/MwR//Z1zzmMHmY
o//sa47+s6955iGO/rMfPWdfc/Sffc1jusnDHP1nX3P0n5+P5mOunps+O3/8
+WCfOO8/8DXn/Qe+5jGdeD5Pk+el+Jrz/gNf85iDOH3/c/PnPQe+5rz/wNc8
8xDn/Qf+vOfA15z3H/iax/Tia877D3zNef/B89F8TO45pc/OP+fPB/2fOfrP
vubo/8zfHprH9OJrjv6zrzn6z77mMYfJwxz9Z19z9J99zTNP8TVH/9nXHP1n
X/OYbvIwR//Z1xz9575pPubquemz88/59w36P3P0f+ZvD83Rf/Y1z+dZfM3R
f52HOfrPvuYxh8nDHP1nX3P0n33NM0/xNUf/2dcc/Wdf85hu8jBH/9nXHP3n
fmo+5uq56bPzz3h+5BMv+0/m17zsP+lrHtOLr3nZfygP87L/pK95zFF8zcv+
k77mZf8ZP8v+w3mKr3nZfzKP5mX/SV/zmF58zcv+k/k1L/tP+pqPwZ6Tvubp
n/PzQP9njv6zrzn6P3P0n/3n9OJrjv6zrzn6z77mMYfJwxz95+ejOfrPvuaZ
p/iao//sa47+s695TDd5mKP/7GuO/uv8zMdcPTd9dv45//1G/2eO/rOvOfo/
c/Sf/fHciq85+s++5ug/+5rHHCYPc/Sfn4/m6D/7mmee4muO/rOvOfrPvuYx
3eRhjv6zrzn6r/MzH3P13PTZ+WfkJZ94Of9KX/Ny/pW+5jGdOO8/nOel+JqX
86/0NY85iq95Of8anP+/Dj6dc6WveeYpvubl/Ct9zcv5V/qax/Tia17Ov9LX
vJx/UX7mY3DONecpPP1zfn30f+boP/uao//sax7TdZ7C0f+Zo//sR8/Z1zzm
KL7m6D/7mqP//H41zzzF1xz9Z19z9J99zWO6ycMc/Wdfc/Rf52c+5uq56bPz
z/nvE+//r+lHz9nXnPd/+Jrn89R5Cuf9n/Mw5/0/OO//nOcovua8/yOP5rz/
w9c88xRfc97/4WvO+z98zWO6ycOc93/4mvP+z/mZj8k9v/TZ+Wf8e/KJl/vP
6Wte7j+nr3lML77m5f4z5WFe7j+nr3nMUXzNy/3n9DUv95/T1zzzFF/zcv85
fc3L/ef0NY/pxde83H9OX/Ny/5nyMx+De85znsLdPUbP9+43untinu/dH3P3
xDwfr7vM9+6PuXtinu/dF3L3gjyP97XK9+4LuXtBno/3v8lX73u4ex2e7933
cPc6PN+77+HuOXg+P6+P+d79B3evwPO9+wbuXoHn4zks8737Bu5c3vPxuss8
PpdVvnde787lPd87r3fn8p6P113me+f17lze8/G5LPO983p3Du559GqVj5zL
PHq1yvfOx905uOd75+PuHNzz8brLfO983J2Dez4+l2W+dz7uzp09j16t8pFz
mdN/dz7ke+fR7tzZ873zaHcu7PneebE7F/Y8Ppe181N3Tup5fC6rfO/81J2T
eh7va+28zJ2LeR7va5XvnZe5c7GP+Op5hzvX8HzvvMOda3ger7v2/bP7ntnz
eN1Vvvf9s/vez/N43Y/4f5gdHTM=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJztmDFuFEEQRRdzjUmISCeZwMnIvoIFiE2RiLmCj0KMCDhCH43R7vyurfer
JSPZWiPZyWqexd+qt6uPuz98+/Hw/eZwODy8OxzeH/Rze3d6ebxv6XXjn08/
q/Ffp59b4+fXZZAzG/904h8HOZPxn6f3vTH+58zvyPcc41/P72v8y3nOQc5i
/PfZwyB/rXMe70e8Jd8X/snln3yfc5AzG5f/OmcyLv/k8j/IMS7/5PI/2Mu4
/Nf5a52z+R/wlr7XF/7J9Uwu/3XObFz+Mz92/+Tyzxz5r+eZjMs/ufwP9jIu
/3X+Wuds/ge8yR/9k+d/Hzw/M2c2nvqn8/BPnvrngqf+8RzjqX8ueOof38t4
6p8LnvqHOeof5y17Yv8Ez/0z55zeP8yZjef+Yc4EfkT/BM/9E3zPMZ77J3ju
H+Ys4Oyf4Ll/sFfvH+Mtfx/DP7n8k8t/nTMb13OdMxmXf3L5zzz8k8s/ufzX
OYtx+ec88l/utfkf8Ka96Z889494n9N4/ryD5zkiPz8Hz/0TPPcP55mM5/4J
nvvH9jKe+yfmyf2DvXr/GG95v/Cf+bH7J9/nNC7/5PJf50zG9Uwu/4Mc4/JP
Lv+DvYzLP73JP7n8D3jL36Nj908u/+TyX+fMxuW/zpmMa25yPQ9yjMs/ufwP
9jIu/5mHf3L5H/CmeemfXP7J9zkHObNx9A+9GUf/9PnRP3mv6J+eg/7pHP3D
vSwf/dM5+ifPE/1D3vJc0T+Zh3/yfU7j8k8u/3XOZPPIP7n8k2tPcj2Ty3+d
sxiX/zp/rXM2/wPe8ucf/jMP/+TyTy7/5PJf50w2j/yTyz+5/JNrf3I91zmL
cfmv89c6Z/M/4E3vQ//kuX/E2T/B5Z8c5y/kTOD8fy44zl95rzh/dY7zV+c4
fyFnMY7zF/JX46eXOH+Rt5wX/snln3zPBQ//5PJPvnszLv98X/mv55mMyz+5
/A/2Mq7nOn+tczb/A97y58b+D577f805vf+ZM4Oz/4PLP3Ny/wfP/c95JuO5
/4Pn/re9jOf+Z/5a5/T+N970e/onT/1zweW/zpmN4/6Z3ozj/rlz3D8zxzju
nzvH/TP3Mo77Z+SvdU7cP+/8X+8bX9v92Gu7F7rWvcdz3T9c697g7VxPP/W+
b+dxeXvaefx/OUc/17n4WufTa53LXvrc8dJ/Pz/978C/XZdROQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301480813216*^9, 3.6147092458135223`*^9, 
  3.614729103095026*^9},
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"During evaluation of In[128]:="]
}, Open  ]],

Cell[TextData[{
 "The custom ",
 StyleBox["ApertureStop", "MB"],
 " at work."
}], "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[{
 "We may examine the image of the light on the ",
 StyleBox["Boundary", "MB"],
 ", which is ",
 StyleBox["ComponentNumber", "MB"],
 " 3  It matches the shape of the aperture."
}], "Text",
 CellChangeTimes->{{3.5661010430095043`*^9, 3.566101044819829*^9}},
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowSystem", "[", 
   RowBox[{"output", ",", 
    RowBox[{"PlotType", "\[Rule]", "Surface"}], ",", 
    RowBox[{"RayChoice", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"ComponentNumber", "\[Rule]", "3"}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5661010273202953`*^9, 3.5661010275663633`*^9}},
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"In[130]:="],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., -25.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{2.3333333333333286`, -25.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{2.3333333333333286`, -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-2.3333333333333357`, -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-11.666666666666671`, -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-16.333333333333336`, -21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{2.3333333333333286`, -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-2.3333333333333357`, -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.666666666666671`, -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-16.333333333333336`, -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., -16.333333333333332`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., -11.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.666666666666671`, -11.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-16.333333333333336`, -11.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., -11.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-25.66666666666667, -11.666666666666664`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{16.333333333333332`, -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{11.666666666666664`, -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-11.666666666666671`, -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-16.333333333333336`, -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-25.66666666666667, -7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{25.666666666666664`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{16.333333333333332`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{2.3333333333333286`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-2.3333333333333357`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.666666666666671`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-16.333333333333336`, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-25.66666666666667, -2.3333333333333286`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{30.333333333333332`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{25.666666666666664`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{16.333333333333332`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{2.3333333333333286`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-2.3333333333333357`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-7., 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.666666666666671`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-16.333333333333336`, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-25.66666666666667, 2.3333333333333357`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{30.333333333333332`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{25.666666666666664`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{16.333333333333332`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{11.666666666666664`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{2.3333333333333286`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-11.666666666666671`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-16.333333333333336`, 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-21., 7.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{25.666666666666664`, 11.666666666666671`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., 11.666666666666671`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{16.333333333333332`, 11.666666666666671`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, 11.666666666666671`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 11.666666666666671`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{25.666666666666664`, 16.333333333333336`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., 16.333333333333336`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{16.333333333333332`, 16.333333333333336`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, 16.333333333333336`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 16.333333333333336`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{21., 21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{16.333333333333332`, 21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{11.666666666666664`, 21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 21.}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{16.333333333333332`, 25.66666666666667}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, 25.66666666666667}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 25.66666666666667}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{2.3333333333333286`, 25.66666666666667}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{11.666666666666664`, 30.333333333333343`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{7., 30.333333333333343`}], 
     {RGBColor[0, 0, 0], Thickness[
       NCache[
        Rational[1, 5000], 0.0002]], 
      LineBox[{{-50., -50.}, {50., -50.}, {50., 50.}, {-50., 
       50.}, {-50., -50.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301485059029*^9, 3.614709249995449*^9, 
  3.61472910716453*^9},
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"},
 CellLabel->"During evaluation of In[130]:="]
}, Open  ]],

Cell["\<\
The image at the boundary matches the shape of the custom aperture.\
\>", "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[{
 "The example used the ",
 StyleBox["ApertureStop", "Input"],
 " component to demonstrate a complex polygon hole opening, nevertheless,  \
the basic method works equally well for both the holes and edges of any  \
component aperture."
}], "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Light Sources", "Section",
 CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 StyleBox["Some situations require light sources with special behaviors.   \
One such situation is when you want to move a light source but still maintain \
 full illumination of an entrance pupil.  Another is when the origin of some \
angular source lies far away from the rest of the system, but only light \
within a reasonable distance of the pupil is of interest.  Finally, some \
optical systems expect a chromatic source.  ",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["Rayica",
  FontSlant->"Italic"],
 StyleBox[" presents some options to handle these cases.",
  FontVariations->{"CompatibilityType"->0}]
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell["4.2.1 Maintaining Constant Pupil Illumination", "Subsection",
 CellTags->{
  "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
   "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell["Constant Illumination with BirthPoint", "Subsubsection",
 CellTags->{
  "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
   "PR4.2.1"}],

Cell[TextData[{
 "You often test an optical system by varying the vantage point of an input \
light source.  In general, however, only one vantage point will afford full \
illumination of the entrance pupil.  Typically this position is on the optic \
axis.  The ",
 StyleBox["BirthPoint", "MB"],
 " option makes it possible to maintain illumination of the whole pupil \
regardless of vantage point.  This option reconfigures light source functions \
to interpret their input parameters in terms of entrance pupil requirements.  \
So, instead of distributing emission evenly across some geometry, a source \
will distribute rays evenly across the entrance pupil.  This behavioral \
change saves you from designing a unique light source for every new position \
just to hold constant pupil illumination."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "The ",
 StyleBox["BirthPoint", "MB"],
 " concept is easily visualized.  Following are two examples showing the \
effect of using ",
 StyleBox["BirthPoint", "MB"],
 ".  The entrance pupil consists of a simple ",
 StyleBox["PlanoConvexLens", "MB"],
 ".  The lens presents its planar side to the light sources.  This is the \
pupil.  The first example does not use ",
 StyleBox["BirthPoint", "MB"],
 ".  Instead, the two sources are positioned with ",
 StyleBox["Move", "MB"],
 "-related functions."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"MoveDirected3D", "[", 
       RowBox[{
        RowBox[{"PointOfRays", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"10", ",", "10"}], "}"}], ",", 
          RowBox[{"RayLineRGB", "\[Rule]", "Red"}], ",", 
          RowBox[{"RayPointRGB", "\[Rule]", "Red"}], ",", 
          RowBox[{"RayPointSize", "\[Rule]", "4"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", "100", ",", "100"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "0", ",", 
        RowBox[{"SideOfObject", "\[Rule]", "After"}]}], "]"}], ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"PointOfRays", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"10", ",", "10"}], "}"}], ",", 
          RowBox[{"RayLineRGB", "\[Rule]", "Green"}], ",", 
          RowBox[{"RayPointRGB", "\[Rule]", "Green"}], ",", 
          RowBox[{"RayPointSize", "\[Rule]", "4"}]}], "]"}], ",", 
        RowBox[{"-", "100"}]}], "]"}], ",", 
      RowBox[{"PlanoConvexLens", "[", 
       RowBox[{"100", ",", "50", ",", "10", ",", 
        RowBox[{"GraphicDesign", "\[Rule]", "Solid"}], ",", 
        RowBox[{"CurvatureDirection", "\[Rule]", "Back"}]}], "]"}], ",", 
      RowBox[{"Boundary", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", 
          RowBox[{"-", "30"}], ",", 
          RowBox[{"-", "30"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "100", ",", "100"}], "}"}]}], "]"}]}], "}"}], ",", 
    
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.708"}], ",", 
       RowBox[{"-", "2.587"}], ",", "1.356"}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[131]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0., 8.333333333333332, 0.}, {0., 
      8.049381885742235, 2.156825375854339}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 8.333333333333332, 0.}, {0., 16.666666666666664`, 
      0.}, {0., 16.09876377148447, 4.313650751708678}, {0., 8.049381885742235,
       2.156825375854339}, {0., 8.333333333333332, 0.}}], 
     Polygon3DBox[{{0., 16.666666666666664`, 0.}, {0., 25., 0.}, {0., 
      24.148145657226706`, 6.4704761275630185`}, {0., 16.09876377148447, 
      4.313650751708678}, {0., 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 8.049381885742235, 2.156825375854339}, {
      0., 7.216878364870323, 4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}],
      Polygon3DBox[{{0., 8.049381885742235, 2.156825375854339}, {0., 
      16.09876377148447, 4.313650751708678}, {0., 14.433756729740645`, 
      8.333333333333332}, {0., 7.216878364870323, 4.166666666666666}, {0., 
      8.049381885742235, 2.156825375854339}}], 
     Polygon3DBox[{{0., 16.09876377148447, 4.313650751708678}, {0., 
      24.148145657226706`, 6.4704761275630185`}, {0., 21.65063509461097, 
      12.499999999999998`}, {0., 14.433756729740645`, 8.333333333333332}, {0.,
       16.09876377148447, 4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 7.216878364870323, 4.166666666666666}, {
      0., 5.892556509887896, 5.8925565098878945`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 7.216878364870323, 4.166666666666666}, {0., 
      14.433756729740645`, 8.333333333333332}, {0., 11.785113019775793`, 
      11.785113019775789`}, {0., 5.892556509887896, 5.8925565098878945`}, {0.,
       7.216878364870323, 4.166666666666666}}], 
     Polygon3DBox[{{0., 14.433756729740645`, 8.333333333333332}, {0., 
      21.65063509461097, 12.499999999999998`}, {0., 17.67766952966369, 
      17.677669529663685`}, {0., 11.785113019775793`, 11.785113019775789`}, {
      0., 14.433756729740645`, 8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 5.892556509887896, 
      5.8925565098878945`}, {0., 4.166666666666668, 7.216878364870322}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.892556509887896, 5.8925565098878945`}, {0., 
      11.785113019775793`, 11.785113019775789`}, {0., 8.333333333333336, 
      14.433756729740644`}, {0., 4.166666666666668, 7.216878364870322}, {0., 
      5.892556509887896, 5.8925565098878945`}}], 
     Polygon3DBox[{{0., 11.785113019775793`, 11.785113019775789`}, {0., 
      17.67766952966369, 17.677669529663685`}, {0., 12.500000000000004`, 
      21.650635094610966`}, {0., 8.333333333333336, 14.433756729740644`}, {0.,
       11.785113019775793`, 11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 4.166666666666668, 7.216878364870322}, {
      0., 2.156825375854341, 8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}],
      Polygon3DBox[{{0., 4.166666666666668, 7.216878364870322}, {0., 
      8.333333333333336, 14.433756729740644`}, {0., 4.313650751708682, 
      16.09876377148447}, {0., 2.156825375854341, 8.049381885742235}, {0., 
      4.166666666666668, 7.216878364870322}}], 
     Polygon3DBox[{{0., 8.333333333333336, 14.433756729740644`}, {0., 
      12.500000000000004`, 21.650635094610966`}, {0., 6.470476127563024, 
      24.148145657226706`}, {0., 4.313650751708682, 16.09876377148447}, {0., 
      8.333333333333336, 14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 2.156825375854341, 8.049381885742235}, {
      0., 2.3606412073533245`*^-15, 8.333333333333332}, {0., 0., 0.}, {0., 0.,
       0.}}], Polygon3DBox[{{0., 2.156825375854341, 8.049381885742235}, {0., 
      4.313650751708682, 16.09876377148447}, {0., 4.721282414706649*^-15, 
      16.666666666666664`}, {0., 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 2.156825375854341, 8.049381885742235}}], 
     Polygon3DBox[{{0., 4.313650751708682, 16.09876377148447}, {0., 
      6.470476127563024, 24.148145657226706`}, {0., 7.0819236220599744`*^-15, 
      25.}, {0., 4.721282414706649*^-15, 16.666666666666664`}, {0., 
      4.313650751708682, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 5.102694996447305*^-16, 
      8.333333333333332}, {0., -2.1568253758543383`, 8.049381885742235}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.102694996447305*^-16, 8.333333333333332}, {0., 
      1.020538999289461*^-15, 16.666666666666664`}, {0., -4.313650751708677, 
      16.09876377148447}, {0., -2.1568253758543383`, 8.049381885742235}, {0., 
      5.102694996447305*^-16, 8.333333333333332}}], 
     Polygon3DBox[{{0., 1.020538999289461*^-15, 16.666666666666664`}, {0., 
      1.5308084989341915`*^-15, 25.}, {0., -6.470476127563016, 
      24.148145657226706`}, {0., -4.313650751708677, 16.09876377148447}, {0., 
      1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -2.1568253758543383`, 
      8.049381885742235}, {0., -4.166666666666664, 7.216878364870323}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -2.1568253758543383`, 8.049381885742235}, {
      0., -4.313650751708677, 16.09876377148447}, {0., -8.333333333333329, 
      14.433756729740645`}, {0., -4.166666666666664, 7.216878364870323}, {
      0., -2.1568253758543383`, 8.049381885742235}}], 
     Polygon3DBox[{{0., -4.313650751708677, 16.09876377148447}, {
      0., -6.470476127563016, 24.148145657226706`}, {0., -12.499999999999995`,
       21.65063509461097}, {0., -8.333333333333329, 14.433756729740645`}, {
      0., -4.313650751708677, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -4.166666666666664, 
      7.216878364870323}, {0., -5.8925565098878945`, 5.892556509887896}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -4.166666666666664, 7.216878364870323}, {
      0., -8.333333333333329, 14.433756729740645`}, {0., -11.785113019775789`,
       11.785113019775793`}, {0., -5.8925565098878945`, 5.892556509887896}, {
      0., -4.166666666666664, 7.216878364870323}}], 
     Polygon3DBox[{{0., -8.333333333333329, 14.433756729740645`}, {
      0., -12.499999999999995`, 21.65063509461097}, {0., -17.677669529663685`,
       17.67766952966369}, {0., -11.785113019775789`, 11.785113019775793`}, {
      0., -8.333333333333329, 14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -5.8925565098878945`, 
      5.892556509887896}, {0., -7.216878364870323, 4.166666666666666}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -5.8925565098878945`, 5.892556509887896}, {
      0., -11.785113019775789`, 11.785113019775793`}, {
      0., -14.433756729740645`, 8.333333333333332}, {0., -7.216878364870323, 
      4.166666666666666}, {0., -5.8925565098878945`, 5.892556509887896}}], 
     Polygon3DBox[{{0., -11.785113019775789`, 11.785113019775793`}, {
      0., -17.677669529663685`, 17.67766952966369}, {0., -21.65063509461097, 
      12.499999999999998`}, {0., -14.433756729740645`, 8.333333333333332}, {
      0., -11.785113019775789`, 11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -7.21687836487032, 4.16666666666667}, {
      0., -8.049381885742235, 2.156825375854342}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -7.21687836487032, 4.16666666666667}, {
      0., -14.43375672974064, 8.33333333333334}, {0., -16.09876377148447, 
      4.313650751708684}, {0., -8.049381885742235, 2.156825375854342}, {
      0., -7.21687836487032, 4.16666666666667}}], 
     Polygon3DBox[{{0., -14.43375672974064, 8.33333333333334}, {
      0., -21.650635094610962`, 12.500000000000009`}, {
      0., -24.148145657226706`, 6.470476127563026}, {0., -16.09876377148447, 
      4.313650751708684}, {0., -14.43375672974064, 8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -8.049381885742235, 
      2.156825375854342}, {0., -8.333333333333332, 1.020538999289461*^-15}, {
      0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -8.049381885742235, 2.156825375854342}, {
      0., -16.09876377148447, 4.313650751708684}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}, {0., -8.333333333333332, 
      1.020538999289461*^-15}, {0., -8.049381885742235, 2.156825375854342}}], 
     Polygon3DBox[{{0., -16.09876377148447, 4.313650751708684}, {
      0., -24.148145657226706`, 6.470476127563026}, {0., -25., 
      3.061616997868383*^-15}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}, {0., -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -8.333333333333332, 
      1.020538999289461*^-15}, {0., -8.049381885742235, -2.15682537585434}, {
      0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -8.333333333333332, 1.020538999289461*^-15}, {
      0., -16.666666666666664`, 2.041077998578922*^-15}, {
      0., -16.09876377148447, -4.31365075170868}, {
      0., -8.049381885742235, -2.15682537585434}, {0., -8.333333333333332, 
      1.020538999289461*^-15}}], 
     Polygon3DBox[{{0., -16.666666666666664`, 2.041077998578922*^-15}, {
      0., -25., 3.061616997868383*^-15}, {
      0., -24.148145657226706`, -6.47047612756302}, {
      0., -16.09876377148447, -4.31365075170868}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -8.049381885742235, -2.156825375854336}, {
      0., -7.216878364870323, -4.166666666666664}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -8.049381885742235, -2.156825375854336}, {
      0., -16.09876377148447, -4.313650751708672}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -7.216878364870323, -4.166666666666664}, {
      0., -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{0., -16.09876377148447, -4.313650751708672}, {
      0., -24.14814565722671, -6.470476127563009}, {
      0., -21.65063509461097, -12.499999999999993`}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -7.216878364870323, -4.166666666666664}, {
      0., -5.892556509887897, -5.8925565098878945`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -7.216878364870323, -4.166666666666664}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -11.785113019775794`, -11.785113019775789`}, {
      0., -5.892556509887897, -5.8925565098878945`}, {
      0., -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{0., -14.433756729740645`, -8.333333333333329}, {
      0., -21.65063509461097, -12.499999999999993`}, {
      0., -17.677669529663692`, -17.677669529663685`}, {
      0., -11.785113019775794`, -11.785113019775789`}, {
      0., -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -5.892556509887898, -5.892556509887893}, {
      0., -4.16666666666667, -7.216878364870319}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -5.892556509887898, -5.892556509887893}, {
      0., -11.785113019775796`, -11.785113019775785`}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -4.16666666666667, -7.216878364870319}, {
      0., -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{0., -11.785113019775796`, -11.785113019775785`}, {
      0., -17.677669529663696`, -17.677669529663678`}, {
      0., -12.50000000000001, -21.65063509461096}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -4.16666666666667, -7.216878364870319}, {
      0., -2.156825375854346, -8.049381885742234}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -4.16666666666667, -7.216878364870319}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -2.156825375854346, -8.049381885742234}, {
      0., -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{0., -8.33333333333334, -14.433756729740638`}, {
      0., -12.50000000000001, -21.65063509461096}, {
      0., -6.470476127563038, -24.148145657226703`}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -2.156825375854346, -8.049381885742234}, {
      0., -8.932295329768568*^-15, -8.333333333333332}, {0., 0., 0.}, {0., 0.,
       0.}}], Polygon3DBox[{{0., -2.156825375854346, -8.049381885742234}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0., -8.932295329768568*^-15, -8.333333333333332}, {
      0., -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{0., -4.313650751708692, -16.098763771484467`}, {
      0., -6.470476127563038, -24.148145657226703`}, {
      0., -2.6796885989305705`*^-14, -25.}, {
      0., -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0., -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -1.5308084989341913`*^-15, -8.333333333333332}, {0., 
      2.1568253758543356`, -8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -1.5308084989341913`*^-15, -8.333333333333332}, {
      0., -3.0616169978683826`*^-15, -16.666666666666664`}, {0., 
      4.313650751708671, -16.09876377148447}, {0., 
      2.1568253758543356`, -8.049381885742235}, {
      0., -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{0., -3.0616169978683826`*^-15, -16.666666666666664`}, {
      0., -4.592425496802574*^-15, -25.}, {0., 
      6.470476127563007, -24.14814565722671}, {0., 
      4.313650751708671, -16.09876377148447}, {
      0., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      2.1568253758543356`, -8.049381885742235}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 2.1568253758543356`, -8.049381885742235}, {0., 
      4.313650751708671, -16.09876377148447}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{0., 4.313650751708671, -16.09876377148447}, {0., 
      6.470476127563007, -24.14814565722671}, {0., 
      12.499999999999984`, -21.650635094610976`}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 4.166666666666661, -7.216878364870325}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      11.78511301977578, -11.785113019775807`}, {0., 
      5.89255650988789, -5.892556509887903}, {0., 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{0., 8.333333333333321, -14.43375672974065}, {0., 
      12.499999999999984`, -21.650635094610976`}, {0., 
      17.67766952966367, -17.67766952966371}, {0., 
      11.78511301977578, -11.785113019775807`}, {0., 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      5.8925565098878945`, -5.892556509887897}, {0., 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.8925565098878945`, -5.892556509887897}, {0., 
      11.785113019775789`, -11.785113019775794`}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      7.216878364870319, -4.16666666666667}, {0., 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{0., 11.785113019775789`, -11.785113019775794`}, {0., 
      17.677669529663685`, -17.677669529663692`}, {0., 
      21.65063509461096, -12.50000000000001}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 7.216878364870319, -4.16666666666667}, {
      0., 8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 7.216878364870319, -4.16666666666667}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      16.098763771484467`, -4.313650751708693}, {0., 
      8.049381885742234, -2.1568253758543463`}, {0., 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{0., 14.433756729740638`, -8.33333333333334}, {0., 
      21.65063509461096, -12.50000000000001}, {0., 
      24.148145657226703`, -6.470476127563039}, {0., 
      16.098763771484467`, -4.313650751708693}, {0., 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      8.049381885742234, -2.1568253758543463`}, {0., 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 8.049381885742234, -2.1568253758543463`}, {0.,
       16.098763771484467`, -4.313650751708693}, {0., 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0., 
      8.333333333333332, -9.442564829413298*^-15}, {0., 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{0., 16.098763771484467`, -4.313650751708693}, {0., 
      24.148145657226703`, -6.470476127563039}, {0., 
      25., -2.8327694488239898`*^-14}, {0., 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0., 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBnRg6YAu4nF1w/03qhYOjrtK6448lITLP/vdwjph
manDfzDQgIvvSBM+UL3W0GE7lIaJM4FJTYenUH0wcXeouTB7YOKnz59fP3vy
bRt0d9lB1B9AV/8X4o4Dz9DMh7rjwA409zyBqDvACnUXmn8PeKL5F+qOAxB3
vbaBiXhC1ZtB3YUWPgf+QN0FE98Fdc9WKA0TZ4O448BjqD6YeDjUXHeoPTDx
G7dvH96y7ssemLtg4iZQd3uiqf8OjacXaObD4mknmnug7nCAuQsmDnWHQwSa
f6HucICEz+89ABYlv5c=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 8.333333333333332, 
        0.}, {9.32624200410794, 8.049381885742235, 2.156825375854339}, {10., 
        0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 8.333333333333332, 0.}, {
        7.249551165715211, 16.666666666666664`, 0.}, {7.249551165715211, 
        16.09876377148447, 4.313650751708678}, {9.32624200410794, 
        8.049381885742235, 2.156825375854339}, {9.32624200410794, 
        8.333333333333332, 0.}}], 
       Polygon3DBox[{{7.249551165715211, 16.666666666666664`, 0.}, {
        3.5780254190444083`, 25., 0.}, {3.5780254190444083`, 
        24.148145657226706`, 6.4704761275630185`}, {7.249551165715211, 
        16.09876377148447, 4.313650751708678}, {7.249551165715211, 
        16.666666666666664`, 0.}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 8.049381885742235, 
        2.156825375854339}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 8.049381885742235, 
        2.156825375854339}, {7.249551165715211, 16.09876377148447, 
        4.313650751708678}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {9.32624200410794, 8.049381885742235, 
        2.156825375854339}}], 
       Polygon3DBox[{{7.249551165715211, 16.09876377148447, 
        4.313650751708678}, {3.5780254190444083`, 24.148145657226706`, 
        6.4704761275630185`}, {3.5780254190444083`, 21.65063509461097, 
        12.499999999999998`}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {7.249551165715211, 16.09876377148447, 
        4.313650751708678}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}}], 
       Polygon3DBox[{{7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {3.5780254190444083`, 21.65063509461097, 
        12.499999999999998`}, {3.5780254190444083`, 17.67766952966369, 
        17.677669529663685`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}}], 
       Polygon3DBox[{{7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {3.5780254190444083`, 17.67766952966369, 
        17.677669529663685`}, {3.5780254190444083`, 12.500000000000004`, 
        21.650635094610966`}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}}], 
       Polygon3DBox[{{7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {3.5780254190444083`, 12.500000000000004`, 
        21.650635094610966`}, {3.5780254190444083`, 6.470476127563024, 
        24.148145657226706`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {9.32624200410794, 2.3606412073533245`*^-15, 
        8.333333333333332}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {7.249551165715211, 4.721282414706649*^-15, 
        16.666666666666664`}, {9.32624200410794, 2.3606412073533245`*^-15, 
        8.333333333333332}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {3.5780254190444083`, 6.470476127563024, 
        24.148145657226706`}, {3.5780254190444083`, 7.0819236220599744`*^-15, 
        25.}, {7.249551165715211, 4.721282414706649*^-15, 
        16.666666666666664`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 5.102694996447305*^-16,
         8.333333333333332}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 5.102694996447305*^-16, 
        8.333333333333332}, {7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {9.32624200410794, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}, {3.5780254190444083`, 1.5308084989341915`*^-15, 
        25.}, {3.5780254190444083`, -6.470476127563016, 
        24.148145657226706`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {3.5780254190444083`, -6.470476127563016, 
        24.148145657226706`}, {3.5780254190444083`, -12.499999999999995`, 
        21.65063509461097}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}}], 
       Polygon3DBox[{{7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {3.5780254190444083`, -12.499999999999995`, 
        21.65063509461097}, {3.5780254190444083`, -17.677669529663685`, 
        17.67766952966369}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {9.326242004107932, -7.216878364870323, 
        4.166666666666666}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {7.249551165715211, -14.433756729740645`, 
        8.333333333333332}, {9.326242004107932, -7.216878364870323, 
        4.166666666666666}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}}], 
       Polygon3DBox[{{7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {3.5780254190444083`, -17.677669529663685`, 
        17.67766952966369}, {3.5780254190444083`, -21.65063509461097, 
        12.499999999999998`}, {7.249551165715211, -14.433756729740645`, 
        8.333333333333332}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, -7.21687836487032, 
        4.16666666666667}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, -7.21687836487032, 
        4.16666666666667}, {7.249551165715218, -14.43375672974064, 
        8.33333333333334}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {9.326242004107932, -7.21687836487032, 
        4.16666666666667}}], 
       Polygon3DBox[{{7.249551165715218, -14.43375672974064, 
        8.33333333333334}, {3.578025419044401, -21.650635094610962`, 
        12.500000000000009`}, {3.5780254190444083`, -24.148145657226706`, 
        6.470476127563026}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {7.249551165715218, -14.43375672974064, 
        8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}}], 
       Polygon3DBox[{{7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {3.5780254190444083`, -24.148145657226706`, 
        6.470476127563026}, {3.5780254190444083`, -25., 
        3.061616997868383*^-15}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {
        9.32624200410794, -8.049381885742235, -2.15682537585434}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {
        7.249551165715211, -16.09876377148447, -4.31365075170868}, {
        9.32624200410794, -8.049381885742235, -2.15682537585434}, {
        9.32624200410794, -8.333333333333332, 1.020538999289461*^-15}}], 
       Polygon3DBox[{{7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {3.5780254190444083`, -25., 
        3.061616997868383*^-15}, {
        3.5780254190444083`, -24.148145657226706`, -6.47047612756302}, {
        7.249551165715211, -16.09876377148447, -4.31365075170868}, {
        7.249551165715211, -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -8.049381885742235, -2.156825375854336}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -8.049381885742235, -2.156825375854336}, {
        7.249551165715211, -16.09876377148447, -4.313650751708672}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        9.32624200410794, -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{
        7.249551165715211, -16.09876377148447, -4.313650751708672}, {
        3.5780254190444083`, -24.14814565722671, -6.470476127563009}, {
        3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        7.249551165715211, -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        9.32624200410794, -5.892556509887897, -5.8925565098878945`}, {10., 0.,
         0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        7.249551165715211, -11.785113019775794`, -11.785113019775789`}, {
        9.32624200410794, -5.892556509887897, -5.8925565098878945`}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
        3.5780254190444083`, -17.677669529663692`, -17.677669529663685`}, {
        7.249551165715211, -11.785113019775794`, -11.785113019775789`}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -5.892556509887898, -5.892556509887893}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -5.892556509887898, -5.892556509887893}, {
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        9.32624200410794, -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}, {
        3.5780254190444083`, -17.677669529663696`, -17.677669529663678`}, {
        3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
        3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        9.32624200410794, -8.932295329768568*^-15, -8.333333333333332}, {10., 
        0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        7.249551165715211, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        9.32624200410794, -8.932295329768568*^-15, -8.333333333333332}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
        3.5780254190444083`, -2.6796885989305705`*^-14, -25.}, {
        7.249551165715211, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}, {
        9.32624200410794, 2.1568253758543356`, -8.049381885742235}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}, {
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        7.249551165715211, 4.313650751708671, -16.09876377148447}, {
        9.32624200410794, 2.1568253758543356`, -8.049381885742235}, {
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        3.5780254190444083`, -4.592425496802574*^-15, -25.}, {
        3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {
        7.249551165715211, 4.313650751708671, -16.09876377148447}, {
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}}],
        Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}, {7.249551165715211, 
        4.313650751708671, -16.09876377148447}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, 
        4.313650751708671, -16.09876377148447}, {3.5780254190444083`, 
        6.470476127563007, -24.14814565722671}, {3.5780254190444083`, 
        12.499999999999984`, -21.650635094610976`}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {7.249551165715211, 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {9.32624200410794, 
        5.89255650988789, -5.892556509887903}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {7.249551165715211, 
        11.78511301977578, -11.785113019775807`}, {9.32624200410794, 
        5.89255650988789, -5.892556509887903}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {3.5780254190444083`, 
        12.499999999999984`, -21.650635094610976`}, {3.578025419044401, 
        17.67766952966367, -17.67766952966371}, {7.249551165715211, 
        11.78511301977578, -11.785113019775807`}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}, {7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}, {3.5780254190444083`, 
        17.677669529663685`, -17.677669529663692`}, {3.5780254190444083`, 
        21.65063509461096, -12.50000000000001}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {3.5780254190444083`, 
        21.65063509461096, -12.50000000000001}, {3.5780254190444083`, 
        24.148145657226703`, -6.470476127563039}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {9.32624200410794, 
        8.333333333333332, -9.442564829413298*^-15}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {7.249551165715211, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {9.32624200410794, 
        8.333333333333332, -9.442564829413298*^-15}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {3.5780254190444083`, 
        24.148145657226703`, -6.470476127563039}, {3.5780254190444083`, 
        25., -2.8327694488239898`*^-14}, {7.249551165715211, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIE7Irjh1ej6PAwMYWEJphLjH1Q3336haODjuKq07
8lDSASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBDZV0+EpVB9M3B1q
LswemPjp8+fXz5582wbmLpi4HUT9AXT1fyHuOPAMzXyoOw7A3BUAFX8CUXeA
FeouNP8e8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZx
x4HHUH0w8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNO
NPdA3QF3Fzy+oOEegeZfWDxBwuf3HgB25B2h
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{0., 25., 0.}, {3.5780254190444083`, 25., 0.}, {
          3.5780254190444083`, 24.148145657226706`, 6.4704761275630185`}, {0.,
           24.148145657226706`, 6.4704761275630185`}, {0., 25., 0.}}], 
         Polygon3DBox[{{0., 24.148145657226706`, 6.4704761275630185`}, {
          3.5780254190444083`, 24.148145657226706`, 6.4704761275630185`}, {
          3.5780254190444083`, 21.65063509461097, 12.499999999999998`}, {0., 
          21.65063509461097, 12.499999999999998`}, {0., 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{0., 21.65063509461097, 12.499999999999998`}, {
          3.5780254190444083`, 21.65063509461097, 12.499999999999998`}, {
          3.5780254190444083`, 17.67766952966369, 17.677669529663685`}, {0., 
          17.67766952966369, 17.677669529663685`}, {0., 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{0., 17.67766952966369, 17.677669529663685`}, {
          3.5780254190444083`, 17.67766952966369, 17.677669529663685`}, {
          3.5780254190444083`, 12.500000000000004`, 21.650635094610966`}, {0.,
           12.500000000000004`, 21.650635094610966`}, {0., 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{0., 12.500000000000004`, 21.650635094610966`}, {
          3.5780254190444083`, 12.500000000000004`, 21.650635094610966`}, {
          3.5780254190444083`, 6.470476127563024, 24.148145657226706`}, {0., 
          6.470476127563024, 24.148145657226706`}, {0., 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{0., 6.470476127563024, 24.148145657226706`}, {
          3.5780254190444083`, 6.470476127563024, 24.148145657226706`}, {
          3.5780254190444083`, 7.0819236220599744`*^-15, 25.}, {0., 
          7.0819236220599744`*^-15, 25.}, {0., 6.470476127563024, 
          24.148145657226706`}}], 
         Polygon3DBox[{{0., 1.5308084989341915`*^-15, 25.}, {
          3.5780254190444083`, 1.5308084989341915`*^-15, 25.}, {
          3.5780254190444083`, -6.470476127563016, 24.148145657226706`}, {
          0., -6.470476127563016, 24.148145657226706`}, {0., 
          1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{0., -6.470476127563016, 24.148145657226706`}, {
          3.5780254190444083`, -6.470476127563016, 24.148145657226706`}, {
          3.5780254190444083`, -12.499999999999995`, 21.65063509461097}, {
          0., -12.499999999999995`, 21.65063509461097}, {
          0., -6.470476127563016, 24.148145657226706`}}], 
         Polygon3DBox[{{0., -12.499999999999995`, 21.65063509461097}, {
          3.5780254190444083`, -12.499999999999995`, 21.65063509461097}, {
          3.5780254190444083`, -17.677669529663685`, 17.67766952966369}, {
          0., -17.677669529663685`, 17.67766952966369}, {
          0., -12.499999999999995`, 21.65063509461097}}], 
         Polygon3DBox[{{0., -17.677669529663685`, 17.67766952966369}, {
          3.5780254190444083`, -17.677669529663685`, 17.67766952966369}, {
          3.5780254190444083`, -21.65063509461097, 12.499999999999998`}, {
          0., -21.65063509461097, 12.499999999999998`}, {
          0., -17.677669529663685`, 17.67766952966369}}], 
         Polygon3DBox[{{0., -21.650635094610962`, 12.500000000000009`}, {
          3.578025419044401, -21.650635094610962`, 12.500000000000009`}, {
          3.5780254190444083`, -24.148145657226706`, 6.470476127563026}, {
          0., -24.148145657226706`, 6.470476127563026}, {
          0., -21.650635094610962`, 12.500000000000009`}}], 
         Polygon3DBox[{{0., -24.148145657226706`, 6.470476127563026}, {
          3.5780254190444083`, -24.148145657226706`, 6.470476127563026}, {
          3.5780254190444083`, -25., 3.061616997868383*^-15}, {0., -25., 
          3.061616997868383*^-15}, {0., -24.148145657226706`, 
          6.470476127563026}}], 
         Polygon3DBox[{{0., -25., 3.061616997868383*^-15}, {
          3.5780254190444083`, -25., 3.061616997868383*^-15}, {
          3.5780254190444083`, -24.148145657226706`, -6.47047612756302}, {
          0., -24.148145657226706`, -6.47047612756302}, {0., -25., 
          3.061616997868383*^-15}}], 
         Polygon3DBox[{{0., -24.14814565722671, -6.470476127563009}, {
          3.5780254190444083`, -24.14814565722671, -6.470476127563009}, {
          3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
          0., -21.65063509461097, -12.499999999999993`}, {
          0., -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{0., -21.65063509461097, -12.499999999999993`}, {
          3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
          3.5780254190444083`, -17.677669529663692`, -17.677669529663685`}, {
          0., -17.677669529663692`, -17.677669529663685`}, {
          0., -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{0., -17.677669529663696`, -17.677669529663678`}, {
          3.5780254190444083`, -17.677669529663696`, -17.677669529663678`}, {
          3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
          0., -12.50000000000001, -21.65063509461096}, {
          0., -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{0., -12.50000000000001, -21.65063509461096}, {
          3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
          3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
          0., -6.470476127563038, -24.148145657226703`}, {
          0., -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{0., -6.470476127563038, -24.148145657226703`}, {
          3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
          3.5780254190444083`, -2.6796885989305705`*^-14, -25.}, {
          0., -2.6796885989305705`*^-14, -25.}, {
          0., -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{0., -4.592425496802574*^-15, -25.}, {
          3.5780254190444083`, -4.592425496802574*^-15, -25.}, {
          3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {0., 
          6.470476127563007, -24.14814565722671}, {
          0., -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{0., 6.470476127563007, -24.14814565722671}, {
          3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {
          3.5780254190444083`, 12.499999999999984`, -21.650635094610976`}, {
          0., 12.499999999999984`, -21.650635094610976`}, {0., 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{0., 12.499999999999984`, -21.650635094610976`}, {
          3.5780254190444083`, 12.499999999999984`, -21.650635094610976`}, {
          3.578025419044401, 17.67766952966367, -17.67766952966371}, {0., 
          17.67766952966367, -17.67766952966371}, {0., 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{0., 17.677669529663685`, -17.677669529663692`}, {
          3.5780254190444083`, 17.677669529663685`, -17.677669529663692`}, {
          3.5780254190444083`, 21.65063509461096, -12.50000000000001}, {0., 
          21.65063509461096, -12.50000000000001}, {0., 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{0., 21.65063509461096, -12.50000000000001}, {
          3.5780254190444083`, 21.65063509461096, -12.50000000000001}, {
          3.5780254190444083`, 24.148145657226703`, -6.470476127563039}, {0., 
          24.148145657226703`, -6.470476127563039}, {0., 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{0., 24.148145657226703`, -6.470476127563039}, {
          3.5780254190444083`, 24.148145657226703`, -6.470476127563039}, {
          3.5780254190444083`, 25., -2.8327694488239898`*^-14}, {0., 
          25., -2.8327694488239898`*^-14}, {0., 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 100., -30.}, {0., -30., -30.}, {0., -30., 100.}, {0., 
       100., 100.}, {0., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., -30., -30.}, {-100., -30., -30.}, {-100., -30., 100.}, {
       0., -30., 100.}, {0., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -30., -30.}, {-100., 100., -30.}, {-100., 100., 
       100.}, {-100., -30., 100.}, {-100., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -30.}, {0., 100., -30.}, {0., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., -30., -30.}, {0., 100., -30.}, {-100., 
       100., -30.}, {-100., -30., -30.}, {0., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 100., 100.}, {0., -30., 100.}, {-100., -30., 
       100.}, {-100., 100., 100.}, {0., 100., 100.}}]}}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAJR2QKNJFEeAG3USfeFVhgTVS8isj+bp
MTtQ8Drn5jFTBQLqBfaeWGv43CDa2AFCKxPtHlRAPf8K/Hfmk59o4vChbW/E
skmyBwiph4ETDb+3FJ0wJqAeUxwAKBc7Xw==
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAAMO8LSSvz1tgqLDyS/hB+LzFB0IqYcB
8ddSmdn1hNVDzT9ArPmo5hJ2P3ZA0Hw0eaLD5wCx7kG1h+jwOQAA/kI3EA==

      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], 
     Line3DBox[{{{0., 0., 17.477898484211295`}, {
      7.813343592360431, -3.6809821751335754`, 14.440274636869479`}}, {{
      0., -22.54706357026234, 8.105032724901065}, {0., -22.54706357026234, 
      8.105032724901065}}, {{-1.4210854715202004`*^-14, 19.356214952114698`, 
      9.678107476057349}, {6.780720402192315, 16.69577726636623, 
      6.698389118639783}}, {{0., 0., 0.}, {
      9.635150250318308, -4.3426881840035385`, -4.3426881840035385`}}, {{0., 
      20.566880122757595`, -7.393212687080208}, {5.502074954027084, 
      18.538073600416006`, -10.136149772913956`}}, {{0., 
      0., -19.783000289346802`}, {
      4.9166751057798175`, -2.0981607243843325`, -22.29624015590705}}}]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxYeBpJX972gRFh5Nfwg/E5yk6yJmIPfm9UsFh
ZUzo8m+tSg6XKiLVRZKUHBjQgPhrqczsekWH96f/rv4UjJD/aLaUV6AXwYea
fwCH+QfQzYeZC+PDzEc3Fz9QwakOav4BHOYfQFePFj4HcIQPhj6YPTjC5wCa
+QdwmA8LnwMA0I53Vw==
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgAGImIAax53/00i6Vl3a4F15TKrfJwGHTocQWtdNSDgxg
cMFGp2NKkqogs8OBjJ7GfbK8B1r3n3svzyTmsGkBi+H+TiOHV9w+OVtdVQ4w
QMFWAfY7s78oOWTvWKIvIq5+AJc59QwqorMuSzlcqdp6bna3+gHz14985+/S
xmnOdym+1nWiCg4vZF+nCCvwHTBSX2/TYKpN0JyWhA6m2jV6B5bEP39x64Qe
TnNg6hctCGdS19c+4HPXQ05jthpOcwiJo5tTulPl1VcbEQcZ3SuXVY8ZH9jH
NfnKja3KBwCbJY5F
      "]]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{-100., 100., 100.}, {0., 0., 17.477898484211295`}, {
      0., -22.54706357026234, 8.105032724901065}, {-1.4210854715202004`*^-14, 
      19.356214952114698`, 9.678107476057349}, {0., 0., 0.}, {-100., 100., 
      100.}, {0., 20.566880122757595`, -7.393212687080208}, {0., 
      0., -19.783000289346802`}, {-100., 100., 100.}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{0., 8.78203222335737, 8.715574274765816}, {0., 0., 
      8.7488663525924}, {0., -8.78203222335737, 8.715574274765816}, {0., 
      8.7488663525924, 0.}, {0., 0., 0.}, {0., -8.7488663525924, 0.}, {0., 
      8.78203222335737, -8.715574274765816}, {0., 0., -8.7488663525924}, {
      0., -8.78203222335737, -8.715574274765816}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{7.813343592360431, -3.6809821751335754`, 
      14.440274636869479`}, {0., -22.54706357026234, 8.105032724901065}, {
      6.780720402192315, 16.69577726636623, 6.698389118639783}, {
      9.635150250318308, -4.3426881840035385`, -4.3426881840035385`}, {
      5.502074954027084, 18.538073600416006`, -10.136149772913956`}, {
      4.9166751057798175`, -2.0981607243843325`, -22.29624015590705}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{8.331999900541685, 9.261647442979966, 9.191560010597104}, {
      9.163960814219505, 0., 9.275513101976204}, {
      8.331999900541685, -9.261647442979966, 9.191560010597104}, {
      9.163960814219505, 9.275513101976204, 0.}, {10., 0., 0.}, {
      9.163960814219505, -9.275513101976204, 0.}, {8.331999900541685, 
      9.261647442979966, -9.191560010597104}, {9.163960814219505, 
      0., -9.275513101976204}, {
      8.331999900541685, -9.261647442979966, -9.191560010597104}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{8.881784197001252*^-16, 
      2.3833720876291604`, -3.6395235177015763`}, {0., 
      9.477751613485774, -11.545075882775754`}, {
      6.70664246589888, -11.772673091557785`, -13.864496644926119`}, {
      8.042347104999392, -3.7656619915248832`, -13.604493996029849`}, {
      0., -15.336891249797425`, -15.392295149082038`}, {
      0., -13.592094491192544`, -11.303040453333459`}, {
      0., -15.336891249797425`, -15.392295149082038`}, {
      5.059531839839441, -19.774014701176483`, -9.855169909429033}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.708, -2.587, 1.356}]], "Print",
 CellChangeTimes->{3.60130148579134*^9, 3.614709250709908*^9, 
  3.614729107858532*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"During evaluation of In[131]:="]
}, Open  ]],

Cell[TextData[{
 "Uneven illumination caused by off-axis positioning of the corner source.  \
The sources are positioned with ",
 StyleBox["Move", "MB"],
 " functions instead of ",
 StyleBox["BirthPoint", "MB"],
 "."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "The on-axis source spreads a nice grid of ray intercepts across the lens \
surface.  The pattern is symmetric with respect to the lens.  Yet the light \
from the corner source falls unevenly across the lens, and some of it misses \
altogether.  These stray light rays can be seen intercepting the outer ",
 StyleBox["Boundary", "MB"],
 " object, where they terminate."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "Now instead of ",
 StyleBox["Move", "MB"],
 " functions, you employ ",
 StyleBox["BirthPoint", "MB"],
 ".  When you position a source with ",
 StyleBox["BirthPoint", "MB"],
 ", ",
 StyleBox["Move", "MB"],
 "-related functions are unnecessary."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointOfRays", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"30", ",", "30"}], "}"}], ",", 
        RowBox[{"BirthPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", "100", ",", "100"}], "}"}]}], ",", 
        RowBox[{"RayLineRGB", "\[Rule]", "Red"}], ",", 
        RowBox[{"RayPointRGB", "\[Rule]", "Red"}], ",", 
        RowBox[{"RayPointSize", "\[Rule]", "4"}]}], "]"}], ",", 
      RowBox[{"PointOfRays", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"30", ",", "30"}], "}"}], ",", 
        RowBox[{"BirthPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", "0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"RayLineRGB", "\[Rule]", "Green"}], ",", 
        RowBox[{"RayPointRGB", "\[Rule]", "Green"}], ",", 
        RowBox[{"RayPointSize", "\[Rule]", "4"}]}], "]"}], ",", 
      RowBox[{"PlanoConvexLens", "[", 
       RowBox[{"100", ",", "50", ",", "10", ",", 
        RowBox[{"GraphicDesign", "\[Rule]", "Solid"}], ",", 
        RowBox[{"CurvatureDirection", "\[Rule]", "Back"}]}], "]"}], ",", 
      RowBox[{"Boundary", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", 
          RowBox[{"-", "30"}], ",", 
          RowBox[{"-", "30"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "100", ",", "100"}], "}"}]}], "]"}]}], "}"}], ",", 
    
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.708"}], ",", 
       RowBox[{"-", "2.587"}], ",", "1.356"}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[132]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0., 8.333333333333332, 0.}, {0., 
      8.049381885742235, 2.156825375854339}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 8.333333333333332, 0.}, {0., 16.666666666666664`, 
      0.}, {0., 16.09876377148447, 4.313650751708678}, {0., 8.049381885742235,
       2.156825375854339}, {0., 8.333333333333332, 0.}}], 
     Polygon3DBox[{{0., 16.666666666666664`, 0.}, {0., 25., 0.}, {0., 
      24.148145657226706`, 6.4704761275630185`}, {0., 16.09876377148447, 
      4.313650751708678}, {0., 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 8.049381885742235, 2.156825375854339}, {
      0., 7.216878364870323, 4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}],
      Polygon3DBox[{{0., 8.049381885742235, 2.156825375854339}, {0., 
      16.09876377148447, 4.313650751708678}, {0., 14.433756729740645`, 
      8.333333333333332}, {0., 7.216878364870323, 4.166666666666666}, {0., 
      8.049381885742235, 2.156825375854339}}], 
     Polygon3DBox[{{0., 16.09876377148447, 4.313650751708678}, {0., 
      24.148145657226706`, 6.4704761275630185`}, {0., 21.65063509461097, 
      12.499999999999998`}, {0., 14.433756729740645`, 8.333333333333332}, {0.,
       16.09876377148447, 4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 7.216878364870323, 4.166666666666666}, {
      0., 5.892556509887896, 5.8925565098878945`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 7.216878364870323, 4.166666666666666}, {0., 
      14.433756729740645`, 8.333333333333332}, {0., 11.785113019775793`, 
      11.785113019775789`}, {0., 5.892556509887896, 5.8925565098878945`}, {0.,
       7.216878364870323, 4.166666666666666}}], 
     Polygon3DBox[{{0., 14.433756729740645`, 8.333333333333332}, {0., 
      21.65063509461097, 12.499999999999998`}, {0., 17.67766952966369, 
      17.677669529663685`}, {0., 11.785113019775793`, 11.785113019775789`}, {
      0., 14.433756729740645`, 8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 5.892556509887896, 
      5.8925565098878945`}, {0., 4.166666666666668, 7.216878364870322}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.892556509887896, 5.8925565098878945`}, {0., 
      11.785113019775793`, 11.785113019775789`}, {0., 8.333333333333336, 
      14.433756729740644`}, {0., 4.166666666666668, 7.216878364870322}, {0., 
      5.892556509887896, 5.8925565098878945`}}], 
     Polygon3DBox[{{0., 11.785113019775793`, 11.785113019775789`}, {0., 
      17.67766952966369, 17.677669529663685`}, {0., 12.500000000000004`, 
      21.650635094610966`}, {0., 8.333333333333336, 14.433756729740644`}, {0.,
       11.785113019775793`, 11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 4.166666666666668, 7.216878364870322}, {
      0., 2.156825375854341, 8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}],
      Polygon3DBox[{{0., 4.166666666666668, 7.216878364870322}, {0., 
      8.333333333333336, 14.433756729740644`}, {0., 4.313650751708682, 
      16.09876377148447}, {0., 2.156825375854341, 8.049381885742235}, {0., 
      4.166666666666668, 7.216878364870322}}], 
     Polygon3DBox[{{0., 8.333333333333336, 14.433756729740644`}, {0., 
      12.500000000000004`, 21.650635094610966`}, {0., 6.470476127563024, 
      24.148145657226706`}, {0., 4.313650751708682, 16.09876377148447}, {0., 
      8.333333333333336, 14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 2.156825375854341, 8.049381885742235}, {
      0., 2.3606412073533245`*^-15, 8.333333333333332}, {0., 0., 0.}, {0., 0.,
       0.}}], Polygon3DBox[{{0., 2.156825375854341, 8.049381885742235}, {0., 
      4.313650751708682, 16.09876377148447}, {0., 4.721282414706649*^-15, 
      16.666666666666664`}, {0., 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 2.156825375854341, 8.049381885742235}}], 
     Polygon3DBox[{{0., 4.313650751708682, 16.09876377148447}, {0., 
      6.470476127563024, 24.148145657226706`}, {0., 7.0819236220599744`*^-15, 
      25.}, {0., 4.721282414706649*^-15, 16.666666666666664`}, {0., 
      4.313650751708682, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 5.102694996447305*^-16, 
      8.333333333333332}, {0., -2.1568253758543383`, 8.049381885742235}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.102694996447305*^-16, 8.333333333333332}, {0., 
      1.020538999289461*^-15, 16.666666666666664`}, {0., -4.313650751708677, 
      16.09876377148447}, {0., -2.1568253758543383`, 8.049381885742235}, {0., 
      5.102694996447305*^-16, 8.333333333333332}}], 
     Polygon3DBox[{{0., 1.020538999289461*^-15, 16.666666666666664`}, {0., 
      1.5308084989341915`*^-15, 25.}, {0., -6.470476127563016, 
      24.148145657226706`}, {0., -4.313650751708677, 16.09876377148447}, {0., 
      1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -2.1568253758543383`, 
      8.049381885742235}, {0., -4.166666666666664, 7.216878364870323}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -2.1568253758543383`, 8.049381885742235}, {
      0., -4.313650751708677, 16.09876377148447}, {0., -8.333333333333329, 
      14.433756729740645`}, {0., -4.166666666666664, 7.216878364870323}, {
      0., -2.1568253758543383`, 8.049381885742235}}], 
     Polygon3DBox[{{0., -4.313650751708677, 16.09876377148447}, {
      0., -6.470476127563016, 24.148145657226706`}, {0., -12.499999999999995`,
       21.65063509461097}, {0., -8.333333333333329, 14.433756729740645`}, {
      0., -4.313650751708677, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -4.166666666666664, 
      7.216878364870323}, {0., -5.8925565098878945`, 5.892556509887896}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -4.166666666666664, 7.216878364870323}, {
      0., -8.333333333333329, 14.433756729740645`}, {0., -11.785113019775789`,
       11.785113019775793`}, {0., -5.8925565098878945`, 5.892556509887896}, {
      0., -4.166666666666664, 7.216878364870323}}], 
     Polygon3DBox[{{0., -8.333333333333329, 14.433756729740645`}, {
      0., -12.499999999999995`, 21.65063509461097}, {0., -17.677669529663685`,
       17.67766952966369}, {0., -11.785113019775789`, 11.785113019775793`}, {
      0., -8.333333333333329, 14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -5.8925565098878945`, 
      5.892556509887896}, {0., -7.216878364870323, 4.166666666666666}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -5.8925565098878945`, 5.892556509887896}, {
      0., -11.785113019775789`, 11.785113019775793`}, {
      0., -14.433756729740645`, 8.333333333333332}, {0., -7.216878364870323, 
      4.166666666666666}, {0., -5.8925565098878945`, 5.892556509887896}}], 
     Polygon3DBox[{{0., -11.785113019775789`, 11.785113019775793`}, {
      0., -17.677669529663685`, 17.67766952966369}, {0., -21.65063509461097, 
      12.499999999999998`}, {0., -14.433756729740645`, 8.333333333333332}, {
      0., -11.785113019775789`, 11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -7.21687836487032, 4.16666666666667}, {
      0., -8.049381885742235, 2.156825375854342}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -7.21687836487032, 4.16666666666667}, {
      0., -14.43375672974064, 8.33333333333334}, {0., -16.09876377148447, 
      4.313650751708684}, {0., -8.049381885742235, 2.156825375854342}, {
      0., -7.21687836487032, 4.16666666666667}}], 
     Polygon3DBox[{{0., -14.43375672974064, 8.33333333333334}, {
      0., -21.650635094610962`, 12.500000000000009`}, {
      0., -24.148145657226706`, 6.470476127563026}, {0., -16.09876377148447, 
      4.313650751708684}, {0., -14.43375672974064, 8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -8.049381885742235, 
      2.156825375854342}, {0., -8.333333333333332, 1.020538999289461*^-15}, {
      0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -8.049381885742235, 2.156825375854342}, {
      0., -16.09876377148447, 4.313650751708684}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}, {0., -8.333333333333332, 
      1.020538999289461*^-15}, {0., -8.049381885742235, 2.156825375854342}}], 
     Polygon3DBox[{{0., -16.09876377148447, 4.313650751708684}, {
      0., -24.148145657226706`, 6.470476127563026}, {0., -25., 
      3.061616997868383*^-15}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}, {0., -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., -8.333333333333332, 
      1.020538999289461*^-15}, {0., -8.049381885742235, -2.15682537585434}, {
      0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -8.333333333333332, 1.020538999289461*^-15}, {
      0., -16.666666666666664`, 2.041077998578922*^-15}, {
      0., -16.09876377148447, -4.31365075170868}, {
      0., -8.049381885742235, -2.15682537585434}, {0., -8.333333333333332, 
      1.020538999289461*^-15}}], 
     Polygon3DBox[{{0., -16.666666666666664`, 2.041077998578922*^-15}, {
      0., -25., 3.061616997868383*^-15}, {
      0., -24.148145657226706`, -6.47047612756302}, {
      0., -16.09876377148447, -4.31365075170868}, {0., -16.666666666666664`, 
      2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -8.049381885742235, -2.156825375854336}, {
      0., -7.216878364870323, -4.166666666666664}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -8.049381885742235, -2.156825375854336}, {
      0., -16.09876377148447, -4.313650751708672}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -7.216878364870323, -4.166666666666664}, {
      0., -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{0., -16.09876377148447, -4.313650751708672}, {
      0., -24.14814565722671, -6.470476127563009}, {
      0., -21.65063509461097, -12.499999999999993`}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -7.216878364870323, -4.166666666666664}, {
      0., -5.892556509887897, -5.8925565098878945`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -7.216878364870323, -4.166666666666664}, {
      0., -14.433756729740645`, -8.333333333333329}, {
      0., -11.785113019775794`, -11.785113019775789`}, {
      0., -5.892556509887897, -5.8925565098878945`}, {
      0., -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{0., -14.433756729740645`, -8.333333333333329}, {
      0., -21.65063509461097, -12.499999999999993`}, {
      0., -17.677669529663692`, -17.677669529663685`}, {
      0., -11.785113019775794`, -11.785113019775789`}, {
      0., -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -5.892556509887898, -5.892556509887893}, {
      0., -4.16666666666667, -7.216878364870319}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -5.892556509887898, -5.892556509887893}, {
      0., -11.785113019775796`, -11.785113019775785`}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -4.16666666666667, -7.216878364870319}, {
      0., -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{0., -11.785113019775796`, -11.785113019775785`}, {
      0., -17.677669529663696`, -17.677669529663678`}, {
      0., -12.50000000000001, -21.65063509461096}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -4.16666666666667, -7.216878364870319}, {
      0., -2.156825375854346, -8.049381885742234}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., -4.16666666666667, -7.216878364870319}, {
      0., -8.33333333333334, -14.433756729740638`}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -2.156825375854346, -8.049381885742234}, {
      0., -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{0., -8.33333333333334, -14.433756729740638`}, {
      0., -12.50000000000001, -21.65063509461096}, {
      0., -6.470476127563038, -24.148145657226703`}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -2.156825375854346, -8.049381885742234}, {
      0., -8.932295329768568*^-15, -8.333333333333332}, {0., 0., 0.}, {0., 0.,
       0.}}], Polygon3DBox[{{0., -2.156825375854346, -8.049381885742234}, {
      0., -4.313650751708692, -16.098763771484467`}, {
      0., -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0., -8.932295329768568*^-15, -8.333333333333332}, {
      0., -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{0., -4.313650751708692, -16.098763771484467`}, {
      0., -6.470476127563038, -24.148145657226703`}, {
      0., -2.6796885989305705`*^-14, -25.}, {
      0., -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0., -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0., -1.5308084989341913`*^-15, -8.333333333333332}, {0., 
      2.1568253758543356`, -8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., -1.5308084989341913`*^-15, -8.333333333333332}, {
      0., -3.0616169978683826`*^-15, -16.666666666666664`}, {0., 
      4.313650751708671, -16.09876377148447}, {0., 
      2.1568253758543356`, -8.049381885742235}, {
      0., -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{0., -3.0616169978683826`*^-15, -16.666666666666664`}, {
      0., -4.592425496802574*^-15, -25.}, {0., 
      6.470476127563007, -24.14814565722671}, {0., 
      4.313650751708671, -16.09876377148447}, {
      0., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      2.1568253758543356`, -8.049381885742235}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 2.1568253758543356`, -8.049381885742235}, {0., 
      4.313650751708671, -16.09876377148447}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{0., 4.313650751708671, -16.09876377148447}, {0., 
      6.470476127563007, -24.14814565722671}, {0., 
      12.499999999999984`, -21.650635094610976`}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      4.166666666666661, -7.216878364870325}, {0., 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 4.166666666666661, -7.216878364870325}, {0., 
      8.333333333333321, -14.43375672974065}, {0., 
      11.78511301977578, -11.785113019775807`}, {0., 
      5.89255650988789, -5.892556509887903}, {0., 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{0., 8.333333333333321, -14.43375672974065}, {0., 
      12.499999999999984`, -21.650635094610976`}, {0., 
      17.67766952966367, -17.67766952966371}, {0., 
      11.78511301977578, -11.785113019775807`}, {0., 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      5.8925565098878945`, -5.892556509887897}, {0., 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 5.8925565098878945`, -5.892556509887897}, {0., 
      11.785113019775789`, -11.785113019775794`}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      7.216878364870319, -4.16666666666667}, {0., 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{0., 11.785113019775789`, -11.785113019775794`}, {0., 
      17.677669529663685`, -17.677669529663692`}, {0., 
      21.65063509461096, -12.50000000000001}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 7.216878364870319, -4.16666666666667}, {
      0., 8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 7.216878364870319, -4.16666666666667}, {0., 
      14.433756729740638`, -8.33333333333334}, {0., 
      16.098763771484467`, -4.313650751708693}, {0., 
      8.049381885742234, -2.1568253758543463`}, {0., 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{0., 14.433756729740638`, -8.33333333333334}, {0., 
      21.65063509461096, -12.50000000000001}, {0., 
      24.148145657226703`, -6.470476127563039}, {0., 
      16.098763771484467`, -4.313650751708693}, {0., 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0., 
      8.049381885742234, -2.1568253758543463`}, {0., 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0., 8.049381885742234, -2.1568253758543463`}, {0.,
       16.098763771484467`, -4.313650751708693}, {0., 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0., 
      8.333333333333332, -9.442564829413298*^-15}, {0., 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{0., 16.098763771484467`, -4.313650751708693}, {0., 
      24.148145657226703`, -6.470476127563039}, {0., 
      25., -2.8327694488239898`*^-14}, {0., 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0., 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBnRg6YAu4nF1w/03qhYOjrtK6448lITLP/vdwjph
manDfzDQgIvvSBM+UL3W0GE7lIaJM4FJTYenUH0wcXeouTB7YOKnz59fP3vy
bRt0d9lB1B9AV/8X4o4Dz9DMh7rjwA409zyBqDvACnUXmn8PeKL5F+qOAxB3
vbaBiXhC1ZtB3YUWPgf+QN0FE98Fdc9WKA0TZ4O448BjqD6YeDjUXHeoPTDx
G7dvH96y7ssemLtg4iZQd3uiqf8OjacXaObD4mknmnug7nCAuQsmDnWHQwSa
f6HucICEz+89ABYlv5c=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 8.333333333333332, 
        0.}, {9.32624200410794, 8.049381885742235, 2.156825375854339}, {10., 
        0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 8.333333333333332, 0.}, {
        7.249551165715211, 16.666666666666664`, 0.}, {7.249551165715211, 
        16.09876377148447, 4.313650751708678}, {9.32624200410794, 
        8.049381885742235, 2.156825375854339}, {9.32624200410794, 
        8.333333333333332, 0.}}], 
       Polygon3DBox[{{7.249551165715211, 16.666666666666664`, 0.}, {
        3.5780254190444083`, 25., 0.}, {3.5780254190444083`, 
        24.148145657226706`, 6.4704761275630185`}, {7.249551165715211, 
        16.09876377148447, 4.313650751708678}, {7.249551165715211, 
        16.666666666666664`, 0.}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 8.049381885742235, 
        2.156825375854339}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 8.049381885742235, 
        2.156825375854339}, {7.249551165715211, 16.09876377148447, 
        4.313650751708678}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {9.32624200410794, 8.049381885742235, 
        2.156825375854339}}], 
       Polygon3DBox[{{7.249551165715211, 16.09876377148447, 
        4.313650751708678}, {3.5780254190444083`, 24.148145657226706`, 
        6.4704761275630185`}, {3.5780254190444083`, 21.65063509461097, 
        12.499999999999998`}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {7.249551165715211, 16.09876377148447, 
        4.313650751708678}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, 7.216878364870323, 
        4.166666666666666}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {9.326242004107932, 7.216878364870323, 
        4.166666666666666}}], 
       Polygon3DBox[{{7.249551165715211, 14.433756729740645`, 
        8.333333333333332}, {3.5780254190444083`, 21.65063509461097, 
        12.499999999999998`}, {3.5780254190444083`, 17.67766952966369, 
        17.677669529663685`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {7.249551165715211, 14.433756729740645`, 
        8.333333333333332}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {9.32624200410794, 5.892556509887896, 
        5.8925565098878945`}}], 
       Polygon3DBox[{{7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}, {3.5780254190444083`, 17.67766952966369, 
        17.677669529663685`}, {3.5780254190444083`, 12.500000000000004`, 
        21.650635094610966`}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {7.249551165715218, 11.785113019775793`, 
        11.785113019775789`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, 4.166666666666668, 
        7.216878364870322}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {9.326242004107932, 4.166666666666668, 
        7.216878364870322}}], 
       Polygon3DBox[{{7.249551165715211, 8.333333333333336, 
        14.433756729740644`}, {3.5780254190444083`, 12.500000000000004`, 
        21.650635094610966`}, {3.5780254190444083`, 6.470476127563024, 
        24.148145657226706`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {7.249551165715211, 8.333333333333336, 
        14.433756729740644`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {9.32624200410794, 2.3606412073533245`*^-15, 
        8.333333333333332}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 2.156825375854341, 
        8.049381885742235}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {7.249551165715211, 4.721282414706649*^-15, 
        16.666666666666664`}, {9.32624200410794, 2.3606412073533245`*^-15, 
        8.333333333333332}, {9.32624200410794, 2.156825375854341, 
        8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, 4.313650751708682, 
        16.09876377148447}, {3.5780254190444083`, 6.470476127563024, 
        24.148145657226706`}, {3.5780254190444083`, 7.0819236220599744`*^-15, 
        25.}, {7.249551165715211, 4.721282414706649*^-15, 
        16.666666666666664`}, {7.249551165715211, 4.313650751708682, 
        16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 5.102694996447305*^-16,
         8.333333333333332}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, 5.102694996447305*^-16, 
        8.333333333333332}, {7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {9.32624200410794, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}, {3.5780254190444083`, 1.5308084989341915`*^-15, 
        25.}, {3.5780254190444083`, -6.470476127563016, 
        24.148145657226706`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {7.249551165715211, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {9.32624200410794, -2.1568253758543383`, 
        8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, -4.313650751708677, 
        16.09876377148447}, {3.5780254190444083`, -6.470476127563016, 
        24.148145657226706`}, {3.5780254190444083`, -12.499999999999995`, 
        21.65063509461097}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {7.249551165715211, -4.313650751708677, 
        16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, -4.166666666666664, 
        7.216878364870323}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {9.326242004107932, -4.166666666666664, 
        7.216878364870323}}], 
       Polygon3DBox[{{7.249551165715211, -8.333333333333329, 
        14.433756729740645`}, {3.5780254190444083`, -12.499999999999995`, 
        21.65063509461097}, {3.5780254190444083`, -17.677669529663685`, 
        17.67766952966369}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {7.249551165715211, -8.333333333333329, 
        14.433756729740645`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {9.326242004107932, -7.216878364870323, 
        4.166666666666666}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {7.249551165715211, -14.433756729740645`, 
        8.333333333333332}, {9.326242004107932, -7.216878364870323, 
        4.166666666666666}, {9.32624200410794, -5.8925565098878945`, 
        5.892556509887896}}], 
       Polygon3DBox[{{7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}, {3.5780254190444083`, -17.677669529663685`, 
        17.67766952966369}, {3.5780254190444083`, -21.65063509461097, 
        12.499999999999998`}, {7.249551165715211, -14.433756729740645`, 
        8.333333333333332}, {7.249551165715218, -11.785113019775789`, 
        11.785113019775793`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, -7.21687836487032, 
        4.16666666666667}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.326242004107932, -7.21687836487032, 
        4.16666666666667}, {7.249551165715218, -14.43375672974064, 
        8.33333333333334}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {9.326242004107932, -7.21687836487032, 
        4.16666666666667}}], 
       Polygon3DBox[{{7.249551165715218, -14.43375672974064, 
        8.33333333333334}, {3.578025419044401, -21.650635094610962`, 
        12.500000000000009`}, {3.5780254190444083`, -24.148145657226706`, 
        6.470476127563026}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {7.249551165715218, -14.43375672974064, 
        8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {10., 0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -8.049381885742235, 
        2.156825375854342}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {9.32624200410794, -8.049381885742235, 
        2.156825375854342}}], 
       Polygon3DBox[{{7.249551165715211, -16.09876377148447, 
        4.313650751708684}, {3.5780254190444083`, -24.148145657226706`, 
        6.470476127563026}, {3.5780254190444083`, -25., 
        3.061616997868383*^-15}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {7.249551165715211, -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {
        9.32624200410794, -8.049381885742235, -2.15682537585434}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{9.32624200410794, -8.333333333333332, 
        1.020538999289461*^-15}, {7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {
        7.249551165715211, -16.09876377148447, -4.31365075170868}, {
        9.32624200410794, -8.049381885742235, -2.15682537585434}, {
        9.32624200410794, -8.333333333333332, 1.020538999289461*^-15}}], 
       Polygon3DBox[{{7.249551165715211, -16.666666666666664`, 
        2.041077998578922*^-15}, {3.5780254190444083`, -25., 
        3.061616997868383*^-15}, {
        3.5780254190444083`, -24.148145657226706`, -6.47047612756302}, {
        7.249551165715211, -16.09876377148447, -4.31365075170868}, {
        7.249551165715211, -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -8.049381885742235, -2.156825375854336}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -8.049381885742235, -2.156825375854336}, {
        7.249551165715211, -16.09876377148447, -4.313650751708672}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        9.32624200410794, -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{
        7.249551165715211, -16.09876377148447, -4.313650751708672}, {
        3.5780254190444083`, -24.14814565722671, -6.470476127563009}, {
        3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        7.249551165715211, -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        9.32624200410794, -5.892556509887897, -5.8925565098878945`}, {10., 0.,
         0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.326242004107932, -7.216878364870323, -4.166666666666664}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        7.249551165715211, -11.785113019775794`, -11.785113019775789`}, {
        9.32624200410794, -5.892556509887897, -5.8925565098878945`}, {
        9.326242004107932, -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{
        7.249551165715211, -14.433756729740645`, -8.333333333333329}, {
        3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
        3.5780254190444083`, -17.677669529663692`, -17.677669529663685`}, {
        7.249551165715211, -11.785113019775794`, -11.785113019775789`}, {
        7.249551165715211, -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -5.892556509887898, -5.892556509887893}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -5.892556509887898, -5.892556509887893}, {
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        9.32624200410794, -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}, {
        3.5780254190444083`, -17.677669529663696`, -17.677669529663678`}, {
        3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        7.249551165715211, -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.326242004107932, -4.16666666666667, -7.216878364870319}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        9.326242004107932, -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{
        7.249551165715218, -8.33333333333334, -14.433756729740638`}, {
        3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
        3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        7.249551165715218, -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        9.32624200410794, -8.932295329768568*^-15, -8.333333333333332}, {10., 
        0., 0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -2.156825375854346, -8.049381885742234}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        7.249551165715211, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        9.32624200410794, -8.932295329768568*^-15, -8.333333333333332}, {
        9.32624200410794, -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{
        7.249551165715211, -4.313650751708692, -16.098763771484467`}, {
        3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
        3.5780254190444083`, -2.6796885989305705`*^-14, -25.}, {
        7.249551165715211, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        7.249551165715211, -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{10., 0., 0.}, {
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}, {
        9.32624200410794, 2.1568253758543356`, -8.049381885742235}, {10., 0., 
        0.}, {10., 0., 0.}}], 
       Polygon3DBox[{{
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}, {
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        7.249551165715211, 4.313650751708671, -16.09876377148447}, {
        9.32624200410794, 2.1568253758543356`, -8.049381885742235}, {
        9.32624200410794, -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        3.5780254190444083`, -4.592425496802574*^-15, -25.}, {
        3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {
        7.249551165715211, 4.313650751708671, -16.09876377148447}, {
        7.249551165715211, -3.0616169978683826`*^-15, -16.666666666666664`}}],
        Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}, {7.249551165715211, 
        4.313650751708671, -16.09876377148447}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {9.32624200410794, 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{7.249551165715211, 
        4.313650751708671, -16.09876377148447}, {3.5780254190444083`, 
        6.470476127563007, -24.14814565722671}, {3.5780254190444083`, 
        12.499999999999984`, -21.650635094610976`}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {7.249551165715211, 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {9.32624200410794, 
        5.89255650988789, -5.892556509887903}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{9.32624200410794, 
        4.166666666666661, -7.216878364870325}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {7.249551165715211, 
        11.78511301977578, -11.785113019775807`}, {9.32624200410794, 
        5.89255650988789, -5.892556509887903}, {9.32624200410794, 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{7.249551165715211, 
        8.333333333333321, -14.43375672974065}, {3.5780254190444083`, 
        12.499999999999984`, -21.650635094610976`}, {3.578025419044401, 
        17.67766952966367, -17.67766952966371}, {7.249551165715211, 
        11.78511301977578, -11.785113019775807`}, {7.249551165715211, 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {10., 0., 0.}, {10., 0., 0.}}],
        Polygon3DBox[{{9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}, {7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {9.32624200410794, 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}, {3.5780254190444083`, 
        17.677669529663685`, -17.677669529663692`}, {3.5780254190444083`, 
        21.65063509461096, -12.50000000000001}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {7.249551165715211, 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.326242004107932, 
        7.216878364870319, -4.16666666666667}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {9.326242004107932, 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{7.249551165715218, 
        14.433756729740638`, -8.33333333333334}, {3.5780254190444083`, 
        21.65063509461096, -12.50000000000001}, {3.5780254190444083`, 
        24.148145657226703`, -6.470476127563039}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {7.249551165715218, 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{10., 0., 0.}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {9.32624200410794, 
        8.333333333333332, -9.442564829413298*^-15}, {10., 0., 0.}, {10., 0., 
        0.}}], Polygon3DBox[{{9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {7.249551165715211, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {9.32624200410794, 
        8.333333333333332, -9.442564829413298*^-15}, {9.32624200410794, 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{7.249551165715211, 
        16.098763771484467`, -4.313650751708693}, {3.5780254190444083`, 
        24.148145657226703`, -6.470476127563039}, {3.5780254190444083`, 
        25., -2.8327694488239898`*^-14}, {7.249551165715211, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {7.249551165715211, 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIE7Irjh1ej6PAwMYWEJphLjH1Q3336haODjuKq07
8lDSASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBDZV0+EpVB9M3B1q
LswemPjp8+fXz5582wbmLpi4HUT9AXT1fyHuOPAMzXyoOw7A3BUAFX8CUXeA
FeouNP8e8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZx
x4HHUH0w8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNO
NPdA3QF3Fzy+oOEegeZfWDxBwuf3HgB25B2h
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{0., 25., 0.}, {3.5780254190444083`, 25., 0.}, {
          3.5780254190444083`, 24.148145657226706`, 6.4704761275630185`}, {0.,
           24.148145657226706`, 6.4704761275630185`}, {0., 25., 0.}}], 
         Polygon3DBox[{{0., 24.148145657226706`, 6.4704761275630185`}, {
          3.5780254190444083`, 24.148145657226706`, 6.4704761275630185`}, {
          3.5780254190444083`, 21.65063509461097, 12.499999999999998`}, {0., 
          21.65063509461097, 12.499999999999998`}, {0., 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{0., 21.65063509461097, 12.499999999999998`}, {
          3.5780254190444083`, 21.65063509461097, 12.499999999999998`}, {
          3.5780254190444083`, 17.67766952966369, 17.677669529663685`}, {0., 
          17.67766952966369, 17.677669529663685`}, {0., 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{0., 17.67766952966369, 17.677669529663685`}, {
          3.5780254190444083`, 17.67766952966369, 17.677669529663685`}, {
          3.5780254190444083`, 12.500000000000004`, 21.650635094610966`}, {0.,
           12.500000000000004`, 21.650635094610966`}, {0., 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{0., 12.500000000000004`, 21.650635094610966`}, {
          3.5780254190444083`, 12.500000000000004`, 21.650635094610966`}, {
          3.5780254190444083`, 6.470476127563024, 24.148145657226706`}, {0., 
          6.470476127563024, 24.148145657226706`}, {0., 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{0., 6.470476127563024, 24.148145657226706`}, {
          3.5780254190444083`, 6.470476127563024, 24.148145657226706`}, {
          3.5780254190444083`, 7.0819236220599744`*^-15, 25.}, {0., 
          7.0819236220599744`*^-15, 25.}, {0., 6.470476127563024, 
          24.148145657226706`}}], 
         Polygon3DBox[{{0., 1.5308084989341915`*^-15, 25.}, {
          3.5780254190444083`, 1.5308084989341915`*^-15, 25.}, {
          3.5780254190444083`, -6.470476127563016, 24.148145657226706`}, {
          0., -6.470476127563016, 24.148145657226706`}, {0., 
          1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{0., -6.470476127563016, 24.148145657226706`}, {
          3.5780254190444083`, -6.470476127563016, 24.148145657226706`}, {
          3.5780254190444083`, -12.499999999999995`, 21.65063509461097}, {
          0., -12.499999999999995`, 21.65063509461097}, {
          0., -6.470476127563016, 24.148145657226706`}}], 
         Polygon3DBox[{{0., -12.499999999999995`, 21.65063509461097}, {
          3.5780254190444083`, -12.499999999999995`, 21.65063509461097}, {
          3.5780254190444083`, -17.677669529663685`, 17.67766952966369}, {
          0., -17.677669529663685`, 17.67766952966369}, {
          0., -12.499999999999995`, 21.65063509461097}}], 
         Polygon3DBox[{{0., -17.677669529663685`, 17.67766952966369}, {
          3.5780254190444083`, -17.677669529663685`, 17.67766952966369}, {
          3.5780254190444083`, -21.65063509461097, 12.499999999999998`}, {
          0., -21.65063509461097, 12.499999999999998`}, {
          0., -17.677669529663685`, 17.67766952966369}}], 
         Polygon3DBox[{{0., -21.650635094610962`, 12.500000000000009`}, {
          3.578025419044401, -21.650635094610962`, 12.500000000000009`}, {
          3.5780254190444083`, -24.148145657226706`, 6.470476127563026}, {
          0., -24.148145657226706`, 6.470476127563026}, {
          0., -21.650635094610962`, 12.500000000000009`}}], 
         Polygon3DBox[{{0., -24.148145657226706`, 6.470476127563026}, {
          3.5780254190444083`, -24.148145657226706`, 6.470476127563026}, {
          3.5780254190444083`, -25., 3.061616997868383*^-15}, {0., -25., 
          3.061616997868383*^-15}, {0., -24.148145657226706`, 
          6.470476127563026}}], 
         Polygon3DBox[{{0., -25., 3.061616997868383*^-15}, {
          3.5780254190444083`, -25., 3.061616997868383*^-15}, {
          3.5780254190444083`, -24.148145657226706`, -6.47047612756302}, {
          0., -24.148145657226706`, -6.47047612756302}, {0., -25., 
          3.061616997868383*^-15}}], 
         Polygon3DBox[{{0., -24.14814565722671, -6.470476127563009}, {
          3.5780254190444083`, -24.14814565722671, -6.470476127563009}, {
          3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
          0., -21.65063509461097, -12.499999999999993`}, {
          0., -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{0., -21.65063509461097, -12.499999999999993`}, {
          3.5780254190444083`, -21.65063509461097, -12.499999999999993`}, {
          3.5780254190444083`, -17.677669529663692`, -17.677669529663685`}, {
          0., -17.677669529663692`, -17.677669529663685`}, {
          0., -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{0., -17.677669529663696`, -17.677669529663678`}, {
          3.5780254190444083`, -17.677669529663696`, -17.677669529663678`}, {
          3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
          0., -12.50000000000001, -21.65063509461096}, {
          0., -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{0., -12.50000000000001, -21.65063509461096}, {
          3.5780254190444083`, -12.50000000000001, -21.65063509461096}, {
          3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
          0., -6.470476127563038, -24.148145657226703`}, {
          0., -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{0., -6.470476127563038, -24.148145657226703`}, {
          3.5780254190444083`, -6.470476127563038, -24.148145657226703`}, {
          3.5780254190444083`, -2.6796885989305705`*^-14, -25.}, {
          0., -2.6796885989305705`*^-14, -25.}, {
          0., -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{0., -4.592425496802574*^-15, -25.}, {
          3.5780254190444083`, -4.592425496802574*^-15, -25.}, {
          3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {0., 
          6.470476127563007, -24.14814565722671}, {
          0., -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{0., 6.470476127563007, -24.14814565722671}, {
          3.5780254190444083`, 6.470476127563007, -24.14814565722671}, {
          3.5780254190444083`, 12.499999999999984`, -21.650635094610976`}, {
          0., 12.499999999999984`, -21.650635094610976`}, {0., 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{0., 12.499999999999984`, -21.650635094610976`}, {
          3.5780254190444083`, 12.499999999999984`, -21.650635094610976`}, {
          3.578025419044401, 17.67766952966367, -17.67766952966371}, {0., 
          17.67766952966367, -17.67766952966371}, {0., 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{0., 17.677669529663685`, -17.677669529663692`}, {
          3.5780254190444083`, 17.677669529663685`, -17.677669529663692`}, {
          3.5780254190444083`, 21.65063509461096, -12.50000000000001}, {0., 
          21.65063509461096, -12.50000000000001}, {0., 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{0., 21.65063509461096, -12.50000000000001}, {
          3.5780254190444083`, 21.65063509461096, -12.50000000000001}, {
          3.5780254190444083`, 24.148145657226703`, -6.470476127563039}, {0., 
          24.148145657226703`, -6.470476127563039}, {0., 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{0., 24.148145657226703`, -6.470476127563039}, {
          3.5780254190444083`, 24.148145657226703`, -6.470476127563039}, {
          3.5780254190444083`, 25., -2.8327694488239898`*^-14}, {0., 
          25., -2.8327694488239898`*^-14}, {0., 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 100., -30.}, {0., -30., -30.}, {0., -30., 100.}, {0., 
       100., 100.}, {0., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., -30., -30.}, {-100., -30., -30.}, {-100., -30., 100.}, {
       0., -30., 100.}, {0., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -30., -30.}, {-100., 100., -30.}, {-100., 100., 
       100.}, {-100., -30., 100.}, {-100., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -30.}, {0., 100., -30.}, {0., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., -30., -30.}, {0., 100., -30.}, {-100., 
       100., -30.}, {-100., -30., -30.}, {0., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 100., 100.}, {0., -30., 100.}, {-100., -30., 
       100.}, {-100., 100., 100.}, {0., 100., 100.}}]}}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAJR2QKVhQO8AKk1IPQPDj/8goEukej0H
Ys1HNZdY96MDYt1DtPoDqPqIdQ9h9VD/OsBoAAm/Nk4=
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAANeoHcAlcalXsAWxmIkSj3cfAdizUc1
FwYImY8OCJrvQJr58PBxIGQ+jIVqD9Hh4wAAdVoU/A==
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxUYHeARi97tqZH9dLBByS+r19034YHIDR6Dp+
/AcB3QOZ9s1N5dFSDkpyb+pKzrIdCFRZGqHkboSmXs8BZn5n//VLya0iDh/W
fUpbIa7l8PVK9K7NSwwPoJsL48PMh5kLswfDC1CwKPhRppGrskOI6J5lL+ME
D8Bo7O5hYAhq1T16i1fRIevt2zfKZuoOf++pH9b8xI+uHhY+DjD3w9wN8wd2
1+g5wMyHmQuzB82/DjA6SsJ27ow6GYfJt7+0bBXTgNMAaiGIng==
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxUYHeARh9Y/m8q4n9Ig6Juqd65jLoH4DREHkB
W5gORqh6v5rnBQbmcg4w8R/Trk+sq4aph5vvgMN8B3TzYebCdMLMx24uLqDi
gF0cbj5cHs18HPrg4eOAI3wcYObDdMDswRE+aPbAwwfdfDgNAP/VU+c=
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], 
     Line3DBox[{{{7.123629052022887, 12.0443536328219, 12.0443536328219}, {
      0., -0.903971572677527, -0.903971572677527}}, {{
      0., -0.903971572677527, -0.903971572677527}, {
      6.643560374721445, -12.979695845523413`, -12.979695845523413`}}, {{
      6.643560374721445, -12.979695845523413`, -12.979695845523413`}, {
      0., -15.40376867223476, -15.40376867223476}}, {{
      0., -15.40376867223476, -15.40376867223476}, {
      0., -15.403768672234762`, -15.403768672234762`}}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{0., -15., -15.}, {0., 0., -14.999999999999986`}, {0., 
      15., -15.}, {0., -14.999999999999986`, 0.}, {0., 0., 0.}, {0., 15., 
      0.}, {0., -15., 15.}, {0., 0., 15.}, {0., 14.999999999999986`, 
      14.999999999999986`}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{0., -15., -15.}, {1.4210854715202004`*^-14, 
      0., -15.000000000000002`}, {0., 15., -15.}, {
      1.4210854715202004`*^-14, -15.000000000000002`, 0.}, {0., 0., 0.}, {
      1.4210854715202004`*^-14, 15.000000000000002`, 0.}, {0., -15., 15.}, {
      1.4210854715202004`*^-14, 0., 15.000000000000002`}, {0., 15., 15.}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      4.114105117323261, -16.970311003634727`, -16.970311003634727`}, {
      6.589323081265186, -2.850319854336491, -18.27786783248695}, {
      5.130263609320431, 13.046206681370194`, -17.643367431087388`}, {
      6.589323081265186, -18.27786783248695, -2.850319854336491}, {
      9.635150250318308, -4.3426881840035385`, -4.3426881840035385`}, {
      8.52705970936464, 11.605742839855072`, -3.993243717817562}, {
      5.130263609320431, -17.643367431087388`, 13.046206681370194`}, {
      8.52705970936464, -3.993243717817562, 11.605742839855072`}, {
      7.123629052022887, 12.0443536328219, 12.0443536328219}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      5.140021646317074, -15.501202010803071`, -15.501202010803071`}, {
      7.553895725373037, 0., -15.74120002514563}, {5.140021646317074, 
      15.501202010803071`, -15.501202010803071`}, {
      7.553895725373037, -15.74120002514563, 0.}, {10., 0., 0.}, {
      7.553895725373037, 15.74120002514563, 0.}, {
      5.140021646317074, -15.501202010803071`, 15.501202010803071`}, {
      7.553895725373037, 0., 15.74120002514563}, {5.140021646317074, 
      15.501202010803071`, 15.501202010803071`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{0., -0.903971572677527, -0.903971572677527}, {
      6.643560374721445, -12.979695845523413`, -12.979695845523413`}, {
      0., -15.40376867223476, -15.40376867223476}, {
      0., -15.403768672234762`, -15.403768672234762`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.708, -2.587, 1.356}]], "Print",
 CellChangeTimes->{3.601301486377769*^9, 3.614709251388399*^9, 
  3.61472910845259*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"During evaluation of In[132]:="]
}, Open  ]],

Cell[TextData[{
 "When you position a light source with ",
 StyleBox["BirthPoint", "MB"],
 ", the distribution of light on planar entrance pupils is the same no matter \
where you put the source."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "The light sources in each case have identical positions.  However, with ",
 StyleBox["BirthPoint", "MB"],
 ", the corner source now distributes its light evenly across the lens.  You \
can see that the intercept points are the same as those for the on-axis \
source."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "The caveat with ",
 StyleBox["BirthPoint", "MB"],
 " is that it works well only for planar entrance pupils.  In both of the \
examples above, ",
 StyleBox["CurvatureDirection\[Rule] Back", "MB"],
 " was used flip the ",
 StyleBox["PlanoConvexLens", "MB"],
 " around.  The lens then presented its planar side to the light sources.  So \
you had a planar entrance pupil."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constant Illumination with ReadRays", "Subsubsection",
 CellTags->{
  "Constant Illumination with ReadRays", "Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 StyleBox["BirthPoint", "MB"],
 " is designed for planar entrance pupils.  Curved pupils require a different \
approach.  Problems crop up when ",
 StyleBox["BirthPoint", "MB"],
 " sources illuminate a curved surface, as the next example demonstrates.  \
This topic is somewhat advanced, and may be skipped without penalty."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 StyleBox["BiConvexLens", "MB"],
 " has equally curved surfaces on both sides.  Position two sources using ",
 StyleBox["BirthPoint", "MB"],
 ": ",
 StyleBox["referenceSource", "MB"],
 " on the optic axis, and ",
 StyleBox["offAxisSource", "MB"],
 " at an off-axis point."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"offAxisSource", "=", 
   RowBox[{"PointOfRays", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30", ",", "30"}], "}"}], ",", 
     RowBox[{"BirthPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100"}], ",", "100", ",", "100"}], "}"}]}], ",", 
     RowBox[{"RayLineRGB", "\[Rule]", "Red"}], ",", 
     RowBox[{"RayPointRGB", "\[Rule]", "Red"}], ",", 
     RowBox[{"RayPointSize", "\[Rule]", "4"}], ",", 
     RowBox[{"SourceID", "\[Rule]", "1"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"referenceSource", "=", 
   RowBox[{"PointOfRays", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"30", ",", "30"}], "}"}], ",", 
     RowBox[{"BirthPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100"}], ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"RayLineRGB", "\[Rule]", "Green"}], ",", 
     RowBox[{"RayPointRGB", "\[Rule]", "Green"}], ",", 
     RowBox[{"RayPointSize", "\[Rule]", "4"}], ",", 
     RowBox[{"SourceID", "\[Rule]", "2"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"offAxisSource", ",", "referenceSource", ",", 
       RowBox[{"BiConvexLens", "[", 
        RowBox[{"50", ",", "50", ",", "20", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", 
           RowBox[{"-", "30"}], ",", 
           RowBox[{"-", "30"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "100", ",", "100"}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.708"}], ",", 
        RowBox[{"-", "2.587"}], ",", "1.356"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[133]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.333333333333332, 0.}, {
      0.725904213297639, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.333333333333332, 0.}, {
      2.9734754115314814`, 16.666666666666664`, 0.}, {2.9734754115314814`, 
      16.09876377148447, 4.313650751708678}, {0.725904213297639, 
      8.049381885742235, 2.156825375854339}, {0.725904213297639, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.666666666666664`, 0.}, {
      6.990968363763578, 25., 0.}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {6.990968363763578, 7.0819236220599744`*^-15, 
      25.}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {6.990968363763578, 1.5308084989341915`*^-15, 
      25.}, {6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
      2.9734754115314814`, -4.313650751708677, 16.09876377148447}, {
      2.9734754115314814`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {6.990968363763578, -6.470476127563016, 
      24.148145657226706`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {6.990968363763578, -21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {6.990968363763578, -21.650635094610962`, 
      12.500000000000009`}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {6.990968363763578, -25., 3.061616997868383*^-15}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {
      0.725904213297639, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {6.990968363763578, -25., 
      3.061616997868383*^-15}, {
      6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      6.990968363763578, -24.14814565722671, -6.470476127563009}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      2.9734754115314814`, 4.313650751708671, -16.09876377148447}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      6.990968363763578, -4.592425496802574*^-15, -25.}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
      17.67766952966367, -17.67766952966371}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {6.990968363763578, 
      17.677669529663685`, -17.677669529663692`}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
      25., -2.8327694488239898`*^-14}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIL7xQS3zwDdpBwYwsITSDAwXoOIeVzfcf6Nq4eC4
q7TuyENJB5j6Z79bWCcsM3X4DwYacPEdacIHqtcaOmyH0jBxJrCpmg5Pofpg
4u5Qc2H2wMRPnz+/fvbk2zYwd8HE7SDqD6Cr/wtxx4FnaOZD3XFgB5p7nkDU
HWCFuusGqn8PeKL5F+qOAxB3vbaBiXtC1ZtB3XUBNXwO/IG6C6Z+F9Q9W6E0
TJwN4o4Dj6H6YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZ
D4unnVD3wNwPdQfcXfD4goZ7BNRd6OkHEj6/9wAABeEttg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.333333333333332, 
        0.}, {19.27409578670236, 8.049381885742235, 2.156825375854339}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.333333333333332, 0.}, {
        17.02652458846852, 16.666666666666664`, 0.}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {19.27409578670236, 
        8.049381885742235, 2.156825375854339}, {19.27409578670236, 
        8.333333333333332, 0.}}], 
       Polygon3DBox[{{17.02652458846852, 16.666666666666664`, 0.}, {
        13.009031636236422`, 25., 0.}, {13.009031636236429`, 
        24.148145657226706`, 6.4704761275630185`}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {17.02652458846852, 
        16.666666666666664`, 0.}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}}], 
       Polygon3DBox[{{17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {13.009031636236429`, 24.148145657226706`, 
        6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}}], 
       Polygon3DBox[{{17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}}], 
       Polygon3DBox[{{17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}}], 
       Polygon3DBox[{{17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {13.009031636236422`, 7.0819236220599744`*^-15, 
        25.}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.102694996447305*^-16, 8.333333333333332}, {
        19.27409578670236, -2.1568253758543383`, 8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {13.009031636236422`, 1.5308084989341915`*^-15, 
        25.}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}}], 
       Polygon3DBox[{{17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}}], 
       Polygon3DBox[{{17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {13.009031636236422`, -21.650635094610962`, 
        12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}}], 
       Polygon3DBox[{{17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {
        19.27409578670236, -8.333333333333332, 1.020538999289461*^-15}}], 
       Polygon3DBox[{{17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {
        13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        17.02652458846852, -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {20.,
         0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        13.009031636236422`, -4.592425496802574*^-15, -25.}, {
        13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}}],
        Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {13.009031636236422`, 
        6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
        17.67766952966367, -17.67766952966371}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {13.009031636236422`, 
        17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
        25., -2.8327694488239898`*^-14}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIJ7SnnN6PouWAwMYWEJpBoYZUHGPqxvuv1G1cHDc
VVp35KGkA0z9s98trBOWmTr8BwMNuPiONOED1WsNHbZDaZg4E9hUTYenUH0w
cXeouTB7YOKnz59fP3vybRuYu2DidhD1B9DV/4W448AzNPOh7jiwA809TyDq
DrBC3TUF1b8HPNH8C3XHAYi7XtvAxD2h6s2g7pqBGj4H/kDdBVO/C+qerVAa
Js4GcceBx1B9MPFwqLnuUHtg4jdu3z68Zd2XPTB3wcRNoO72RFP/HRpPL9DM
h8XTTqh7YO6HugPuLnh8QcM9Auou9PQDCZ/fewD+rBP5
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{6.990968363763578, 25., 0.}, {13.009031636236422`, 
          25., 0.}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763578, 25., 0.}}], 
         Polygon3DBox[{{6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          6.470476127563024, 24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, 1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{6.990968363763578, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -6.470476127563016, 
          24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}}], 
         Polygon3DBox[{{6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}}], 
         Polygon3DBox[{{6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}}], 
         Polygon3DBox[{{6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}}], 
         Polygon3DBox[{{6.990968363763578, -25., 3.061616997868383*^-15}, {
          13.009031636236422`, -25., 3.061616997868383*^-15}, {
          13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763578, -25., 3.061616997868383*^-15}}], 
         Polygon3DBox[{{
          6.990968363763578, -24.14814565722671, -6.470476127563009}, {
          13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763578, -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{6.990968363763578, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{6.990968363763578, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236422`, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., -30.}, {5., -30., -30.}, {5., -30., 100.}, {5., 
       100., 100.}, {5., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {-100., -30., -30.}, {-100., -30., 100.}, {
       5., -30., 100.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -30., -30.}, {-100., 100., -30.}, {-100., 100., 
       100.}, {-100., -30., 100.}, {-100., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -30.}, {5., 100., -30.}, {5., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {5., 100., -30.}, {-100., 
       100., -30.}, {-100., -30., -30.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., 100.}, {5., -30., 100.}, {-100., -30., 
       100.}, {-100., 100., 100.}, {5., 100., 100.}}]}}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAJR2QKOJFg94fHZJ1DlhGH1gx/RE/l0b
TQ7gUr9AffOzzGdSDgb86oZuE5UcEqTfct/YbYZTPcx8mLkwe/C702IvlLZF
pTHVN+zS2mR295+9xR3Bv3U7tGD8/YTcD3M3zB+EzIeZC7MHl/qEkI+mJuc4
HRwCwxr1WjTgNADaVWov
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAAMaaGj9G/OYR8zBfK7Ordjl+gdgNC71
C3TnLTFSZ3GA8QN2T/KpOKiHUz2a+Q7Emo9qLm73Q4CALXZxguY7EFKPI3wc
CJkP46PaQ3T4OAAAp9dQzQ==
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgAGImIAaxAx6fXRJ1TtgBSh/YMT2Rf9dGkwP3xZwDlX5o
O6hNyHuXzyV/QCdx/9zVf0wPLFDf/CzzmZSDAb+6odtEJYcE6bfcN3abHXAq
fHKCrUzLYfukmT1LEyUclurEFlTeNT8AMx9mLswemPkwc1Wh9jCAgcVeKG0L
owO2cUsfajdyMNFdf151i8IBGN2wS2uT2d1/9hZ3BP/W7dBygPL37zU18pU+
b+RQc9fQZ70Ln0Ozwr0d4i+U4e6HuRvmDxeo+2Hu3gr1B8x8mLkwe2Dmw8yF
2ZMQ8tHU5Byng0NgWKNeiwacPuwq/ZnpgbFDyPHOjfPnMcNpAJzlqFs=
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxG1r/xjzmEXMwn6tzK3a5/gEY7fbjxs+MIl0H
9tNSF1yY9A/A6AW685YYqbM4MEBBwO5JPhUH9Q4ImG6fVzfFEC6u25V66IeG
3gE08x1wmO+Abj7MXJh5MPNh5jKgAAFbBqzAxAFdBM18uDya+XBxHOHjgCN8
HHCEjwOO8HHAET7o5sNpAMvhiWQ=
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], 
     Line3DBox[{{{19.87504500785668, 2.4524530286952686`, 
      2.4524530286952686`}, {
      2.632724949887031, -11.109510882685575`, -11.109510882685575`}}, {{
      2.632724949887031, -11.109510882685575`, -11.109510882685575`}, \
{-8.986945184239104, -30., -30.}}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{-100., 100., 100.}, {
      4.951517653528597, -4.951517653528597, -20.694245301557856`}, {
      6.725013355908146, 9.283738647478089, -22.733765359294352`}, {
      4.951517653528597, -20.694245301557856`, -4.951517653528597}, \
{-8.526512829121202*^-14, 8.526512829121202*^-14, 8.526512829121202*^-14}, {
      1.9290072402615408`, 13.360343845777706`, -1.9290072402615408`}, {
      6.725013355908146, -22.733765359294352`, 9.283738647478089}, {
      1.9290072402615408`, -1.9290072402615408`, 13.360343845777706`}, {
      3.2256855215332934`, 12.258167306696691`, 12.258167306696691`}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      5.512586071943019, -15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, 0., -15.377870934402068`}, {5.512586071943019, 
      15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, -15.377870934402068`, 0.}, {
      1.4210854715202004`*^-14, 0., 0.}, {2.5191395626804507`, 
      15.377870934402068`, 0.}, {5.512586071943019, -15.826887910791454`, 
      15.826887910791454`}, {2.5191395626804507`, 0., 15.377870934402068`}, {
      5.512586071943019, 15.826887910791454`, 15.826887910791454`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      13.984636821212403`, -7.760192609308467, -21.986993655417947`}, {
      13.230520513425862`, 6.0953580826505265`, -23.86513426089063}, {
      13.984636821212403`, -21.986993655417947`, -7.760192609308466}, {
      18.530305567130483`, -8.351850977071628, -8.351850977071628}, {
      18.809010338552742`, 3.783537478706135, -9.953305985560524}, {
      13.230520513425866`, -23.86513426089063, 6.095358082650525}, {
      18.809010338552742`, -9.953305985560524, 3.783537478706135}, {
      19.87504500785668, 2.4524530286952686`, 2.4524530286952686`}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      14.723457153068136`, -15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, 0., -15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, -15.080022883315076`, 0.}, {20., 0., 0.}, {
      17.580057067612017`, 15.080022883315076`, 0.}, {
      14.723457153068136`, -15.504431250830306`, 15.504431250830306`}, {
      17.580057067612017`, 0., 15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, 15.504431250830306`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      2.632724949887031, -11.109510882685575`, -11.109510882685575`}, \
{-8.986945184239104, -30., -30.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.708, -2.587, 1.356}]], "Print",
 CellChangeTimes->{3.601301487081567*^9, 3.614709252128376*^9, 
  3.61472910915172*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"During evaluation of In[133]:="]
}, Open  ]],

Cell[TextData[{
 "Two standard sources illuminating a ",
 StyleBox["BiConvexLens", "MB"],
 " from their respective ",
 StyleBox["BirthPoint", "MB"],
 " positions.  The corner source fails to illuminate the lens evenly."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "The illuminated surface is nonplanar, so ",
 StyleBox["offAxisSource", "MB"],
 " fails to cover it evenly.  The lesson here is that the ",
 StyleBox["BirthPoint", "MB"],
 " option is fairly easy to use, but from the standpoint of uniform \
illumination does not perform well in the presence of curvature."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "A more advanced technique for maintaining illumination exploits actual ray \
trace data.  The idea is to perform an initial scout trace to glean surface \
intercept data, then employ that same data to ",
 StyleBox["define",
  FontSlant->"Italic"],
 " a light source.  This procedure is tantamount to selecting ray intercepts \
ahead of time and constraining a light source to produce them."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 StyleBox["referenceSource", "MB"],
 " has already produced a useful scout trace.  The strategy now will be to \
extract intercept data from the ",
 StyleBox["Ray", "MB"],
 " objects created by this trace.  ",
 StyleBox["referenceSource", "MB"],
 " illuminates the lens in a regular, full pattern.  You want to create an \
equivalent light source that reproduces the same pattern from the vantage of ",
 StyleBox["offAxisSource", "MB"],
 ".  The main piece of information you need for this purpose is the location \
of the intercepts.  As is usual in such cases, ",
 StyleBox["ReadRays", "MB"],
 " provides the needed information."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rayendpts", "=", 
  RowBox[{"ReadRays", "[", 
   RowBox[{"sys", ",", "RayEnd", ",", 
    RowBox[{"SourceID", "\[Rule]", "2"}], ",", 
    RowBox[{"IntersectionNumber", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5.512586071943019`", ",", 
     RowBox[{"-", "15.826887910791454`"}], ",", 
     RowBox[{"-", "15.826887910791454`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5191395626804507`", ",", "0.`", ",", 
     RowBox[{"-", "15.377870934402068`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.512586071943019`", ",", "15.826887910791454`", ",", 
     RowBox[{"-", "15.826887910791454`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5191395626804507`", ",", 
     RowBox[{"-", "15.377870934402068`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4210854715202004`*^-14", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"2.5191395626804507`", ",", "15.377870934402068`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.512586071943019`", ",", 
     RowBox[{"-", "15.826887910791454`"}], ",", "15.826887910791454`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5191395626804507`", ",", "0.`", ",", "15.377870934402068`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5.512586071943019`", ",", "15.826887910791454`", ",", 
     "15.826887910791454`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5634042311295652`*^9, 3.5634581280636*^9, 
  3.564487573857809*^9, 3.566100661983158*^9, 3.601301240032752*^9, 
  3.60130148711353*^9, 3.61470925214421*^9, 3.614729109193163*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"Out[136]="]
}, Open  ]],

Cell[TextData[{
 "The variable ",
 StyleBox["rayendpts", "MB"],
 " holds the return value from ",
 StyleBox["ReadRays", "MB"],
 ".  This return value is a list of 3D coordinate triplets.  The arguments to \
",
 StyleBox["ReadRays", "MB"],
 " are ",
 StyleBox["sys", "MB"],
 ", which holds the ",
 StyleBox["OpticalSystem", "MB"],
 " that was previously traced; ",
 StyleBox["RayEnd", "MB"],
 ", the ray data which you seek; ",
 StyleBox["SourceID", "MB"],
 ", constraining your query to those rays emanating from a particular source; \
and ",
 StyleBox["IntersectionNumber", "MB"],
 ", further stipulating only those rays that hit the first surface.  This \
final constraint is required because the system has many other rays traveling \
between other surfaces.  In this system there are two other surfaces, namely \
the other side of the lens and the ",
 StyleBox["Boundary", "MB"],
 " itself.  You do not want ",
 StyleBox["RayEnd", "MB"],
 " data from these other rays."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "Now you have a starting and an ending point for all the rays you need.  The \
whole set of rays must start at a common point, the position of ",
 StyleBox["offAxisSource", "MB"],
 ", and terminate at various locations given by ",
 StyleBox["rayendpts", "MB"],
 ".  However, the ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " function that will construct the new source requires a slightly different  \
form of input.  ",
 StyleBox["CustomRays", "MB"],
 " cannot define a light source by means of starting and ending points.  \
Instead, ",
 StyleBox["CustomRays", "MB"],
 " requires a starting point and a ",
 StyleBox["direction vector",
  FontSlant->"Italic"],
 " for each ray.  So first, construct a set of ",
 StyleBox["direction vectors",
  FontVariations->{"CompatibilityType"->0}],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "This construction involves simple vector subtraction and normalization.  \
The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Map", "MB"],
 " applies a ",
 StyleBox["Function", "MB"],
 " to each element in a list.  ",
 StyleBox["Function", "MB"],
 " here defined is a so-called pure function, which, in our case, performs \
the vector subtraction.  The other ",
 StyleBox["Map/Function", "MB"],
 " combination on the second line normalizes the direction vectors."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"raydirvecs", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{"#1", "-", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "100", ",", "100"}], "}"}]}], "]"}], ",", 
     "rayendpts"}], "]"}]}], ";"}], "\n", 
 RowBox[{"raydirvecs", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"#1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{"#1", ",", "#1"}], "]"}], "]"}]}], "]"}], ",", "raydirvecs"}],
    "]"}]}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[137]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5415201414764395`", ",", 
     RowBox[{"-", "0.5944560271270436`"}], ",", 
     RowBox[{"-", "0.5944560271270436`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.557447345850537`", ",", 
     RowBox[{"-", "0.5437495361631595`"}], ",", 
     RowBox[{"-", "0.62736663804074`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5932366734627076`", ",", 
     RowBox[{"-", "0.4732570669508389`"}], ",", 
     RowBox[{"-", "0.6512280689896512`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.557447345850537`", ",", 
     RowBox[{"-", "0.62736663804074`"}], ",", 
     RowBox[{"-", "0.5437495361631595`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5773502691896258`", ",", 
     RowBox[{"-", "0.5773502691896257`"}], ",", 
     RowBox[{"-", "0.5773502691896257`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6162996310116153`", ",", 
     RowBox[{"-", "0.5087107357807961`"}], ",", 
     RowBox[{"-", "0.6011556804325383`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5932366734627076`", ",", 
     RowBox[{"-", "0.6512280689896512`"}], ",", 
     RowBox[{"-", "0.4732570669508389`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6162996310116153`", ",", 
     RowBox[{"-", "0.6011556804325383`"}], ",", 
     RowBox[{"-", "0.5087107357807961`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6633108969599998`", ",", 
     RowBox[{"-", "0.5291590753138987`"}], ",", 
     RowBox[{"-", "0.5291590753138987`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5634042318721857`*^9, 3.563458128114152*^9, 
  3.564487573905877*^9, 3.566100662024865*^9, 3.6013012401574574`*^9, 
  3.601301487154499*^9, 3.614709252196907*^9, 3.614729109240877*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"Out[138]="]
}, Open  ]],

Cell["\<\
Armed with the starting point and direction vector for each ray, you can \
define a new light source.\
\>", "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"customSource", "=", 
   RowBox[{
    StyleBox["CustomRays", "MB"], "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"RayTilt", ",", "raydirvecs"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"RayStart", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "100"}], ",", "100", ",", "100"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Length", "[", "raydirvecs", "]"}], "}"}]}], "]"}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"RayLineRGB", "\[Rule]", "Red"}], ",", 
     RowBox[{"RayPointRGB", "\[Rule]", "Red"}], ",", 
     RowBox[{"RayPointSize", "\[Rule]", "4"}], ",", 
     RowBox[{"SourceID", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[139]:="],

Cell[TextData[{
 StyleBox["CustomRays", "MB"],
 " is the only ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " light source function which allows free-form light source shaping.  \
Essentially, we are instructing ",
 StyleBox["CustomRays", "MB"],
 " to accept the given parameter lists for the ",
 StyleBox["RayStart", "MB"],
 " and ",
 StyleBox["RayTilt", "MB"],
 " attributes of the ",
 StyleBox["Ray", "MB"],
 " objects that it will generate.  We used ",
 StyleBox["Table", "MB"],
 " inside ",
 StyleBox["CustomRays", "MB"],
 " to generate a list of as many starting points as there are vectors in ",
 StyleBox["raydirvecs", "MB"],
 ".  This construction conforms our input to the format expected by ",
 StyleBox["CustomRays", "MB"],
 ".  Note that ",
 StyleBox["BirthPoint", "MB"],
 " does not appear in our definition of ",
 StyleBox["customSource", "MB"],
 ".  In fact, ",
 StyleBox["CustomRays", "MB"],
 " does not accept the ",
 StyleBox["BirthPoint", "MB"],
 " option."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell["Now let us analyze the modified system.", "Text",
 PageBreakAbove->True,
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"newsys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"customSource", ",", "referenceSource", ",", 
       RowBox[{"BiConvexLens", "[", 
        RowBox[{"50", ",", "50", ",", "20", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", 
           RowBox[{"-", "30"}], ",", 
           RowBox[{"-", "30"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "100", ",", "100"}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.708"}], ",", 
        RowBox[{"-", "2.587"}], ",", "1.356"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[140]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.333333333333332, 0.}, {
      0.725904213297639, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.333333333333332, 0.}, {
      2.9734754115314814`, 16.666666666666664`, 0.}, {2.9734754115314814`, 
      16.09876377148447, 4.313650751708678}, {0.725904213297639, 
      8.049381885742235, 2.156825375854339}, {0.725904213297639, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.666666666666664`, 0.}, {
      6.990968363763578, 25., 0.}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {6.990968363763578, 7.0819236220599744`*^-15, 
      25.}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {6.990968363763578, 1.5308084989341915`*^-15, 
      25.}, {6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
      2.9734754115314814`, -4.313650751708677, 16.09876377148447}, {
      2.9734754115314814`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {6.990968363763578, -6.470476127563016, 
      24.148145657226706`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {6.990968363763578, -21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {6.990968363763578, -21.650635094610962`, 
      12.500000000000009`}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {6.990968363763578, -25., 3.061616997868383*^-15}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {
      0.725904213297639, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {6.990968363763578, -25., 
      3.061616997868383*^-15}, {
      6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      6.990968363763578, -24.14814565722671, -6.470476127563009}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      2.9734754115314814`, 4.313650751708671, -16.09876377148447}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      6.990968363763578, -4.592425496802574*^-15, -25.}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
      17.67766952966367, -17.67766952966371}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {6.990968363763578, 
      17.677669529663685`, -17.677669529663692`}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
      25., -2.8327694488239898`*^-14}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIL7xQS3zwDdpBwYwsITSDAwXoOIeVzfcf6Nq4eC4
q7TuyENJB5j6Z79bWCcsM3X4DwYacPEdacIHqtcaOmyH0jBxJrCpmg5Pofpg
4u5Qc2H2wMRPnz+/fvbk2zYwd8HE7SDqD6Cr/wtxx4FnaOZD3XFgB5p7nkDU
HWCFuusGqn8PeKL5F+qOAxB3vbaBiXtC1ZtB3XUBNXwO/IG6C6Z+F9Q9W6E0
TJwN4o4Dj6H6YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZ
D4unnVD3wNwPdQfcXfD4goZ7BNRd6OkHEj6/9wAABeEttg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.333333333333332, 
        0.}, {19.27409578670236, 8.049381885742235, 2.156825375854339}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.333333333333332, 0.}, {
        17.02652458846852, 16.666666666666664`, 0.}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {19.27409578670236, 
        8.049381885742235, 2.156825375854339}, {19.27409578670236, 
        8.333333333333332, 0.}}], 
       Polygon3DBox[{{17.02652458846852, 16.666666666666664`, 0.}, {
        13.009031636236422`, 25., 0.}, {13.009031636236429`, 
        24.148145657226706`, 6.4704761275630185`}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {17.02652458846852, 
        16.666666666666664`, 0.}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}}], 
       Polygon3DBox[{{17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {13.009031636236429`, 24.148145657226706`, 
        6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}}], 
       Polygon3DBox[{{17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}}], 
       Polygon3DBox[{{17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}}], 
       Polygon3DBox[{{17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {13.009031636236422`, 7.0819236220599744`*^-15, 
        25.}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.102694996447305*^-16, 8.333333333333332}, {
        19.27409578670236, -2.1568253758543383`, 8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {13.009031636236422`, 1.5308084989341915`*^-15, 
        25.}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}}], 
       Polygon3DBox[{{17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}}], 
       Polygon3DBox[{{17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {13.009031636236422`, -21.650635094610962`, 
        12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}}], 
       Polygon3DBox[{{17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {
        19.27409578670236, -8.333333333333332, 1.020538999289461*^-15}}], 
       Polygon3DBox[{{17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {
        13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        17.02652458846852, -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {20.,
         0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        13.009031636236422`, -4.592425496802574*^-15, -25.}, {
        13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}}],
        Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {13.009031636236422`, 
        6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
        17.67766952966367, -17.67766952966371}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {13.009031636236422`, 
        17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
        25., -2.8327694488239898`*^-14}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIJ7SnnN6PouWAwMYWEJpBoYZUHGPqxvuv1G1cHDc
VVp35KGkA0z9s98trBOWmTr8BwMNuPiONOED1WsNHbZDaZg4E9hUTYenUH0w
cXeouTB7YOKnz59fP3vybRuYu2DidhD1B9DV/4W448AzNPOh7jiwA809TyDq
DrBC3TUF1b8HPNH8C3XHAYi7XtvAxD2h6s2g7pqBGj4H/kDdBVO/C+qerVAa
Js4GcceBx1B9MPFwqLnuUHtg4jdu3z68Zd2XPTB3wcRNoO72RFP/HRpPL9DM
h8XTTqh7YO6HugPuLnh8QcM9Auou9PQDCZ/fewD+rBP5
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{6.990968363763578, 25., 0.}, {13.009031636236422`, 
          25., 0.}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763578, 25., 0.}}], 
         Polygon3DBox[{{6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          6.470476127563024, 24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, 1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{6.990968363763578, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -6.470476127563016, 
          24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}}], 
         Polygon3DBox[{{6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}}], 
         Polygon3DBox[{{6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}}], 
         Polygon3DBox[{{6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}}], 
         Polygon3DBox[{{6.990968363763578, -25., 3.061616997868383*^-15}, {
          13.009031636236422`, -25., 3.061616997868383*^-15}, {
          13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763578, -25., 3.061616997868383*^-15}}], 
         Polygon3DBox[{{
          6.990968363763578, -24.14814565722671, -6.470476127563009}, {
          13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763578, -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{6.990968363763578, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{6.990968363763578, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236422`, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., -30.}, {5., -30., -30.}, {5., -30., 100.}, {5., 
       100., 100.}, {5., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {-100., -30., -30.}, {-100., -30., 100.}, {
       5., -30., 100.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -30., -30.}, {-100., 100., -30.}, {-100., 100., 
       100.}, {-100., -30., 100.}, {-100., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -30.}, {5., 100., -30.}, {5., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {5., 100., -30.}, {-100., 
       100., -30.}, {-100., -30., -30.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., 100.}, {5., -30., 100.}, {-100., -30., 
       100.}, {-100., 100., 100.}, {5., 100., 100.}}]}}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAJR2gNEPOv/GPOYRc1gwX+dW7HL9AzAa
l/oFevOWGKmzQPkOe2fsnuRTcVAPp/oPLRDzK+aCzXV4MYc481HNddiLSz2E
1rCF0Ap7UWlM9Q66EPMzIOZDxQ1sCbkf5m6YPwiZDzMX1R5M9RNaIeZbQM2F
0QCHiWRD
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAAMaaGj9G/OYR8zBfK7Ordjl+gdgNC71
C3TnLTFSZ3GA8QN2T/KpOKiHUz2a+Q7Emo9qLm73Q4CALXZxguY7EFKPI3wc
CJkP46PaQ3T4OAAAp9dQzQ==
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxH3T+jXnMI+awYL7Ordjl+gdgdBjvJguXZ1oO
T60nT/NVNzwAoxfozVtipM7iwAAGDntn7J7kU3FQ78Bn0Wpvx936Dt/OVS17
oSB6QJwrozn4rNGBDy0Q8yvmgs11eDEHYv7txU4Cnx/qOkzv0pvk+FLFoVHZ
vuvCcSO4+TBzYfbAzIeZC7MHIq9hC6EV9sLo4G3c0ofajRxEddefV92icABG
O+hCzM+AmA/1h4Ft5qp1kcc/GTkYnEurO/ROzGGtYVqvbbYC3P0wd8P8AXM/
zN0wf8DMh5kLswdm/jqouXpQeya0Qsy3gJoLo29YrJhde9zIoY9XQXFKjRyc
BgDhZbB9
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxG1r/xjzmEXMwn6tzK3a5/gEY7fbjxs+MIl0H
9tNSF1yY9A/A6AW685YYqbM4MEBBwO5JPhUH9Q4ImG6fVzfFEC6u25V66IeG
3gE08x1wmO+Abj7MXJh5MPNh5jKgAAFbBqzAxAFdBM18uDya+XBxHOHjgCN8
HHCEjwOO8HHAET7o5sNpAMvhiWQ=
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], 
     Line3DBox[{{{14.941307552466176`, 
      10.455578392201728`, -18.7805258182666}, {
      2.234606302806256, -9.836865786907756, -10.660246056745464`}}, {{
      14.941307552466176`, -18.7805258182666, 10.455578392201728`}, {
      2.2346063028062577`, -10.66024605674547, -9.836865786907753}}, {{
      18.77926037652, 7.621658818799359, 7.621658818799359}, {
      5.077834711788297, -15.226266698905482`, -15.226266698905482`}}, {{
      2.234606302806256, -9.836865786907756, -10.660246056745464`}, {
      14.709748385679472`, -21.90119521400225, 1.5129386055843472`}}, {{
      2.2346063028062577`, -10.66024605674547, -9.836865786907753}, {
      14.70974838567947, 1.5129386055843455`, -21.901195214002254`}}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      5.512586071944014, -15.82688791079255, -15.82688791079255}, {
      2.5191395626805644`, -1.1368683772161603`*^-13, -15.377870934402196`}, {
      5.512586071942891, 15.82688791079157, -15.826887910791314`}, {
      2.5191395626805644`, -15.377870934402196`, -1.1368683772161603`*^-13}, {
      4.263256414560601*^-14, -2.842170943040401*^-14, \
-2.842170943040401*^-14}, {2.519139562680408, 15.377870934402111`, 
      5.684341886080802*^-14}, {5.512586071942891, -15.826887910791314`, 
      15.82688791079157}, {2.519139562680408, 5.684341886080802*^-14, 
      15.377870934402111`}, {5.5125860719430335`, 15.826887910791456`, 
      15.826887910791456`}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      5.512586071943019, -15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, 0., -15.377870934402068`}, {5.512586071943019, 
      15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, -15.377870934402068`, 0.}, {
      1.4210854715202004`*^-14, 0., 0.}, {2.5191395626804507`, 
      15.377870934402068`, 0.}, {5.512586071943019, -15.826887910791454`, 
      15.826887910791454`}, {2.5191395626804507`, 0., 15.377870934402068`}, {
      5.512586071943019, 15.826887910791454`, 15.826887910791454`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      13.44973923848617, -17.153527651735107`, -17.153527651735107`}, {
      15.865732535147776`, -5.282137490506775, -18.802055561924217`}, {
      14.941307552466176`, 10.455578392201728`, -18.7805258182666}, {
      15.865732535147776`, -18.802055561924217`, -5.282137490506775}, {
      18.530305567130494`, -8.351850977071573, -8.351850977071573}, {
      18.94835434450434, 5.733163809799905, -8.209453982090816}, {
      14.941307552466176`, -18.7805258182666, 10.455578392201728`}, {
      18.94835434450434, -8.209453982090817, 5.733163809799903}, {
      18.77926037652, 7.621658818799359, 7.621658818799359}}]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      14.723457153068136`, -15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, 0., -15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, -15.080022883315076`, 0.}, {20., 0., 0.}, {
      17.580057067612017`, 15.080022883315076`, 0.}, {
      14.723457153068136`, -15.504431250830306`, 15.504431250830306`}, {
      17.580057067612017`, 0., 15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, 15.504431250830306`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      2.234606302806256, -9.836865786907756, -10.660246056745464`}, {
      2.2346063028062577`, -10.66024605674547, -9.836865786907753}, {
      5.077834711788297, -15.226266698905482`, -15.226266698905482`}, {
      14.709748385679472`, -21.90119521400225, 1.5129386055843472`}, {
      14.70974838567947, 1.5129386055843455`, -21.901195214002254`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.708, -2.587, 1.356}]], "Print",
 CellChangeTimes->{3.601301487791041*^9, 3.614709252883676*^9, 
  3.6147291098769484`*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"During evaluation of In[140]:="]
}, Open  ]],

Cell["\<\
Custom light source modifications enforce uniform illumination from two \
positions.\
\>", "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "A new light source has been defined, ",
 StyleBox["customSource", "MB"],
 ", to replace ",
 StyleBox["offAxisSource", "MB"],
 ".  This new source intercepts the entrance pupil at the same points as the ",
 StyleBox["onAxisSource", "MB"],
 ".  Thus both sources illuminate the pupil evenly."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "This new source works for one fixed position, ",
 StyleBox["{-100,100,100}", "MB"],
 ".  The question remains as to what happens if you move ",
 StyleBox["customSource", "MB"],
 ".  At that stage, the direction vectors will no longer point in the right \
direction, so ",
 StyleBox["customSource", "MB"],
 " will break it is moved."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "Arbitrary positioning requires consolidation of all the previous steps into \
a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function.  This function, which is entitled ",
 StyleBox["FixedIlluminationSource", "MB"],
 ", accepts the position as an input parameter."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "FixedIlluminationSource", "]"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"good", " ", "practice"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FixedIlluminationSource", "[", 
    RowBox[{"newbirthpoint_", ",", "endpts_", ",", "options___"}], "]"}], ":=",
    " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "raydirvecs", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"raydirvecs", " ", "=", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{"#1", "-", "newbirthpoint"}], "]"}], ",", "endpts"}], 
        "]"}]}], ";", 
      RowBox[{"raydirvecs", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{"#1", " ", "/", " ", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"Dot", "[", 
             RowBox[{"#1", ",", "#1"}], "]"}], "]"}]}], "]"}], ",", 
         "raydirvecs"}], "]"}]}], ";", 
      RowBox[{"Return", "[", 
       RowBox[{
        StyleBox["CustomRays", "MB"], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"RayTilt", ",", "raydirvecs"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"RayStart", ",", 
             RowBox[{"Table", "[", 
              RowBox[{"newbirthpoint", ",", 
               RowBox[{"{", 
                RowBox[{"Length", "[", "raydirvecs", "]"}], "}"}]}], "]"}]}], 
            "}"}]}], "}"}], ",", "options"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[141]:="],

Cell["\<\
A custom light source function providing fixed illumination of a particular \
entrance pupil from any position.\
\>", "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "A simple test of ",
 StyleBox["FixedIlluminationSource", "MB"],
 " will show that it performs as specified."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"multisys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"FixedIlluminationSource", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "100"}], ",", "start", ",", "start"}], "}"}], ",", 
           "rayendpts", ",", 
           RowBox[{"RayLineRGB", "\[Rule]", "Red"}], ",", 
           RowBox[{"RayPointRGB", "\[Rule]", "Red"}], ",", 
           RowBox[{"RayPointSize", "\[Rule]", "4"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"start", ",", "25", ",", "100", ",", "25"}], "}"}]}], "]"}],
        ",", "referenceSource", ",", 
       RowBox[{"BiConvexLens", "[", 
        RowBox[{"50", ",", "50", ",", "20", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", 
           RowBox[{"-", "30"}], ",", 
           RowBox[{"-", "30"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "100", ",", "100"}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.708"}], ",", 
        RowBox[{"-", "2.587"}], ",", "1.356"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"In[143]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.333333333333332, 0.}, {
      0.725904213297639, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.333333333333332, 0.}, {
      2.9734754115314814`, 16.666666666666664`, 0.}, {2.9734754115314814`, 
      16.09876377148447, 4.313650751708678}, {0.725904213297639, 
      8.049381885742235, 2.156825375854339}, {0.725904213297639, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.666666666666664`, 0.}, {
      6.990968363763578, 25., 0.}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 8.049381885742235, 
      2.156825375854339}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}, {6.990968363763571, 24.148145657226706`, 
      6.4704761275630185`}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 16.09876377148447, 
      4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 7.216878364870323, 
      4.166666666666666}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}, {6.990968363763578, 21.65063509461097, 
      12.499999999999998`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 14.433756729740645`, 
      8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}, {6.990968363763578, 17.67766952966369, 
      17.677669529663685`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 4.166666666666668, 
      7.216878364870322}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.7259042132976461, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}, {6.990968363763578, 12.500000000000004`, 
      21.650635094610966`}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 8.333333333333336, 
      14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 2.156825375854341, 
      8.049381885742235}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {0.725904213297639, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0.725904213297639, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}, {6.990968363763578, 6.470476127563024, 
      24.148145657226706`}, {6.990968363763578, 7.0819236220599744`*^-15, 
      25.}, {2.9734754115314814`, 4.721282414706649*^-15, 
      16.666666666666664`}, {2.9734754115314814`, 4.313650751708682, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}, {2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.725904213297639, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{2.9734754115314814`, 1.020538999289461*^-15, 
      16.666666666666664`}, {6.990968363763578, 1.5308084989341915`*^-15, 
      25.}, {6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
      2.9734754115314814`, -4.313650751708677, 16.09876377148447}, {
      2.9734754115314814`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}, {6.990968363763578, -6.470476127563016, 
      24.148145657226706`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -4.313650751708677, 
      16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -4.166666666666664, 
      7.216878364870323}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}, {6.990968363763578, -12.499999999999995`, 
      21.65063509461097}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -8.333333333333329, 
      14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {0.7259042132976461, -7.216878364870323, 
      4.166666666666666}, {0.725904213297639, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}, {6.990968363763578, -17.677669529663685`, 
      17.67766952966369}, {6.990968363763578, -21.65063509461097, 
      12.499999999999998`}, {2.9734754115314814`, -14.433756729740645`, 
      8.333333333333332}, {2.9734754115314814`, -11.785113019775789`, 
      11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, -7.21687836487032, 
      4.16666666666667}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.7259042132976461, -7.21687836487032, 
      4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}, {6.990968363763578, -21.650635094610962`, 
      12.500000000000009`}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -14.43375672974064, 
      8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.049381885742235, 
      2.156825375854342}, {2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {0.725904213297639, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.09876377148447, 
      4.313650751708684}, {6.990968363763578, -24.148145657226706`, 
      6.470476127563026}, {6.990968363763578, -25., 3.061616997868383*^-15}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, -8.333333333333332, 
      1.020538999289461*^-15}, {2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      0.725904213297639, -8.049381885742235, -2.15682537585434}, {
      0.725904213297639, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{2.9734754115314814`, -16.666666666666664`, 
      2.041077998578922*^-15}, {6.990968363763578, -25., 
      3.061616997868383*^-15}, {
      6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
      2.9734754115314814`, -16.09876377148447, -4.31365075170868}, {
      2.9734754115314814`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -8.049381885742235, -2.156825375854336}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}, {
      6.990968363763578, -24.14814565722671, -6.470476127563009}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -7.216878364870323, -4.166666666666664}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      0.725904213297639, -5.892556509887897, -5.8925565098878945`}, {
      0.7259042132976461, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}, {
      6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
      6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
      2.9734754115314814`, -11.785113019775794`, -11.785113019775789`}, {
      2.9734754115314814`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -5.892556509887898, -5.892556509887893}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}, {
      6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.7259042132976461, -4.16666666666667, -7.216878364870319}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.7259042132976461, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}, {
      6.990968363763578, -12.50000000000001, -21.65063509461096}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -2.156825375854346, -8.049381885742234}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      0.725904213297639, -8.932295329768568*^-15, -8.333333333333332}, {
      0.725904213297639, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}, {
      6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
      6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
      2.9734754115314814`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      2.9734754115314814`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      2.9734754115314814`, 4.313650751708671, -16.09876377148447}, {
      0.725904213297639, 2.1568253758543356`, -8.049381885742235}, {
      0.725904213297639, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      6.990968363763578, -4.592425496802574*^-15, -25.}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {
      2.9734754115314814`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}, {6.990968363763578, 
      6.470476127563007, -24.14814565722671}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      4.166666666666661, -7.216878364870325}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {0.725904213297639, 
      5.89255650988789, -5.892556509887903}, {0.725904213297639, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}, {6.990968363763578, 
      12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
      17.67766952966367, -17.67766952966371}, {2.9734754115314814`, 
      11.78511301977578, -11.785113019775807`}, {2.9734754115314814`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}, {6.990968363763578, 
      17.677669529663685`, -17.677669529663692`}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.7259042132976461, 
      7.216878364870319, -4.16666666666667}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.7259042132976461, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}, {6.990968363763571, 
      21.65063509461096, -12.50000000000001}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {0.725904213297639, 
      8.333333333333332, -9.442564829413298*^-15}, {0.725904213297639, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}, {6.990968363763578, 
      24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
      25., -2.8327694488239898`*^-14}, {2.9734754115314814`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {2.9734754115314814`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIL7xQS3zwDdpBwYwsITSDAwXoOIeVzfcf6Nq4eC4
q7TuyENJB5j6Z79bWCcsM3X4DwYacPEdacIHqtcaOmyH0jBxJrCpmg5Pofpg
4u5Qc2H2wMRPnz+/fvbk2zYwd8HE7SDqD6Cr/wtxx4FnaOZD3XFgB5p7nkDU
HWCFuusGqn8PeKL5F+qOAxB3vbaBiXtC1ZtB3XUBNXwO/IG6C6Z+F9Q9W6E0
TJwN4o4Dj6H6YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZ
D4unnVD3wNwPdQfcXfD4goZ7BNRd6OkHEj6/9wAABeEttg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.333333333333332, 
        0.}, {19.27409578670236, 8.049381885742235, 2.156825375854339}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.333333333333332, 0.}, {
        17.02652458846852, 16.666666666666664`, 0.}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {19.27409578670236, 
        8.049381885742235, 2.156825375854339}, {19.27409578670236, 
        8.333333333333332, 0.}}], 
       Polygon3DBox[{{17.02652458846852, 16.666666666666664`, 0.}, {
        13.009031636236422`, 25., 0.}, {13.009031636236429`, 
        24.148145657226706`, 6.4704761275630185`}, {17.02652458846852, 
        16.09876377148447, 4.313650751708678}, {17.02652458846852, 
        16.666666666666664`, 0.}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 8.049381885742235, 
        2.156825375854339}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 8.049381885742235, 
        2.156825375854339}}], 
       Polygon3DBox[{{17.02652458846852, 16.09876377148447, 
        4.313650751708678}, {13.009031636236429`, 24.148145657226706`, 
        6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 16.09876377148447, 
        4.313650751708678}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 7.216878364870323, 
        4.166666666666666}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 7.216878364870323, 
        4.166666666666666}}], 
       Polygon3DBox[{{17.02652458846852, 14.433756729740645`, 
        8.333333333333332}, {13.009031636236422`, 21.65063509461097, 
        12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 14.433756729740645`, 
        8.333333333333332}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 5.892556509887896, 
        5.8925565098878945`}}], 
       Polygon3DBox[{{17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}, {13.009031636236422`, 17.67766952966369, 
        17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 11.785113019775793`, 
        11.785113019775789`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, 4.166666666666668, 
        7.216878364870322}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.274095786702354`, 4.166666666666668, 
        7.216878364870322}}], 
       Polygon3DBox[{{17.02652458846852, 8.333333333333336, 
        14.433756729740644`}, {13.009031636236422`, 12.500000000000004`, 
        21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 8.333333333333336, 
        14.433756729740644`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 2.156825375854341, 
        8.049381885742235}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {19.27409578670236, 2.3606412073533245`*^-15, 
        8.333333333333332}, {19.27409578670236, 2.156825375854341, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 4.313650751708682, 
        16.09876377148447}, {13.009031636236422`, 6.470476127563024, 
        24.148145657226706`}, {13.009031636236422`, 7.0819236220599744`*^-15, 
        25.}, {17.02652458846852, 4.721282414706649*^-15, 
        16.666666666666664`}, {17.02652458846852, 4.313650751708682, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.102694996447305*^-16, 8.333333333333332}, {
        19.27409578670236, -2.1568253758543383`, 8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.27409578670236, 5.102694996447305*^-16, 
        8.333333333333332}}], 
       Polygon3DBox[{{17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}, {13.009031636236422`, 1.5308084989341915`*^-15, 
        25.}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, 1.020538999289461*^-15, 
        16.666666666666664`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -2.1568253758543383`, 
        8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, -4.313650751708677, 
        16.09876377148447}, {13.009031636236422`, -6.470476127563016, 
        24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -4.313650751708677, 
        16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -4.166666666666664, 
        7.216878364870323}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -4.166666666666664, 
        7.216878364870323}}], 
       Polygon3DBox[{{17.02652458846852, -8.333333333333329, 
        14.433756729740645`}, {13.009031636236422`, -12.499999999999995`, 
        21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -8.333333333333329, 
        14.433756729740645`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {19.274095786702354`, -7.216878364870323, 
        4.166666666666666}, {19.27409578670236, -5.8925565098878945`, 
        5.892556509887896}}], 
       Polygon3DBox[{{17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}, {13.009031636236422`, -17.677669529663685`, 
        17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
        12.499999999999998`}, {17.02652458846852, -14.433756729740645`, 
        8.333333333333332}, {17.02652458846852, -11.785113019775789`, 
        11.785113019775793`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.274095786702354`, -7.21687836487032, 
        4.16666666666667}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.274095786702354`, -7.21687836487032, 
        4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, -14.43375672974064, 
        8.33333333333334}, {13.009031636236422`, -21.650635094610962`, 
        12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -14.43375672974064, 
        8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {20., 0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.049381885742235, 
        2.156825375854342}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {19.27409578670236, -8.049381885742235, 
        2.156825375854342}}], 
       Polygon3DBox[{{17.02652458846852, -16.09876377148447, 
        4.313650751708684}, {13.009031636236422`, -24.148145657226706`, 
        6.470476127563026}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {17.02652458846852, -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{19.27409578670236, -8.333333333333332, 
        1.020538999289461*^-15}, {17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        19.27409578670236, -8.049381885742235, -2.15682537585434}, {
        19.27409578670236, -8.333333333333332, 1.020538999289461*^-15}}], 
       Polygon3DBox[{{17.02652458846852, -16.666666666666664`, 
        2.041077998578922*^-15}, {13.009031636236422`, -25., 
        3.061616997868383*^-15}, {
        13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
        17.02652458846852, -16.09876377148447, -4.31365075170868}, {
        17.02652458846852, -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -8.049381885742235, -2.156825375854336}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{
        17.02652458846852, -16.09876377148447, -4.313650751708672}, {
        13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {20., 
        0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -7.216878364870323, -4.166666666666664}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        19.27409578670236, -5.892556509887897, -5.8925565098878945`}, {
        19.274095786702354`, -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{
        17.02652458846852, -14.433756729740645`, -8.333333333333329}, {
        13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
        13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
        17.02652458846852, -11.785113019775794`, -11.785113019775789`}, {
        17.02652458846852, -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -5.892556509887898, -5.892556509887893}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}, {
        13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {20., 0., 
        0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.274095786702354`, -4.16666666666667, -7.216878364870319}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.274095786702354`, -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{
        17.02652458846852, -8.33333333333334, -14.433756729740638`}, {
        13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {20.,
         0., 0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -2.156825375854346, -8.049381885742234}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        19.27409578670236, -8.932295329768568*^-15, -8.333333333333332}, {
        19.27409578670236, -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{
        17.02652458846852, -4.313650751708692, -16.098763771484467`}, {
        13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
        13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
        17.02652458846852, -1.7864590659537137`*^-14, -16.666666666666664`}, {
        17.02652458846852, -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{20., 0., 0.}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {20., 0.,
         0.}, {20., 0., 0.}}], 
       Polygon3DBox[{{
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        19.27409578670236, 2.1568253758543356`, -8.049381885742235}, {
        19.27409578670236, -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}, {
        13.009031636236422`, -4.592425496802574*^-15, -25.}, {
        13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
        17.02652458846852, 4.313650751708671, -16.09876377148447}, {
        17.02652458846852, -3.0616169978683826`*^-15, -16.666666666666664`}}],
        Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{17.02652458846852, 
        4.313650751708671, -16.09876377148447}, {13.009031636236422`, 
        6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        4.166666666666661, -7.216878364870325}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {19.27409578670236, 
        5.89255650988789, -5.892556509887903}, {19.27409578670236, 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{17.02652458846852, 
        8.333333333333321, -14.43375672974065}, {13.009031636236422`, 
        12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
        17.67766952966367, -17.67766952966371}, {17.02652458846852, 
        11.78511301977578, -11.785113019775807`}, {17.02652458846852, 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {20., 0., 0.}, {20., 0., 0.}}],
        Polygon3DBox[{{19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}, {13.009031636236422`, 
        17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.274095786702354`, 
        7.216878364870319, -4.16666666666667}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.274095786702354`, 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{17.02652458846852, 
        14.433756729740638`, -8.33333333333334}, {13.009031636236429`, 
        21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{20., 0., 0.}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {20., 0., 0.}, {20., 0., 
        0.}}], Polygon3DBox[{{19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {19.27409578670236, 
        8.333333333333332, -9.442564829413298*^-15}, {19.27409578670236, 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{17.02652458846852, 
        16.098763771484467`, -4.313650751708693}, {13.009031636236422`, 
        24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
        25., -2.8327694488239898`*^-14}, {17.02652458846852, 
        16.666666666666664`, -1.8885129658826596`*^-14}, {17.02652458846852, 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIJ7SnnN6PouWAwMYWEJpBoYZUHGPqxvuv1G1cHDc
VVp35KGkA0z9s98trBOWmTr8BwMNuPiONOED1WsNHbZDaZg4E9hUTYenUH0w
cXeouTB7YOKnz59fP3vybRuYu2DidhD1B9DV/4W448AzNPOh7jiwA809TyDq
DrBC3TUF1b8HPNH8C3XHAYi7XtvAxD2h6s2g7pqBGj4H/kDdBVO/C+qerVAa
Js4GcceBx1B9MPFwqLnuUHtg4jdu3z68Zd2XPTB3wcRNoO72RFP/HRpPL9DM
h8XTTqh7YO6HugPuLnh8QcM9Auou9PQDCZ/fewD+rBP5
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{6.990968363763578, 25., 0.}, {13.009031636236422`, 
          25., 0.}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {6.990968363763578, 25., 0.}}], 
         Polygon3DBox[{{6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236429`, 24.148145657226706`, 
          6.4704761275630185`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {6.990968363763571, 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{6.990968363763578, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 21.65063509461097, 
          12.499999999999998`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {6.990968363763578, 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{6.990968363763578, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 17.67766952966369, 
          17.677669529663685`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {6.990968363763578, 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 12.500000000000004`, 
          21.650635094610966`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {6.990968363763578, 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{6.990968363763578, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 6.470476127563024, 
          24.148145657226706`}, {13.009031636236422`, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          7.0819236220599744`*^-15, 25.}, {6.990968363763578, 
          6.470476127563024, 24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, 1.5308084989341915`*^-15, 25.}, {
          13.009031636236422`, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, -6.470476127563016, 24.148145657226706`}, {
          6.990968363763578, 1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{6.990968363763578, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -6.470476127563016, 
          24.148145657226706`}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {6.990968363763578, -6.470476127563016, 
          24.148145657226706`}}], 
         Polygon3DBox[{{6.990968363763578, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -12.499999999999995`, 
          21.65063509461097}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {6.990968363763578, -12.499999999999995`, 
          21.65063509461097}}], 
         Polygon3DBox[{{6.990968363763578, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -17.677669529663685`, 
          17.67766952966369}, {13.009031636236422`, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -21.65063509461097, 
          12.499999999999998`}, {6.990968363763578, -17.677669529663685`, 
          17.67766952966369}}], 
         Polygon3DBox[{{6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -21.650635094610962`, 
          12.500000000000009`}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {6.990968363763578, -21.650635094610962`, 
          12.500000000000009`}}], 
         Polygon3DBox[{{6.990968363763578, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -24.148145657226706`, 
          6.470476127563026}, {13.009031636236422`, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -25., 
          3.061616997868383*^-15}, {6.990968363763578, -24.148145657226706`, 
          6.470476127563026}}], 
         Polygon3DBox[{{6.990968363763578, -25., 3.061616997868383*^-15}, {
          13.009031636236422`, -25., 3.061616997868383*^-15}, {
          13.009031636236429`, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763571, -24.148145657226706`, -6.47047612756302}, {
          6.990968363763578, -25., 3.061616997868383*^-15}}], 
         Polygon3DBox[{{
          6.990968363763578, -24.14814565722671, -6.470476127563009}, {
          13.009031636236422`, -24.14814565722671, -6.470476127563009}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          6.990968363763578, -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{
          6.990968363763571, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236429`, -21.65063509461097, -12.499999999999993`}, {
          13.009031636236422`, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763578, -17.677669529663692`, -17.677669529663685`}, {
          6.990968363763571, -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -17.677669529663696`, -17.677669529663678`}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          6.990968363763578, -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{
          6.990968363763578, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -12.50000000000001, -21.65063509461096}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          6.990968363763578, -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{
          6.990968363763578, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -6.470476127563038, -24.148145657226703`}, {
          13.009031636236422`, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -2.6796885989305705`*^-14, -25.}, {
          6.990968363763578, -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{6.990968363763578, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, -4.592425496802574*^-15, -25.}, {
          13.009031636236422`, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, 6.470476127563007, -24.14814565722671}, {
          6.990968363763578, -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{6.990968363763578, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          6.470476127563007, -24.14814565722671}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {6.990968363763578, 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          12.499999999999984`, -21.650635094610976`}, {13.009031636236422`, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          17.67766952966367, -17.67766952966371}, {6.990968363763578, 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236422`, 
          17.677669529663685`, -17.677669529663692`}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {6.990968363763578, 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{6.990968363763571, 
          21.65063509461096, -12.50000000000001}, {13.009031636236429`, 
          21.65063509461096, -12.50000000000001}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {6.990968363763571, 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{6.990968363763578, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          24.148145657226703`, -6.470476127563039}, {13.009031636236422`, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          25., -2.8327694488239898`*^-14}, {6.990968363763578, 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., -30.}, {5., -30., -30.}, {5., -30., 100.}, {5., 
       100., 100.}, {5., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {-100., -30., -30.}, {-100., -30., 100.}, {
       5., -30., 100.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., -30., -30.}, {-100., 100., -30.}, {-100., 100., 
       100.}, {-100., -30., 100.}, {-100., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-100., 100., -30.}, {5., 100., -30.}, {5., 100., 
       100.}, {-100., 100., 100.}, {-100., 100., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., -30., -30.}, {5., 100., -30.}, {-100., 
       100., -30.}, {-100., -30., -30.}, {5., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{5., 100., 100.}, {5., -30., 100.}, {-100., -30., 
       100.}, {-100., 100., 100.}, {5., 100., 100.}}]}}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyNlL9Lw0AUxw917OAkHRUCZohtkIJ1CLyhi+IQuxUUgiB00zFjB5W6BScH
f2QQXN3lIP4Xxang4ujoIlh575k8cselEL5N+uHb773vXTZOzoany0opb3Et
La6/7/gZFai7wJpf/Bx9tNagdR+8Hz93C1Ybn3QenrY3V+i+rZPXm4P0rWPl
s0v030Ff6Df0l75tbeNR/YgWqKXW+ckW+h+iPz1XkSs/5+Z1uPzZV/5PnT+X
/v8q+T1gnVwhP6U8U+M8Sz4XfQU6NfZV8rzeHuWAhv7SN9A2HpX7WtVS6zzv
BxBz9Kw85+fcPcc85X72NBj7KvmQ/AfkOzD5F0NgBTpfL3eYh9XGz7vVPPt6
Zuqrwn+Rf0I5vh3+3FcmfPvaxuNzn37n3vzIxue0/2N5vpQrP+dOHPPM5flS
samvCh836UuN+B7m18jnj5iH1cbL8wX61ni+Sp7Xm1KOT1NfBn/pC9rGo3I/
61pqnQea51jMMYxsPOfn3KljniD6CqOx8XyVfGZ5H/4COXqLxw==
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxISDyAAMaaGj9G/OYR8zBfK7Ordjl+gdgNC71
C3TnLTFSZ3GA8QN2T/KpOKiHUz2a+Q7Emo9qLm73Q4CALXZxguY7EFKPI3wc
CJkP46PaQ3T4OAAAp9dQzQ==
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1lH1MTWEcx09EUllKN1vhppve7su5J3SNyy9ilnuTaoxqLksr1jI0FxXX
u5DEqk1yt5KXpSzKS049mtYiuSZbE5PSm1kTZkZ5Pc/v5PzhbGffs52zz/f7
e77Pc3w2pkVvGsswjOL3Peb3/efZenAkvttZBs7nlS8SLmkI6vP1HzwXeCjB
teCj2WEzS1BN6uJSzt8emL/XVN5Um2cw31eTyNPZdtu7WEhc2nrWYG9Htlsn
FfcOsCT3kMAPFbigo/wbd1O33clQQb3P/vBYTyUU/ag2cs2jfOSiD/KRiz7C
+wC9oAyPGlMZVL/oUQhkGgbmyDWOBHWfSuCvEvh0Dka/8Hawn20xB6G7Ut4e
CAyEmuH0zRpvezE/5sY5qml+zF1H50A+ctEH+chFn61SvqgPOzRF/hYNnH9h
aDz1LVjUfYeF74/SPKg2xeTP39cFQ9aNgvqK1yxBtUr6UvJmuq4jZS9PZCSw
MPZVrPPQLBdyr7K3dMZPrTjvbJoDKN8gu7Kyp0AF3hEt3SHLAmFmnSVuXJ1W
5JslfSl55CMXfaR9ufKo8+aW75y2JgQeZCvmL9ktI6i4H0DSl4IfNL0fTK/h
wMu2I+9umy+UJt8aeVbiLubH3DiHkebH3DiHdD8rePRBPnLRh6X8cMpFHXPH
bW3sEAvlUc19Vd3+ogI9X9eLhDyovnN6z2WOD4av7uq8SnctQe3U/Jsngm+n
6zrB/bBDvhMLxuWMaeSkGxlsK45MPcGRD5Rvojm+Uv68uGTNUK0KXrW8c3za
MQvGtx4PlG3gxL5yJX3peBfKf0m5OdSH9sVLewvQp1suO1R0cZAWVhpg8ZtG
UK10/0dJzxfTd9FW1tjPQeHexPc7jdMhKyI/03OFl5gfc+McmB9z4xxW6fli
0Af5yEWfqP/0lesU/3mKHQfRw99JaIqvqJ3HhO+tF4Q8qKtdqnThvUHQM/9M
vtFfS1Cl5wv4Qrqunzz2rAir1cCX1t1l/XIP4jkx+UDM49G+zDRHP527o2Sx
66c3KijIVueFDSjA4rso29Y02lehpC/gkY9c9JH2JOdRY2qcvBqOcOChqnzi
d1NOUIGuZ7KkL1afcrVibdNHDtjWpKyGQRlc0yad1G+Ri/kxN86B+TE3zgGS
vlg9+iC/gnLV1Cf3P//Ddt3lc5lNHOS4yH3OZkwX9RdHbbf9
      "]]}, 
    {RGBColor[0., 1., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxG1r/xjzmEXMwn6tzK3a5/gEY7fbjxs+MIl0H
9tNSF1yY9A/A6AW685YYqbM4MEBBwO5JPhUH9Q4ImG6fVzfFEC6u25V66IeG
3gE08x1wmO+Abj7MXJh5MPNh5jKgAAFbBqzAxAFdBM18uDya+XBxHOHjgCN8
HHCEjwOO8HHAET7o5sNpAMvhiWQ=
      "]]}, 
    {RGBColor[1., 0., 0.], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgBGImIAaxmXYKRYZ8NHBYE3Dy+abH6nCaY1fvm2UMbA7X
FliKC25SOwCjJ3DHfBFhNHII+vP7gHmmMpwu2p/eyacv6CBhe1rDVFHnAIy+
vdhJ4PNDXYfpXXqTHF+qODQq23ddOG50QOHFe5fKB4wOvy8qr6lco3zghGDW
Ue4gVbh6mDqYPhWo+tNQdT+h+m5YrJhde9zIoY9XQXFKjRyc9qsXe77ZX8RB
+VO/1c1ivQMwGpe//i6WsFsmoeswqf3DLp9a/QMwGpe/2M5ZNuRy6TiITa0K
+VlgcABG4/LXssMflVOydR36ig/v2vLM9IBGca3Mf5Mf9rj8tRSqXgGqrh+q
DwBa2MTW
      "]]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], Point3DBox[CompressedData["
1:eJx1kjFLA0EQhZdomcJKUiocmOJMDhFMszCFlVhEa4VDCKSL5ZUpjGh3WKVI
zBaCrb0MxH8hVgGblJY2giEzLziLOVgeLO+92W/3dq96552Kcy5ZrI3FCjc/
F5/VbaqO04/L5+YUmjcenw72Nsktvxrnrw+nxVtjWg7EfyQ+akV++JATrXtR
x9D+vvjPxK9znEc/ejEHfviQu7b+lfZvZf9Oe6DBcKVcRFyHmqfIXxiuNOLa
YijugQxXwuhHL+bYe04YuUz9x+qDkr7Xy0h6oLPm354Tftfzfqk/1/z3yHKV
hqsFroiv7oPef9u+l0M/ejEn2PdyyLXXcM3uZT9M9HyT/96LeBhxFZqfR1xD
w0URzw5DSc/ZNVyZRz96MYcMV+aRK9f8h7/poi+W
      "]]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      5.512586071943019, -15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, 0., -15.377870934402068`}, {5.512586071943019, 
      15.826887910791454`, -15.826887910791454`}, {
      2.5191395626804507`, -15.377870934402068`, 0.}, {
      1.4210854715202004`*^-14, 0., 0.}, {2.5191395626804507`, 
      15.377870934402068`, 0.}, {5.512586071943019, -15.826887910791454`, 
      15.826887910791454`}, {2.5191395626804507`, 0., 15.377870934402068`}, {
      5.512586071943019, 15.826887910791454`, 15.826887910791454`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGBQAWJmIL4a/0HcRlTHQWD6pwr2LIMDMNpvYhdj8SMDhxTX
c1N8WBgPFC/gm/fspcGBzbtyi3bW6DrsV2xyCRHXcZjzb6uv0UmEepg6mL7g
9Vr77U8bO9T6vDRV0Oc8AKPtdmirXnAycjCvzHzSrKnpsO1PaZa+DMuBrVDz
Yebug9oDUw9TB9N36rb+HPVGfYe5t3yO9v/ShtMXVAS//I7SdqjbPH3/uvsG
B2D032V3empiDRyY74bwfFTjPbBn/bMl8v8ND/iIrfR/Ol3XQcbrzGNjN00H
pX2N0az7DOHqYepg+izN1pTLhhs7HOlSsXauEjsAo98lvHlXus3IQfpCyaRd
V5QdlmRs/3t5sfABX6j5MHNh9sDUw9TB9DHtFIoM+WjgsCbg5PNNj9XhtLLp
s9m1bNoOP4T1Jq0XNjwAozmE29incRs4+HowJPztFTrw7so8v9weowOW0Rn6
H3frOtw984rz4m01B7Zz3ZpiiUYHeKHq70DV9UH1lTauYF/3yMgh33GJRqOq
7AEY/XzphWVHXxg5zKhPeVPuK+dQ5zWtVtxbGm4+zFyYPTD1MHUwfRO4Y76I
MBo5BP35fcA8UxlOh/FusnB5puXw1HryNF91wwMw+rNotbfjbn2Hb+eqlr1Q
ED0gzpXRHHzW6MDtxU4Cnx/qOkzv0pvk+FLFoVHZvuvCcSO4epg6mL7gbdzS
h9qNHER1159X3aJwAEZnrloXefyTkYPBubS6Q+/EHNYapvXaZivAzYeZC7MH
pn4dVJ0eVN8NixWza48bOfTxKihOqZGD0wAClIo3
      "]]}, 
    {RGBColor[0., 1., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      14.723457153068136`, -15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, 0., -15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, -15.504431250830306`}, {
      17.580057067612017`, -15.080022883315076`, 0.}, {20., 0., 0.}, {
      17.580057067612017`, 15.080022883315076`, 0.}, {
      14.723457153068136`, -15.504431250830306`, 15.504431250830306`}, {
      17.580057067612017`, 0., 15.080022883315076`}, {14.723457153068136`, 
      15.504431250830306`, 15.504431250830306`}}]}, 
    {RGBColor[1., 0., 0.], AbsolutePointSize[4.], 
     Point3DBox[{{
      2.750318382334857, -11.34778664186926, -11.34778664186926}, {
      4.295953890759721, -14.064858698663144`, -14.064858698663144`}, {
      2.234606302806256, -9.836865786907756, -10.660246056745464`}, {
      2.2346063028062577`, -10.66024605674547, -9.836865786907753}, {
      5.077834711788297, -15.226266698905482`, -15.226266698905482`}, {
      14.548143330104716`, -15.744726030217667`, -15.744726030217667`}, {
      14.020366675430534`, -16.441304473807655`, -16.441304473807655`}, {
      14.709748385679472`, -21.90119521400225, 1.5129386055843472`}, {
      14.70974838567947, 1.5129386055843455`, -21.901195214002254`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.708, -2.587, 1.356}]], "Print",
 CellChangeTimes->{3.6013014888808107`*^9, 3.614709253933695*^9, 
  3.614729110937489*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"},
 CellLabel->"During evaluation of In[143]:="]
}, Open  ]],

Cell[TextData[{
 "A demonstration of the ",
 StyleBox["FixedIlluminationSource", "MB"],
 " function at work.  Rays from this custom source always intercept the same \
points on the lens surface."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "No matter where you position a ",
 StyleBox["FixedIlluminationSource", "MB"],
 ", the rays always intercept the same points on the surface of the lens.  \
This function equips you to test with uniform illumination any system having  \
this entrance pupil."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[{
 "In fact, the function is more general because it has defined ",
 StyleBox["endpts", "MB"],
 " as an input parameter.  To apply this function to a different system, \
illuminate the system with the pattern you want to hold constant, then call \
",
 StyleBox["ReadRays", "MB"],
 " to find the surface intercepts.  You then use these intercepts as the ",
 StyleBox["endpts", "MB"],
 " argument to ",
 StyleBox["FixedIlluminationSource", "MB"],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2.2 Distant Sources, Lasers, and Beam Divergence", "Subsection",
 CellTags->{
  "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
   "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "If you consider a source as being at infinity, then, as far as your system \
is concerned, its rays are all parallel.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " presents a suite of parallel ray sources for such cases: ",
 StyleBox["GridOfRays", "MB"],
 ", ",
 StyleBox["CircleOfRays", "MB"],
 ", ",
 StyleBox["LineOfRays", "MB"],
 ", and so on."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell["\<\
Sometimes the source is distant, but not at infinity.  In these situations \
you need a mechanism to express the divergence of the light as it enters your \
system, without including the entire path from its point of origin.  You care \
only about the local divergence near the entrance of your system.\
\>", "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "Lasers present a similar dilemma.  Laser light exhibits beam divergence.  \
In the far field, laser light appears to emerge from a virtual point.  This \
virtual source point is the center of the \"beam waist\" in the lasing \
cavity.  However, you normally want to model laser light with a certain \
divergence only as it approaches your system.  The task of modeling the beam \
waist would require an intimate knowledge of the laser.  It would also \
introduce unwanted complexity into your project. In many instances, you can \
simply use the built-in ",
 StyleBox["GaussianBeam", "Input"],
 " source to model such divergence issues for lasers. However, ",
 StyleBox["GaussianBeam", "Input"],
 " may not be appropriate for all applications."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "As an alternative to ",
 StyleBox["GaussianBeam", "Input"],
 " you can instead model distant, diverging sources with the use of the ",
 StyleBox["BirthPoint", "MB"],
 " and ",
 StyleBox["StartAtBirthPoint", "MB"],
 " options in tandem for any of the built-in source functions.  When you \
define a ",
 StyleBox["BirthPoint", "MB"],
 " source with ",
 StyleBox["StartAtBirthPoint\[Rule]False", "MB"],
 ", ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " still positions the source at the ",
 StyleBox["BirthPoint", "MB"],
 ".  However, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " handles the rays differently.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " considers the light only in the vicinity of the origin.  More precisely, \
the rays do not start at the ",
 StyleBox["BirthPoint", "MB"],
 " but from the principal coordinate plane orthogonal to the optic axis.  The \
modified ray trajectories are colinear with the old but originate from this \
plane.  (Therefore when you set ",
 StyleBox["StartAtBirthPoint\[Rule]False", "MB"],
 ", you should position the ",
 StyleBox["BirthPoint", "MB"],
 " behind this plane.)  You may view this technique as a way to turn far-away \
point sources into near-field planar sources with characteristic divergence.  \
Once configured in this way, the diverging source can be moved and rotated \
arbitrarily like any other source."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "Here is a standard light source shooting rays from its ",
 StyleBox["BirthPoint", "MB"],
 " because ",
 StyleBox["StartAtBirthPoint\[Rule]True", "MB"],
 " has been set.  This ",
 StyleBox["divSource", "MB"],
 " is a point source.  The eventual system aperture is represented, for the \
time being, by a simple ",
 StyleBox["Baffle", "MB"],
 " placed 50 units away from the origin.  There is then a total path length \
of 100 units from the source to the baffle."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"divSource", " ", "=", " ", 
   RowBox[{"WedgeOfRays", "[", 
    RowBox[{"10", ",", 
     RowBox[{"BirthPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "50"}], ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"StartAtBirthPoint", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"divSource", ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Baffle", "[", 
          RowBox[{"{", 
           RowBox[{"20", ",", "20"}], "}"}], "]"}], ",", "50"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], ";"}]}], "Input",
 GeneratedCell->False,
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"In[144]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{50., -10.}, {50., 10.}, {50., 10.}, {50., -10.}, {
      50., -10.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -10.}, {50., 10.}, {50., 10.}, {50., -10.}, {
       50., -10.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-50., 0.}, {50., -10.000000000000002`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{-50., 0.}, {50.000000000000014`, -6.000000000000001}}]}, 
     {Arrowheads[Small], ArrowBox[{{-50., 0.}, {50., -2.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-50., 0.}, {50., 2.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-50., 0.}, {50.000000000000014`, 6.000000000000001}}]}, 
     {Arrowheads[Small], ArrowBox[{{-50., 0.}, {50., 10.000000000000002`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., -10.000000000000002`}, {
      50.000000000000014`, -6.000000000000001}, {50., -2.}, {50., 2.}, {
      50.000000000000014`, 6.000000000000001}, {50., 10.000000000000002`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013014890937233`*^9, 3.614709254110474*^9, 
  3.614729111200139*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"During evaluation of In[144]:="]
}, Open  ]],

Cell[TextData[{
 "With the option setting ",
 StyleBox["StartAtBirthPoint\[Rule]True", "MB"],
 ", analysis and graphics encompass a large area that includes the source of \
the light."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "The ",
 StyleBox["BirthPoint", "MB"],
 " at ",
 StyleBox["{-50,0,0}", "MB"],
 " is far from the intended system input plane.  The source indeed exhibits \
the divergence you need at the input plane, but incorporates a long optical \
path that you do not.  To remedy this situation, set ",
 StyleBox["StartAtBirthPoint \[Rule] False", "MB"],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"divSource", " ", "=", " ", 
   RowBox[{"WedgeOfRays", "[", 
    RowBox[{"10", ",", 
     RowBox[{"BirthPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "50"}], ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"StartAtBirthPoint", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"divSource", ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Baffle", "[", 
          RowBox[{"{", 
           RowBox[{"20", ",", "20"}], "}"}], "]"}], ",", "50"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], ";"}]}], "Input",
 GeneratedCell->False,
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"In[146]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{50., -10.}, {50., 10.}, {50., 10.}, {50., -10.}, {
      50., -10.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -10.}, {50., 10.}, {50., 10.}, {50., -10.}, {
       50., -10.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-0.24814048950054157`, -4.975185951049946}, {50., -10.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{-0.08975772671106824, -2.9946145363973358`}, {50., -6.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-0.009997000999647374, -0.9998000599800071}, {50., -2.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-0.009997000999647374, 0.9998000599800071}, {50., 2.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-0.08975772671106824, 2.9946145363973358`}, {50., 6.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-0.24814048950054157`, 4.975185951049946}, {50., 10.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., -10.}, {50., -6.}, {50., -2.}, {50., 2.}, {50., 6.}, {
      50., 10.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301489208066*^9, 3.614709254223319*^9, 
  3.6147291113119164`*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"During evaluation of In[146]:="]
}, Open  ]],

Cell[TextData[{
 "With the option setting ",
 StyleBox["StartAtBirthPoint\[Rule]False", "MB"],
 ", analysis and graphics need only include the vicinity of your system."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " now recognizes that the system begins at the origin instead of ",
 StyleBox["{-50,0,0}", "MB"],
 ".  For all intents and purposes, ",
 StyleBox["divSource", "MB"],
 " now represents a broad, planar source with characteristic divergence.  In \
fact you can orient ",
 StyleBox["divSource", "MB"],
 " in 3-space just like any other source."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[{
 "Here is a diverging beam source spotlighting a cube from two positions.  \
Use a ",
 StyleBox["ConeOfRays", "MB"],
 " with ",
 StyleBox["StartAtBirthPoint\[Rule]False", "MB"],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"beamSource", "=", 
   RowBox[{"ConeOfRays", "[", 
    RowBox[{"10", ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "15"}], ",", 
     RowBox[{"BirthPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "30"}], ",", "0", ",", "30"}], "}"}]}], ",", 
     RowBox[{"StartAtBirthPoint", "\[Rule]", "False"}], ",", 
     RowBox[{"CoordinateSystem", "\[Rule]", "CarthesianCoordinates"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"beamSource", ",", 
      RowBox[{"Move", "[", 
       RowBox[{"beamSource", ",", 
        RowBox[{"{", 
         RowBox[{"25", ",", "0", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "0"}], "]"}], ",", 
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Boundary", "[", 
         RowBox[{"20", ",", 
          RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"30", ",", "0", ",", 
          RowBox[{"-", "15"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "0"}], "]"}], ",", 
      RowBox[{"Boundary", "[", 
       RowBox[{"50", ",", 
        RowBox[{"GraphicDesign", "\[Rule]", "Off"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.479"}], ",", 
       RowBox[{"-", "2.959"}], ",", "0.713"}], "}"}]}]}], "]"}], 
  ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"In[148]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{50., 10., -25.}, {50., -10., -25.}, {50., -10., -5.}, {
      50., 10., -5.}, {50., 10., -25.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{50., 10., -25.}, {50., -10., -25.}, {50., -10., -5.}, {50., 
       10., -5.}, {50., 10., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{50., -10., -25.}, {30., -10., -25.}, {30., -10., -5.}, {
        50., -10., -5.}, {50., -10., -25.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{50., -10., -25.}, {30., -10., -25.}, {30., -10., -5.}, {
         50., -10., -5.}, {50., -10., -25.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{30., -10., -25.}, {30., 10., -25.}, {30., 10., -5.}, {
          30., -10., -5.}, {30., -10., -25.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{30., -10., -25.}, {30., 10., -25.}, {30., 10., -5.}, {
           30., -10., -5.}, {30., -10., -25.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{30., 10., -25.}, {50., 10., -25.}, {50., 
            10., -5.}, {30., 10., -5.}, {30., 10., -25.}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{30., 10., -25.}, {50., 10., -25.}, {50., 10., -5.}, {
             30., 10., -5.}, {30., 10., -25.}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{50., -10., -25.}, {50., 10., -25.}, {30., 
              10., -25.}, {30., -10., -25.}, {50., -10., -25.}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], 
              Line3DBox[{{50., -10., -25.}, {50., 10., -25.}, {30., 
               10., -25.}, {30., -10., -25.}, {50., -10., -25.}}], 
              {GrayLevel[0.5], EdgeForm[None], 
               Polygon3DBox[{{50., 10., -5.}, {50., -10., -5.}, {
                30., -10., -5.}, {30., 10., -5.}, {50., 10., -5.}}], 
               {GrayLevel[0], AbsoluteThickness[0.5], 
                Line3DBox[{{50., 10., -5.}, {50., -10., -5.}, {
                 30., -10., -5.}, {30., 10., -5.}, {50., 
                 10., -5.}}]}}}}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxVlAs0VHkcx2e8V0PGYE+eQwp1Is/xKPfnNZxFtTq7S8ejLax2w2IjhZHW
1soSI2+rVHsatlaHhHD/ea1BpTWJZUVShhahvMZYOXPvOfs/53////+5n/M7
3/P/fe7VPxbpEyJNoVB0N6bUxvy4v3TxcnBgcCdemmOY8mSIAZIzRvnfUANi
J1Lv2vr74iRmaHqtvKlDFfrx4hHm0jyWQBc7v1zfB9W8ojT/RX0Jb4fc8y24
+ztFmGWlj+9wIA16LV79qa1Dlbx3hMcZhQ3jLZoQKogsSs+yQS5KJ48bcaSB
23KLwq9fwSj8Ia8nZbJAlfA3xlZlKmoVIOrmSoFnohU617fY7FQoA+GF1BI5
k5d4aydL+CJPjqxfUiP7dULdLJ4dFK0vp2yFeMn/bs0NogKNyeu7Fi2Lpq1R
Q1y7NMmL1z8OBlIMC85b/tIaJXJNluYuvccsdw3e15xQQTu8bHY5565iRJ6J
JceHu0yZqPVwkbKbni3itWsdysMEWE+LyunpVgbiD+asMZLeYGn6a7Unlu3B
ULZ1OpNrgIj74fhlPF0++xpvqdry9qkmA03H15i5UAU4cd+HIL1U5zID5cTx
tiiUzeJsj3HXqo4lPGnylGFupTKii45k5T6ZJ/nJzTwqaKEyu20qRR5x1VNv
PRBTUAa31P/7K1KINhe3k39MTPKym08ZJDRjPaX50FH8d8n5h+Wl0eDUyCla
9zD+K2/WcnsBVZIXNbRv3ucIPgRajfNjDMSz5rf1+kohYVCK67DgA+YsvqGQ
zKcgon7pZr+WMOY9xe4wWQa6c/7nnjDxGh4476Xe9OknQHmeqrK7aZnMw9/0
QRFi70D2ozolpM5cyYk4M4cHPVu4/VkWHYCiLawtEZL8gz+CvI+4qUJXz/Xq
VVcKmhm2cWF12QLhs4FzdnzWCUNJf10lq65kVUOVvklHG5/bAeHzah5DW4az
E4zk2zKHytwAc93zlX2oDogkXvxoYjlwvdseCJ/v0ZbN3d2NwaL+aJ+bqTuo
1tPDQ4QaZP1b58Lfvop0IH0GC1ZvVZgJ2HNi1db3eYDih/Nf5CrIkXzPSqCt
B9eB9PnunPfK4k0TUBRxYiJPe0C5wmjCftVpnODVK9cezu12IH1OUNo7U/LO
GByLT5642uUOxmEebHSBjgjetiDFDPfdyC/xOZXPduuINoIFWs3nGVFsUIs7
+E5+QpPktSIhQHzIDgifG70HsNG4HdAzOZja/NgVfCrGQBCii6QkvNUvMeZM
L1sgfDb3Snn9Pmg7XDybJdTAXMBDuzkzx18bEd9ZQsXdrh9iWED4nHRVsEfp
J33QbBLkq4qdgLVSNzOqqUHWPxAwk2Y8YgOEz01U88HfLJngUJj41xkTJyh/
JAo/wFIk82fNzaSrl9oA4bN5hXxohKUe6Nrdj5V6BFDTT9+rljqOE/U9B9gX
xqttgPD5RfLtVaxID+T+Pj7/ZgrA4MqzCAaVQv4n2r5ZjN7GZAHhM9NtpsS+
gwkHaFIcq1QnyGV7HuQO0cn+rgdUavj1s4DwWYRFRBmGGgBWwP7WJ9sZVP3+
iSgu30by/wHoVVcL
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQA2JmBnQg4gBj1Qj+c3r038Zhy8rZXTHfFaHilgcgtJ3D
ub5Ze54elnJIu5I/u2ei2QFGqPiSx79ZVu/gcChc+mumd60JXP3cbayJNTs/
7J8UX6TIxocQ//cfBIQPcGWkTP8ZZgo358UPu4NaegoHjgTP5nOVtzjQpfh3
R+ZPKwcV1iPv+icrHUB1DwNDgEPPfNkJwgemlK/k5lj0YT9M/BXYHIEDXzZM
Ovq6iR2unhVMshx4qW9+kSdIECp+YM8xsDsf7L/jIL3382NhuPr5YH/9sFfY
ynUmgxUhfhIcDlwOZescJp3dyQsX370+3jfKVcjh9IXFW367MEDFXaDhKAel
RQ6osx/tv7PI1cHeRTfcKk3W4Q80PIx2JVxz1XN3ENolmJv6Ugyu3qq+TOS/
jYcD17fm0GkcbHBxrj/1xfkVHg6rOB7W2Aq92w8Tt5uTk7ngtLuDRoaH24F2
mD9FDnzh2RbYV+jmIFLu/5H9hRRc/MKr262Hzrk4BK1+7HAlVe4AE1S8o3ri
SzF7ZwcPmUP9U2JkDsDiTWrflRlC/xwdzH/tfP9QSgyu3npW7aUqTUeHVWf/
5PqZc8HNl7PcXsZ01sFh2w1BA5HWp/th6tluJX9+/trBQWnq1TxhRgZ4uvDj
Yao3aXV0mObm7T/5jiDcv/Yz3bKCJjk5CEXezZuzShIuDgAXG/lE
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All,
  ViewPoint:>{-1.479, -2.959, 0.713}]], "Print",
 CellChangeTimes->{3.6013014897120857`*^9, 3.61470925473308*^9, 
  3.614729111817395*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"},
 CellLabel->"During evaluation of In[148]:="]
}, Open  ]],

Cell[TextData[{
 "Divergent beams created by the option setting ",
 StyleBox["StartAtBirthPoint\[Rule]False", "MB"],
 ".  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " omits the light source birth points from its analysis and graphics."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2.3 Laser Cavities and MoveAligned", "Subsection",
 CellTags->{
  "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
   "PR4.2.3"}],

Cell[TextData[{
 "The ",
 StyleBox["MoveAligned", "MB"],
 " function, introduced previously in Section 2.4, is well-suited for \
designing laser cavities.  The prism elements reroute the light path in \
unpredictable ways.  ",
 StyleBox["MoveAligned", "MB"],
 " tracks these zig-zags."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 "The following example demonstrates laser cavity design; it also shows a way \
to employ units in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ".  The base unit in this example is the millimeter, so the variable",
 StyleBox[" ",
  FontSlant->"Italic"],
 StyleBox["mm", "MB",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 " is defined as 1.0.  Other units are then scaled relative to this value.  \
Note that all of the ",
 StyleBox["Move", "MB"],
 " directives in the following effect only orientation changes.  The \
translation terms are zero."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "mm", ",", "cm", ",", "m1", ",", "m2", ",", "m3", ",", "m4", ",", "r1", 
    ",", "r2", ",", "r3", ",", "r4", ",", "theta1", ",", "theta2", ",", "p1", 
    ",", "p2", ",", "p3", ",", "p4", ",", "system"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mm", " ", "=", " ", "1."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cm", " ", "=", " ", 
   RowBox[{"10.", " ", "mm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"theta1", "=", "10"}], " ", ";"}], "\n", 
 RowBox[{
  RowBox[{"theta2", " ", "=", "5"}], " ", ";"}], "\n", 
 RowBox[{
  RowBox[{"theta3", " ", "=", " ", "15"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Tweeter", " ", "=", " ", 
   RowBox[{"SphericalMirror", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "20"}], " ", "cm"}], ",", 
     RowBox[{"2", " ", "cm"}], ",", 
     RowBox[{"6", " ", "mm"}], ",", "\"\<Tweeter\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"LFM", " ", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"SphericalMirror", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "20"}], " ", "cm"}], ",", 
       RowBox[{"2", " ", "cm"}], ",", 
       RowBox[{"6", " ", "mm"}], ",", "\"\<LFM\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{".5", " ", "theta1"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"OC", " ", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"BeamSplitter", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"70", ",", "30"}], "}"}], ",", 
       RowBox[{"2", " ", "cm"}], ",", 
       RowBox[{"6", " ", "mm"}], ",", "\"\<OC\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", ".5"}], " ", "theta1"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"UFM", " ", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"SphericalMirror", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "20"}], " ", "cm"}], ",", 
       RowBox[{"1", " ", "cm"}], ",", 
       RowBox[{"6", " ", "mm"}], ",", "\"\<UFM\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", ".5"}], " ", "theta3"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AC", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"RhomboidPrism", "[", 
      RowBox[{"Automatic", ",", 
       RowBox[{"1", " ", "cm"}], ",", " ", 
       RowBox[{"2", " ", "cm"}], ",", "\"\<AC\>\""}], "]"}], ",", "0", ",", 
     RowBox[{"TwistAngle", "\[Rule]", "180"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Diode", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"RhomboidPrism", "[", 
      RowBox[{"Automatic", ",", 
       RowBox[{"1", " ", "cm"}], ",", " ", 
       RowBox[{"2", " ", "cm"}], ",", "\"\<Diode\>\""}], "]"}], ",", "0", ",", 
     RowBox[{"TwistAngle", "\[Rule]", "180"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Rhomb", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"RhomboidPrism", "[", 
      RowBox[{"Automatic", ",", 
       RowBox[{"1", " ", "cm"}], ",", " ", 
       RowBox[{"2", " ", "cm"}], ",", "\"\<Rhomb\>\""}], "]"}], ",", "0", ",", 
     RowBox[{"TwistAngle", "\[Rule]", "180"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BRF", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"RhomboidPrism", "[", 
      RowBox[{"Automatic", ",", 
       RowBox[{"1", " ", "cm"}], ",", " ", 
       RowBox[{"2", " ", "cm"}], ",", "\"\<BRF\>\""}], "]"}], ",", "0", ",", 
     RowBox[{"TwistAngle", "\[Rule]", "180"}]}], "]"}]}], ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"In[150]:="],

Cell["Definitions for a laser cavity design.", "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 StyleBox["MoveAligned", "MB"],
 " will place every component except the final ",
 StyleBox["Tweeter", "MB"],
 ".  The spacings between components are defined as separate variables.  \
These might change several times during design iterations."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"s1", "=", 
   RowBox[{"30", " ", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"20", " ", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s3", "=", 
   RowBox[{"4", " ", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s4", "=", 
   RowBox[{"5", " ", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s5", " ", "=", " ", 
   RowBox[{"50", " ", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s6", " ", "=", " ", 
   RowBox[{"5", "cm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s7", "=", 
   RowBox[{"35", " ", "cm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"partialcavity", " ", "=", " ", 
  RowBox[{"MoveAligned", "[", 
   RowBox[{
    RowBox[{"Move", "[", 
     RowBox[{
      RowBox[{"SingleRay", "[", "]"}], ",", 
      RowBox[{"15", " ", "cm"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "s1", ",", " ", "BRF", ",", " ", "s2", " ", ",", " ", "OC", ",", " ", 
      "s3", ",", " ", "Rhomb", ",", " ", "s4", ",", "Diode", ",", " ", "s5", 
      ",", "UFM", ",", " ", "s6", ",", "AC", ",", " ", "s7", " ", ",", " ", 
      "LFM"}], "}"}]}], "]"}]}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"In[164]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"BRF\"\>", ",", "450.`", ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"OC\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"659.1862154371977`", ",", 
          RowBox[{"-", "3.9543388611028942`"}]}], "}"}], ",", 
        RowBox[{"-", "4.999999999999999`"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"Rhomb\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"705.1934363220911`", ",", 
          RowBox[{"-", "4.133769426549076`"}]}], "}"}], ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"Diode\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"764.3796517592887`", ",", 
          RowBox[{"-", "8.08810828765197`"}]}], "}"}], ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"UFM\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"1273.5658671964864`", ",", 
          RowBox[{"-", "12.042447148754864`"}]}], "}"}], ",", 
        RowBox[{"-", "7.500000000000001`"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"AC\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"1225.2695758820328`", ",", "0.8985051063711769`"}], "}"}], 
        ",", "141.69968119308808`", ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"LFM\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"879.3457921522568`", ",", "97.68233643165254`"}], "}"}], 
        ",", "170.00000000000003`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.563404241435363*^9, 3.5634581351697893`*^9, 
  3.564487580254177*^9, 3.566100672314208*^9, 3.601301240543622*^9, 
  3.601301492428187*^9, 3.614709257663293*^9, 3.614729114364256*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"Out[171]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " echoes the ",
 StyleBox["Move", "MB"],
 " equivalents for this usage of ",
 StyleBox["MoveAligned", "MB"],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 "Now propagate a ",
 StyleBox["SingleRay", "MB"],
 " through the ",
 StyleBox["partialcavity", "MB"],
 " to determine where the ",
 StyleBox["Tweeter", "MB"],
 " belongs.  This component, a spherical mirror, will complete the cavity."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"system", "=", 
   RowBox[{"AnalyzeSystem", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SingleRay", "[", "]"}], ",", "partialcavity", ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"75", " ", "cm"}], ",", 
          RowBox[{"30", " ", "cm"}], ",", 
          RowBox[{"GraphicDesign", "\[Rule]", "Off"}]}], "]"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"In[172]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460., 6.581231607541547}, {440., -6.581231607541547}, {
       440., -6.581231607541547}, {460., 6.581231607541547}, {460., 
       6.581231607541547}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{449.184441804226, -10.536737737581726`}, {
       440., -6.5812316075415485`}, {440., -6.5812316075415485`}, {
       449.184441804226, -10.536737737581726`}, {
       449.184441804226, -10.536737737581726`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{469.184441804226, 2.625725477501369}, {
       449.184441804226, -10.536737737581724`}, {
       449.184441804226, -10.536737737581724`}, {469.184441804226, 
       2.625725477501369}, {469.184441804226, 2.625725477501369}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{469.184441804226, 2.625725477501371}, {460., 
       6.5812316075415485`}, {460., 6.5812316075415485`}, {469.184441804226, 
       2.625725477501371}, {469.184441804226, 2.625725477501371}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460.0027038895489, 6.585511099877827}, {
       439.992703889549, -6.583533346812808}, {
       449.1817379146771, -10.541017229918005`}, {469.19173791467705`, 
       2.6280272167726313`}, {460.0027038895489, 6.585511099877827}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460.0027038895489, 6.585511099877827}, {
       439.992703889549, -6.583533346812808}, {
       449.1817379146771, -10.541017229918005`}, {469.19173791467705`, 
       2.6280272167726313`}, {460.0027038895489, 6.585511099877827}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{658.3146580097211, -13.916285842020349`}, {
      664.2918261982716, -14.4392202985063}, {
      664.5823453407637, -11.11857130486715}, {
      658.6051771522133, -10.595636848381199`}, {
      658.3146580097211, -13.916285842020349`}}], 
     PolygonBox[{{658.6051771522133, -10.595636848381199`}, {
      664.5823453407637, -11.11857130486715}, {
      664.872864483256, -7.797922311227998}, {
      658.8956962947055, -7.274987854742047}, {
      658.6051771522133, -10.595636848381199`}}], 
     PolygonBox[{{658.8956962947055, -7.274987854742047}, {
      664.872864483256, -7.797922311227998}, {
      665.1633836257481, -4.477273317588845}, {
      659.1862154371977, -3.9543388611028942`}, {
      658.8956962947055, -7.274987854742047}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      665.1633836257481, -4.4772733175888435`}, {
      665.4539027682403, -1.1566243239496927`}, {
      659.4767345796898, -0.6336898674637435}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4767345796898, -0.6336898674637435}, {
      665.4539027682403, -1.1566243239496927`}, {665.7444219107325, 
      2.16402466968946}, {659.7672537221821, 2.6869591261754073`}, {
      659.4767345796898, -0.6336898674637435}}], 
     PolygonBox[{{659.7672537221821, 2.6869591261754073`}, {665.7444219107325,
       2.164024669689459}, {666.0349410532247, 5.48467366332861}, {
      660.0577728646742, 6.007608119814558}, {659.7672537221821, 
      2.6869591261754073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{658.3146580097211, -13.916285842020349`}, {
       658.6051771522133, -10.595636848381199`}, {
       658.8956962947055, -7.274987854742047}, {
       659.1862154371977, -3.9543388611028942`}, {
       659.4767345796898, -0.6336898674637435}, {659.7672537221821, 
       2.6869591261754073`}, {660.0577728646742, 6.007608119814561}, {
       666.0349410532247, 5.4846736633286115`}, {665.7444219107325, 
       2.1640246696894607`}, {665.4539027682403, -1.156624323949691}, {
       665.1633836257481, -4.4772733175888435`}, {
       664.872864483256, -7.797922311227994}, {
       664.5823453407637, -11.118571304867146`}, {
       664.2918261982716, -14.4392202985063}, {
       658.3146580097211, -13.916285842020349`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.954338861102894}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.954338861102894}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.954338861102894}, {
        659.1862154371977, -3.954338861102894}}], 
       PolygonBox[{{659.1862154371977, -3.954338861102894}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.1862154371977, -3.954338861102894}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028933`}, {
        665.1633836257481, -4.4772733175888435`}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.1862154371977, -3.9543388611028933`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028933`}, {
        665.1633836257481, -4.4772733175888435`}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.954338861102893}, {
        659.1862154371977, -3.9543388611028933`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         659.1862154371977, -3.9543388611028942`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.4767345796898, -0.6336898674637426}, {
      659.4668353799623, -0.7468382381060339}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4767345796898, -0.6336898674637426}, {659.7672537221821,
       2.686959126175409}, {659.7474553227269, 2.4606623848908264`}, {
      659.4668353799623, -0.7468382381060339}, {
      659.4767345796898, -0.6336898674637426}}], 
     PolygonBox[{{659.7672537221821, 2.686959126175409}, {660.0577728646742, 
      6.007608119814561}, {660.0280752654913, 5.668163007887689}, {
      659.7474553227269, 2.4606623848908264`}, {659.7672537221821, 
      2.686959126175409}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.4668353799623, -0.7468382381060339}, {
      659.4378123948816, -1.0785724755601578`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4668353799623, -0.7468382381060339}, {659.7474553227269,
       2.4606623848908264`}, {659.6894093525655, 1.7971939099825787`}, {
      659.4378123948816, -1.0785724755601578`}, {
      659.4668353799623, -0.7468382381060339}}], 
     PolygonBox[{{659.7474553227269, 2.4606623848908264`}, {660.0280752654913,
       5.668163007887689}, {659.9410063102495, 4.672960295525316}, {
      659.6894093525655, 1.7971939099825787`}, {659.7474553227269, 
      2.4606623848908264`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.4378123948816, -1.0785724755601578`}, {
      659.3916434929184, -1.6062854397603652`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4378123948816, -1.0785724755601578`}, {
      659.6894093525655, 1.7971939099825787`}, {659.5970715486392, 
      0.7417679815821638}, {659.3916434929184, -1.6062854397603652`}, {
      659.4378123948816, -1.0785724755601578`}}], 
     PolygonBox[{{659.6894093525655, 1.7971939099825787`}, {659.9410063102495,
       4.672960295525316}, {659.8024996043599, 3.089821402924693}, {
      659.5970715486392, 0.7417679815821638}, {659.6894093525655, 
      1.7971939099825787`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.3916434929184, -1.6062854397603652`}, {
      659.3314750084438, -2.294014364283318}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.3916434929184, -1.6062854397603652`}, {
      659.5970715486392, 0.7417679815821638}, {
      659.4767345796898, -0.6336898674637417}, {
      659.3314750084438, -2.294014364283318}, {
      659.3916434929184, -1.6062854397603652`}}], 
     PolygonBox[{{659.5970715486392, 0.7417679815821638}, {659.8024996043599, 
      3.089821402924693}, {659.621994150936, 1.0266346293558342`}, {
      659.4767345796898, -0.6336898674637417}, {659.5970715486392, 
      0.7417679815821638}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.3314750084438, -2.294014364283318}, {
      659.2614073242415, -3.094891659448562}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.3314750084438, -2.294014364283318}, {
      659.4767345796898, -0.6336898674637417}, {
      659.3365992112854, -2.2354444577942294`}, {
      659.2614073242415, -3.094891659448562}, {
      659.3314750084438, -2.294014364283318}}], 
     PolygonBox[{{659.4767345796898, -0.6336898674637417}, {659.621994150936, 
      1.0266346293558342`}, {659.4117910983292, -1.3759972561398968`}, {
      659.3365992112854, -2.2354444577942294`}, {
      659.4767345796898, -0.6336898674637417}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.2614073242415, -3.094891659448562}, {
      659.1862154371977, -3.9543388611028933`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.2614073242415, -3.094891659448562}, {
      659.3365992112854, -2.2354444577942294`}, {
      659.1862154371977, -3.9543388611028925`}, {
      659.1862154371977, -3.9543388611028933`}, {
      659.2614073242415, -3.094891659448562}}], 
     PolygonBox[{{659.3365992112854, -2.2354444577942294`}, {
      659.4117910983292, -1.3759972561398968`}, {
      659.1862154371977, -3.9543388611028916`}, {
      659.1862154371977, -3.9543388611028925`}, {
      659.3365992112854, -2.2354444577942294`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1110235501538, -4.8137860627572255`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.954338861102894}, {
      659.03583166311, -5.673233264411557}, {
      659.1110235501538, -4.8137860627572255`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.1862154371977, -3.954338861102894}, {
      659.1862154371977, -3.954338861102894}, {
      658.9606397760662, -6.532680466065889}, {
      659.03583166311, -5.673233264411557}, {
      659.1862154371977, -3.954338861102894}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.1110235501538, -4.8137860627572255`}, {
      659.0409558659516, -5.61466335792247}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.1110235501538, -4.8137860627572255`}, {
      659.03583166311, -5.673233264411557}, {
      658.8956962947055, -7.2749878547420455`}, {
      659.0409558659516, -5.61466335792247}, {
      659.1110235501538, -4.8137860627572255`}}], 
     PolygonBox[{{659.03583166311, -5.673233264411557}, {
      658.9606397760662, -6.532680466065889}, {
      658.7504367234594, -8.93531235156162}, {
      658.8956962947055, -7.2749878547420455`}, {
      659.03583166311, -5.673233264411557}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.0409558659516, -5.61466335792247}, {
      658.980787381477, -6.302392282445423}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.0409558659516, -5.61466335792247}, {
      658.8956962947055, -7.2749878547420455`}, {
      658.7753593257562, -8.650445703787952}, {
      658.980787381477, -6.302392282445423}, {
      659.0409558659516, -5.61466335792247}}], 
     PolygonBox[{{658.8956962947055, -7.2749878547420455`}, {
      658.7504367234594, -8.93531235156162}, {
      658.5699312700355, -10.998499125130481`}, {
      658.7753593257562, -8.650445703787952}, {
      658.8956962947055, -7.2749878547420455`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.980787381477, -6.302392282445423}, {
      658.9346184795138, -6.830105246645631}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.980787381477, -6.302392282445423}, {
      658.7753593257562, -8.650445703787952}, {
      658.6830215218299, -9.705871632188368}, {
      658.9346184795138, -6.830105246645631}, {
      658.980787381477, -6.302392282445423}}], 
     PolygonBox[{{658.7753593257562, -8.650445703787952}, {
      658.5699312700355, -10.998499125130481`}, {
      658.4314245641459, -12.581638017731104`}, {
      658.6830215218299, -9.705871632188368}, {
      658.7753593257562, -8.650445703787952}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.9346184795138, -6.83010524664563}, {
      658.9055954944331, -7.161839484099755}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.9346184795138, -6.83010524664563}, {
      658.6830215218299, -9.705871632188366}, {
      658.6249755516685, -10.369340107096614`}, {
      658.9055954944331, -7.161839484099755}, {
      658.9346184795138, -6.83010524664563}}], 
     PolygonBox[{{658.6830215218299, -9.705871632188366}, {
      658.4314245641459, -12.581638017731102`}, {
      658.344355608904, -13.576840730093474`}, {
      658.6249755516685, -10.369340107096614`}, {
      658.6830215218299, -9.705871632188366}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.9055954944331, -7.161839484099755}, {
      658.8956962947055, -7.2749878547420455`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.9055954944331, -7.161839484099755}, {
      658.6249755516685, -10.369340107096614`}, {
      658.6051771522133, -10.595636848381197`}, {
      658.8956962947055, -7.2749878547420455`}, {
      658.9055954944331, -7.161839484099755}}], 
     PolygonBox[{{658.6249755516685, -10.369340107096614`}, {
      658.344355608904, -13.576840730093474`}, {
      658.3146580097211, -13.916285842020349`}, {
      658.6051771522133, -10.595636848381197`}, {
      658.6249755516685, -10.369340107096614`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.8956962947055, -7.2749878547420455`}, {
      658.9055954944331, -7.161839484099755}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.8956962947055, -7.2749878547420455`}, {
      658.6051771522133, -10.595636848381197`}, {
      658.6249755516685, -10.369340107096615`}, {
      658.9055954944331, -7.161839484099755}, {
      658.8956962947055, -7.2749878547420455`}}], 
     PolygonBox[{{658.6051771522133, -10.595636848381197`}, {
      658.3146580097211, -13.916285842020349`}, {
      658.344355608904, -13.576840730093476`}, {
      658.6249755516685, -10.369340107096615`}, {
      658.6051771522133, -10.595636848381197`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.9055954944331, -7.1618394840997555`}, {
      658.9346184795138, -6.830105246645632}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.9055954944331, -7.1618394840997555`}, {
      658.6249755516685, -10.369340107096617`}, {
      658.6830215218299, -9.705871632188368}, {
      658.9346184795138, -6.830105246645632}, {
      658.9055954944331, -7.1618394840997555`}}], 
     PolygonBox[{{658.6249755516685, -10.369340107096617`}, {
      658.344355608904, -13.576840730093478`}, {
      658.4314245641459, -12.581638017731105`}, {
      658.6830215218299, -9.705871632188368}, {
      658.6249755516685, -10.369340107096617`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.9346184795138, -6.830105246645632}, {
      658.980787381477, -6.302392282445424}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.9346184795138, -6.830105246645632}, {
      658.6830215218299, -9.705871632188368}, {
      658.7753593257562, -8.650445703787954}, {
      658.980787381477, -6.302392282445424}, {
      658.9346184795138, -6.830105246645632}}], 
     PolygonBox[{{658.6830215218299, -9.705871632188368}, {
      658.4314245641459, -12.581638017731105`}, {
      658.5699312700355, -10.998499125130483`}, {
      658.7753593257562, -8.650445703787954}, {
      658.6830215218299, -9.705871632188368}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      658.980787381477, -6.302392282445425}, {
      659.0409558659516, -5.614663357922471}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{658.980787381477, -6.302392282445425}, {
      658.7753593257562, -8.650445703787954}, {
      658.8956962947055, -7.274987854742049}, {
      659.0409558659516, -5.614663357922471}, {
      658.980787381477, -6.302392282445425}}], 
     PolygonBox[{{658.7753593257562, -8.650445703787954}, {
      658.5699312700355, -10.998499125130484`}, {
      658.7504367234594, -8.935312351561626}, {
      658.8956962947055, -7.274987854742049}, {
      658.7753593257562, -8.650445703787954}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.0409558659516, -5.614663357922471}, {
      659.1110235501538, -4.813786062757228}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.0409558659516, -5.614663357922471}, {
      658.8956962947055, -7.274987854742049}, {
      659.03583166311, -5.673233264411563}, {
      659.1110235501538, -4.813786062757228}, {
      659.0409558659516, -5.614663357922471}}], 
     PolygonBox[{{658.8956962947055, -7.274987854742049}, {
      658.7504367234594, -8.935312351561626}, {
      658.9606397760662, -6.532680466065898}, {
      659.03583166311, -5.673233264411563}, {
      658.8956962947055, -7.274987854742049}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.1110235501538, -4.813786062757228}, {
      659.1862154371977, -3.954338861102898}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.1110235501538, -4.813786062757228}, {
      659.03583166311, -5.673233264411563}, {
      659.1862154371977, -3.9543388611029013`}, {
      659.1862154371977, -3.954338861102898}, {
      659.1110235501538, -4.813786062757228}}], 
     PolygonBox[{{659.03583166311, -5.673233264411563}, {
      658.9606397760662, -6.532680466065898}, {
      659.1862154371977, -3.954338861102905}, {
      659.1862154371977, -3.9543388611029013`}, {
      659.03583166311, -5.673233264411563}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028947`}, {
      659.2614073242415, -3.094891659448564}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028947`}, {
      659.1862154371977, -3.9543388611028956`}, {
      659.3365992112854, -2.235444457794234}, {
      659.2614073242415, -3.094891659448564}, {
      659.1862154371977, -3.9543388611028947`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028956`}, {
      659.1862154371977, -3.954338861102896}, {
      659.4117910983292, -1.3759972561399034`}, {
      659.3365992112854, -2.235444457794234}, {
      659.1862154371977, -3.9543388611028956`}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.2614073242415, -3.094891659448564}, {
      659.3314750084438, -2.2940143642833206`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.2614073242415, -3.094891659448564}, {
      659.3365992112854, -2.235444457794234}, {
      659.4767345796898, -0.633689867463747}, {
      659.3314750084438, -2.2940143642833206`}, {
      659.2614073242415, -3.094891659448564}}], 
     PolygonBox[{{659.3365992112854, -2.235444457794234}, {
      659.4117910983292, -1.3759972561399034`}, {659.621994150936, 
      1.0266346293558262`}, {659.4767345796898, -0.633689867463747}, {
      659.3365992112854, -2.235444457794234}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.3314750084438, -2.2940143642833206`}, {
      659.3916434929184, -1.6062854397603679`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.3314750084438, -2.2940143642833206`}, {
      659.4767345796898, -0.633689867463747}, {659.5970715486392, 
      0.7417679815821585}, {659.3916434929184, -1.6062854397603679`}, {
      659.3314750084438, -2.2940143642833206`}}], 
     PolygonBox[{{659.4767345796898, -0.633689867463747}, {659.621994150936, 
      1.0266346293558262`}, {659.8024996043599, 3.0898214029246858`}, {
      659.5970715486392, 0.7417679815821585}, {
      659.4767345796898, -0.633689867463747}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.3916434929184, -1.606285439760366}, {
      659.4378123948816, -1.0785724755601591`}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.3916434929184, -1.606285439760366}, {659.5970715486392, 
      0.7417679815821621}, {659.6894093525655, 1.797193909982576}, {
      659.4378123948816, -1.0785724755601591`}, {
      659.3916434929184, -1.606285439760366}}], 
     PolygonBox[{{659.5970715486392, 0.7417679815821621}, {659.8024996043599, 
      3.089821402924691}, {659.9410063102495, 4.6729602955253124`}, {
      659.6894093525655, 1.797193909982576}, {659.5970715486392, 
      0.7417679815821621}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.4378123948816, -1.0785724755601591`}, {
      659.4668353799623, -0.7468382381060343}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4378123948816, -1.0785724755601591`}, {
      659.6894093525655, 1.797193909982576}, {659.7474553227269, 
      2.4606623848908256`}, {659.4668353799623, -0.7468382381060343}, {
      659.4378123948816, -1.0785724755601591`}}], 
     PolygonBox[{{659.6894093525655, 1.797193909982576}, {659.9410063102495, 
      4.6729602955253124`}, {660.0280752654913, 5.668163007887687}, {
      659.7474553227269, 2.4606623848908256`}, {659.6894093525655, 
      1.797193909982576}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      659.4668353799623, -0.7468382381060343}, {
      659.4767345796898, -0.6336898674637426}, {
      659.1862154371977, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4668353799623, -0.7468382381060343}, {659.7474553227269,
       2.4606623848908256`}, {659.7672537221821, 2.686959126175409}, {
      659.4767345796898, -0.6336898674637426}, {
      659.4668353799623, -0.7468382381060343}}], 
     PolygonBox[{{659.7474553227269, 2.4606623848908256`}, {660.0280752654913,
       5.668163007887687}, {660.0577728646742, 6.007608119814561}, {
      659.7672537221821, 2.686959126175409}, {659.7474553227269, 
      2.4606623848908256`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/WvRvMCyBS0OdWruOafYJRyeRrTVWwL5JpK5b4zW
iDmc/xeg1z6/xWGR2ucGmY1CDtbzXrZkz2txuBy2wOPLdg6HaUcEb/yc0+Lw
LPlBnkTuB/u7CxQjvWe3ODBIv9gkyvJtv9GzlrjamS0OEi/XZtYs4j/Qrv0i
ef30FoewR5//lClKHTjH/uMJw7QWBw7GzU4P7yke0NRTsOif0uLgyPXfzfq/
6oGpZ3f0FU9ucbjTHlB6RlPzQH1xs+3BSS0Oqo28q8PVtQ9kaWZntwD5p9t/
ZSlf1YbLq0PlYfrvQfXDzHeGmg+znxtqP8x9CVD3wdwvC3U/zH9yUP/B/H8I
6n9Y+JyHhg8s/OZBww8WvkbQ8EUPfwB2c78j
       "]], {}}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{660.0577728646742, 6.007608119814561}, {666.0349410532247, 
       5.4846736633286115`}, {666.0052434540418, 5.145228551401739}, {
       660.0280752654913, 5.668163007887689}, {660.0577728646742, 
       6.007608119814561}}], 
      LineBox[{{660.0280752654913, 5.668163007887689}, {666.0052434540418, 
       5.145228551401739}, {665.9181744987999, 4.150025839039366}, {
       659.9410063102495, 4.672960295525316}, {660.0280752654913, 
       5.668163007887689}}], 
      LineBox[{{659.9410063102495, 4.672960295525316}, {665.9181744987999, 
       4.150025839039366}, {665.7796677929103, 2.5668869464387436`}, {
       659.8024996043599, 3.089821402924693}, {659.9410063102495, 
       4.672960295525316}}], 
      LineBox[{{659.8024996043599, 3.089821402924693}, {665.7796677929103, 
       2.5668869464387436`}, {665.5991623394864, 0.5037001728698849}, {
       659.621994150936, 1.0266346293558342`}, {659.8024996043599, 
       3.089821402924693}}], 
      LineBox[{{659.621994150936, 1.0266346293558342`}, {665.5991623394864, 
       0.5037001728698849}, {665.3889592868796, -1.898931712625846}, {
       659.4117910983292, -1.3759972561398968`}, {659.621994150936, 
       1.0266346293558342`}}], 
      LineBox[{{659.4117910983292, -1.3759972561398968`}, {
       665.3889592868796, -1.898931712625846}, {
       665.1633836257481, -4.477273317588841}, {
       659.1862154371977, -3.9543388611028916`}, {
       659.4117910983292, -1.3759972561398968`}}], 
      LineBox[{{659.1862154371977, -3.954338861102894}, {
       665.1633836257481, -4.477273317588843}, {
       664.9378079646166, -7.055614922551838}, {
       658.9606397760662, -6.532680466065889}, {
       659.1862154371977, -3.954338861102894}}], 
      LineBox[{{658.9606397760662, -6.532680466065889}, {
       664.9378079646166, -7.055614922551838}, {
       664.7276049120098, -9.45824680804757}, {
       658.7504367234594, -8.93531235156162}, {
       658.9606397760662, -6.532680466065889}}], 
      LineBox[{{658.7504367234594, -8.93531235156162}, {
       664.7276049120098, -9.45824680804757}, {
       664.5470994585859, -11.52143358161643}, {
       658.5699312700355, -10.998499125130481`}, {
       658.7504367234594, -8.93531235156162}}], 
      LineBox[{{658.5699312700355, -10.998499125130481`}, {
       664.5470994585859, -11.52143358161643}, {
       664.4085927526963, -13.104572474217054`}, {
       658.4314245641459, -12.581638017731104`}, {
       658.5699312700355, -10.998499125130481`}}], 
      LineBox[{{658.4314245641459, -12.581638017731102`}, {
       664.4085927526963, -13.10457247421705}, {
       664.3215237974545, -14.099775186579425`}, {
       658.344355608904, -13.576840730093474`}, {
       658.4314245641459, -12.581638017731102`}}], 
      LineBox[{{658.344355608904, -13.576840730093474`}, {
       664.3215237974545, -14.099775186579425`}, {
       664.2918261982716, -14.4392202985063}, {
       658.3146580097211, -13.916285842020349`}, {
       658.344355608904, -13.576840730093474`}}], 
      LineBox[{{658.3146580097211, -13.916285842020349`}, {
       664.2918261982716, -14.4392202985063}, {
       664.3215237974545, -14.099775186579425`}, {
       658.344355608904, -13.576840730093476`}, {
       658.3146580097211, -13.916285842020349`}}], 
      LineBox[{{658.344355608904, -13.576840730093478`}, {
       664.3215237974545, -14.099775186579429`}, {
       664.4085927526963, -13.104572474217054`}, {
       658.4314245641459, -12.581638017731105`}, {
       658.344355608904, -13.576840730093478`}}], 
      LineBox[{{658.4314245641459, -12.581638017731105`}, {
       664.4085927526963, -13.104572474217054`}, {
       664.5470994585859, -11.521433581616431`}, {
       658.5699312700355, -10.998499125130483`}, {
       658.4314245641459, -12.581638017731105`}}], 
      LineBox[{{658.5699312700355, -10.998499125130484`}, {
       664.5470994585859, -11.521433581616435`}, {
       664.7276049120098, -9.458246808047576}, {
       658.7504367234594, -8.935312351561626}, {
       658.5699312700355, -10.998499125130484`}}], 
      LineBox[{{658.7504367234594, -8.935312351561626}, {
       664.7276049120098, -9.458246808047576}, {
       664.9378079646166, -7.055614922551847}, {
       658.9606397760662, -6.532680466065898}, {
       658.7504367234594, -8.935312351561626}}], 
      LineBox[{{658.9606397760662, -6.532680466065898}, {
       664.9378079646166, -7.055614922551847}, {
       665.1633836257481, -4.477273317588854}, {
       659.1862154371977, -3.954338861102905}, {
       658.9606397760662, -6.532680466065898}}], 
      LineBox[{{659.1862154371977, -3.954338861102896}, {
       665.1633836257481, -4.477273317588845}, {
       665.3889592868796, -1.8989317126258527`}, {
       659.4117910983292, -1.3759972561399034`}, {
       659.1862154371977, -3.954338861102896}}], 
      LineBox[{{659.4117910983292, -1.3759972561399034`}, {
       665.3889592868796, -1.8989317126258527`}, {665.5991623394864, 
       0.5037001728698769}, {659.621994150936, 1.0266346293558262`}, {
       659.4117910983292, -1.3759972561399034`}}], 
      LineBox[{{659.621994150936, 1.0266346293558262`}, {665.5991623394864, 
       0.5037001728698769}, {665.7796677929103, 2.5668869464387365`}, {
       659.8024996043599, 3.0898214029246858`}, {659.621994150936, 
       1.0266346293558262`}}], 
      LineBox[{{659.8024996043599, 3.089821402924691}, {665.7796677929103, 
       2.566886946438742}, {665.9181744987999, 4.150025839039363}, {
       659.9410063102495, 4.6729602955253124`}, {659.8024996043599, 
       3.089821402924691}}], 
      LineBox[{{659.9410063102495, 4.6729602955253124`}, {665.9181744987999, 
       4.150025839039363}, {666.0052434540418, 5.145228551401737}, {
       660.0280752654913, 5.668163007887687}, {659.9410063102495, 
       4.6729602955253124`}}], 
      LineBox[{{660.0280752654913, 5.668163007887687}, {666.0052434540418, 
       5.145228551401737}, {666.0349410532247, 5.4846736633286115`}, {
       660.0577728646742, 6.007608119814561}, {660.0280752654913, 
       5.668163007887687}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{715.1934363220911, 2.4474621809924706`}, {
       695.1934363220911, -10.715001034090623`}, {
       695.1934363220911, -10.715001034090623`}, {715.1934363220911, 
       2.4474621809924706`}, {715.1934363220911, 2.4474621809924706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{704.3778781263171, -14.670507164130802`}, {
       695.1934363220911, -10.715001034090625`}, {
       695.1934363220911, -10.715001034090625`}, {
       704.3778781263171, -14.670507164130802`}, {
       704.3778781263171, -14.670507164130802`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{724.3778781263171, -1.5080439490477069`}, {
       704.3778781263171, -14.6705071641308}, {
       704.3778781263171, -14.6705071641308}, {
       724.3778781263171, -1.5080439490477069`}, {
       724.3778781263171, -1.5080439490477069`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{724.3778781263171, -1.5080439490477051`}, {715.1934363220911, 
       2.4474621809924724`}, {715.1934363220911, 2.4474621809924724`}, {
       724.3778781263171, -1.5080439490477051`}, {
       724.3778781263171, -1.5080439490477051`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{715.19614021164, 2.451741673328751}, {
       695.18614021164, -10.717302773361883`}, {
       704.3751742367682, -14.67478665646708}, {
       724.3851742367681, -1.5057422097764448`}, {715.19614021164, 
       2.451741673328751}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{715.19614021164, 2.451741673328751}, {
       695.18614021164, -10.717302773361883`}, {
       704.3751742367682, -14.67478665646708}, {
       724.3851742367681, -1.5057422097764448`}, {715.19614021164, 
       2.451741673328751}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{774.3796517592887, -1.5068766801104232`}, {
       754.3796517592887, -14.669339895193517`}, {
       754.3796517592887, -14.669339895193517`}, {
       774.3796517592887, -1.5068766801104232`}, {
       774.3796517592887, -1.5068766801104232`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{763.5640935635147, -18.624846025233694`}, {
       754.3796517592887, -14.669339895193517`}, {
       754.3796517592887, -14.669339895193517`}, {
       763.5640935635147, -18.624846025233694`}, {
       763.5640935635147, -18.624846025233694`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{783.5640935635147, -5.462382810150601}, {
       763.5640935635147, -18.624846025233694`}, {
       763.5640935635147, -18.624846025233694`}, {
       783.5640935635147, -5.462382810150601}, {
       783.5640935635147, -5.462382810150601}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{783.5640935635147, -5.462382810150599}, {
       774.3796517592887, -1.5068766801104214`}, {
       774.3796517592887, -1.5068766801104214`}, {
       783.5640935635147, -5.462382810150599}, {
       783.5640935635147, -5.462382810150599}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{774.3823556488376, -1.5025971877741426`}, {
       754.3723556488376, -14.671641634464777`}, {
       763.5613896739658, -18.629125517569975`}, {
       783.5713896739658, -5.460081070879339}, {
       774.3823556488376, -1.5025971877741426`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{774.3823556488376, -1.5025971877741426`}, {
       754.3723556488376, -14.671641634464777`}, {
       763.5613896739658, -18.629125517569975`}, {
       783.5713896739658, -5.460081070879339}, {
       774.3823556488376, -1.5025971877741426`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1272.851261246445, -16.991512293541824`}, {
      1278.861905403629, -17.782828608944225`}, {
      1279.079449057329, -16.13042050665454}, {
      1273.103237841273, -15.343637373950951`}, {
      1272.851261246445, -16.991512293541824`}}], 
     PolygonBox[{{1273.103237841273, -15.343637373950951`}, {
      1279.079449057329, -16.13042050665454}, {
      1279.2969927110291`, -14.47801240436486}, {
      1273.3414383894908`, -13.69394880341692}, {
      1273.103237841273, -15.343637373950951`}}], 
     PolygonBox[{{1273.3414383894908`, -13.69394880341692}, {
      1279.2969927110291`, -14.47801240436486}, {
      1279.514536364729, -12.825604302075174`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.3414383894908`, -13.69394880341692}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1279.514536364729, -12.825604302075174`}, {
      1279.732080018429, -11.17319619978549}, {
      1273.7765256968908`, -10.389132598837552`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.7765256968908`, -10.389132598837552`}, {
      1279.732080018429, -11.17319619978549}, {
      1279.9496236721293`, -9.520788097495807}, {
      1273.9734124560734`, -8.734004964792216}, {
      1273.7765256968908`, -10.389132598837552`}}], 
     PolygonBox[{{1273.9734124560734`, -8.734004964792216}, {
      1279.9496236721293`, -9.520788097495807}, {
      1280.1671673258293`, -7.868379995206123}, {
      1274.1565231686452`, -7.077063679803722}, {
      1273.9734124560734`, -8.734004964792216}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1272.851261246445, -16.991512293541824`}, {
       1273.103237841273, -15.343637373950951`}, {
       1273.3414383894908`, -13.69394880341692}, {
       1273.5658671964864`, -12.042447148754864`}, {
       1273.7765256968908`, -10.389132598837552`}, {
       1273.9734124560734`, -8.734004964792216}, {
       1274.1565231686452`, -7.077063679803722}, {
       1280.1671673258293`, -7.868379995206122}, {
       1279.9496236721293`, -9.520788097495807}, {
       1279.732080018429, -11.17319619978549}, {
       1279.514536364729, -12.825604302075174`}, {
       1279.2969927110291`, -14.478012404364858`}, {
       1279.079449057329, -16.13042050665454}, {
       1278.861905403629, -17.782828608944225`}, {
       1272.851261246445, -16.991512293541824`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1273.503892207545, -12.034287986672773`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.5383251486733`, -12.038821169371584`}, {
        1273.503892207545, -12.034287986672773`}}], 
       PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.5589820431908`, -12.041540701127236`}, {
        1273.5383251486733`, -12.038821169371584`}}], 
       PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.5658671964864`, -12.042447148754864`}, {
        1273.5589820431908`, -12.041540701127236`}}], 
       PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.5589820431908`, -12.041540701127236`}, {
        1273.5658671964864`, -12.042447148754864`}}], 
       PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.5383251486733`, -12.038821169371584`}, {
        1273.5589820431908`, -12.041540701127236`}}], 
       PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
        1279.514536364729, -12.825604302075174`}, {
        1279.514536364729, -12.825604302075174`}, {
        1273.503892207545, -12.034287986672773`}, {
        1273.5383251486733`, -12.038821169371584`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1273.503892207545, -12.034287986672773`}, {
         1273.5383251486733`, -12.038821169371584`}, {
         1273.5589820431908`, -12.041540701127236`}, {
         1273.5658671964864`, -12.042447148754864`}, {
         1273.5589820431908`, -12.041540701127236`}, {
         1273.5383251486733`, -12.038821169371584`}, {
         1273.503892207545, -12.034287986672773`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1279.514536364729, -12.825604302075174`}, {
         1273.503892207545, -12.034287986672773`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.7765256968908`, -10.389132598837552`}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.7765256968908`, -10.389132598837552`}, {
      1273.9734124560734`, -8.734004964792216}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.7765256968908`, -10.389132598837552`}}], 
     PolygonBox[{{1273.9734124560734`, -8.734004964792216}, {
      1274.1565231686452`, -7.077063679803722}, {
      1274.1342853079077`, -7.2459770019600285`}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.9734124560734`, -8.734004964792216}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.747380373727, -10.610513307125133`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.769113076645, -10.445437039556321`}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.9151218097459`, -9.176766381367376}, {
      1273.747380373727, -10.610513307125133`}, {
      1273.769113076645, -10.445437039556321`}}], 
     PolygonBox[{{1273.9585872155817`, -8.846613846229754}, {
      1274.1342853079077`, -7.2459770019600285`}, {
      1274.0690871991542`, -7.741205804666468}, {
      1273.9151218097459`, -9.176766381367376}, {
      1273.9585872155817`, -8.846613846229754}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.747380373727, -10.610513307125133`}, {
      1273.7128086359262`, -10.873111726710606`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.747380373727, -10.610513307125133`}, {
      1273.9151218097459`, -9.176766381367376}, {
      1273.845978334144, -9.701963220538325}, {
      1273.7128086359262`, -10.873111726710606`}, {
      1273.747380373727, -10.610513307125133`}}], 
     PolygonBox[{{1273.9151218097459`, -9.176766381367376}, {
      1274.0690871991542`, -7.741205804666468}, {
      1273.9653719857513`, -8.529001063422882}, {
      1273.845978334144, -9.701963220538325}, {
      1273.9151218097459`, -9.176766381367376}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.7128086359262`, -10.873111726710606`}, {
      1273.6677538700408`, -11.215336649982394`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.7128086359262`, -10.873111726710606`}, {
      1273.845978334144, -9.701963220538325}, {
      1273.7558688023732`, -10.386413067081897`}, {
      1273.6677538700408`, -11.215336649982394`}, {
      1273.7128086359262`, -10.873111726710606`}}], 
     PolygonBox[{{1273.845978334144, -9.701963220538325}, {
      1273.9653719857513`, -8.529001063422882}, {
      1273.8302076880952`, -9.555675833238247}, {
      1273.7558688023732`, -10.386413067081897`}, {
      1273.845978334144, -9.701963220538325}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.6677538700408`, -11.215336649982394`}, {
      1273.6152864839096`, -11.61386601397295}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.6677538700408`, -11.215336649982394`}, {
      1273.7558688023732`, -10.386413067081897`}, {
      1273.6509340301109`, -11.183471795063014`}, {
      1273.6152864839096`, -11.61386601397295}, {
      1273.6677538700408`, -11.215336649982394`}}], 
     PolygonBox[{{1273.7558688023732`, -10.386413067081897`}, {
      1273.8302076880952`, -9.555675833238247}, {
      1273.6728055297015`, -10.75126392520992}, {
      1273.6509340301109`, -11.183471795063014`}, {
      1273.7558688023732`, -10.386413067081897`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.6152864839096`, -11.61386601397295}, {
      1273.5589820431908`, -12.041540701127236`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.6152864839096`, -11.61386601397295}, {
      1273.6509340301109`, -11.183471795063014`}, {
      1273.5383251486733`, -12.038821169371582`}, {
      1273.5589820431908`, -12.041540701127236`}, {
      1273.6152864839096`, -11.61386601397295}}], 
     PolygonBox[{{1273.6509340301109`, -11.183471795063014`}, {
      1273.6728055297015`, -10.75126392520992}, {
      1273.503892207545, -12.034287986672771`}, {
      1273.5383251486733`, -12.038821169371582`}, {
      1273.6509340301109`, -11.183471795063014`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.5589820431908`, -12.041540701127236`}, {
      1273.502677602472, -12.469215388281519`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
      1273.5383251486733`, -12.038821169371584`}, {
      1273.4257162672357`, -12.894170543680152`}, {
      1273.502677602472, -12.469215388281519`}, {
      1273.5589820431908`, -12.041540701127236`}}], 
     PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
      1273.503892207545, -12.034287986672773`}, {
      1273.3349788853886`, -13.317312048135626`}, {
      1273.4257162672357`, -12.894170543680152`}, {
      1273.5383251486733`, -12.038821169371584`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.502677602472, -12.469215388281519`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.502677602472, -12.469215388281519`}, {
      1273.4257162672357`, -12.894170543680152`}, {
      1273.3207814949733`, -13.691229271661264`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.502677602472, -12.469215388281519`}}], 
     PolygonBox[{{1273.4257162672357`, -12.894170543680152`}, {
      1273.3349788853886`, -13.317312048135626`}, {
      1273.1775767269949`, -14.512900140107298`}, {
      1273.3207814949733`, -13.691229271661264`}, {
      1273.4257162672357`, -12.894170543680152`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.4502102163408`, -12.867744752272078`}, {
      1273.3207814949733`, -13.691229271661264`}, {
      1273.2306719632024`, -14.375679118204843`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.4502102163408`, -12.867744752272078`}}], 
     PolygonBox[{{1273.3207814949733`, -13.691229271661264`}, {
      1273.1775767269949`, -14.512900140107298`}, {
      1273.0424124293388`, -15.539574909922662`}, {
      1273.2306719632024`, -14.375679118204843`}, {
      1273.3207814949733`, -13.691229271661264`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.3705837126545`, -13.472568095129338`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.4051554504554`, -13.209969675543865`}, {
      1273.2306719632024`, -14.375679118204843`}, {
      1273.1615284876002`, -14.900875957375783`}, {
      1273.3705837126545`, -13.472568095129338`}, {
      1273.4051554504554`, -13.209969675543865`}}], 
     PolygonBox[{{1273.2306719632024`, -14.375679118204843`}, {
      1273.0424124293388`, -15.539574909922662`}, {
      1272.938697215936, -16.327370168679078`}, {
      1273.1615284876002`, -14.900875957375783`}, {
      1273.2306719632024`, -14.375679118204843`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.3705837126545`, -13.472568095129336`}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.3705837126545`, -13.472568095129336`}, {
      1273.1615284876002`, -14.900875957375783`}, {
      1273.1180630817648`, -15.231028492513412`}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.3705837126545`, -13.472568095129336`}}], 
     PolygonBox[{{1273.1615284876002`, -14.900875957375783`}, {
      1272.938697215936, -16.327370168679078`}, {
      1272.8734991071824`, -16.822598971385514`}, {
      1273.1180630817648`, -15.231028492513412`}, {
      1273.1615284876002`, -14.900875957375783`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.3414383894908`, -13.69394880341692}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.3488510097366`, -13.63764436269815}, {
      1273.1180630817648`, -15.231028492513412`}, {
      1273.103237841273, -15.343637373950951`}, {
      1273.3414383894908`, -13.69394880341692}, {
      1273.3488510097366`, -13.63764436269815}}], 
     PolygonBox[{{1273.1180630817648`, -15.231028492513412`}, {
      1272.8734991071824`, -16.822598971385514`}, {
      1272.851261246445, -16.991512293541824`}, {
      1273.103237841273, -15.343637373950951`}, {
      1273.1180630817648`, -15.231028492513412`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.3414383894908`, -13.69394880341692}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.3414383894908`, -13.69394880341692}, {
      1273.103237841273, -15.343637373950951`}, {
      1273.1180630817648`, -15.231028492513412`}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.3414383894908`, -13.69394880341692}}], 
     PolygonBox[{{1273.103237841273, -15.343637373950951`}, {
      1272.851261246445, -16.991512293541824`}, {
      1272.8734991071824`, -16.822598971385517`}, {
      1273.1180630817648`, -15.231028492513412`}, {
      1273.103237841273, -15.343637373950951`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.3488510097366`, -13.63764436269815}, {
      1273.3705837126545`, -13.472568095129338`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.3488510097366`, -13.63764436269815}, {
      1273.1180630817648`, -15.231028492513413`}, {
      1273.1615284876002`, -14.900875957375785`}, {
      1273.3705837126545`, -13.472568095129338`}, {
      1273.3488510097366`, -13.63764436269815}}], 
     PolygonBox[{{1273.1180630817648`, -15.231028492513413`}, {
      1272.8734991071824`, -16.822598971385517`}, {
      1272.938697215936, -16.327370168679078`}, {
      1273.1615284876002`, -14.900875957375785`}, {
      1273.1180630817648`, -15.231028492513413`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.3705837126545`, -13.472568095129338`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.3705837126545`, -13.472568095129338`}, {
      1273.1615284876002`, -14.900875957375785`}, {
      1273.2306719632024`, -14.375679118204843`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.3705837126545`, -13.472568095129338`}}], 
     PolygonBox[{{1273.1615284876002`, -14.900875957375785`}, {
      1272.938697215936, -16.327370168679078`}, {
      1273.0424124293388`, -15.539574909922663`}, {
      1273.2306719632024`, -14.375679118204843`}, {
      1273.1615284876002`, -14.900875957375785`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.4051554504554`, -13.209969675543865`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.4051554504554`, -13.209969675543865`}, {
      1273.2306719632024`, -14.375679118204845`}, {
      1273.3207814949733`, -13.691229271661266`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.4051554504554`, -13.209969675543865`}}], 
     PolygonBox[{{1273.2306719632024`, -14.375679118204845`}, {
      1273.0424124293388`, -15.539574909922663`}, {
      1273.1775767269949`, -14.512900140107302`}, {
      1273.3207814949733`, -13.691229271661266`}, {
      1273.2306719632024`, -14.375679118204845`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.4502102163408`, -12.867744752272078`}, {
      1273.502677602472, -12.46921538828152}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.4502102163408`, -12.867744752272078`}, {
      1273.3207814949733`, -13.691229271661266`}, {
      1273.4257162672357`, -12.894170543680156`}, {
      1273.502677602472, -12.46921538828152}, {
      1273.4502102163408`, -12.867744752272078`}}], 
     PolygonBox[{{1273.3207814949733`, -13.691229271661266`}, {
      1273.1775767269949`, -14.512900140107302`}, {
      1273.3349788853886`, -13.31731204813563}, {
      1273.4257162672357`, -12.894170543680156`}, {
      1273.3207814949733`, -13.691229271661266`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.502677602472, -12.46921538828152}, {
      1273.5589820431908`, -12.041540701127238`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.502677602472, -12.46921538828152}, {
      1273.4257162672357`, -12.894170543680156`}, {
      1273.5383251486733`, -12.038821169371587`}, {
      1273.5589820431908`, -12.041540701127238`}, {
      1273.502677602472, -12.46921538828152}}], 
     PolygonBox[{{1273.4257162672357`, -12.894170543680156`}, {
      1273.3349788853886`, -13.31731204813563}, {
      1273.503892207545, -12.034287986672778`}, {
      1273.5383251486733`, -12.038821169371587`}, {
      1273.4257162672357`, -12.894170543680156`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.5589820431908`, -12.041540701127236`}, {
      1273.6152864839096`, -11.613866013972952`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
      1273.5383251486733`, -12.038821169371584`}, {
      1273.6509340301109`, -11.183471795063017`}, {
      1273.6152864839096`, -11.613866013972952`}, {
      1273.5589820431908`, -12.041540701127236`}}], 
     PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
      1273.503892207545, -12.034287986672775`}, {
      1273.6728055297015`, -10.751263925209923`}, {
      1273.6509340301109`, -11.183471795063017`}, {
      1273.5383251486733`, -12.038821169371584`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.6152864839096`, -11.613866013972952`}, {
      1273.6677538700408`, -11.215336649982396`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.6152864839096`, -11.613866013972952`}, {
      1273.6509340301109`, -11.183471795063017`}, {
      1273.7558688023732`, -10.386413067081898`}, {
      1273.6677538700408`, -11.215336649982396`}, {
      1273.6152864839096`, -11.613866013972952`}}], 
     PolygonBox[{{1273.6509340301109`, -11.183471795063017`}, {
      1273.6728055297015`, -10.751263925209923`}, {
      1273.8302076880952`, -9.55567583323825}, {
      1273.7558688023732`, -10.386413067081898`}, {
      1273.6509340301109`, -11.183471795063017`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.6677538700408`, -11.215336649982396`}, {
      1273.7128086359262`, -10.873111726710608`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.6677538700408`, -11.215336649982396`}, {
      1273.7558688023732`, -10.386413067081898`}, {
      1273.845978334144, -9.701963220538328}, {
      1273.7128086359262`, -10.873111726710608`}, {
      1273.6677538700408`, -11.215336649982396`}}], 
     PolygonBox[{{1273.7558688023732`, -10.386413067081898`}, {
      1273.8302076880952`, -9.55567583323825}, {
      1273.9653719857513`, -8.529001063422886}, {
      1273.845978334144, -9.701963220538328}, {
      1273.7558688023732`, -10.386413067081898`}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.7128086359262`, -10.873111726710606`}, {
      1273.747380373727, -10.610513307125135`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.7128086359262`, -10.873111726710606`}, {
      1273.845978334144, -9.701963220538325}, {
      1273.9151218097459`, -9.17676638136738}, {
      1273.747380373727, -10.610513307125135`}, {
      1273.7128086359262`, -10.873111726710606`}}], 
     PolygonBox[{{1273.845978334144, -9.701963220538325}, {
      1273.9653719857513`, -8.529001063422886}, {
      1274.0690871991542`, -7.741205804666471}, {
      1273.9151218097459`, -9.17676638136738}, {
      1273.845978334144, -9.701963220538325}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.747380373727, -10.610513307125135`}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.747380373727, -10.610513307125135`}, {
      1273.9151218097459`, -9.17676638136738}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.747380373727, -10.610513307125135`}}], 
     PolygonBox[{{1273.9151218097459`, -9.17676638136738}, {
      1274.0690871991542`, -7.741205804666471}, {
      1274.1342853079077`, -7.245977001960032}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.9151218097459`, -9.17676638136738}}], 
     PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
      1273.769113076645, -10.445437039556321`}, {
      1273.7765256968908`, -10.389132598837552`}, {
      1273.5658671964864`, -12.042447148754864`}, {
      1273.5658671964864`, -12.042447148754864`}}], 
     PolygonBox[{{1273.769113076645, -10.445437039556321`}, {
      1273.9585872155817`, -8.846613846229754}, {
      1273.9734124560734`, -8.734004964792216}, {
      1273.7765256968908`, -10.389132598837552`}, {
      1273.769113076645, -10.445437039556321`}}], 
     PolygonBox[{{1273.9585872155817`, -8.846613846229754}, {
      1274.1342853079077`, -7.245977001960032}, {
      1274.1565231686452`, -7.077063679803722}, {
      1273.9734124560734`, -8.734004964792216}, {
      1273.9585872155817`, -8.846613846229754}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQPZ1zjvuCF5MdZtxlPPHST+aAQblYUyeQr/BJO/Xh
b5kDh4pP73MD8lOmdy3/903ugLRvZded55MdVjwztbrJp3iA/eo3xSAgX+X+
165GGeUD3afefd7wbLLDk4deq5Y2qB4oWxD4hxnIrzn/yrBPUONAYtkWlvCn
kx1E9nbtLFukdeBp9pprW59Mdriy//6NWWy6By5+1szTBvL9d8zXdBbRP6B1
9rrlwceTHRZrcnScCzY4sOdkT1kdkP/50vwbUy8ZHAg1Z9+YDuSLRbzaf/kv
Qv4LVB5dP8z8AKj5MPuvQe2HuU8M6j6Y+2uh7of57xnUfzD/q0H9DwufVdDw
gYVfBjT8YOGrAg1f9PAHAE/S2Lg=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQPS30pe5qhikOp5f8n2VRKX9A/3ByxhQgf/UdERkJ
YYUDB/dLLA0E8n30XfYuE1A8IDXzWMHz/5MdnE9tWcywROkAm6ILRyyQv+9Q
yZcVG1UOdInZ3Nr9b7JD3dGTwmdF1Q+Uvpn3iA/IF9ucOXvrMs0DCYcYXyf+
neywbgGn8jxznQNPtv/cc+DPZIe8xXFOh2brHbhgXx5iBuR/8e333BpicEBT
UlXhzO/JDgWzj9skyRke2C16K6YTyD/gEt+rOdfwQEhzyPQiIP/xyZUl6ScQ
8geh8uj6YeZ/hZoPs78Aaj/MfRug7oO5Xxzqfpj/GqD+g/n/ANT/6OEDCz9f
aPjBwncNNHzRwx8Av4DGFw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1274.1565231686452`, -7.077063679803722}, {
       1280.1671673258293`, -7.868379995206122}, {
       1280.1449294650918`, -8.037293317362431}, {
       1274.1342853079077`, -7.2459770019600285`}, {
       1274.1565231686452`, -7.077063679803722}}], 
      LineBox[{{1274.1342853079077`, -7.2459770019600285`}, {
       1280.1449294650918`, -8.037293317362431}, {
       1280.0797313563382`, -8.532522120068869}, {
       1274.0690871991542`, -7.741205804666468}, {
       1274.1342853079077`, -7.2459770019600285`}}], 
      LineBox[{{1274.0690871991542`, -7.741205804666468}, {
       1280.0797313563382`, -8.532522120068869}, {
       1279.9760161429354`, -9.320317378825285}, {
       1273.9653719857513`, -8.529001063422882}, {
       1274.0690871991542`, -7.741205804666468}}], 
      LineBox[{{1273.9653719857513`, -8.529001063422882}, {
       1279.9760161429354`, -9.320317378825285}, {
       1279.8408518452793`, -10.346992148640648`}, {
       1273.8302076880952`, -9.555675833238247}, {
       1273.9653719857513`, -8.529001063422882}}], 
      LineBox[{{1273.8302076880952`, -9.555675833238247}, {
       1279.8408518452793`, -10.346992148640648`}, {
       1279.6834496868855`, -11.54258024061232}, {
       1273.6728055297015`, -10.75126392520992}, {
       1273.8302076880952`, -9.555675833238247}}], 
      LineBox[{{1273.6728055297015`, -10.75126392520992}, {
       1279.6834496868855`, -11.54258024061232}, {
       1279.514536364729, -12.825604302075172`}, {
       1273.503892207545, -12.034287986672771`}, {
       1273.6728055297015`, -10.75126392520992}}], 
      LineBox[{{1273.503892207545, -12.034287986672773`}, {
       1279.514536364729, -12.825604302075174`}, {
       1279.3456230425727`, -14.108628363538028`}, {
       1273.3349788853886`, -13.317312048135626`}, {
       1273.503892207545, -12.034287986672773`}}], 
      LineBox[{{1273.3349788853886`, -13.317312048135626`}, {
       1279.3456230425727`, -14.108628363538028`}, {
       1279.188220884179, -15.3042164555097}, {
       1273.1775767269949`, -14.512900140107298`}, {
       1273.3349788853886`, -13.317312048135626`}}], 
      LineBox[{{1273.1775767269949`, -14.512900140107298`}, {
       1279.188220884179, -15.3042164555097}, {
       1279.0530565865229`, -16.33089122532506}, {
       1273.0424124293388`, -15.539574909922662`}, {
       1273.1775767269949`, -14.512900140107298`}}], 
      LineBox[{{1273.0424124293388`, -15.539574909922662`}, {
       1279.0530565865229`, -16.33089122532506}, {
       1278.94934137312, -17.11868648408148}, {
       1272.938697215936, -16.327370168679078`}, {
       1273.0424124293388`, -15.539574909922662`}}], 
      LineBox[{{1272.938697215936, -16.327370168679078`}, {
       1278.94934137312, -17.11868648408148}, {
       1278.8841432643665`, -17.613915286787915`}, {
       1272.8734991071824`, -16.822598971385514`}, {
       1272.938697215936, -16.327370168679078`}}], 
      LineBox[{{1272.8734991071824`, -16.822598971385514`}, {
       1278.8841432643665`, -17.613915286787915`}, {
       1278.861905403629, -17.782828608944225`}, {
       1272.851261246445, -16.991512293541824`}, {
       1272.8734991071824`, -16.822598971385514`}}], 
      LineBox[{{1272.851261246445, -16.991512293541824`}, {
       1278.861905403629, -17.782828608944225`}, {
       1278.8841432643665`, -17.613915286787915`}, {
       1272.8734991071824`, -16.822598971385517`}, {
       1272.851261246445, -16.991512293541824`}}], 
      LineBox[{{1272.8734991071824`, -16.822598971385517`}, {
       1278.8841432643665`, -17.61391528678792}, {
       1278.94934137312, -17.11868648408148}, {
       1272.938697215936, -16.327370168679078`}, {
       1272.8734991071824`, -16.822598971385517`}}], 
      LineBox[{{1272.938697215936, -16.327370168679078`}, {
       1278.94934137312, -17.11868648408148}, {
       1279.0530565865229`, -16.330891225325065`}, {
       1273.0424124293388`, -15.539574909922663`}, {
       1272.938697215936, -16.327370168679078`}}], 
      LineBox[{{1273.0424124293388`, -15.539574909922663`}, {
       1279.0530565865229`, -16.330891225325065`}, {
       1279.188220884179, -15.304216455509703`}, {
       1273.1775767269949`, -14.512900140107302`}, {
       1273.0424124293388`, -15.539574909922663`}}], 
      LineBox[{{1273.1775767269949`, -14.512900140107302`}, {
       1279.188220884179, -15.304216455509703`}, {
       1279.3456230425727`, -14.108628363538031`}, {
       1273.3349788853886`, -13.31731204813563}, {
       1273.1775767269949`, -14.512900140107302`}}], 
      LineBox[{{1273.3349788853886`, -13.31731204813563}, {
       1279.3456230425727`, -14.108628363538031`}, {
       1279.514536364729, -12.82560430207518}, {
       1273.503892207545, -12.034287986672778`}, {
       1273.3349788853886`, -13.31731204813563}}], 
      LineBox[{{1273.503892207545, -12.034287986672775`}, {
       1279.514536364729, -12.825604302075176`}, {
       1279.6834496868855`, -11.542580240612324`}, {
       1273.6728055297015`, -10.751263925209923`}, {
       1273.503892207545, -12.034287986672775`}}], 
      LineBox[{{1273.6728055297015`, -10.751263925209923`}, {
       1279.6834496868855`, -11.542580240612324`}, {
       1279.8408518452793`, -10.346992148640652`}, {
       1273.8302076880952`, -9.55567583323825}, {
       1273.6728055297015`, -10.751263925209923`}}], 
      LineBox[{{1273.8302076880952`, -9.55567583323825}, {
       1279.8408518452793`, -10.346992148640652`}, {
       1279.9760161429354`, -9.320317378825287}, {
       1273.9653719857513`, -8.529001063422886}, {
       1273.8302076880952`, -9.55567583323825}}], 
      LineBox[{{1273.9653719857513`, -8.529001063422886}, {
       1279.9760161429354`, -9.320317378825285}, {
       1280.0797313563382`, -8.53252212006887}, {
       1274.0690871991542`, -7.741205804666471}, {
       1273.9653719857513`, -8.529001063422886}}], 
      LineBox[{{1274.0690871991542`, -7.741205804666471}, {
       1280.0797313563382`, -8.53252212006887}, {
       1280.1449294650918`, -8.037293317362433}, {
       1274.1342853079077`, -7.245977001960032}, {
       1274.0690871991542`, -7.741205804666471}}], 
      LineBox[{{1274.1342853079077`, -7.245977001960032}, {
       1280.1449294650918`, -8.037293317362433}, {
       1280.1671673258293`, -7.868379995206122}, {
       1274.1565231686452`, -7.077063679803722}, {
       1274.1342853079077`, -7.245977001960032}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1213.9069695388796`, -2.8702860211179173`}, {
       1236.632182225186, 4.667296233860271}, {1236.632182225186, 
       4.667296233860271}, {1213.9069695388796`, -2.8702860211179173`}, {
       1213.9069695388796`, -2.8702860211179173`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1228.7844530059092`, 10.86513021848026}, {1236.6321822251857`,
        4.667296233860274}, {1236.6321822251857`, 4.667296233860274}, {
       1228.7844530059092`, 10.86513021848026}, {1228.7844530059092`, 
       10.86513021848026}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1206.0592403196028`, 3.3275479635020693`}, {
       1228.7844530059092`, 10.865130218480257`}, {1228.7844530059092`, 
       10.865130218480257`}, {1206.0592403196028`, 3.3275479635020693`}, {
       1206.0592403196028`, 3.3275479635020693`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1206.059240319603, 3.3275479635020666`}, {
       1213.9069695388796`, -2.870286021117919}, {
       1213.9069695388796`, -2.870286021117919}, {1206.059240319603, 
       3.3275479635020666`}, {1206.059240319603, 3.3275479635020666`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1213.9032501680128`, -2.8737198751778177`}, {
       1236.6398254606622`, 4.667631170927862}, {1228.788172376776, 
       10.868564072540156`}, {1206.0515970841266`, 3.3272130264344772`}, {
       1213.9032501680128`, -2.8737198751778177`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1213.9032501680128`, -2.8737198751778177`}, {
       1236.6398254606622`, 4.667631170927862}, {1228.788172376776, 
       10.868564072540156`}, {1206.0515970841266`, 3.3272130264344772`}, {
       1213.9032501680128`, -2.8737198751778177`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{881.3286299360368, 107.48697475086138`}, {875.1734274108528,
       108.5723030277762}, {874.594600151963, 105.28961051773551`}, {
      880.6129001659033, 104.22842184727972`}, {881.3286299360368, 
      107.48697475086138`}}], 
     PolygonBox[{{880.6129001659033, 104.22842184727972`}, {874.594600151963, 
      105.28961051773551`}, {874.0157728930733, 102.00691800769481`}, {
      879.9519770820336, 100.96020504618647`}, {880.6129001659033, 
      104.22842184727972`}}], 
     PolygonBox[{{879.9519770820336, 100.96020504618647`}, {874.0157728930733,
       102.00691800769481`}, {873.4369456341835, 98.72422549765412}, {
      879.3457921522566, 97.68233643165254}, {879.9519770820336, 
      100.96020504618647`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {873.4369456341835, 
      98.72422549765412}, {872.8581183752938, 95.44153298761343}, {
      878.7943225642541, 94.3948200261051}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.7943225642541, 94.3948200261051}, {872.8581183752938, 
      95.44153298761343}, {872.279291116404, 92.15884047757272}, {
      878.2975911303442, 91.09765180711693}, {878.7943225642541, 
      94.3948200261051}}], 
     PolygonBox[{{878.2975911303442, 91.09765180711693}, {872.279291116404, 
      92.15884047757274}, {871.7004638575143, 88.87614796753203}, {
      877.8556663826982, 87.79081969061723}, {878.2975911303442, 
      91.09765180711693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{881.3286299360368, 107.48697475086138`}, {880.6129001659033, 
       104.22842184727972`}, {879.9519770820336, 100.96020504618647`}, {
       879.3457921522566, 97.68233643165254}, {878.7943225642541, 
       94.3948200261051}, {878.2975911303442, 91.09765180711693}, {
       877.8556663826982, 87.79081969061721}, {871.7004638575143, 
       88.87614796753203}, {872.279291116404, 92.15884047757272}, {
       872.8581183752938, 95.44153298761343}, {873.4369456341835, 
       98.72422549765412}, {874.0157728930733, 102.00691800769481`}, {
       874.594600151963, 105.2896105177355}, {875.1734274108528, 
       108.5723030277762}, {881.3286299360368, 107.48697475086138`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{879.5921481593675, 97.6388972207393}, {873.4369456341835, 
        98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.4552456481238, 97.66303682719831}, {879.5921481593675, 
        97.6388972207393}}], 
       PolygonBox[{{879.4552456481238, 97.66303682719831}, {873.4369456341835,
         98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.3731498231439, 97.6775125361458}, {879.4552456481238, 
        97.66303682719831}}], 
       PolygonBox[{{879.3731498231439, 97.6775125361458}, {873.4369456341835, 
        98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.3457921522566, 97.68233643165254}, {879.3731498231439, 
        97.6775125361458}}], 
       PolygonBox[{{879.3457921522566, 97.68233643165254}, {873.4369456341835,
         98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.3731498231439, 97.6775125361458}, {879.3457921522566, 
        97.68233643165254}}], 
       PolygonBox[{{879.3731498231439, 97.6775125361458}, {873.4369456341835, 
        98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.4552456481238, 97.66303682719831}, {879.3731498231439, 
        97.6775125361458}}], 
       PolygonBox[{{879.4552456481238, 97.66303682719831}, {873.4369456341835,
         98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
        879.5921481593675, 97.6388972207393}, {879.4552456481238, 
        97.66303682719831}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{879.5921481593675, 97.6388972207393}, {879.4552456481238, 
         97.66303682719831}, {879.3731498231439, 97.6775125361458}, {
         879.3457921522566, 97.68233643165254}, {879.3731498231439, 
         97.6775125361458}, {879.4552456481238, 97.66303682719831}, {
         879.5921481593675, 97.6388972207393}, {873.4369456341835, 
         98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
         873.4369456341835, 98.72422549765412}, {873.4369456341835, 
         98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
         873.4369456341835, 98.72422549765412}, {873.4369456341835, 
         98.72422549765412}, {879.5921481593675, 97.6388972207393}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.7943225642541, 
      94.3948200261051}, {878.8140456248223, 94.5066750609318}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.7943225642541, 94.3948200261051}, {878.2975911303442, 
      91.09765180711693}, {878.3370372514803, 91.32136187677034}, {
      878.8140456248223, 94.5066750609318}, {878.7943225642541, 
      94.3948200261051}}], 
     PolygonBox[{{878.2975911303442, 91.09765180711693}, {877.8556663826982, 
      87.79081969061721}, {877.9148355644024, 88.12638479509732}, {
      878.3370372514803, 91.32136187677034}, {878.2975911303442, 
      91.09765180711693}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.8140456248223, 
      94.5066750609318}, {878.8718707125424, 94.83461742963763}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.8140456248223, 94.5066750609318}, {878.3370372514803, 
      91.32136187677034}, {878.4526874269209, 91.97724661418204}, {
      878.8718707125424, 94.83461742963763}, {878.8140456248223, 
      94.5066750609318}}], 
     PolygonBox[{{878.3370372514803, 91.32136187677034}, {877.9148355644024, 
      88.12638479509732}, {878.0883108275632, 89.11021190121487}, {
      878.4526874269209, 91.97724661418204}, {878.3370372514803, 
      91.32136187677034}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.8718707125424, 
      94.83461742963763}, {878.9638571432472, 95.35629840174573}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.8718707125424, 94.83461742963763}, {878.4526874269209, 
      91.97724661418204}, {878.6366602883306, 93.02060855839821}, {
      878.9638571432472, 95.35629840174573}, {878.8718707125424, 
      94.83461742963763}}], 
     PolygonBox[{{878.4526874269209, 91.97724661418204}, {878.0883108275632, 
      89.11021190121487}, {878.3642701196777, 90.67525481753911}, {
      878.6366602883306, 93.02060855839821}, {878.4526874269209, 
      91.97724661418204}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.9638571432472, 
      95.35629840174573}, {879.083736193699, 96.03616628112545}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.9638571432472, 95.35629840174573}, {878.6366602883306, 
      93.02060855839821}, {878.876418389234, 94.38034431715762}, {
      879.083736193699, 96.03616628112545}, {878.9638571432472, 
      95.35629840174573}}], 
     PolygonBox[{{878.6366602883306, 93.02060855839821}, {878.3642701196777, 
      90.67525481753911}, {878.7239072710329, 92.71485845567827}, {
      878.876418389234, 94.38034431715762}, {878.6366602883306, 
      93.02060855839821}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.083736193699, 
      96.03616628112545}, {879.2233383047187, 96.82788919533186}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.083736193699, 96.03616628112545}, {878.876418389234, 
      94.38034431715762}, {879.1556226112734, 95.96379014557046}, {
      879.2233383047187, 96.82788919533186}, {879.083736193699, 
      96.03616628112545}}], 
     PolygonBox[{{878.876418389234, 94.38034431715762}, {878.7239072710329, 
      92.71485845567827}, {879.142713604092, 95.09002719829752}, {
      879.1556226112734, 95.96379014557046}, {878.876418389234, 
      94.38034431715762}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.2233383047187, 
      96.82788919533186}, {879.3731498231439, 97.6775125361458}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.2233383047187, 96.82788919533186}, {879.1556226112734, 
      95.96379014557046}, {879.4552456481238, 97.66303682719831}, {
      879.3731498231439, 97.6775125361458}, {879.2233383047187, 
      96.82788919533186}}], 
     PolygonBox[{{879.1556226112734, 95.96379014557046}, {879.142713604092, 
      95.09002719829752}, {879.5921481593675, 97.6388972207393}, {
      879.4552456481238, 97.66303682719831}, {879.1556226112734, 
      95.96379014557046}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.3731498231439, 
      97.6775125361458}, {879.522961341569, 98.52713587695972}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.3731498231439, 97.6775125361458}, {879.4552456481238, 
      97.66303682719831}, {879.7548686849741, 99.36228350882618}, {
      879.522961341569, 98.52713587695972}, {879.3731498231439, 
      97.6775125361458}}], 
     PolygonBox[{{879.4552456481238, 97.66303682719831}, {879.5921481593675, 
      97.6388972207393}, {880.041582714643, 100.1877672431811}, {
      879.7548686849741, 99.36228350882618}, {879.4552456481238, 
      97.66303682719831}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.522961341569, 
      98.52713587695972}, {879.6625634525888, 99.31885879116614}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.522961341569, 98.52713587695972}, {879.7548686849741, 
      99.36228350882618}, {880.0340729070135, 100.94572933723902`}, {
      879.6625634525888, 99.31885879116614}, {879.522961341569, 
      98.52713587695972}}], 
     PolygonBox[{{879.7548686849741, 99.36228350882618}, {880.041582714643, 
      100.1877672431811}, {880.4603890477022, 102.56293598580035`}, {
      880.0340729070135, 100.94572933723902`}, {879.7548686849741, 
      99.36228350882618}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.6625634525888, 
      99.31885879116614}, {879.7824425030406, 99.99872667054586}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.6625634525888, 99.31885879116614}, {880.0340729070135, 
      100.94572933723902`}, {880.2738310079169, 102.30546509599846`}, {
      879.7824425030406, 99.99872667054586}, {879.6625634525888, 
      99.31885879116614}}], 
     PolygonBox[{{880.0340729070135, 100.94572933723902`}, {880.4603890477022,
       102.56293598580035`}, {880.8200261990573, 104.60253962393949`}, {
      880.2738310079169, 102.30546509599846`}, {880.0340729070135, 
      100.94572933723902`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.7824425030406, 
      99.99872667054586}, {879.8744289337453, 100.52040764265392`}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.7824425030406, 99.99872667054586}, {880.2738310079169, 
      102.30546509599846`}, {880.4578038693267, 103.34882704021462`}, {
      879.8744289337453, 100.52040764265392`}, {879.7824425030406, 
      99.99872667054586}}], 
     PolygonBox[{{880.2738310079169, 102.30546509599846`}, {880.8200261990573,
       104.60253962393949`}, {881.0959854911719, 106.16758254026374`}, {
      880.4578038693267, 103.34882704021462`}, {880.2738310079169, 
      102.30546509599846`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.8744289337453, 
      100.52040764265392`}, {879.9322540214655, 100.84835001135977`}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.8744289337453, 100.52040764265392`}, {880.4578038693267,
       103.34882704021462`}, {880.5734540447672, 104.00471177762631`}, {
      879.9322540214655, 100.84835001135977`}, {879.8744289337453, 
      100.52040764265392`}}], 
     PolygonBox[{{880.4578038693267, 103.34882704021462`}, {881.0959854911719,
       106.16758254026374`}, {881.2694607543326, 107.15140964638127`}, {
      880.5734540447672, 104.00471177762631`}, {880.4578038693267, 
      103.34882704021462`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.9322540214655, 
      100.84835001135977`}, {879.9519770820336, 100.96020504618647`}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.9322540214655, 100.84835001135977`}, {880.5734540447672,
       104.00471177762631`}, {880.6129001659033, 104.22842184727972`}, {
      879.9519770820336, 100.96020504618647`}, {879.9322540214655, 
      100.84835001135977`}}], 
     PolygonBox[{{880.5734540447672, 104.00471177762631`}, {881.2694607543326,
       107.15140964638127`}, {881.3286299360368, 107.48697475086138`}, {
      880.6129001659033, 104.22842184727972`}, {880.5734540447672, 
      104.00471177762631`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.9519770820336, 
      100.96020504618647`}, {879.9322540214655, 100.84835001135977`}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.9519770820336, 100.96020504618647`}, {880.6129001659033,
       104.22842184727972`}, {880.5734540447672, 104.00471177762631`}, {
      879.9322540214655, 100.84835001135977`}, {879.9519770820336, 
      100.96020504618647`}}], 
     PolygonBox[{{880.6129001659033, 104.22842184727972`}, {881.3286299360368,
       107.48697475086138`}, {881.2694607543326, 107.15140964638127`}, {
      880.5734540447672, 104.00471177762631`}, {880.6129001659033, 
      104.22842184727972`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.9322540214655, 
      100.8483500113598}, {879.8744289337453, 100.52040764265392`}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.9322540214655, 100.8483500113598}, {880.5734540447672, 
      104.00471177762631`}, {880.4578038693267, 103.34882704021462`}, {
      879.8744289337453, 100.52040764265392`}, {879.9322540214655, 
      100.8483500113598}}], 
     PolygonBox[{{880.5734540447672, 104.00471177762631`}, {881.2694607543328,
       107.15140964638127`}, {881.0959854911719, 106.16758254026374`}, {
      880.4578038693267, 103.34882704021462`}, {880.5734540447672, 
      104.00471177762631`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.8744289337453, 
      100.52040764265392`}, {879.7824425030406, 99.99872667054586}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.8744289337453, 100.52040764265392`}, {880.4578038693267,
       103.34882704021462`}, {880.2738310079169, 102.30546509599846`}, {
      879.7824425030406, 99.99872667054586}, {879.8744289337453, 
      100.52040764265392`}}], 
     PolygonBox[{{880.4578038693267, 103.34882704021462`}, {881.0959854911719,
       106.16758254026374`}, {880.8200261990573, 104.60253962393949`}, {
      880.2738310079169, 102.30546509599846`}, {880.4578038693267, 
      103.34882704021462`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.7824425030406, 
      99.99872667054586}, {879.6625634525888, 99.31885879116614}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.7824425030406, 99.99872667054586}, {880.2738310079169, 
      102.30546509599846`}, {880.0340729070135, 100.94572933723902`}, {
      879.6625634525888, 99.31885879116614}, {879.7824425030406, 
      99.99872667054586}}], 
     PolygonBox[{{880.2738310079169, 102.30546509599846`}, {880.8200261990573,
       104.60253962393949`}, {880.4603890477022, 102.56293598580035`}, {
      880.0340729070135, 100.94572933723902`}, {880.2738310079169, 
      102.30546509599846`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.6625634525888, 
      99.31885879116614}, {879.522961341569, 98.52713587695973}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.6625634525888, 99.31885879116614}, {880.0340729070135, 
      100.94572933723902`}, {879.7548686849741, 99.36228350882618}, {
      879.522961341569, 98.52713587695973}, {879.6625634525888, 
      99.31885879116614}}], 
     PolygonBox[{{880.0340729070135, 100.94572933723902`}, {880.4603890477022,
       102.56293598580035`}, {880.041582714643, 100.1877672431811}, {
      879.7548686849741, 99.36228350882618}, {880.0340729070135, 
      100.94572933723902`}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.522961341569, 
      98.52713587695973}, {879.3731498231439, 97.6775125361458}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.522961341569, 98.52713587695973}, {879.7548686849741, 
      99.36228350882618}, {879.4552456481238, 97.66303682719833}, {
      879.3731498231439, 97.6775125361458}, {879.522961341569, 
      98.52713587695973}}], 
     PolygonBox[{{879.7548686849741, 99.36228350882618}, {880.041582714643, 
      100.1877672431811}, {879.5921481593675, 97.63889722073931}, {
      879.4552456481238, 97.66303682719833}, {879.7548686849741, 
      99.36228350882618}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.3731498231439, 
      97.6775125361458}, {879.2233383047187, 96.82788919533186}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.3731498231439, 97.6775125361458}, {879.4552456481238, 
      97.66303682719831}, {879.1556226112734, 95.96379014557047}, {
      879.2233383047187, 96.82788919533186}, {879.3731498231439, 
      97.6775125361458}}], 
     PolygonBox[{{879.4552456481238, 97.66303682719831}, {879.5921481593675, 
      97.6388972207393}, {879.142713604092, 95.09002719829752}, {
      879.1556226112734, 95.96379014557047}, {879.4552456481238, 
      97.66303682719831}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.2233383047187, 
      96.82788919533186}, {879.083736193699, 96.03616628112545}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.2233383047187, 96.82788919533186}, {879.1556226112734, 
      95.96379014557047}, {878.876418389234, 94.38034431715764}, {
      879.083736193699, 96.03616628112545}, {879.2233383047187, 
      96.82788919533186}}], 
     PolygonBox[{{879.1556226112734, 95.96379014557047}, {879.142713604092, 
      95.09002719829752}, {878.7239072710329, 92.71485845567827}, {
      878.876418389234, 94.38034431715764}, {879.1556226112734, 
      95.96379014557047}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {879.083736193699, 
      96.03616628112545}, {878.9638571432472, 95.35629840174573}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{879.083736193699, 96.03616628112545}, {878.876418389234, 
      94.38034431715764}, {878.6366602883306, 93.02060855839821}, {
      878.9638571432472, 95.35629840174573}, {879.083736193699, 
      96.03616628112545}}], 
     PolygonBox[{{878.876418389234, 94.38034431715764}, {878.7239072710329, 
      92.71485845567827}, {878.3642701196777, 90.67525481753913}, {
      878.6366602883306, 93.02060855839821}, {878.876418389234, 
      94.38034431715764}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.9638571432472, 
      95.35629840174573}, {878.8718707125424, 94.83461742963763}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.9638571432472, 95.35629840174573}, {878.6366602883306, 
      93.02060855839821}, {878.4526874269209, 91.97724661418204}, {
      878.8718707125424, 94.83461742963763}, {878.9638571432472, 
      95.35629840174573}}], 
     PolygonBox[{{878.6366602883306, 93.02060855839821}, {878.3642701196777, 
      90.67525481753911}, {878.0883108275632, 89.11021190121488}, {
      878.4526874269209, 91.97724661418204}, {878.6366602883306, 
      93.02060855839821}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.8718707125424, 
      94.83461742963763}, {878.8140456248223, 94.5066750609318}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.8718707125424, 94.83461742963763}, {878.4526874269209, 
      91.97724661418204}, {878.3370372514803, 91.32136187677034}, {
      878.8140456248223, 94.5066750609318}, {878.8718707125424, 
      94.83461742963763}}], 
     PolygonBox[{{878.4526874269209, 91.97724661418204}, {878.0883108275632, 
      89.11021190121488}, {877.9148355644024, 88.12638479509732}, {
      878.3370372514803, 91.32136187677034}, {878.4526874269209, 
      91.97724661418204}}], 
     PolygonBox[{{879.3457921522566, 97.68233643165254}, {878.8140456248223, 
      94.5066750609318}, {878.7943225642541, 94.3948200261051}, {
      879.3457921522566, 97.68233643165254}, {879.3457921522566, 
      97.68233643165254}}], 
     PolygonBox[{{878.8140456248223, 94.5066750609318}, {878.3370372514803, 
      91.32136187677034}, {878.2975911303442, 91.09765180711693}, {
      878.7943225642541, 94.3948200261051}, {878.8140456248223, 
      94.5066750609318}}], 
     PolygonBox[{{878.3370372514803, 91.32136187677034}, {877.9148355644024, 
      88.12638479509732}, {877.8556663826982, 87.79081969061721}, {
      878.2975911303442, 91.09765180711693}, {878.3370372514803, 
      91.32136187677034}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfe783PQbed0O3/gMT835FOow55Pf1MD8bodnmQ4b
xDjCHJQW+d3ZUtDt4HzNfBuve5hDxvVitldF3Q6Mxb/jzVeHOSQZP+0/Vdrt
ICC1zvaAbriDxiZ2d5XKbgc+mQLGw0fDHb5N09mxp6bbQUNVe+PjjAiHI9WB
mqEN3Q4ues8SWHgiHbp+FT9Y19zt4GSwQoV9SaRDS9jTzP62boeA61FME9Si
HE51c0050gE0r0Ruzc6uKIcAa67b6l3dDlkPRDdtOBnlIBe3m2MhkB9lrTpD
636UQxCaPLp+dPPR7Ud3H7r70f2H7n/08IGFnws0/NDDFz38AbXGrqI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQnddwumeWbbdD0YE354QswhysF9fsErbrdkiS/rOl
xzfM4VBQDWO5fbfD/vbPu5p7whw4OxZqr3HsdqhR2Z6y9kOYA9MToa09Lt0O
3aczncyKwx1OJJnmPHPvdug8q81myR3hMM096m6dd7fDkmvPtkaui3BI0an3
E/cHmnd/YWpVYKSD1uqFrIVB3Q57HyZr1r6MdFBmF+4PDO12ON0hxs6WE+WQ
ZWOxsy0caJ7qrQ36F6IcPr42Z3gV0e3wbOLFbWr80Q77+F7qJkd2O1x782DO
ApVoDHmY/i6ofpj5Z6Dmo9uP7j5096P7D+b/Hqj/YeFTCw0f9PBDD1/08AcA
aSCxPQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{877.8556663826982, 87.79081969061721}, {871.7004638575143, 
       88.87614796753203}, {871.7596330392183, 89.21171307201215}, {
       877.9148355644024, 88.12638479509732}, {877.8556663826982, 
       87.79081969061721}}], 
      LineBox[{{877.9148355644024, 88.12638479509732}, {871.7596330392183, 
       89.21171307201215}, {871.9331083023792, 90.19554017812969}, {
       878.0883108275632, 89.11021190121487}, {877.9148355644024, 
       88.12638479509732}}], 
      LineBox[{{878.0883108275632, 89.11021190121487}, {871.9331083023792, 
       90.19554017812969}, {872.2090675944938, 91.76058309445392}, {
       878.3642701196777, 90.67525481753911}, {878.0883108275632, 
       89.11021190121487}}], 
      LineBox[{{878.3642701196777, 90.67525481753911}, {872.2090675944938, 
       91.76058309445392}, {872.5687047458489, 93.80018673259308}, {
       878.7239072710329, 92.71485845567827}, {878.3642701196777, 
       90.67525481753911}}], 
      LineBox[{{878.7239072710329, 92.71485845567827}, {872.5687047458489, 
       93.80018673259308}, {872.987511078908, 96.17535547521233}, {
       879.142713604092, 95.09002719829752}, {878.7239072710329, 
       92.71485845567827}}], 
      LineBox[{{879.142713604092, 95.09002719829752}, {872.987511078908, 
       96.17535547521233}, {873.4369456341835, 98.72422549765412}, {
       879.5921481593675, 97.6388972207393}, {879.142713604092, 
       95.09002719829752}}], 
      LineBox[{{879.5921481593675, 97.6388972207393}, {873.4369456341835, 
       98.72422549765412}, {873.886380189459, 101.27309552009591`}, {
       880.041582714643, 100.1877672431811}, {879.5921481593675, 
       97.6388972207393}}], 
      LineBox[{{880.041582714643, 100.1877672431811}, {873.886380189459, 
       101.27309552009591`}, {874.3051865225182, 103.64826426271516`}, {
       880.4603890477022, 102.56293598580035`}, {880.041582714643, 
       100.1877672431811}}], 
      LineBox[{{880.4603890477022, 102.56293598580035`}, {874.3051865225182, 
       103.64826426271516`}, {874.6648236738732, 105.6878679008543}, {
       880.8200261990573, 104.60253962393949`}, {880.4603890477022, 
       102.56293598580035`}}], 
      LineBox[{{880.8200261990573, 104.60253962393949`}, {874.6648236738732, 
       105.6878679008543}, {874.9407829659879, 107.25291081717855`}, {
       881.0959854911719, 106.16758254026374`}, {880.8200261990573, 
       104.60253962393949`}}], 
      LineBox[{{881.0959854911719, 106.16758254026374`}, {874.9407829659879, 
       107.25291081717855`}, {875.1142582291487, 108.23673792329609`}, {
       881.2694607543326, 107.15140964638127`}, {881.0959854911719, 
       106.16758254026374`}}], 
      LineBox[{{881.2694607543326, 107.15140964638127`}, {875.1142582291487, 
       108.23673792329609`}, {875.1734274108528, 108.5723030277762}, {
       881.3286299360368, 107.48697475086138`}, {881.2694607543326, 
       107.15140964638127`}}], 
      LineBox[{{881.3286299360368, 107.48697475086138`}, {875.1734274108528, 
       108.5723030277762}, {875.1142582291487, 108.23673792329609`}, {
       881.2694607543326, 107.15140964638127`}, {881.3286299360368, 
       107.48697475086138`}}], 
      LineBox[{{881.2694607543328, 107.15140964638127`}, {875.1142582291487, 
       108.23673792329609`}, {874.9407829659879, 107.25291081717856`}, {
       881.0959854911719, 106.16758254026374`}, {881.2694607543328, 
       107.15140964638127`}}], 
      LineBox[{{881.0959854911719, 106.16758254026374`}, {874.9407829659879, 
       107.25291081717856`}, {874.6648236738732, 105.68786790085431`}, {
       880.8200261990573, 104.60253962393949`}, {881.0959854911719, 
       106.16758254026374`}}], 
      LineBox[{{880.8200261990573, 104.60253962393949`}, {874.6648236738732, 
       105.68786790085431`}, {874.3051865225182, 103.64826426271516`}, {
       880.4603890477022, 102.56293598580035`}, {880.8200261990573, 
       104.60253962393949`}}], 
      LineBox[{{880.4603890477022, 102.56293598580035`}, {874.3051865225182, 
       103.64826426271516`}, {873.886380189459, 101.27309552009591`}, {
       880.041582714643, 100.1877672431811}, {880.4603890477022, 
       102.56293598580035`}}], 
      LineBox[{{880.041582714643, 100.1877672431811}, {873.886380189459, 
       101.27309552009591`}, {873.4369456341835, 98.72422549765413}, {
       879.5921481593675, 97.63889722073931}, {880.041582714643, 
       100.1877672431811}}], 
      LineBox[{{879.5921481593675, 97.6388972207393}, {873.4369456341835, 
       98.72422549765412}, {872.987511078908, 96.17535547521233}, {
       879.142713604092, 95.09002719829752}, {879.5921481593675, 
       97.6388972207393}}], 
      LineBox[{{879.142713604092, 95.09002719829752}, {872.987511078908, 
       96.17535547521233}, {872.5687047458489, 93.80018673259309}, {
       878.7239072710329, 92.71485845567827}, {879.142713604092, 
       95.09002719829752}}], 
      LineBox[{{878.7239072710329, 92.71485845567827}, {872.5687047458489, 
       93.80018673259309}, {872.2090675944938, 91.76058309445393}, {
       878.3642701196777, 90.67525481753913}, {878.7239072710329, 
       92.71485845567827}}], 
      LineBox[{{878.3642701196777, 90.67525481753911}, {872.2090675944938, 
       91.76058309445393}, {871.9331083023792, 90.19554017812969}, {
       878.0883108275632, 89.11021190121488}, {878.3642701196777, 
       90.67525481753911}}], 
      LineBox[{{878.0883108275632, 89.11021190121488}, {871.9331083023792, 
       90.19554017812969}, {871.7596330392183, 89.21171307201215}, {
       877.9148355644024, 88.12638479509732}, {878.0883108275632, 
       89.11021190121488}}], 
      LineBox[{{877.9148355644024, 88.12638479509732}, {871.7596330392183, 
       89.21171307201215}, {871.7004638575143, 88.87614796753203}, {
       877.8556663826982, 87.79081969061721}, {877.9148355644024, 
       88.12638479509732}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {450., 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{450., 0.}, {459.18621543719763`, -3.9543388611028942`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{459.18621543719763`, -3.9543388611028942`}, {
       659.1862154371977, -3.9543388611028942`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{659.1862154371977, -3.9543388611028942`}, {
       665.1934363220911, -4.133769426549076}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{659.1862154371977, -3.9543388611028942`}, {0., 
       112.27797623157788`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{665.1934363220911, -4.133769426549076}, {
       705.1934363220911, -4.133769426549076}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{705.1934363220911, -4.133769426549076}, {
       714.3796517592887, -8.08810828765197}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{714.3796517592887, -8.08810828765197}, {
       764.3796517592887, -8.088108287651966}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{764.3796517592887, -8.088108287651966}, {
       773.5658671964862, -12.042447148754862`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{773.5658671964862, -12.042447148754862`}, {
       1273.5658671964866`, -12.042447148754865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1273.5658671964866`, -12.042447148754865`}, {
       1225.269575882033, 0.8985051063712362}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1225.269575882033, 0.8985051063712362}, {1217.419831353431, 
       7.0956706457705625`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1217.419831353431, 7.0956706457705625`}, {879.3457921522569, 
       97.6823364316528}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{450., 0.}, {459.18621543719763`, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}, {
      665.1934363220911, -4.133769426549076}, {0., 112.27797623157788`}, {
      705.1934363220911, -4.133769426549076}, {
      714.3796517592887, -8.08810828765197}, {
      764.3796517592887, -8.088108287651966}, {
      773.5658671964862, -12.042447148754862`}, {
      1273.5658671964866`, -12.042447148754865`}, {1225.269575882033, 
      0.8985051063712362}, {1217.419831353431, 7.0956706457705625`}, {
      879.3457921522569, 97.6823364316528}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"LFM\"\>", {882.9826588087744, 135.58434363056597`}, \
{0., 0.}], 
    InsetBox["\<\"OC\"\>", {658.8665657453565, -42.02909129441862}, {0., 0.}],
     InsetBox["\<\"Diode\"\>", {783.9860743743933, 24.796191021010337`}, \
{0., 0.}], 
    InsetBox["\<\"BRF\"\>", {469.6064226151047, 32.88429930866231}, {0., 0.}],
     InsetBox["\<\"Rhomb\"\>", {724.7998589371957, 28.75052988211323}, \
{0., 0.}], 
    InsetBox["\<\"UFM\"\>", {1272.2383553261955`, -45.10979362382976}, \
{0., 0.}], 
    InsetBox["\<\"AC\"\>", {1197.8201429710316`, -25.790773296167654`}, \
{0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.60130149313935*^9, 3.614709258564961*^9, 
  3.614729115072054*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"During evaluation of In[172]:="]
}, Open  ]],

Cell["Pilot trace for the laser cavity design.", "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 StyleBox["Tweeter", "MB"],
 " must be placed at the geometric crossover between the input to ",
 StyleBox["BRF", "MB"],
 " and the output from ",
 StyleBox["LFM", "MB"],
 ".  It will have to reflect toward both directions.  ",
 StyleBox["MoveReflected", "MB"],
 " is the perfect directive for this purpose."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 "Unfortunately, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " has no built-in call to obtain the ideal placement.  You must guess it \
from screen coordinates.  The guess will be reasonable, however.  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " features a keystroke mechanism that enables you to obtain plot coordinates \
from mouse movements.  In the present case, put ",
 StyleBox["Tweeter", "MB"],
 " at ",
 StyleBox["{178.95,0}", "MB"],
 ".  Using ",
 StyleBox["Append", "MB"],
 ", a standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function, construct the final system and trace it."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"finalcavity", "=", 
  RowBox[{"Append", "[", "\[IndentingNewLine]", 
   RowBox[{"partialcavity", ",", "\[IndentingNewLine]", 
    RowBox[{"MoveReflected", "[", "\[IndentingNewLine]", 
     RowBox[{"Tweeter", ",", 
      RowBox[{"{", 
       RowBox[{"429.728", ",", 
        RowBox[{"-", "67.4776"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"178.95", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"450", ",", "0"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"In[173]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"BRF\"\>", ",", "450.`", ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"OC\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"659.1862154371977`", ",", 
          RowBox[{"-", "3.9543388611028942`"}]}], "}"}], ",", 
        RowBox[{"-", "4.999999999999999`"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"Rhomb\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"705.1934363220911`", ",", 
          RowBox[{"-", "4.133769426549076`"}]}], "}"}], ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"Diode\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"764.3796517592887`", ",", 
          RowBox[{"-", "8.08810828765197`"}]}], "}"}], ",", 
        RowBox[{"-", "23.300318806911935`"}], ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"UFM\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"1273.5658671964864`", ",", 
          RowBox[{"-", "12.042447148754864`"}]}], "}"}], ",", 
        RowBox[{"-", "7.500000000000001`"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"AC\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"1225.2695758820328`", ",", "0.8985051063711769`"}], "}"}], 
        ",", "141.69968119308808`", ",", "180"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"LFM\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"879.3457921522568`", ",", "97.68233643165254`"}], "}"}], 
        ",", "170.00000000000003`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"Tweeter\"\>", ",", "178.95`", ",", 
        "172.46996917583195`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.563404242668007*^9, 3.56345813670721*^9, 
  3.564487581202582*^9, 3.5661006742177153`*^9, 3.6013012411062937`*^9, 
  3.601301493293696*^9, 3.614709259083617*^9, 3.614729115204609*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"Out[173]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"system", "=", 
   RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"SingleRay", "[", "]"}], ",", "250"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Resonate", "[", "finalcavity", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"75", " ", "cm"}], ",", 
          RowBox[{"30", " ", "cm"}], ",", 
          RowBox[{"GraphicDesign", "\[Rule]", "Off"}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"QuickTrace", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"In[174]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{658.3146580097211, -13.916285842020349`}, {
      664.2918261982716, -14.4392202985063}, {
      664.5823453407637, -11.11857130486715}, {
      658.6051771522133, -10.595636848381199`}, {
      658.3146580097211, -13.916285842020349`}}], 
     PolygonBox[{{658.6051771522133, -10.595636848381199`}, {
      664.5823453407637, -11.11857130486715}, {
      664.872864483256, -7.797922311227998}, {
      658.8956962947055, -7.274987854742047}, {
      658.6051771522133, -10.595636848381199`}}], 
     PolygonBox[{{658.8956962947055, -7.274987854742047}, {
      664.872864483256, -7.797922311227998}, {
      665.1633836257481, -4.477273317588845}, {
      659.1862154371977, -3.9543388611028942`}, {
      658.8956962947055, -7.274987854742047}}], 
     PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
      665.1633836257481, -4.4772733175888435`}, {
      665.4539027682403, -1.1566243239496927`}, {
      659.4767345796898, -0.6336898674637435}, {
      659.1862154371977, -3.9543388611028942`}}], 
     PolygonBox[{{659.4767345796898, -0.6336898674637435}, {
      665.4539027682403, -1.1566243239496927`}, {665.7444219107325, 
      2.16402466968946}, {659.7672537221821, 2.6869591261754073`}, {
      659.4767345796898, -0.6336898674637435}}], 
     PolygonBox[{{659.7672537221821, 2.6869591261754073`}, {665.7444219107325,
       2.164024669689459}, {666.0349410532247, 5.48467366332861}, {
      660.0577728646742, 6.007608119814558}, {659.7672537221821, 
      2.6869591261754073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{658.3146580097211, -13.916285842020349`}, {
       658.6051771522133, -10.595636848381199`}, {
       658.8956962947055, -7.274987854742047}, {
       659.1862154371977, -3.9543388611028942`}, {
       659.4767345796898, -0.6336898674637435}, {659.7672537221821, 
       2.6869591261754073`}, {660.0577728646742, 6.007608119814561}, {
       666.0349410532247, 5.4846736633286115`}, {665.7444219107325, 
       2.1640246696894607`}, {665.4539027682403, -1.156624323949691}, {
       665.1633836257481, -4.4772733175888435`}, {
       664.872864483256, -7.797922311227994}, {
       664.5823453407637, -11.118571304867146`}, {
       664.2918261982716, -14.4392202985063}, {
       658.3146580097211, -13.916285842020349`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.954338861102894}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.954338861102894}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.477273317588843}, {
        659.1862154371977, -3.954338861102894}, {
        659.1862154371977, -3.954338861102894}}], 
       PolygonBox[{{659.1862154371977, -3.954338861102894}, {
        665.1633836257481, -4.477273317588843}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.1862154371977, -3.954338861102894}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028933`}, {
        665.1633836257481, -4.4772733175888435`}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.1862154371977, -3.9543388611028933`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028933`}, {
        665.1633836257481, -4.4772733175888435`}, {
        665.1633836257481, -4.4772733175888435`}, {
        659.1862154371977, -3.954338861102893}, {
        659.1862154371977, -3.9543388611028933`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         659.1862154371977, -3.9543388611028942`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         665.1633836257481, -4.4772733175888435`}, {
         659.1862154371977, -3.9543388611028942`}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{1272.851261246445, -16.991512293541824`}, {
          1278.861905403629, -17.782828608944225`}, {
          1279.079449057329, -16.13042050665454}, {
          1273.103237841273, -15.343637373950951`}, {
          1272.851261246445, -16.991512293541824`}}], 
         PolygonBox[{{1273.103237841273, -15.343637373950951`}, {
          1279.079449057329, -16.13042050665454}, {
          1279.2969927110291`, -14.47801240436486}, {
          1273.3414383894908`, -13.69394880341692}, {
          1273.103237841273, -15.343637373950951`}}], 
         PolygonBox[{{1273.3414383894908`, -13.69394880341692}, {
          1279.2969927110291`, -14.47801240436486}, {
          1279.514536364729, -12.825604302075174`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.3414383894908`, -13.69394880341692}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1279.514536364729, -12.825604302075174`}, {
          1279.732080018429, -11.17319619978549}, {
          1273.7765256968908`, -10.389132598837552`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.7765256968908`, -10.389132598837552`}, {
          1279.732080018429, -11.17319619978549}, {
          1279.9496236721293`, -9.520788097495807}, {
          1273.9734124560734`, -8.734004964792216}, {
          1273.7765256968908`, -10.389132598837552`}}], 
         PolygonBox[{{1273.9734124560734`, -8.734004964792216}, {
          1279.9496236721293`, -9.520788097495807}, {
          1280.1671673258293`, -7.868379995206123}, {
          1274.1565231686452`, -7.077063679803722}, {
          1273.9734124560734`, -8.734004964792216}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1272.851261246445, -16.991512293541824`}, {
           1273.103237841273, -15.343637373950951`}, {
           1273.3414383894908`, -13.69394880341692}, {
           1273.5658671964864`, -12.042447148754864`}, {
           1273.7765256968908`, -10.389132598837552`}, {
           1273.9734124560734`, -8.734004964792216}, {
           1274.1565231686452`, -7.077063679803722}, {
           1280.1671673258293`, -7.868379995206122}, {
           1279.9496236721293`, -9.520788097495807}, {
           1279.732080018429, -11.17319619978549}, {
           1279.514536364729, -12.825604302075174`}, {
           1279.2969927110291`, -14.478012404364858`}, {
           1279.079449057329, -16.13042050665454}, {
           1278.861905403629, -17.782828608944225`}, {
           1272.851261246445, -16.991512293541824`}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           PolygonBox[{{1273.503892207545, -12.034287986672773`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.5383251486733`, -12.038821169371584`}, {
            1273.503892207545, -12.034287986672773`}}], 
           PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.5589820431908`, -12.041540701127236`}, {
            1273.5383251486733`, -12.038821169371584`}}], 
           PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.5658671964864`, -12.042447148754864`}, {
            1273.5589820431908`, -12.041540701127236`}}], 
           PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.5589820431908`, -12.041540701127236`}, {
            1273.5658671964864`, -12.042447148754864`}}], 
           PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.5383251486733`, -12.038821169371584`}, {
            1273.5589820431908`, -12.041540701127236`}}], 
           PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
            1279.514536364729, -12.825604302075174`}, {
            1279.514536364729, -12.825604302075174`}, {
            1273.503892207545, -12.034287986672773`}, {
            1273.5383251486733`, -12.038821169371584`}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            LineBox[{{1273.503892207545, -12.034287986672773`}, {
             1273.5383251486733`, -12.038821169371584`}, {
             1273.5589820431908`, -12.041540701127236`}, {
             1273.5658671964864`, -12.042447148754864`}, {
             1273.5589820431908`, -12.041540701127236`}, {
             1273.5383251486733`, -12.038821169371584`}, {
             1273.503892207545, -12.034287986672773`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1279.514536364729, -12.825604302075174`}, {
             1273.503892207545, -12.034287986672773`}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             PolygonBox[{{881.3286299360368, 107.48697475086138`}, {
              875.1734274108528, 108.5723030277762}, {874.594600151963, 
              105.28961051773551`}, {880.6129001659033, 
              104.22842184727972`}, {881.3286299360368, 
              107.48697475086138`}}], 
             PolygonBox[{{880.6129001659033, 104.22842184727972`}, {
              874.594600151963, 105.28961051773551`}, {874.0157728930733, 
              102.00691800769481`}, {879.9519770820336, 
              100.96020504618647`}, {880.6129001659033, 
              104.22842184727972`}}], 
             PolygonBox[{{879.9519770820336, 100.96020504618647`}, {
              874.0157728930733, 102.00691800769481`}, {873.4369456341835, 
              98.72422549765412}, {879.3457921522566, 97.68233643165254}, {
              879.9519770820336, 100.96020504618647`}}], 
             PolygonBox[{{879.3457921522566, 97.68233643165254}, {
              873.4369456341835, 98.72422549765412}, {872.8581183752938, 
              95.44153298761343}, {878.7943225642541, 94.3948200261051}, {
              879.3457921522566, 97.68233643165254}}], 
             PolygonBox[{{878.7943225642541, 94.3948200261051}, {
              872.8581183752938, 95.44153298761343}, {872.279291116404, 
              92.15884047757272}, {878.2975911303442, 91.09765180711693}, {
              878.7943225642541, 94.3948200261051}}], 
             PolygonBox[{{878.2975911303442, 91.09765180711693}, {
              872.279291116404, 92.15884047757274}, {871.7004638575143, 
              88.87614796753203}, {877.8556663826982, 87.79081969061723}, {
              878.2975911303442, 91.09765180711693}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], 
              LineBox[{{881.3286299360368, 107.48697475086138`}, {
               880.6129001659033, 104.22842184727972`}, {879.9519770820336, 
               100.96020504618647`}, {879.3457921522566, 97.68233643165254}, {
               878.7943225642541, 94.3948200261051}, {878.2975911303442, 
               91.09765180711693}, {877.8556663826982, 87.79081969061721}, {
               871.7004638575143, 88.87614796753203}, {872.279291116404, 
               92.15884047757272}, {872.8581183752938, 95.44153298761343}, {
               873.4369456341835, 98.72422549765412}, {874.0157728930733, 
               102.00691800769481`}, {874.594600151963, 105.2896105177355}, {
               875.1734274108528, 108.5723030277762}, {881.3286299360368, 
               107.48697475086138`}}], 
              {GrayLevel[0.5], EdgeForm[None], 
               PolygonBox[{{879.5921481593675, 97.6388972207393}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.4552456481238, 97.66303682719831}, {
                879.5921481593675, 97.6388972207393}}], 
               PolygonBox[{{879.4552456481238, 97.66303682719831}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.3731498231439, 97.6775125361458}, {
                879.4552456481238, 97.66303682719831}}], 
               PolygonBox[{{879.3731498231439, 97.6775125361458}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.3457921522566, 97.68233643165254}, {
                879.3731498231439, 97.6775125361458}}], 
               PolygonBox[{{879.3457921522566, 97.68233643165254}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.3731498231439, 97.6775125361458}, {
                879.3457921522566, 97.68233643165254}}], 
               PolygonBox[{{879.3731498231439, 97.6775125361458}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.4552456481238, 97.66303682719831}, {
                879.3731498231439, 97.6775125361458}}], 
               PolygonBox[{{879.4552456481238, 97.66303682719831}, {
                873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                98.72422549765412}, {879.5921481593675, 97.6388972207393}, {
                879.4552456481238, 97.66303682719831}}], 
               {GrayLevel[0], AbsoluteThickness[0.5], 
                LineBox[{{879.5921481593675, 97.6388972207393}, {
                 879.4552456481238, 97.66303682719831}, {879.3731498231439, 
                 97.6775125361458}, {879.3457921522566, 97.68233643165254}, {
                 879.3731498231439, 97.6775125361458}, {879.4552456481238, 
                 97.66303682719831}, {879.5921481593675, 97.6388972207393}, {
                 873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                 98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
                 873.4369456341835, 98.72422549765412}, {873.4369456341835, 
                 98.72422549765412}, {873.4369456341835, 98.72422549765412}, {
                 873.4369456341835, 98.72422549765412}, {879.5921481593675, 
                 97.6388972207393}}], 
                {GrayLevel[0.5], EdgeForm[None], 
                 PolygonBox[{{180.50845744401832`, 9.880981157884484}, {
                  174.31220039993167`, 10.700038077951227`}, {
                  173.8753809767203, 7.395450372560978}, {179.93382238498074`,
                   6.594610716467255}, {180.50845744401832`, 
                  9.880981157884484}}], 
                 PolygonBox[{{179.93382238498074`, 6.594610716467255}, {
                  173.8753809767203, 7.395450372560978}, {173.43856155350892`,
                   4.090862667170731}, {179.41435956673237`, 
                  3.300947290706027}, {179.93382238498074`, 
                  6.594610716467255}}], 
                 PolygonBox[{{179.41435956673237`, 3.300947290706027}, {
                  173.43856155350892`, 4.090862667170731}, {
                  173.00174213029754`, 0.7862749617804803}, {
                  178.94999999999996`, 0.}, {179.41435956673237`, 
                  3.300947290706027}}], 
                 PolygonBox[{{178.94999999999996`, 0.}, {173.00174213029754`, 
                  0.7862749617804785}, {
                  172.56492270708617`, -2.5183127436097696`}, {
                  178.54072072030962`, -3.308228120074471}, {
                  178.94999999999996`, 0.}}], 
                 PolygonBox[{{178.54072072030962`, -3.308228120074471}, {
                  172.56492270708617`, -2.5183127436097696`}, {
                  172.1281032838748, -5.82290044900002}, {
                  178.18654469213524`, -6.623740105093738}, {
                  178.54072072030962`, -3.308228120074471}}], 
                 PolygonBox[{{178.18654469213524`, -6.623740105093738}, {
                  172.1281032838748, -5.822900449000018}, {
                  171.69128386066342`, -9.127488154390269}, {
                  177.88754090475007`, -9.946545074457013}, {
                  178.18654469213524`, -6.623740105093738}}], 
                 {GrayLevel[0], AbsoluteThickness[0.5], 
                  LineBox[{{180.50845744401832`, 9.880981157884484}, {
                   179.93382238498074`, 6.594610716467255}, {
                   179.41435956673237`, 3.300947290706027}, {
                   178.94999999999996`, 0.}, {
                   178.54072072030962`, -3.308228120074471}, {
                   178.18654469213524`, -6.623740105093738}, {
                   177.88754090475007`, -9.946545074457013}, {
                   171.69128386066342`, -9.12748815439027}, {
                   172.1281032838748, -5.82290044900002}, {
                   172.56492270708617`, -2.5183127436097714`}, {
                   173.00174213029754`, 0.7862749617804785}, {
                   173.43856155350892`, 4.090862667170727}, {
                   173.8753809767203, 7.395450372560974}, {
                   174.31220039993167`, 10.700038077951227`}, {
                   180.50845744401832`, 9.880981157884484}}], 
                  {GrayLevel[0.5], EdgeForm[None], 
                   PolygonBox[{{179.1979991743842, -0.03278195828626451}, {
                    173.00174213029754`, 0.7862749617804773}, {
                    173.00174213029754`, 0.7862749617804775}, {
                    179.060183538558, -0.014564694313243365`}, {
                    179.1979991743842, -0.03278195828626451}}], 
                   PolygonBox[{{179.060183538558, -0.014564694313243365`}, {
                    173.00174213029754`, 0.7862749617804775}, {
                    173.00174213029754`, 0.7862749617804777}, {
                    178.977540143521, -0.003640414684223714}, {
                    179.060183538558, -0.014564694313243365`}}], 
                   PolygonBox[{{178.977540143521, -0.003640414684223714}, {
                    173.00174213029754`, 0.7862749617804777}, {
                    173.00174213029754`, 0.786274961780478}, {
                    178.94999999999996`, 0.}, {
                    178.977540143521, -0.003640414684223714}}], 
                   PolygonBox[{{178.94999999999996`, 0.}, {
                    173.00174213029754`, 0.786274961780478}, {
                    173.00174213029754`, 0.7862749617804781}, {
                    178.977540143521, -0.003640414684223714}, {
                    178.94999999999996`, 0.}}], 
                   PolygonBox[{{178.977540143521, -0.003640414684223714}, {
                    173.00174213029754`, 0.7862749617804781}, {
                    173.00174213029754`, 0.7862749617804783}, {
                    179.060183538558, -0.014564694313243365`}, {
                    178.977540143521, -0.003640414684223714}}], 
                   PolygonBox[{{179.060183538558, -0.014564694313243365`}, {
                    173.00174213029754`, 0.7862749617804783}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    179.1979991743842, -0.03278195828626451}, {
                    179.060183538558, -0.014564694313243365`}}], 
                   {GrayLevel[0], AbsoluteThickness[0.5], 
                    LineBox[{{179.1979991743842, -0.03278195828626451}, {
                    179.060183538558, -0.014564694313243365`}, {
                    178.977540143521, -0.003640414684223714}, {
                    178.94999999999996`, 0.}, {
                    178.977540143521, -0.003640414684223714}, {
                    179.060183538558, -0.014564694313243365`}, {
                    179.1979991743842, -0.03278195828626451}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    173.00174213029754`, 0.7862749617804785}, {
                    179.1979991743842, \
-0.03278195828626451}}]}}}}}}}}}}}}}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460., 6.581231607541547}, {440., -6.581231607541547}, {
       440., -6.581231607541547}, {460., 6.581231607541547}, {460., 
       6.581231607541547}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{449.184441804226, -10.536737737581726`}, {
       440., -6.5812316075415485`}, {440., -6.5812316075415485`}, {
       449.184441804226, -10.536737737581726`}, {
       449.184441804226, -10.536737737581726`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{469.184441804226, 2.625725477501369}, {
       449.184441804226, -10.536737737581724`}, {
       449.184441804226, -10.536737737581724`}, {469.184441804226, 
       2.625725477501369}, {469.184441804226, 2.625725477501369}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{469.184441804226, 2.625725477501371}, {460., 
       6.5812316075415485`}, {460., 6.5812316075415485`}, {469.184441804226, 
       2.625725477501371}, {469.184441804226, 2.625725477501371}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460.0027038895489, 6.585511099877827}, {
       439.992703889549, -6.583533346812808}, {
       449.1817379146771, -10.541017229918005`}, {469.19173791467705`, 
       2.6280272167726313`}, {460.0027038895489, 6.585511099877827}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{460.0027038895489, 6.585511099877827}, {
       439.992703889549, -6.583533346812808}, {
       449.1817379146771, -10.541017229918005`}, {469.19173791467705`, 
       2.6280272167726313`}, {460.0027038895489, 6.585511099877827}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.4767345796898, -0.6336898674637426}, {
        659.4668353799623, -0.7468382381060339}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.4767345796898, -0.6336898674637426}, {
        659.7672537221821, 2.686959126175409}, {659.7474553227269, 
        2.4606623848908264`}, {659.4668353799623, -0.7468382381060339}, {
        659.4767345796898, -0.6336898674637426}}], 
       PolygonBox[{{659.7672537221821, 2.686959126175409}, {660.0577728646742,
         6.007608119814561}, {660.0280752654913, 5.668163007887689}, {
        659.7474553227269, 2.4606623848908264`}, {659.7672537221821, 
        2.686959126175409}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.4668353799623, -0.7468382381060339}, {
        659.4378123948816, -1.0785724755601578`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.4668353799623, -0.7468382381060339}, {
        659.7474553227269, 2.4606623848908264`}, {659.6894093525655, 
        1.7971939099825787`}, {659.4378123948816, -1.0785724755601578`}, {
        659.4668353799623, -0.7468382381060339}}], 
       PolygonBox[{{659.7474553227269, 2.4606623848908264`}, {
        660.0280752654913, 5.668163007887689}, {659.9410063102495, 
        4.672960295525316}, {659.6894093525655, 1.7971939099825787`}, {
        659.7474553227269, 2.4606623848908264`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.4378123948816, -1.0785724755601578`}, {
        659.3916434929184, -1.6062854397603652`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.4378123948816, -1.0785724755601578`}, {
        659.6894093525655, 1.7971939099825787`}, {659.5970715486392, 
        0.7417679815821638}, {659.3916434929184, -1.6062854397603652`}, {
        659.4378123948816, -1.0785724755601578`}}], 
       PolygonBox[{{659.6894093525655, 1.7971939099825787`}, {
        659.9410063102495, 4.672960295525316}, {659.8024996043599, 
        3.089821402924693}, {659.5970715486392, 0.7417679815821638}, {
        659.6894093525655, 1.7971939099825787`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.3916434929184, -1.6062854397603652`}, {
        659.3314750084438, -2.294014364283318}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.3916434929184, -1.6062854397603652`}, {
        659.5970715486392, 0.7417679815821638}, {
        659.4767345796898, -0.6336898674637417}, {
        659.3314750084438, -2.294014364283318}, {
        659.3916434929184, -1.6062854397603652`}}], 
       PolygonBox[{{659.5970715486392, 0.7417679815821638}, {
        659.8024996043599, 3.089821402924693}, {659.621994150936, 
        1.0266346293558342`}, {659.4767345796898, -0.6336898674637417}, {
        659.5970715486392, 0.7417679815821638}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.3314750084438, -2.294014364283318}, {
        659.2614073242415, -3.094891659448562}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.3314750084438, -2.294014364283318}, {
        659.4767345796898, -0.6336898674637417}, {
        659.3365992112854, -2.2354444577942294`}, {
        659.2614073242415, -3.094891659448562}, {
        659.3314750084438, -2.294014364283318}}], 
       PolygonBox[{{659.4767345796898, -0.6336898674637417}, {
        659.621994150936, 1.0266346293558342`}, {
        659.4117910983292, -1.3759972561398968`}, {
        659.3365992112854, -2.2354444577942294`}, {
        659.4767345796898, -0.6336898674637417}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.2614073242415, -3.094891659448562}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.2614073242415, -3.094891659448562}, {
        659.3365992112854, -2.2354444577942294`}, {
        659.1862154371977, -3.9543388611028925`}, {
        659.1862154371977, -3.9543388611028933`}, {
        659.2614073242415, -3.094891659448562}}], 
       PolygonBox[{{659.3365992112854, -2.2354444577942294`}, {
        659.4117910983292, -1.3759972561398968`}, {
        659.1862154371977, -3.9543388611028916`}, {
        659.1862154371977, -3.9543388611028925`}, {
        659.3365992112854, -2.2354444577942294`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1110235501538, -4.8137860627572255`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.954338861102894}, {
        659.03583166311, -5.673233264411557}, {
        659.1110235501538, -4.8137860627572255`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.954338861102894}, {
        659.1862154371977, -3.954338861102894}, {
        658.9606397760662, -6.532680466065889}, {
        659.03583166311, -5.673233264411557}, {
        659.1862154371977, -3.954338861102894}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.1110235501538, -4.8137860627572255`}, {
        659.0409558659516, -5.61466335792247}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1110235501538, -4.8137860627572255`}, {
        659.03583166311, -5.673233264411557}, {
        658.8956962947055, -7.2749878547420455`}, {
        659.0409558659516, -5.61466335792247}, {
        659.1110235501538, -4.8137860627572255`}}], 
       PolygonBox[{{659.03583166311, -5.673233264411557}, {
        658.9606397760662, -6.532680466065889}, {
        658.7504367234594, -8.93531235156162}, {
        658.8956962947055, -7.2749878547420455`}, {
        659.03583166311, -5.673233264411557}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.0409558659516, -5.61466335792247}, {
        658.980787381477, -6.302392282445423}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.0409558659516, -5.61466335792247}, {
        658.8956962947055, -7.2749878547420455`}, {
        658.7753593257562, -8.650445703787952}, {
        658.980787381477, -6.302392282445423}, {
        659.0409558659516, -5.61466335792247}}], 
       PolygonBox[{{658.8956962947055, -7.2749878547420455`}, {
        658.7504367234594, -8.93531235156162}, {
        658.5699312700355, -10.998499125130481`}, {
        658.7753593257562, -8.650445703787952}, {
        658.8956962947055, -7.2749878547420455`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.980787381477, -6.302392282445423}, {
        658.9346184795138, -6.830105246645631}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.980787381477, -6.302392282445423}, {
        658.7753593257562, -8.650445703787952}, {
        658.6830215218299, -9.705871632188368}, {
        658.9346184795138, -6.830105246645631}, {
        658.980787381477, -6.302392282445423}}], 
       PolygonBox[{{658.7753593257562, -8.650445703787952}, {
        658.5699312700355, -10.998499125130481`}, {
        658.4314245641459, -12.581638017731104`}, {
        658.6830215218299, -9.705871632188368}, {
        658.7753593257562, -8.650445703787952}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.9346184795138, -6.83010524664563}, {
        658.9055954944331, -7.161839484099755}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.9346184795138, -6.83010524664563}, {
        658.6830215218299, -9.705871632188366}, {
        658.6249755516685, -10.369340107096614`}, {
        658.9055954944331, -7.161839484099755}, {
        658.9346184795138, -6.83010524664563}}], 
       PolygonBox[{{658.6830215218299, -9.705871632188366}, {
        658.4314245641459, -12.581638017731102`}, {
        658.344355608904, -13.576840730093474`}, {
        658.6249755516685, -10.369340107096614`}, {
        658.6830215218299, -9.705871632188366}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.9055954944331, -7.161839484099755}, {
        658.8956962947055, -7.2749878547420455`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.9055954944331, -7.161839484099755}, {
        658.6249755516685, -10.369340107096614`}, {
        658.6051771522133, -10.595636848381197`}, {
        658.8956962947055, -7.2749878547420455`}, {
        658.9055954944331, -7.161839484099755}}], 
       PolygonBox[{{658.6249755516685, -10.369340107096614`}, {
        658.344355608904, -13.576840730093474`}, {
        658.3146580097211, -13.916285842020349`}, {
        658.6051771522133, -10.595636848381197`}, {
        658.6249755516685, -10.369340107096614`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.8956962947055, -7.2749878547420455`}, {
        658.9055954944331, -7.161839484099755}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.8956962947055, -7.2749878547420455`}, {
        658.6051771522133, -10.595636848381197`}, {
        658.6249755516685, -10.369340107096615`}, {
        658.9055954944331, -7.161839484099755}, {
        658.8956962947055, -7.2749878547420455`}}], 
       PolygonBox[{{658.6051771522133, -10.595636848381197`}, {
        658.3146580097211, -13.916285842020349`}, {
        658.344355608904, -13.576840730093476`}, {
        658.6249755516685, -10.369340107096615`}, {
        658.6051771522133, -10.595636848381197`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.9055954944331, -7.1618394840997555`}, {
        658.9346184795138, -6.830105246645632}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.9055954944331, -7.1618394840997555`}, {
        658.6249755516685, -10.369340107096617`}, {
        658.6830215218299, -9.705871632188368}, {
        658.9346184795138, -6.830105246645632}, {
        658.9055954944331, -7.1618394840997555`}}], 
       PolygonBox[{{658.6249755516685, -10.369340107096617`}, {
        658.344355608904, -13.576840730093478`}, {
        658.4314245641459, -12.581638017731105`}, {
        658.6830215218299, -9.705871632188368}, {
        658.6249755516685, -10.369340107096617`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.9346184795138, -6.830105246645632}, {
        658.980787381477, -6.302392282445424}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.9346184795138, -6.830105246645632}, {
        658.6830215218299, -9.705871632188368}, {
        658.7753593257562, -8.650445703787954}, {
        658.980787381477, -6.302392282445424}, {
        658.9346184795138, -6.830105246645632}}], 
       PolygonBox[{{658.6830215218299, -9.705871632188368}, {
        658.4314245641459, -12.581638017731105`}, {
        658.5699312700355, -10.998499125130483`}, {
        658.7753593257562, -8.650445703787954}, {
        658.6830215218299, -9.705871632188368}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        658.980787381477, -6.302392282445425}, {
        659.0409558659516, -5.614663357922471}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{658.980787381477, -6.302392282445425}, {
        658.7753593257562, -8.650445703787954}, {
        658.8956962947055, -7.274987854742049}, {
        659.0409558659516, -5.614663357922471}, {
        658.980787381477, -6.302392282445425}}], 
       PolygonBox[{{658.7753593257562, -8.650445703787954}, {
        658.5699312700355, -10.998499125130484`}, {
        658.7504367234594, -8.935312351561626}, {
        658.8956962947055, -7.274987854742049}, {
        658.7753593257562, -8.650445703787954}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.0409558659516, -5.614663357922471}, {
        659.1110235501538, -4.813786062757228}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.0409558659516, -5.614663357922471}, {
        658.8956962947055, -7.274987854742049}, {
        659.03583166311, -5.673233264411563}, {
        659.1110235501538, -4.813786062757228}, {
        659.0409558659516, -5.614663357922471}}], 
       PolygonBox[{{658.8956962947055, -7.274987854742049}, {
        658.7504367234594, -8.935312351561626}, {
        658.9606397760662, -6.532680466065898}, {
        659.03583166311, -5.673233264411563}, {
        658.8956962947055, -7.274987854742049}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.1110235501538, -4.813786062757228}, {
        659.1862154371977, -3.954338861102898}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1110235501538, -4.813786062757228}, {
        659.03583166311, -5.673233264411563}, {
        659.1862154371977, -3.9543388611029013`}, {
        659.1862154371977, -3.954338861102898}, {
        659.1110235501538, -4.813786062757228}}], 
       PolygonBox[{{659.03583166311, -5.673233264411563}, {
        658.9606397760662, -6.532680466065898}, {
        659.1862154371977, -3.954338861102905}, {
        659.1862154371977, -3.9543388611029013`}, {
        659.03583166311, -5.673233264411563}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028947`}, {
        659.2614073242415, -3.094891659448564}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028947`}, {
        659.1862154371977, -3.9543388611028956`}, {
        659.3365992112854, -2.235444457794234}, {
        659.2614073242415, -3.094891659448564}, {
        659.1862154371977, -3.9543388611028947`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028956`}, {
        659.1862154371977, -3.954338861102896}, {
        659.4117910983292, -1.3759972561399034`}, {
        659.3365992112854, -2.235444457794234}, {
        659.1862154371977, -3.9543388611028956`}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.2614073242415, -3.094891659448564}, {
        659.3314750084438, -2.2940143642833206`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.2614073242415, -3.094891659448564}, {
        659.3365992112854, -2.235444457794234}, {
        659.4767345796898, -0.633689867463747}, {
        659.3314750084438, -2.2940143642833206`}, {
        659.2614073242415, -3.094891659448564}}], 
       PolygonBox[{{659.3365992112854, -2.235444457794234}, {
        659.4117910983292, -1.3759972561399034`}, {659.621994150936, 
        1.0266346293558262`}, {659.4767345796898, -0.633689867463747}, {
        659.3365992112854, -2.235444457794234}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.3314750084438, -2.2940143642833206`}, {
        659.3916434929184, -1.6062854397603679`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.3314750084438, -2.2940143642833206`}, {
        659.4767345796898, -0.633689867463747}, {659.5970715486392, 
        0.7417679815821585}, {659.3916434929184, -1.6062854397603679`}, {
        659.3314750084438, -2.2940143642833206`}}], 
       PolygonBox[{{659.4767345796898, -0.633689867463747}, {659.621994150936,
         1.0266346293558262`}, {659.8024996043599, 3.0898214029246858`}, {
        659.5970715486392, 0.7417679815821585}, {
        659.4767345796898, -0.633689867463747}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.3916434929184, -1.606285439760366}, {
        659.4378123948816, -1.0785724755601591`}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.3916434929184, -1.606285439760366}, {
        659.5970715486392, 0.7417679815821621}, {659.6894093525655, 
        1.797193909982576}, {659.4378123948816, -1.0785724755601591`}, {
        659.3916434929184, -1.606285439760366}}], 
       PolygonBox[{{659.5970715486392, 0.7417679815821621}, {
        659.8024996043599, 3.089821402924691}, {659.9410063102495, 
        4.6729602955253124`}, {659.6894093525655, 1.797193909982576}, {
        659.5970715486392, 0.7417679815821621}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.4378123948816, -1.0785724755601591`}, {
        659.4668353799623, -0.7468382381060343}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.4378123948816, -1.0785724755601591`}, {
        659.6894093525655, 1.797193909982576}, {659.7474553227269, 
        2.4606623848908256`}, {659.4668353799623, -0.7468382381060343}, {
        659.4378123948816, -1.0785724755601591`}}], 
       PolygonBox[{{659.6894093525655, 1.797193909982576}, {659.9410063102495,
         4.6729602955253124`}, {660.0280752654913, 5.668163007887687}, {
        659.7474553227269, 2.4606623848908256`}, {659.6894093525655, 
        1.797193909982576}}], 
       PolygonBox[{{659.1862154371977, -3.9543388611028942`}, {
        659.4668353799623, -0.7468382381060343}, {
        659.4767345796898, -0.6336898674637426}, {
        659.1862154371977, -3.9543388611028942`}, {
        659.1862154371977, -3.9543388611028942`}}], 
       PolygonBox[{{659.4668353799623, -0.7468382381060343}, {
        659.7474553227269, 2.4606623848908256`}, {659.7672537221821, 
        2.686959126175409}, {659.4767345796898, -0.6336898674637426}, {
        659.4668353799623, -0.7468382381060343}}], 
       PolygonBox[{{659.7474553227269, 2.4606623848908256`}, {
        660.0280752654913, 5.668163007887687}, {660.0577728646742, 
        6.007608119814561}, {659.7672537221821, 2.686959126175409}, {
        659.7474553227269, 2.4606623848908256`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/WvRvMCyBS0OdWruOafYJRyeRrTVWwL5JpK5b4zW
iDmc/xeg1z6/xWGR2ucGmY1CDtbzXrZkz2txuBy2wOPLdg6HaUcEb/yc0+Lw
LPlBnkTuB/u7CxQjvWe3ODBIv9gkyvJtv9GzlrjamS0OEi/XZtYs4j/Qrv0i
ef30FoewR5//lClKHTjH/uMJw7QWBw7GzU4P7yke0NRTsOif0uLgyPXfzfq/
6oGpZ3f0FU9ucbjTHlB6RlPzQH1xs+3BSS0Oqo28q8PVtQ9kaWZntwD5p9t/
ZSlf1YbLq0PlYfrvQfXDzHeGmg+znxtqP8x9CVD3wdwvC3U/zH9yUP/B/H8I
6n9Y+JyHhg8s/OZBww8WvkbQ8EUPfwB2c78j
         "]], {}}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{660.0577728646742, 6.007608119814561}, {666.0349410532247, 
         5.4846736633286115`}, {666.0052434540418, 5.145228551401739}, {
         660.0280752654913, 5.668163007887689}, {660.0577728646742, 
         6.007608119814561}}], 
        LineBox[{{660.0280752654913, 5.668163007887689}, {666.0052434540418, 
         5.145228551401739}, {665.9181744987999, 4.150025839039366}, {
         659.9410063102495, 4.672960295525316}, {660.0280752654913, 
         5.668163007887689}}], 
        LineBox[{{659.9410063102495, 4.672960295525316}, {665.9181744987999, 
         4.150025839039366}, {665.7796677929103, 2.5668869464387436`}, {
         659.8024996043599, 3.089821402924693}, {659.9410063102495, 
         4.672960295525316}}], 
        LineBox[{{659.8024996043599, 3.089821402924693}, {665.7796677929103, 
         2.5668869464387436`}, {665.5991623394864, 0.5037001728698849}, {
         659.621994150936, 1.0266346293558342`}, {659.8024996043599, 
         3.089821402924693}}], 
        LineBox[{{659.621994150936, 1.0266346293558342`}, {665.5991623394864, 
         0.5037001728698849}, {665.3889592868796, -1.898931712625846}, {
         659.4117910983292, -1.3759972561398968`}, {659.621994150936, 
         1.0266346293558342`}}], 
        LineBox[{{659.4117910983292, -1.3759972561398968`}, {
         665.3889592868796, -1.898931712625846}, {
         665.1633836257481, -4.477273317588841}, {
         659.1862154371977, -3.9543388611028916`}, {
         659.4117910983292, -1.3759972561398968`}}], 
        LineBox[{{659.1862154371977, -3.954338861102894}, {
         665.1633836257481, -4.477273317588843}, {
         664.9378079646166, -7.055614922551838}, {
         658.9606397760662, -6.532680466065889}, {
         659.1862154371977, -3.954338861102894}}], 
        LineBox[{{658.9606397760662, -6.532680466065889}, {
         664.9378079646166, -7.055614922551838}, {
         664.7276049120098, -9.45824680804757}, {
         658.7504367234594, -8.93531235156162}, {
         658.9606397760662, -6.532680466065889}}], 
        LineBox[{{658.7504367234594, -8.93531235156162}, {
         664.7276049120098, -9.45824680804757}, {
         664.5470994585859, -11.52143358161643}, {
         658.5699312700355, -10.998499125130481`}, {
         658.7504367234594, -8.93531235156162}}], 
        LineBox[{{658.5699312700355, -10.998499125130481`}, {
         664.5470994585859, -11.52143358161643}, {
         664.4085927526963, -13.104572474217054`}, {
         658.4314245641459, -12.581638017731104`}, {
         658.5699312700355, -10.998499125130481`}}], 
        LineBox[{{658.4314245641459, -12.581638017731102`}, {
         664.4085927526963, -13.10457247421705}, {
         664.3215237974545, -14.099775186579425`}, {
         658.344355608904, -13.576840730093474`}, {
         658.4314245641459, -12.581638017731102`}}], 
        LineBox[{{658.344355608904, -13.576840730093474`}, {
         664.3215237974545, -14.099775186579425`}, {
         664.2918261982716, -14.4392202985063}, {
         658.3146580097211, -13.916285842020349`}, {
         658.344355608904, -13.576840730093474`}}], 
        LineBox[{{658.3146580097211, -13.916285842020349`}, {
         664.2918261982716, -14.4392202985063}, {
         664.3215237974545, -14.099775186579425`}, {
         658.344355608904, -13.576840730093476`}, {
         658.3146580097211, -13.916285842020349`}}], 
        LineBox[{{658.344355608904, -13.576840730093478`}, {
         664.3215237974545, -14.099775186579429`}, {
         664.4085927526963, -13.104572474217054`}, {
         658.4314245641459, -12.581638017731105`}, {
         658.344355608904, -13.576840730093478`}}], 
        LineBox[{{658.4314245641459, -12.581638017731105`}, {
         664.4085927526963, -13.104572474217054`}, {
         664.5470994585859, -11.521433581616431`}, {
         658.5699312700355, -10.998499125130483`}, {
         658.4314245641459, -12.581638017731105`}}], 
        LineBox[{{658.5699312700355, -10.998499125130484`}, {
         664.5470994585859, -11.521433581616435`}, {
         664.7276049120098, -9.458246808047576}, {
         658.7504367234594, -8.935312351561626}, {
         658.5699312700355, -10.998499125130484`}}], 
        LineBox[{{658.7504367234594, -8.935312351561626}, {
         664.7276049120098, -9.458246808047576}, {
         664.9378079646166, -7.055614922551847}, {
         658.9606397760662, -6.532680466065898}, {
         658.7504367234594, -8.935312351561626}}], 
        LineBox[{{658.9606397760662, -6.532680466065898}, {
         664.9378079646166, -7.055614922551847}, {
         665.1633836257481, -4.477273317588854}, {
         659.1862154371977, -3.954338861102905}, {
         658.9606397760662, -6.532680466065898}}], 
        LineBox[{{659.1862154371977, -3.954338861102896}, {
         665.1633836257481, -4.477273317588845}, {
         665.3889592868796, -1.8989317126258527`}, {
         659.4117910983292, -1.3759972561399034`}, {
         659.1862154371977, -3.954338861102896}}], 
        LineBox[{{659.4117910983292, -1.3759972561399034`}, {
         665.3889592868796, -1.8989317126258527`}, {665.5991623394864, 
         0.5037001728698769}, {659.621994150936, 1.0266346293558262`}, {
         659.4117910983292, -1.3759972561399034`}}], 
        LineBox[{{659.621994150936, 1.0266346293558262`}, {665.5991623394864, 
         0.5037001728698769}, {665.7796677929103, 2.5668869464387365`}, {
         659.8024996043599, 3.0898214029246858`}, {659.621994150936, 
         1.0266346293558262`}}], 
        LineBox[{{659.8024996043599, 3.089821402924691}, {665.7796677929103, 
         2.566886946438742}, {665.9181744987999, 4.150025839039363}, {
         659.9410063102495, 4.6729602955253124`}, {659.8024996043599, 
         3.089821402924691}}], 
        LineBox[{{659.9410063102495, 4.6729602955253124`}, {665.9181744987999,
          4.150025839039363}, {666.0052434540418, 5.145228551401737}, {
         660.0280752654913, 5.668163007887687}, {659.9410063102495, 
         4.6729602955253124`}}], 
        LineBox[{{660.0280752654913, 5.668163007887687}, {666.0052434540418, 
         5.145228551401737}, {666.0349410532247, 5.4846736633286115`}, {
         660.0577728646742, 6.007608119814561}, {660.0280752654913, 
         5.668163007887687}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{715.1934363220911, 2.4474621809924706`}, {
         695.1934363220911, -10.715001034090623`}, {
         695.1934363220911, -10.715001034090623`}, {715.1934363220911, 
         2.4474621809924706`}, {715.1934363220911, 2.4474621809924706`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{704.3778781263171, -14.670507164130802`}, {
         695.1934363220911, -10.715001034090625`}, {
         695.1934363220911, -10.715001034090625`}, {
         704.3778781263171, -14.670507164130802`}, {
         704.3778781263171, -14.670507164130802`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{724.3778781263171, -1.5080439490477069`}, {
         704.3778781263171, -14.6705071641308}, {
         704.3778781263171, -14.6705071641308}, {
         724.3778781263171, -1.5080439490477069`}, {
         724.3778781263171, -1.5080439490477069`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{724.3778781263171, -1.5080439490477051`}, {
         715.1934363220911, 2.4474621809924724`}, {715.1934363220911, 
         2.4474621809924724`}, {724.3778781263171, -1.5080439490477051`}, {
         724.3778781263171, -1.5080439490477051`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{715.19614021164, 2.451741673328751}, {
         695.18614021164, -10.717302773361883`}, {
         704.3751742367682, -14.67478665646708}, {
         724.3851742367681, -1.5057422097764448`}, {715.19614021164, 
         2.451741673328751}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{715.19614021164, 2.451741673328751}, {
         695.18614021164, -10.717302773361883`}, {
         704.3751742367682, -14.67478665646708}, {
         724.3851742367681, -1.5057422097764448`}, {715.19614021164, 
         2.451741673328751}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{774.3796517592887, -1.5068766801104232`}, {
         754.3796517592887, -14.669339895193517`}, {
         754.3796517592887, -14.669339895193517`}, {
         774.3796517592887, -1.5068766801104232`}, {
         774.3796517592887, -1.5068766801104232`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{763.5640935635147, -18.624846025233694`}, {
         754.3796517592887, -14.669339895193517`}, {
         754.3796517592887, -14.669339895193517`}, {
         763.5640935635147, -18.624846025233694`}, {
         763.5640935635147, -18.624846025233694`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{783.5640935635147, -5.462382810150601}, {
         763.5640935635147, -18.624846025233694`}, {
         763.5640935635147, -18.624846025233694`}, {
         783.5640935635147, -5.462382810150601}, {
         783.5640935635147, -5.462382810150601}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{783.5640935635147, -5.462382810150599}, {
         774.3796517592887, -1.5068766801104214`}, {
         774.3796517592887, -1.5068766801104214`}, {
         783.5640935635147, -5.462382810150599}, {
         783.5640935635147, -5.462382810150599}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{774.3823556488376, -1.5025971877741426`}, {
         754.3723556488376, -14.671641634464777`}, {
         763.5613896739658, -18.629125517569975`}, {
         783.5713896739658, -5.460081070879339}, {
         774.3823556488376, -1.5025971877741426`}}]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{774.3823556488376, -1.5025971877741426`}, {
         754.3723556488376, -14.671641634464777`}, {
         763.5613896739658, -18.629125517569975`}, {
         783.5713896739658, -5.460081070879339}, {
         774.3823556488376, -1.5025971877741426`}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.7765256968908`, -10.389132598837552`}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.7765256968908`, -10.389132598837552`}, {
          1273.9734124560734`, -8.734004964792216}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.7765256968908`, -10.389132598837552`}}], 
         PolygonBox[{{1273.9734124560734`, -8.734004964792216}, {
          1274.1565231686452`, -7.077063679803722}, {
          1274.1342853079077`, -7.2459770019600285`}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.9734124560734`, -8.734004964792216}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.747380373727, -10.610513307125133`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.769113076645, -10.445437039556321`}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.9151218097459`, -9.176766381367376}, {
          1273.747380373727, -10.610513307125133`}, {
          1273.769113076645, -10.445437039556321`}}], 
         PolygonBox[{{1273.9585872155817`, -8.846613846229754}, {
          1274.1342853079077`, -7.2459770019600285`}, {
          1274.0690871991542`, -7.741205804666468}, {
          1273.9151218097459`, -9.176766381367376}, {
          1273.9585872155817`, -8.846613846229754}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.747380373727, -10.610513307125133`}, {
          1273.7128086359262`, -10.873111726710606`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.747380373727, -10.610513307125133`}, {
          1273.9151218097459`, -9.176766381367376}, {
          1273.845978334144, -9.701963220538325}, {
          1273.7128086359262`, -10.873111726710606`}, {
          1273.747380373727, -10.610513307125133`}}], 
         PolygonBox[{{1273.9151218097459`, -9.176766381367376}, {
          1274.0690871991542`, -7.741205804666468}, {
          1273.9653719857513`, -8.529001063422882}, {
          1273.845978334144, -9.701963220538325}, {
          1273.9151218097459`, -9.176766381367376}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.7128086359262`, -10.873111726710606`}, {
          1273.6677538700408`, -11.215336649982394`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.7128086359262`, -10.873111726710606`}, {
          1273.845978334144, -9.701963220538325}, {
          1273.7558688023732`, -10.386413067081897`}, {
          1273.6677538700408`, -11.215336649982394`}, {
          1273.7128086359262`, -10.873111726710606`}}], 
         PolygonBox[{{1273.845978334144, -9.701963220538325}, {
          1273.9653719857513`, -8.529001063422882}, {
          1273.8302076880952`, -9.555675833238247}, {
          1273.7558688023732`, -10.386413067081897`}, {
          1273.845978334144, -9.701963220538325}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.6677538700408`, -11.215336649982394`}, {
          1273.6152864839096`, -11.61386601397295}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.6677538700408`, -11.215336649982394`}, {
          1273.7558688023732`, -10.386413067081897`}, {
          1273.6509340301109`, -11.183471795063014`}, {
          1273.6152864839096`, -11.61386601397295}, {
          1273.6677538700408`, -11.215336649982394`}}], 
         PolygonBox[{{1273.7558688023732`, -10.386413067081897`}, {
          1273.8302076880952`, -9.555675833238247}, {
          1273.6728055297015`, -10.75126392520992}, {
          1273.6509340301109`, -11.183471795063014`}, {
          1273.7558688023732`, -10.386413067081897`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.6152864839096`, -11.61386601397295}, {
          1273.5589820431908`, -12.041540701127236`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.6152864839096`, -11.61386601397295}, {
          1273.6509340301109`, -11.183471795063014`}, {
          1273.5383251486733`, -12.038821169371582`}, {
          1273.5589820431908`, -12.041540701127236`}, {
          1273.6152864839096`, -11.61386601397295}}], 
         PolygonBox[{{1273.6509340301109`, -11.183471795063014`}, {
          1273.6728055297015`, -10.75126392520992}, {
          1273.503892207545, -12.034287986672771`}, {
          1273.5383251486733`, -12.038821169371582`}, {
          1273.6509340301109`, -11.183471795063014`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.5589820431908`, -12.041540701127236`}, {
          1273.502677602472, -12.469215388281519`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
          1273.5383251486733`, -12.038821169371584`}, {
          1273.4257162672357`, -12.894170543680152`}, {
          1273.502677602472, -12.469215388281519`}, {
          1273.5589820431908`, -12.041540701127236`}}], 
         PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
          1273.503892207545, -12.034287986672773`}, {
          1273.3349788853886`, -13.317312048135626`}, {
          1273.4257162672357`, -12.894170543680152`}, {
          1273.5383251486733`, -12.038821169371584`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.502677602472, -12.469215388281519`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.502677602472, -12.469215388281519`}, {
          1273.4257162672357`, -12.894170543680152`}, {
          1273.3207814949733`, -13.691229271661264`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.502677602472, -12.469215388281519`}}], 
         PolygonBox[{{1273.4257162672357`, -12.894170543680152`}, {
          1273.3349788853886`, -13.317312048135626`}, {
          1273.1775767269949`, -14.512900140107298`}, {
          1273.3207814949733`, -13.691229271661264`}, {
          1273.4257162672357`, -12.894170543680152`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.4502102163408`, -12.867744752272078`}, {
          1273.3207814949733`, -13.691229271661264`}, {
          1273.2306719632024`, -14.375679118204843`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.4502102163408`, -12.867744752272078`}}], 
         PolygonBox[{{1273.3207814949733`, -13.691229271661264`}, {
          1273.1775767269949`, -14.512900140107298`}, {
          1273.0424124293388`, -15.539574909922662`}, {
          1273.2306719632024`, -14.375679118204843`}, {
          1273.3207814949733`, -13.691229271661264`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.3705837126545`, -13.472568095129338`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.4051554504554`, -13.209969675543865`}, {
          1273.2306719632024`, -14.375679118204843`}, {
          1273.1615284876002`, -14.900875957375783`}, {
          1273.3705837126545`, -13.472568095129338`}, {
          1273.4051554504554`, -13.209969675543865`}}], 
         PolygonBox[{{1273.2306719632024`, -14.375679118204843`}, {
          1273.0424124293388`, -15.539574909922662`}, {
          1272.938697215936, -16.327370168679078`}, {
          1273.1615284876002`, -14.900875957375783`}, {
          1273.2306719632024`, -14.375679118204843`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.3705837126545`, -13.472568095129336`}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.3705837126545`, -13.472568095129336`}, {
          1273.1615284876002`, -14.900875957375783`}, {
          1273.1180630817648`, -15.231028492513412`}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.3705837126545`, -13.472568095129336`}}], 
         PolygonBox[{{1273.1615284876002`, -14.900875957375783`}, {
          1272.938697215936, -16.327370168679078`}, {
          1272.8734991071824`, -16.822598971385514`}, {
          1273.1180630817648`, -15.231028492513412`}, {
          1273.1615284876002`, -14.900875957375783`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.3414383894908`, -13.69394880341692}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.3488510097366`, -13.63764436269815}, {
          1273.1180630817648`, -15.231028492513412`}, {
          1273.103237841273, -15.343637373950951`}, {
          1273.3414383894908`, -13.69394880341692}, {
          1273.3488510097366`, -13.63764436269815}}], 
         PolygonBox[{{1273.1180630817648`, -15.231028492513412`}, {
          1272.8734991071824`, -16.822598971385514`}, {
          1272.851261246445, -16.991512293541824`}, {
          1273.103237841273, -15.343637373950951`}, {
          1273.1180630817648`, -15.231028492513412`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.3414383894908`, -13.69394880341692}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.3414383894908`, -13.69394880341692}, {
          1273.103237841273, -15.343637373950951`}, {
          1273.1180630817648`, -15.231028492513412`}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.3414383894908`, -13.69394880341692}}], 
         PolygonBox[{{1273.103237841273, -15.343637373950951`}, {
          1272.851261246445, -16.991512293541824`}, {
          1272.8734991071824`, -16.822598971385517`}, {
          1273.1180630817648`, -15.231028492513412`}, {
          1273.103237841273, -15.343637373950951`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.3488510097366`, -13.63764436269815}, {
          1273.3705837126545`, -13.472568095129338`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.3488510097366`, -13.63764436269815}, {
          1273.1180630817648`, -15.231028492513413`}, {
          1273.1615284876002`, -14.900875957375785`}, {
          1273.3705837126545`, -13.472568095129338`}, {
          1273.3488510097366`, -13.63764436269815}}], 
         PolygonBox[{{1273.1180630817648`, -15.231028492513413`}, {
          1272.8734991071824`, -16.822598971385517`}, {
          1272.938697215936, -16.327370168679078`}, {
          1273.1615284876002`, -14.900875957375785`}, {
          1273.1180630817648`, -15.231028492513413`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.3705837126545`, -13.472568095129338`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.3705837126545`, -13.472568095129338`}, {
          1273.1615284876002`, -14.900875957375785`}, {
          1273.2306719632024`, -14.375679118204843`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.3705837126545`, -13.472568095129338`}}], 
         PolygonBox[{{1273.1615284876002`, -14.900875957375785`}, {
          1272.938697215936, -16.327370168679078`}, {
          1273.0424124293388`, -15.539574909922663`}, {
          1273.2306719632024`, -14.375679118204843`}, {
          1273.1615284876002`, -14.900875957375785`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.4051554504554`, -13.209969675543865`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.4051554504554`, -13.209969675543865`}, {
          1273.2306719632024`, -14.375679118204845`}, {
          1273.3207814949733`, -13.691229271661266`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.4051554504554`, -13.209969675543865`}}], 
         PolygonBox[{{1273.2306719632024`, -14.375679118204845`}, {
          1273.0424124293388`, -15.539574909922663`}, {
          1273.1775767269949`, -14.512900140107302`}, {
          1273.3207814949733`, -13.691229271661266`}, {
          1273.2306719632024`, -14.375679118204845`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.4502102163408`, -12.867744752272078`}, {
          1273.502677602472, -12.46921538828152}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.4502102163408`, -12.867744752272078`}, {
          1273.3207814949733`, -13.691229271661266`}, {
          1273.4257162672357`, -12.894170543680156`}, {
          1273.502677602472, -12.46921538828152}, {
          1273.4502102163408`, -12.867744752272078`}}], 
         PolygonBox[{{1273.3207814949733`, -13.691229271661266`}, {
          1273.1775767269949`, -14.512900140107302`}, {
          1273.3349788853886`, -13.31731204813563}, {
          1273.4257162672357`, -12.894170543680156`}, {
          1273.3207814949733`, -13.691229271661266`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.502677602472, -12.46921538828152}, {
          1273.5589820431908`, -12.041540701127238`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.502677602472, -12.46921538828152}, {
          1273.4257162672357`, -12.894170543680156`}, {
          1273.5383251486733`, -12.038821169371587`}, {
          1273.5589820431908`, -12.041540701127238`}, {
          1273.502677602472, -12.46921538828152}}], 
         PolygonBox[{{1273.4257162672357`, -12.894170543680156`}, {
          1273.3349788853886`, -13.31731204813563}, {
          1273.503892207545, -12.034287986672778`}, {
          1273.5383251486733`, -12.038821169371587`}, {
          1273.4257162672357`, -12.894170543680156`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.5589820431908`, -12.041540701127236`}, {
          1273.6152864839096`, -11.613866013972952`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.5589820431908`, -12.041540701127236`}, {
          1273.5383251486733`, -12.038821169371584`}, {
          1273.6509340301109`, -11.183471795063017`}, {
          1273.6152864839096`, -11.613866013972952`}, {
          1273.5589820431908`, -12.041540701127236`}}], 
         PolygonBox[{{1273.5383251486733`, -12.038821169371584`}, {
          1273.503892207545, -12.034287986672775`}, {
          1273.6728055297015`, -10.751263925209923`}, {
          1273.6509340301109`, -11.183471795063017`}, {
          1273.5383251486733`, -12.038821169371584`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.6152864839096`, -11.613866013972952`}, {
          1273.6677538700408`, -11.215336649982396`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.6152864839096`, -11.613866013972952`}, {
          1273.6509340301109`, -11.183471795063017`}, {
          1273.7558688023732`, -10.386413067081898`}, {
          1273.6677538700408`, -11.215336649982396`}, {
          1273.6152864839096`, -11.613866013972952`}}], 
         PolygonBox[{{1273.6509340301109`, -11.183471795063017`}, {
          1273.6728055297015`, -10.751263925209923`}, {
          1273.8302076880952`, -9.55567583323825}, {
          1273.7558688023732`, -10.386413067081898`}, {
          1273.6509340301109`, -11.183471795063017`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.6677538700408`, -11.215336649982396`}, {
          1273.7128086359262`, -10.873111726710608`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.6677538700408`, -11.215336649982396`}, {
          1273.7558688023732`, -10.386413067081898`}, {
          1273.845978334144, -9.701963220538328}, {
          1273.7128086359262`, -10.873111726710608`}, {
          1273.6677538700408`, -11.215336649982396`}}], 
         PolygonBox[{{1273.7558688023732`, -10.386413067081898`}, {
          1273.8302076880952`, -9.55567583323825}, {
          1273.9653719857513`, -8.529001063422886}, {
          1273.845978334144, -9.701963220538328}, {
          1273.7558688023732`, -10.386413067081898`}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.7128086359262`, -10.873111726710606`}, {
          1273.747380373727, -10.610513307125135`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.7128086359262`, -10.873111726710606`}, {
          1273.845978334144, -9.701963220538325}, {
          1273.9151218097459`, -9.17676638136738}, {
          1273.747380373727, -10.610513307125135`}, {
          1273.7128086359262`, -10.873111726710606`}}], 
         PolygonBox[{{1273.845978334144, -9.701963220538325}, {
          1273.9653719857513`, -8.529001063422886}, {
          1274.0690871991542`, -7.741205804666471}, {
          1273.9151218097459`, -9.17676638136738}, {
          1273.845978334144, -9.701963220538325}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.747380373727, -10.610513307125135`}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.747380373727, -10.610513307125135`}, {
          1273.9151218097459`, -9.17676638136738}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.747380373727, -10.610513307125135`}}], 
         PolygonBox[{{1273.9151218097459`, -9.17676638136738}, {
          1274.0690871991542`, -7.741205804666471}, {
          1274.1342853079077`, -7.245977001960032}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.9151218097459`, -9.17676638136738}}], 
         PolygonBox[{{1273.5658671964864`, -12.042447148754864`}, {
          1273.769113076645, -10.445437039556321`}, {
          1273.7765256968908`, -10.389132598837552`}, {
          1273.5658671964864`, -12.042447148754864`}, {
          1273.5658671964864`, -12.042447148754864`}}], 
         PolygonBox[{{1273.769113076645, -10.445437039556321`}, {
          1273.9585872155817`, -8.846613846229754}, {
          1273.9734124560734`, -8.734004964792216}, {
          1273.7765256968908`, -10.389132598837552`}, {
          1273.769113076645, -10.445437039556321`}}], 
         PolygonBox[{{1273.9585872155817`, -8.846613846229754}, {
          1274.1342853079077`, -7.245977001960032}, {
          1274.1565231686452`, -7.077063679803722}, {
          1273.9734124560734`, -8.734004964792216}, {
          1273.9585872155817`, -8.846613846229754}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQPZ1zjvuCF5MdZtxlPPHST+aAQblYUyeQr/BJO/Xh
b5kDh4pP73MD8lOmdy3/903ugLRvZded55MdVjwztbrJp3iA/eo3xSAgX+X+
165GGeUD3afefd7wbLLDk4deq5Y2qB4oWxD4hxnIrzn/yrBPUONAYtkWlvCn
kx1E9nbtLFukdeBp9pprW59Mdriy//6NWWy6By5+1szTBvL9d8zXdBbRP6B1
9rrlwceTHRZrcnScCzY4sOdkT1kdkP/50vwbUy8ZHAg1Z9+YDuSLRbzaf/kv
Qv4LVB5dP8z8AKj5MPuvQe2HuU8M6j6Y+2uh7of57xnUfzD/q0H9DwufVdDw
gYVfBjT8YOGrAg1f9PAHAE/S2Lg=
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQPS30pe5qhikOp5f8n2VRKX9A/3ByxhQgf/UdERkJ
YYUDB/dLLA0E8n30XfYuE1A8IDXzWMHz/5MdnE9tWcywROkAm6ILRyyQv+9Q
yZcVG1UOdInZ3Nr9b7JD3dGTwmdF1Q+Uvpn3iA/IF9ucOXvrMs0DCYcYXyf+
neywbgGn8jxznQNPtv/cc+DPZIe8xXFOh2brHbhgXx5iBuR/8e333BpicEBT
UlXhzO/JDgWzj9skyRke2C16K6YTyD/gEt+rOdfwQEhzyPQiIP/xyZUl6ScQ
8geh8uj6YeZ/hZoPs78Aaj/MfRug7oO5Xxzqfpj/GqD+g/n/ANT/6OEDCz9f
aPjBwncNNHzRwx8Av4DGFw==
           "]]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1274.1565231686452`, -7.077063679803722}, {
           1280.1671673258293`, -7.868379995206122}, {
           1280.1449294650918`, -8.037293317362431}, {
           1274.1342853079077`, -7.2459770019600285`}, {
           1274.1565231686452`, -7.077063679803722}}], 
          LineBox[{{1274.1342853079077`, -7.2459770019600285`}, {
           1280.1449294650918`, -8.037293317362431}, {
           1280.0797313563382`, -8.532522120068869}, {
           1274.0690871991542`, -7.741205804666468}, {
           1274.1342853079077`, -7.2459770019600285`}}], 
          LineBox[{{1274.0690871991542`, -7.741205804666468}, {
           1280.0797313563382`, -8.532522120068869}, {
           1279.9760161429354`, -9.320317378825285}, {
           1273.9653719857513`, -8.529001063422882}, {
           1274.0690871991542`, -7.741205804666468}}], 
          LineBox[{{1273.9653719857513`, -8.529001063422882}, {
           1279.9760161429354`, -9.320317378825285}, {
           1279.8408518452793`, -10.346992148640648`}, {
           1273.8302076880952`, -9.555675833238247}, {
           1273.9653719857513`, -8.529001063422882}}], 
          LineBox[{{1273.8302076880952`, -9.555675833238247}, {
           1279.8408518452793`, -10.346992148640648`}, {
           1279.6834496868855`, -11.54258024061232}, {
           1273.6728055297015`, -10.75126392520992}, {
           1273.8302076880952`, -9.555675833238247}}], 
          LineBox[{{1273.6728055297015`, -10.75126392520992}, {
           1279.6834496868855`, -11.54258024061232}, {
           1279.514536364729, -12.825604302075172`}, {
           1273.503892207545, -12.034287986672771`}, {
           1273.6728055297015`, -10.75126392520992}}], 
          LineBox[{{1273.503892207545, -12.034287986672773`}, {
           1279.514536364729, -12.825604302075174`}, {
           1279.3456230425727`, -14.108628363538028`}, {
           1273.3349788853886`, -13.317312048135626`}, {
           1273.503892207545, -12.034287986672773`}}], 
          LineBox[{{1273.3349788853886`, -13.317312048135626`}, {
           1279.3456230425727`, -14.108628363538028`}, {
           1279.188220884179, -15.3042164555097}, {
           1273.1775767269949`, -14.512900140107298`}, {
           1273.3349788853886`, -13.317312048135626`}}], 
          LineBox[{{1273.1775767269949`, -14.512900140107298`}, {
           1279.188220884179, -15.3042164555097}, {
           1279.0530565865229`, -16.33089122532506}, {
           1273.0424124293388`, -15.539574909922662`}, {
           1273.1775767269949`, -14.512900140107298`}}], 
          LineBox[{{1273.0424124293388`, -15.539574909922662`}, {
           1279.0530565865229`, -16.33089122532506}, {
           1278.94934137312, -17.11868648408148}, {
           1272.938697215936, -16.327370168679078`}, {
           1273.0424124293388`, -15.539574909922662`}}], 
          LineBox[{{1272.938697215936, -16.327370168679078`}, {
           1278.94934137312, -17.11868648408148}, {
           1278.8841432643665`, -17.613915286787915`}, {
           1272.8734991071824`, -16.822598971385514`}, {
           1272.938697215936, -16.327370168679078`}}], 
          LineBox[{{1272.8734991071824`, -16.822598971385514`}, {
           1278.8841432643665`, -17.613915286787915`}, {
           1278.861905403629, -17.782828608944225`}, {
           1272.851261246445, -16.991512293541824`}, {
           1272.8734991071824`, -16.822598971385514`}}], 
          LineBox[{{1272.851261246445, -16.991512293541824`}, {
           1278.861905403629, -17.782828608944225`}, {
           1278.8841432643665`, -17.613915286787915`}, {
           1272.8734991071824`, -16.822598971385517`}, {
           1272.851261246445, -16.991512293541824`}}], 
          LineBox[{{1272.8734991071824`, -16.822598971385517`}, {
           1278.8841432643665`, -17.61391528678792}, {
           1278.94934137312, -17.11868648408148}, {
           1272.938697215936, -16.327370168679078`}, {
           1272.8734991071824`, -16.822598971385517`}}], 
          LineBox[{{1272.938697215936, -16.327370168679078`}, {
           1278.94934137312, -17.11868648408148}, {
           1279.0530565865229`, -16.330891225325065`}, {
           1273.0424124293388`, -15.539574909922663`}, {
           1272.938697215936, -16.327370168679078`}}], 
          LineBox[{{1273.0424124293388`, -15.539574909922663`}, {
           1279.0530565865229`, -16.330891225325065`}, {
           1279.188220884179, -15.304216455509703`}, {
           1273.1775767269949`, -14.512900140107302`}, {
           1273.0424124293388`, -15.539574909922663`}}], 
          LineBox[{{1273.1775767269949`, -14.512900140107302`}, {
           1279.188220884179, -15.304216455509703`}, {
           1279.3456230425727`, -14.108628363538031`}, {
           1273.3349788853886`, -13.31731204813563}, {
           1273.1775767269949`, -14.512900140107302`}}], 
          LineBox[{{1273.3349788853886`, -13.31731204813563}, {
           1279.3456230425727`, -14.108628363538031`}, {
           1279.514536364729, -12.82560430207518}, {
           1273.503892207545, -12.034287986672778`}, {
           1273.3349788853886`, -13.31731204813563}}], 
          LineBox[{{1273.503892207545, -12.034287986672775`}, {
           1279.514536364729, -12.825604302075176`}, {
           1279.6834496868855`, -11.542580240612324`}, {
           1273.6728055297015`, -10.751263925209923`}, {
           1273.503892207545, -12.034287986672775`}}], 
          LineBox[{{1273.6728055297015`, -10.751263925209923`}, {
           1279.6834496868855`, -11.542580240612324`}, {
           1279.8408518452793`, -10.346992148640652`}, {
           1273.8302076880952`, -9.55567583323825}, {
           1273.6728055297015`, -10.751263925209923`}}], 
          LineBox[{{1273.8302076880952`, -9.55567583323825}, {
           1279.8408518452793`, -10.346992148640652`}, {
           1279.9760161429354`, -9.320317378825287}, {
           1273.9653719857513`, -8.529001063422886}, {
           1273.8302076880952`, -9.55567583323825}}], 
          LineBox[{{1273.9653719857513`, -8.529001063422886}, {
           1279.9760161429354`, -9.320317378825285}, {
           1280.0797313563382`, -8.53252212006887}, {
           1274.0690871991542`, -7.741205804666471}, {
           1273.9653719857513`, -8.529001063422886}}], 
          LineBox[{{1274.0690871991542`, -7.741205804666471}, {
           1280.0797313563382`, -8.53252212006887}, {
           1280.1449294650918`, -8.037293317362433}, {
           1274.1342853079077`, -7.245977001960032}, {
           1274.0690871991542`, -7.741205804666471}}], 
          LineBox[{{1274.1342853079077`, -7.245977001960032}, {
           1280.1449294650918`, -8.037293317362433}, {
           1280.1671673258293`, -7.868379995206122}, {
           1274.1565231686452`, -7.077063679803722}, {
           1274.1342853079077`, -7.245977001960032}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1213.9069695388796`, -2.8702860211179173`}, {
           1236.632182225186, 4.667296233860271}, {1236.632182225186, 
           4.667296233860271}, {1213.9069695388796`, -2.8702860211179173`}, {
           1213.9069695388796`, -2.8702860211179173`}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1228.7844530059092`, 10.86513021848026}, {
           1236.6321822251857`, 4.667296233860274}, {1236.6321822251857`, 
           4.667296233860274}, {1228.7844530059092`, 10.86513021848026}, {
           1228.7844530059092`, 10.86513021848026}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1206.0592403196028`, 3.3275479635020693`}, {
           1228.7844530059092`, 10.865130218480257`}, {1228.7844530059092`, 
           10.865130218480257`}, {1206.0592403196028`, 3.3275479635020693`}, {
           1206.0592403196028`, 3.3275479635020693`}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1206.059240319603, 3.3275479635020666`}, {
           1213.9069695388796`, -2.870286021117919}, {
           1213.9069695388796`, -2.870286021117919}, {1206.059240319603, 
           3.3275479635020666`}, {1206.059240319603, 
           3.3275479635020666`}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1213.9032501680128`, -2.8737198751778177`}, {
           1236.6398254606622`, 4.667631170927862}, {1228.788172376776, 
           10.868564072540156`}, {1206.0515970841266`, 3.3272130264344772`}, {
           1213.9032501680128`, -2.8737198751778177`}}]}, 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{1213.9032501680128`, -2.8737198751778177`}, {
           1236.6398254606622`, 4.667631170927862}, {1228.788172376776, 
           10.868564072540156`}, {1206.0515970841266`, 3.3272130264344772`}, {
           1213.9032501680128`, -2.8737198751778177`}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.7943225642541, 94.3948200261051}, {878.8140456248223, 
            94.5066750609318}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.7943225642541, 94.3948200261051}, {
            878.2975911303442, 91.09765180711693}, {878.3370372514803, 
            91.32136187677034}, {878.8140456248223, 94.5066750609318}, {
            878.7943225642541, 94.3948200261051}}], 
           PolygonBox[{{878.2975911303442, 91.09765180711693}, {
            877.8556663826982, 87.79081969061721}, {877.9148355644024, 
            88.12638479509732}, {878.3370372514803, 91.32136187677034}, {
            878.2975911303442, 91.09765180711693}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.8140456248223, 94.5066750609318}, {878.8718707125424, 
            94.83461742963763}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.8140456248223, 94.5066750609318}, {
            878.3370372514803, 91.32136187677034}, {878.4526874269209, 
            91.97724661418204}, {878.8718707125424, 94.83461742963763}, {
            878.8140456248223, 94.5066750609318}}], 
           PolygonBox[{{878.3370372514803, 91.32136187677034}, {
            877.9148355644024, 88.12638479509732}, {878.0883108275632, 
            89.11021190121487}, {878.4526874269209, 91.97724661418204}, {
            878.3370372514803, 91.32136187677034}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.8718707125424, 94.83461742963763}, {878.9638571432472, 
            95.35629840174573}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.8718707125424, 94.83461742963763}, {
            878.4526874269209, 91.97724661418204}, {878.6366602883306, 
            93.02060855839821}, {878.9638571432472, 95.35629840174573}, {
            878.8718707125424, 94.83461742963763}}], 
           PolygonBox[{{878.4526874269209, 91.97724661418204}, {
            878.0883108275632, 89.11021190121487}, {878.3642701196777, 
            90.67525481753911}, {878.6366602883306, 93.02060855839821}, {
            878.4526874269209, 91.97724661418204}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.9638571432472, 95.35629840174573}, {879.083736193699, 
            96.03616628112545}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.9638571432472, 95.35629840174573}, {
            878.6366602883306, 93.02060855839821}, {878.876418389234, 
            94.38034431715762}, {879.083736193699, 96.03616628112545}, {
            878.9638571432472, 95.35629840174573}}], 
           PolygonBox[{{878.6366602883306, 93.02060855839821}, {
            878.3642701196777, 90.67525481753911}, {878.7239072710329, 
            92.71485845567827}, {878.876418389234, 94.38034431715762}, {
            878.6366602883306, 93.02060855839821}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.083736193699, 96.03616628112545}, {879.2233383047187, 
            96.82788919533186}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.083736193699, 96.03616628112545}, {
            878.876418389234, 94.38034431715762}, {879.1556226112734, 
            95.96379014557046}, {879.2233383047187, 96.82788919533186}, {
            879.083736193699, 96.03616628112545}}], 
           PolygonBox[{{878.876418389234, 94.38034431715762}, {
            878.7239072710329, 92.71485845567827}, {879.142713604092, 
            95.09002719829752}, {879.1556226112734, 95.96379014557046}, {
            878.876418389234, 94.38034431715762}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.2233383047187, 96.82788919533186}, {879.3731498231439, 
            97.6775125361458}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.2233383047187, 96.82788919533186}, {
            879.1556226112734, 95.96379014557046}, {879.4552456481238, 
            97.66303682719831}, {879.3731498231439, 97.6775125361458}, {
            879.2233383047187, 96.82788919533186}}], 
           PolygonBox[{{879.1556226112734, 95.96379014557046}, {
            879.142713604092, 95.09002719829752}, {879.5921481593675, 
            97.6388972207393}, {879.4552456481238, 97.66303682719831}, {
            879.1556226112734, 95.96379014557046}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.3731498231439, 97.6775125361458}, {879.522961341569, 
            98.52713587695972}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.3731498231439, 97.6775125361458}, {
            879.4552456481238, 97.66303682719831}, {879.7548686849741, 
            99.36228350882618}, {879.522961341569, 98.52713587695972}, {
            879.3731498231439, 97.6775125361458}}], 
           PolygonBox[{{879.4552456481238, 97.66303682719831}, {
            879.5921481593675, 97.6388972207393}, {880.041582714643, 
            100.1877672431811}, {879.7548686849741, 99.36228350882618}, {
            879.4552456481238, 97.66303682719831}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.522961341569, 98.52713587695972}, {879.6625634525888, 
            99.31885879116614}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.522961341569, 98.52713587695972}, {
            879.7548686849741, 99.36228350882618}, {880.0340729070135, 
            100.94572933723902`}, {879.6625634525888, 99.31885879116614}, {
            879.522961341569, 98.52713587695972}}], 
           PolygonBox[{{879.7548686849741, 99.36228350882618}, {
            880.041582714643, 100.1877672431811}, {880.4603890477022, 
            102.56293598580035`}, {880.0340729070135, 100.94572933723902`}, {
            879.7548686849741, 99.36228350882618}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.6625634525888, 99.31885879116614}, {879.7824425030406, 
            99.99872667054586}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.6625634525888, 99.31885879116614}, {
            880.0340729070135, 100.94572933723902`}, {880.2738310079169, 
            102.30546509599846`}, {879.7824425030406, 99.99872667054586}, {
            879.6625634525888, 99.31885879116614}}], 
           PolygonBox[{{880.0340729070135, 100.94572933723902`}, {
            880.4603890477022, 102.56293598580035`}, {880.8200261990573, 
            104.60253962393949`}, {880.2738310079169, 102.30546509599846`}, {
            880.0340729070135, 100.94572933723902`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.7824425030406, 99.99872667054586}, {879.8744289337453, 
            100.52040764265392`}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.7824425030406, 99.99872667054586}, {
            880.2738310079169, 102.30546509599846`}, {880.4578038693267, 
            103.34882704021462`}, {879.8744289337453, 100.52040764265392`}, {
            879.7824425030406, 99.99872667054586}}], 
           PolygonBox[{{880.2738310079169, 102.30546509599846`}, {
            880.8200261990573, 104.60253962393949`}, {881.0959854911719, 
            106.16758254026374`}, {880.4578038693267, 103.34882704021462`}, {
            880.2738310079169, 102.30546509599846`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.8744289337453, 100.52040764265392`}, {879.9322540214655, 
            100.84835001135977`}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.8744289337453, 100.52040764265392`}, {
            880.4578038693267, 103.34882704021462`}, {880.5734540447672, 
            104.00471177762631`}, {879.9322540214655, 100.84835001135977`}, {
            879.8744289337453, 100.52040764265392`}}], 
           PolygonBox[{{880.4578038693267, 103.34882704021462`}, {
            881.0959854911719, 106.16758254026374`}, {881.2694607543326, 
            107.15140964638127`}, {880.5734540447672, 104.00471177762631`}, {
            880.4578038693267, 103.34882704021462`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.9322540214655, 100.84835001135977`}, {879.9519770820336, 
            100.96020504618647`}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.9322540214655, 100.84835001135977`}, {
            880.5734540447672, 104.00471177762631`}, {880.6129001659033, 
            104.22842184727972`}, {879.9519770820336, 100.96020504618647`}, {
            879.9322540214655, 100.84835001135977`}}], 
           PolygonBox[{{880.5734540447672, 104.00471177762631`}, {
            881.2694607543326, 107.15140964638127`}, {881.3286299360368, 
            107.48697475086138`}, {880.6129001659033, 104.22842184727972`}, {
            880.5734540447672, 104.00471177762631`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.9519770820336, 100.96020504618647`}, {879.9322540214655, 
            100.84835001135977`}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.9519770820336, 100.96020504618647`}, {
            880.6129001659033, 104.22842184727972`}, {880.5734540447672, 
            104.00471177762631`}, {879.9322540214655, 100.84835001135977`}, {
            879.9519770820336, 100.96020504618647`}}], 
           PolygonBox[{{880.6129001659033, 104.22842184727972`}, {
            881.3286299360368, 107.48697475086138`}, {881.2694607543326, 
            107.15140964638127`}, {880.5734540447672, 104.00471177762631`}, {
            880.6129001659033, 104.22842184727972`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.9322540214655, 100.8483500113598}, {879.8744289337453, 
            100.52040764265392`}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.9322540214655, 100.8483500113598}, {
            880.5734540447672, 104.00471177762631`}, {880.4578038693267, 
            103.34882704021462`}, {879.8744289337453, 100.52040764265392`}, {
            879.9322540214655, 100.8483500113598}}], 
           PolygonBox[{{880.5734540447672, 104.00471177762631`}, {
            881.2694607543328, 107.15140964638127`}, {881.0959854911719, 
            106.16758254026374`}, {880.4578038693267, 103.34882704021462`}, {
            880.5734540447672, 104.00471177762631`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.8744289337453, 100.52040764265392`}, {879.7824425030406, 
            99.99872667054586}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.8744289337453, 100.52040764265392`}, {
            880.4578038693267, 103.34882704021462`}, {880.2738310079169, 
            102.30546509599846`}, {879.7824425030406, 99.99872667054586}, {
            879.8744289337453, 100.52040764265392`}}], 
           PolygonBox[{{880.4578038693267, 103.34882704021462`}, {
            881.0959854911719, 106.16758254026374`}, {880.8200261990573, 
            104.60253962393949`}, {880.2738310079169, 102.30546509599846`}, {
            880.4578038693267, 103.34882704021462`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.7824425030406, 99.99872667054586}, {879.6625634525888, 
            99.31885879116614}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.7824425030406, 99.99872667054586}, {
            880.2738310079169, 102.30546509599846`}, {880.0340729070135, 
            100.94572933723902`}, {879.6625634525888, 99.31885879116614}, {
            879.7824425030406, 99.99872667054586}}], 
           PolygonBox[{{880.2738310079169, 102.30546509599846`}, {
            880.8200261990573, 104.60253962393949`}, {880.4603890477022, 
            102.56293598580035`}, {880.0340729070135, 100.94572933723902`}, {
            880.2738310079169, 102.30546509599846`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.6625634525888, 99.31885879116614}, {879.522961341569, 
            98.52713587695973}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.6625634525888, 99.31885879116614}, {
            880.0340729070135, 100.94572933723902`}, {879.7548686849741, 
            99.36228350882618}, {879.522961341569, 98.52713587695973}, {
            879.6625634525888, 99.31885879116614}}], 
           PolygonBox[{{880.0340729070135, 100.94572933723902`}, {
            880.4603890477022, 102.56293598580035`}, {880.041582714643, 
            100.1877672431811}, {879.7548686849741, 99.36228350882618}, {
            880.0340729070135, 100.94572933723902`}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.522961341569, 98.52713587695973}, {879.3731498231439, 
            97.6775125361458}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.522961341569, 98.52713587695973}, {
            879.7548686849741, 99.36228350882618}, {879.4552456481238, 
            97.66303682719833}, {879.3731498231439, 97.6775125361458}, {
            879.522961341569, 98.52713587695973}}], 
           PolygonBox[{{879.7548686849741, 99.36228350882618}, {
            880.041582714643, 100.1877672431811}, {879.5921481593675, 
            97.63889722073931}, {879.4552456481238, 97.66303682719833}, {
            879.7548686849741, 99.36228350882618}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.3731498231439, 97.6775125361458}, {879.2233383047187, 
            96.82788919533186}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.3731498231439, 97.6775125361458}, {
            879.4552456481238, 97.66303682719831}, {879.1556226112734, 
            95.96379014557047}, {879.2233383047187, 96.82788919533186}, {
            879.3731498231439, 97.6775125361458}}], 
           PolygonBox[{{879.4552456481238, 97.66303682719831}, {
            879.5921481593675, 97.6388972207393}, {879.142713604092, 
            95.09002719829752}, {879.1556226112734, 95.96379014557047}, {
            879.4552456481238, 97.66303682719831}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.2233383047187, 96.82788919533186}, {879.083736193699, 
            96.03616628112545}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.2233383047187, 96.82788919533186}, {
            879.1556226112734, 95.96379014557047}, {878.876418389234, 
            94.38034431715764}, {879.083736193699, 96.03616628112545}, {
            879.2233383047187, 96.82788919533186}}], 
           PolygonBox[{{879.1556226112734, 95.96379014557047}, {
            879.142713604092, 95.09002719829752}, {878.7239072710329, 
            92.71485845567827}, {878.876418389234, 94.38034431715764}, {
            879.1556226112734, 95.96379014557047}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            879.083736193699, 96.03616628112545}, {878.9638571432472, 
            95.35629840174573}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{879.083736193699, 96.03616628112545}, {
            878.876418389234, 94.38034431715764}, {878.6366602883306, 
            93.02060855839821}, {878.9638571432472, 95.35629840174573}, {
            879.083736193699, 96.03616628112545}}], 
           PolygonBox[{{878.876418389234, 94.38034431715764}, {
            878.7239072710329, 92.71485845567827}, {878.3642701196777, 
            90.67525481753913}, {878.6366602883306, 93.02060855839821}, {
            878.876418389234, 94.38034431715764}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.9638571432472, 95.35629840174573}, {878.8718707125424, 
            94.83461742963763}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.9638571432472, 95.35629840174573}, {
            878.6366602883306, 93.02060855839821}, {878.4526874269209, 
            91.97724661418204}, {878.8718707125424, 94.83461742963763}, {
            878.9638571432472, 95.35629840174573}}], 
           PolygonBox[{{878.6366602883306, 93.02060855839821}, {
            878.3642701196777, 90.67525481753911}, {878.0883108275632, 
            89.11021190121488}, {878.4526874269209, 91.97724661418204}, {
            878.6366602883306, 93.02060855839821}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.8718707125424, 94.83461742963763}, {878.8140456248223, 
            94.5066750609318}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.8718707125424, 94.83461742963763}, {
            878.4526874269209, 91.97724661418204}, {878.3370372514803, 
            91.32136187677034}, {878.8140456248223, 94.5066750609318}, {
            878.8718707125424, 94.83461742963763}}], 
           PolygonBox[{{878.4526874269209, 91.97724661418204}, {
            878.0883108275632, 89.11021190121488}, {877.9148355644024, 
            88.12638479509732}, {878.3370372514803, 91.32136187677034}, {
            878.4526874269209, 91.97724661418204}}], 
           PolygonBox[{{879.3457921522566, 97.68233643165254}, {
            878.8140456248223, 94.5066750609318}, {878.7943225642541, 
            94.3948200261051}, {879.3457921522566, 97.68233643165254}, {
            879.3457921522566, 97.68233643165254}}], 
           PolygonBox[{{878.8140456248223, 94.5066750609318}, {
            878.3370372514803, 91.32136187677034}, {878.2975911303442, 
            91.09765180711693}, {878.7943225642541, 94.3948200261051}, {
            878.8140456248223, 94.5066750609318}}], 
           PolygonBox[{{878.3370372514803, 91.32136187677034}, {
            877.9148355644024, 88.12638479509732}, {877.8556663826982, 
            87.79081969061721}, {878.2975911303442, 91.09765180711693}, {
            878.3370372514803, 91.32136187677034}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfe783PQbed0O3/gMT835FOow55Pf1MD8bodnmQ4b
xDjCHJQW+d3ZUtDt4HzNfBuve5hDxvVitldF3Q6Mxb/jzVeHOSQZP+0/Vdrt
ICC1zvaAbriDxiZ2d5XKbgc+mQLGw0fDHb5N09mxp6bbQUNVe+PjjAiHI9WB
mqEN3Q4ues8SWHgiHbp+FT9Y19zt4GSwQoV9SaRDS9jTzP62boeA61FME9Si
HE51c0050gE0r0Ruzc6uKIcAa67b6l3dDlkPRDdtOBnlIBe3m2MhkB9lrTpD
636UQxCaPLp+dPPR7Ud3H7r70f2H7n/08IGFnws0/NDDFz38AbXGrqI=
             "]]}, 
           {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQnddwumeWbbdD0YE354QswhysF9fsErbrdkiS/rOl
xzfM4VBQDWO5fbfD/vbPu5p7whw4OxZqr3HsdqhR2Z6y9kOYA9MToa09Lt0O
3aczncyKwx1OJJnmPHPvdug8q81myR3hMM096m6dd7fDkmvPtkaui3BI0an3
E/cHmnd/YWpVYKSD1uqFrIVB3Q57HyZr1r6MdFBmF+4PDO12ON0hxs6WE+WQ
ZWOxsy0caJ7qrQ36F6IcPr42Z3gV0e3wbOLFbWr80Q77+F7qJkd2O1x782DO
ApVoDHmY/i6ofpj5Z6Dmo9uP7j5096P7D+b/Hqj/YeFTCw0f9PBDD1/08AcA
aSCxPQ==
             "]]}, 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            LineBox[{{877.8556663826982, 87.79081969061721}, {
             871.7004638575143, 88.87614796753203}, {871.7596330392183, 
             89.21171307201215}, {877.9148355644024, 88.12638479509732}, {
             877.8556663826982, 87.79081969061721}}], 
            LineBox[{{877.9148355644024, 88.12638479509732}, {
             871.7596330392183, 89.21171307201215}, {871.9331083023792, 
             90.19554017812969}, {878.0883108275632, 89.11021190121487}, {
             877.9148355644024, 88.12638479509732}}], 
            LineBox[{{878.0883108275632, 89.11021190121487}, {
             871.9331083023792, 90.19554017812969}, {872.2090675944938, 
             91.76058309445392}, {878.3642701196777, 90.67525481753911}, {
             878.0883108275632, 89.11021190121487}}], 
            LineBox[{{878.3642701196777, 90.67525481753911}, {
             872.2090675944938, 91.76058309445392}, {872.5687047458489, 
             93.80018673259308}, {878.7239072710329, 92.71485845567827}, {
             878.3642701196777, 90.67525481753911}}], 
            LineBox[{{878.7239072710329, 92.71485845567827}, {
             872.5687047458489, 93.80018673259308}, {872.987511078908, 
             96.17535547521233}, {879.142713604092, 95.09002719829752}, {
             878.7239072710329, 92.71485845567827}}], 
            LineBox[{{879.142713604092, 95.09002719829752}, {872.987511078908,
              96.17535547521233}, {873.4369456341835, 98.72422549765412}, {
             879.5921481593675, 97.6388972207393}, {879.142713604092, 
             95.09002719829752}}], 
            LineBox[{{879.5921481593675, 97.6388972207393}, {
             873.4369456341835, 98.72422549765412}, {873.886380189459, 
             101.27309552009591`}, {880.041582714643, 100.1877672431811}, {
             879.5921481593675, 97.6388972207393}}], 
            LineBox[{{880.041582714643, 100.1877672431811}, {873.886380189459,
              101.27309552009591`}, {874.3051865225182, 
             103.64826426271516`}, {880.4603890477022, 102.56293598580035`}, {
             880.041582714643, 100.1877672431811}}], 
            LineBox[{{880.4603890477022, 102.56293598580035`}, {
             874.3051865225182, 103.64826426271516`}, {874.6648236738732, 
             105.6878679008543}, {880.8200261990573, 104.60253962393949`}, {
             880.4603890477022, 102.56293598580035`}}], 
            LineBox[{{880.8200261990573, 104.60253962393949`}, {
             874.6648236738732, 105.6878679008543}, {874.9407829659879, 
             107.25291081717855`}, {881.0959854911719, 106.16758254026374`}, {
             880.8200261990573, 104.60253962393949`}}], 
            LineBox[{{881.0959854911719, 106.16758254026374`}, {
             874.9407829659879, 107.25291081717855`}, {875.1142582291487, 
             108.23673792329609`}, {881.2694607543326, 107.15140964638127`}, {
             881.0959854911719, 106.16758254026374`}}], 
            LineBox[{{881.2694607543326, 107.15140964638127`}, {
             875.1142582291487, 108.23673792329609`}, {875.1734274108528, 
             108.5723030277762}, {881.3286299360368, 107.48697475086138`}, {
             881.2694607543326, 107.15140964638127`}}], 
            LineBox[{{881.3286299360368, 107.48697475086138`}, {
             875.1734274108528, 108.5723030277762}, {875.1142582291487, 
             108.23673792329609`}, {881.2694607543326, 107.15140964638127`}, {
             881.3286299360368, 107.48697475086138`}}], 
            LineBox[{{881.2694607543328, 107.15140964638127`}, {
             875.1142582291487, 108.23673792329609`}, {874.9407829659879, 
             107.25291081717856`}, {881.0959854911719, 106.16758254026374`}, {
             881.2694607543328, 107.15140964638127`}}], 
            LineBox[{{881.0959854911719, 106.16758254026374`}, {
             874.9407829659879, 107.25291081717856`}, {874.6648236738732, 
             105.68786790085431`}, {880.8200261990573, 104.60253962393949`}, {
             881.0959854911719, 106.16758254026374`}}], 
            LineBox[{{880.8200261990573, 104.60253962393949`}, {
             874.6648236738732, 105.68786790085431`}, {874.3051865225182, 
             103.64826426271516`}, {880.4603890477022, 102.56293598580035`}, {
             880.8200261990573, 104.60253962393949`}}], 
            LineBox[{{880.4603890477022, 102.56293598580035`}, {
             874.3051865225182, 103.64826426271516`}, {873.886380189459, 
             101.27309552009591`}, {880.041582714643, 100.1877672431811}, {
             880.4603890477022, 102.56293598580035`}}], 
            LineBox[{{880.041582714643, 100.1877672431811}, {873.886380189459,
              101.27309552009591`}, {873.4369456341835, 98.72422549765413}, {
             879.5921481593675, 97.63889722073931}, {880.041582714643, 
             100.1877672431811}}], 
            LineBox[{{879.5921481593675, 97.6388972207393}, {
             873.4369456341835, 98.72422549765412}, {872.987511078908, 
             96.17535547521233}, {879.142713604092, 95.09002719829752}, {
             879.5921481593675, 97.6388972207393}}], 
            LineBox[{{879.142713604092, 95.09002719829752}, {872.987511078908,
              96.17535547521233}, {872.5687047458489, 93.80018673259309}, {
             878.7239072710329, 92.71485845567827}, {879.142713604092, 
             95.09002719829752}}], 
            LineBox[{{878.7239072710329, 92.71485845567827}, {
             872.5687047458489, 93.80018673259309}, {872.2090675944938, 
             91.76058309445393}, {878.3642701196777, 90.67525481753913}, {
             878.7239072710329, 92.71485845567827}}], 
            LineBox[{{878.3642701196777, 90.67525481753911}, {
             872.2090675944938, 91.76058309445393}, {871.9331083023792, 
             90.19554017812969}, {878.0883108275632, 89.11021190121488}, {
             878.3642701196777, 90.67525481753911}}], 
            LineBox[{{878.0883108275632, 89.11021190121488}, {
             871.9331083023792, 90.19554017812969}, {871.7596330392183, 
             89.21171307201215}, {877.9148355644024, 88.12638479509732}, {
             878.0883108275632, 89.11021190121488}}], 
            LineBox[{{877.9148355644024, 88.12638479509732}, {
             871.7596330392183, 89.21171307201215}, {871.7004638575143, 
             88.87614796753203}, {877.8556663826982, 87.79081969061721}, {
             877.9148355644024, 88.12638479509732}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.54072072030962`, -3.308228120074471}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.54072072030962`, -3.308228120074471}, {
              178.18654469213524`, -6.623740105093745}, {
              178.2163132139489, -6.398537914060789}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.54072072030962`, -3.308228120074471}}], 
             PolygonBox[{{178.18654469213524`, -6.623740105093745}, {
              177.88754090475007`, -9.946545074457013}, {
              177.93219368747052`, -9.608741787907583}, {
              178.2163132139489, -6.398537914060789}, {
              178.18654469213524`, -6.623740105093745}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.55560498121642`, -3.1956270245579965`}, {
              178.2163132139489, -6.398537914060789}, {
              178.30359010382298`, -5.738278498116607}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.55560498121642`, -3.1956270245579965`}}], 
             PolygonBox[{{178.2163132139489, -6.398537914060789}, {
              177.93219368747052`, -9.608741787907583}, {
              178.06310902228162`, -8.61835266399131}, {
              178.30359010382298`, -5.738278498116607}, {
              178.2163132139489, -6.398537914060789}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.66866216721425`, -2.340336790191362}, {178.94999999999996`, 
              0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.59924342615352`, -2.8654973165859126`}, {
              178.30359010382298`, -5.738278498116607}, {
              178.44242758594442`, -4.687957445327516}, {
              178.66866216721425`, -2.340336790191362}, {
              178.59924342615352`, -2.8654973165859126`}}], 
             PolygonBox[{{178.30359010382298`, -5.738278498116607}, {
              178.06310902228162`, -8.61835266399131}, {
              178.2713652454639, -7.042871084807679}, {
              178.44242758594442`, -4.687957445327516}, {
              178.30359010382298`, -5.738278498116607}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.66866216721425`, -2.340336790191362}, {
              178.7591304319153, -1.6559342673793545`}, {178.94999999999996`, 
              0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.66866216721425`, -2.340336790191362}, {
              178.44242758594442`, -4.687957445327516}, {
              178.62336411534662`, -3.319152399703494}, {
              178.7591304319153, -1.6559342673793545`}, {
              178.66866216721425`, -2.340336790191362}}], 
             PolygonBox[{{178.44242758594442`, -4.687957445327516}, {
              178.2713652454639, -7.042871084807679}, {
              178.5427700395671, -4.989663516371639}, {
              178.62336411534662`, -3.319152399703494}, {
              178.44242758594442`, -4.687957445327516}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.7591304319153, -1.6559342673793545`}, {
              178.86448295752322`, -0.8589306490508584}, {178.94999999999996`,
               0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.7591304319153, -1.6559342673793545`}, {
              178.62336411534662`, -3.319152399703494}, {
              178.8340691665624, -1.7251451630465127`}, {
              178.86448295752322`, -0.8589306490508584}, {
              178.7591304319153, -1.6559342673793545`}}], 
             PolygonBox[{{178.62336411534662`, -3.319152399703494}, {
              178.5427700395671, -4.989663516371639}, {
              178.8588276163908, -2.5986526613861685`}, {
              178.8340691665624, -1.7251451630465127`}, {
              178.62336411534662`, -3.319152399703494}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.86448295752322`, -0.8589306490508584}, {
              178.977540143521, -0.003640414684223714}, {178.94999999999996`, 
              0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.86448295752322`, -0.8589306490508584}, {
              178.8340691665624, -1.7251451630465127`}, {
              179.060183538558, -0.014564694313246918`}, {
              178.977540143521, -0.003640414684223714}, {
              178.86448295752322`, -0.8589306490508584}}], 
             PolygonBox[{{178.8340691665624, -1.7251451630465127`}, {
              178.8588276163908, -2.5986526613861685`}, {
              179.1979991743842, -0.032781958286268065`}, {
              179.060183538558, -0.014564694313246918`}, {
              178.8340691665624, -1.7251451630465127`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.977540143521, -0.003640414684223714}, {179.09059732951877`, 
              0.8516498196824109}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{178.977540143521, -0.003640414684223714}, {
              179.060183538558, -0.014564694313243365`}, {179.2862979105536, 
              1.696015774420026}, {179.09059732951877`, 0.8516498196824109}, {
              178.977540143521, -0.003640414684223714}}], 
             PolygonBox[{{179.060183538558, -0.014564694313243365`}, {
              179.1979991743842, -0.03278195828626451}, {179.53717073237758`, 
              2.5330887448136394`}, {179.2862979105536, 1.696015774420026}, {
              179.060183538558, -0.014564694313243365`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.09059732951877`, 
              0.8516498196824109}, {179.19594985512674`, 
              1.6486534380108928`}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.09059732951877`, 0.8516498196824109}, {
              179.2862979105536, 1.696015774420026}, {179.49700296176937`, 
              3.290023011077004}, {179.19594985512674`, 
              1.6486534380108928`}, {179.09059732951877`, 
              0.8516498196824109}}], 
             PolygonBox[{{179.2862979105536, 1.696015774420026}, {
              179.53717073237758`, 2.5330887448136394`}, {179.85322830920128`,
               4.924099599799106}, {179.49700296176937`, 3.290023011077004}, {
              179.2862979105536, 1.696015774420026}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.19594985512674`, 
              1.6486534380108928`}, {179.28641811982774`, 
              2.3330559608229144`}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.19594985512674`, 1.6486534380108928`}, {
              179.49700296176937`, 3.290023011077004}, {179.67793949117151`, 
              4.6588280567010365`}, {179.28641811982774`, 
              2.3330559608229144`}, {179.19594985512674`, 
              1.6486534380108928`}}], 
             PolygonBox[{{179.49700296176937`, 3.290023011077004}, {
              179.85322830920128`, 4.924099599799106}, {180.1246331033045, 
              6.97730716823515}, {179.67793949117151`, 4.6588280567010365`}, {
              179.49700296176937`, 3.290023011077004}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.28641811982774`, 
              2.3330559608229144`}, {179.35583686088853`, 
              2.858216487217451}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.28641811982774`, 2.3330559608229144`}, {
              179.67793949117151`, 4.6588280567010365`}, {179.816776973293, 
              5.70914910949012}, {179.35583686088853`, 2.858216487217451}, {
              179.28641811982774`, 2.3330559608229144`}}], 
             PolygonBox[{{179.67793949117151`, 4.6588280567010365`}, {
              180.1246331033045, 6.97730716823515}, {180.33288932648676`, 
              8.552788747418784}, {179.816776973293, 5.70914910949012}, {
              179.67793949117151`, 4.6588280567010365`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.35583686088853`, 
              2.858216487217451}, {179.39947530582558`, 3.188346195189549}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{179.35583686088853`, 2.858216487217451}, {
              179.816776973293, 5.70914910949012}, {179.9040538631671, 
              6.369408525434302}, {179.39947530582558`, 3.188346195189549}, {
              179.35583686088853`, 2.858216487217451}}], 
             PolygonBox[{{179.816776973293, 5.70914910949012}, {
              180.33288932648676`, 8.55278874741878}, {180.46380466129787`, 
              9.543177871335054}, {179.9040538631671, 6.369408525434302}, {
              179.816776973293, 5.70914910949012}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.39947530582558`, 
              3.188346195189549}, {179.41435956673237`, 
              3.3009472907060236`}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.39947530582558`, 3.188346195189549}, {
              179.9040538631671, 6.369408525434302}, {179.93382238498074`, 
              6.594610716467255}, {179.41435956673237`, 
              3.3009472907060236`}, {179.39947530582558`, 
              3.188346195189549}}], 
             PolygonBox[{{179.9040538631671, 6.369408525434302}, {
              180.46380466129787`, 9.543177871335054}, {180.50845744401832`, 
              9.880981157884484}, {179.93382238498074`, 6.594610716467255}, {
              179.9040538631671, 6.369408525434302}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.41435956673237`, 
              3.3009472907060236`}, {179.39947530582558`, 
              3.188346195189549}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.41435956673237`, 3.3009472907060236`}, {
              179.93382238498074`, 6.594610716467255}, {179.9040538631671, 
              6.369408525434302}, {179.39947530582558`, 3.188346195189549}, {
              179.41435956673237`, 3.3009472907060236`}}], 
             PolygonBox[{{179.93382238498074`, 6.594610716467255}, {
              180.50845744401832`, 9.880981157884484}, {180.46380466129787`, 
              9.543177871335054}, {179.9040538631671, 6.369408525434302}, {
              179.93382238498074`, 6.594610716467255}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.39947530582558`, 
              3.188346195189549}, {179.35583686088853`, 2.858216487217451}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{179.39947530582558`, 3.188346195189549}, {
              179.9040538631671, 6.369408525434302}, {179.816776973293, 
              5.709149109490124}, {179.35583686088853`, 2.858216487217451}, {
              179.39947530582558`, 3.188346195189549}}], 
             PolygonBox[{{179.9040538631671, 6.369408525434302}, {
              180.46380466129787`, 9.543177871335054}, {180.33288932648676`, 
              8.552788747418788}, {179.816776973293, 5.709149109490124}, {
              179.9040538631671, 6.369408525434302}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.35583686088853`, 
              2.858216487217451}, {179.28641811982774`, 
              2.3330559608229144`}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.35583686088853`, 2.858216487217451}, {
              179.816776973293, 5.709149109490124}, {179.67793949117151`, 
              4.6588280567010365`}, {179.28641811982774`, 
              2.3330559608229144`}, {179.35583686088853`, 
              2.858216487217451}}], 
             PolygonBox[{{179.816776973293, 5.709149109490124}, {
              180.33288932648676`, 8.552788747418788}, {180.1246331033045, 
              6.9773071682351535`}, {179.67793949117151`, 
              4.6588280567010365`}, {179.816776973293, 5.709149109490124}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.28641811982774`, 
              2.3330559608229144`}, {179.19594985512674`, 
              1.6486534380108964`}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.28641811982774`, 2.3330559608229144`}, {
              179.67793949117151`, 4.65882805670104}, {179.49700296176937`, 
              3.2900230110770075`}, {179.19594985512674`, 
              1.6486534380108964`}, {179.28641811982774`, 
              2.3330559608229144`}}], 
             PolygonBox[{{179.67793949117151`, 4.65882805670104}, {
              180.1246331033045, 6.9773071682351535`}, {179.85322830920128`, 
              4.9240995997991135`}, {179.49700296176937`, 
              3.2900230110770075`}, {179.67793949117151`, 4.65882805670104}}],
              PolygonBox[{{178.94999999999996`, 0.}, {179.19594985512674`, 
              1.6486534380108964`}, {179.09059732951877`, 
              0.8516498196824145}, {178.94999999999996`, 0.}, {
              178.94999999999996`, 0.}}], 
             PolygonBox[{{179.19594985512674`, 1.6486534380108964`}, {
              179.49700296176937`, 3.2900230110770075`}, {179.2862979105536, 
              1.6960157744200295`}, {179.09059732951877`, 
              0.8516498196824145}, {179.19594985512674`, 
              1.6486534380108964`}}], 
             PolygonBox[{{179.49700296176937`, 3.2900230110770075`}, {
              179.85322830920128`, 4.9240995997991135`}, {179.53717073237758`,
               2.5330887448136465`}, {179.2862979105536, 
              1.6960157744200295`}, {179.49700296176937`, 
              3.2900230110770075`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {179.09059732951877`, 
              0.8516498196824145}, {
              178.977540143521, -0.0036404146842201612`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{179.09059732951877`, 0.8516498196824145}, {
              179.2862979105536, 1.6960157744200295`}, {
              179.060183538558, -0.01456469431323626}, {
              178.977540143521, -0.0036404146842201612`}, {
              179.09059732951877`, 0.8516498196824145}}], 
             PolygonBox[{{179.2862979105536, 1.6960157744200295`}, {
              179.53717073237758`, 2.5330887448136465`}, {
              179.1979991743842, -0.032781958286253854`}, {
              179.060183538558, -0.01456469431323626}, {179.2862979105536, 
              1.6960157744200295`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.977540143521, -0.003640414684223714}, {
              178.86448295752322`, -0.8589306490508584}, {178.94999999999996`,
               0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.977540143521, -0.003640414684223714}, {
              179.060183538558, -0.014564694313243365`}, {
              178.8340691665624, -1.7251451630465091`}, {
              178.86448295752322`, -0.8589306490508584}, {
              178.977540143521, -0.003640414684223714}}], 
             PolygonBox[{{179.060183538558, -0.014564694313243365`}, {
              179.1979991743842, -0.03278195828626096}, {
              178.8588276163908, -2.598652661386165}, {
              178.8340691665624, -1.7251451630465091`}, {
              179.060183538558, -0.014564694313243365`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.86448295752322`, -0.8589306490508584}, {
              178.7591304319153, -1.6559342673793545`}, {178.94999999999996`, 
              0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.86448295752322`, -0.8589306490508584}, {
              178.8340691665624, -1.7251451630465091`}, {
              178.62336411534662`, -3.319152399703487}, {
              178.7591304319153, -1.6559342673793545`}, {
              178.86448295752322`, -0.8589306490508584}}], 
             PolygonBox[{{178.8340691665624, -1.7251451630465091`}, {
              178.8588276163908, -2.598652661386165}, {
              178.5427700395671, -4.989663516371632}, {
              178.62336411534662`, -3.319152399703487}, {
              178.8340691665624, -1.7251451630465091`}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.7591304319153, -1.6559342673793545`}, {
              178.66866216721425`, -2.3403367901913583`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.7591304319153, -1.6559342673793545`}, {
              178.62336411534662`, -3.319152399703487}, {
              178.44242758594442`, -4.687957445327513}, {
              178.66866216721425`, -2.3403367901913583`}, {
              178.7591304319153, -1.6559342673793545`}}], 
             PolygonBox[{{178.62336411534662`, -3.319152399703487}, {
              178.5427700395671, -4.989663516371632}, {
              178.2713652454639, -7.042871084807672}, {
              178.44242758594442`, -4.687957445327513}, {
              178.62336411534662`, -3.319152399703487}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.66866216721425`, -2.340336790191362}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.66866216721425`, -2.340336790191362}, {
              178.44242758594442`, -4.687957445327516}, {
              178.30359010382298`, -5.738278498116607}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.66866216721425`, -2.340336790191362}}], 
             PolygonBox[{{178.44242758594442`, -4.687957445327516}, {
              178.2713652454639, -7.042871084807679}, {
              178.06310902228162`, -8.61835266399131}, {
              178.30359010382298`, -5.738278498116607}, {
              178.44242758594442`, -4.687957445327516}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.59924342615352`, -2.8654973165859126`}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.94999999999996`, 0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.59924342615352`, -2.8654973165859126`}, {
              178.30359010382298`, -5.738278498116607}, {
              178.2163132139489, -6.398537914060789}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.59924342615352`, -2.8654973165859126`}}], 
             PolygonBox[{{178.30359010382298`, -5.738278498116607}, {
              178.06310902228162`, -8.61835266399131}, {
              177.93219368747052`, -9.608741787907583}, {
              178.2163132139489, -6.398537914060789}, {
              178.30359010382298`, -5.738278498116607}}], 
             PolygonBox[{{178.94999999999996`, 0.}, {
              178.55560498121642`, -3.1956270245579965`}, {
              178.54072072030962`, -3.308228120074471}, {178.94999999999996`, 
              0.}, {178.94999999999996`, 0.}}], 
             PolygonBox[{{178.55560498121642`, -3.1956270245579965`}, {
              178.2163132139489, -6.398537914060789}, {
              178.18654469213524`, -6.623740105093745}, {
              178.54072072030962`, -3.308228120074471}, {
              178.55560498121642`, -3.1956270245579965`}}], 
             PolygonBox[{{178.2163132139489, -6.398537914060789}, {
              177.93219368747052`, -9.608741787907583}, {
              177.88754090475007`, -9.946545074457013}, {
              178.18654469213524`, -6.623740105093745}, {
              178.2163132139489, -6.398537914060789}}], 
             {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXfhDb0+aTZqDzvfQvoVPlA+oq99uv2Kb5iDS/ZZh
rbnyAfZIs78sTmkOOZVZO2bYKB6wvqjFtt4jzWHF0TOpz7RlDvCrucXHBaY5
mBQGR2V9FT4weyVvS3V0moNCp1AG1ymWA+uDY5nC0tIcGDiq/p4+sWD/4b9r
GgwK0xwe7FDjOOLM4uDfWLLUtzrNQaAzVst9k7CD8rX+f3+a0xw67l4zPfxC
2iHcr4V9eVeaQ0xrvgK7tKKDecP9mut9aQ4s0z9lSIspO7xd1+3hOiHNQYY5
+hv/YWUMeZj+BKh+mPk9UPNh9ktA7Ye57wPUfXD3s0HcD/OfBNR/MP/rQP2P
Hj7o4YcevujhDwA2Qaqd
               "]]}, 
             {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvWpnyH+5slSHOeWzFdwclQ4kvGA43VOe6tDCbTw5
cIriAUepGIe91akOez7HT60ykj9QMinAM70p1aHjWHiX/lOJA57PsxeJdac6
iBTdq9u8TuDA5Szj48ZTUx2OiQYmWVb+2f9CpNmVb0GqQ33EBWktzZf2f/dd
OvxiVaqD3HaB/YYXuRzanWa9YN2a6mDUcYn13w8xh5jpWx237k11WHHHW7BK
X96hn3+VV/yRVIe3LFp9SfuUHAocWQ/0n0h1mCy29lrZThUHtYKN3X9Ppjqs
aRJNyU5ThctPhcrD9L+H6oeZvw5qPsx+K6j9MPcZQd0Hc/8UqPth/lsB9R/M
/zxQ/8PCpw0aPrDw2wENP1j4NkPDFz38ARm6tcU=
               "]]}, 
             {GrayLevel[0], AbsoluteThickness[0.5], 
              LineBox[{{177.88754090475007`, -9.946545074457013}, {
               171.69128386066342`, -9.12748815439027}, {
               171.73593664338387`, -8.78968486784084}, {
               177.93219368747052`, -9.608741787907583}, {
               177.88754090475007`, -9.946545074457013}}], 
              LineBox[{{177.93219368747052`, -9.608741787907583}, {
               171.73593664338387`, -8.78968486784084}, {
               171.866851978195, -7.799295743924571}, {
               178.06310902228162`, -8.61835266399131}, {
               177.93219368747052`, -9.608741787907583}}], 
              LineBox[{{178.06310902228162`, -8.61835266399131}, {
               171.866851978195, -7.799295743924571}, {
               172.07510820137725`, -6.223814164740936}, {
               178.2713652454639, -7.042871084807679}, {
               178.06310902228162`, -8.61835266399131}}], 
              LineBox[{{178.2713652454639, -7.042871084807679}, {
               172.07510820137725`, -6.223814164740936}, {
               172.34651299548048`, -4.170606596304896}, {
               178.5427700395671, -4.989663516371639}, {
               178.2713652454639, -7.042871084807679}}], 
              LineBox[{{178.5427700395671, -4.989663516371639}, {
               172.34651299548048`, -4.170606596304896}, {
               172.66257057230413`, -1.7795957413194272`}, {
               178.8588276163908, -2.5986526613861685`}, {
               178.5427700395671, -4.989663516371639}}], 
              LineBox[{{178.8588276163908, -2.5986526613861685`}, {
               172.66257057230413`, -1.7795957413194272`}, {
               173.00174213029754`, 0.7862749617804757}, {
               179.1979991743842, -0.032781958286268065`}, {
               178.8588276163908, -2.5986526613861685`}}], 
              LineBox[{{179.1979991743842, -0.03278195828626451}, {
               173.00174213029754`, 0.786274961780478}, {173.34091368829095`, 
               3.352145664880381}, {179.53717073237758`, 
               2.5330887448136394`}, {
               179.1979991743842, -0.03278195828626451}}], 
              LineBox[{{179.53717073237758`, 2.5330887448136394`}, {
               173.34091368829095`, 3.352145664880381}, {173.6569712651146, 
               5.743156519865851}, {179.85322830920128`, 4.924099599799106}, {
               179.53717073237758`, 2.5330887448136394`}}], 
              LineBox[{{179.85322830920128`, 4.924099599799106}, {
               173.6569712651146, 5.743156519865851}, {173.92837605921784`, 
               7.7963640883018925`}, {180.1246331033045, 6.97730716823515}, {
               179.85322830920128`, 4.924099599799106}}], 
              LineBox[{{180.1246331033045, 6.97730716823515}, {
               173.92837605921784`, 7.7963640883018925`}, {174.1366322824001, 
               9.371845667485527}, {180.33288932648676`, 8.552788747418784}, {
               180.1246331033045, 6.97730716823515}}], 
              LineBox[{{180.33288932648676`, 8.55278874741878}, {
               174.1366322824001, 9.371845667485525}, {174.26754761721122`, 
               10.362234791401795`}, {180.46380466129787`, 
               9.543177871335054}, {180.33288932648676`, 8.55278874741878}}], 
              LineBox[{{180.46380466129787`, 9.543177871335054}, {
               174.26754761721122`, 10.362234791401795`}, {
               174.31220039993167`, 10.700038077951227`}, {
               180.50845744401832`, 9.880981157884484}, {180.46380466129787`, 
               9.543177871335054}}], 
              LineBox[{{180.50845744401832`, 9.880981157884484}, {
               174.31220039993167`, 10.700038077951227`}, {
               174.26754761721122`, 10.362234791401796`}, {
               180.46380466129787`, 9.543177871335054}, {180.50845744401832`, 
               9.880981157884484}}], 
              LineBox[{{180.46380466129787`, 9.543177871335054}, {
               174.26754761721122`, 10.362234791401798`}, {174.1366322824001, 
               9.371845667485529}, {180.33288932648676`, 8.552788747418788}, {
               180.46380466129787`, 9.543177871335054}}], 
              LineBox[{{180.33288932648676`, 8.552788747418788}, {
               174.1366322824001, 9.371845667485529}, {173.92837605921784`, 
               7.796364088301896}, {180.1246331033045, 6.9773071682351535`}, {
               180.33288932648676`, 8.552788747418788}}], 
              LineBox[{{180.1246331033045, 6.9773071682351535`}, {
               173.92837605921784`, 7.796364088301898}, {173.6569712651146, 
               5.743156519865858}, {179.85322830920128`, 
               4.9240995997991135`}, {180.1246331033045, 
               6.9773071682351535`}}], 
              LineBox[{{179.85322830920128`, 4.9240995997991135`}, {
               173.6569712651146, 5.743156519865858}, {173.34091368829095`, 
               3.35214566488039}, {179.53717073237758`, 
               2.5330887448136465`}, {179.85322830920128`, 
               4.9240995997991135`}}], 
              LineBox[{{179.53717073237758`, 2.5330887448136465`}, {
               173.34091368829095`, 3.35214566488039}, {173.00174213029754`, 
               0.7862749617804892}, {
               179.1979991743842, -0.032781958286253854`}, {
               179.53717073237758`, 2.5330887448136465`}}], 
              LineBox[{{179.1979991743842, -0.03278195828626096}, {
               173.00174213029754`, 0.7862749617804803}, {
               172.66257057230413`, -1.7795957413194206`}, {
               178.8588276163908, -2.598652661386165}, {
               179.1979991743842, -0.03278195828626096}}], 
              LineBox[{{178.8588276163908, -2.598652661386165}, {
               172.66257057230413`, -1.7795957413194206`}, {
               172.34651299548048`, -4.170606596304889}, {
               178.5427700395671, -4.989663516371632}, {
               178.8588276163908, -2.598652661386165}}], 
              LineBox[{{178.5427700395671, -4.989663516371632}, {
               172.34651299548048`, -4.170606596304889}, {
               172.07510820137725`, -6.223814164740929}, {
               178.2713652454639, -7.042871084807672}, {
               178.5427700395671, -4.989663516371632}}], 
              LineBox[{{178.2713652454639, -7.042871084807679}, {
               172.07510820137725`, -6.223814164740935}, {
               171.866851978195, -7.799295743924567}, {
               178.06310902228162`, -8.61835266399131}, {
               178.2713652454639, -7.042871084807679}}], 
              LineBox[{{178.06310902228162`, -8.61835266399131}, {
               171.866851978195, -7.799295743924567}, {
               171.73593664338387`, -8.789684867840839}, {
               177.93219368747052`, -9.608741787907583}, {
               178.06310902228162`, -8.61835266399131}}], 
              LineBox[{{177.93219368747052`, -9.608741787907583}, {
               171.73593664338387`, -8.789684867840839}, {
               171.69128386066342`, -9.12748815439027}, {
               177.88754090475007`, -9.946545074457013}, {
               177.93219368747052`, -9.608741787907583}}]}}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{250., 0.}, {450., 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{450., 0.}, {459.18621543719763`, -3.9543388611028942`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{459.18621543719763`, -3.9543388611028942`}, {
       659.1862154371977, -3.9543388611028942`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{659.1862154371977, -3.9543388611028942`}, {
       665.1934363220911, -4.133769426549076}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{659.1862154371977, -3.9543388611028942`}, {0., 
       112.27797623157788`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{665.1934363220911, -4.133769426549076}, {
       705.1934363220911, -4.133769426549076}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{705.1934363220911, -4.133769426549076}, {
       714.3796517592887, -8.08810828765197}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{714.3796517592887, -8.08810828765197}, {
       764.3796517592887, -8.088108287651966}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{764.3796517592887, -8.088108287651966}, {
       773.5658671964862, -12.042447148754862`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{773.5658671964862, -12.042447148754862`}, {
       1273.5658671964866`, -12.042447148754865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1273.5658671964866`, -12.042447148754865`}, {
       1225.269575882033, 0.8985051063712362}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1225.269575882033, 0.8985051063712362}, {1217.419831353431, 
       7.0956706457705625`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1217.419831353431, 7.0956706457705625`}, {879.3457921522569, 
       97.6823364316528}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{450., 0.}, {459.18621543719763`, -3.9543388611028942`}, {
      659.1862154371977, -3.9543388611028942`}, {
      665.1934363220911, -4.133769426549076}, {0., 112.27797623157788`}, {
      705.1934363220911, -4.133769426549076}, {
      714.3796517592887, -8.08810828765197}, {
      764.3796517592887, -8.088108287651966}, {
      773.5658671964862, -12.042447148754862`}, {
      1273.5658671964866`, -12.042447148754865`}, {1225.269575882033, 
      0.8985051063712362}, {1217.419831353431, 7.0956706457705625`}, {
      879.3457921522569, 97.6823364316528}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"AC\"\>", {1197.8201429710316`, -25.79077329616765}, \
{0., 0.}], 
    InsetBox["\<\"BRF\"\>", {469.6064226151047, 32.88429930866231}, {0., 0.}],
     InsetBox["\<\"Diode\"\>", {783.9860743743933, 24.796191021010337`}, \
{0., 0.}], 
    InsetBox["\<\"LFM\"\>", {882.9826588087744, 135.58434363056597`}, \
{0., 0.}], 
    InsetBox["\<\"OC\"\>", {658.8665657453565, -42.02909129441862}, {0., 0.}],
     InsetBox["\<\"Rhomb\"\>", {724.7998589371957, 28.750529882113234`}, \
{0., 0.}], 
    InsetBox["\<\"Tweeter\"\>", {180.95007263377204`, 38.02352769330342}, \
{0., 0.}], 
    InsetBox["\<\"UFM\"\>", {1272.2383553261955`, -45.109793623829766`}, \
{0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301494497066*^9, 3.614709260433648*^9, 
  3.6147291163587418`*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"},
 CellLabel->"During evaluation of In[174]:="]
}, Open  ]],

Cell[TextData[{
 "The source ",
 StyleBox["SingleRay", "MB"],
 " shifted past the ",
 StyleBox["Tweeter", "MB"],
 " to trace the system.  In the pilot trace, the ",
 StyleBox["SingleRay", "MB"],
 " emerged from ",
 StyleBox["{0,0}", "MB"],
 ", but here it emerges from ",
 StyleBox["{250,0}", "MB"],
 " and resonates in the laser cavity.  The ",
 StyleBox["Resonate", "MB"],
 " function instructs ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " that this is a resonating cavity.  System output emerges from the \
beam-splitter ",
 StyleBox["OC", "MB"],
 " at right."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[{
 "The lesson of this example is how ",
 StyleBox["MoveAligned", "MB"],
 " simplified the design.  All that had to be specified was the spacing from \
one component to the next.  ",
 StyleBox["MoveAligned", "MB"],
 " handled the task of keeping the components aligned with the light path \
inside the cavity."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2.4 Chromatic Sources", "Subsection",
 CellTags->{"4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}
  ],

Cell[TextData[{
 "Often you need a light source with certain chromatic characteristics.  The \
most common type of chromatic source is white light.  White light contains \
all visible wavelengths equally.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " can approximate white light with colinear rays of different wavelengths.  \
Multiple ray objects follow the same path, but each has a distinct wavelength."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[{
 StyleBox["RainbowOfRays", "MB"],
 " creates a white light source.  You must supply two numbers, in microns, \
delimiting the bandwidth of the white light. The bandwidth divides evenly \
across the ",
 StyleBox["NumberOfRays", "MB"],
 " specified.  Each ray has only one wavelength; the more rays, the better ",
 StyleBox["RainbowOfRays", "MB"],
 " populates the bandwidth."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[{
 "The following is a ",
 StyleBox["RainbowOfRays", "MB"],
 " passing through a diffraction grating.  The rays start out colinear, but \
diffract differently according to their different wavelengths.  By default,  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " renders each ray with a screen color matching its wavelength."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rainbowSource", "=", 
   RowBox[{"RainbowOfRays", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{".4", ",", ".65"}], "}"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "8"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"rainbowSource", ",", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Grating", "[", 
        RowBox[{"800", ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "20"}], "}"}], ",", "1", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", "20"}], 
      "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{"85", ",", "20"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"75", ",", "35"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
    "}"}], "]"}], ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"In[175]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
      20., -10., 10.}, {20., -10., -10.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
       20., -10., 10.}, {20., -10., -10.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375,
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375, 
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
          10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
           10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {
            21.0075, 10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {21.0075, 
             10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {20.00375, 
              10., -10.}, {20., 10., -10.}, {20., 10., 10.}}], 
             Polygon3DBox[{{20., 10., -10.}, {20.00375, 10., -10.}, {
              20.00375, -10., -10.}, {20., -10., -10.}, {20., 10., -10.}}], 
             Polygon3DBox[{{20., -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., -10., -10.}}], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., 10., 10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, 10., -10.}, {20.00375, 10., -10.}, {20.00375, 10., 
              10.}}], Polygon3DBox[{{20.00375, 10., -10.}, {20.0075, 
              10., -10.}, {20.0075, -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, 10., -10.}}], 
             Polygon3DBox[{{20.00375, -10., -10.}, {20.0075, -10., -10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {
              20.00375, -10., -10.}}], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {20.00375, 10., 
              10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {21.0075,
               10., -10.}, {20.0075, 10., -10.}, {20.0075, 10., 10.}}], 
             Polygon3DBox[{{20.0075, 10., -10.}, {21.0075, 10., -10.}, {
              21.0075, -10., -10.}, {20.0075, -10., -10.}, {20.0075, 
              10., -10.}}], 
             Polygon3DBox[{{20.0075, -10., -10.}, {21.0075, -10., -10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {
              20.0075, -10., -10.}}], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {20.0075, 10., 
              10.}}]}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOQAYcgdYEAGQPEVq0BAygFdPBQErppgiIPp
Bkfs6qd6YIiDjV/lj92chGCixVfjMCcMh7243BmGw18bcIQDhIEZbujiAC+Z
OUc=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOQAphscITSDygF08dWrQEAKQ3wNWJwLQ5wB
GSCJr4Cod8AuLoUhDnUP0eKrcZizBoe9BNyJ4a8VOMIB6h6c4gCb30x9
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{75., -7.5, -10.}, {75., 77.5, -10.}, {75., 77.5, 10.}, {
      75., -7.5, 10.}, {75., -7.5, -10.}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[
     0.00014232872026925802`, 0.06100616222842559, 0.9245653045955307], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.0029195316244007286`, 0.2620647688199004, 0.7478723780009169],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.012269748700108773`, 0.8705164430239098, 0.0811097489482357], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.08429885281448907, 0.9219992922171469, 0.03204489532805488], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9255035138909913, 0.8948510066587307, 0.018815429279408213`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9511160833375614, 0.08350666720565736, 0.012919395072518991`],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[
     0.00014232872026925802`, 0.06100616222842559, 0.9245653045955307], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.0029195316244007286`, 0.2620647688199004, 0.7478723780009169],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.012269748700108773`, 0.8705164430239098, 0.0811097489482357], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.08429885281448907, 0.9219992922171469, 0.03204489532805488], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9255035138909913, 0.8948510066587307, 0.018815429279408213`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9511160833375614, 0.08350666720565736, 0.012919395072518991`],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0008015878672741625, 0.}}}]}, 
    {RGBColor[
     0.00014232872026925802`, 0.06100616222842559, 0.9245653045955307], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0008794179106335223, 0.}}}]}, 
    {RGBColor[0.0029195316244007286`, 0.2620647688199004, 0.7478723780009169],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0009581408993863582, 0.}}}]}, 
    {RGBColor[0.012269748700108773`, 0.8705164430239098, 0.0811097489482357], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0010379233658994464`, 0.}}}]}, 
    {RGBColor[0.08429885281448907, 0.9219992922171469, 0.03204489532805488], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0011189251026216685`, 0.}}}]}, 
    {RGBColor[0.9255035138909913, 0.8948510066587307, 0.018815429279408213`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0012013059840616288`, 0.}}}]}, 
    {RGBColor[0.9511160833375614, 0.08350666720565736, 0.012919395072518991`],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0012852304574813716`, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0013708709797176347`, 0.}}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0008015878672741625, 0.}, {21.0075, 0.21455835247370939`, 0.}}}]}, 
    {RGBColor[
     0.00014232872026925802`, 0.06100616222842559, 0.9245653045955307], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0008794179106335223, 0.}, {21.0075, 0.23539086074623058`, 0.}}}]}, 
    {RGBColor[0.0029195316244007286`, 0.2620647688199004, 0.7478723780009169],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0009581408993863582, 0.}, {21.0075, 0.2564623807357388, 0.}}}]}, 
    {RGBColor[0.012269748700108773`, 0.8705164430239098, 0.0811097489482357], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0010379233658994464`, 0.}, {21.0075, 0.2778174876057413, 0.}}}]}, 
    {RGBColor[0.08429885281448907, 0.9219992922171469, 0.03204489532805488], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0011189251026216685`, 0.}, {21.0075, 0.2994989524683887, 0.}}}]}, 
    {RGBColor[0.9255035138909913, 0.8948510066587307, 0.018815429279408213`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0012013059840616288`, 0.}, {21.0075, 0.3215495684004839, 0.}}}]}, 
    {RGBColor[0.9511160833375614, 0.08350666720565736, 0.012919395072518991`],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0012852304574813716`, 0.}, {21.0075, 0.34401335245250075`, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0013708709797176347`, 0.}, {21.0075, 0.36693646557107296`, 0.}}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.21455835247370939`, 0.}, {75., 18.445516795391136`, 0.}}}]}, 
    {RGBColor[
     0.00014232872026925802`, 0.06100616222842559, 0.9245653045955307], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.23539086074623058`, 0.}, {75., 20.308760310330737`, 0.}}}]}, 
    {RGBColor[0.0029195316244007286`, 0.2620647688199004, 0.7478723780009169],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2564623807357388, 0.}, {75., 22.23599316004487, 0.}}}]}, 
    {RGBColor[0.012269748700108773`, 0.8705164430239098, 0.0811097489482357], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2778174876057413, 0.}, {75., 24.236736315113404`, 0.}}}]}, 
    {RGBColor[0.08429885281448907, 0.9219992922171469, 0.03204489532805488], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2994989524683887, 0.}, {75., 26.32196773370386, 0.}}}]}, 
    {RGBColor[0.9255035138909913, 0.8948510066587307, 0.018815429279408213`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.3215495684004839, 0.}, {75., 28.504478593101297`, 0.}}}]}, 
    {RGBColor[0.9511160833375614, 0.08350666720565736, 0.012919395072518991`],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.34401335245250075`, 0.}, {75., 30.799334320896385`, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.36693646557107296`, 0.}, {75., 33.22448094314466, 0.}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGBwAGJmBhgwcWDACga/uGZM/6GvQ1g8aIdc62tG3OIcrgnX
TFy87IlVP8nBdKr4RR+i1a9V+/ayPNWfaPXN/5N2xTIGEq3+cKTNOpnQIKLV
z2ivr1qyLpho9a43xTct5QslWn156IzGm6VhaOpNcag3deBcXvVyadlpotU7
h4ev8FQ8R7T6e81VBg8zLxCt/kDjw/+Hjl8kWn1qXtPyv1qXiVb/ZrXIEpcp
V4hWP+1d15QAlmtEq+eZfVX0cfV1exTJA0EY6mHifGxNybxFRg7Eqo/XyX7F
5W9CtPoPFRY8WTZmRKvnMPA+MMvGgmj1ogvMqnKCrIhW/+VZUJNqow3R6pku
9eksPGNHtPrrGxad2j3HAS4PACFb7BE=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301495651208*^9, 3.614709261710368*^9, 
  3.614729117538577*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"During evaluation of In[175]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["RainbowOfRays", "MB"],
 " diffracted by a ",
 StyleBox["Grating", "MB"],
 ".  The color separation is even across the screen."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[{
 "If you need to test specific wavelengths, use ",
 StyleBox["CustomRays", "MB"],
 " instead.  The ",
 StyleBox["WaveLength", "MB"],
 " specifier allows you to create a set of colinear rays with arbitrary \
wavelength settings.  You need not rely on the even-distribution principle of \
 ",
 StyleBox["RainbowOfRays", "MB"],
 ", but you may instead define your own distribution."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"whiteLightSource", "=", 
   RowBox[{
    StyleBox["CustomRays", "MB"], "[", 
    RowBox[{"{", 
     RowBox[{"WaveLength", ",", 
      RowBox[{"{", 
       RowBox[{
       ".446", ",", ".476", ",", ".512", ",", ".530", ",", ".532", ",", 
        ".590", ",", ".632", ",", ".650"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"whiteLightSource", ",", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Grating", "[", 
        RowBox[{"800", ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "20"}], "}"}], ",", "1", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", "20"}], 
      "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", 
        RowBox[{"{", 
         RowBox[{"85", ",", "20"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"75", ",", "35"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
    "}"}], "]"}], ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"In[177]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
      20., -10., 10.}, {20., -10., -10.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
       20., -10., 10.}, {20., -10., -10.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375,
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375, 
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
          10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
           10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {
            21.0075, 10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {21.0075, 
             10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {20.00375, 
              10., -10.}, {20., 10., -10.}, {20., 10., 10.}}], 
             Polygon3DBox[{{20., 10., -10.}, {20.00375, 10., -10.}, {
              20.00375, -10., -10.}, {20., -10., -10.}, {20., 10., -10.}}], 
             Polygon3DBox[{{20., -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., -10., -10.}}], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., 10., 10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, 10., -10.}, {20.00375, 10., -10.}, {20.00375, 10., 
              10.}}], Polygon3DBox[{{20.00375, 10., -10.}, {20.0075, 
              10., -10.}, {20.0075, -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, 10., -10.}}], 
             Polygon3DBox[{{20.00375, -10., -10.}, {20.0075, -10., -10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {
              20.00375, -10., -10.}}], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {20.00375, 10., 
              10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {21.0075,
               10., -10.}, {20.0075, 10., -10.}, {20.0075, 10., 10.}}], 
             Polygon3DBox[{{20.0075, 10., -10.}, {21.0075, 10., -10.}, {
              21.0075, -10., -10.}, {20.0075, -10., -10.}, {20.0075, 
              10., -10.}}], 
             Polygon3DBox[{{20.0075, -10., -10.}, {21.0075, -10., -10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {
              20.0075, -10., -10.}}], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {20.0075, 10., 
              10.}}]}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOQAYcgdYEAGQPEVq0BAygFdPBQErppgiIPp
Bkfs6qd6YIiDjV/lj92chGCixVfjMCcMh7243BmGw18bcIQDhIEZbujiAC+Z
OUc=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4EOQAphscITSDygF08dWrQEAKQ3wNWJwLQ5wB
GSCJr4Cod8AuLoUhDnUP0eKrcZizBoe9BNyJ4a8VOMIB6h6c4gCb30x9
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{75., -7.5, -10.}, {75., 77.5, -10.}, {75., 77.5, 10.}, {
      75., -7.5, 10.}, {75., -7.5, -10.}}]}, 
    {RGBColor[0.0004723914058232803, 0.08072189441827354, 0.9098778825823923],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.0035777879630370935`, 0.3660529318034587, 0.6349588969127503],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.014934111286966645`, 0.8855223875743046, 0.06815786895594672],
      AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.0345992871928365, 0.9144691708111385, 0.04166187027570961], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.0004723914058232803, 0.08072189441827354, 0.9098778825823923],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.0035777879630370935`, 0.3660529318034587, 0.6349588969127503],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.014934111286966645`, 0.8855223875743046, 0.06815786895594672],
      AbsoluteThickness[0.5], Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.0345992871928365, 0.9144691708111385, 0.04166187027570961], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.0004723914058232803, 0.08072189441827354, 0.9098778825823923],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.000901991028211396, 0.}}}]}, 
    {RGBColor[0.0035777879630370935`, 0.3660529318034587, 0.6349588969127503],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0009682905438860188, 0.}}}]}, 
    {RGBColor[0.014934111286966645`, 0.8855223875743046, 0.06815786895594672],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0010488644347242844`, 0.}}}]}, 
    {RGBColor[0.0345992871928365, 0.9144691708111385, 0.04166187027570961], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0010896140082123484`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0010941620785389807`, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0012279858068713315`, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0013274825208540778`, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0013708709797176347`, 0.}}}]}, 
    {RGBColor[0.0004723914058232803, 0.08072189441827354, 0.9098778825823923],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.000901991028211396, 0.}, {21.0075, 0.24143293188457454`, 0.}}}]}, 
    {RGBColor[0.0035777879630370935`, 0.3660529318034587, 0.6349588969127503],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0009682905438860188, 0.}, {21.0075, 0.25917910224681456`, 0.}}}]}, 
    {RGBColor[0.014934111286966645`, 0.8855223875743046, 0.06815786895594672],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0010488644347242844`, 0.}, {21.0075, 0.2807460470278562, 0.}}}]}, 
    {RGBColor[0.0345992871928365, 0.9144691708111385, 0.04166187027570961], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0010896140082123484`, 0.}, {21.0075, 0.29165334953149424`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0010941620785389807`, 0.}, {21.0075, 0.2928707163555894, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0012279858068713315`, 0.}, {21.0075, 0.3286908676392139, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0013274825208540778`, 0.}, {21.0075, 0.3553228214152614, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0013708709797176347`, 0.}, {21.0075, 0.36693646557107296`, 0.}}}]}, 
    {RGBColor[0.0004723914058232803, 0.08072189441827354, 0.9098778825823923],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.24143293188457454`, 0.}, {75., 20.85684791099162, 0.}}}]}, 
    {RGBColor[0.0035777879630370935`, 0.3660529318034587, 0.6349588969127503],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.25917910224681456`, 0.}, {75., 22.487771084572227`, 0.}}}]}, 
    {RGBColor[0.014934111286966645`, 0.8855223875743046, 0.06815786895594672],
      AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2807460470278562, 0.}, {75., 24.515099949471058`, 0.}}}]}, 
    {RGBColor[0.0345992871928365, 0.9144691708111385, 0.04166187027570961], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.29165334953149424`, 0.}, {75., 25.560789328844976`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2928707163555894, 0.}, {75., 25.678393891780313`, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.3286908676392139, 0.}, {75., 29.22581467985691, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.3553228214152614, 0.}, {75., 31.984670806750543`, 0.}}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.36693646557107296`, 0.}, {75., 33.22448094314466, 0.}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGBwAGJmBhgwcWDACga/uGZM/6GvQ1g8aIdc62tG3OJ/m67+
LurztSdW/YzdHDJzdvkTrf6CZs0cR/1AotVbeH9R1LlFvPrgOYzT7N8Sr/5T
e+SObrkQotWL+V5ruLs/lGj15aEzGm+WhqGpN8Wh3tSBaZK/pdvzc0Sr3271
92PytAtEq19yca7Lvu8XiVbfldNwvmjVJaLVr2bWvZiyj3j1zm4Hsl05rxKt
Pkgg4d3svdeIVs8z+6ro4+rr9iiSB4Iw1MPE70RVJ0XdRotPPOqFdW5MuFdj
RrR6JzXZ6XebLYhWfyB08+P+fkui1a9muG2xei3x6g0+rvh7ztKWaPVnAi8k
Cf+xJ1r99Q2LTu2e4wCXBwCx6vNP
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301496648526*^9, 3.614709262744268*^9, 
  3.6147291185247593`*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"During evaluation of In[177]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["CustomRays", "MB"],
 " diffracted by a ",
 StyleBox["Grating", "MB"],
 ".  The color separation is uneven because the wavelengths were manually \
defined."
}], "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[{
 StyleBox["CustomRays", "MB"],
 " acts effectively like a single, multichromatic ray.  Sometimes you need \
more than one of these multichromatic rays.  Since light sources can be \
nested, the task is not hard.  Use ",
 StyleBox["CustomRays", "MB"],
 " as the inner light source."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[{
 "Define a ",
 StyleBox["CustomRays", "MB"],
 " nested inside a ",
 StyleBox["PointOfRays", "MB"],
 ". Set not only the wavelength of each ray, but also its ",
 StyleBox["Intensity", "MB"],
 "."
}], "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pointWhiteLightSource", "=", "\[IndentingNewLine]", 
   RowBox[{"PointOfRays", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CustomRays", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"WaveLength", ",", 
          RowBox[{"{", 
           RowBox[{".430", ",", ".532", ",", ".590", ",", ".632"}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Intensity", ",", 
          RowBox[{"{", 
           RowBox[{"50", ",", "70", ",", "60", ",", "40"}], "}"}]}], "}"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"30", ",", "30"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"pointWhiteLightSource", ",", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Grating", "[", 
        RowBox[{"700", ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "20"}], "}"}], ",", "1", ",", 
         RowBox[{"GraphicDesign", "\[Rule]", "Solid"}]}], "]"}], ",", "20"}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Boundary", "[", "75", "]"}]}], "}"}], "]"}], ";"}]}], "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"In[179]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
      20., -10., 10.}, {20., -10., -10.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{20., -10., -10.}, {20., 10., -10.}, {20., 10., 10.}, {
       20., -10., 10.}, {20., -10., -10.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375,
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        Line3DBox[{{20.00375, -10., -10.}, {20.00375, 10., -10.}, {20.00375, 
         10., 10.}, {20.00375, -10., 10.}, {20.00375, -10., -10.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
          10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          Line3DBox[{{20.0075, -10., -10.}, {20.0075, 10., -10.}, {20.0075, 
           10., 10.}, {20.0075, -10., 10.}, {20.0075, -10., -10.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {
            21.0075, 10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            Line3DBox[{{21.0075, -10., -10.}, {21.0075, 10., -10.}, {21.0075, 
             10., 10.}, {21.0075, -10., 10.}, {21.0075, -10., -10.}}], 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {20.00375, 
              10., -10.}, {20., 10., -10.}, {20., 10., 10.}}], 
             Polygon3DBox[{{20., 10., -10.}, {20.00375, 10., -10.}, {
              20.00375, -10., -10.}, {20., -10., -10.}, {20., 10., -10.}}], 
             Polygon3DBox[{{20., -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., -10., -10.}}], 
             Polygon3DBox[{{20., 10., 10.}, {20.00375, 10., 10.}, {
              20.00375, -10., 10.}, {20., -10., 10.}, {20., 10., 10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, 10., -10.}, {20.00375, 10., -10.}, {20.00375, 10., 
              10.}}], Polygon3DBox[{{20.00375, 10., -10.}, {20.0075, 
              10., -10.}, {20.0075, -10., -10.}, {20.00375, -10., -10.}, {
              20.00375, 10., -10.}}], 
             Polygon3DBox[{{20.00375, -10., -10.}, {20.0075, -10., -10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {
              20.00375, -10., -10.}}], 
             Polygon3DBox[{{20.00375, 10., 10.}, {20.0075, 10., 10.}, {
              20.0075, -10., 10.}, {20.00375, -10., 10.}, {20.00375, 10., 
              10.}}]}, 
            {GrayLevel[0.5], EdgeForm[None], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {21.0075,
               10., -10.}, {20.0075, 10., -10.}, {20.0075, 10., 10.}}], 
             Polygon3DBox[{{20.0075, 10., -10.}, {21.0075, 10., -10.}, {
              21.0075, -10., -10.}, {20.0075, -10., -10.}, {20.0075, 
              10., -10.}}], 
             Polygon3DBox[{{20.0075, -10., -10.}, {21.0075, -10., -10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {
              20.0075, -10., -10.}}], 
             Polygon3DBox[{{20.0075, 10., 10.}, {21.0075, 10., 10.}, {
              21.0075, -10., 10.}, {20.0075, -10., 10.}, {20.0075, 10., 
              10.}}]}}}}}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., 37.5, -37.5}, {75., -37.5, -37.5}, {75., -37.5, 
       37.5}, {75., 37.5, 37.5}, {75., 37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., -37.5, -37.5}, {0., -37.5, -37.5}, {0., -37.5, 37.5}, {
       75., -37.5, 37.5}, {75., -37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[
       NCache[{{0, Rational[-75, 2], Rational[-75, 2]}, {
         0, Rational[75, 2], Rational[-75, 2]}, {
         0, Rational[75, 2], Rational[75, 2]}, {
         0, Rational[-75, 2], Rational[75, 2]}, {
         0, Rational[-75, 2], Rational[-75, 2]}}, {{0, -37.5, -37.5}, {
         0, 37.5, -37.5}, {0, 37.5, 37.5}, {0, -37.5, 37.5}, {
         0, -37.5, -37.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 37.5, -37.5}, {75., 37.5, -37.5}, {75., 37.5, 37.5}, {
       0., 37.5, 37.5}, {0., 37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., -37.5, -37.5}, {75., 37.5, -37.5}, {0., 37.5, -37.5}, {
       0., -37.5, -37.5}, {75., -37.5, -37.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{75., 37.5, 37.5}, {75., -37.5, 37.5}, {0., -37.5, 37.5}, {
       0., 37.5, 37.5}, {75., 37.5, 37.5}}]}}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., 5.3589838486224535`}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., 5.3589838486224535`}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., 5.3589838486224535`}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., 5.3589838486224535`}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, -5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, -5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, -5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, -5.535566505469914, 
      5.176380902050416}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 5.3589838486224535`, 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 5.3589838486224535`, 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 5.3589838486224535`, 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 5.3589838486224535`, 0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], Line3DBox[{{0., 0., 0.}, {20., 0., 0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., -5.3589838486224535`, 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., -5.3589838486224535`, 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., -5.3589838486224535`, 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., -5.3589838486224535`, 0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 
      5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 
      5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 
      5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20.000000000000004`, 
      5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., -5.3589838486224535`}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., -5.3589838486224535`}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., -5.3589838486224535`}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {20., 0., -5.3589838486224535`}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      20.000000000000004`, -5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      20.000000000000004`, -5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      20.000000000000004`, -5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{0., 0., 0.}, {
      20.000000000000004`, -5.535566505469914, -5.176380902050416}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 5.535566505469914, 5.176380902050416}, {
      20.00375, 5.536220006972014, 5.176991999883237}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 5.535566505469914, 5.176380902050416}, {
      20.00375, 5.536223559658515, 5.176995322047018}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 5.535566505469914, 5.176380902050416}, {
      20.00375, 5.536224830048395, 5.176996510005272}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 5.535566505469914, 5.176380902050416}, {
      20.00375, 5.536225556582681, 5.176997189397019}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 5.3589838486224535`}, {20.00375, 0., 
      5.359628842088705}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 5.3589838486224535`}, {20.00375, 0., 
      5.359632257093304}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 5.3589838486224535`}, {20.00375, 0., 
      5.359633477899016}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 5.3589838486224535`}, {20.00375, 0., 
      5.359634175992843}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, -5.535566505469914, 
      5.176380902050416}, {20.00375, -5.536220006972014, 
      5.176991999883237}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, -5.535566505469914, 
      5.176380902050416}, {20.00375, -5.536223559658515, 
      5.176995322047018}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, -5.535566505469914, 
      5.176380902050416}, {20.00375, -5.536224830048395, 
      5.176996510005272}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, -5.535566505469914, 
      5.176380902050416}, {20.00375, -5.536225556582681, 
      5.176997189397019}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 5.3589838486224535`, 0.}, {20.00375, 5.359628842088705, 
      0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 5.3589838486224535`, 0.}, {20.00375, 5.359632257093304, 
      0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 5.3589838486224535`, 0.}, {20.00375, 5.359633477899016, 
      0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 5.3589838486224535`, 0.}, {20.00375, 5.359634175992843, 
      0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., 0.}, {20.00375, 0., 0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., -5.3589838486224535`, 0.}, {
      20.00375, -5.359628842088705, 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., -5.3589838486224535`, 0.}, {
      20.00375, -5.359632257093304, 0.}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., -5.3589838486224535`, 0.}, {
      20.00375, -5.359633477899016, 0.}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., -5.3589838486224535`, 0.}, {
      20.00375, -5.359634175992843, 0.}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 
      5.535566505469914, -5.176380902050416}, {20.00375, 
      5.536220006972014, -5.176991999883237}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 
      5.535566505469914, -5.176380902050416}, {20.00375, 
      5.536223559658515, -5.176995322047018}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 
      5.535566505469914, -5.176380902050416}, {20.00375, 
      5.536224830048395, -5.176996510005272}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20.000000000000004`, 
      5.535566505469914, -5.176380902050416}, {20.00375, 
      5.536225556582681, -5.176997189397019}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., -5.3589838486224535`}, {20.00375, 
      0., -5.359628842088705}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., -5.3589838486224535`}, {20.00375, 
      0., -5.359632257093304}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., -5.3589838486224535`}, {20.00375, 
      0., -5.359633477899016}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{20., 0., -5.3589838486224535`}, {20.00375, 
      0., -5.359634175992843}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      20.000000000000004`, -5.535566505469914, -5.176380902050416}, {
      20.00375, -5.536220006972014, -5.176991999883237}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      20.000000000000004`, -5.535566505469914, -5.176380902050416}, {
      20.00375, -5.536223559658515, -5.176995322047018}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      20.000000000000004`, -5.535566505469914, -5.176380902050416}, {
      20.00375, -5.536224830048395, -5.176996510005272}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{
      20.000000000000004`, -5.535566505469914, -5.176380902050416}, {
      20.00375, -5.536225556582681, -5.176997189397019}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536220006972014, 5.176991999883237}, {20.0075, 
      5.536873508474115, 5.177603097716059}}, {{20.00375, 5.536220006972014, 
      5.176991999883237}, {20.0075, 5.5377195092920655`, 
      5.177640370718604}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536223559658515, 5.176995322047018}, {20.0075, 
      5.536880613847116, 5.177609742043622}}, {{20.00375, 5.536223559658515, 
      5.176995322047018}, {20.0075, 5.537963275587602, 
      5.1776624784459955`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536224830048395, 5.176996510005272}, {20.0075, 
      5.536883154626877, 5.177612117960128}}, {{20.00375, 5.536224830048395, 
      5.176996510005272}, {20.0075, 5.538107879278192, 5.177674996791398}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536225556582681, 5.176997189397019}, {20.0075, 
      5.536884607695448, 5.177613476743622}}, {{20.00375, 5.536225556582681, 
      5.176997189397019}, {20.0075, 5.538216273482809, 5.177684399532419}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 5.359628842088705}, {20.0075, 0., 
      5.360273835554957}}, {{20.00375, 0., 5.359628842088705}, {20.0075, 
      0.000765366399026969, 5.360287132378238}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 5.359632257093304}, {20.0075, 0., 
      5.360280665564155}}, {{20.00375, 0., 5.359632257093304}, {20.0075, 
      0.0009629680444023091, 5.3603017029211975`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 5.359633477899016}, {20.0075, 0., 
      5.3602831071755785`}}, {{20.00375, 0., 5.359633477899016}, {20.0075, 
      0.001078337440826018, 5.360309432325619}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 5.359634175992843}, {20.0075, 0., 
      5.360284503363233}}, {{20.00375, 0., 5.359634175992843}, {20.0075, 
      0.0011635766126270668`, 5.360315090204013}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536220006972014, 5.176991999883237}, {
      20.0075, -5.536873508474115, 5.177603097716059}}, {{
      20.00375, -5.536220006972014, 5.176991999883237}, {
      20.0075, -5.53611524715537, 5.17759425950732}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536223559658515, 5.176995322047018}, {
      20.0075, -5.536880613847116, 5.177609742043622}}, {{
      20.00375, -5.536223559658515, 5.176995322047018}, {
      20.0075, -5.535938977580152, 5.177602262607217}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536224830048395, 5.176996510005272}, {
      20.0075, -5.536883154626877, 5.177612117960128}}, {{
      20.00375, -5.536224830048395, 5.176996510005272}, {
      20.0075, -5.535836783401482, 5.177606083205858}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536225556582681, 5.176997189397019}, {
      20.0075, -5.536884607695448, 5.177613476743622}}, {{
      20.00375, -5.536225556582681, 5.176997189397019}, {
      20.0075, -5.535761940448675, 5.177608795236757}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.359628842088705, 0.}, {20.0075, 
      5.360273835554957, 0.}}, {{20.00375, 5.359628842088705, 0.}, {20.0075, 
      5.361106421641449, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.359632257093304, 0.}, {20.0075, 
      5.360280665564155, 0.}}, {{20.00375, 5.359632257093304, 0.}, {20.0075, 
      5.3613450776094185`, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.359633477899016, 0.}, {20.0075, 
      5.3602831071755785`, 0.}}, {{20.00375, 5.359633477899016, 0.}, {20.0075,
       5.3614864424077, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.359634175992843, 0.}, {20.0075, 
      5.360284503363233, 0.}}, {{20.00375, 5.359634175992843, 0.}, {20.0075, 
      5.361592285030552, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.000753839473655256, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0009479809154441664, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0010612346026256645`, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., 0.}, {20.0075, 0., 0.}}, {{20.00375, 0., 
      0.}, {20.0075, 0.0011448565581814076`, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.359628842088705, 0.}, {
      20.0075, -5.360273835554957, 0.}}, {{20.00375, -5.359628842088705, 
      0.}, {20.0075, -5.359525407730264, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.359632257093304, 0.}, {
      20.0075, -5.360280665564155, 0.}}, {{20.00375, -5.359632257093304, 
      0.}, {20.0075, -5.359351330757668, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.359633477899016, 0.}, {
      20.0075, -5.3602831071755785`, 0.}}, {{20.00375, -5.359633477899016, 
      0.}, {20.0075, -5.359250458600529, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.359634175992843, 0.}, {
      20.0075, -5.360284503363233, 0.}}, {{20.00375, -5.359634175992843, 
      0.}, {20.0075, -5.359176605592023, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536220006972014, -5.176991999883237}, {20.0075, 
      5.536873508474115, -5.177603097716059}}, {{20.00375, 
      5.536220006972014, -5.176991999883237}, {20.0075, 
      5.5377195092920655`, -5.177640370718604}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536223559658515, -5.176995322047018}, {20.0075, 
      5.536880613847116, -5.177609742043622}}, {{20.00375, 
      5.536223559658515, -5.176995322047018}, {20.0075, 
      5.537963275587602, -5.1776624784459955`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536224830048395, -5.176996510005272}, {20.0075, 
      5.536883154626877, -5.177612117960128}}, {{20.00375, 
      5.536224830048395, -5.176996510005272}, {20.0075, 
      5.538107879278192, -5.177674996791398}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 5.536225556582681, -5.176997189397019}, {20.0075, 
      5.536884607695448, -5.177613476743622}}, {{20.00375, 
      5.536225556582681, -5.176997189397019}, {20.0075, 
      5.538216273482809, -5.177684399532419}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., -5.359628842088705}, {20.0075, 
      0., -5.360273835554957}}, {{20.00375, 0., -5.359628842088705}, {20.0075,
       0.000765366399026969, -5.360287132378238}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., -5.359632257093304}, {20.0075, 
      0., -5.360280665564155}}, {{20.00375, 0., -5.359632257093304}, {20.0075,
       0.0009629680444023091, -5.3603017029211975`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., -5.359633477899016}, {20.0075, 
      0., -5.3602831071755785`}}, {{20.00375, 0., -5.359633477899016}, {
      20.0075, 0.001078337440826018, -5.360309432325619}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, 0., -5.359634175992843}, {20.0075, 
      0., -5.360284503363233}}, {{20.00375, 0., -5.359634175992843}, {20.0075,
       0.0011635766126270668`, -5.360315090204013}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536220006972014, -5.176991999883237}, {
      20.0075, -5.536873508474115, -5.177603097716059}}, {{
      20.00375, -5.536220006972014, -5.176991999883237}, {
      20.0075, -5.53611524715537, -5.17759425950732}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536223559658515, -5.176995322047018}, {
      20.0075, -5.536880613847116, -5.177609742043622}}, {{
      20.00375, -5.536223559658515, -5.176995322047018}, {
      20.0075, -5.535938977580152, -5.177602262607217}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536224830048395, -5.176996510005272}, {
      20.0075, -5.536883154626877, -5.177612117960128}}, {{
      20.00375, -5.536224830048395, -5.176996510005272}, {
      20.0075, -5.535836783401482, -5.177606083205858}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.00375, -5.536225556582681, -5.176997189397019}, {
      20.0075, -5.536884607695448, -5.177613476743622}}, {{
      20.00375, -5.536225556582681, -5.176997189397019}, {
      20.0075, -5.535761940448675, -5.177608795236757}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536873508474115, 5.177603097716059}, {21.0075, 
      5.711140575700928, 5.340562519801917}}, {{20.0075, 5.5377195092920655`, 
      5.177640370718604}, {21.0075, 5.937586794638937, 5.350539260149721}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536880613847116, 5.177609742043622}, {21.0075, 
      5.712095064140792, 5.341455074471156}}, {{20.0075, 5.537963275587602, 
      5.1776624784459955`}, {21.0075, 6.001887523344205, 
      5.355570851506587}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536883154626877, 5.177612117960128}, {21.0075, 
      5.712436375555326, 5.3417742392551215`}}, {{20.0075, 5.538107879278192, 
      5.177674996791398}, {21.0075, 6.040254340557335, 5.358604806425204}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536884607695448, 5.177613476743622}, {21.0075, 
      5.712631571100055, 5.341956769171238}}, {{20.0075, 5.538216273482809, 
      5.177684399532419}, {21.0075, 6.0690741135167885`, 
      5.360940435638935}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 5.360273835554957}, {21.0075, 0., 
      5.5322720932221845`}}, {{20.0075, 0.000765366399026969, 
      5.360287132378238}, {21.0075, 0.20486307280621097`, 
      5.535831209586945}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 5.360280665564155}, {21.0075, 0., 
      5.533189591124469}}, {{20.0075, 0.0009629680444023091, 
      5.3603017029211975`}, {21.0075, 0.257754446551675, 
      5.538820590359405}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 5.3602831071755785`}, {21.0075, 0., 
      5.533517580925479}}, {{20.0075, 0.001078337440826018, 
      5.360309432325619}, {21.0075, 0.28863498832775325`, 
      5.540563946086483}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 5.360284503363233}, {21.0075, 0., 
      5.53370513546722}}, {{20.0075, 0.0011635766126270668`, 
      5.360315090204013}, {21.0075, 0.3114506733131664, 
      5.5418922131826305`}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536873508474115, 5.177603097716059}, {
      21.0075, -5.711140575700928, 5.340562519801917}}, {{
      20.0075, -5.53611524715537, 5.17759425950732}, {
      21.0075, -5.508179296050059, 5.3381968259293915`}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536880613847116, 5.177609742043622}, {
      21.0075, -5.712095064140792, 5.341455074471156}}, {{
      20.0075, -5.535938977580152, 5.177602262607217}, {
      21.0075, -5.460050423349957, 5.33945307866037}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536883154626877, 5.177612117960128}, {
      21.0075, -5.712436375555326, 5.3417742392551215`}}, {{
      20.0075, -5.535836783401482, 5.177606083205858}, {
      21.0075, -5.432357677558005, 5.340158936695677}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536884607695448, 5.177613476743622}, {
      21.0075, -5.712631571100055, 5.341956769171238}}, {{
      20.0075, -5.535761940448675, 5.177608795236757}, {
      21.0075, -5.412130971380379, 5.340703685833359}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.360273835554957, 0.}, {21.0075, 
      5.5322720932221845`, 0.}}, {{20.0075, 5.361106421641449, 0.}, {21.0075, 
      5.755127635706533, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.360280665564155, 0.}, {21.0075, 
      5.533189591124469, 0.}}, {{20.0075, 5.3613450776094185`, 0.}, {21.0075, 
      5.818097215239936, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.3602831071755785`, 0.}, {21.0075, 
      5.533517580925479, 0.}}, {{20.0075, 5.3614864424077, 0.}, {21.0075, 
      5.855610311390083, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.360284503363233, 0.}, {21.0075, 5.53370513546722,
       0.}}, {{20.0075, 5.361592285030552, 0.}, {21.0075, 5.8837546950862665`,
       0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.000753839473655256, 0.}, {21.0075, 0.20177769911504922`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0009479809154441664, 0.}, {21.0075, 0.2537428917005456, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0010612346026256645`, 0.}, {21.0075, 0.2840571286361254, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., 0.}, {21.0075, 0., 0.}}, {{20.0075, 
      0.0011448565581814076`, 0.}, {21.0075, 0.30643993873987857`, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.360273835554957, 0.}, {
      21.0075, -5.5322720932221845`, 0.}}, {{20.0075, -5.359525407730264, 
      0.}, {21.0075, -5.331942912146028, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.360280665564155, 0.}, {
      21.0075, -5.533189591124469, 0.}}, {{20.0075, -5.359351330757668, 0.}, {
      21.0075, -5.284437641254559, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.3602831071755785`, 0.}, {
      21.0075, -5.533517580925479, 0.}}, {{20.0075, -5.359250458600529, 0.}, {
      21.0075, -5.25711197900409, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.360284503363233, 0.}, {
      21.0075, -5.53370513546722, 0.}}, {{20.0075, -5.359176605592023, 0.}, {
      21.0075, -5.237157832040019, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536873508474115, -5.177603097716059}, {21.0075, 
      5.711140575700928, -5.340562519801917}}, {{20.0075, 
      5.5377195092920655`, -5.177640370718604}, {21.0075, 
      5.937586794638937, -5.350539260149721}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536880613847116, -5.177609742043622}, {21.0075, 
      5.712095064140792, -5.341455074471156}}, {{20.0075, 
      5.537963275587602, -5.1776624784459955`}, {21.0075, 
      6.001887523344205, -5.355570851506587}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536883154626877, -5.177612117960128}, {21.0075, 
      5.712436375555326, -5.3417742392551215`}}, {{20.0075, 
      5.538107879278192, -5.177674996791398}, {21.0075, 
      6.040254340557335, -5.358604806425204}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 5.536884607695448, -5.177613476743622}, {21.0075, 
      5.712631571100055, -5.341956769171238}}, {{20.0075, 
      5.538216273482809, -5.177684399532419}, {21.0075, 
      6.0690741135167885`, -5.360940435638935}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., -5.360273835554957}, {21.0075, 
      0., -5.5322720932221845`}}, {{20.0075, 
      0.000765366399026969, -5.360287132378238}, {21.0075, 
      0.20486307280621097`, -5.535831209586945}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., -5.360280665564155}, {21.0075, 
      0., -5.533189591124469}}, {{20.0075, 
      0.0009629680444023091, -5.3603017029211975`}, {21.0075, 
      0.257754446551675, -5.538820590359405}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., -5.3602831071755785`}, {21.0075, 
      0., -5.533517580925479}}, {{20.0075, 
      0.001078337440826018, -5.360309432325619}, {21.0075, 
      0.28863498832775325`, -5.540563946086483}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, 0., -5.360284503363233}, {21.0075, 
      0., -5.53370513546722}}, {{20.0075, 
      0.0011635766126270668`, -5.360315090204013}, {21.0075, 
      0.3114506733131664, -5.5418922131826305`}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536873508474115, -5.177603097716059}, {
      21.0075, -5.711140575700928, -5.340562519801917}}, {{
      20.0075, -5.53611524715537, -5.17759425950732}, {
      21.0075, -5.508179296050059, -5.3381968259293915`}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536880613847116, -5.177609742043622}, {
      21.0075, -5.712095064140792, -5.341455074471156}}, {{
      20.0075, -5.535938977580152, -5.177602262607217}, {
      21.0075, -5.460050423349957, -5.33945307866037}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536883154626877, -5.177612117960128}, {
      21.0075, -5.712436375555326, -5.3417742392551215`}}, {{
      20.0075, -5.535836783401482, -5.177606083205858}, {
      21.0075, -5.432357677558005, -5.340158936695677}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{20.0075, -5.536884607695448, -5.177613476743622}, {
      21.0075, -5.712631571100055, -5.341956769171238}}, {{
      20.0075, -5.535761940448675, -5.177608795236757}, {
      21.0075, -5.412130971380379, -5.340703685833359}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.711140575700928, 5.340562519801917}, {75., 
      20.655094303030133`, 19.31484981249976}}, {{21.0075, 5.937586794638937, 
      5.350539260149721}, {65.6971411424789, 37.5, 18.997832727128618`}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712095064140792, 5.341455074471156}, {75., 
      20.656048791469996`, 19.315742367168994`}}, {{21.0075, 
      6.001887523344205, 5.355570851506587}, {57.7880791877328, 37.5, 
      17.434650512247618`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712436375555326, 5.3417742392551215`}, {75., 
      20.65639010288449, 19.316061531952922`}}, {{21.0075, 6.040254340557335, 
      5.358604806425204}, {53.80006112800987, 37.5, 
      16.693954614111494`}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712631571100055, 5.341956769171238}, {75., 
      20.656585298429253`, 19.31624406186907}}, {{21.0075, 
      6.0690741135167885`, 5.360940435638935}, {51.076990303996475`, 37.5, 
      16.2111275379824}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 5.5322720932221845`}, {75., 0., 
      19.99951886555961}}, {{21.0075, 0.20486307280621097`, 
      5.535831209586945}, {75., 17.90622547590106, 20.76074178349048}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 5.533189591124469}, {75., 0., 
      20.00043636346195}}, {{21.0075, 0.257754446551675, 5.538820590359405}, {
      75., 22.81078676359979, 21.217464838997728`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 5.533517580925479}, {75., 0., 
      20.00076435326288}}, {{21.0075, 0.28863498832775325`, 
      5.540563946086483}, {75., 25.81782166729275, 21.54350151450547}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 5.53370513546722}, {75., 0., 
      20.00095190780471}}, {{21.0075, 0.3114506733131664, 
      5.5418922131826305`}, {75., 28.120155543568973`, 
      21.815287651781066`}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.711140575700928, 5.340562519801917}, {
      75., -20.655094303030133`, 19.31484981249976}}, {{
      21.0075, -5.508179296050059, 5.3381968259293915`}, {
      75., -3.163295162571271, 18.81883360036518}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712095064140792, 5.341455074471156}, {
      75., -20.656048791469996`, 19.315742367168994`}}, {{
      21.0075, -5.460050423349957, 5.33945307866037}, {75., 0.898432280206932,
       18.90046534025737}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712436375555326, 5.3417742392551215`}, {
      75., -20.65639010288449, 19.316061531952922`}}, {{
      21.0075, -5.432357677558005, 5.340158936695677}, {75., 
      3.251341655270747, 18.981174617040697`}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712631571100055, 5.341956769171238}, {
      75., -20.656585298429253`, 19.31624406186907}}, {{
      21.0075, -5.412130971380379, 5.340703685833359}, {75., 
      4.984531222856762, 19.05605749982989}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.5322720932221845`, 0.}, {75., 19.99951886555961, 
      0.}}, {{21.0075, 5.755127635706533, 0.}, {68.00462536302119, 37.5, 
      0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.533189591124469, 0.}, {75., 20.00043636346195, 
      0.}}, {{21.0075, 5.818097215239936, 0.}, {59.94663315930133, 37.5, 
      0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.533517580925479, 0.}, {75., 20.00076435326288, 
      0.}}, {{21.0075, 5.855610311390083, 0.}, {55.90757033232031, 37.5, 
      0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.53370513546722, 0.}, {75., 20.00095190780471, 
      0.}}, {{21.0075, 5.8837546950862665`, 0.}, {53.1631645246734, 37.5, 
      0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.20177769911504922`, 0.}, {75., 17.238756772495236`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2537428917005456, 0.}, {75., 21.912096913848483`, 0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.2840571286361254, 0.}, {75., 24.760755905092502`, 0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., 0.}, {75., 0., 0.}}, {{21.0075, 
      0.30643993873987857`, 0.}, {75., 26.932059430049645`, 0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.5322720932221845`, 0.}, {
      75., -19.99951886555961, 0.}}, {{21.0075, -5.331942912146028, 0.}, {
      75., -3.0568978763220245`, 0.}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.533189591124469, 0.}, {75., -20.00043636346195, 
      0.}}, {{21.0075, -5.284437641254559, 0.}, {75., 0.8825028705269657, 
      0.}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.533517580925479, 0.}, {75., -20.00076435326288, 
      0.}}, {{21.0075, -5.25711197900409, 0.}, {75., 3.1620450603120727`, 
      0.}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.53370513546722, 0.}, {75., -20.00095190780471, 
      0.}}, {{21.0075, -5.237157832040019, 0.}, {75., 4.839474680151014, 
      0.}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.711140575700928, -5.340562519801917}, {75., 
      20.655094303030133`, -19.31484981249976}}, {{21.0075, 
      5.937586794638937, -5.350539260149721}, {65.6971411424789, 
      37.5, -18.997832727128618`}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712095064140792, -5.341455074471156}, {75., 
      20.656048791469996`, -19.315742367168994`}}, {{21.0075, 
      6.001887523344205, -5.355570851506587}, {57.7880791877328, 
      37.5, -17.434650512247618`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712436375555326, -5.3417742392551215`}, {75., 
      20.65639010288449, -19.316061531952922`}}, {{21.0075, 
      6.040254340557335, -5.358604806425204}, {53.80006112800987, 
      37.5, -16.693954614111494`}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 5.712631571100055, -5.341956769171238}, {75., 
      20.656585298429253`, -19.31624406186907}}, {{21.0075, 
      6.0690741135167885`, -5.360940435638935}, {51.076990303996475`, 
      37.5, -16.2111275379824}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., -5.5322720932221845`}, {75., 
      0., -19.99951886555961}}, {{21.0075, 
      0.20486307280621097`, -5.535831209586945}, {75., 
      17.90622547590106, -20.76074178349048}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., -5.533189591124469}, {75., 
      0., -20.00043636346195}}, {{21.0075, 
      0.257754446551675, -5.538820590359405}, {75., 
      22.81078676359979, -21.217464838997728`}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., -5.533517580925479}, {75., 
      0., -20.00076435326288}}, {{21.0075, 
      0.28863498832775325`, -5.540563946086483}, {75., 
      25.81782166729275, -21.54350151450547}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, 0., -5.53370513546722}, {75., 
      0., -20.00095190780471}}, {{21.0075, 
      0.3114506733131664, -5.5418922131826305`}, {75., 
      28.120155543568973`, -21.815287651781066`}}}]}, 
    {RGBColor[
     0.00042396070585731804`, 0.05347360086735514, 0.9296299372454464], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.711140575700928, -5.340562519801917}, {
      75., -20.655094303030133`, -19.31484981249976}}, {{
      21.0075, -5.508179296050059, -5.3381968259293915`}, {
      75., -3.163295162571271, -18.81883360036518}}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712095064140792, -5.341455074471156}, {
      75., -20.656048791469996`, -19.315742367168994`}}, {{
      21.0075, -5.460050423349957, -5.33945307866037}, {75., 
      0.898432280206932, -18.90046534025737}}}]}, 
    {RGBColor[0.9410810081576009, 0.8235584439732623, 0.016478627054058947`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712436375555326, -5.3417742392551215`}, {
      75., -20.65639010288449, -19.316061531952922`}}, {{
      21.0075, -5.432357677558005, -5.340158936695677}, {75., 
      3.251341655270747, -18.981174617040697`}}}]}, 
    {RGBColor[0.951110704933134, 0.0284256904756362, 0.011094507350767169`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{21.0075, -5.712631571100055, -5.341956769171238}, {
      75., -20.656585298429253`, -19.31624406186907}}, {{
      21.0075, -5.412130971380379, -5.340703685833359}, {75., 
      4.984531222856762, -19.05605749982989}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJytlntQVFUcxxcMw0LTggUdBEGUV4Aga6TinnhlYstDzQLER6CY0oqZD3yE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      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301499188768*^9, 3.61470926546288*^9, 
  3.614729120943591*^9},
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"},
 CellLabel->"During evaluation of In[179]:="]
}, Open  ]],

Cell["\<\
Nested light source with multichromatic rays having different energies at \
each wavelength.\
\>", "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3 Custom Surface Shapes", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", "4.3", 
   "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "With ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " you can blend traditional mathematical functions with your optics to \
create new forms of optical component shapes. In order to accomplish this you \
can either define a new surface model using ",
 StyleBox["ModelSurfaceShape", "Input"],
 " or you can directly specify the new surface function in a custom \
component. In particular, with every category of optical component in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", there exists a \"Custom\" version of it. These are listed in the \
following table."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[Cell[BoxData[
 TagBox[GridBox[{
    {"CustomBaffle", "CustomBeamSplitter", "CustomBirefringentLensSurface"},
    {"CustomBranchingSurface", "CustomConjugateBeamSplitter", 
     "CustomConjugateMirror"},
    {"CustomDiffuser", "CustomDiffuserMirror", "CustomFiber"},
    {"CustomFiberMirror", "CustomGrating", "CustomGratingMirror"},
    {"CustomIntrinsicSurface", "CustomJonesMatrixOptic", "CustomLens"},
    {"CustomLensSurface", "CustomLinearPolarizer", "CustomMirror"},
    {"CustomPrism", "CustomRetardationPlate", "CustomScreen"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]]]], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell["Custom component function names.", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "With the exceptions of ",
 StyleBox["CustomPrism", "Input"],
 ", ",
 StyleBox["CustomFiber", "Input"],
 ", and ",
 StyleBox["CustomFiberMirror", "Input"],
 ", the surface shapes for all of these component functions work essentially \
in the same fashion. Therefore, in the following examples, ",
 StyleBox["CustomLens", "Input"],
 " and ",
 StyleBox["CustomMirror", "Input"],
 " will be used to illustrate the different methods employed. (Demonstrations \
of ",
 StyleBox["CustomPrism", "Input"],
 ", ",
 StyleBox["CustomFiber", "Input"],
 " and ",
 StyleBox["CustomFiberMirror", "Input"],
 " are presented in the on-line Rayica Example Library documentation.)"
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 StyleBox["CustomLens[", "Input"],
 StyleBox["f1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["f2",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["label",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " designates a double-surfaced refractive component having user-defined \
surface functions. The surfaces are given by f1 and f2, where f1 and f2 are \
user-defined surface functions, and an optional user-named ",
 StyleBox["objectlabel",
  FontSlant->"Italic"],
 ".",
 StyleBox["\nCustomMirror[", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["label",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " and ",
 StyleBox["CustomMirror[", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["label",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " designate a mirror that has a user-defined ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 ", and an optional user-named ",
 StyleBox["label",
  FontSlant->"Italic"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "In order to specify a new surface shape in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", you must provide a ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " in one of the three following formats:"
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 StyleBox["(1) Function[{s,t}, ", "Input"],
 StyleBox["fx[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["]\n(2) Function[{s,t}, {", "Input"],
 StyleBox["fx[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fy[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fz[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["}]\n(3) {Function[{s,t}, ", "Input"],
 StyleBox["fx[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["], Function[{s,t}, ", "Input"],
 StyleBox["fy[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["], Function[{s,t}, ", "Input"],
 StyleBox["fz[", "Input",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["]}", "Input"]
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell["\<\
Three different surface function formats that describe a surface shape.  {fx, \
fy, fz} are user-specified functions that depend on parameters {s,t}.\
\>", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "As indicated, the ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " must always have a ",
 StyleBox["Function", "Input"],
 " head. If the surface shape is very simple, then only the single-valued, \
non-parametric function format, shown in (1), can be given. The \
vector-parametric format, shown in (2), is the most general way to specify a \
geometric three-dimensional shape since it permits enclosed surfaces with \
multiple \"folds\". This format is a three-dimensional vector function of two \
parametric coordinates. Internally, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " always uses this vector parametric format. In fact, regardless of how the \
function was originally inputted by the user, it is always converted \
internally into this form. The last format, listed in (3), is an obsolete \
format that was previously used by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " version 1, although this format is still recognized."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "Very often, the two parametric coordinates correspond with ",
 StyleBox["y",
  FontSlant->"Italic"],
 " and ",
 StyleBox["z ",
  FontSlant->"Italic"],
 "coordinate axes of three-dimensional Cartesian space. In such cases, the ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " output has a single-value that specifies the x-axis component. For the \
such systems, the position of the unperturbed optical surface has a local \
coordinate system that matches the global coordinate system of the optical \
space. In the conic lens example given below, the two parametric variables \
correspond with the y and z axes of the optical coordinate system and the \
function result corresponds with the x-axis (optical axis). Once a component \
surface has been spatially reoriented, however, the surface function's local \
reference coordinates become different from the global coordinate space."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{
\tMove[GridOfRays[40, NumberOfRays -> 6], {-5,0,5}],
\tCustomLens[ Function[{y,z}, Sqrt[y^2 + z^2]], Function[0], 50, 25, \
GraphicDesign -> Solid],
\tBoundary[45,GraphicDesign->Off]
\t}, 
\tAxes -> True,
\tAxesLabel -> {\"x-axis\",\"y-axis\",\"z-axis\"}
];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"In[181]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301500822538*^9, 3.6147092666934767`*^9, 
  3.614729122415709*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"During evaluation of In[181]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301500822538*^9, 3.6147092666934767`*^9, 
  3.614729122534218*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"During evaluation of In[181]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.333333333333332, 0.}, {
      8.333333333333332, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.333333333333332, 0.}, {
      16.666666666666664`, 16.666666666666664`, 0.}, {16.666666666666664`, 
      16.09876377148447, 4.313650751708678}, {8.333333333333332, 
      8.049381885742235, 2.156825375854339}, {8.333333333333332, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{16.666666666666664`, 16.666666666666664`, 0.}, {25., 25., 
      0.}, {24.999999999999996`, 24.148145657226706`, 6.4704761275630185`}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}, {
      16.666666666666664`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {24.999999999999996`, 24.148145657226706`, 
      6.4704761275630185`}, {25., 21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {25., 21.65063509461097, 12.499999999999998`}, {
      24.999999999999996`, 17.67766952966369, 17.677669529663685`}, {
      16.666666666666664`, 11.785113019775793`, 11.785113019775789`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {24.999999999999996`, 17.67766952966369, 
      17.677669529663685`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {25., 6.470476127563024, 24.148145657226706`}, {
      16.666666666666668`, 4.313650751708682, 16.09876377148447}, {
      16.666666666666668`, 8.333333333333336, 14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {16.666666666666664`, 4.721282414706649*^-15, 
      16.666666666666664`}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {25., 6.470476127563024, 24.148145657226706`}, {25.,
       7.0819236220599744`*^-15, 25.}, {16.666666666666664`, 
      4.721282414706649*^-15, 16.666666666666664`}, {16.666666666666668`, 
      4.313650751708682, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {25., 1.5308084989341915`*^-15, 25.}, {
      24.999999999999996`, -6.470476127563016, 24.148145657226706`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}, {
      16.666666666666664`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {24.999999999999996`, -6.470476127563016, 
      24.148145657226706`}, {25., -12.499999999999995`, 21.65063509461097}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {25., -12.499999999999995`, 21.65063509461097}, {
      24.999999999999996`, -17.677669529663685`, 17.67766952966369}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {16.666666666666668`, -14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {24.999999999999996`, -17.677669529663685`, 
      17.67766952966369}, {25., -21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, -14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -7.21687836487032, 
      4.16666666666667}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -7.21687836487032, 4.16666666666667}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      8.333333333333334, -8.049381885742235, 2.156825375854342}, {
      8.333333333333334, -7.21687836487032, 4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666668`, -14.43375672974064, 
      8.33333333333334}, {25., -21.650635094610962`, 12.500000000000009`}, {
      25., -24.148145657226706`, 6.470476127563026}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {25., -24.148145657226706`, 6.470476127563026}, {
      25., -25., 3.061616997868383*^-15}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {
      8.333333333333332, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {25., -25., 3.061616997868383*^-15}, {
      25., -24.148145657226706`, -6.47047612756302}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      25., -24.14814565722671, -6.470476127563009}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      25., -17.677669529663692`, -17.677669529663685`}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      25., -17.677669529663696`, -17.677669529663678`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      25., -2.6796885989305705`*^-14, -25.}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      16.666666666666664`, 4.313650751708671, -16.09876377148447}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      25., -4.592425496802574*^-15, -25.}, {25., 
      6.470476127563007, -24.14814565722671}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {25., 
      6.470476127563007, -24.14814565722671}, {25., 
      12.499999999999984`, -21.650635094610976`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {25., 
      12.499999999999984`, -21.650635094610976`}, {25.000000000000004`, 
      17.67766952966367, -17.67766952966371}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {25., 
      17.677669529663685`, -17.677669529663692`}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {25., 
      25., -2.8327694488239898`*^-14}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwdEClGRj+g4GFg8fVDfffqFo4OO4qrTvyUBKu
7tnvFtYJy0wdIOo0HGDqd6QJH6hea+iwHUozQtUzgWlNh6dQfTBz3KHmwuyB
iZ8+f3797Mm3bWB8mPl2EPUH0NX/hbjjAKq7LGDuOABzF0z9E4i6A6xQd8HE
oeYe8ETzL5Q+AHHXa7i7PKHqzaDuQgufA3+g7oKJ74K6ZyuUhrmTDeKOA4+h
+mDhFg411x1qD8ycG7dvH96y7ssemLtg4iZQd3uiqf8OjacXUPNh4rB42onm
Hqg74O6CuQfqDocINP+ixtvvPQBgjO9B
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{25., 0., 0.}, {25., 8.333333333333332, 0.}, {25., 
        8.049381885742235, 2.156825375854339}, {25., 0., 0.}, {25., 0., 0.}}],
        Polygon3DBox[{{25., 8.333333333333332, 0.}, {25., 16.666666666666664`,
         0.}, {25., 16.09876377148447, 4.313650751708678}, {25., 
        8.049381885742235, 2.156825375854339}, {25., 8.333333333333332, 0.}}],
        Polygon3DBox[{{25., 16.666666666666664`, 0.}, {25., 25., 0.}, {25., 
        24.148145657226706`, 6.4704761275630185`}, {25., 16.09876377148447, 
        4.313650751708678}, {25., 16.666666666666664`, 0.}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 8.049381885742235, 
        2.156825375854339}, {25., 7.216878364870323, 4.166666666666666}, {25.,
         0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 8.049381885742235, 2.156825375854339}, {25., 
        16.09876377148447, 4.313650751708678}, {25., 14.433756729740645`, 
        8.333333333333332}, {25., 7.216878364870323, 4.166666666666666}, {25.,
         8.049381885742235, 2.156825375854339}}], 
       Polygon3DBox[{{25., 16.09876377148447, 4.313650751708678}, {25., 
        24.148145657226706`, 6.4704761275630185`}, {25., 21.65063509461097, 
        12.499999999999998`}, {25., 14.433756729740645`, 8.333333333333332}, {
        25., 16.09876377148447, 4.313650751708678}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 7.216878364870323, 
        4.166666666666666}, {25., 5.892556509887896, 5.8925565098878945`}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 7.216878364870323, 4.166666666666666}, {25., 
        14.433756729740645`, 8.333333333333332}, {25., 11.785113019775793`, 
        11.785113019775789`}, {25., 5.892556509887896, 5.8925565098878945`}, {
        25., 7.216878364870323, 4.166666666666666}}], 
       Polygon3DBox[{{25., 14.433756729740645`, 8.333333333333332}, {25., 
        21.65063509461097, 12.499999999999998`}, {25., 17.67766952966369, 
        17.677669529663685`}, {25., 11.785113019775793`, 
        11.785113019775789`}, {25., 14.433756729740645`, 8.333333333333332}}],
        Polygon3DBox[{{25., 0., 0.}, {25., 5.892556509887896, 
        5.8925565098878945`}, {25., 4.166666666666668, 7.216878364870322}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 5.892556509887896, 5.8925565098878945`}, {25., 
        11.785113019775793`, 11.785113019775789`}, {25., 8.333333333333336, 
        14.433756729740644`}, {25., 4.166666666666668, 7.216878364870322}, {
        25., 5.892556509887896, 5.8925565098878945`}}], 
       Polygon3DBox[{{25., 11.785113019775793`, 11.785113019775789`}, {25., 
        17.67766952966369, 17.677669529663685`}, {25., 12.500000000000004`, 
        21.650635094610966`}, {25., 8.333333333333336, 14.433756729740644`}, {
        25., 11.785113019775793`, 11.785113019775789`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 4.166666666666668, 
        7.216878364870322}, {25., 2.156825375854341, 8.049381885742235}, {25.,
         0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 4.166666666666668, 7.216878364870322}, {25., 
        8.333333333333336, 14.433756729740644`}, {25., 4.313650751708682, 
        16.09876377148447}, {25., 2.156825375854341, 8.049381885742235}, {25.,
         4.166666666666668, 7.216878364870322}}], 
       Polygon3DBox[{{25., 8.333333333333336, 14.433756729740644`}, {25., 
        12.500000000000004`, 21.650635094610966`}, {25., 6.470476127563024, 
        24.148145657226706`}, {25., 4.313650751708682, 16.09876377148447}, {
        25., 8.333333333333336, 14.433756729740644`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 2.156825375854341, 
        8.049381885742235}, {25., 2.3606412073533245`*^-15, 
        8.333333333333332}, {25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 2.156825375854341, 8.049381885742235}, {25., 
        4.313650751708682, 16.09876377148447}, {25., 4.721282414706649*^-15, 
        16.666666666666664`}, {25., 2.3606412073533245`*^-15, 
        8.333333333333332}, {25., 2.156825375854341, 8.049381885742235}}], 
       Polygon3DBox[{{25., 4.313650751708682, 16.09876377148447}, {25., 
        6.470476127563024, 24.148145657226706`}, {25., 
        7.0819236220599744`*^-15, 25.}, {25., 4.721282414706649*^-15, 
        16.666666666666664`}, {25., 4.313650751708682, 16.09876377148447}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 5.102694996447305*^-16, 
        8.333333333333332}, {25., -2.1568253758543383`, 8.049381885742235}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., 5.102694996447305*^-16, 8.333333333333332}, {25., 
        1.020538999289461*^-15, 16.666666666666664`}, {
        25., -4.313650751708677, 16.09876377148447}, {
        25., -2.1568253758543383`, 8.049381885742235}, {25., 
        5.102694996447305*^-16, 8.333333333333332}}], 
       Polygon3DBox[{{25., 1.020538999289461*^-15, 16.666666666666664`}, {25.,
         1.5308084989341915`*^-15, 25.}, {25., -6.470476127563016, 
        24.148145657226706`}, {25., -4.313650751708677, 16.09876377148447}, {
        25., 1.020538999289461*^-15, 16.666666666666664`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -2.1568253758543383`, 
        8.049381885742235}, {25., -4.166666666666664, 7.216878364870323}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., -2.1568253758543383`, 8.049381885742235}, {
        25., -4.313650751708677, 16.09876377148447}, {25., -8.333333333333329,
         14.433756729740645`}, {25., -4.166666666666664, 7.216878364870323}, {
        25., -2.1568253758543383`, 8.049381885742235}}], 
       Polygon3DBox[{{25., -4.313650751708677, 16.09876377148447}, {
        25., -6.470476127563016, 24.148145657226706`}, {
        25., -12.499999999999995`, 21.65063509461097}, {
        25., -8.333333333333329, 14.433756729740645`}, {
        25., -4.313650751708677, 16.09876377148447}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -4.166666666666664, 
        7.216878364870323}, {25., -5.8925565098878945`, 5.892556509887896}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., -4.166666666666664, 7.216878364870323}, {
        25., -8.333333333333329, 14.433756729740645`}, {
        25., -11.785113019775789`, 11.785113019775793`}, {
        25., -5.8925565098878945`, 5.892556509887896}, {
        25., -4.166666666666664, 7.216878364870323}}], 
       Polygon3DBox[{{25., -8.333333333333329, 14.433756729740645`}, {
        25., -12.499999999999995`, 21.65063509461097}, {
        25., -17.677669529663685`, 17.67766952966369}, {
        25., -11.785113019775789`, 11.785113019775793`}, {
        25., -8.333333333333329, 14.433756729740645`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -5.8925565098878945`, 
        5.892556509887896}, {25., -7.216878364870323, 4.166666666666666}, {
        25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., -5.8925565098878945`, 5.892556509887896}, {
        25., -11.785113019775789`, 11.785113019775793`}, {
        25., -14.433756729740645`, 8.333333333333332}, {
        25., -7.216878364870323, 4.166666666666666}, {
        25., -5.8925565098878945`, 5.892556509887896}}], 
       Polygon3DBox[{{25., -11.785113019775789`, 11.785113019775793`}, {
        25., -17.677669529663685`, 17.67766952966369}, {
        25., -21.65063509461097, 12.499999999999998`}, {
        25., -14.433756729740645`, 8.333333333333332}, {
        25., -11.785113019775789`, 11.785113019775793`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -7.21687836487032, 
        4.16666666666667}, {25., -8.049381885742235, 2.156825375854342}, {25.,
         0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., -7.21687836487032, 4.16666666666667}, {
        25., -14.43375672974064, 8.33333333333334}, {25., -16.09876377148447, 
        4.313650751708684}, {25., -8.049381885742235, 2.156825375854342}, {
        25., -7.21687836487032, 4.16666666666667}}], 
       Polygon3DBox[{{25., -14.43375672974064, 8.33333333333334}, {
        25., -21.650635094610962`, 12.500000000000009`}, {
        25., -24.148145657226706`, 6.470476127563026}, {
        25., -16.09876377148447, 4.313650751708684}, {25., -14.43375672974064,
         8.33333333333334}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -8.049381885742235, 
        2.156825375854342}, {25., -8.333333333333332, 
        1.020538999289461*^-15}, {25., 0., 0.}, {25., 0., 0.}}], 
       Polygon3DBox[{{25., -8.049381885742235, 2.156825375854342}, {
        25., -16.09876377148447, 4.313650751708684}, {
        25., -16.666666666666664`, 2.041077998578922*^-15}, {
        25., -8.333333333333332, 1.020538999289461*^-15}, {
        25., -8.049381885742235, 2.156825375854342}}], 
       Polygon3DBox[{{25., -16.09876377148447, 4.313650751708684}, {
        25., -24.148145657226706`, 6.470476127563026}, {25., -25., 
        3.061616997868383*^-15}, {25., -16.666666666666664`, 
        2.041077998578922*^-15}, {25., -16.09876377148447, 
        4.313650751708684}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., -8.333333333333332, 
        1.020538999289461*^-15}, {
        25., -8.049381885742235, -2.15682537585434}, {25., 0., 0.}, {25., 0., 
        0.}}], 
       Polygon3DBox[{{25., -8.333333333333332, 1.020538999289461*^-15}, {
        25., -16.666666666666664`, 2.041077998578922*^-15}, {
        25., -16.09876377148447, -4.31365075170868}, {
        25., -8.049381885742235, -2.15682537585434}, {25., -8.333333333333332,
         1.020538999289461*^-15}}], 
       Polygon3DBox[{{25., -16.666666666666664`, 2.041077998578922*^-15}, {
        25., -25., 3.061616997868383*^-15}, {
        25., -24.148145657226706`, -6.47047612756302}, {
        25., -16.09876377148447, -4.31365075170868}, {
        25., -16.666666666666664`, 2.041077998578922*^-15}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -8.049381885742235, -2.156825375854336}, {
        25., -7.216878364870323, -4.166666666666664}, {25., 0., 0.}, {25., 0.,
         0.}}], Polygon3DBox[{{25., -8.049381885742235, -2.156825375854336}, {
        25., -16.09876377148447, -4.313650751708672}, {
        25., -14.433756729740645`, -8.333333333333329}, {
        25., -7.216878364870323, -4.166666666666664}, {
        25., -8.049381885742235, -2.156825375854336}}], 
       Polygon3DBox[{{25., -16.09876377148447, -4.313650751708672}, {
        25., -24.14814565722671, -6.470476127563009}, {
        25., -21.65063509461097, -12.499999999999993`}, {
        25., -14.433756729740645`, -8.333333333333329}, {
        25., -16.09876377148447, -4.313650751708672}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -7.216878364870323, -4.166666666666664}, {
        25., -5.892556509887897, -5.8925565098878945`}, {25., 0., 0.}, {25., 
        0., 0.}}], 
       Polygon3DBox[{{25., -7.216878364870323, -4.166666666666664}, {
        25., -14.433756729740645`, -8.333333333333329}, {
        25., -11.785113019775794`, -11.785113019775789`}, {
        25., -5.892556509887897, -5.8925565098878945`}, {
        25., -7.216878364870323, -4.166666666666664}}], 
       Polygon3DBox[{{25., -14.433756729740645`, -8.333333333333329}, {
        25., -21.65063509461097, -12.499999999999993`}, {
        25., -17.677669529663692`, -17.677669529663685`}, {
        25., -11.785113019775794`, -11.785113019775789`}, {
        25., -14.433756729740645`, -8.333333333333329}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -5.892556509887898, -5.892556509887893}, {
        25., -4.16666666666667, -7.216878364870319}, {25., 0., 0.}, {25., 0., 
        0.}}], Polygon3DBox[{{25., -5.892556509887898, -5.892556509887893}, {
        25., -11.785113019775796`, -11.785113019775785`}, {
        25., -8.33333333333334, -14.433756729740638`}, {
        25., -4.16666666666667, -7.216878364870319}, {
        25., -5.892556509887898, -5.892556509887893}}], 
       Polygon3DBox[{{25., -11.785113019775796`, -11.785113019775785`}, {
        25., -17.677669529663696`, -17.677669529663678`}, {
        25., -12.50000000000001, -21.65063509461096}, {
        25., -8.33333333333334, -14.433756729740638`}, {
        25., -11.785113019775796`, -11.785113019775785`}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -4.16666666666667, -7.216878364870319}, {
        25., -2.156825375854346, -8.049381885742234}, {25., 0., 0.}, {25., 0.,
         0.}}], Polygon3DBox[{{25., -4.16666666666667, -7.216878364870319}, {
        25., -8.33333333333334, -14.433756729740638`}, {
        25., -4.313650751708692, -16.098763771484467`}, {
        25., -2.156825375854346, -8.049381885742234}, {
        25., -4.16666666666667, -7.216878364870319}}], 
       Polygon3DBox[{{25., -8.33333333333334, -14.433756729740638`}, {
        25., -12.50000000000001, -21.65063509461096}, {
        25., -6.470476127563038, -24.148145657226703`}, {
        25., -4.313650751708692, -16.098763771484467`}, {
        25., -8.33333333333334, -14.433756729740638`}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -2.156825375854346, -8.049381885742234}, {
        25., -8.932295329768568*^-15, -8.333333333333332}, {25., 0., 0.}, {
        25., 0., 0.}}], 
       Polygon3DBox[{{25., -2.156825375854346, -8.049381885742234}, {
        25., -4.313650751708692, -16.098763771484467`}, {
        25., -1.7864590659537137`*^-14, -16.666666666666664`}, {
        25., -8.932295329768568*^-15, -8.333333333333332}, {
        25., -2.156825375854346, -8.049381885742234}}], 
       Polygon3DBox[{{25., -4.313650751708692, -16.098763771484467`}, {
        25., -6.470476127563038, -24.148145657226703`}, {
        25., -2.6796885989305705`*^-14, -25.}, {
        25., -1.7864590659537137`*^-14, -16.666666666666664`}, {
        25., -4.313650751708692, -16.098763771484467`}}], 
       Polygon3DBox[{{25., 0., 0.}, {
        25., -1.5308084989341913`*^-15, -8.333333333333332}, {25., 
        2.1568253758543356`, -8.049381885742235}, {25., 0., 0.}, {25., 0., 
        0.}}], Polygon3DBox[{{
        25., -1.5308084989341913`*^-15, -8.333333333333332}, {
        25., -3.0616169978683826`*^-15, -16.666666666666664`}, {25., 
        4.313650751708671, -16.09876377148447}, {25., 
        2.1568253758543356`, -8.049381885742235}, {
        25., -1.5308084989341913`*^-15, -8.333333333333332}}], 
       Polygon3DBox[{{25., -3.0616169978683826`*^-15, -16.666666666666664`}, {
        25., -4.592425496802574*^-15, -25.}, {25., 
        6.470476127563007, -24.14814565722671}, {25., 
        4.313650751708671, -16.09876377148447}, {
        25., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 
        2.1568253758543356`, -8.049381885742235}, {25., 
        4.166666666666661, -7.216878364870325}, {25., 0., 0.}, {25., 0., 
        0.}}], Polygon3DBox[{{25., 2.1568253758543356`, -8.049381885742235}, {
        25., 4.313650751708671, -16.09876377148447}, {25., 
        8.333333333333321, -14.43375672974065}, {25., 
        4.166666666666661, -7.216878364870325}, {25., 
        2.1568253758543356`, -8.049381885742235}}], 
       Polygon3DBox[{{25., 4.313650751708671, -16.09876377148447}, {25., 
        6.470476127563007, -24.14814565722671}, {25., 
        12.499999999999984`, -21.650635094610976`}, {25., 
        8.333333333333321, -14.43375672974065}, {25., 
        4.313650751708671, -16.09876377148447}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 
        4.166666666666661, -7.216878364870325}, {25., 
        5.89255650988789, -5.892556509887903}, {25., 0., 0.}, {25., 0., 0.}}],
        Polygon3DBox[{{25., 4.166666666666661, -7.216878364870325}, {25., 
        8.333333333333321, -14.43375672974065}, {25., 
        11.78511301977578, -11.785113019775807`}, {25., 
        5.89255650988789, -5.892556509887903}, {25., 
        4.166666666666661, -7.216878364870325}}], 
       Polygon3DBox[{{25., 8.333333333333321, -14.43375672974065}, {25., 
        12.499999999999984`, -21.650635094610976`}, {25., 
        17.67766952966367, -17.67766952966371}, {25., 
        11.78511301977578, -11.785113019775807`}, {25., 
        8.333333333333321, -14.43375672974065}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 
        5.8925565098878945`, -5.892556509887897}, {25., 
        7.216878364870319, -4.16666666666667}, {25., 0., 0.}, {25., 0., 0.}}],
        Polygon3DBox[{{25., 5.8925565098878945`, -5.892556509887897}, {25., 
        11.785113019775789`, -11.785113019775794`}, {25., 
        14.433756729740638`, -8.33333333333334}, {25., 
        7.216878364870319, -4.16666666666667}, {25., 
        5.8925565098878945`, -5.892556509887897}}], 
       Polygon3DBox[{{25., 11.785113019775789`, -11.785113019775794`}, {25., 
        17.677669529663685`, -17.677669529663692`}, {25., 
        21.65063509461096, -12.50000000000001}, {25., 
        14.433756729740638`, -8.33333333333334}, {25., 
        11.785113019775789`, -11.785113019775794`}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 
        7.216878364870319, -4.16666666666667}, {25., 
        8.049381885742234, -2.1568253758543463`}, {25., 0., 0.}, {25., 0., 
        0.}}], Polygon3DBox[{{25., 7.216878364870319, -4.16666666666667}, {
        25., 14.433756729740638`, -8.33333333333334}, {25., 
        16.098763771484467`, -4.313650751708693}, {25., 
        8.049381885742234, -2.1568253758543463`}, {25., 
        7.216878364870319, -4.16666666666667}}], 
       Polygon3DBox[{{25., 14.433756729740638`, -8.33333333333334}, {25., 
        21.65063509461096, -12.50000000000001}, {25., 
        24.148145657226703`, -6.470476127563039}, {25., 
        16.098763771484467`, -4.313650751708693}, {25., 
        14.433756729740638`, -8.33333333333334}}], 
       Polygon3DBox[{{25., 0., 0.}, {25., 
        8.049381885742234, -2.1568253758543463`}, {25., 
        8.333333333333332, -9.442564829413298*^-15}, {25., 0., 0.}, {25., 0., 
        0.}}], Polygon3DBox[{{25., 8.049381885742234, -2.1568253758543463`}, {
        25., 16.098763771484467`, -4.313650751708693}, {25., 
        16.666666666666664`, -1.8885129658826596`*^-14}, {25., 
        8.333333333333332, -9.442564829413298*^-15}, {25., 
        8.049381885742234, -2.1568253758543463`}}], 
       Polygon3DBox[{{25., 16.098763771484467`, -4.313650751708693}, {25., 
        24.148145657226703`, -6.470476127563039}, {25., 
        25., -2.8327694488239898`*^-14}, {25., 
        16.666666666666664`, -1.8885129658826596`*^-14}, {25., 
        16.098763771484467`, -4.313650751708693}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwdEClEeIeVzfcf6Nq4eC4q7TuyENJuLpnv1tY
JywzdfgPBhpw8R1pwgeq1xo6bIfSMHEmMK3p8BSqDybuDjUXZg9M/PT58+tn
T75tg+4+O4j6A+jq/0LcceAZmvlQdxzYgeaeJxB1B1ih7kLz7wFPNP9C6QMQ
d72Gu8sTqt4M6i608DnwB+oumPguqHu2QmmYOBvEHQceQ/XBxMOh5rpD7YGJ
37h9+/CWdV/2wNwFEzeButsTTf13aDy9QDMfFk870dwDdQfcXfD4goZ7BJp/
UePt9x4AMInLaA==
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{25., 25., 0.}, {25., 25., 0.}, {25., 
          24.148145657226706`, 6.4704761275630185`}, {24.999999999999996`, 
          24.148145657226706`, 6.4704761275630185`}, {25., 25., 0.}}], 
         Polygon3DBox[{{24.999999999999996`, 24.148145657226706`, 
          6.4704761275630185`}, {25., 24.148145657226706`, 
          6.4704761275630185`}, {25., 21.65063509461097, 
          12.499999999999998`}, {25., 21.65063509461097, 
          12.499999999999998`}, {24.999999999999996`, 24.148145657226706`, 
          6.4704761275630185`}}], 
         Polygon3DBox[{{25., 21.65063509461097, 12.499999999999998`}, {25., 
          21.65063509461097, 12.499999999999998`}, {25., 17.67766952966369, 
          17.677669529663685`}, {24.999999999999996`, 17.67766952966369, 
          17.677669529663685`}, {25., 21.65063509461097, 
          12.499999999999998`}}], 
         Polygon3DBox[{{24.999999999999996`, 17.67766952966369, 
          17.677669529663685`}, {25., 17.67766952966369, 
          17.677669529663685`}, {25., 12.500000000000004`, 
          21.650635094610966`}, {25.000000000000004`, 12.500000000000004`, 
          21.650635094610966`}, {24.999999999999996`, 17.67766952966369, 
          17.677669529663685`}}], 
         Polygon3DBox[{{25.000000000000004`, 12.500000000000004`, 
          21.650635094610966`}, {25., 12.500000000000004`, 
          21.650635094610966`}, {25., 6.470476127563024, 
          24.148145657226706`}, {25., 6.470476127563024, 
          24.148145657226706`}, {25.000000000000004`, 12.500000000000004`, 
          21.650635094610966`}}], 
         Polygon3DBox[{{25., 6.470476127563024, 24.148145657226706`}, {25., 
          6.470476127563024, 24.148145657226706`}, {25., 
          7.0819236220599744`*^-15, 25.}, {25., 7.0819236220599744`*^-15, 
          25.}, {25., 6.470476127563024, 24.148145657226706`}}], 
         Polygon3DBox[{{25., 1.5308084989341915`*^-15, 25.}, {25., 
          1.5308084989341915`*^-15, 25.}, {25., -6.470476127563016, 
          24.148145657226706`}, {24.999999999999996`, -6.470476127563016, 
          24.148145657226706`}, {25., 1.5308084989341915`*^-15, 25.}}], 
         Polygon3DBox[{{24.999999999999996`, -6.470476127563016, 
          24.148145657226706`}, {25., -6.470476127563016, 
          24.148145657226706`}, {25., -12.499999999999995`, 
          21.65063509461097}, {25., -12.499999999999995`, 
          21.65063509461097}, {24.999999999999996`, -6.470476127563016, 
          24.148145657226706`}}], 
         Polygon3DBox[{{25., -12.499999999999995`, 21.65063509461097}, {
          25., -12.499999999999995`, 21.65063509461097}, {
          25., -17.677669529663685`, 17.67766952966369}, {
          24.999999999999996`, -17.677669529663685`, 17.67766952966369}, {
          25., -12.499999999999995`, 21.65063509461097}}], 
         Polygon3DBox[{{24.999999999999996`, -17.677669529663685`, 
          17.67766952966369}, {25., -17.677669529663685`, 
          17.67766952966369}, {25., -21.65063509461097, 
          12.499999999999998`}, {25., -21.65063509461097, 
          12.499999999999998`}, {24.999999999999996`, -17.677669529663685`, 
          17.67766952966369}}], 
         Polygon3DBox[{{25., -21.650635094610962`, 12.500000000000009`}, {
          25., -21.650635094610962`, 12.500000000000009`}, {
          25., -24.148145657226706`, 6.470476127563026}, {
          25., -24.148145657226706`, 6.470476127563026}, {
          25., -21.650635094610962`, 12.500000000000009`}}], 
         Polygon3DBox[{{25., -24.148145657226706`, 6.470476127563026}, {
          25., -24.148145657226706`, 6.470476127563026}, {25., -25., 
          3.061616997868383*^-15}, {25., -25., 3.061616997868383*^-15}, {
          25., -24.148145657226706`, 6.470476127563026}}], 
         Polygon3DBox[{{25., -25., 3.061616997868383*^-15}, {25., -25., 
          3.061616997868383*^-15}, {
          25., -24.148145657226706`, -6.47047612756302}, {
          25., -24.148145657226706`, -6.47047612756302}, {25., -25., 
          3.061616997868383*^-15}}], 
         Polygon3DBox[{{25., -24.14814565722671, -6.470476127563009}, {
          25., -24.14814565722671, -6.470476127563009}, {
          25., -21.65063509461097, -12.499999999999993`}, {
          25., -21.65063509461097, -12.499999999999993`}, {
          25., -24.14814565722671, -6.470476127563009}}], 
         Polygon3DBox[{{25., -21.65063509461097, -12.499999999999993`}, {
          25., -21.65063509461097, -12.499999999999993`}, {
          25., -17.677669529663692`, -17.677669529663685`}, {
          25., -17.677669529663692`, -17.677669529663685`}, {
          25., -21.65063509461097, -12.499999999999993`}}], 
         Polygon3DBox[{{25., -17.677669529663696`, -17.677669529663678`}, {
          25., -17.677669529663696`, -17.677669529663678`}, {
          25., -12.50000000000001, -21.65063509461096}, {
          24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
          25., -17.677669529663696`, -17.677669529663678`}}], 
         Polygon3DBox[{{
          24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
          25., -12.50000000000001, -21.65063509461096}, {
          25., -6.470476127563038, -24.148145657226703`}, {
          25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
          24.999999999999996`, -12.50000000000001, -21.65063509461096}}], 
         Polygon3DBox[{{
          25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
          25., -6.470476127563038, -24.148145657226703`}, {
          25., -2.6796885989305705`*^-14, -25.}, {
          25., -2.6796885989305705`*^-14, -25.}, {
          25.000000000000004`, -6.470476127563038, -24.148145657226703`}}], 
         Polygon3DBox[{{25., -4.592425496802574*^-15, -25.}, {
          25., -4.592425496802574*^-15, -25.}, {25., 
          6.470476127563007, -24.14814565722671}, {25., 
          6.470476127563007, -24.14814565722671}, {
          25., -4.592425496802574*^-15, -25.}}], 
         Polygon3DBox[{{25., 6.470476127563007, -24.14814565722671}, {25., 
          6.470476127563007, -24.14814565722671}, {25., 
          12.499999999999984`, -21.650635094610976`}, {25., 
          12.499999999999984`, -21.650635094610976`}, {25., 
          6.470476127563007, -24.14814565722671}}], 
         Polygon3DBox[{{25., 12.499999999999984`, -21.650635094610976`}, {25.,
           12.499999999999984`, -21.650635094610976`}, {25., 
          17.67766952966367, -17.67766952966371}, {25.000000000000004`, 
          17.67766952966367, -17.67766952966371}, {25., 
          12.499999999999984`, -21.650635094610976`}}], 
         Polygon3DBox[{{25., 17.677669529663685`, -17.677669529663692`}, {25.,
           17.677669529663685`, -17.677669529663692`}, {25., 
          21.65063509461096, -12.50000000000001}, {24.999999999999996`, 
          21.65063509461096, -12.50000000000001}, {25., 
          17.677669529663685`, -17.677669529663692`}}], 
         Polygon3DBox[{{24.999999999999996`, 
          21.65063509461096, -12.50000000000001}, {25., 
          21.65063509461096, -12.50000000000001}, {25., 
          24.148145657226703`, -6.470476127563039}, {25.000000000000004`, 
          24.148145657226703`, -6.470476127563039}, {24.999999999999996`, 
          21.65063509461096, -12.50000000000001}}], 
         Polygon3DBox[{{25.000000000000004`, 
          24.148145657226703`, -6.470476127563039}, {25., 
          24.148145657226703`, -6.470476127563039}, {25., 
          25., -2.8327694488239898`*^-14}, {25., 
          25., -2.8327694488239898`*^-14}, {25.000000000000004`, 
          24.148145657226703`, -6.470476127563039}}]}}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFlg1MU1cYhgtWnKYTULBqwmwFqiAKIkOOm9wP4tgwBKeZCiKKRs3c8J8p
P5mig7CgMpk6g0OZiMb4N6aLOnS5x+kMTGOQaYYoxWUmOtCkUZgEsK56zrnN
/UpvT9Lce9886Xn79fRJzUvXzFk+QKfTZTpe3o7X63u2AqhOtQJAfXXJOe/n
5F5VVdyoHAUuOee92A2EDx9Rd/CpCR4UP0zvWmYGnAu+79WbJU9APM5RH76P
Sx9nznk9u6G1K2ZFDtndLZXGfLN8fYQecC74TravVMPzzZzHubqP0g8SSpZe
i7aOBZyr5+MHcy0ROdPvjQNd1ZfJBWFh4JKr5uNL5yHeJVf3UeaQqO7jZj5+
9IfoJYc67trl3/alz/S74g84V8/HFy7w/BLnca7+vOPRHMKh/zyAsrM6EgpJ
4qT79ZNgV5Pt5tTiKMC54O1v9jXSrYjHOepDvfm+3uo+Si74QWxfal9ftPBC
eSBtmdi+Z/ZYE+Bc8N1sX/DZwPK/OI9z9fcVpcwhngTumH9FPDtzdX8TPyfR
8FXGfNP5ghjAueDZORnDz4mTxznqo8wB9XGZDzsnJnosJe1x/jkzjbM8uVFq
HQc4Fzw7J2PgNM9jOI9zdZ8YZQ7JjzNg9wHx7MzV8wmB9siptwxzYsHLOPdo
6hdxgHPBs3MSTDsQj3PUh59Tlz5KLviBbF/atHh19aia8dQn++GJtZciAeeC
Z+ckGFp4ruc8ztWfWyzxTJR8z9rElxUrn8va3iaQtirHUqC/K9V+7W+r+KBN
0vY2gaQth6b11LVLOblrvLs+NHjwNoEZjJcFr+1tAlmsj0x5H3feZtvFwcaT
KRU3Uw2QklTUM/HXgdSdtwW/jfF0Hue1vU1gacP18mOTfaE1c0zG4C0DPHib
wKcbF829FekDeeYfZ2eVmjx4m8AyxtN8zmt728GzPrSN93HnbS/OP1gw/U7m
0D4pLji2t8TQIWl7m4CN8XIO51nuztsEdh2KuDz6HTPYzlc92Vpi8OBtAqu6
+uTkiADYmGG0Rz0I8+BtAisZTzdxXtvbBMpZH/qM99H2toMv3XfW96yODms8
OyhUb5e1vU2gkPHgx3ltbxMg/4xcnhs0AfRlkdLnz/w8eJvAyykt6xpvBkGy
ccjfO3dN9uBtAi8YT2dyXtvbBKaxPtSH99H2NoFuH3rvaVAg1Vt7lxzOMnrw
NoF/GQ9DOK/tbQLN1xqazp2K5tdhHrzt4D8anH71fjCEbNYdqwv35G0CdxhP
Qzmv7W2lD23hfbS97fh9bfi5+WC2ifaGdi5IfT/Eg7cJ3GY86CyMF7mOL8Xb
r1dhkpKPpyeqbx+0KDz2tuD7EvPb9h830ot/pu1L2Buk8Njbgj+VO6Wis/6F
HD1yybuTw0cpvIu3OV/DeCkW8djbgu9hfaCO93HnbcEXbuoe3WgcB707r9/q
vmim7rwt+G2Mp3bOiz4u3uZ8lbH6dPPRYbTkwMyWso8HKbyLt0WfHSfzvu26
J9vOF33v29ypeBJ7W/BZjJcaMY+8LfhK1geKeR933hZ8x5Yj1/efCYXE7FNv
x3Q4z22/3nbyNAvx2NuCX2s9bP0j87Gse9g6NCz1ttIfe1vw2ZfTZtfr/5Ng
XuV3CfEG5f2xtwX/GePlGYjH3lbmyfpIb6E+2NuCH7Hgl/qC2kBIasifGLR5
uPL+2NuCH8p4+gnisbcFTzPy1h1Z6AsL73aseFTxXBI89rbgQ9IHBC/yN8D2
6mfn/Eud/4uwtwVvZjwtQzz2tuCvsj50EeqDvS34mvYzsyqbXkgRbeXXchf3
KDz2tuBrGS+nIB57W/CthqerLVfN/Oql9MfeFvx7xVF5cbFGaG2wp5x4FKbw
2NuCJ4ynbYjH3kZ9qBX1wd4WfEC8eZp170v55O8HOn8i3lTw/Xrbwdumv+Gl
45z/H9PAtYs=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxd1QtMU1cYwPELVJikowXBggmjFSiCIFA7pGxwD41jQggOM5C3hYiZGyoq
Qx4ZoIOwoDI6H6SOx0A0RMAxWcChyz1ORmAYAgyzAlJYRiKjkjQIg/CoY5zT
wzg3aZr+eu//fvfcPiRpZ46kmzMMk7z+sGBMmz1gtmzrr9/Uap5VOWEXApNP
lkzFLxyXADMEwGvHzs6aWTHx1TcbG7cXO9WBZrhTJv86/Zw3D/DQG7D1xGFf
62tLbAH2edRhG7CHlqZ1y3S7cUdM5mFqvwjP9/TE8whBjNQ7K3jMgziaRwBj
sSu3dsg8v1TGRwif2uJ5hPA7WWqdfsTIPcaO5hGAh9jR8V74vHvIPBVDhv4D
JX4Ara0jKFIo973o2UfcuNERwYvYzbd2oDnujPrMXI/eLQZWqAON54qTHqod
4B/Yl1AHWJ5HHqJwuHL0qR+ew4/M82XiUXFHvhz3xXh9ZMTR+rjg9ZEBqkPm
CZS+elam88DrI4aNkXHTee0SKMeO1scF3McePp0IrlXLcUdO5jETxdyN+jwQ
z+MGZnwPDPKPBBBH6+MK9dipDrTAHcuMqabMx75gG+rAoWOn650a9kAedrQ+
rmAUOzpegTsMcz1TuaY5+ZozedypLGk+b4Rt/crWoPlggjV5WGFd0HLnDJuV
c8Z84UM+MPlB5BztKtThIO6gj3EgyG6O1PRH8UFkWPGyz8/boMkvIYex2E2d
tN4+daO/AIwnuyRuL7Qg/U+yU2IGfS1BruT7aFWZmPhx5DCPdtSBE7hjhn0y
Ifh5ss0qG+gasFLK15PrNSDnsiivqPN+susdCTB01L66WLp5vacWVrlwb3uQ
nSgy+k16Ej+JHF6gXI06cI7qqMsq2wRtDLQbaLNy5xnJfSlCDoSUK/5yTM9x
3gt45b7sZ3NC0lnbP3p2oN8ZhIus/7xa4U98ETmMoDwIdaAl1VmyhGOzzg6Q
p1tJva0SkfvyN3JgTbm2u3eovUWGn+1IR3toe3zXC1fgVsA0dnoFEH+OHLpT
jjtwlOpMnv9RW5Mhhivu8wlR77uR8w4jB4z0f14Uho/77xelqX64Rkp8VZk3
ceueCD76Pa4y9IYz8Zac/Zr5nkVO5pj6rr+XE/EG5GwA5cuoAzqpTtGFpV0D
Ig+wcrVvcOmRhPgl5NBIea2o/r72rh0srY4YLf/IarNzpTn3m4UxztBR/K1A
O8+ZXIWcHaC8CnVACdXRF97pu/XAHSgzWt6W6/H/3KZDFeWZutu635KnOWZq
3MYzapj0M57ERffw/mFBbNXN0BA+2f9T5NxBylWow75FdXYm/NST3+oAwnrz
fJwLdpD9bZDDjymHibln7yQJQNKI/sRLzWvW5G7xFq4ptnxwuX6u3db0fV93
CXJYTnkX6sAUqtMw8+Bw1dAi6z2h7s45tky8FTkXSfk4f/a0tEuCn81I/70S
v9zAABEY7zVGNr30JK5ADicoxx2oozr2IZIg3Y01rvnX6vkfFObkPhqCN5y9
h/1fjL4NAg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  AxesLabel:>{
    FormBox["\"x-axis\"", TraditionalForm], 
    FormBox["\"y-axis\"", TraditionalForm], 
    FormBox["\"z-axis\"", TraditionalForm]},
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015013716373`*^9, 3.6147092677431498`*^9, 
  3.614729122918795*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"During evaluation of In[181]:="]
}, Open  ]],

Cell["\<\
Single-valued surface function format of a conic-shaped lens.\
\>", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "Based on the previous, ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " format notation, this conic lens example specifies ",
 StyleBox["Sqrt[y^2 + z^2]", "Input"],
 "for ",
 StyleBox["fx", "Input",
  FontSlant->"Italic"],
 " and ",
 StyleBox["{y,z}", "Input"],
 " for ",
 StyleBox["{s,t}", "Input"],
 ". In general, there is nothing sacred about the naming of parametric \
variables in your surface function. As shown in the table below, you can also \
use {#1, #2} instead of alphabetic symbols."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 StyleBox["(1) Function[", "Input"],
 StyleBox["fx[", "Input",
  FontSlant->"Italic"],
 StyleBox["#1,#2", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["]\n(2) Function[{", "Input"],
 StyleBox["fx[", "Input",
  FontSlant->"Italic"],
 StyleBox["#1,#2", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fy[", "Input",
  FontSlant->"Italic"],
 StyleBox["#1,#2", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fz[", "Input",
  FontSlant->"Italic"],
 StyleBox["#1,#2", "Input"],
 StyleBox["]", "Input",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"]
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell["\<\
The two principle surface function formats shown in slot variable notation. \
\>", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[{
 "These \"slot\" variables have an advantage in that they do not require any \
declaration before they can be used in the ",
 StyleBox["Function", "Input"],
 " statement. For this reason, slot variables are sometimes called \"pure\" \
variables and ",
 "are a kind of short-hand notation for working with ",
 StyleBox["Function", "Input"],
 " statements.",
 " They are known as slot variables because, internally, they are represented \
by the ",
 StyleBox["Slot", "Input"],
 " head:"
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[CellGroupData[{

Cell["FullForm[#1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"In[182]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Slot", "[", "1", "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.563404253399559*^9, 3.563458147683176*^9, 
  3.5644875902289553`*^9, 3.566100689358156*^9, 3.601301241365364*^9, 
  3.601301501515513*^9, 3.614709267970458*^9, 3.614729123061227*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"Out[182]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "For some surface models, the two parametric variables do not have any \
correspondence with the three-dimensional coordinates of ordinary Cartesian \
space. In such cases, the surface function must provide a vector quantity \
that designates all three components of space. This is demonstrated in the \
spherical mirror example given below. Here, the two parametric variables have \
angular dimensions instead of rectangular spatial dimensions. In this case, \
the ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 " parameter of ",
 StyleBox["CustomMirror", "Input"],
 " has units of radians."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{Move[GridOfRays[1.5,NumberOfRays->5],2,180],
\tCustomMirror[ Function[{Sin[#1], Cos[#1]*Sin[#2], Cos[#1]*Cos[#2]}], \
{2.001*Pi,1.001*Pi}],
\tBoundary[2]},
\tPlotPoints -> 60,
\tAxes -> True,
\tAxesLabel -> {\"x-axis\",\"y-axis\",\"z-axis\"}
];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"In[183]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGAwBmJmIO478JsldU+kPQMU7Gxdmfn3//v9LxwF+TZXXtgP
E7/cs3/Xi9fv9u9lsCvIfnsfLr52p+T7q7tf70/Z+Sr61MxncPENJw2SCpY/
2+85s+mG/qbXcPHUIydCctkf7D/PdVb49bN3cHHhyUsm/513Yf+h+Kyo/0D7
YeLmTepdqXs8928/GSnh8Aqh/l34kaeKbRfs/Q+JbJy/A2F+39K4cxN/3Le/
Pn3R/CeLEO5Z8uDCp/B5z+yflF8ouM34AC6uM18nJGPra/uLK0uFJkxC+Lfb
jNls2ot38HBBBR/sT0HUw+V7oOofQMyHi+tBzb8CcQ9cfDnUPb4Q98PFp0Ld
D/UvXBzmX2j4wMXNiyDhcwESnnBxfmh4+kLCHy4eBw1/aHzBxWHxdRoSv3Dx
ldD4/QBJD3DxS9D0AE0/8HCDpR9c4i/QzEFLV3BxtHSF4U5PNH+hpSu4OFq6
QoQbarrCCGd/tHhBS1dwcbR0BRdHS1dwcSLTFTzc0NIVXBwtXcHF0dIVXBwt
XWHkI4x8h5qu4OJo6QoujpauMMqB02jlBlq6goujpSuMcgmXOAAO3daf
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGAwBmJmBgTY2boy8+//9/tXHPzNkroncj9MPHvb4wlFu9/v
t0627/RpO2APE2+rseFe9Prdfp18k8lHqy/AxReUPf8gPeXt/u0fzsTz5NyA
i7875//r8K7X+23OrudU/ngfLt6qv2fZ9vSX+89vNTdkKX0MF08RMp2ntfTZ
/uDMuS6Cc57BxU/PZXhtWf94/xz1C3Mexb+Eiy+5bnF+G/OD/TpeKgtCt7yG
i09WWGF/pfnG/nm5Pg0G/W/h4qvXTolbNOXCfgO229L+L97BxfOkxXaG7jyw
/5RF5c5jO9/DxVHBB7h4GkS9/Wk09csh5tsbopnfD3GP/Xw09yyCuN9eF839
pyD+tUf3LzR87NHDpxkSnvaX0MLzDST87Z3Rwn8+JL7sd6PFFzR+7Q3Q4hea
HuzR0wM0/dijpx9c4rjMgdmLI13Z40hX9jjSlT2OdIURbqdxhDM0XdnjSFf2
ONKVPY50ZU9iutqPI13tx5Gu9uNIV/txpCuMfIQr30HT1X4c6Wo/jnS1H0e6
2o8jXWGUM7jKJXRxAHfuqwI=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.0015707956808306586`, 0.999997532600929, 
      0.0015707937429396226`}, {-0.25742794393320745`, 0.9662963053824021, 
      0.001517855935476677}, {-0.25742794393320745`, 
      0.9582113052864007, -0.12474753746528762`}, {0.0015707956808306586`, 
      0.9916305543748455, -0.12909832001682145`}, {0.0015707956808306586`, 
      0.999997532600929, 0.0015707937429396226`}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.9916305543748455, -0.12909832001682145`}, {-0.25742794393320745`, 
      0.9582113052864007, -0.12474753746528762`}, {-0.25742794393320745`, 
      0.933698284125023, -0.2488742009616693}, {0.0015707956808306586`, 
      0.9662625999063955, -0.25755411202903006`}, {0.0015707956808306586`, 
      0.9916305543748455, -0.12909832001682145`}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.9662625999063955, -0.25755411202902984`}, {-0.25742794393320745`, 
      0.933698284125023, -0.24887420096166907`}, {-0.25742794393320745`, 
      0.893177504554108, -0.36873404920188435`}, {0.0015707956808306586`, 
      0.9243285892263636, -0.3815942763456096}, {0.0015707956808306586`, 
      0.9662625999063955, -0.25755411202902984`}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.9243285892263636, -0.3815942763456096}, {-0.25742794393320745`, 
      0.893177504554108, -0.36873404920188435`}, {-0.25742794393320745`, 
      0.8373436736979657, -0.48227214910288585`}, {0.0015707956808306586`, 
      0.8665474585516433, -0.4990922105970169}, {0.0015707956808306586`, 
      0.9243285892263636, -0.3815942763456096}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.8665474585516434, -0.49909221059701675`}, {-0.25742794393320745`, 
      0.8373436736979658, -0.4822721491028857}, {-0.25742794393320745`, 
      0.7671540327667603, -0.5875419505805674}, {0.0015707956808306586`, 
      0.7939098345077701, -0.6080334754540856}, {0.0015707956808306586`, 
      0.8665474585516434, -0.49909221059701675`}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.79390983450777, -0.6080334754540857}, {-0.25742794393320745`, 
      0.7671540327667602, -0.5875419505805675}, {-0.25742794393320745`, 
      0.6838119456672076, -0.682738659111339}, {0.0015707956808306586`, 
      0.707661050364502, -0.70655033111445}, {0.0015707956808306586`, 
      0.79390983450777, -0.6080334754540857}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.7076610503645019, -0.7065503311144501}, {-0.25742794393320745`, 
      0.6838119456672075, -0.6827386591113391}, {-0.25742794393320745`, 
      0.5887462679710909, -0.7662301779703237}, {0.0015707956808306586`, 
      0.6092797954620207, -0.792953758703928}, {0.0015707956808306586`, 
      0.7076610503645019, -0.7065503311144501}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.6092797954620207, -0.792953758703928}, {-0.25742794393320745`, 
      0.5887462679710909, -0.7662301779703237}, {-0.25742794393320745`, 
      0.4835868499496082, -0.8365850896580315}, {0.0015707956808306586`, 
      0.5004527638719365, -0.8657624176030447}, {0.0015707956808306586`, 
      0.6092797954620207, -0.792953758703928}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.5004527638719365, -0.8657624176030447}, {-0.25742794393320745`, 
      0.4835868499496082, -0.8365850896580315}, {-0.25742794393320745`, 
      0.37013659366094737`, -0.8925971967888944}, {0.0015707956808306586`, 
      0.383045736928263, -0.9237280422407956}, {0.0015707956808306586`, 
      0.5004527638719365, -0.8657624176030447}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.3830457369282629, -0.9237280422407956}, {-0.25742794393320745`, 
      0.37013659366094726`, -0.8925971967888944}, {-0.25742794393320745`, 
      0.2503405431573963, -0.9333062017012322}, {0.0015707956808306586`, 
      0.25907159540292685`, -0.9658568429411841}, {0.0015707956808306586`, 
      0.3830457369282629, -0.9237280422407956}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.25907159540292696`, -0.9658568429411841}, {-0.25742794393320745`, 
      0.2503405431573964, -0.9333062017012322}, {-0.25742794393320745`, 
      0.1262525377438808, -0.9580141702477846}, {0.0015707956808306586`, 
      0.13065580973997765`, -0.9914265439164516}, {0.0015707956808306586`, 
      0.25907159540292696`, -0.9658568429411841}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0.13065580973997756`, -0.9914265439164516}, {-0.25742794393320745`, 
      0.1262525377438807, -0.9580141702477846}, {-0.25742794393320745`, 
      8.04604297774884*^-17, -0.9662974975039113}, {0.0015707956808306586`, 
      8.326662412070115*^-17, -0.9999987662997035}, {0.0015707956808306586`, 
      0.13065580973997756`, -0.9914265439164516}}], 
     Polygon3DBox[{{0.0015707956808306586`, 
      0., -0.9999987662997035}, {-0.25742794393320745`, 
      0., -0.9662974975039113}, {-0.25742794393320745`, \
-0.12625253774388065`, -0.9580141702477847}, {
      0.0015707956808306586`, -0.13065580973997748`, -0.9914265439164517}, {
      0.0015707956808306586`, 0., -0.9999987662997035}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.13065580973997734`, -0.9914265439164517}, \
{-0.25742794393320745`, -0.1262525377438805, -0.9580141702477847}, \
{-0.25742794393320745`, -0.25034054315739607`, -0.9333062017012324}, {
      0.0015707956808306586`, -0.2590715954029266, -0.9658568429411842}, {
      0.0015707956808306586`, -0.13065580973997734`, -0.9914265439164517}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.25907159540292674`, -0.9658568429411842}, \
{-0.25742794393320745`, -0.2503405431573962, -0.9333062017012324}, \
{-0.25742794393320745`, -0.37013659366094714`, -0.8925971967888944}, {
      0.0015707956808306586`, -0.38304573692826277`, -0.9237280422407956}, {
      0.0015707956808306586`, -0.25907159540292674`, -0.9658568429411842}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.38304573692826266`, -0.9237280422407957}, \
{-0.25742794393320745`, -0.37013659366094703`, -0.8925971967888945}, \
{-0.25742794393320745`, -0.483586849949608, -0.8365850896580317}, {
      0.0015707956808306586`, -0.5004527638719363, -0.865762417603045}, {
      0.0015707956808306586`, -0.38304573692826266`, -0.9237280422407957}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.5004527638719363, -0.8657624176030448}, \
{-0.25742794393320745`, -0.483586849949608, -0.8365850896580316}, \
{-0.25742794393320745`, -0.5887462679710906, -0.7662301779703238}, {
      0.0015707956808306586`, -0.6092797954620205, -0.7929537587039281}, {
      0.0015707956808306586`, -0.5004527638719363, -0.8657624176030448}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.6092797954620206, -0.792953758703928}, \
{-0.25742794393320745`, -0.5887462679710908, -0.7662301779703237}, \
{-0.25742794393320745`, -0.6838119456672074, -0.6827386591113392}, {
      0.0015707956808306586`, -0.7076610503645018, -0.7065503311144502}, {
      0.0015707956808306586`, -0.6092797954620206, -0.792953758703928}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.7076610503645019, -0.7065503311144501}, \
{-0.25742794393320745`, -0.6838119456672075, -0.6827386591113391}, \
{-0.25742794393320745`, -0.7671540327667602, -0.5875419505805676}, {
      0.0015707956808306586`, -0.79390983450777, -0.6080334754540858}, {
      0.0015707956808306586`, -0.7076610503645019, -0.7065503311144501}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.7939098345077698, -0.608033475454086}, \
{-0.25742794393320745`, -0.76715403276676, -0.5875419505805678}, \
{-0.25742794393320745`, -0.8373436736979656, -0.48227214910288607`}, {
      0.0015707956808306586`, -0.8665474585516432, -0.49909221059701714`}, {
      0.0015707956808306586`, -0.7939098345077698, -0.608033475454086}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.8665474585516432, -0.49909221059701714`}, \
{-0.25742794393320745`, -0.8373436736979656, -0.48227214910288607`}, \
{-0.25742794393320745`, -0.8931775045541079, -0.3687340492018845}, {
      0.0015707956808306586`, -0.9243285892263635, -0.38159427634560983`}, {
      0.0015707956808306586`, -0.8665474585516432, -0.49909221059701714`}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.9243285892263635, -0.38159427634560983`}, \
{-0.25742794393320745`, -0.8931775045541079, -0.3687340492018845}, \
{-0.25742794393320745`, -0.933698284125023, -0.2488742009616693}, {
      0.0015707956808306586`, -0.9662625999063955, -0.25755411202903006`}, {
      0.0015707956808306586`, -0.9243285892263635, -0.38159427634560983`}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.9662625999063955, -0.25755411202903006`}, \
{-0.25742794393320745`, -0.933698284125023, -0.2488742009616693}, \
{-0.25742794393320745`, -0.9582113052864007, -0.12474753746528762`}, {
      0.0015707956808306586`, -0.9916305543748455, -0.12909832001682145`}, {
      0.0015707956808306586`, -0.9662625999063955, -0.25755411202903006`}}], 
     Polygon3DBox[{{
      0.0015707956808306586`, -0.9916305543748455, -0.12909832001682145`}, \
{-0.25742794393320745`, -0.9582113052864007, -0.12474753746528762`}, \
{-0.25742794393320745`, -0.9662963053824021, 0.001517855935476677}, {
      0.0015707956808306586`, -0.999997532600929, 0.0015707937429396226`}, {
      0.0015707956808306586`, -0.9916305543748455, -0.12909832001682145`}}], 
     Polygon3DBox[{{-0.25742794393320745`, 0.9662963053824021, 
      0.001517855935476677}, {-0.4988659473529074, 0.8666780908892273, 
      0.0013613758813692408`}, {-0.4988659473529074, 
      0.8594265962814024, -0.11188696159897044`}, {-0.25742794393320745`, 
      0.9582113052864007, -0.12474753746528762`}, {-0.25742794393320745`, 
      0.9662963053824021, 0.001517855935476677}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.9582113052864007, -0.12474753746528762`}, {-0.4988659473529074, 
      0.8594265962814024, -0.11188696159897044`}, {-0.4988659473529074, 
      0.8374406916849207, -0.2232170568795487}, {-0.25742794393320745`, 
      0.933698284125023, -0.2488742009616693}, {-0.25742794393320745`, 
      0.9582113052864007, -0.12474753746528762`}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.933698284125023, -0.24887420096166907`}, {-0.4988659473529074, 
      0.8374406916849207, -0.22321705687954854`}, {-0.4988659473529074, 
      0.8010973136918051, -0.3307202149362202}, {-0.25742794393320745`, 
      0.893177504554108, -0.36873404920188435`}, {-0.25742794393320745`, 
      0.933698284125023, -0.24887420096166907`}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.893177504554108, -0.36873404920188435`}, {-0.4988659473529074, 
      0.8010973136918051, -0.3307202149362202}, {-0.4988659473529074, 
      0.7510195501073903, -0.4325533515396445}, {-0.25742794393320745`, 
      0.8373436736979657, -0.48227214910288585`}, {-0.25742794393320745`, 
      0.893177504554108, -0.36873404920188435`}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.8373436736979658, -0.4822721491028857}, {-0.4988659473529074, 
      0.7510195501073904, -0.4325533515396444}, {-0.4988659473529074, 
      0.6880659574426807, -0.5269705919500378}, {-0.25742794393320745`, 
      0.7671540327667603, -0.5875419505805674}, {-0.25742794393320745`, 
      0.8373436736979658, -0.4822721491028857}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.7671540327667602, -0.5875419505805675}, {-0.4988659473529074, 
      0.6880659574426806, -0.5269705919500378}, {-0.4988659473529074, 
      0.6133158414215092, -0.6123532030071471}, {-0.25742794393320745`, 
      0.6838119456672076, -0.682738659111339}, {-0.25742794393320745`, 
      0.7671540327667602, -0.5875419505805675}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.6838119456672075, -0.6827386591113391}, {-0.4988659473529074, 
      0.6133158414215091, -0.6123532030071472}, {-0.4988659473529074, 
      0.5280507528603401, -0.687237345445745}, {-0.25742794393320745`, 
      0.5887462679710909, -0.7662301779703237}, {-0.25742794393320745`, 
      0.6838119456672075, -0.6827386591113391}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.5887462679710909, -0.7662301779703237}, {-0.4988659473529074, 
      0.5280507528603401, -0.687237345445745}, {-0.4988659473529074, 
      0.4337325161639746, -0.7503391706380212}, {-0.25742794393320745`, 
      0.4835868499496082, -0.8365850896580315}, {-0.25742794393320745`, 
      0.5887462679710909, -0.7662301779703237}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.4835868499496082, -0.8365850896580315}, {-0.4988659473529074, 
      0.4337325161639746, -0.7503391706380212}, {-0.4988659473529074, 
      0.3319781671268653, -0.8005768314926265}, {-0.25742794393320745`, 
      0.37013659366094737`, -0.8925971967888944}, {-0.25742794393320745`, 
      0.4835868499496082, -0.8365850896580315}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.37013659366094726`, -0.8925971967888944}, {-0.4988659473529074, 
      0.3319781671268652, -0.8005768314926265}, {-0.4988659473529074, 
      0.22453222971804992`, -0.837089030145257}, {-0.25742794393320745`, 
      0.2503405431573963, -0.9333062017012322}, {-0.25742794393320745`, 
      0.37013659366094726`, -0.8925971967888944}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.2503405431573964, -0.9333062017012322}, {-0.4988659473529074, 
      0.22453222971805004`, -0.837089030145257}, {-0.4988659473529074, 
      0.11323680714942269`, -0.8592497844505348}, {-0.25742794393320745`, 
      0.1262525377438808, -0.9580141702477846}, {-0.25742794393320745`, 
      0.2503405431573964, -0.9333062017012322}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0.1262525377438807, -0.9580141702477846}, {-0.4988659473529074, 
      0.11323680714942262`, -0.8592497844505348}, {-0.4988659473529074, 
      7.216553688889883*^-17, -0.8666791601115641}, {-0.25742794393320745`, 
      8.04604297774884*^-17, -0.9662974975039113}, {-0.25742794393320745`, 
      0.1262525377438807, -0.9580141702477846}}], 
     Polygon3DBox[{{-0.25742794393320745`, 
      0., -0.9662974975039113}, {-0.4988659473529074, 
      0., -0.8666791601115641}, {-0.4988659473529074, -0.11323680714942255`, \
-0.8592497844505349}, {-0.25742794393320745`, -0.12625253774388065`, \
-0.9580141702477847}, {-0.25742794393320745`, 0., -0.9662974975039113}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.1262525377438805, \
-0.9580141702477847}, {-0.4988659473529074, -0.11323680714942243`, \
-0.8592497844505349}, {-0.4988659473529074, -0.22453222971804976`, \
-0.837089030145257}, {-0.25742794393320745`, -0.25034054315739607`, \
-0.9333062017012324}, {-0.25742794393320745`, -0.1262525377438805, \
-0.9580141702477847}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.2503405431573962, \
-0.9333062017012324}, {-0.4988659473529074, -0.22453222971804984`, \
-0.837089030145257}, {-0.4988659473529074, -0.3319781671268651, \
-0.8005768314926265}, {-0.25742794393320745`, -0.37013659366094714`, \
-0.8925971967888944}, {-0.25742794393320745`, -0.2503405431573962, \
-0.9333062017012324}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.37013659366094703`, \
-0.8925971967888945}, {-0.4988659473529074, -0.331978167126865, \
-0.8005768314926266}, {-0.4988659473529074, -0.4337325161639744, \
-0.7503391706380215}, {-0.25742794393320745`, -0.483586849949608, \
-0.8365850896580317}, {-0.25742794393320745`, -0.37013659366094703`, \
-0.8925971967888945}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.483586849949608, \
-0.8365850896580316}, {-0.4988659473529074, -0.4337325161639744, \
-0.7503391706380214}, {-0.4988659473529074, -0.5280507528603399, \
-0.6872373454457451}, {-0.25742794393320745`, -0.5887462679710906, \
-0.7662301779703238}, {-0.25742794393320745`, -0.483586849949608, \
-0.8365850896580316}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.5887462679710908, \
-0.7662301779703237}, {-0.4988659473529074, -0.52805075286034, \
-0.687237345445745}, {-0.4988659473529074, -0.613315841421509, \
-0.6123532030071474}, {-0.25742794393320745`, -0.6838119456672074, \
-0.6827386591113392}, {-0.25742794393320745`, -0.5887462679710908, \
-0.7662301779703237}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.6838119456672075, \
-0.6827386591113391}, {-0.4988659473529074, -0.6133158414215091, \
-0.6123532030071472}, {-0.4988659473529074, -0.6880659574426806, \
-0.5269705919500379}, {-0.25742794393320745`, -0.7671540327667602, \
-0.5875419505805676}, {-0.25742794393320745`, -0.6838119456672075, \
-0.6827386591113391}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.76715403276676, \
-0.5875419505805678}, {-0.4988659473529074, -0.6880659574426805, \
-0.5269705919500381}, {-0.4988659473529074, -0.7510195501073902, \
-0.43255335153964475`}, {-0.25742794393320745`, -0.8373436736979656, \
-0.48227214910288607`}, {-0.25742794393320745`, -0.76715403276676, \
-0.5875419505805678}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.8373436736979656, \
-0.48227214910288607`}, {-0.4988659473529074, -0.7510195501073902, \
-0.43255335153964475`}, {-0.4988659473529074, -0.801097313691805, \
-0.33072021493622045`}, {-0.25742794393320745`, -0.8931775045541079, \
-0.3687340492018845}, {-0.25742794393320745`, -0.8373436736979656, \
-0.48227214910288607`}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.8931775045541079, \
-0.3687340492018845}, {-0.4988659473529074, -0.801097313691805, \
-0.33072021493622045`}, {-0.4988659473529074, -0.8374406916849207, \
-0.2232170568795487}, {-0.25742794393320745`, -0.933698284125023, \
-0.2488742009616693}, {-0.25742794393320745`, -0.8931775045541079, \
-0.3687340492018845}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.933698284125023, \
-0.2488742009616693}, {-0.4988659473529074, -0.8374406916849207, \
-0.2232170568795487}, {-0.4988659473529074, -0.8594265962814024, \
-0.11188696159897044`}, {-0.25742794393320745`, -0.9582113052864007, \
-0.12474753746528762`}, {-0.25742794393320745`, -0.933698284125023, \
-0.2488742009616693}}], 
     Polygon3DBox[{{-0.25742794393320745`, -0.9582113052864007, \
-0.12474753746528762`}, {-0.4988659473529074, -0.8594265962814024, \
-0.11188696159897044`}, {-0.4988659473529074, -0.8666780908892273, 
      0.0013613758813692408`}, {-0.25742794393320745`, -0.9662963053824021, 
      0.001517855935476677}, {-0.25742794393320745`, -0.9582113052864007, \
-0.12474753746528762`}}], 
     Polygon3DBox[{{-0.4988659473529074, 0.8666780908892273, 
      0.0013613758813692408`}, {-0.7062732501270085, 0.7079384574584596, 
      0.001112028043179037}, {-0.7062732501270085, 
      0.7020151371843025, -0.091393891038389}, {-0.4988659473529074, 
      0.8594265962814024, -0.11188696159897044`}, {-0.4988659473529074, 
      0.8666780908892273, 0.0013613758813692408`}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.8594265962814024, -0.11188696159897044`}, {-0.7062732501270085, 
      0.7020151371843025, -0.091393891038389}, {-0.7062732501270085, 
      0.6840561423170244, -0.18233291066996923`}, {-0.4988659473529074, 
      0.8374406916849207, -0.2232170568795487}, {-0.4988659473529074, 
      0.8594265962814024, -0.11188696159897044`}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.8374406916849207, -0.22321705687954854`}, {-0.7062732501270085, 
      0.6840561423170244, -0.1823329106699691}, {-0.7062732501270085, 
      0.6543693702320422, -0.27014592992890457`}, {-0.4988659473529074, 
      0.8010973136918051, -0.3307202149362202}, {-0.4988659473529074, 
      0.8374406916849207, -0.22321705687954854`}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.8010973136918051, -0.3307202149362202}, {-0.7062732501270085, 
      0.6543693702320422, -0.27014592992890457`}, {-0.7062732501270085, 
      0.6134637847815715, -0.3533274414993857}, {-0.4988659473529074, 
      0.7510195501073903, -0.4325533515396445}, {-0.4988659473529074, 
      0.8010973136918051, -0.3307202149362202}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.7510195501073904, -0.4325533515396444}, {-0.7062732501270085, 
      0.6134637847815716, -0.3533274414993856}, {-0.7062732501270085, 
      0.562040690381209, -0.43045134279131486`}, {-0.4988659473529074, 
      0.6880659574426807, -0.5269705919500378}, {-0.4988659473529074, 
      0.7510195501073904, -0.4325533515396444}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.6880659574426806, -0.5269705919500378}, {-0.7062732501270085, 
      0.562040690381209, -0.4304513427913149}, {-0.7062732501270085, 
      0.500981708520281, -0.5001953857075576}, {-0.4988659473529074, 
      0.6133158414215092, -0.6123532030071471}, {-0.4988659473529074, 
      0.6880659574426806, -0.5269705919500378}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.6133158414215091, -0.6123532030071472}, {-0.7062732501270085, 
      0.5009817085202809, -0.5001953857075576}, {-0.7062732501270085, 
      0.4313336628322677, -0.5613638458813782}, {-0.4988659473529074, 
      0.5280507528603401, -0.687237345445745}, {-0.4988659473529074, 
      0.6133158414215091, -0.6123532030071472}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.5280507528603401, -0.687237345445745}, {-0.7062732501270085, 
      0.4313336628322677, -0.5613638458813782}, {-0.7062732501270085, 
      0.3542906318626974, -0.6129080227320921}, {-0.4988659473529074, 
      0.4337325161639746, -0.7503391706380212}, {-0.4988659473529074, 
      0.5280507528603401, -0.687237345445745}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.4337325161639746, -0.7503391706380212}, {-0.7062732501270085, 
      0.3542906318626974, -0.6129080227320921}, {-0.7062732501270085, 
      0.2711734772302192, -0.6539442188764298}, {-0.4988659473529074, 
      0.3319781671268653, -0.8005768314926265}, {-0.4988659473529074, 
      0.4337325161639746, -0.7503391706380212}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.3319781671268652, -0.8005768314926265}, {-0.7062732501270085, 
      0.2711734772302191, -0.6539442188764298}, {-0.7062732501270085, 
      0.18340719815960052`, -0.6837688906482051}, {-0.4988659473529074, 
      0.22453222971804992`, -0.837089030145257}, {-0.4988659473529074, 
      0.3319781671268652, -0.8005768314926265}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.22453222971805004`, -0.837089030145257}, {-0.7062732501270085, 
      0.1834071981596006, -0.6837688906482051}, {-0.7062732501270085, 
      0.09249650063108548, -0.7018707099787223}, {-0.4988659473529074, 
      0.11323680714942269`, -0.8592497844505348}, {-0.4988659473529074, 
      0.22453222971805004`, -0.837089030145257}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0.11323680714942262`, -0.8592497844505348}, {-0.7062732501270085, 
      0.09249650063108542, -0.7018707099787223}, {-0.7062732501270085, 
      5.8947790885507*^-17, -0.707939330843422}, {-0.4988659473529074, 
      7.216553688889883*^-17, -0.8666791601115641}, {-0.4988659473529074, 
      0.11323680714942262`, -0.8592497844505348}}], 
     Polygon3DBox[{{-0.4988659473529074, 
      0., -0.8666791601115641}, {-0.7062732501270085, 
      0., -0.707939330843422}, {-0.7062732501270085, -0.09249650063108536, \
-0.7018707099787224}, {-0.4988659473529074, -0.11323680714942255`, \
-0.8592497844505349}, {-0.4988659473529074, 0., -0.8666791601115641}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.11323680714942243`, \
-0.8592497844505349}, {-0.7062732501270085, -0.09249650063108526, \
-0.7018707099787224}, {-0.7062732501270085, -0.18340719815960035`, \
-0.6837688906482052}, {-0.4988659473529074, -0.22453222971804976`, \
-0.837089030145257}, {-0.4988659473529074, -0.11323680714942243`, \
-0.8592497844505349}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.22453222971804984`, \
-0.837089030145257}, {-0.7062732501270085, -0.18340719815960044`, \
-0.6837688906482052}, {-0.7062732501270085, -0.27117347723021906`, \
-0.6539442188764298}, {-0.4988659473529074, -0.3319781671268651, \
-0.8005768314926265}, {-0.4988659473529074, -0.22453222971804984`, \
-0.837089030145257}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.331978167126865, \
-0.8005768314926266}, {-0.7062732501270085, -0.27117347723021895`, \
-0.6539442188764298}, {-0.7062732501270085, -0.3542906318626972, \
-0.6129080227320922}, {-0.4988659473529074, -0.4337325161639744, \
-0.7503391706380215}, {-0.4988659473529074, -0.331978167126865, \
-0.8005768314926266}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.4337325161639744, \
-0.7503391706380214}, {-0.7062732501270085, -0.3542906318626972, \
-0.6129080227320922}, {-0.7062732501270085, -0.43133366283226754`, \
-0.5613638458813783}, {-0.4988659473529074, -0.5280507528603399, \
-0.6872373454457451}, {-0.4988659473529074, -0.4337325161639744, \
-0.7503391706380214}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.52805075286034, \
-0.687237345445745}, {-0.7062732501270085, -0.43133366283226765`, \
-0.5613638458813782}, {-0.7062732501270085, -0.5009817085202808, \
-0.5001953857075577}, {-0.4988659473529074, -0.613315841421509, \
-0.6123532030071474}, {-0.4988659473529074, -0.52805075286034, \
-0.687237345445745}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.6133158414215091, \
-0.6123532030071472}, {-0.7062732501270085, -0.5009817085202809, \
-0.5001953857075576}, {-0.7062732501270085, -0.562040690381209, \
-0.430451342791315}, {-0.4988659473529074, -0.6880659574426806, \
-0.5269705919500379}, {-0.4988659473529074, -0.6133158414215091, \
-0.6123532030071472}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.6880659574426805, \
-0.5269705919500381}, {-0.7062732501270085, -0.5620406903812087, \
-0.43045134279131514`}, {-0.7062732501270085, -0.6134637847815714, \
-0.3533274414993859}, {-0.4988659473529074, -0.7510195501073902, \
-0.43255335153964475`}, {-0.4988659473529074, -0.6880659574426805, \
-0.5269705919500381}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.7510195501073902, \
-0.43255335153964475`}, {-0.7062732501270085, -0.6134637847815714, \
-0.3533274414993859}, {-0.7062732501270085, -0.6543693702320421, \
-0.2701459299289047}, {-0.4988659473529074, -0.801097313691805, \
-0.33072021493622045`}, {-0.4988659473529074, -0.7510195501073902, \
-0.43255335153964475`}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.801097313691805, \
-0.33072021493622045`}, {-0.7062732501270085, -0.6543693702320421, \
-0.2701459299289047}, {-0.7062732501270085, -0.6840561423170244, \
-0.18233291066996923`}, {-0.4988659473529074, -0.8374406916849207, \
-0.2232170568795487}, {-0.4988659473529074, -0.801097313691805, \
-0.33072021493622045`}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.8374406916849207, \
-0.2232170568795487}, {-0.7062732501270085, -0.6840561423170244, \
-0.18233291066996923`}, {-0.7062732501270085, -0.7020151371843025, \
-0.091393891038389}, {-0.4988659473529074, -0.8594265962814024, \
-0.11188696159897044`}, {-0.4988659473529074, -0.8374406916849207, \
-0.2232170568795487}}], 
     Polygon3DBox[{{-0.4988659473529074, -0.8594265962814024, \
-0.11188696159897044`}, {-0.7062732501270085, -0.7020151371843025, \
-0.091393891038389}, {-0.7062732501270085, -0.7079384574584596, 
      0.001112028043179037}, {-0.4988659473529074, -0.8666780908892273, 
      0.0013613758813692408`}, {-0.4988659473529074, -0.8594265962814024, \
-0.11188696159897044`}}], 
     Polygon3DBox[{{-0.7062732501270088, 0.7079384574584593, 
      0.0011120280431790367`}, {-0.8655013302530191, 0.5009060073920574, 
      0.0007868219636160942}, {-0.8655013302530191, 
      0.49671492739382667`, -0.06466628359817624}, {-0.7062732501270088, 
      0.7020151371843022, -0.09139389103838896}, {-0.7062732501270088, 
      0.7079384574584593, 0.0011120280431790367`}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.7020151371843022, -0.09139389103838896}, {-0.8655013302530191, 
      0.49671492739382667`, -0.06466628359817624}, {-0.8655013302530191, 
      0.48400793525211133`, -0.12901072026479946`}, {-0.7062732501270088, 
      0.684056142317024, -0.18233291066996915`}, {-0.7062732501270088, 
      0.7020151371843022, -0.09139389103838896}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.684056142317024, -0.18233291066996898`}, {-0.8655013302530191, 
      0.48400793525211133`, -0.12901072026479932`}, {-0.8655013302530191, 
      0.46300288556060054`, -0.19114333703483294`}, {-0.7062732501270088, 
      0.6543693702320419, -0.2701459299289044}, {-0.7062732501270088, 
      0.684056142317024, -0.18233291066996898`}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.6543693702320419, -0.2701459299289044}, {-0.8655013302530191, 
      0.46300288556060054`, -0.19114333703483294`}, {-0.8655013302530191, 
      0.43405989867782874`, -0.24999890337768957`}, {-0.7062732501270088, 
      0.6134637847815712, -0.35332744149938555`}, {-0.7062732501270088, 
      0.6543693702320419, -0.2701459299289044}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.6134637847815713, -0.35332744149938544`}, {-0.8655013302530191, 
      0.4340598986778288, -0.24999890337768949`}, {-0.8655013302530191, 
      0.39767518665596224`, -0.30456837204214077`}, {-0.7062732501270088, 
      0.5620406903812087, -0.43045134279131464`}, {-0.7062732501270088, 
      0.6134637847815713, -0.35332744149938544`}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.5620406903812086, -0.4304513427913147}, {-0.8655013302530191, 
      0.3976751866559622, -0.3045683720421408}, {-0.8655013302530191, 
      0.35447254595018285`, -0.3539161786325256}, {-0.7062732501270088, 
      0.5009817085202808, -0.5001953857075574}, {-0.7062732501270088, 
      0.5620406903812086, -0.4304513427913147}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.5009817085202807, -0.5001953857075574}, {-0.8655013302530191, 
      0.3544725459501828, -0.35391617863252567`}, {-0.8655013302530191, 
      0.30519266276162277`, -0.3971962813606451}, {-0.7062732501270088, 
      0.4313336628322675, -0.561363845881378}, {-0.7062732501270088, 
      0.5009817085202807, -0.5001953857075574}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.4313336628322675, -0.561363845881378}, {-0.8655013302530191, 
      0.30519266276162277`, -0.3971962813606451}, {-0.8655013302530191, 
      0.2506804143680333, -0.43366666598036496`}, {-0.7062732501270088, 
      0.3542906318626972, -0.6129080227320918}, {-0.7062732501270088, 
      0.4313336628322675, -0.561363845881378}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.3542906318626972, -0.6129080227320918}, {-0.8655013302530191, 
      0.2506804143680333, -0.43366666598036496`}, {-0.8655013302530191, 
      0.19187038415409216`, -0.4627020672255695}, {-0.7062732501270088, 
      0.27117347723021906`, -0.6539442188764295}, {-0.7062732501270088, 
      0.3542906318626972, -0.6129080227320918}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.271173477230219, -0.6539442188764295}, {-0.8655013302530191, 
      0.1918703841540921, -0.4627020672255695}, {-0.8655013302530191, 
      0.12977083867841735`, -0.4838046886492053}, {-0.7062732501270088, 
      0.18340719815960044`, -0.6837688906482048}, {-0.7062732501270088, 
      0.271173477230219, -0.6539442188764295}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.18340719815960052`, -0.6837688906482048}, {-0.8655013302530191, 
      0.1297708386784174, -0.4838046886492053}, {-0.8655013302530191, 
      0.0654464414819174, -0.49661273707750214`}, {-0.7062732501270088, 
      0.09249650063108544, -0.7018707099787219}, {-0.7062732501270088, 
      0.18340719815960052`, -0.6837688906482048}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0.09249650063108537, -0.7018707099787219}, {-0.8655013302530191, 
      0.06544644148191736, -0.49661273707750214`}, {-0.8655013302530191, 
      4.170885514970604*^-17, -0.5009066253607096}, {-0.7062732501270088, 
      5.894779088550697*^-17, -0.7079393308434216}, {-0.7062732501270088, 
      0.09249650063108537, -0.7018707099787219}}], 
     Polygon3DBox[{{-0.7062732501270088, 
      0., -0.7079393308434216}, {-0.8655013302530191, 
      0., -0.5009066253607096}, {-0.8655013302530191, -0.06544644148191732, \
-0.4966127370775022}, {-0.7062732501270088, -0.09249650063108532, \
-0.701870709978722}, {-0.7062732501270088, 0., -0.7079393308434216}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.09249650063108522, \
-0.701870709978722}, {-0.8655013302530191, -0.06544644148191725, \
-0.4966127370775022}, {-0.8655013302530191, -0.12977083867841724`, \
-0.48380468864920534`}, {-0.7062732501270088, -0.18340719815960027`, \
-0.6837688906482049}, {-0.7062732501270088, -0.09249650063108522, \
-0.701870709978722}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.18340719815960035`, \
-0.6837688906482049}, {-0.8655013302530191, -0.1297708386784173, \
-0.48380468864920534`}, {-0.8655013302530191, -0.19187038415409205`, \
-0.4627020672255695}, {-0.7062732501270088, -0.2711734772302189, \
-0.6539442188764295}, {-0.7062732501270088, -0.18340719815960035`, \
-0.6837688906482049}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.27117347723021884`, \
-0.6539442188764296}, {-0.8655013302530191, -0.191870384154092, \
-0.46270206722556956`}, {-0.8655013302530191, -0.2506804143680332, \
-0.4336666659803651}, {-0.7062732501270088, -0.35429063186269705`, \
-0.612908022732092}, {-0.7062732501270088, -0.27117347723021884`, \
-0.6539442188764296}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.35429063186269705`, \
-0.6129080227320919}, {-0.8655013302530191, -0.2506804143680332, \
-0.433666665980365}, {-0.8655013302530191, -0.30519266276162266`, \
-0.39719628136064516`}, {-0.7062732501270088, -0.4313336628322673, \
-0.561363845881378}, {-0.7062732501270088, -0.35429063186269705`, \
-0.6129080227320919}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.43133366283226743`, \
-0.561363845881378}, {-0.8655013302530191, -0.3051926627616227, \
-0.3971962813606451}, {-0.8655013302530191, -0.35447254595018274`, \
-0.3539161786325257}, {-0.7062732501270088, -0.5009817085202806, \
-0.5001953857075575}, {-0.7062732501270088, -0.43133366283226743`, \
-0.561363845881378}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.5009817085202807, \
-0.5001953857075574}, {-0.8655013302530191, -0.3544725459501828, \
-0.35391617863252567`}, {-0.8655013302530191, -0.3976751866559622, \
-0.3045683720421409}, {-0.7062732501270088, -0.5620406903812086, \
-0.4304513427913148}, {-0.7062732501270088, -0.5009817085202807, \
-0.5001953857075574}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.5620406903812085, \
-0.430451342791315}, {-0.8655013302530191, -0.3976751866559621, \
-0.304568372042141}, {-0.8655013302530191, -0.4340598986778287, \
-0.24999890337768968`}, {-0.7062732501270088, -0.6134637847815712, \
-0.3533274414993857}, {-0.7062732501270088, -0.5620406903812085, \
-0.430451342791315}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.6134637847815712, \
-0.3533274414993857}, {-0.8655013302530191, -0.4340598986778287, \
-0.24999890337768968`}, {-0.8655013302530191, -0.4630028855606005, \
-0.19114333703483305`}, {-0.7062732501270088, -0.6543693702320418, \
-0.27014592992890457`}, {-0.7062732501270088, -0.6134637847815712, \
-0.3533274414993857}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.6543693702320418, \
-0.27014592992890457`}, {-0.8655013302530191, -0.4630028855606005, \
-0.19114333703483305`}, {-0.8655013302530191, -0.48400793525211133`, \
-0.12901072026479946`}, {-0.7062732501270088, -0.684056142317024, \
-0.18233291066996915`}, {-0.7062732501270088, -0.6543693702320418, \
-0.27014592992890457`}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.684056142317024, \
-0.18233291066996915`}, {-0.8655013302530191, -0.48400793525211133`, \
-0.12901072026479946`}, {-0.8655013302530191, -0.49671492739382667`, \
-0.06466628359817624}, {-0.7062732501270088, -0.7020151371843022, \
-0.09139389103838896}, {-0.7062732501270088, -0.684056142317024, \
-0.18233291066996915`}}], 
     Polygon3DBox[{{-0.7062732501270088, -0.7020151371843022, \
-0.09139389103838896}, {-0.8655013302530191, -0.49671492739382667`, \
-0.06466628359817624}, {-0.8655013302530191, -0.5009060073920574, 
      0.0007868219636160942}, {-0.7062732501270088, -0.7079384574584593, 
      0.0011120280431790367`}, {-0.7062732501270088, -0.7020151371843022, \
-0.09139389103838896}}], 
     Polygon3DBox[{{-0.8655013302530191, 0.5009060073920574, 
      0.0007868219636160942}, {-0.9656882654893142, 0.2597036916942328, 
      0.00040794194048718665`}, {-0.9656882654893142, 
      0.25753075119908225`, -0.033527393025350405`}, {-0.8655013302530191, 
      0.49671492739382667`, -0.06466628359817624}, {-0.8655013302530191, 
      0.5009060073920574, 0.0007868219636160942}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.49671492739382667`, -0.06466628359817624}, {-0.9656882654893142, 
      0.25753075119908225`, -0.033527393025350405`}, {-0.9656882654893142, 
      0.2509425835172558, -0.06688791874415768}, {-0.8655013302530191, 
      0.48400793525211133`, -0.12901072026479946`}, {-0.8655013302530191, 
      0.49671492739382667`, -0.06466628359817624}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.48400793525211133`, -0.12901072026479932`}, {-0.9656882654893142, 
      0.2509425835172558, -0.06688791874415763}, {-0.9656882654893142, 
      0.2400521392650341, -0.09910168681975405}, {-0.8655013302530191, 
      0.46300288556060054`, -0.19114333703483294`}, {-0.8655013302530191, 
      0.48400793525211133`, -0.12901072026479932`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.46300288556060054`, -0.19114333703483294`}, {-0.9656882654893142, 
      0.2400521392650341, -0.09910168681975405}, {-0.9656882654893142, 
      0.2250461292927273, -0.12961640940328895`}, {-0.8655013302530191, 
      0.43405989867782874`, -0.24999890337768957`}, {-0.8655013302530191, 
      0.46300288556060054`, -0.19114333703483294`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.4340598986778288, -0.24999890337768949`}, {-0.9656882654893142, 
      0.22504612929272733`, -0.1296164094032889}, {-0.9656882654893142, 
      0.20618182362686538`, -0.15790892787344266`}, {-0.8655013302530191, 
      0.39767518665596224`, -0.30456837204214077`}, {-0.8655013302530191, 
      0.4340598986778288, -0.24999890337768949`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.3976751866559622, -0.3045683720421408}, {-0.9656882654893142, 
      0.20618182362686535`, -0.15790892787344268`}, {-0.9656882654893142, 
      0.18378264071299652`, -0.1834941821115797}, {-0.8655013302530191, 
      0.35447254595018285`, -0.3539161786325256}, {-0.8655013302530191, 
      0.3976751866559622, -0.3045683720421408}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.3544725459501828, -0.35391617863252567`}, {-0.9656882654893142, 
      0.1837826407129965, -0.18349418211157972`}, {-0.9656882654893142, 
      0.15823260257917046`, -0.2059335265984202}, {-0.8655013302530191, 
      0.30519266276162277`, -0.3971962813606451}, {-0.8655013302530191, 
      0.3544725459501828, -0.35391617863252567`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.30519266276162277`, -0.3971962813606451}, {-0.9656882654893142, 
      0.15823260257917046`, -0.2059335265984202}, {-0.9656882654893142, 
      0.1299697509833669, -0.22484225075719538`}, {-0.8655013302530191, 
      0.2506804143680333, -0.43366666598036496`}, {-0.8655013302530191, 
      0.30519266276162277`, -0.3971962813606451}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.2506804143680333, -0.43366666598036496`}, {-0.9656882654893142, 
      0.1299697509833669, -0.22484225075719538`}, {-0.9656882654893142, 
      0.09947863742150537, -0.2398961746110192}, {-0.8655013302530191, 
      0.19187038415409216`, -0.4627020672255695}, {-0.8655013302530191, 
      0.2506804143680333, -0.43366666598036496`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.1918703841540921, -0.4627020672255695}, {-0.9656882654893142, 
      0.09947863742150534, -0.2398961746110192}, {-0.9656882654893142, 
      0.06728201575083788, -0.250837206675453}, {-0.8655013302530191, 
      0.12977083867841735`, -0.4838046886492053}, {-0.8655013302530191, 
      0.1918703841540921, -0.4627020672255695}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.1297708386784174, -0.4838046886492053}, {-0.9656882654893142, 
      0.0672820157508379, -0.250837206675453}, {-0.9656882654893142, 
      0.03393187985426032, -0.25747776879916445`}, {-0.8655013302530191, 
      0.0654464414819174, -0.49661273707750214`}, {-0.8655013302530191, 
      0.1297708386784174, -0.4838046886492053}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0.06544644148191736, -0.49661273707750214`}, {-0.9656882654893142, 
      0.0339318798542603, -0.25747776879916445`}, {-0.9656882654893142, 
      2.1624703035834317`*^-17, -0.2597040120911495}, {-0.8655013302530191, 
      4.170885514970604*^-17, -0.5009066253607096}, {-0.8655013302530191, 
      0.06544644148191736, -0.49661273707750214`}}], 
     Polygon3DBox[{{-0.8655013302530191, 
      0., -0.5009066253607096}, {-0.9656882654893142, 
      0., -0.2597040120911495}, {-0.9656882654893142, -0.03393187985426028, \
-0.25747776879916445`}, {-0.8655013302530191, -0.06544644148191732, \
-0.4966127370775022}, {-0.8655013302530191, 0., -0.5009066253607096}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.06544644148191725, \
-0.4966127370775022}, {-0.9656882654893142, -0.033931879854260244`, \
-0.25747776879916445`}, {-0.9656882654893142, -0.06728201575083782, \
-0.25083720667545306`}, {-0.8655013302530191, -0.12977083867841724`, \
-0.48380468864920534`}, {-0.8655013302530191, -0.06544644148191725, \
-0.4966127370775022}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.1297708386784173, \
-0.48380468864920534`}, {-0.9656882654893142, -0.06728201575083785, \
-0.25083720667545306`}, {-0.9656882654893142, -0.09947863742150531, \
-0.2398961746110192}, {-0.8655013302530191, -0.19187038415409205`, \
-0.4627020672255695}, {-0.8655013302530191, -0.1297708386784173, \
-0.48380468864920534`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.191870384154092, \
-0.46270206722556956`}, {-0.9656882654893142, -0.09947863742150528, \
-0.23989617461101923`}, {-0.9656882654893142, -0.12996975098336686`, \
-0.22484225075719544`}, {-0.8655013302530191, -0.2506804143680332, \
-0.4336666659803651}, {-0.8655013302530191, -0.191870384154092, \
-0.46270206722556956`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.2506804143680332, \
-0.433666665980365}, {-0.9656882654893142, -0.12996975098336686`, \
-0.2248422507571954}, {-0.9656882654893142, -0.1582326025791704, \
-0.20593352659842024`}, {-0.8655013302530191, -0.30519266276162266`, \
-0.39719628136064516`}, {-0.8655013302530191, -0.2506804143680332, \
-0.433666665980365}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.3051926627616227, \
-0.3971962813606451}, {-0.9656882654893142, -0.15823260257917043`, \
-0.2059335265984202}, {-0.9656882654893142, -0.18378264071299646`, \
-0.18349418211157975`}, {-0.8655013302530191, -0.35447254595018274`, \
-0.3539161786325257}, {-0.8655013302530191, -0.3051926627616227, \
-0.3971962813606451}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.3544725459501828, \
-0.35391617863252567`}, {-0.9656882654893142, -0.1837826407129965, \
-0.18349418211157972`}, {-0.9656882654893142, -0.20618182362686535`, \
-0.1579089278734427}, {-0.8655013302530191, -0.3976751866559622, \
-0.3045683720421409}, {-0.8655013302530191, -0.3544725459501828, \
-0.35391617863252567`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.3976751866559621, \
-0.304568372042141}, {-0.9656882654893142, -0.2061818236268653, \
-0.15790892787344277`}, {-0.9656882654893142, -0.22504612929272727`, \
-0.129616409403289}, {-0.8655013302530191, -0.4340598986778287, \
-0.24999890337768968`}, {-0.8655013302530191, -0.3976751866559621, \
-0.304568372042141}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.4340598986778287, \
-0.24999890337768968`}, {-0.9656882654893142, -0.22504612929272727`, \
-0.129616409403289}, {-0.9656882654893142, -0.24005213926503408`, \
-0.0991016868197541}, {-0.8655013302530191, -0.4630028855606005, \
-0.19114333703483305`}, {-0.8655013302530191, -0.4340598986778287, \
-0.24999890337768968`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.4630028855606005, \
-0.19114333703483305`}, {-0.9656882654893142, -0.24005213926503408`, \
-0.0991016868197541}, {-0.9656882654893142, -0.2509425835172558, \
-0.06688791874415768}, {-0.8655013302530191, -0.48400793525211133`, \
-0.12901072026479946`}, {-0.8655013302530191, -0.4630028855606005, \
-0.19114333703483305`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.48400793525211133`, \
-0.12901072026479946`}, {-0.9656882654893142, -0.2509425835172558, \
-0.06688791874415768}, {-0.9656882654893142, -0.25753075119908225`, \
-0.033527393025350405`}, {-0.8655013302530191, -0.49671492739382667`, \
-0.06466628359817624}, {-0.8655013302530191, -0.48400793525211133`, \
-0.12901072026479946`}}], 
     Polygon3DBox[{{-0.8655013302530191, -0.49671492739382667`, \
-0.06466628359817624}, {-0.9656882654893142, -0.25753075119908225`, \
-0.033527393025350405`}, {-0.9656882654893142, -0.2597036916942328, 
      0.00040794194048718665`}, {-0.8655013302530191, -0.5009060073920574, 
      0.0007868219636160942}, {-0.8655013302530191, -0.49671492739382667`, \
-0.06466628359817624}}], 
     Polygon3DBox[{{-0.9656882654893142, 0.2597036916942328, 
      0.00040794194048718665`}, {-0.9999996915748783, 0.0007853971137059811, 
      1.233699915962221*^-6}, {-0.9999996915748783, 
      0.0007788256969424667, -0.00010139369810421916`}, {-0.9656882654893142, 
      0.25753075119908225`, -0.033527393025350405`}, {-0.9656882654893142, 
      0.2597036916942328, 0.00040794194048718665`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.25753075119908225`, -0.033527393025350405`}, {-0.9999996915748783, 
      0.0007788256969424667, -0.00010139369810421916`}, {-0.9999996915748783, 
      0.0007589017295619427, -0.00020228275532298967`}, {-0.9656882654893142, 
      0.2509425835172558, -0.06688791874415768}, {-0.9656882654893142, 
      0.25753075119908225`, -0.033527393025350405`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.2509425835172558, -0.06688791874415763}, {-0.9999996915748783, 
      0.0007589017295619427, -0.0002022827553229895}, {-0.9999996915748783, 
      0.0007259667973441087, -0.0002997037827373994}, {-0.9656882654893142, 
      0.2400521392650341, -0.09910168681975405}, {-0.9656882654893142, 
      0.2509425835172558, -0.06688791874415763}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.2400521392650341, -0.09910168681975405}, {-0.9999996915748783, 
      0.0007259667973441087, -0.0002997037827373994}, {-0.9999996915748783, 
      0.0006805855521118729, -0.00039198654886328125`}, {-0.9656882654893142, 
      0.2250461292927273, -0.12961640940328895`}, {-0.9656882654893142, 
      0.2400521392650341, -0.09910168681975405}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.22504612929272733`, -0.1296164094032889}, {-0.9999996915748783, 
      0.000680585552111873, -0.0003919865488632811}, {-0.9999996915748783, 
      0.0006235360310774196, -0.00047754891496200444`}, {-0.9656882654893142, 
      0.20618182362686538`, -0.15790892787344266`}, {-0.9656882654893142, 
      0.22504612929272733`, -0.1296164094032889}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.20618182362686535`, -0.15790892787344268`}, {-0.9999996915748783, 
      0.0006235360310774194, -0.00047754891496200455`}, {-0.9999996915748783, 
      0.000555796317809741, -0.0005549239599641575}, {-0.9656882654893142, 
      0.18378264071299652`, -0.1834941821115797}, {-0.9656882654893142, 
      0.20618182362686535`, -0.15790892787344268`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.1837826407129965, -0.18349418211157972`}, {-0.9999996915748783, 
      0.0005557963178097409, -0.0005549239599641576}, {-0.9999996915748783, 
      0.0004785277735142254, -0.0006227851300478253}, {-0.9656882654893142, 
      0.15823260257917046`, -0.2059335265984202}, {-0.9656882654893142, 
      0.1837826407129965, -0.18349418211157972`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.15823260257917046`, -0.2059335265984202}, {-0.9999996915748783, 
      0.0004785277735142254, -0.0006227851300478253}, {-0.9999996915748783, 
      0.0003930551261150528, -0.0006799689816953773}, {-0.9656882654893142, 
      0.1299697509833669, -0.22484225075719538`}, {-0.9656882654893142, 
      0.15823260257917046`, -0.2059335265984202}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.1299697509833669, -0.22484225075719538`}, {-0.9999996915748783, 
      0.0003930551261150528, -0.0006799689816953773}, {-0.9999996915748783, 
      0.0003008437585024485, -0.0007254951283112031}, {-0.9656882654893142, 
      0.09947863742150537, -0.2398961746110192}, {-0.9656882654893142, 
      0.1299697509833669, -0.22484225075719538`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.09947863742150534, -0.2398961746110192}, {-0.9999996915748783, 
      0.0003008437585024484, -0.0007254951283112031}, {-0.9999996915748783, 
      0.00020347458532566523`, -0.000758583048426286}, {-0.9656882654893142, 
      0.06728201575083788, -0.250837206675453}, {-0.9656882654893142, 
      0.09947863742150534, -0.2398961746110192}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.0672820157508379, -0.250837206675453}, {-0.9999996915748783, 
      0.00020347458532566533`, -0.000758583048426286}, {-0.9999996915748783, 
      0.00010261694905566101`, -0.0007786654673219278}, {-0.9656882654893142, 
      0.03393187985426032, -0.25747776879916445`}, {-0.9656882654893142, 
      0.0672820157508379, -0.250837206675453}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0.0339318798542603, -0.25747776879916445`}, {-0.9999996915748783, 
      0.00010261694905566094`, -0.0007786654673219278}, {-0.9999996915748783, 
      6.539752761423838*^-20, -0.0007853980826518285}, {-0.9656882654893142, 
      2.1624703035834317`*^-17, -0.2597040120911495}, {-0.9656882654893142, 
      0.0339318798542603, -0.25747776879916445`}}], 
     Polygon3DBox[{{-0.9656882654893142, 
      0., -0.2597040120911495}, {-0.9999996915748783, 
      0., -0.0007853980826518285}, {-0.9999996915748783, \
-0.00010261694905566089`, -0.0007786654673219279}, {-0.9656882654893142, \
-0.03393187985426028, -0.25747776879916445`}, {-0.9656882654893142, 
      0., -0.2597040120911495}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.033931879854260244`, \
-0.25747776879916445`}, {-0.9999996915748783, -0.00010261694905566078`, \
-0.0007786654673219279}, {-0.9999996915748783, -0.00020347458532566506`, \
-0.000758583048426286}, {-0.9656882654893142, -0.06728201575083782, \
-0.25083720667545306`}, {-0.9656882654893142, -0.033931879854260244`, \
-0.25747776879916445`}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.06728201575083785, \
-0.25083720667545306`}, {-0.9999996915748783, -0.00020347458532566514`, \
-0.000758583048426286}, {-0.9999996915748783, -0.0003008437585024483, \
-0.0007254951283112031}, {-0.9656882654893142, -0.09947863742150531, \
-0.2398961746110192}, {-0.9656882654893142, -0.06728201575083785, \
-0.25083720667545306`}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.09947863742150528, \
-0.23989617461101923`}, {-0.9999996915748783, -0.00030084375850244826`, \
-0.0007254951283112031}, {-0.9999996915748783, -0.00039305512611505266`, \
-0.0006799689816953774}, {-0.9656882654893142, -0.12996975098336686`, \
-0.22484225075719544`}, {-0.9656882654893142, -0.09947863742150528, \
-0.23989617461101923`}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.12996975098336686`, \
-0.2248422507571954}, {-0.9999996915748783, -0.00039305512611505266`, \
-0.0006799689816953774}, {-0.9999996915748783, -0.00047852777351422524`, \
-0.0006227851300478254}, {-0.9656882654893142, -0.1582326025791704, \
-0.20593352659842024`}, {-0.9656882654893142, -0.12996975098336686`, \
-0.2248422507571954}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.15823260257917043`, \
-0.2059335265984202}, {-0.9999996915748783, -0.0004785277735142253, \
-0.0006227851300478253}, {-0.9999996915748783, -0.0005557963178097408, \
-0.0005549239599641577}, {-0.9656882654893142, -0.18378264071299646`, \
-0.18349418211157975`}, {-0.9656882654893142, -0.15823260257917043`, \
-0.2059335265984202}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.1837826407129965, \
-0.18349418211157972`}, {-0.9999996915748783, -0.0005557963178097409, \
-0.0005549239599641576}, {-0.9999996915748783, -0.0006235360310774194, \
-0.0004775489149620046}, {-0.9656882654893142, -0.20618182362686535`, \
-0.1579089278734427}, {-0.9656882654893142, -0.1837826407129965, \
-0.18349418211157972`}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.2061818236268653, \
-0.15790892787344277`}, {-0.9999996915748783, -0.0006235360310774192, \
-0.0004775489149620048}, {-0.9999996915748783, -0.0006805855521118729, \
-0.0003919865488632814}, {-0.9656882654893142, -0.22504612929272727`, \
-0.129616409403289}, {-0.9656882654893142, -0.2061818236268653, \
-0.15790892787344277`}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.22504612929272727`, \
-0.129616409403289}, {-0.9999996915748783, -0.0006805855521118729, \
-0.0003919865488632814}, {-0.9999996915748783, -0.0007259667973441086, \
-0.00029970378273739954`}, {-0.9656882654893142, -0.24005213926503408`, \
-0.0991016868197541}, {-0.9656882654893142, -0.22504612929272727`, \
-0.129616409403289}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.24005213926503408`, \
-0.0991016868197541}, {-0.9999996915748783, -0.0007259667973441086, \
-0.00029970378273739954`}, {-0.9999996915748783, -0.0007589017295619427, \
-0.00020228275532298967`}, {-0.9656882654893142, -0.2509425835172558, \
-0.06688791874415768}, {-0.9656882654893142, -0.24005213926503408`, \
-0.0991016868197541}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.2509425835172558, \
-0.06688791874415768}, {-0.9999996915748783, -0.0007589017295619427, \
-0.00020228275532298967`}, {-0.9999996915748783, -0.0007788256969424667, \
-0.00010139369810421916`}, {-0.9656882654893142, -0.25753075119908225`, \
-0.033527393025350405`}, {-0.9656882654893142, -0.2509425835172558, \
-0.06688791874415768}}], 
     Polygon3DBox[{{-0.9656882654893142, -0.25753075119908225`, \
-0.033527393025350405`}, {-0.9999996915748783, -0.0007788256969424667, \
-0.00010139369810421916`}, {-0.9999996915748783, -0.0007853971137059811, 
      1.233699915962221*^-6}, {-0.9656882654893142, -0.2597036916942328, 
      0.00040794194048718665`}, {-0.9656882654893142, -0.25753075119908225`, \
-0.033527393025350405`}}], 
     Polygon3DBox[{{-0.9999996915748783, 0.0007853971137057591, 
      1.2336999159618721`*^-6}, {-0.9660950160599018, -0.25818647421265106`, \
-0.0004055586988800313}, {-0.9660950160599018, -0.25602622827445565`, 
      0.033331522314086835`}, {-0.9999996915748783, 
      0.0007788256969422465, -0.00010139369810419049`}, {-0.9999996915748783, 
      0.0007853971137057591, 1.2336999159618721`*^-6}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0007788256969422465, -0.00010139369810419049`}, {-0.9660950160599018, \
-0.25602622827445565`, 
      0.033331522314086835`}, {-0.9660950160599018, -0.24947654939158792`, 
      0.06649715217875692}, {-0.9999996915748783, 
      0.0007589017295617282, -0.00020228275532293248`}, {-0.9999996915748783, 
      0.0007788256969422465, -0.00010139369810419049`}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0007589017295617282, -0.00020228275532293232`}, {-0.9660950160599018, \
-0.24947654939158792`, 
      0.06649715217875686}, {-0.9660950160599018, -0.23864972831042655`, 
      0.09852272388427834}, {-0.9999996915748783, 
      0.0007259667973439034, -0.00029970378273731465`}, {-0.9999996915748783, 
      0.0007589017295617282, -0.00020228275532293232`}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0007259667973439034, -0.00029970378273731465`}, {-0.9660950160599018, \
-0.23864972831042655`, 
      0.09852272388427834}, {-0.9660950160599018, -0.22373138509599388`, 
      0.12885917610805311`}, {-0.9999996915748783, 
      0.0006805855521116805, -0.00039198654886317045`}, {-0.9999996915748783, 
      0.0007259667973439034, -0.00029970378273731465`}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0006805855521116806, -0.0003919865488631703}, {-0.9660950160599018, \
-0.2237313850959939, 
      0.1288591761080531}, {-0.9660950160599018, -0.2049772867750774, 
      0.15698640657886861`}, {-0.9999996915748783, 
      0.0006235360310772433, -0.00047754891496186946`}, {-0.9999996915748783, 
      0.0006805855521116806, -0.0003919865488631703}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0006235360310772432, -0.0004775489149618695}, {-0.9660950160599018, \
-0.20497728677507737`, 
      0.15698640657886864`}, {-0.9660950160599018, -0.18270896234715597`, 
      0.18242218895256054`}, {-0.9999996915748783, 
      0.0005557963178095838, -0.0005549239599640006}, {-0.9999996915748783, 
      0.0006235360310772432, -0.0004775489149618695}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0005557963178095838, -0.0005549239599640007}, {-0.9660950160599018, \
-0.18270896234715595`, 
      0.18242218895256057`}, {-0.9660950160599018, -0.157308190341427, 
      0.20473044032513468`}, {-0.9999996915748783, 
      0.0004785277735140901, -0.0006227851300476492}, {-0.9999996915748783, 
      0.0005557963178095838, -0.0005549239599640007}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0004785277735140901, -0.0006227851300476492}, {-0.9660950160599018, \
-0.157308190341427, 
      0.20473044032513468`}, {-0.9660950160599018, -0.12921045342782442`, 
      0.22352869764125183`}, {-0.9999996915748783, 
      0.0003930551261149417, -0.0006799689816951851}, {-0.9999996915748783, 
      0.0004785277735140901, -0.0006227851300476492}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0003930551261149417, -0.0006799689816951851}, {-0.9660950160599018, \
-0.12921045342782442`, 
      0.22352869764125183`}, {-0.9660950160599018, -0.09889747229922616, 
      0.23849467481904488`}, {-0.9999996915748783, 
      0.0003008437585023634, -0.0007254951283109979}, {-0.9999996915748783, 
      0.0003930551261149417, -0.0006799689816951851}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.00030084375850236337`, -0.0007254951283109979}, {-0.9660950160599018, \
-0.09889747229922612, 
      0.23849467481904488`}, {-0.9660950160599018, -0.06688894682745339, 
      0.24937178817286504`}, {-0.9999996915748783, 
      0.0002034745853256077, -0.0007585830484260715}, {-0.9999996915748783, 
      0.00030084375850236337`, -0.0007254951283109979}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.0002034745853256078, -0.0007585830484260715}, {-0.9660950160599018, \
-0.06688894682745342, 
      0.24937178817286504`}, {-0.9660950160599018, -0.03373364608653079, 
      0.25597355540353545`}, {-0.9999996915748783, 
      0.00010261694905563201`, -0.0007786654673217077}, {-0.9999996915748783, 
      0.0002034745853256078, -0.0007585830484260715}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0.00010261694905563194`, -0.0007786654673217077}, {-0.9660950160599018, \
-0.03373364608653077, 
      0.25597355540353545`}, {-0.9660950160599018, -2.149836914636997*^-17, 
      0.2581867927377738}, {-0.9999996915748783, 
      6.539752761421989*^-20, -0.0007853980826516065}, {-0.9999996915748783, 
      0.00010261694905563194`, -0.0007786654673217077}}], 
     Polygon3DBox[{{-0.9999996915748783, 
      0., -0.0007853980826516065}, {-0.9660950160599018, 0., 
      0.2581867927377738}, {-0.9660950160599018, 0.03373364608653075, 
      0.2559735554035355}, {-0.9999996915748783, -0.00010261694905563187`, \
-0.0007786654673217078}, {-0.9999996915748783, 0., -0.0007853980826516065}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.00010261694905563177`, \
-0.0007786654673217078}, {-0.9660950160599018, 0.03373364608653071, 
      0.2559735554035355}, {-0.9660950160599018, 0.06688894682745333, 
      0.24937178817286507`}, {-0.9999996915748783, -0.00020347458532560755`, \
-0.0007585830484260716}, {-0.9999996915748783, -0.00010261694905563177`, \
-0.0007786654673217078}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.00020347458532560763`, \
-0.0007585830484260716}, {-0.9660950160599018, 0.06688894682745336, 
      0.24937178817286507`}, {-0.9660950160599018, 0.09889747229922609, 
      0.23849467481904488`}, {-0.9999996915748783, -0.00030084375850236326`, \
-0.0007254951283109979}, {-0.9999996915748783, -0.00020347458532560763`, \
-0.0007585830484260716}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0003008437585023632, \
-0.000725495128310998}, {-0.9660950160599018, 0.09889747229922606, 
      0.2384946748190449}, {-0.9660950160599018, 0.12921045342782436`, 
      0.22352869764125188`}, {-0.9999996915748783, -0.0003930551261149415, \
-0.0006799689816951852}, {-0.9999996915748783, -0.0003008437585023632, \
-0.000725495128310998}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0003930551261149415, \
-0.0006799689816951852}, {-0.9660950160599018, 0.12921045342782436`, 
      0.22352869764125186`}, {-0.9660950160599018, 0.15730819034142696`, 
      0.2047304403251347}, {-0.9999996915748783, -0.00047852777351408993`, \
-0.0006227851300476493}, {-0.9999996915748783, -0.0003930551261149415, \
-0.0006799689816951852}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.00047852777351409004`, \
-0.0006227851300476492}, {-0.9660950160599018, 0.15730819034142698`, 
      0.20473044032513468`}, {-0.9660950160599018, 0.18270896234715592`, 
      0.1824221889525606}, {-0.9999996915748783, -0.0005557963178095837, \
-0.0005549239599640008}, {-0.9999996915748783, -0.00047852777351409004`, \
-0.0006227851300476492}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0005557963178095838, \
-0.0005549239599640007}, {-0.9660950160599018, 0.18270896234715595`, 
      0.18242218895256057`}, {-0.9660950160599018, 0.20497728677507737`, 
      0.15698640657886867`}, {-0.9999996915748783, -0.0006235360310772432, \
-0.0004775489149618696}, {-0.9999996915748783, -0.0005557963178095838, \
-0.0005549239599640007}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0006235360310772429, \
-0.0004775489149618698}, {-0.9660950160599018, 0.20497728677507732`, 
      0.15698640657886873`}, {-0.9660950160599018, 0.22373138509599386`, 
      0.12885917610805317`}, {-0.9999996915748783, -0.0006805855521116804, \
-0.0003919865488631706}, {-0.9999996915748783, -0.0006235360310772429, \
-0.0004775489149618698}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0006805855521116804, \
-0.0003919865488631706}, {-0.9660950160599018, 0.22373138509599386`, 
      0.12885917610805317`}, {-0.9660950160599018, 0.23864972831042652`, 
      0.09852272388427841}, {-0.9999996915748783, -0.0007259667973439033, \
-0.0002997037827373148}, {-0.9999996915748783, -0.0006805855521116804, \
-0.0003919865488631706}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0007259667973439033, \
-0.0002997037827373148}, {-0.9660950160599018, 0.23864972831042652`, 
      0.09852272388427841}, {-0.9660950160599018, 0.24947654939158792`, 
      0.06649715217875692}, {-0.9999996915748783, -0.0007589017295617282, \
-0.00020228275532293248`}, {-0.9999996915748783, -0.0007259667973439033, \
-0.0002997037827373148}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0007589017295617282, \
-0.00020228275532293248`}, {-0.9660950160599018, 0.24947654939158792`, 
      0.06649715217875692}, {-0.9660950160599018, 0.25602622827445565`, 
      0.033331522314086835`}, {-0.9999996915748783, -0.0007788256969422465, \
-0.00010139369810419049`}, {-0.9999996915748783, -0.0007589017295617282, \
-0.00020228275532293248`}}], 
     Polygon3DBox[{{-0.9999996915748783, -0.0007788256969422465, \
-0.00010139369810419049`}, {-0.9660950160599018, 0.25602622827445565`, 
      0.033331522314086835`}, {-0.9660950160599018, 
      0.25818647421265106`, -0.0004055586988800313}, {-0.9999996915748783, \
-0.0007853971137057591, 
      1.2336999159618721`*^-6}, {-0.9999996915748783, -0.0007788256969422465, \
-0.00010139369810419049`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.25818647421265106`, \
-0.0004055586988800313}, {-0.8662870844473872, -0.49954586535010065`, \
-0.0007846854557354618}, {-0.8662870844473872, -0.49536616565879915`, 
      0.06449069111231863}, {-0.9660950160599018, -0.25602622827445565`, 
      0.033331522314086835`}, {-0.9660950160599018, -0.25818647421265106`, \
-0.0004055586988800313}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.25602622827445565`, 
      0.033331522314086835`}, {-0.8662870844473872, -0.49536616565879915`, 
      0.06449069111231863}, {-0.8662870844473872, -0.48269367762361015`, 
      0.1286604092245928}, {-0.9660950160599018, -0.24947654939158792`, 
      0.06649715217875692}, {-0.9660950160599018, -0.25602622827445565`, 
      0.033331522314086835`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.24947654939158792`, 
      0.06649715217875686}, {-0.8662870844473872, -0.48269367762361015`, 
      0.12866040922459268`}, {-0.8662870844473872, -0.4617456642837446, 
      0.1906243133359666}, {-0.9660950160599018, -0.23864972831042655`, 
      0.09852272388427834}, {-0.9660950160599018, -0.24947654939158792`, 
      0.06649715217875686}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.23864972831042655`, 
      0.09852272388427834}, {-0.8662870844473872, -0.4617456642837446, 
      0.1906243133359666}, {-0.8662870844473872, -0.43288126813995, 
      0.24932006540427926`}, {-0.9660950160599018, -0.22373138509599388`, 
      0.12885917610805311`}, {-0.9660950160599018, -0.23864972831042655`, 
      0.09852272388427834}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.2237313850959939, 
      0.1288591761080531}, {-0.8662870844473872, -0.43288126813995004`, 
      0.24932006540427917`}, {-0.8662870844473872, -0.39659535384814687`, 
      0.3037413581086852}, {-0.9660950160599018, -0.2049772867750774, 
      0.15698640657886861`}, {-0.9660950160599018, -0.2237313850959939, 
      0.1288591761080531}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.20497728677507737`, 
      0.15698640657886864`}, {-0.8662870844473872, -0.3965953538481468, 
      0.30374135810868524`}, {-0.8662870844473872, -0.3535100240292012, 
      0.3529551674512203}, {-0.9660950160599018, -0.18270896234715597`, 
      0.18242218895256054`}, {-0.9660950160599018, -0.20497728677507737`, 
      0.15698640657886864`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.18270896234715595`, 
      0.18242218895256057`}, {-0.8662870844473872, -0.3535100240292011, 
      0.35295516745122035`}, {-0.8662870844473872, -0.30436395365174396`, 
      0.3961177489549344}, {-0.9660950160599018, -0.157308190341427, 
      0.20473044032513468`}, {-0.9660950160599018, -0.18270896234715595`, 
      0.18242218895256057`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.157308190341427, 
      0.20473044032513468`}, {-0.8662870844473872, -0.30436395365174396`, 
      0.3961177489549344}, {-0.8662870844473872, -0.2499997258443474, 
      0.43248910321231965`}, {-0.9660950160599018, -0.12921045342782442`, 
      0.22352869764125183`}, {-0.9660950160599018, -0.157308190341427, 
      0.20473044032513468`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.12921045342782442`, 
      0.22352869764125183`}, {-0.8662870844473872, -0.2499997258443474, 
      0.43248910321231965`}, {-0.8662870844473872, -0.19134938625779402`, 
      0.4614456627799322}, {-0.9660950160599018, -0.09889747229922616, 
      0.23849467481904488`}, {-0.9660950160599018, -0.12921045342782442`, 
      0.22352869764125183`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.09889747229922612, 
      0.23849467481904488`}, {-0.8662870844473872, -0.19134938625779396`, 
      0.4614456627799322}, {-0.8662870844473872, -0.1294184636401832, 
      0.482490982909173}, {-0.9660950160599018, -0.06688894682745339, 
      0.24937178817286504`}, {-0.9660950160599018, -0.09889747229922612, 
      0.23849467481904488`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.06688894682745342, 
      0.24937178817286504`}, {-0.8662870844473872, -0.12941846364018325`, 
      0.482490982909173}, {-0.8662870844473872, -0.06526873058358044, 
      0.49526425282636066`}, {-0.9660950160599018, -0.03373364608653079, 
      0.25597355540353545`}, {-0.9660950160599018, -0.06688894682745342, 
      0.24937178817286504`}}], 
     Polygon3DBox[{{-0.9660950160599018, -0.03373364608653077, 
      0.25597355540353545`}, {-0.8662870844473872, -0.0652687305835804, 
      0.49526425282636066`}, {-0.8662870844473872, -4.1595600434103085`*^-17, 
      0.49954648164074317`}, {-0.9660950160599018, -2.149836914636997*^-17, 
      0.2581867927377738}, {-0.9660950160599018, -0.03373364608653077, 
      0.25597355540353545`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0., 
      0.2581867927377738}, {-0.8662870844473872, 0., 
      0.49954648164074317`}, {-0.8662870844473872, 0.06526873058358036, 
      0.4952642528263607}, {-0.9660950160599018, 0.03373364608653075, 
      0.2559735554035355}, {-0.9660950160599018, 0., 0.2581867927377738}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.03373364608653071, 
      0.2559735554035355}, {-0.8662870844473872, 0.06526873058358029, 
      0.4952642528263607}, {-0.8662870844473872, 0.12941846364018308`, 
      0.4824909829091731}, {-0.9660950160599018, 0.06688894682745333, 
      0.24937178817286507`}, {-0.9660950160599018, 0.03373364608653071, 
      0.2559735554035355}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.06688894682745336, 
      0.24937178817286507`}, {-0.8662870844473872, 0.12941846364018314`, 
      0.4824909829091731}, {-0.8662870844473872, 0.1913493862577939, 
      0.4614456627799322}, {-0.9660950160599018, 0.09889747229922609, 
      0.23849467481904488`}, {-0.9660950160599018, 0.06688894682745336, 
      0.24937178817286507`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.09889747229922606, 
      0.2384946748190449}, {-0.8662870844473872, 0.19134938625779385`, 
      0.46144566277993226`}, {-0.8662870844473872, 0.2499997258443473, 
      0.43248910321231976`}, {-0.9660950160599018, 0.12921045342782436`, 
      0.22352869764125188`}, {-0.9660950160599018, 0.09889747229922606, 
      0.2384946748190449}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.12921045342782436`, 
      0.22352869764125186`}, {-0.8662870844473872, 0.2499997258443473, 
      0.4324891032123197}, {-0.8662870844473872, 0.30436395365174385`, 
      0.39611774895493446`}, {-0.9660950160599018, 0.15730819034142696`, 
      0.2047304403251347}, {-0.9660950160599018, 0.12921045342782436`, 
      0.22352869764125186`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.15730819034142698`, 
      0.20473044032513468`}, {-0.8662870844473872, 0.3043639536517439, 
      0.3961177489549344}, {-0.8662870844473872, 0.35351002402920106`, 
      0.3529551674512204}, {-0.9660950160599018, 0.18270896234715592`, 
      0.1824221889525606}, {-0.9660950160599018, 0.15730819034142698`, 
      0.20473044032513468`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.18270896234715595`, 
      0.18242218895256057`}, {-0.8662870844473872, 0.3535100240292011, 
      0.35295516745122035`}, {-0.8662870844473872, 0.3965953538481468, 
      0.3037413581086853}, {-0.9660950160599018, 0.20497728677507737`, 
      0.15698640657886867`}, {-0.9660950160599018, 0.18270896234715595`, 
      0.18242218895256057`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.20497728677507732`, 
      0.15698640657886873`}, {-0.8662870844473872, 0.3965953538481467, 
      0.3037413581086854}, {-0.8662870844473872, 0.4328812681399499, 
      0.24932006540427937`}, {-0.9660950160599018, 0.22373138509599386`, 
      0.12885917610805317`}, {-0.9660950160599018, 0.20497728677507732`, 
      0.15698640657886873`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.22373138509599386`, 
      0.12885917610805317`}, {-0.8662870844473872, 0.4328812681399499, 
      0.24932006540427937`}, {-0.8662870844473872, 0.46174566428374453`, 
      0.19062431333596672`}, {-0.9660950160599018, 0.23864972831042652`, 
      0.09852272388427841}, {-0.9660950160599018, 0.22373138509599386`, 
      0.12885917610805317`}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.23864972831042652`, 
      0.09852272388427841}, {-0.8662870844473872, 0.46174566428374453`, 
      0.19062431333596672`}, {-0.8662870844473872, 0.48269367762361015`, 
      0.1286604092245928}, {-0.9660950160599018, 0.24947654939158792`, 
      0.06649715217875692}, {-0.9660950160599018, 0.23864972831042652`, 
      0.09852272388427841}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.24947654939158792`, 
      0.06649715217875692}, {-0.8662870844473872, 0.48269367762361015`, 
      0.1286604092245928}, {-0.8662870844473872, 0.49536616565879915`, 
      0.06449069111231863}, {-0.9660950160599018, 0.25602622827445565`, 
      0.033331522314086835`}, {-0.9660950160599018, 0.24947654939158792`, 
      0.06649715217875692}}], 
     Polygon3DBox[{{-0.9660950160599018, 0.25602622827445565`, 
      0.033331522314086835`}, {-0.8662870844473872, 0.49536616565879915`, 
      0.06449069111231863}, {-0.8662870844473872, 
      0.49954586535010065`, -0.0007846854557354618}, {-0.9660950160599018, 
      0.25818647421265106`, -0.0004055586988800313}, {-0.9660950160599018, 
      0.25602622827445565`, 0.033331522314086835`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.49954586535010065`, \
-0.0007846854557354618}, {-0.7073844068406693, -0.7068281744724698, \
-0.0011102840133085344`}, {-0.7073844068406693, -0.7009141439348027, 
      0.09125055501648728}, {-0.8662870844473872, -0.49536616565879915`, 
      0.06449069111231863}, {-0.8662870844473872, -0.49954586535010065`, \
-0.0007846854557354618}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.49536616565879915`, 
      0.06449069111231863}, {-0.7073844068406693, -0.7009141439348027, 
      0.09125055501648728}, {-0.7073844068406693, -0.6829833147452562, 
      0.18204695201583757`}, {-0.8662870844473872, -0.48269367762361015`, 
      0.1286604092245928}, {-0.8662870844473872, -0.49536616565879915`, 
      0.06449069111231863}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.48269367762361015`, 
      0.12866040922459268`}, {-0.7073844068406693, -0.6829833147452562, 
      0.1820469520158374}, {-0.7073844068406693, -0.6533431013937454, 
      0.2697222512509425}, {-0.8662870844473872, -0.4617456642837446, 
      0.1906243133359666}, {-0.8662870844473872, -0.48269367762361015`, 
      0.12866040922459268`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.4617456642837446, 
      0.1906243133359666}, {-0.7073844068406693, -0.6533431013937454, 
      0.2697222512509425}, {-0.7073844068406693, -0.6125016695078666, 
      0.3527733065422477}, {-0.8662870844473872, -0.43288126813995, 
      0.24932006540427926`}, {-0.8662870844473872, -0.4617456642837446, 
      0.1906243133359666}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.43288126813995004`, 
      0.24932006540427917`}, {-0.7073844068406693, -0.6125016695078666, 
      0.3527733065422476}, {-0.7073844068406693, -0.5611592236246148, 
      0.42977625190288726`}, {-0.8662870844473872, -0.39659535384814687`, 
      0.3037413581086852}, {-0.8662870844473872, -0.43288126813995004`, 
      0.24932006540427917`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.3965953538481468, 
      0.30374135810868524`}, {-0.7073844068406693, -0.5611592236246147, 
      0.4297762519028873}, {-0.7073844068406693, -0.5001960025575634, 
      0.4994109129605684}, {-0.8662870844473872, -0.3535100240292012, 
      0.3529551674512203}, {-0.8662870844473872, -0.3965953538481468, 
      0.30374135810868524`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.3535100240292011, 
      0.35295516745122035`}, {-0.7073844068406693, -0.5001960025575634, 
      0.49941091296056844`}, {-0.7073844068406693, -0.4306571881725259, 
      0.5604834406421014}, {-0.8662870844473872, -0.30436395365174396`, 
      0.3961177489549344}, {-0.8662870844473872, -0.3535100240292011, 
      0.35295516745122035`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.30436395365174396`, 
      0.3961177489549344}, {-0.7073844068406693, -0.4306571881725259, 
      0.5604834406421014}, {-0.7073844068406693, -0.3537349863026794, 
      0.6119467790781463}, {-0.8662870844473872, -0.2499997258443474, 
      0.43248910321231965`}, {-0.8662870844473872, -0.30436395365174396`, 
      0.3961177489549344}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.2499997258443474, 
      0.43248910321231965`}, {-0.7073844068406693, -0.3537349863026794, 
      0.6119467790781463}, {-0.7073844068406693, -0.2707481870162911, 
      0.6529186168168786}, {-0.8662870844473872, -0.19134938625779402`, 
      0.4614456627799322}, {-0.8662870844473872, -0.2499997258443474, 
      0.43248910321231965`}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.19134938625779396`, 
      0.4614456627799322}, {-0.7073844068406693, -0.27074818701629105`, 
      0.6529186168168786}, {-0.7073844068406693, -0.1831195546653401, 
      0.6826965135826034}, {-0.8662870844473872, -0.1294184636401832, 
      0.482490982909173}, {-0.8662870844473872, -0.19134938625779396`, 
      0.4614456627799322}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.12941846364018325`, 
      0.482490982909173}, {-0.7073844068406693, -0.1831195546653402, 
      0.6826965135826034}, {-0.7073844068406693, -0.09235143535057652, 
      0.7007699432391222}, {-0.8662870844473872, -0.06526873058358044, 
      0.49526425282636066`}, {-0.8662870844473872, -0.12941846364018325`, 
      0.482490982909173}}], 
     Polygon3DBox[{{-0.8662870844473872, -0.0652687305835804, 
      0.49526425282636066`}, {-0.7073844068406693, -0.09235143535057645, 
      0.7007699432391222}, {-0.7073844068406693, -5.885534114133456*^-17, 
      0.706829046487674}, {-0.8662870844473872, -4.1595600434103085`*^-17, 
      0.49954648164074317`}, {-0.8662870844473872, -0.0652687305835804, 
      0.49526425282636066`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0., 
      0.49954648164074317`}, {-0.7073844068406693, 0., 
      0.706829046487674}, {-0.7073844068406693, 0.0923514353505764, 
      0.7007699432391223}, {-0.8662870844473872, 0.06526873058358036, 
      0.4952642528263607}, {-0.8662870844473872, 0., 0.49954648164074317`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.06526873058358029, 
      0.4952642528263607}, {-0.7073844068406693, 0.0923514353505763, 
      0.7007699432391223}, {-0.7073844068406693, 0.18311955466533994`, 
      0.6826965135826035}, {-0.8662870844473872, 0.12941846364018308`, 
      0.4824909829091731}, {-0.8662870844473872, 0.06526873058358029, 
      0.4952642528263607}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.12941846364018314`, 
      0.4824909829091731}, {-0.7073844068406693, 0.18311955466534002`, 
      0.6826965135826035}, {-0.7073844068406693, 0.27074818701629094`, 
      0.6529186168168786}, {-0.8662870844473872, 0.1913493862577939, 
      0.4614456627799322}, {-0.8662870844473872, 0.12941846364018314`, 
      0.4824909829091731}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.19134938625779385`, 
      0.46144566277993226`}, {-0.7073844068406693, 0.2707481870162909, 
      0.6529186168168786}, {-0.7073844068406693, 0.35373498630267924`, 
      0.6119467790781464}, {-0.8662870844473872, 0.2499997258443473, 
      0.43248910321231976`}, {-0.8662870844473872, 0.19134938625779385`, 
      0.46144566277993226`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.2499997258443473, 
      0.4324891032123197}, {-0.7073844068406693, 0.35373498630267924`, 
      0.6119467790781463}, {-0.7073844068406693, 0.43065718817252574`, 
      0.5604834406421015}, {-0.8662870844473872, 0.30436395365174385`, 
      0.39611774895493446`}, {-0.8662870844473872, 0.2499997258443473, 
      0.4324891032123197}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.3043639536517439, 
      0.3961177489549344}, {-0.7073844068406693, 0.4306571881725258, 
      0.5604834406421014}, {-0.7073844068406693, 0.5001960025575632, 
      0.49941091296056855`}, {-0.8662870844473872, 0.35351002402920106`, 
      0.3529551674512204}, {-0.8662870844473872, 0.3043639536517439, 
      0.3961177489549344}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.3535100240292011, 
      0.35295516745122035`}, {-0.7073844068406693, 0.5001960025575634, 
      0.49941091296056844`}, {-0.7073844068406693, 0.5611592236246147, 
      0.42977625190288743`}, {-0.8662870844473872, 0.3965953538481468, 
      0.3037413581086853}, {-0.8662870844473872, 0.3535100240292011, 
      0.35295516745122035`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.3965953538481467, 
      0.3037413581086854}, {-0.7073844068406693, 0.5611592236246146, 
      0.42977625190288754`}, {-0.7073844068406693, 0.6125016695078664, 
      0.35277330654224787`}, {-0.8662870844473872, 0.4328812681399499, 
      0.24932006540427937`}, {-0.8662870844473872, 0.3965953538481467, 
      0.3037413581086854}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.4328812681399499, 
      0.24932006540427937`}, {-0.7073844068406693, 0.6125016695078664, 
      0.35277330654224787`}, {-0.7073844068406693, 0.6533431013937453, 
      0.2697222512509427}, {-0.8662870844473872, 0.46174566428374453`, 
      0.19062431333596672`}, {-0.8662870844473872, 0.4328812681399499, 
      0.24932006540427937`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.46174566428374453`, 
      0.19062431333596672`}, {-0.7073844068406693, 0.6533431013937453, 
      0.2697222512509427}, {-0.7073844068406693, 0.6829833147452562, 
      0.18204695201583757`}, {-0.8662870844473872, 0.48269367762361015`, 
      0.1286604092245928}, {-0.8662870844473872, 0.46174566428374453`, 
      0.19062431333596672`}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.48269367762361015`, 
      0.1286604092245928}, {-0.7073844068406693, 0.6829833147452562, 
      0.18204695201583757`}, {-0.7073844068406693, 0.7009141439348027, 
      0.09125055501648728}, {-0.8662870844473872, 0.49536616565879915`, 
      0.06449069111231863}, {-0.8662870844473872, 0.48269367762361015`, 
      0.1286604092245928}}], 
     Polygon3DBox[{{-0.8662870844473872, 0.49536616565879915`, 
      0.06449069111231863}, {-0.7073844068406693, 0.7009141439348027, 
      0.09125055501648728}, {-0.7073844068406693, 
      0.7068281744724698, -0.0011102840133085344`}, {-0.8662870844473872, 
      0.49954586535010065`, -0.0007846854557354618}, {-0.8662870844473872, 
      0.49536616565879915`, 0.06449069111231863}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.7068281744724698, \
-0.0011102840133085344`}, {-0.5002267077832093, -0.8658934061595421, \
-0.001360143300464402}, {-0.5002267077832093, -0.8586484770079644, 
      0.11178565986867343`}, {-0.7073844068406694, -0.7009141439348027, 
      0.09125055501648728}, {-0.7073844068406694, -0.7068281744724698, \
-0.0011102840133085344`}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.7009141439348027, 
      0.09125055501648728}, {-0.5002267077832093, -0.8586484770079644, 
      0.11178565986867343`}, {-0.5002267077832093, -0.8366824783070934, 
      0.22301495760211235`}, {-0.7073844068406694, -0.6829833147452562, 
      0.18204695201583757`}, {-0.7073844068406694, -0.7009141439348027, 
      0.09125055501648728}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.6829833147452562, 
      0.1820469520158374}, {-0.5002267077832093, -0.8366824783070934, 
      0.22301495760211215`}, {-0.5002267077832093, -0.8003720053730027, 
      0.33042078299581845`}, {-0.7073844068406694, -0.6533431013937454, 
      0.2697222512509425}, {-0.7073844068406694, -0.6829833147452562, 
      0.1820469520158374}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.6533431013937454, 
      0.2697222512509425}, {-0.5002267077832093, -0.8003720053730027, 
      0.33042078299581845`}, {-0.5002267077832093, -0.7503395818713643, 
      0.43216172053697427`}, {-0.7073844068406694, -0.6125016695078666, 
      0.3527733065422477}, {-0.7073844068406694, -0.6533431013937454, 
      0.2697222512509425}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.6125016695078666, 
      0.3527733065422476}, {-0.5002267077832093, -0.7503395818713644, 
      0.43216172053697416`}, {-0.5002267077832093, -0.6874429869816789, 
      0.5264934761894766}, {-0.7073844068406694, -0.5611592236246148, 
      0.42977625190288726`}, {-0.7073844068406694, -0.6125016695078666, 
      0.3527733065422476}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.5611592236246147, 
      0.4297762519028873}, {-0.5002267077832093, -0.6874429869816788, 
      0.5264934761894766}, {-0.5002267077832093, -0.6127605492313678, 
      0.6117987823835906}, {-0.7073844068406694, -0.5001960025575634, 
      0.4994109129605684}, {-0.7073844068406694, -0.5611592236246147, 
      0.4297762519028873}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.5001960025575634, 
      0.49941091296056844`}, {-0.5002267077832093, -0.6127605492313677, 
      0.6117987823835908}, {-0.5002267077832093, -0.5275726591290874, 
      0.6866151252046779}, {-0.7073844068406694, -0.4306571881725259, 
      0.5604834406421014}, {-0.7073844068406694, -0.5001960025575634, 
      0.49941091296056844`}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.4306571881725259, 
      0.5604834406421014}, {-0.5002267077832093, -0.5275726591290874, 
      0.6866151252046779}, {-0.5002267077832093, -0.4333398175532914, 
      0.7496598184131599}, {-0.7073844068406694, -0.3537349863026794, 
      0.6119467790781463}, {-0.7073844068406694, -0.4306571881725259, 
      0.5604834406421014}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.3537349863026794, 
      0.6119467790781463}, {-0.5002267077832093, -0.4333398175532914, 
      0.7496598184131599}, {-0.5002267077832093, -0.3316775962446984, 
      0.7998519944150358}, {-0.7073844068406694, -0.2707481870162911, 
      0.6529186168168786}, {-0.7073844068406694, -0.3537349863026794, 
      0.6119467790781463}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.27074818701629105`, 
      0.6529186168168786}, {-0.5002267077832093, -0.3316775962446983, 
      0.7998519944150358}, {-0.5002267077832093, -0.22432893969164447`, 
      0.8363311351595097}, {-0.7073844068406694, -0.1831195546653401, 
      0.6826965135826034}, {-0.7073844068406694, -0.27074818701629105`, 
      0.6529186168168786}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.1831195546653402, 
      0.6826965135826034}, {-0.5002267077832093, -0.22432893969164455`, 
      0.8363311351595097}, {-0.5002267077832093, -0.11313428327770778`, 
      0.8584718252613832}, {-0.7073844068406694, -0.09235143535057652, 
      0.7007699432391222}, {-0.7073844068406694, -0.1831195546653402, 
      0.6826965135826034}}], 
     Polygon3DBox[{{-0.7073844068406694, -0.09235143535057645, 
      0.7007699432391222}, {-0.5002267077832093, -0.1131342832777077, 
      0.8584718252613832}, {-0.5002267077832093, -7.210019867924343*^-17, 
      0.865894474413812}, {-0.7073844068406694, -5.885534114133456*^-17, 
      0.706829046487674}, {-0.7073844068406694, -0.09235143535057645, 
      0.7007699432391222}}], 
     Polygon3DBox[{{-0.7073844068406694, 0., 
      0.706829046487674}, {-0.5002267077832093, 0., 
      0.865894474413812}, {-0.5002267077832093, 0.11313428327770764`, 
      0.8584718252613833}, {-0.7073844068406694, 0.0923514353505764, 
      0.7007699432391223}, {-0.7073844068406694, 0., 0.706829046487674}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.0923514353505763, 
      0.7007699432391223}, {-0.5002267077832093, 0.11313428327770751`, 
      0.8584718252613833}, {-0.5002267077832093, 0.22432893969164427`, 
      0.8363311351595099}, {-0.7073844068406694, 0.18311955466533994`, 
      0.6826965135826035}, {-0.7073844068406694, 0.0923514353505763, 
      0.7007699432391223}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.18311955466534002`, 
      0.6826965135826035}, {-0.5002267077832093, 0.22432893969164436`, 
      0.8363311351595099}, {-0.5002267077832093, 0.33167759624469817`, 
      0.7998519944150358}, {-0.7073844068406694, 0.27074818701629094`, 
      0.6529186168168786}, {-0.7073844068406694, 0.18311955466534002`, 
      0.6826965135826035}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.2707481870162909, 
      0.6529186168168786}, {-0.5002267077832093, 0.33167759624469806`, 
      0.799851994415036}, {-0.5002267077832093, 0.4333398175532912, 
      0.74965981841316}, {-0.7073844068406694, 0.35373498630267924`, 
      0.6119467790781464}, {-0.7073844068406694, 0.2707481870162909, 
      0.6529186168168786}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.35373498630267924`, 
      0.6119467790781463}, {-0.5002267077832093, 0.4333398175532912, 
      0.7496598184131599}, {-0.5002267077832093, 0.5275726591290871, 
      0.686615125204678}, {-0.7073844068406694, 0.43065718817252574`, 
      0.5604834406421015}, {-0.7073844068406694, 0.35373498630267924`, 
      0.6119467790781463}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.4306571881725258, 
      0.5604834406421014}, {-0.5002267077832093, 0.5275726591290872, 
      0.6866151252046779}, {-0.5002267077832093, 0.6127605492313676, 
      0.6117987823835909}, {-0.7073844068406694, 0.5001960025575632, 
      0.49941091296056855`}, {-0.7073844068406694, 0.4306571881725258, 
      0.5604834406421014}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.5001960025575634, 
      0.49941091296056844`}, {-0.5002267077832093, 0.6127605492313677, 
      0.6117987823835908}, {-0.5002267077832093, 0.6874429869816788, 
      0.5264934761894767}, {-0.7073844068406694, 0.5611592236246147, 
      0.42977625190288743`}, {-0.7073844068406694, 0.5001960025575634, 
      0.49941091296056844`}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.5611592236246146, 
      0.42977625190288754`}, {-0.5002267077832093, 0.6874429869816786, 
      0.526493476189477}, {-0.5002267077832093, 0.7503395818713642, 
      0.4321617205369745}, {-0.7073844068406694, 0.6125016695078664, 
      0.35277330654224787`}, {-0.7073844068406694, 0.5611592236246146, 
      0.42977625190288754`}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.6125016695078664, 
      0.35277330654224787`}, {-0.5002267077832093, 0.7503395818713642, 
      0.4321617205369745}, {-0.5002267077832093, 0.8003720053730027, 
      0.3304207829958187}, {-0.7073844068406694, 0.6533431013937453, 
      0.2697222512509427}, {-0.7073844068406694, 0.6125016695078664, 
      0.35277330654224787`}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.6533431013937453, 
      0.2697222512509427}, {-0.5002267077832093, 0.8003720053730027, 
      0.3304207829958187}, {-0.5002267077832093, 0.8366824783070934, 
      0.22301495760211235`}, {-0.7073844068406694, 0.6829833147452562, 
      0.18204695201583757`}, {-0.7073844068406694, 0.6533431013937453, 
      0.2697222512509427}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.6829833147452562, 
      0.18204695201583757`}, {-0.5002267077832093, 0.8366824783070934, 
      0.22301495760211235`}, {-0.5002267077832093, 0.8586484770079644, 
      0.11178565986867343`}, {-0.7073844068406694, 0.7009141439348027, 
      0.09125055501648728}, {-0.7073844068406694, 0.6829833147452562, 
      0.18204695201583757`}}], 
     Polygon3DBox[{{-0.7073844068406694, 0.7009141439348027, 
      0.09125055501648728}, {-0.5002267077832093, 0.8586484770079644, 
      0.11178565986867343`}, {-0.5002267077832093, 
      0.8658934061595421, -0.001360143300464402}, {-0.7073844068406694, 
      0.7068281744724698, -0.0011102840133085344`}, {-0.7073844068406694, 
      0.7009141439348027, 0.09125055501648728}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.8658934061595421, \
-0.001360143300464402}, {-0.2589454822797532, -0.9658907470587756, \
-0.0015172188854276707`}, {-0.2589454822797532, -0.9578091402688101, 
      0.12469518043785292`}, {-0.5002267077832094, -0.8586484770079644, 
      0.11178565986867343`}, {-0.5002267077832094, -0.8658934061595421, \
-0.001360143300464402}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.8586484770079644, 
      0.11178565986867343`}, {-0.2589454822797532, -0.9578091402688101, 
      0.12469518043785292`}, {-0.2589454822797532, -0.9333064073179055, 
      0.24876974749002329`}, {-0.5002267077832094, -0.8366824783070934, 
      0.22301495760211235`}, {-0.5002267077832094, -0.8586484770079644, 
      0.11178565986867343`}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.8366824783070934, 
      0.22301495760211215`}, {-0.2589454822797532, -0.9333064073179055, 
      0.24876974749002306`}, {-0.2589454822797532, -0.8928026344760274, 
      0.3685792900850116}, {-0.5002267077832094, -0.8003720053730027, 
      0.33042078299581845`}, {-0.5002267077832094, -0.8366824783070934, 
      0.22301495760211215`}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.8003720053730027, 
      0.33042078299581845`}, {-0.2589454822797532, -0.8928026344760274, 
      0.3685792900850116}, {-0.2589454822797532, -0.8369922372961989, 
      0.4820697376031911}, {-0.5002267077832094, -0.7503395818713643, 
      0.43216172053697427`}, {-0.5002267077832094, -0.8003720053730027, 
      0.33042078299581845`}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.7503395818713644, 
      0.43216172053697416`}, {-0.2589454822797532, -0.836992237296199, 
      0.482069737603191}, {-0.2589454822797532, -0.7668320552307196, 
      0.5872953569351085}, {-0.5002267077832094, -0.6874429869816789, 
      0.5264934761894766}, {-0.5002267077832094, -0.7503395818713644, 
      0.43216172053697416`}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.6874429869816788, 
      0.5264934761894766}, {-0.2589454822797532, -0.7668320552307195, 
      0.5872953569351086}, {-0.2589454822797532, -0.6835249471297862, 
      0.6824521110364661}, {-0.5002267077832094, -0.6127605492313678, 
      0.6117987823835906}, {-0.5002267077832094, -0.6874429869816788, 
      0.5264934761894766}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.6127605492313677, 
      0.6117987823835908}, {-0.2589454822797532, -0.6835249471297861, 
      0.6824521110364662}, {-0.2589454822797532, -0.5884991688689317, 
      0.7659085881797401}, {-0.5002267077832094, -0.5275726591290874, 
      0.6866151252046779}, {-0.5002267077832094, -0.6127605492313677, 
      0.6117987823835908}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.5275726591290874, 
      0.6866151252046779}, {-0.2589454822797532, -0.5884991688689317, 
      0.7659085881797401}, {-0.2589454822797532, -0.4833838866648466, 
      0.8362339716369412}, {-0.5002267077832094, -0.4333398175532914, 
      0.7496598184131599}, {-0.5002267077832094, -0.5275726591290874, 
      0.6866151252046779}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.4333398175532914, 
      0.7496598184131599}, {-0.2589454822797532, -0.4833838866648466, 
      0.8362339716369412}, {-0.2589454822797532, -0.3699812458907015, 
      0.8922225702682433}, {-0.5002267077832094, -0.3316775962446984, 
      0.7998519944150358}, {-0.5002267077832094, -0.4333398175532914, 
      0.7496598184131599}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.3316775962446983, 
      0.7998519944150358}, {-0.2589454822797532, -0.3699812458907014, 
      0.8922225702682433}, {-0.2589454822797532, -0.25023547425621856`, 
      0.9329144894526353}, {-0.5002267077832094, -0.22432893969164447`, 
      0.8363311351595097}, {-0.5002267077832094, -0.3316775962446983, 
      0.7998519944150358}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.22432893969164455`, 
      0.8363311351595097}, {-0.2589454822797532, -0.25023547425621867`, 
      0.9329144894526353}, {-0.2589454822797532, -0.12619954906196637`, 
      0.9576120879685376}, {-0.5002267077832094, -0.11313428327770778`, 
      0.8584718252613832}, {-0.5002267077832094, -0.22432893969164455`, 
      0.8363311351595097}}], 
     Polygon3DBox[{{-0.5002267077832094, -0.1131342832777077, 
      0.8584718252613832}, {-0.2589454822797532, -0.1261995490619663, 
      0.9576120879685376}, {-0.2589454822797532, -8.0426660221673*^-17, 
      0.9658919386799467}, {-0.5002267077832094, -7.210019867924343*^-17, 
      0.865894474413812}, {-0.5002267077832094, -0.1131342832777077, 
      0.8584718252613832}}], 
     Polygon3DBox[{{-0.5002267077832094, 0., 
      0.865894474413812}, {-0.2589454822797532, 0., 
      0.9658919386799467}, {-0.2589454822797532, 0.1261995490619662, 
      0.9576120879685377}, {-0.5002267077832094, 0.11313428327770764`, 
      0.8584718252613833}, {-0.5002267077832094, 0., 0.865894474413812}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.11313428327770751`, 
      0.8584718252613833}, {-0.2589454822797532, 0.12619954906196607`, 
      0.9576120879685377}, {-0.2589454822797532, 0.25023547425621834`, 
      0.9329144894526354}, {-0.5002267077832094, 0.22432893969164427`, 
      0.8363311351595099}, {-0.5002267077832094, 0.11313428327770751`, 
      0.8584718252613833}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.22432893969164436`, 
      0.8363311351595099}, {-0.2589454822797532, 0.25023547425621845`, 
      0.9329144894526354}, {-0.2589454822797532, 0.3699812458907013, 
      0.8922225702682433}, {-0.5002267077832094, 0.33167759624469817`, 
      0.7998519944150358}, {-0.5002267077832094, 0.22432893969164436`, 
      0.8363311351595099}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.33167759624469806`, 
      0.799851994415036}, {-0.2589454822797532, 0.3699812458907012, 
      0.8922225702682434}, {-0.2589454822797532, 0.48338388666484644`, 
      0.8362339716369415}, {-0.5002267077832094, 0.4333398175532912, 
      0.74965981841316}, {-0.5002267077832094, 0.33167759624469806`, 
      0.799851994415036}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.4333398175532912, 
      0.7496598184131599}, {-0.2589454822797532, 0.48338388666484644`, 
      0.8362339716369414}, {-0.2589454822797532, 0.5884991688689315, 
      0.7659085881797402}, {-0.5002267077832094, 0.5275726591290871, 
      0.686615125204678}, {-0.5002267077832094, 0.4333398175532912, 
      0.7496598184131599}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.5275726591290872, 
      0.6866151252046779}, {-0.2589454822797532, 0.5884991688689316, 
      0.7659085881797401}, {-0.2589454822797532, 0.683524947129786, 
      0.6824521110364663}, {-0.5002267077832094, 0.6127605492313676, 
      0.6117987823835909}, {-0.5002267077832094, 0.5275726591290872, 
      0.6866151252046779}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.6127605492313677, 
      0.6117987823835908}, {-0.2589454822797532, 0.6835249471297861, 
      0.6824521110364662}, {-0.2589454822797532, 0.7668320552307195, 
      0.5872953569351087}, {-0.5002267077832094, 0.6874429869816788, 
      0.5264934761894767}, {-0.5002267077832094, 0.6127605492313677, 
      0.6117987823835908}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.6874429869816786, 
      0.526493476189477}, {-0.2589454822797532, 0.7668320552307193, 
      0.5872953569351089}, {-0.2589454822797532, 0.8369922372961988, 
      0.48206973760319133`}, {-0.5002267077832094, 0.7503395818713642, 
      0.4321617205369745}, {-0.5002267077832094, 0.6874429869816786, 
      0.526493476189477}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.7503395818713642, 
      0.4321617205369745}, {-0.2589454822797532, 0.8369922372961988, 
      0.48206973760319133`}, {-0.2589454822797532, 0.8928026344760273, 
      0.36857929008501183`}, {-0.5002267077832094, 0.8003720053730027, 
      0.3304207829958187}, {-0.5002267077832094, 0.7503395818713642, 
      0.4321617205369745}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.8003720053730027, 
      0.3304207829958187}, {-0.2589454822797532, 0.8928026344760273, 
      0.36857929008501183`}, {-0.2589454822797532, 0.9333064073179055, 
      0.24876974749002329`}, {-0.5002267077832094, 0.8366824783070934, 
      0.22301495760211235`}, {-0.5002267077832094, 0.8003720053730027, 
      0.3304207829958187}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.8366824783070934, 
      0.22301495760211235`}, {-0.2589454822797532, 0.9333064073179055, 
      0.24876974749002329`}, {-0.2589454822797532, 0.9578091402688101, 
      0.12469518043785292`}, {-0.5002267077832094, 0.8586484770079644, 
      0.11178565986867343`}, {-0.5002267077832094, 0.8366824783070934, 
      0.22301495760211235`}}], 
     Polygon3DBox[{{-0.5002267077832094, 0.8586484770079644, 
      0.11178565986867343`}, {-0.2589454822797532, 0.9578091402688101, 
      0.12469518043785292`}, {-0.2589454822797532, 
      0.9658907470587756, -0.0015172188854276707`}, {-0.5002267077832094, 
      0.8658934061595421, -0.001360143300464402}, {-0.5002267077832094, 
      0.8586484770079644, 0.11178565986867343`}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.9658907470587758, \
-0.001517218885427671}, {
      5.551115123125783*^-16, -0.9999987662997035, -0.0015707956808307198`}, {
      5.551115123125783*^-16, -0.9916317777512637, 
      0.12909847928565363`}, {-0.2589454822797529, -0.9578091402688103, 
      0.12469518043785294`}, {-0.2589454822797529, -0.9658907470587758, \
-0.001517218885427671}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.9578091402688103, 
      0.12469518043785294`}, {5.551115123125783*^-16, -0.9916317777512637, 
      0.12909847928565363`}, {5.551115123125783*^-16, -0.9662637919863222, 
      0.25755442977400644`}, {-0.2589454822797529, -0.9333064073179056, 
      0.2487697474900233}, {-0.2589454822797529, -0.9578091402688103, 
      0.12469518043785294`}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.9333064073179056, 
      0.2487697474900231}, {5.551115123125783*^-16, -0.9662637919863222, 
      0.2575544297740062}, {5.551115123125783*^-16, -0.924329729572225, 
      0.38159474711916225`}, {-0.2589454822797529, -0.8928026344760274, 
      0.36857929008501167`}, {-0.2589454822797529, -0.9333064073179056, 
      0.2487697474900231}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.8928026344760274, 
      0.36857929008501167`}, {5.551115123125783*^-16, -0.924329729572225, 
      0.38159474711916225`}, {5.551115123125783*^-16, -0.8665485276128188, 
      0.49909282632798474`}, {-0.2589454822797529, -0.836992237296199, 
      0.48206973760319116`}, {-0.2589454822797529, -0.8928026344760274, 
      0.36857929008501167`}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.8369922372961991, 
      0.48206973760319105`}, {5.551115123125783*^-16, -0.8665485276128189, 
      0.4990928263279846}, {5.551115123125783*^-16, -0.7939108139557767, 
      0.60803422558609}, {-0.2589454822797529, -0.7668320552307197, 
      0.5872953569351086}, {-0.2589454822797529, -0.8369922372961991, 
      0.48206973760319105`}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.7668320552307196, 
      0.5872953569351087}, {5.551115123125783*^-16, -0.7939108139557766, 
      0.6080342255860901}, {5.551115123125783*^-16, -0.7076619234072267, 
      0.7065512027868783}, {-0.2589454822797529, -0.6835249471297862, 
      0.6824521110364662}, {-0.2589454822797529, -0.7668320552307196, 
      0.5872953569351087}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.6835249471297861, 
      0.6824521110364663}, {5.551115123125783*^-16, -0.7076619234072266, 
      0.7065512027868784}, {5.551115123125783*^-16, -0.6092805471316124, 
      0.7929547369724221}, {-0.2589454822797529, -0.5884991688689318, 
      0.7659085881797402}, {-0.2589454822797529, -0.6835249471297861, 
      0.6824521110364663}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.5884991688689318, 
      0.7659085881797402}, {5.551115123125783*^-16, -0.6092805471316124, 
      0.7929547369724221}, {5.551115123125783*^-16, -0.5004533812814214, 
      0.8657634856957137}, {-0.2589454822797529, -0.4833838866648467, 
      0.8362339716369414}, {-0.2589454822797529, -0.5884991688689318, 
      0.7659085881797402}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.4833838866648467, 
      0.8362339716369414}, {5.551115123125783*^-16, -0.5004533812814214, 
      0.8657634856957137}, {5.551115123125783*^-16, -0.3830462094924852, 
      0.9237291818457611}, {-0.2589454822797529, -0.3699812458907016, 
      0.8922225702682434}, {-0.2589454822797529, -0.4833838866648467, 
      0.8362339716369414}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.36998124589070147`, 
      0.8922225702682434}, {5.551115123125783*^-16, -0.3830462094924851, 
      0.9237291818457611}, {5.551115123125783*^-16, -0.2590719150200252, 
      0.9658580345205277}, {-0.2589454822797529, -0.25023547425621856`, 
      0.9329144894526354}, {-0.2589454822797529, -0.36998124589070147`, 
      0.8922225702682434}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.25023547425621867`, 
      0.9329144894526354}, {5.551115123125783*^-16, -0.2590719150200253, 
      0.9658580345205277}, {5.551115123125783*^-16, -0.13065597093028772`, 
      0.9914277670411817}, {-0.2589454822797529, -0.12619954906196637`, 
      0.9576120879685377}, {-0.2589454822797529, -0.25023547425621867`, 
      0.9329144894526354}}], 
     Polygon3DBox[{{-0.2589454822797529, -0.1261995490619663, 
      0.9576120879685377}, {5.551115123125783*^-16, -0.13065597093028763`, 
      0.9914277670411817}, {5.551115123125783*^-16, -8.326672684688674*^-17, 
      1.}, {-0.2589454822797529, -8.042666022167301*^-17, 
      0.9658919386799468}, {-0.2589454822797529, -0.1261995490619663, 
      0.9576120879685377}}], 
     Polygon3DBox[{{-0.2589454822797529, 0., 0.9658919386799468}, {
      5.551115123125783*^-16, 0., 1.}, {5.551115123125783*^-16, 
      0.13065597093028755`, 0.9914277670411819}, {-0.2589454822797529, 
      0.12619954906196623`, 0.9576120879685378}, {-0.2589454822797529, 0., 
      0.9658919386799468}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.1261995490619661, 
      0.9576120879685378}, {5.551115123125783*^-16, 0.1306559709302874, 
      0.9914277670411819}, {5.551115123125783*^-16, 0.25907191502002497`, 
      0.9658580345205278}, {-0.2589454822797529, 0.25023547425621834`, 
      0.9329144894526356}, {-0.2589454822797529, 0.1261995490619661, 
      0.9576120879685378}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.25023547425621845`, 
      0.9329144894526356}, {5.551115123125783*^-16, 0.2590719150200251, 
      0.9658580345205278}, {5.551115123125783*^-16, 0.38304620949248497`, 
      0.9237291818457611}, {-0.2589454822797529, 0.36998124589070136`, 
      0.8922225702682434}, {-0.2589454822797529, 0.25023547425621845`, 
      0.9329144894526356}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.36998124589070125`, 
      0.8922225702682435}, {5.551115123125783*^-16, 0.38304620949248486`, 
      0.9237291818457612}, {5.551115123125783*^-16, 0.5004533812814211, 
      0.8657634856957139}, {-0.2589454822797529, 0.4833838866648465, 
      0.8362339716369416}, {-0.2589454822797529, 0.36998124589070125`, 
      0.8922225702682435}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.4833838866648465, 
      0.8362339716369415}, {5.551115123125783*^-16, 0.5004533812814211, 
      0.8657634856957138}, {5.551115123125783*^-16, 0.6092805471316122, 
      0.7929547369724222}, {-0.2589454822797529, 0.5884991688689316, 
      0.7659085881797403}, {-0.2589454822797529, 0.4833838866648465, 
      0.8362339716369415}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.5884991688689317, 
      0.7659085881797402}, {5.551115123125783*^-16, 0.6092805471316123, 
      0.7929547369724221}, {5.551115123125783*^-16, 0.7076619234072264, 
      0.7065512027868786}, {-0.2589454822797529, 0.683524947129786, 
      0.6824521110364664}, {-0.2589454822797529, 0.5884991688689317, 
      0.7659085881797402}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.6835249471297861, 
      0.6824521110364663}, {5.551115123125783*^-16, 0.7076619234072266, 
      0.7065512027868784}, {5.551115123125783*^-16, 0.7939108139557766, 
      0.6080342255860902}, {-0.2589454822797529, 0.7668320552307196, 
      0.5872953569351088}, {-0.2589454822797529, 0.6835249471297861, 
      0.6824521110364663}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.7668320552307194, 
      0.587295356935109}, {5.551115123125783*^-16, 0.7939108139557763, 
      0.6080342255860904}, {5.551115123125783*^-16, 0.8665485276128186, 
      0.49909282632798496`}, {-0.2589454822797529, 0.8369922372961989, 
      0.4820697376031914}, {-0.2589454822797529, 0.7668320552307194, 
      0.587295356935109}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.8369922372961989, 
      0.4820697376031914}, {5.551115123125783*^-16, 0.8665485276128186, 
      0.49909282632798496`}, {5.551115123125783*^-16, 0.9243297295722249, 
      0.38159474711916247`}, {-0.2589454822797529, 0.8928026344760273, 
      0.3685792900850119}, {-0.2589454822797529, 0.8369922372961989, 
      0.4820697376031914}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.8928026344760273, 
      0.3685792900850119}, {5.551115123125783*^-16, 0.9243297295722249, 
      0.38159474711916247`}, {5.551115123125783*^-16, 0.9662637919863222, 
      0.25755442977400644`}, {-0.2589454822797529, 0.9333064073179056, 
      0.2487697474900233}, {-0.2589454822797529, 0.8928026344760273, 
      0.3685792900850119}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.9333064073179056, 
      0.2487697474900233}, {5.551115123125783*^-16, 0.9662637919863222, 
      0.25755442977400644`}, {5.551115123125783*^-16, 0.9916317777512637, 
      0.12909847928565363`}, {-0.2589454822797529, 0.9578091402688103, 
      0.12469518043785294`}, {-0.2589454822797529, 0.9333064073179056, 
      0.2487697474900233}}], 
     Polygon3DBox[{{-0.2589454822797529, 0.9578091402688103, 
      0.12469518043785294`}, {5.551115123125783*^-16, 0.9916317777512637, 
      0.12909847928565363`}, {5.551115123125783*^-16, 
      0.9999987662997035, -0.0015707956808307198`}, {-0.2589454822797529, 
      0.9658907470587758, -0.001517218885427671}, {-0.2589454822797529, 
      0.9578091402688103, 0.12469518043785294`}}], 
     Polygon3DBox[{{
      4.440892098500626*^-16, -0.9999987662997035, -0.0015707956808307198`}, {
      0.25894548227975384`, -0.9658907470587755, -0.0015172188854276705`}, {
      0.25894548227975384`, -0.95780914026881, 0.12469518043785291`}, {
      4.440892098500626*^-16, -0.9916317777512637, 0.12909847928565363`}, {
      4.440892098500626*^-16, -0.9999987662997035, -0.0015707956808307198`}}],
      Polygon3DBox[{{4.440892098500626*^-16, -0.9916317777512637, 
      0.12909847928565363`}, {0.25894548227975384`, -0.95780914026881, 
      0.12469518043785291`}, {0.25894548227975384`, -0.9333064073179054, 
      0.24876974749002326`}, {4.440892098500626*^-16, -0.9662637919863222, 
      0.25755442977400644`}, {4.440892098500626*^-16, -0.9916317777512637, 
      0.12909847928565363`}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.9662637919863222, 
      0.2575544297740062}, {0.25894548227975384`, -0.9333064073179054, 
      0.24876974749002304`}, {0.25894548227975384`, -0.8928026344760273, 
      0.3685792900850116}, {4.440892098500626*^-16, -0.924329729572225, 
      0.38159474711916225`}, {4.440892098500626*^-16, -0.9662637919863222, 
      0.2575544297740062}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.924329729572225, 
      0.38159474711916225`}, {0.25894548227975384`, -0.8928026344760273, 
      0.3685792900850116}, {0.25894548227975384`, -0.8369922372961988, 
      0.48206973760319105`}, {4.440892098500626*^-16, -0.8665485276128188, 
      0.49909282632798474`}, {4.440892098500626*^-16, -0.924329729572225, 
      0.38159474711916225`}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.8665485276128189, 
      0.4990928263279846}, {0.25894548227975384`, -0.8369922372961989, 
      0.48206973760319094`}, {0.25894548227975384`, -0.7668320552307195, 
      0.5872953569351085}, {4.440892098500626*^-16, -0.7939108139557767, 
      0.60803422558609}, {4.440892098500626*^-16, -0.8665485276128189, 
      0.4990928263279846}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.7939108139557766, 
      0.6080342255860901}, {0.25894548227975384`, -0.7668320552307194, 
      0.5872953569351086}, {0.25894548227975384`, -0.6835249471297861, 
      0.682452111036466}, {4.440892098500626*^-16, -0.7076619234072267, 
      0.7065512027868783}, {4.440892098500626*^-16, -0.7939108139557766, 
      0.6080342255860901}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.7076619234072266, 
      0.7065512027868784}, {0.25894548227975384`, -0.683524947129786, 
      0.6824521110364661}, {0.25894548227975384`, -0.5884991688689317, 
      0.76590858817974}, {4.440892098500626*^-16, -0.6092805471316124, 
      0.7929547369724221}, {4.440892098500626*^-16, -0.7076619234072266, 
      0.7065512027868784}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.6092805471316124, 
      0.7929547369724221}, {0.25894548227975384`, -0.5884991688689317, 
      0.76590858817974}, {0.25894548227975384`, -0.48338388666484655`, 
      0.8362339716369411}, {4.440892098500626*^-16, -0.5004533812814214, 
      0.8657634856957137}, {4.440892098500626*^-16, -0.6092805471316124, 
      0.7929547369724221}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.5004533812814214, 
      0.8657634856957137}, {0.25894548227975384`, -0.48338388666484655`, 
      0.8362339716369411}, {0.25894548227975384`, -0.36998124589070147`, 
      0.8922225702682431}, {4.440892098500626*^-16, -0.3830462094924852, 
      0.9237291818457611}, {4.440892098500626*^-16, -0.5004533812814214, 
      0.8657634856957137}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.3830462094924851, 
      0.9237291818457611}, {0.25894548227975384`, -0.36998124589070136`, 
      0.8922225702682431}, {0.25894548227975384`, -0.2502354742562185, 
      0.9329144894526352}, {4.440892098500626*^-16, -0.2590719150200252, 
      0.9658580345205277}, {4.440892098500626*^-16, -0.3830462094924851, 
      0.9237291818457611}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.2590719150200253, 
      0.9658580345205277}, {0.25894548227975384`, -0.2502354742562186, 
      0.9329144894526352}, {0.25894548227975384`, -0.12619954906196634`, 
      0.9576120879685375}, {4.440892098500626*^-16, -0.13065597093028772`, 
      0.9914277670411817}, {4.440892098500626*^-16, -0.2590719150200253, 
      0.9658580345205277}}], 
     Polygon3DBox[{{4.440892098500626*^-16, -0.13065597093028763`, 
      0.9914277670411817}, {0.25894548227975384`, -0.12619954906196626`, 
      0.9576120879685375}, {0.25894548227975384`, -8.042666022167299*^-17, 
      0.9658919386799466}, {4.440892098500626*^-16, -8.326672684688674*^-17, 
      1.}, {4.440892098500626*^-16, -0.13065597093028763`, 
      0.9914277670411817}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0., 1.}, {0.25894548227975384`, 
      0., 0.9658919386799466}, {0.25894548227975384`, 0.12619954906196618`, 
      0.9576120879685376}, {4.440892098500626*^-16, 0.13065597093028755`, 
      0.9914277670411819}, {4.440892098500626*^-16, 0., 1.}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.1306559709302874, 
      0.9914277670411819}, {0.25894548227975384`, 0.12619954906196607`, 
      0.9576120879685376}, {0.25894548227975384`, 0.2502354742562183, 
      0.9329144894526353}, {4.440892098500626*^-16, 0.25907191502002497`, 
      0.9658580345205278}, {4.440892098500626*^-16, 0.1306559709302874, 
      0.9914277670411819}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.2590719150200251, 
      0.9658580345205278}, {0.25894548227975384`, 0.2502354742562184, 
      0.9329144894526353}, {0.25894548227975384`, 0.36998124589070125`, 
      0.8922225702682431}, {4.440892098500626*^-16, 0.38304620949248497`, 
      0.9237291818457611}, {4.440892098500626*^-16, 0.2590719150200251, 
      0.9658580345205278}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.38304620949248486`, 
      0.9237291818457612}, {0.25894548227975384`, 0.36998124589070114`, 
      0.8922225702682433}, {0.25894548227975384`, 0.4833838866648464, 
      0.8362339716369414}, {4.440892098500626*^-16, 0.5004533812814211, 
      0.8657634856957139}, {4.440892098500626*^-16, 0.38304620949248486`, 
      0.9237291818457612}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.5004533812814211, 
      0.8657634856957138}, {0.25894548227975384`, 0.4833838866648464, 
      0.8362339716369412}, {0.25894548227975384`, 0.5884991688689315, 
      0.7659085881797401}, {4.440892098500626*^-16, 0.6092805471316122, 
      0.7929547369724222}, {4.440892098500626*^-16, 0.5004533812814211, 
      0.8657634856957138}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.6092805471316123, 
      0.7929547369724221}, {0.25894548227975384`, 0.5884991688689316, 
      0.76590858817974}, {0.25894548227975384`, 0.6835249471297858, 
      0.6824521110364662}, {4.440892098500626*^-16, 0.7076619234072264, 
      0.7065512027868786}, {4.440892098500626*^-16, 0.6092805471316123, 
      0.7929547369724221}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.7076619234072266, 
      0.7065512027868784}, {0.25894548227975384`, 0.683524947129786, 
      0.6824521110364661}, {0.25894548227975384`, 0.7668320552307194, 
      0.5872953569351087}, {4.440892098500626*^-16, 0.7939108139557766, 
      0.6080342255860902}, {4.440892098500626*^-16, 0.7076619234072266, 
      0.7065512027868784}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.7939108139557763, 
      0.6080342255860904}, {0.25894548227975384`, 0.7668320552307192, 
      0.5872953569351089}, {0.25894548227975384`, 0.8369922372961986, 
      0.4820697376031913}, {4.440892098500626*^-16, 0.8665485276128186, 
      0.49909282632798496`}, {4.440892098500626*^-16, 0.7939108139557763, 
      0.6080342255860904}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.8665485276128186, 
      0.49909282632798496`}, {0.25894548227975384`, 0.8369922372961986, 
      0.4820697376031913}, {0.25894548227975384`, 0.8928026344760271, 
      0.36857929008501183`}, {4.440892098500626*^-16, 0.9243297295722249, 
      0.38159474711916247`}, {4.440892098500626*^-16, 0.8665485276128186, 
      0.49909282632798496`}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.9243297295722249, 
      0.38159474711916247`}, {0.25894548227975384`, 0.8928026344760271, 
      0.36857929008501183`}, {0.25894548227975384`, 0.9333064073179054, 
      0.24876974749002326`}, {4.440892098500626*^-16, 0.9662637919863222, 
      0.25755442977400644`}, {4.440892098500626*^-16, 0.9243297295722249, 
      0.38159474711916247`}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.9662637919863222, 
      0.25755442977400644`}, {0.25894548227975384`, 0.9333064073179054, 
      0.24876974749002326`}, {0.25894548227975384`, 0.95780914026881, 
      0.12469518043785291`}, {4.440892098500626*^-16, 0.9916317777512637, 
      0.12909847928565363`}, {4.440892098500626*^-16, 0.9662637919863222, 
      0.25755442977400644`}}], 
     Polygon3DBox[{{4.440892098500626*^-16, 0.9916317777512637, 
      0.12909847928565363`}, {0.25894548227975384`, 0.95780914026881, 
      0.12469518043785291`}, {0.25894548227975384`, 
      0.9658907470587755, -0.0015172188854276705`}, {4.440892098500626*^-16, 
      0.9999987662997035, -0.0015707956808307198`}, {4.440892098500626*^-16, 
      0.9916317777512637, 0.12909847928565363`}}], 
     Polygon3DBox[{{
      0.2589454822797537, -0.9658907470587755, -0.0015172188854276705`}, {
      0.5002267077832099, -0.8658934061595418, -0.0013601433004644015`}, {
      0.5002267077832099, -0.8586484770079641, 0.11178565986867339`}, {
      0.2589454822797537, -0.95780914026881, 0.12469518043785291`}, {
      0.2589454822797537, -0.9658907470587755, -0.0015172188854276705`}}], 
     Polygon3DBox[{{0.2589454822797537, -0.95780914026881, 
      0.12469518043785291`}, {0.5002267077832099, -0.8586484770079641, 
      0.11178565986867339`}, {0.5002267077832099, -0.8366824783070931, 
      0.22301495760211226`}, {0.2589454822797537, -0.9333064073179054, 
      0.24876974749002326`}, {0.2589454822797537, -0.95780914026881, 
      0.12469518043785291`}}], 
     Polygon3DBox[{{0.2589454822797537, -0.9333064073179054, 
      0.24876974749002304`}, {0.5002267077832099, -0.8366824783070931, 
      0.22301495760211207`}, {0.5002267077832099, -0.8003720053730025, 
      0.33042078299581834`}, {0.2589454822797537, -0.8928026344760273, 
      0.3685792900850116}, {0.2589454822797537, -0.9333064073179054, 
      0.24876974749002304`}}], 
     Polygon3DBox[{{0.2589454822797537, -0.8928026344760273, 
      0.3685792900850116}, {0.5002267077832099, -0.8003720053730025, 
      0.33042078299581834`}, {0.5002267077832099, -0.7503395818713641, 
      0.4321617205369741}, {0.2589454822797537, -0.8369922372961988, 
      0.48206973760319105`}, {0.2589454822797537, -0.8928026344760273, 
      0.3685792900850116}}], 
     Polygon3DBox[{{0.2589454822797537, -0.8369922372961989, 
      0.48206973760319094`}, {0.5002267077832099, -0.7503395818713641, 
      0.432161720536974}, {0.5002267077832099, -0.6874429869816786, 
      0.5264934761894764}, {0.2589454822797537, -0.7668320552307195, 
      0.5872953569351085}, {0.2589454822797537, -0.8369922372961989, 
      0.48206973760319094`}}], 
     Polygon3DBox[{{0.2589454822797537, -0.7668320552307194, 
      0.5872953569351086}, {0.5002267077832099, -0.6874429869816785, 
      0.5264934761894765}, {0.5002267077832099, -0.6127605492313676, 
      0.6117987823835904}, {0.2589454822797537, -0.6835249471297861, 
      0.682452111036466}, {0.2589454822797537, -0.7668320552307194, 
      0.5872953569351086}}], 
     Polygon3DBox[{{0.2589454822797537, -0.683524947129786, 
      0.6824521110364661}, {0.5002267077832099, -0.6127605492313675, 
      0.6117987823835905}, {0.5002267077832099, -0.5275726591290871, 
      0.6866151252046777}, {0.2589454822797537, -0.5884991688689317, 
      0.76590858817974}, {0.2589454822797537, -0.683524947129786, 
      0.6824521110364661}}], 
     Polygon3DBox[{{0.2589454822797537, -0.5884991688689317, 
      0.76590858817974}, {0.5002267077832099, -0.5275726591290871, 
      0.6866151252046777}, {0.5002267077832099, -0.4333398175532912, 
      0.7496598184131595}, {0.2589454822797537, -0.48338388666484655`, 
      0.8362339716369411}, {0.2589454822797537, -0.5884991688689317, 
      0.76590858817974}}], 
     Polygon3DBox[{{0.2589454822797537, -0.48338388666484655`, 
      0.8362339716369411}, {0.5002267077832099, -0.4333398175532912, 
      0.7496598184131595}, {0.5002267077832099, -0.3316775962446982, 
      0.7998519944150355}, {0.2589454822797537, -0.36998124589070147`, 
      0.8922225702682431}, {0.2589454822797537, -0.48338388666484655`, 
      0.8362339716369411}}], 
     Polygon3DBox[{{0.2589454822797537, -0.36998124589070136`, 
      0.8922225702682431}, {0.5002267077832099, -0.33167759624469817`, 
      0.7998519944150355}, {0.5002267077832099, -0.22432893969164439`, 
      0.8363311351595094}, {0.2589454822797537, -0.2502354742562185, 
      0.9329144894526352}, {0.2589454822797537, -0.36998124589070136`, 
      0.8922225702682431}}], 
     Polygon3DBox[{{0.2589454822797537, -0.2502354742562186, 
      0.9329144894526352}, {0.5002267077832099, -0.22432893969164447`, 
      0.8363311351595094}, {0.5002267077832099, -0.11313428327770773`, 
      0.8584718252613829}, {0.2589454822797537, -0.12619954906196634`, 
      0.9576120879685375}, {0.2589454822797537, -0.2502354742562186, 
      0.9329144894526352}}], 
     Polygon3DBox[{{0.2589454822797537, -0.12619954906196626`, 
      0.9576120879685375}, {0.5002267077832099, -0.11313428327770766`, 
      0.8584718252613829}, {0.5002267077832099, -7.210019867924341*^-17, 
      0.8658944744138116}, {0.2589454822797537, -8.042666022167299*^-17, 
      0.9658919386799466}, {0.2589454822797537, -0.12619954906196626`, 
      0.9576120879685375}}], 
     Polygon3DBox[{{0.2589454822797537, 0., 0.9658919386799466}, {
      0.5002267077832099, 0., 0.8658944744138116}, {0.5002267077832099, 
      0.1131342832777076, 0.858471825261383}, {0.2589454822797537, 
      0.12619954906196618`, 0.9576120879685376}, {0.2589454822797537, 0., 
      0.9658919386799466}}], 
     Polygon3DBox[{{0.2589454822797537, 0.12619954906196607`, 
      0.9576120879685376}, {0.5002267077832099, 0.11313428327770747`, 
      0.858471825261383}, {0.5002267077832099, 0.2243289396916442, 
      0.8363311351595095}, {0.2589454822797537, 0.2502354742562183, 
      0.9329144894526353}, {0.2589454822797537, 0.12619954906196607`, 
      0.9576120879685376}}], 
     Polygon3DBox[{{0.2589454822797537, 0.2502354742562184, 
      0.9329144894526353}, {0.5002267077832099, 0.22432893969164427`, 
      0.8363311351595095}, {0.5002267077832099, 0.33167759624469806`, 
      0.7998519944150355}, {0.2589454822797537, 0.36998124589070125`, 
      0.8922225702682431}, {0.2589454822797537, 0.2502354742562184, 
      0.9329144894526353}}], 
     Polygon3DBox[{{0.2589454822797537, 0.36998124589070114`, 
      0.8922225702682433}, {0.5002267077832099, 0.33167759624469795`, 
      0.7998519944150356}, {0.5002267077832099, 0.43333981755329104`, 
      0.7496598184131598}, {0.2589454822797537, 0.4833838866648464, 
      0.8362339716369414}, {0.2589454822797537, 0.36998124589070114`, 
      0.8922225702682433}}], 
     Polygon3DBox[{{0.2589454822797537, 0.4833838866648464, 
      0.8362339716369412}, {0.5002267077832099, 0.43333981755329104`, 
      0.7496598184131597}, {0.5002267077832099, 0.5275726591290869, 
      0.6866151252046778}, {0.2589454822797537, 0.5884991688689315, 
      0.7659085881797401}, {0.2589454822797537, 0.4833838866648464, 
      0.8362339716369412}}], 
     Polygon3DBox[{{0.2589454822797537, 0.5884991688689316, 
      0.76590858817974}, {0.5002267077832099, 0.527572659129087, 
      0.6866151252046777}, {0.5002267077832099, 0.6127605492313674, 
      0.6117987823835906}, {0.2589454822797537, 0.6835249471297858, 
      0.6824521110364662}, {0.2589454822797537, 0.5884991688689316, 
      0.76590858817974}}], 
     Polygon3DBox[{{0.2589454822797537, 0.683524947129786, 
      0.6824521110364661}, {0.5002267077832099, 0.6127605492313675, 
      0.6117987823835905}, {0.5002267077832099, 0.6874429869816785, 
      0.5264934761894765}, {0.2589454822797537, 0.7668320552307194, 
      0.5872953569351087}, {0.2589454822797537, 0.683524947129786, 
      0.6824521110364661}}], 
     Polygon3DBox[{{0.2589454822797537, 0.7668320552307192, 
      0.5872953569351089}, {0.5002267077832099, 0.6874429869816784, 
      0.5264934761894767}, {0.5002267077832099, 0.750339581871364, 
      0.4321617205369743}, {0.2589454822797537, 0.8369922372961986, 
      0.4820697376031913}, {0.2589454822797537, 0.7668320552307192, 
      0.5872953569351089}}], 
     Polygon3DBox[{{0.2589454822797537, 0.8369922372961986, 
      0.4820697376031913}, {0.5002267077832099, 0.750339581871364, 
      0.4321617205369743}, {0.5002267077832099, 0.8003720053730023, 
      0.33042078299581856`}, {0.2589454822797537, 0.8928026344760271, 
      0.36857929008501183`}, {0.2589454822797537, 0.8369922372961986, 
      0.4820697376031913}}], 
     Polygon3DBox[{{0.2589454822797537, 0.8928026344760271, 
      0.36857929008501183`}, {0.5002267077832099, 0.8003720053730023, 
      0.33042078299581856`}, {0.5002267077832099, 0.8366824783070931, 
      0.22301495760211226`}, {0.2589454822797537, 0.9333064073179054, 
      0.24876974749002326`}, {0.2589454822797537, 0.8928026344760271, 
      0.36857929008501183`}}], 
     Polygon3DBox[{{0.2589454822797537, 0.9333064073179054, 
      0.24876974749002326`}, {0.5002267077832099, 0.8366824783070931, 
      0.22301495760211226`}, {0.5002267077832099, 0.8586484770079641, 
      0.11178565986867339`}, {0.2589454822797537, 0.95780914026881, 
      0.12469518043785291`}, {0.2589454822797537, 0.9333064073179054, 
      0.24876974749002326`}}], 
     Polygon3DBox[{{0.2589454822797537, 0.95780914026881, 
      0.12469518043785291`}, {0.5002267077832099, 0.8586484770079641, 
      0.11178565986867339`}, {0.5002267077832099, 
      0.8658934061595418, -0.0013601433004644015`}, {0.2589454822797537, 
      0.9658907470587755, -0.0015172188854276705`}, {0.2589454822797537, 
      0.95780914026881, 0.12469518043785291`}}], 
     Polygon3DBox[{{
      0.5002267077832102, -0.8658934061595417, -0.0013601433004644013`}, {
      0.7073844068406702, -0.706828174472469, -0.001110284013308533}, {
      0.7073844068406702, -0.700914143934802, 0.09125055501648718}, {
      0.5002267077832102, -0.858648477007964, 0.11178565986867338`}, {
      0.5002267077832102, -0.8658934061595417, -0.0013601433004644013`}}], 
     Polygon3DBox[{{0.5002267077832102, -0.858648477007964, 
      0.11178565986867338`}, {0.7073844068406702, -0.700914143934802, 
      0.09125055501648718}, {0.7073844068406702, -0.6829833147452555, 
      0.18204695201583737`}, {0.5002267077832102, -0.836682478307093, 
      0.22301495760211223`}, {0.5002267077832102, -0.858648477007964, 
      0.11178565986867338`}}], 
     Polygon3DBox[{{0.5002267077832102, -0.836682478307093, 
      0.22301495760211204`}, {0.7073844068406702, -0.6829833147452555, 
      0.1820469520158372}, {0.7073844068406702, -0.6533431013937446, 
      0.26972225125094224`}, {0.5002267077832102, -0.8003720053730023, 
      0.3304207829958183}, {0.5002267077832102, -0.836682478307093, 
      0.22301495760211204`}}], 
     Polygon3DBox[{{0.5002267077832102, -0.8003720053730023, 
      0.3304207829958183}, {0.7073844068406702, -0.6533431013937446, 
      0.26972225125094224`}, {0.7073844068406702, -0.6125016695078658, 
      0.3527733065422473}, {0.5002267077832102, -0.750339581871364, 
      0.43216172053697405`}, {0.5002267077832102, -0.8003720053730023, 
      0.3304207829958183}}], 
     Polygon3DBox[{{0.5002267077832102, -0.7503395818713641, 
      0.43216172053697394`}, {0.7073844068406702, -0.6125016695078659, 
      0.3527733065422472}, {0.7073844068406702, -0.5611592236246141, 
      0.42977625190288676`}, {0.5002267077832102, -0.6874429869816785, 
      0.5264934761894763}, {0.5002267077832102, -0.7503395818713641, 
      0.43216172053697394`}}], 
     Polygon3DBox[{{0.5002267077832102, -0.6874429869816784, 
      0.5264934761894764}, {0.7073844068406702, -0.561159223624614, 
      0.4297762519028869}, {0.7073844068406702, -0.5001960025575628, 
      0.49941091296056783`}, {0.5002267077832102, -0.6127605492313675, 
      0.6117987823835903}, {0.5002267077832102, -0.6874429869816784, 
      0.5264934761894764}}], 
     Polygon3DBox[{{0.5002267077832102, -0.6127605492313674, 
      0.6117987823835904}, {0.7073844068406702, -0.5001960025575628, 
      0.4994109129605679}, {0.7073844068406702, -0.4306571881725254, 
      0.5604834406421009}, {0.5002267077832102, -0.527572659129087, 
      0.6866151252046776}, {0.5002267077832102, -0.6127605492313674, 
      0.6117987823835904}}], 
     Polygon3DBox[{{0.5002267077832102, -0.527572659129087, 
      0.6866151252046776}, {0.7073844068406702, -0.4306571881725254, 
      0.5604834406421009}, {0.7073844068406702, -0.353734986302679, 
      0.6119467790781457}, {0.5002267077832102, -0.43333981755329115`, 
      0.7496598184131594}, {0.5002267077832102, -0.527572659129087, 
      0.6866151252046776}}], 
     Polygon3DBox[{{0.5002267077832102, -0.43333981755329115`, 
      0.7496598184131594}, {0.7073844068406702, -0.353734986302679, 
      0.6119467790781457}, {0.7073844068406702, -0.27074818701629083`, 
      0.6529186168168778}, {0.5002267077832102, -0.3316775962446982, 
      0.7998519944150354}, {0.5002267077832102, -0.43333981755329115`, 
      0.7496598184131594}}], 
     Polygon3DBox[{{0.5002267077832102, -0.3316775962446981, 
      0.7998519944150354}, {0.7073844068406702, -0.2707481870162907, 
      0.6529186168168778}, {0.7073844068406702, -0.1831195546653399, 
      0.6826965135826027}, {0.5002267077832102, -0.22432893969164436`, 
      0.8363311351595093}, {0.5002267077832102, -0.3316775962446981, 
      0.7998519944150354}}], 
     Polygon3DBox[{{0.5002267077832102, -0.22432893969164444`, 
      0.8363311351595093}, {0.7073844068406702, -0.18311955466534, 
      0.6826965135826027}, {0.7073844068406702, -0.09235143535057641, 
      0.7007699432391215}, {0.5002267077832102, -0.11313428327770772`, 
      0.8584718252613828}, {0.5002267077832102, -0.22432893969164444`, 
      0.8363311351595093}}], 
     Polygon3DBox[{{0.5002267077832102, -0.11313428327770765`, 
      0.8584718252613828}, {0.7073844068406702, -0.09235143535057636, 
      0.7007699432391215}, {0.7073844068406702, -5.885534114133449*^-17, 
      0.7068290464876732}, {0.5002267077832102, -7.210019867924341*^-17, 
      0.8658944744138115}, {0.5002267077832102, -0.11313428327770765`, 
      0.8584718252613828}}], 
     Polygon3DBox[{{0.5002267077832102, 0., 0.8658944744138115}, {
      0.7073844068406702, 0., 0.7068290464876732}, {0.7073844068406702, 
      0.0923514353505763, 0.7007699432391216}, {0.5002267077832102, 
      0.11313428327770758`, 0.8584718252613829}, {0.5002267077832102, 0., 
      0.8658944744138115}}], 
     Polygon3DBox[{{0.5002267077832102, 0.11313428327770746`, 
      0.8584718252613829}, {0.7073844068406702, 0.0923514353505762, 
      0.7007699432391216}, {0.7073844068406702, 0.18311955466533975`, 
      0.6826965135826027}, {0.5002267077832102, 0.22432893969164416`, 
      0.8363311351595094}, {0.5002267077832102, 0.11313428327770746`, 
      0.8584718252613829}}], 
     Polygon3DBox[{{0.5002267077832102, 0.22432893969164425`, 
      0.8363311351595094}, {0.7073844068406702, 0.18311955466533983`, 
      0.6826965135826027}, {0.7073844068406702, 0.27074818701629066`, 
      0.6529186168168778}, {0.5002267077832102, 0.331677596244698, 
      0.7998519944150354}, {0.5002267077832102, 0.22432893969164425`, 
      0.8363311351595094}}], 
     Polygon3DBox[{{0.5002267077832102, 0.3316775962446979, 
      0.7998519944150355}, {0.7073844068406702, 0.2707481870162906, 
      0.6529186168168779}, {0.7073844068406702, 0.35373498630267886`, 
      0.6119467790781458}, {0.5002267077832102, 0.433339817553291, 
      0.7496598184131597}, {0.5002267077832102, 0.3316775962446979, 
      0.7998519944150355}}], 
     Polygon3DBox[{{0.5002267077832102, 0.433339817553291, 
      0.7496598184131595}, {0.7073844068406702, 0.35373498630267886`, 
      0.6119467790781457}, {0.7073844068406702, 0.43065718817252524`, 
      0.5604834406421009}, {0.5002267077832102, 0.5275726591290868, 
      0.6866151252046777}, {0.5002267077832102, 0.433339817553291, 
      0.7496598184131595}}], 
     Polygon3DBox[{{0.5002267077832102, 0.5275726591290869, 
      0.6866151252046776}, {0.7073844068406702, 0.43065718817252535`, 
      0.5604834406421009}, {0.7073844068406702, 0.5001960025575627, 
      0.499410912960568}, {0.5002267077832102, 0.6127605492313672, 
      0.6117987823835905}, {0.5002267077832102, 0.5275726591290869, 
      0.6866151252046776}}], 
     Polygon3DBox[{{0.5002267077832102, 0.6127605492313674, 
      0.6117987823835904}, {0.7073844068406702, 0.5001960025575628, 
      0.4994109129605679}, {0.7073844068406702, 0.561159223624614, 
      0.42977625190288693`}, {0.5002267077832102, 0.6874429869816784, 
      0.5264934761894765}, {0.5002267077832102, 0.6127605492313674, 
      0.6117987823835904}}], 
     Polygon3DBox[{{0.5002267077832102, 0.6874429869816783, 
      0.5264934761894767}, {0.7073844068406702, 0.5611592236246139, 
      0.4297762519028871}, {0.7073844068406702, 0.6125016695078658, 
      0.3527733065422475}, {0.5002267077832102, 0.7503395818713638, 
      0.43216172053697427`}, {0.5002267077832102, 0.6874429869816783, 
      0.5264934761894767}}], 
     Polygon3DBox[{{0.5002267077832102, 0.7503395818713638, 
      0.43216172053697427`}, {0.7073844068406702, 0.6125016695078658, 
      0.3527733065422475}, {0.7073844068406702, 0.6533431013937445, 
      0.2697222512509424}, {0.5002267077832102, 0.8003720053730022, 
      0.3304207829958185}, {0.5002267077832102, 0.7503395818713638, 
      0.43216172053697427`}}], 
     Polygon3DBox[{{0.5002267077832102, 0.8003720053730022, 
      0.3304207829958185}, {0.7073844068406702, 0.6533431013937445, 
      0.2697222512509424}, {0.7073844068406702, 0.6829833147452555, 
      0.18204695201583737`}, {0.5002267077832102, 0.836682478307093, 
      0.22301495760211223`}, {0.5002267077832102, 0.8003720053730022, 
      0.3304207829958185}}], 
     Polygon3DBox[{{0.5002267077832102, 0.836682478307093, 
      0.22301495760211223`}, {0.7073844068406702, 0.6829833147452555, 
      0.18204695201583737`}, {0.7073844068406702, 0.700914143934802, 
      0.09125055501648718}, {0.5002267077832102, 0.858648477007964, 
      0.11178565986867338`}, {0.5002267077832102, 0.836682478307093, 
      0.22301495760211223`}}], 
     Polygon3DBox[{{0.5002267077832102, 0.858648477007964, 
      0.11178565986867338`}, {0.7073844068406702, 0.700914143934802, 
      0.09125055501648718}, {0.7073844068406702, 
      0.706828174472469, -0.001110284013308533}, {0.5002267077832102, 
      0.8658934061595417, -0.0013601433004644013`}, {0.5002267077832102, 
      0.858648477007964, 0.11178565986867338`}}], 
     Polygon3DBox[{{
      0.70738440684067, -0.7068281744724692, -0.0011102840133085333`}, {
      0.8662870844473877, -0.49954586535009987`, -0.0007846854557354606}, {
      0.8662870844473877, -0.4953661656587984, 0.06449069111231853}, {
      0.70738440684067, -0.7009141439348021, 0.0912505550164872}, {
      0.70738440684067, -0.7068281744724692, -0.0011102840133085333`}}], 
     Polygon3DBox[{{0.70738440684067, -0.7009141439348021, 
      0.0912505550164872}, {0.8662870844473877, -0.4953661656587984, 
      0.06449069111231853}, {0.8662870844473877, -0.48269367762360943`, 
      0.1286604092245926}, {0.70738440684067, -0.6829833147452556, 
      0.1820469520158374}, {0.70738440684067, -0.7009141439348021, 
      0.0912505550164872}}], 
     Polygon3DBox[{{0.70738440684067, -0.6829833147452556, 
      0.18204695201583723`}, {0.8662870844473877, -0.48269367762360943`, 
      0.1286604092245925}, {0.8662870844473877, -0.4617456642837439, 
      0.19062431333596633`}, {0.70738440684067, -0.6533431013937447, 
      0.2697222512509423}, {0.70738440684067, -0.6829833147452556, 
      0.18204695201583723`}}], 
     Polygon3DBox[{{0.70738440684067, -0.6533431013937447, 
      0.2697222512509423}, {0.8662870844473877, -0.4617456642837439, 
      0.19062431333596633`}, {0.8662870844473877, -0.4328812681399493, 
      0.24932006540427887`}, {0.70738440684067, -0.6125016695078659, 
      0.35277330654224737`}, {0.70738440684067, -0.6533431013937447, 
      0.2697222512509423}}], 
     Polygon3DBox[{{0.70738440684067, -0.612501669507866, 
      0.35277330654224726`}, {0.8662870844473877, -0.43288126813994937`, 
      0.24932006540427878`}, {0.8662870844473877, -0.39659535384814626`, 
      0.30374135810868474`}, {0.70738440684067, -0.5611592236246142, 
      0.4297762519028868}, {0.70738440684067, -0.612501669507866, 
      0.35277330654224726`}}], 
     Polygon3DBox[{{0.70738440684067, -0.5611592236246141, 
      0.42977625190288693`}, {0.8662870844473877, -0.3965953538481462, 
      0.3037413581086848}, {0.8662870844473877, -0.3535100240292006, 
      0.35295516745121974`}, {0.70738440684067, -0.5001960025575629, 
      0.4994109129605679}, {0.70738440684067, -0.5611592236246141, 
      0.42977625190288693`}}], 
     Polygon3DBox[{{0.70738440684067, -0.5001960025575628, 
      0.499410912960568}, {0.8662870844473877, -0.35351002402920056`, 
      0.3529551674512198}, {0.8662870844473877, -0.3043639536517435, 
      0.3961177489549338}, {0.70738440684067, -0.43065718817252546`, 
      0.5604834406421009}, {0.70738440684067, -0.5001960025575628, 
      0.499410912960568}}], 
     Polygon3DBox[{{0.70738440684067, -0.43065718817252546`, 
      0.5604834406421009}, {0.8662870844473877, -0.3043639536517435, 
      0.3961177489549338}, {0.8662870844473877, -0.24999972584434701`, 
      0.432489103212319}, {0.70738440684067, -0.3537349863026791, 
      0.6119467790781458}, {0.70738440684067, -0.43065718817252546`, 
      0.5604834406421009}}], 
     Polygon3DBox[{{0.70738440684067, -0.3537349863026791, 
      0.6119467790781458}, {0.8662870844473877, -0.24999972584434701`, 
      0.432489103212319}, {0.8662870844473877, -0.1913493862577937, 
      0.4614456627799315}, {0.70738440684067, -0.2707481870162909, 
      0.6529186168168779}, {0.70738440684067, -0.3537349863026791, 
      0.6119467790781458}}], 
     Polygon3DBox[{{0.70738440684067, -0.2707481870162908, 
      0.6529186168168779}, {0.8662870844473877, -0.19134938625779366`, 
      0.4614456627799315}, {0.8662870844473877, -0.12941846364018297`, 
      0.4824909829091723}, {0.70738440684067, -0.18311955466533994`, 
      0.6826965135826029}, {0.70738440684067, -0.2707481870162908, 
      0.6529186168168779}}], 
     Polygon3DBox[{{0.70738440684067, -0.18311955466534002`, 
      0.6826965135826029}, {0.8662870844473877, -0.12941846364018303`, 
      0.4824909829091723}, {0.8662870844473877, -0.06526873058358035, 
      0.49526425282635994`}, {0.70738440684067, -0.09235143535057642, 
      0.7007699432391216}, {0.70738440684067, -0.18311955466534002`, 
      0.6826965135826029}}], 
     Polygon3DBox[{{0.70738440684067, -0.09235143535057637, 
      0.7007699432391216}, {0.8662870844473877, -0.0652687305835803, 
      0.49526425282635994`}, {0.8662870844473877, -4.159560043410302*^-17, 
      0.4995464816407424}, {0.70738440684067, -5.88553411413345*^-17, 
      0.7068290464876733}, {0.70738440684067, -0.09235143535057637, 
      0.7007699432391216}}], 
     Polygon3DBox[{{0.70738440684067, 0., 0.7068290464876733}, {
      0.8662870844473877, 0., 0.4995464816407424}, {0.8662870844473877, 
      0.06526873058358026, 0.49526425282636}, {0.70738440684067, 
      0.09235143535057631, 0.7007699432391217}, {0.70738440684067, 0., 
      0.7068290464876733}}], 
     Polygon3DBox[{{0.70738440684067, 0.09235143535057622, 
      0.7007699432391217}, {0.8662870844473877, 0.0652687305835802, 
      0.49526425282636}, {0.8662870844473877, 0.12941846364018286`, 
      0.48249098290917236`}, {0.70738440684067, 0.18311955466533977`, 
      0.6826965135826029}, {0.70738440684067, 0.09235143535057622, 
      0.7007699432391217}}], 
     Polygon3DBox[{{0.70738440684067, 0.18311955466533986`, 
      0.6826965135826029}, {0.8662870844473877, 0.12941846364018292`, 
      0.48249098290917236`}, {0.8662870844473877, 0.1913493862577936, 
      0.4614456627799315}, {0.70738440684067, 0.2707481870162907, 
      0.6529186168168779}, {0.70738440684067, 0.18311955466533986`, 
      0.6826965135826029}}], 
     Polygon3DBox[{{0.70738440684067, 0.2707481870162906, 
      0.652918616816878}, {0.8662870844473877, 0.19134938625779355`, 
      0.46144566277993154`}, {0.8662870844473877, 0.2499997258443469, 
      0.4324891032123191}, {0.70738440684067, 0.3537349863026789, 
      0.6119467790781459}, {0.70738440684067, 0.2707481870162906, 
      0.652918616816878}}], 
     Polygon3DBox[{{0.70738440684067, 0.3537349863026789, 
      0.6119467790781458}, {0.8662870844473877, 0.2499997258443469, 
      0.43248910321231904`}, {0.8662870844473877, 0.3043639536517434, 
      0.39611774895493385`}, {0.70738440684067, 0.43065718817252535`, 
      0.560483440642101}, {0.70738440684067, 0.3537349863026789, 
      0.6119467790781458}}], 
     Polygon3DBox[{{0.70738440684067, 0.4306571881725254, 
      0.5604834406421009}, {0.8662870844473877, 0.30436395365174346`, 
      0.3961177489549338}, {0.8662870844473877, 0.3535100240292005, 
      0.35295516745121985`}, {0.70738440684067, 0.5001960025575628, 
      0.49941091296056805`}, {0.70738440684067, 0.4306571881725254, 
      0.5604834406421009}}], 
     Polygon3DBox[{{0.70738440684067, 0.5001960025575628, 
      0.499410912960568}, {0.8662870844473877, 0.35351002402920056`, 
      0.3529551674512198}, {0.8662870844473877, 0.3965953538481462, 
      0.30374135810868486`}, {0.70738440684067, 0.5611592236246141, 
      0.429776251902887}, {0.70738440684067, 0.5001960025575628, 
      0.499410912960568}}], 
     Polygon3DBox[{{0.70738440684067, 0.561159223624614, 
      0.42977625190288715`}, {0.8662870844473877, 0.3965953538481461, 
      0.30374135810868497`}, {0.8662870844473877, 0.43288126813994926`, 
      0.24932006540427898`}, {0.70738440684067, 0.6125016695078659, 
      0.35277330654224753`}, {0.70738440684067, 0.561159223624614, 
      0.42977625190288715`}}], 
     Polygon3DBox[{{0.70738440684067, 0.6125016695078659, 
      0.35277330654224753`}, {0.8662870844473877, 0.43288126813994926`, 
      0.24932006540427898`}, {0.8662870844473877, 0.46174566428374386`, 
      0.19062431333596644`}, {0.70738440684067, 0.6533431013937446, 
      0.2697222512509424}, {0.70738440684067, 0.6125016695078659, 
      0.35277330654224753`}}], 
     Polygon3DBox[{{0.70738440684067, 0.6533431013937446, 
      0.2697222512509424}, {0.8662870844473877, 0.46174566428374386`, 
      0.19062431333596644`}, {0.8662870844473877, 0.48269367762360943`, 
      0.1286604092245926}, {0.70738440684067, 0.6829833147452556, 
      0.1820469520158374}, {0.70738440684067, 0.6533431013937446, 
      0.2697222512509424}}], 
     Polygon3DBox[{{0.70738440684067, 0.6829833147452556, 
      0.1820469520158374}, {0.8662870844473877, 0.48269367762360943`, 
      0.1286604092245926}, {0.8662870844473877, 0.4953661656587984, 
      0.06449069111231853}, {0.70738440684067, 0.7009141439348021, 
      0.0912505550164872}, {0.70738440684067, 0.6829833147452556, 
      0.1820469520158374}}], 
     Polygon3DBox[{{0.70738440684067, 0.7009141439348021, 
      0.0912505550164872}, {0.8662870844473877, 0.4953661656587984, 
      0.06449069111231853}, {0.8662870844473877, 
      0.49954586535009987`, -0.0007846854557354606}, {0.70738440684067, 
      0.7068281744724692, -0.0011102840133085333`}, {0.70738440684067, 
      0.7009141439348021, 0.0912505550164872}}], 
     Polygon3DBox[{{
      0.8662870844473877, -0.49954586535009987`, -0.0007846854557354606}, {
      0.966095016059902, -0.2581864742126502, -0.0004055586988800299}, {
      0.966095016059902, -0.25602622827445476`, 0.033331522314086724`}, {
      0.8662870844473877, -0.4953661656587984, 0.06449069111231853}, {
      0.8662870844473877, -0.49954586535009987`, -0.0007846854557354606}}], 
     Polygon3DBox[{{0.8662870844473877, -0.4953661656587984, 
      0.06449069111231853}, {0.966095016059902, -0.25602622827445476`, 
      0.033331522314086724`}, {0.966095016059902, -0.24947654939158706`, 
      0.06649715217875668}, {0.8662870844473877, -0.48269367762360943`, 
      0.1286604092245926}, {0.8662870844473877, -0.4953661656587984, 
      0.06449069111231853}}], 
     Polygon3DBox[{{0.8662870844473877, -0.48269367762360943`, 
      0.1286604092245925}, {0.966095016059902, -0.24947654939158706`, 
      0.06649715217875662}, {0.966095016059902, -0.23864972831042575`, 
      0.098522723884278}, {0.8662870844473877, -0.4617456642837439, 
      0.19062431333596633`}, {0.8662870844473877, -0.48269367762360943`, 
      0.1286604092245925}}], 
     Polygon3DBox[{{0.8662870844473877, -0.4617456642837439, 
      0.19062431333596633`}, {0.966095016059902, -0.23864972831042575`, 
      0.098522723884278}, {0.966095016059902, -0.2237313850959931, 
      0.12885917610805267`}, {0.8662870844473877, -0.4328812681399493, 
      0.24932006540427887`}, {0.8662870844473877, -0.4617456642837439, 
      0.19062431333596633`}}], 
     Polygon3DBox[{{0.8662870844473877, -0.43288126813994937`, 
      0.24932006540427878`}, {0.966095016059902, -0.22373138509599313`, 
      0.12885917610805264`}, {0.966095016059902, -0.20497728677507668`, 
      0.15698640657886806`}, {0.8662870844473877, -0.39659535384814626`, 
      0.30374135810868474`}, {0.8662870844473877, -0.43288126813994937`, 
      0.24932006540427878`}}], 
     Polygon3DBox[{{0.8662870844473877, -0.3965953538481462, 
      0.3037413581086848}, {0.966095016059902, -0.20497728677507665`, 
      0.1569864065788681}, {0.966095016059902, -0.18270896234715536`, 
      0.1824221889525599}, {0.8662870844473877, -0.3535100240292006, 
      0.35295516745121974`}, {0.8662870844473877, -0.3965953538481462, 
      0.3037413581086848}}], 
     Polygon3DBox[{{0.8662870844473877, -0.35351002402920056`, 
      0.3529551674512198}, {0.966095016059902, -0.18270896234715533`, 
      0.18242218895255993`}, {0.966095016059902, -0.15730819034142648`, 
      0.204730440325134}, {0.8662870844473877, -0.3043639536517435, 
      0.3961177489549338}, {0.8662870844473877, -0.35351002402920056`, 
      0.3529551674512198}}], 
     Polygon3DBox[{{0.8662870844473877, -0.3043639536517435, 
      0.3961177489549338}, {0.966095016059902, -0.15730819034142648`, 
      0.204730440325134}, {0.966095016059902, -0.12921045342782397`, 
      0.22352869764125105`}, {0.8662870844473877, -0.24999972584434701`, 
      0.432489103212319}, {0.8662870844473877, -0.3043639536517435, 
      0.3961177489549338}}], 
     Polygon3DBox[{{0.8662870844473877, -0.24999972584434701`, 
      0.432489103212319}, {0.966095016059902, -0.12921045342782397`, 
      0.22352869764125105`}, {0.966095016059902, -0.09889747229922581, 
      0.23849467481904407`}, {0.8662870844473877, -0.1913493862577937, 
      0.4614456627799315}, {0.8662870844473877, -0.24999972584434701`, 
      0.432489103212319}}], 
     Polygon3DBox[{{0.8662870844473877, -0.19134938625779366`, 
      0.4614456627799315}, {0.966095016059902, -0.09889747229922578, 
      0.23849467481904407`}, {0.966095016059902, -0.06688894682745315, 
      0.24937178817286418`}, {0.8662870844473877, -0.12941846364018297`, 
      0.4824909829091723}, {0.8662870844473877, -0.19134938625779366`, 
      0.4614456627799315}}], 
     Polygon3DBox[{{0.8662870844473877, -0.12941846364018303`, 
      0.4824909829091723}, {0.966095016059902, -0.06688894682745318, 
      0.24937178817286418`}, {0.966095016059902, -0.03373364608653068, 
      0.25597355540353456`}, {0.8662870844473877, -0.06526873058358035, 
      0.49526425282635994`}, {0.8662870844473877, -0.12941846364018303`, 
      0.4824909829091723}}], 
     Polygon3DBox[{{0.8662870844473877, -0.0652687305835803, 
      0.49526425282635994`}, {0.966095016059902, -0.03373364608653066, 
      0.25597355540353456`}, {0.966095016059902, -2.1498369146369897`*^-17, 
      0.2581867927377729}, {0.8662870844473877, -4.159560043410302*^-17, 
      0.4995464816407424}, {0.8662870844473877, -0.0652687305835803, 
      0.49526425282635994`}}], 
     Polygon3DBox[{{0.8662870844473877, 0., 0.4995464816407424}, {
      0.966095016059902, 0., 0.2581867927377729}, {0.966095016059902, 
      0.033733646086530636`, 0.2559735554035346}, {0.8662870844473877, 
      0.06526873058358026, 0.49526425282636}, {0.8662870844473877, 0., 
      0.4995464816407424}}], 
     Polygon3DBox[{{0.8662870844473877, 0.0652687305835802, 
      0.49526425282636}, {0.966095016059902, 0.033733646086530594`, 
      0.2559735554035346}, {0.966095016059902, 0.0668889468274531, 
      0.2493717881728642}, {0.8662870844473877, 0.12941846364018286`, 
      0.48249098290917236`}, {0.8662870844473877, 0.0652687305835802, 
      0.49526425282636}}], 
     Polygon3DBox[{{0.8662870844473877, 0.12941846364018292`, 
      0.48249098290917236`}, {0.966095016059902, 0.06688894682745312, 
      0.2493717881728642}, {0.966095016059902, 0.09889747229922576, 
      0.23849467481904407`}, {0.8662870844473877, 0.1913493862577936, 
      0.4614456627799315}, {0.8662870844473877, 0.12941846364018292`, 
      0.48249098290917236`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.19134938625779355`, 
      0.46144566277993154`}, {0.966095016059902, 0.09889747229922573, 
      0.2384946748190441}, {0.966095016059902, 0.12921045342782392`, 
      0.2235286976412511}, {0.8662870844473877, 0.2499997258443469, 
      0.4324891032123191}, {0.8662870844473877, 0.19134938625779355`, 
      0.46144566277993154`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.2499997258443469, 
      0.43248910321231904`}, {0.966095016059902, 0.12921045342782392`, 
      0.22352869764125108`}, {0.966095016059902, 0.15730819034142643`, 
      0.20473044032513402`}, {0.8662870844473877, 0.3043639536517434, 
      0.39611774895493385`}, {0.8662870844473877, 0.2499997258443469, 
      0.43248910321231904`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.30436395365174346`, 
      0.3961177489549338}, {0.966095016059902, 0.15730819034142646`, 
      0.204730440325134}, {0.966095016059902, 0.18270896234715528`, 
      0.18242218895255996`}, {0.8662870844473877, 0.3535100240292005, 
      0.35295516745121985`}, {0.8662870844473877, 0.30436395365174346`, 
      0.3961177489549338}}], 
     Polygon3DBox[{{0.8662870844473877, 0.35351002402920056`, 
      0.3529551674512198}, {0.966095016059902, 0.18270896234715533`, 
      0.18242218895255993`}, {0.966095016059902, 0.20497728677507665`, 
      0.15698640657886812`}, {0.8662870844473877, 0.3965953538481462, 
      0.30374135810868486`}, {0.8662870844473877, 0.35351002402920056`, 
      0.3529551674512198}}], 
     Polygon3DBox[{{0.8662870844473877, 0.3965953538481461, 
      0.30374135810868497`}, {0.966095016059902, 0.2049772867750766, 
      0.15698640657886817`}, {0.966095016059902, 0.22373138509599308`, 
      0.12885917610805273`}, {0.8662870844473877, 0.43288126813994926`, 
      0.24932006540427898`}, {0.8662870844473877, 0.3965953538481461, 
      0.30374135810868497`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.43288126813994926`, 
      0.24932006540427898`}, {0.966095016059902, 0.22373138509599308`, 
      0.12885917610805273`}, {0.966095016059902, 0.23864972831042572`, 
      0.09852272388427806}, {0.8662870844473877, 0.46174566428374386`, 
      0.19062431333596644`}, {0.8662870844473877, 0.43288126813994926`, 
      0.24932006540427898`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.46174566428374386`, 
      0.19062431333596644`}, {0.966095016059902, 0.23864972831042572`, 
      0.09852272388427806}, {0.966095016059902, 0.24947654939158706`, 
      0.06649715217875668}, {0.8662870844473877, 0.48269367762360943`, 
      0.1286604092245926}, {0.8662870844473877, 0.46174566428374386`, 
      0.19062431333596644`}}], 
     Polygon3DBox[{{0.8662870844473877, 0.48269367762360943`, 
      0.1286604092245926}, {0.966095016059902, 0.24947654939158706`, 
      0.06649715217875668}, {0.966095016059902, 0.25602622827445476`, 
      0.033331522314086724`}, {0.8662870844473877, 0.4953661656587984, 
      0.06449069111231853}, {0.8662870844473877, 0.48269367762360943`, 
      0.1286604092245926}}], 
     Polygon3DBox[{{0.8662870844473877, 0.4953661656587984, 
      0.06449069111231853}, {0.966095016059902, 0.25602622827445476`, 
      0.033331522314086724`}, {0.966095016059902, 
      0.2581864742126502, -0.0004055586988800299}, {0.8662870844473877, 
      0.49954586535009987`, -0.0007846854557354606}, {0.8662870844473877, 
      0.4953661656587984, 0.06449069111231853}}], 
     Polygon3DBox[{{
      0.9660950160599021, -0.2581864742126498, -0.0004055586988800293}, {
      0.9999996915748783, 0.0007853971137068693, 1.233699915963616*^-6}, {
      0.9999996915748783, 0.0007788256969433474, -0.00010139369810433382`}, {
      0.9660950160599021, -0.2560262282744544, 0.03333152231408667}, {
      0.9660950160599021, -0.2581864742126498, -0.0004055586988800293}}], 
     Polygon3DBox[{{0.9660950160599021, -0.2560262282744544, 
      0.03333152231408667}, {0.9999996915748783, 
      0.0007788256969433474, -0.00010139369810433382`}, {0.9999996915748783, 
      0.0007589017295628009, -0.00020228275532321844`}, {
      0.9660950160599021, -0.2494765493915867, 0.06649715217875658}, {
      0.9660950160599021, -0.2560262282744544, 0.03333152231408667}}], 
     Polygon3DBox[{{0.9660950160599021, -0.2494765493915867, 
      0.06649715217875653}, {0.9999996915748783, 
      0.0007589017295628009, -0.00020228275532321825`}, {0.9999996915748783, 
      0.0007259667973449296, -0.0002997037827377383}, {
      0.9660950160599021, -0.23864972831042539`, 0.09852272388427785}, {
      0.9660950160599021, -0.2494765493915867, 0.06649715217875653}}], 
     Polygon3DBox[{{0.9660950160599021, -0.23864972831042539`, 
      0.09852272388427785}, {0.9999996915748783, 
      0.0007259667973449296, -0.0002997037827377383}, {0.9999996915748783, 
      0.0006805855521126425, -0.00039198654886372453`}, {
      0.9660950160599021, -0.22373138509599277`, 0.12885917610805248`}, {
      0.9660950160599021, -0.23864972831042539`, 0.09852272388427785}}], 
     Polygon3DBox[{{0.9660950160599021, -0.2237313850959928, 
      0.12885917610805245`}, {0.9999996915748783, 
      0.0006805855521126426, -0.0003919865488637244}, {0.9999996915748783, 
      0.0006235360310781246, -0.0004775489149625445}, {
      0.9660950160599021, -0.20497728677507637`, 0.15698640657886784`}, {
      0.9660950160599021, -0.2237313850959928, 0.12885917610805245`}}], 
     Polygon3DBox[{{0.9660950160599021, -0.20497728677507634`, 
      0.15698640657886787`}, {0.9999996915748783, 
      0.0006235360310781246, -0.0004775489149625446}, {0.9999996915748783, 
      0.0005557963178103695, -0.0005549239599647851}, {
      0.9660950160599021, -0.18270896234715508`, 0.18242218895255963`}, {
      0.9660950160599021, -0.20497728677507634`, 0.15698640657886787`}}], 
     Polygon3DBox[{{0.9660950160599021, -0.18270896234715506`, 
      0.18242218895255966`}, {0.9999996915748783, 
      0.0005557963178103694, -0.0005549239599647851}, {0.9999996915748783, 
      0.00047852777351476653`, -0.0006227851300485296}, {
      0.9660950160599021, -0.15730819034142624`, 0.20473044032513366`}, {
      0.9660950160599021, -0.18270896234715506`, 0.18242218895255966`}}], 
     Polygon3DBox[{{0.9660950160599021, -0.15730819034142624`, 
      0.20473044032513366`}, {0.9999996915748783, 
      0.00047852777351476653`, -0.0006227851300485296}, {0.9999996915748783, 
      0.0003930551261154973, -0.0006799689816961462}, {
      0.9660950160599021, -0.12921045342782378`, 0.22352869764125072`}, {
      0.9660950160599021, -0.15730819034142624`, 0.20473044032513366`}}], 
     Polygon3DBox[{{0.9660950160599021, -0.12921045342782378`, 
      0.22352869764125072`}, {0.9999996915748783, 
      0.0003930551261154973, -0.0006799689816961462}, {0.9999996915748783, 
      0.0003008437585027887, -0.0007254951283120235}, {
      0.9660950160599021, -0.09889747229922566, 0.2384946748190437}, {
      0.9660950160599021, -0.12921045342782378`, 0.22352869764125072`}}], 
     Polygon3DBox[{{0.9660950160599021, -0.09889747229922563, 
      0.2384946748190437}, {0.9999996915748783, 
      0.00030084375850278865`, -0.0007254951283120235}, {0.9999996915748783, 
      0.00020347458532589535`, -0.0007585830484271439}, {
      0.9660950160599021, -0.06688894682745306, 0.2493717881728638}, {
      0.9660950160599021, -0.09889747229922563, 0.2384946748190437}}], 
     Polygon3DBox[{{0.9660950160599021, -0.06688894682745308, 
      0.2493717881728638}, {0.9999996915748783, 
      0.00020347458532589543`, -0.0007585830484271439}, {0.9999996915748783, 
      0.00010261694905577706`, -0.0007786654673228084}, {
      0.9660950160599021, -0.03373364608653062, 0.25597355540353417`}, {
      0.9660950160599021, -0.06688894682745308, 0.2493717881728638}}], 
     Polygon3DBox[{{0.9660950160599021, -0.0337336460865306, 
      0.25597355540353417`}, {0.9999996915748783, 
      0.000102616949055777, -0.0007786654673228084}, {0.9999996915748783, 
      6.539752761431233*^-20, -0.0007853980826527167}, {
      0.9660950160599021, -2.1498369146369863`*^-17, 0.2581867927377725}, {
      0.9660950160599021, -0.0337336460865306, 0.25597355540353417`}}], 
     Polygon3DBox[{{0.9660950160599021, 0., 0.2581867927377725}, {
      0.9999996915748783, 0., -0.0007853980826527167}, {
      0.9999996915748783, -0.00010261694905577693`, -0.0007786654673228085}, {
      0.9660950160599021, 0.03373364608653058, 0.2559735554035342}, {
      0.9660950160599021, 0., 0.2581867927377725}}], 
     Polygon3DBox[{{0.9660950160599021, 0.033733646086530546`, 
      0.2559735554035342}, {
      0.9999996915748783, -0.00010261694905577682`, -0.0007786654673228085}, {
      0.9999996915748783, -0.00020347458532589516`, -0.000758583048427144}, {
      0.9660950160599021, 0.066888946827453, 0.24937178817286382`}, {
      0.9660950160599021, 0.033733646086530546`, 0.2559735554035342}}], 
     Polygon3DBox[{{0.9660950160599021, 0.06688894682745303, 
      0.24937178817286382`}, {
      0.9999996915748783, -0.00020347458532589524`, -0.000758583048427144}, {
      0.9999996915748783, -0.00030084375850278854`, -0.0007254951283120235}, {
      0.9660950160599021, 0.0988974722992256, 0.2384946748190437}, {
      0.9660950160599021, 0.06688894682745303, 0.24937178817286382`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.09889747229922558, 
      0.23849467481904374`}, {
      0.9999996915748783, -0.00030084375850278843`, -0.0007254951283120236}, {
      0.9999996915748783, -0.0003930551261154971, -0.0006799689816961464}, {
      0.9660950160599021, 0.12921045342782372`, 0.22352869764125077`}, {
      0.9660950160599021, 0.09889747229922558, 0.23849467481904374`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.12921045342782372`, 
      0.22352869764125075`}, {
      0.9999996915748783, -0.0003930551261154971, -0.0006799689816961463}, {
      0.9999996915748783, -0.00047852777351476637`, -0.0006227851300485297}, {
      0.9660950160599021, 0.15730819034142618`, 0.2047304403251337}, {
      0.9660950160599021, 0.12921045342782372`, 0.22352869764125075`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.1573081903414262, 
      0.20473044032513366`}, {
      0.9999996915748783, -0.0004785277735147665, -0.0006227851300485296}, {
      0.9999996915748783, -0.0005557963178103693, -0.0005549239599647852}, {
      0.9660950160599021, 0.18270896234715503`, 0.18242218895255968`}, {
      0.9660950160599021, 0.1573081903414262, 0.20473044032513366`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.18270896234715506`, 
      0.18242218895255966`}, {
      0.9999996915748783, -0.0005557963178103694, -0.0005549239599647851}, {
      0.9999996915748783, -0.0006235360310781246, -0.00047754891496254464`}, {
      0.9660950160599021, 0.20497728677507634`, 0.1569864065788679}, {
      0.9660950160599021, 0.18270896234715506`, 0.18242218895255966`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.2049772867750763, 
      0.15698640657886795`}, {
      0.9999996915748783, -0.0006235360310781244, -0.00047754891496254486`}, {
      0.9999996915748783, -0.0006805855521126424, -0.0003919865488637247}, {
      0.9660950160599021, 0.22373138509599275`, 0.12885917610805253`}, {
      0.9660950160599021, 0.2049772867750763, 0.15698640657886795`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.22373138509599275`, 
      0.12885917610805253`}, {
      0.9999996915748783, -0.0006805855521126424, -0.0003919865488637247}, {
      0.9999996915748783, -0.0007259667973449295, -0.00029970378273773846`}, {
      0.9660950160599021, 0.23864972831042536`, 0.09852272388427791}, {
      0.9660950160599021, 0.22373138509599275`, 0.12885917610805253`}}], 
     Polygon3DBox[{{0.9660950160599021, 0.23864972831042536`, 
      0.09852272388427791}, {
      0.9999996915748783, -0.0007259667973449295, -0.00029970378273773846`}, {
      0.9999996915748783, -0.0007589017295628009, -0.00020228275532321844`}, {
      0.9660950160599021, 0.2494765493915867, 0.06649715217875658}, {
      0.9660950160599021, 0.23864972831042536`, 0.09852272388427791}}], 
     Polygon3DBox[{{0.9660950160599021, 0.2494765493915867, 
      0.06649715217875658}, {
      0.9999996915748783, -0.0007589017295628009, -0.00020228275532321844`}, {
      0.9999996915748783, -0.0007788256969433474, -0.00010139369810433382`}, {
      0.9660950160599021, 0.2560262282744544, 0.03333152231408667}, {
      0.9660950160599021, 0.2494765493915867, 0.06649715217875658}}], 
     Polygon3DBox[{{0.9660950160599021, 0.2560262282744544, 
      0.03333152231408667}, {
      0.9999996915748783, -0.0007788256969433474, -0.00010139369810433382`}, {
      0.9999996915748783, -0.0007853971137068693, 1.233699915963616*^-6}, {
      0.9660950160599021, 0.2581864742126498, -0.0004055586988800293}, {
      0.9660950160599021, 0.2560262282744544, 0.03333152231408667}}], 
     Polygon3DBox[{{0.9999996915748783, 0.0007853971137064252, 
      1.2336999159629184`*^-6}, {0.965688265489314, 0.25970369169423324`, 
      0.00040794194048718736`}, {0.965688265489314, 
      0.2575307511990827, -0.03352739302535046}, {0.9999996915748783, 
      0.000778825696942907, -0.00010139369810427649`}, {0.9999996915748783, 
      0.0007853971137064252, 1.2336999159629184`*^-6}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.000778825696942907, -0.00010139369810427649`}, {0.965688265489314, 
      0.2575307511990827, -0.03352739302535046}, {0.965688265489314, 
      0.25094258351725623`, -0.06688791874415781}, {0.9999996915748783, 
      0.0007589017295623718, -0.00020228275532310406`}, {0.9999996915748783, 
      0.000778825696942907, -0.00010139369810427649`}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.0007589017295623718, -0.00020228275532310387`}, {0.965688265489314, 
      0.25094258351725623`, -0.06688791874415774}, {0.965688265489314, 
      0.2400521392650345, -0.09910168681975422}, {0.9999996915748783, 
      0.0007259667973445192, -0.00029970378273756884`}, {0.9999996915748783, 
      0.0007589017295623718, -0.00020228275532310387`}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.0007259667973445192, -0.00029970378273756884`}, {0.965688265489314, 
      0.2400521392650345, -0.09910168681975422}, {0.965688265489314, 
      0.2250461292927277, -0.12961640940328917`}, {0.9999996915748783, 
      0.0006805855521122578, -0.00039198654886350286`}, {0.9999996915748783, 
      0.0007259667973445192, -0.00029970378273756884`}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.0006805855521122579, -0.00039198654886350275`}, {0.965688265489314, 
      0.22504612929272771`, -0.1296164094032891}, {0.965688265489314, 
      0.20618182362686574`, -0.1579089278734429}, {0.9999996915748783, 
      0.0006235360310777721, -0.00047754891496227446`}, {0.9999996915748783, 
      0.0006805855521122579, -0.00039198654886350275`}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.000623536031077772, -0.00047754891496227457`}, {0.965688265489314, 
      0.2061818236268657, -0.15790892787344293`}, {0.965688265489314, 
      0.18378264071299683`, -0.18349418211158}, {0.9999996915748783, 
      0.0005557963178100552, -0.0005549239599644713}, {0.9999996915748783, 
      0.000623536031077772, -0.00047754891496227457`}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.0005557963178100551, -0.0005549239599644713}, {0.965688265489314, 
      0.1837826407129968, -0.18349418211158003`}, {0.965688265489314, 
      0.15823260257917074`, -0.20593352659842057`}, {0.9999996915748783, 
      0.00047852777351449597`, -0.0006227851300481775}, {0.9999996915748783, 
      0.0005557963178100551, -0.0005549239599644713}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.00047852777351449597`, -0.0006227851300481775}, {0.965688265489314, 
      0.15823260257917074`, -0.20593352659842057`}, {0.965688265489314, 
      0.12996975098336713`, -0.22484225075719577`}, {0.9999996915748783, 
      0.0003930551261152751, -0.0006799689816957618}, {0.9999996915748783, 
      0.00047852777351449597`, -0.0006227851300481775}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.0003930551261152751, -0.0006799689816957618}, {0.965688265489314, 
      0.12996975098336713`, -0.22484225075719577`}, {0.965688265489314, 
      0.09947863742150553, -0.2398961746110196}, {0.9999996915748783, 
      0.0003008437585026186, -0.0007254951283116132}, {0.9999996915748783, 
      0.0003930551261152751, -0.0006799689816957618}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.00030084375850261854`, -0.0007254951283116132}, {0.965688265489314, 
      0.0994786374215055, -0.2398961746110196}, {0.965688265489314, 
      0.067282015750838, -0.25083720667545345`}, {0.9999996915748783, 
      0.0002034745853257803, -0.000758583048426715}, {0.9999996915748783, 
      0.00030084375850261854`, -0.0007254951283116132}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.00020347458532578037`, -0.000758583048426715}, {0.965688265489314, 
      0.06728201575083803, -0.25083720667545345`}, {0.965688265489314, 
      0.03393187985426038, -0.2574777687991649}, {0.9999996915748783, 
      0.00010261694905571904`, -0.0007786654673223681}, {0.9999996915748783, 
      0.00020347458532578037`, -0.000758583048426715}}], 
     Polygon3DBox[{{0.9999996915748783, 
      0.00010261694905571898`, -0.0007786654673223681}, {0.965688265489314, 
      0.033931879854260355`, -0.2574777687991649}, {0.965688265489314, 
      2.1624703035834354`*^-17, -0.25970401209114996`}, {0.9999996915748783, 
      6.539752761427535*^-20, -0.0007853980826522726}, {0.9999996915748783, 
      0.00010261694905571898`, -0.0007786654673223681}}], 
     Polygon3DBox[{{0.9999996915748783, 0., -0.0007853980826522726}, {
      0.965688265489314, 0., -0.25970401209114996`}, {
      0.965688265489314, -0.033931879854260334`, -0.2574777687991649}, {
      0.9999996915748783, -0.00010261694905571891`, -0.0007786654673223682}, {
      0.9999996915748783, 0., -0.0007853980826522726}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0001026169490557188, -0.0007786654673223682}, {
      0.965688265489314, -0.0339318798542603, -0.2574777687991649}, {
      0.965688265489314, -0.06728201575083793, -0.2508372066754535}, {
      0.9999996915748783, -0.0002034745853257801, -0.0007585830484267151}, {
      0.9999996915748783, -0.0001026169490557188, -0.0007786654673223682}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0002034745853257802, -0.0007585830484267151}, {
      0.965688265489314, -0.06728201575083796, -0.2508372066754535}, {
      0.965688265489314, -0.09947863742150548, -0.2398961746110196}, {
      0.9999996915748783, -0.0003008437585026184, -0.0007254951283116132}, {
      0.9999996915748783, -0.0002034745853257802, -0.0007585830484267151}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0003008437585026183, -0.0007254951283116133}, {
      0.965688265489314, -0.09947863742150545, -0.23989617461101964`}, {
      0.965688265489314, -0.12996975098336708`, -0.22484225075719583`}, {
      0.9999996915748783, -0.00039305512611527486`, -0.000679968981695762}, {
      0.9999996915748783, -0.0003008437585026183, -0.0007254951283116133}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.00039305512611527486`, -0.0006799689816957619}, {
      0.965688265489314, -0.12996975098336708`, -0.2248422507571958}, {
      0.965688265489314, -0.15823260257917068`, -0.2059335265984206}, {
      0.9999996915748783, -0.0004785277735144958, -0.0006227851300481776}, {
      0.9999996915748783, -0.00039305512611527486`, -0.0006799689816957619}}],
      Polygon3DBox[{{
      0.9999996915748783, -0.0004785277735144959, -0.0006227851300481775}, {
      0.965688265489314, -0.1582326025791707, -0.20593352659842057`}, {
      0.965688265489314, -0.18378264071299677`, -0.18349418211158006`}, {
      0.9999996915748783, -0.0005557963178100551, -0.0005549239599644714}, {
      0.9999996915748783, -0.0004785277735144959, -0.0006227851300481775}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0005557963178100551, -0.0005549239599644713}, {
      0.965688265489314, -0.1837826407129968, -0.18349418211158003`}, {
      0.965688265489314, -0.2061818236268657, -0.157908927873443}, {
      0.9999996915748783, -0.000623536031077772, -0.0004775489149622746}, {
      0.9999996915748783, -0.0005557963178100551, -0.0005549239599644713}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0006235360310777718, -0.00047754891496227484`}, {
      0.965688265489314, -0.20618182362686566`, -0.15790892787344304`}, {
      0.965688265489314, -0.22504612929272766`, -0.12961640940328922`}, {
      0.9999996915748783, -0.0006805855521122576, -0.0003919865488635031}, {
      0.9999996915748783, -0.0006235360310777718, -0.00047754891496227484`}}],
      Polygon3DBox[{{
      0.9999996915748783, -0.0006805855521122576, -0.0003919865488635031}, {
      0.965688265489314, -0.22504612929272766`, -0.12961640940328922`}, {
      0.965688265489314, -0.24005213926503446`, -0.09910168681975429}, {
      0.9999996915748783, -0.0007259667973445191, -0.000299703782737569}, {
      0.9999996915748783, -0.0006805855521122576, -0.0003919865488635031}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0007259667973445191, -0.000299703782737569}, {
      0.965688265489314, -0.24005213926503446`, -0.09910168681975429}, {
      0.965688265489314, -0.25094258351725623`, -0.06688791874415781}, {
      0.9999996915748783, -0.0007589017295623718, -0.00020228275532310406`}, {
      0.9999996915748783, -0.0007259667973445191, -0.000299703782737569}}], 
     Polygon3DBox[{{
      0.9999996915748783, -0.0007589017295623718, -0.00020228275532310406`}, {
      0.965688265489314, -0.25094258351725623`, -0.06688791874415781}, {
      0.965688265489314, -0.2575307511990827, -0.03352739302535046}, {
      0.9999996915748783, -0.000778825696942907, -0.00010139369810427649`}, {
      0.9999996915748783, -0.0007589017295623718, -0.00020228275532310406`}}],
      Polygon3DBox[{{
      0.9999996915748783, -0.000778825696942907, -0.00010139369810427649`}, {
      0.965688265489314, -0.2575307511990827, -0.03352739302535046}, {
      0.965688265489314, -0.25970369169423324`, 0.00040794194048718736`}, {
      0.9999996915748783, -0.0007853971137064252, 1.2336999159629184`*^-6}, {
      0.9999996915748783, -0.000778825696942907, -0.00010139369810427649`}}], 
     Polygon3DBox[{{0.9656882654893139, 0.2597036916942337, 
      0.00040794194048718806`}, {0.8655013302530187, 0.5009060073920582, 
      0.0007868219636160954}, {0.8655013302530187, 
      0.49671492739382744`, -0.06466628359817633}, {0.9656882654893139, 
      0.25753075119908314`, -0.03352739302535052}, {0.9656882654893139, 
      0.2597036916942337, 0.00040794194048718806`}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.25753075119908314`, -0.03352739302535052}, {0.8655013302530187, 
      0.49671492739382744`, -0.06466628359817633}, {0.8655013302530187, 
      0.4840079352521121, -0.12901072026479965`}, {0.9656882654893139, 
      0.2509425835172567, -0.06688791874415792}, {0.9656882654893139, 
      0.25753075119908314`, -0.03352739302535052}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.2509425835172567, -0.06688791874415786}, {0.8655013302530187, 
      0.4840079352521121, -0.12901072026479954`}, {0.8655013302530187, 
      0.46300288556060126`, -0.19114333703483322`}, {0.9656882654893139, 
      0.2400521392650349, -0.0991016868197544}, {0.9656882654893139, 
      0.2509425835172567, -0.06688791874415786}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.2400521392650349, -0.0991016868197544}, {0.8655013302530187, 
      0.46300288556060126`, -0.19114333703483322`}, {0.8655013302530187, 
      0.4340598986778294, -0.24999890337768996`}, {0.9656882654893139, 
      0.22504612929272808`, -0.1296164094032894}, {0.9656882654893139, 
      0.2400521392650349, -0.0991016868197544}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.2250461292927281, -0.12961640940328933`}, {0.8655013302530187, 
      0.43405989867782946`, -0.24999890337768987`}, {0.8655013302530187, 
      0.39767518665596285`, -0.30456837204214127`}, {0.9656882654893139, 
      0.20618182362686607`, -0.15790892787344318`}, {0.9656882654893139, 
      0.2250461292927281, -0.12961640940328933`}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.20618182362686605`, -0.1579089278734432}, {0.8655013302530187, 
      0.3976751866559628, -0.3045683720421413}, {0.8655013302530187, 
      0.3544725459501834, -0.35391617863252617`}, {0.9656882654893139, 
      0.18378264071299716`, -0.1834941821115803}, {0.9656882654893139, 
      0.20618182362686605`, -0.1579089278734432}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.18378264071299713`, -0.18349418211158033`}, {0.8655013302530187, 
      0.35447254595018335`, -0.3539161786325262}, {0.8655013302530187, 
      0.3051926627616232, -0.3971962813606457}, {0.9656882654893139, 
      0.158232602579171, -0.2059335265984209}, {0.9656882654893139, 
      0.18378264071299713`, -0.18349418211158033`}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.158232602579171, -0.2059335265984209}, {0.8655013302530187, 
      0.3051926627616232, -0.3971962813606457}, {0.8655013302530187, 
      0.2506804143680337, -0.43366666598036563`}, {0.9656882654893139, 
      0.12996975098336735`, -0.22484225075719616`}, {0.9656882654893139, 
      0.158232602579171, -0.2059335265984209}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.12996975098336735`, -0.22484225075719616`}, {0.8655013302530187, 
      0.2506804143680337, -0.43366666598036563`}, {0.8655013302530187, 
      0.19187038415409247`, -0.4627020672255702}, {0.9656882654893139, 
      0.0994786374215057, -0.23989617461102003`}, {0.9656882654893139, 
      0.12996975098336735`, -0.22484225075719616`}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.09947863742150567, -0.23989617461102003`}, {0.8655013302530187, 
      0.1918703841540924, -0.4627020672255702}, {0.8655013302530187, 
      0.12977083867841757`, -0.48380468864920606`}, {0.9656882654893139, 
      0.06728201575083811, -0.2508372066754539}, {0.9656882654893139, 
      0.09947863742150567, -0.23989617461102003`}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.06728201575083814, -0.2508372066754539}, {0.8655013302530187, 
      0.12977083867841763`, -0.48380468864920606`}, {0.8655013302530187, 
      0.0654464414819175, -0.49661273707750286`}, {0.9656882654893139, 
      0.03393187985426044, -0.2574777687991653}, {0.9656882654893139, 
      0.06728201575083814, -0.2508372066754539}}], 
     Polygon3DBox[{{0.9656882654893139, 
      0.03393187985426042, -0.2574777687991653}, {0.8655013302530187, 
      0.06544644148191746, -0.49661273707750286`}, {0.8655013302530187, 
      4.1708855149706103`*^-17, -0.5009066253607104}, {0.9656882654893139, 
      2.162470303583439*^-17, -0.2597040120911504}, {0.9656882654893139, 
      0.03393187985426042, -0.2574777687991653}}], 
     Polygon3DBox[{{0.9656882654893139, 0., -0.2597040120911504}, {
      0.8655013302530187, 0., -0.5009066253607104}, {
      0.8655013302530187, -0.06544644148191742, -0.4966127370775029}, {
      0.9656882654893139, -0.0339318798542604, -0.25747776879916534`}, {
      0.9656882654893139, 0., -0.2597040120911504}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.033931879854260355`, -0.25747776879916534`}, {
      0.8655013302530187, -0.06544644148191735, -0.4966127370775029}, {
      0.8655013302530187, -0.12977083867841746`, -0.4838046886492061}, {
      0.9656882654893139, -0.06728201575083806, -0.2508372066754539}, {
      0.9656882654893139, -0.033931879854260355`, -0.25747776879916534`}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.06728201575083809, -0.2508372066754539}, {
      0.8655013302530187, -0.12977083867841752`, -0.4838046886492061}, {
      0.8655013302530187, -0.19187038415409235`, -0.4627020672255702}, {
      0.9656882654893139, -0.09947863742150564, -0.23989617461102003`}, {
      0.9656882654893139, -0.06728201575083809, -0.2508372066754539}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.09947863742150562, -0.23989617461102006`}, {
      0.8655013302530187, -0.1918703841540923, -0.4627020672255703}, {
      0.8655013302530187, -0.25068041436803357`, -0.43366666598036574`}, {
      0.9656882654893139, -0.1299697509833673, -0.22484225075719622`}, {
      0.9656882654893139, -0.09947863742150562, -0.23989617461102006`}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.1299697509833673, -0.2248422507571962}, {
      0.8655013302530187, -0.25068041436803357`, -0.4336666659803657}, {
      0.8655013302530187, -0.3051926627616231, -0.3971962813606458}, {
      0.9656882654893139, -0.15823260257917093`, -0.20593352659842093`}, {
      0.9656882654893139, -0.1299697509833673, -0.2248422507571962}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.15823260257917096`, -0.2059335265984209}, {
      0.8655013302530187, -0.30519266276162316`, -0.3971962813606457}, {
      0.8655013302530187, -0.3544725459501833, -0.3539161786325263}, {
      0.9656882654893139, -0.18378264071299708`, -0.18349418211158036`}, {
      0.9656882654893139, -0.15823260257917096`, -0.2059335265984209}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.18378264071299713`, -0.18349418211158033`}, {
      0.8655013302530187, -0.35447254595018335`, -0.3539161786325262}, {
      0.8655013302530187, -0.3976751866559628, -0.3045683720421414}, {
      0.9656882654893139, -0.20618182362686605`, -0.15790892787344324`}, {
      0.9656882654893139, -0.18378264071299713`, -0.18349418211158033`}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.206181823626866, -0.1579089278734433}, {
      0.8655013302530187, -0.3976751866559627, -0.3045683720421415}, {
      0.8655013302530187, -0.43405989867782935`, -0.24999890337769007`}, {
      0.9656882654893139, -0.22504612929272802`, -0.12961640940328945`}, {
      0.9656882654893139, -0.206181823626866, -0.1579089278734433}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.22504612929272802`, -0.12961640940328945`}, {
      0.8655013302530187, -0.43405989867782935`, -0.24999890337769007`}, {
      0.8655013302530187, -0.4630028855606012, -0.19114333703483333`}, {
      0.9656882654893139, -0.24005213926503488`, -0.09910168681975445}, {
      0.9656882654893139, -0.22504612929272802`, -0.12961640940328945`}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.24005213926503488`, -0.09910168681975445}, {
      0.8655013302530187, -0.4630028855606012, -0.19114333703483333`}, {
      0.8655013302530187, -0.4840079352521121, -0.12901072026479965`}, {
      0.9656882654893139, -0.2509425835172567, -0.06688791874415792}, {
      0.9656882654893139, -0.24005213926503488`, -0.09910168681975445}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.2509425835172567, -0.06688791874415792}, {
      0.8655013302530187, -0.4840079352521121, -0.12901072026479965`}, {
      0.8655013302530187, -0.49671492739382744`, -0.06466628359817633}, {
      0.9656882654893139, -0.25753075119908314`, -0.03352739302535052}, {
      0.9656882654893139, -0.2509425835172567, -0.06688791874415792}}], 
     Polygon3DBox[{{
      0.9656882654893139, -0.25753075119908314`, -0.03352739302535052}, {
      0.8655013302530187, -0.49671492739382744`, -0.06466628359817633}, {
      0.8655013302530187, -0.5009060073920582, 0.0007868219636160954}, {
      0.9656882654893139, -0.2597036916942337, 0.00040794194048718806`}, {
      0.9656882654893139, -0.25753075119908314`, -0.03352739302535052}}], 
     Polygon3DBox[{{0.8655013302530189, 0.5009060073920578, 
      0.0007868219636160948}, {0.7062732501270085, 0.7079384574584596, 
      0.001112028043179037}, {0.7062732501270085, 
      0.7020151371843025, -0.091393891038389}, {0.8655013302530189, 
      0.4967149273938271, -0.06466628359817629}, {0.8655013302530189, 
      0.5009060073920578, 0.0007868219636160948}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.4967149273938271, -0.06466628359817629}, {0.7062732501270085, 
      0.7020151371843025, -0.091393891038389}, {0.7062732501270085, 
      0.6840561423170244, -0.18233291066996923`}, {0.8655013302530189, 
      0.4840079352521118, -0.12901072026479957`}, {0.8655013302530189, 
      0.4967149273938271, -0.06466628359817629}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.4840079352521118, -0.12901072026479946`}, {0.7062732501270085, 
      0.6840561423170244, -0.1823329106699691}, {0.7062732501270085, 
      0.6543693702320422, -0.27014592992890457`}, {0.8655013302530189, 
      0.463002885560601, -0.1911433370348331}, {0.8655013302530189, 
      0.4840079352521118, -0.12901072026479946`}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.463002885560601, -0.1911433370348331}, {0.7062732501270085, 
      0.6543693702320422, -0.27014592992890457`}, {0.7062732501270085, 
      0.6134637847815715, -0.3533274414993857}, {0.8655013302530189, 
      0.4340598986778291, -0.2499989033776898}, {0.8655013302530189, 
      0.463002885560601, -0.1911433370348331}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.4340598986778292, -0.2499989033776897}, {0.7062732501270085, 
      0.6134637847815716, -0.3533274414993856}, {0.7062732501270085, 
      0.562040690381209, -0.43045134279131486`}, {0.8655013302530189, 
      0.39767518665596263`, -0.30456837204214104`}, {0.8655013302530189, 
      0.4340598986778292, -0.2499989033776897}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.3976751866559626, -0.3045683720421411}, {0.7062732501270085, 
      0.562040690381209, -0.4304513427913149}, {0.7062732501270085, 
      0.500981708520281, -0.5001953857075576}, {0.8655013302530189, 
      0.3544725459501832, -0.35391617863252595`}, {0.8655013302530189, 
      0.3976751866559626, -0.3045683720421411}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.3544725459501831, -0.353916178632526}, {0.7062732501270085, 
      0.5009817085202809, -0.5001953857075576}, {0.7062732501270085, 
      0.4313336628322677, -0.5613638458813782}, {0.8655013302530189, 
      0.30519266276162305`, -0.39719628136064544`}, {0.8655013302530189, 
      0.3544725459501831, -0.353916178632526}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.30519266276162305`, -0.39719628136064544`}, {0.7062732501270085, 
      0.4313336628322677, -0.5613638458813782}, {0.7062732501270085, 
      0.3542906318626974, -0.6129080227320921}, {0.8655013302530189, 
      0.2506804143680335, -0.43366666598036535`}, {0.8655013302530189, 
      0.30519266276162305`, -0.39719628136064544`}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.2506804143680335, -0.43366666598036535`}, {0.7062732501270085, 
      0.3542906318626974, -0.6129080227320921}, {0.7062732501270085, 
      0.2711734772302192, -0.6539442188764298}, {0.8655013302530189, 
      0.19187038415409235`, -0.4627020672255699}, {0.8655013302530189, 
      0.2506804143680335, -0.43366666598036535`}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.1918703841540923, -0.4627020672255699}, {0.7062732501270085, 
      0.2711734772302191, -0.6539442188764298}, {0.7062732501270085, 
      0.18340719815960052`, -0.6837688906482051}, {0.8655013302530189, 
      0.12977083867841746`, -0.4838046886492057}, {0.8655013302530189, 
      0.1918703841540923, -0.4627020672255699}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.12977083867841752`, -0.4838046886492057}, {0.7062732501270085, 
      0.1834071981596006, -0.6837688906482051}, {0.7062732501270085, 
      0.09249650063108548, -0.7018707099787223}, {0.8655013302530189, 
      0.06544644148191746, -0.49661273707750253`}, {0.8655013302530189, 
      0.12977083867841752`, -0.4838046886492057}}], 
     Polygon3DBox[{{0.8655013302530189, 
      0.06544644148191742, -0.49661273707750253`}, {0.7062732501270085, 
      0.09249650063108542, -0.7018707099787223}, {0.7062732501270085, 
      5.8947790885507*^-17, -0.707939330843422}, {0.8655013302530189, 
      4.170885514970608*^-17, -0.5009066253607101}, {0.8655013302530189, 
      0.06544644148191742, -0.49661273707750253`}}], 
     Polygon3DBox[{{0.8655013302530189, 0., -0.5009066253607101}, {
      0.7062732501270085, 0., -0.707939330843422}, {
      0.7062732501270085, -0.09249650063108536, -0.7018707099787224}, {
      0.8655013302530189, -0.06544644148191738, -0.4966127370775026}, {
      0.8655013302530189, 0., -0.5009066253607101}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.0654464414819173, -0.4966127370775026}, {
      0.7062732501270085, -0.09249650063108526, -0.7018707099787224}, {
      0.7062732501270085, -0.18340719815960035`, -0.6837688906482052}, {
      0.8655013302530189, -0.12977083867841735`, -0.4838046886492058}, {
      0.8655013302530189, -0.0654464414819173, -0.4966127370775026}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.1297708386784174, -0.4838046886492058}, {
      0.7062732501270085, -0.18340719815960044`, -0.6837688906482052}, {
      0.7062732501270085, -0.27117347723021906`, -0.6539442188764298}, {
      0.8655013302530189, -0.19187038415409224`, -0.4627020672255699}, {
      0.8655013302530189, -0.1297708386784174, -0.4838046886492058}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.1918703841540922, -0.46270206722556995`}, {
      0.7062732501270085, -0.27117347723021895`, -0.6539442188764298}, {
      0.7062732501270085, -0.3542906318626972, -0.6129080227320922}, {
      0.8655013302530189, -0.2506804143680334, -0.43366666598036546`}, {
      0.8655013302530189, -0.1918703841540922, -0.46270206722556995`}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.2506804143680334, -0.4336666659803654}, {
      0.7062732501270085, -0.3542906318626972, -0.6129080227320922}, {
      0.7062732501270085, -0.43133366283226754`, -0.5613638458813783}, {
      0.8655013302530189, -0.30519266276162293`, -0.3971962813606455}, {
      0.8655013302530189, -0.2506804143680334, -0.4336666659803654}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.305192662761623, -0.39719628136064544`}, {
      0.7062732501270085, -0.43133366283226765`, -0.5613638458813782}, {
      0.7062732501270085, -0.5009817085202808, -0.5001953857075577}, {
      0.8655013302530189, -0.35447254595018307`, -0.35391617863252606`}, {
      0.8655013302530189, -0.305192662761623, -0.39719628136064544`}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.3544725459501831, -0.353916178632526}, {
      0.7062732501270085, -0.5009817085202809, -0.5001953857075576}, {
      0.7062732501270085, -0.562040690381209, -0.430451342791315}, {
      0.8655013302530189, -0.3976751866559626, -0.30456837204214116`}, {
      0.8655013302530189, -0.3544725459501831, -0.353916178632526}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.39767518665596246`, -0.30456837204214127`}, {
      0.7062732501270085, -0.5620406903812087, -0.43045134279131514`}, {
      0.7062732501270085, -0.6134637847815714, -0.3533274414993859}, {
      0.8655013302530189, -0.43405989867782907`, -0.2499989033776899}, {
      0.8655013302530189, -0.39767518665596246`, -0.30456837204214127`}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.43405989867782907`, -0.2499989033776899}, {
      0.7062732501270085, -0.6134637847815714, -0.3533274414993859}, {
      0.7062732501270085, -0.6543693702320421, -0.2701459299289047}, {
      0.8655013302530189, -0.46300288556060093`, -0.19114333703483322`}, {
      0.8655013302530189, -0.43405989867782907`, -0.2499989033776899}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.46300288556060093`, -0.19114333703483322`}, {
      0.7062732501270085, -0.6543693702320421, -0.2701459299289047}, {
      0.7062732501270085, -0.6840561423170244, -0.18233291066996923`}, {
      0.8655013302530189, -0.4840079352521118, -0.12901072026479957`}, {
      0.8655013302530189, -0.46300288556060093`, -0.19114333703483322`}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.4840079352521118, -0.12901072026479957`}, {
      0.7062732501270085, -0.6840561423170244, -0.18233291066996923`}, {
      0.7062732501270085, -0.7020151371843025, -0.091393891038389}, {
      0.8655013302530189, -0.4967149273938271, -0.06466628359817629}, {
      0.8655013302530189, -0.4840079352521118, -0.12901072026479957`}}], 
     Polygon3DBox[{{
      0.8655013302530189, -0.4967149273938271, -0.06466628359817629}, {
      0.7062732501270085, -0.7020151371843025, -0.091393891038389}, {
      0.7062732501270085, -0.7079384574584596, 0.001112028043179037}, {
      0.8655013302530189, -0.5009060073920578, 0.0007868219636160948}, {
      0.8655013302530189, -0.4967149273938271, -0.06466628359817629}}], 
     Polygon3DBox[{{0.7062732501270081, 0.70793845745846, 
      0.0011120280431790378`}, {0.498865947352907, 0.8666780908892275, 
      0.001361375881369241}, {0.498865947352907, 
      0.8594265962814026, -0.11188696159897046`}, {0.7062732501270081, 
      0.7020151371843029, -0.09139389103838905}, {0.7062732501270081, 
      0.70793845745846, 0.0011120280431790378`}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.7020151371843029, -0.09139389103838905}, {0.498865947352907, 
      0.8594265962814026, -0.11188696159897046`}, {0.498865947352907, 
      0.837440691684921, -0.2232170568795488}, {0.7062732501270081, 
      0.6840561423170247, -0.18233291066996932`}, {0.7062732501270081, 
      0.7020151371843029, -0.09139389103838905}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.6840561423170247, -0.18233291066996918`}, {0.498865947352907, 
      0.837440691684921, -0.2232170568795486}, {0.498865947352907, 
      0.8010973136918054, -0.33072021493622034`}, {0.7062732501270081, 
      0.6543693702320424, -0.2701459299289047}, {0.7062732501270081, 
      0.6840561423170247, -0.18233291066996918`}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.6543693702320424, -0.2701459299289047}, {0.498865947352907, 
      0.8010973136918054, -0.33072021493622034`}, {0.498865947352907, 
      0.7510195501073904, -0.43255335153964464`}, {0.7062732501270081, 
      0.6134637847815718, -0.3533274414993859}, {0.7062732501270081, 
      0.6543693702320424, -0.2701459299289047}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.6134637847815718, -0.3533274414993858}, {0.498865947352907, 
      0.7510195501073905, -0.4325533515396445}, {0.498865947352907, 
      0.688065957442681, -0.5269705919500379}, {0.7062732501270081, 
      0.5620406903812093, -0.43045134279131503`}, {0.7062732501270081, 
      0.6134637847815718, -0.3533274414993858}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.5620406903812092, -0.43045134279131514`}, {0.498865947352907, 
      0.6880659574426808, -0.526970591950038}, {0.498865947352907, 
      0.6133158414215094, -0.6123532030071472}, {0.7062732501270081, 
      0.5009817085202812, -0.5001953857075578}, {0.7062732501270081, 
      0.5620406903812092, -0.43045134279131514`}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.5009817085202811, -0.500195385707558}, {0.498865947352907, 
      0.6133158414215093, -0.6123532030071474}, {0.498865947352907, 
      0.5280507528603402, -0.6872373454457452}, {0.7062732501270081, 
      0.43133366283226793`, -0.5613638458813784}, {0.7062732501270081, 
      0.5009817085202811, -0.500195385707558}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.43133366283226793`, -0.5613638458813784}, {0.498865947352907, 
      0.5280507528603402, -0.6872373454457452}, {0.498865947352907, 
      0.43373251616397474`, -0.7503391706380215}, {0.7062732501270081, 
      0.35429063186269755`, -0.6129080227320924}, {0.7062732501270081, 
      0.43133366283226793`, -0.5613638458813784}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.35429063186269755`, -0.6129080227320924}, {0.498865947352907, 
      0.43373251616397474`, -0.7503391706380215}, {0.498865947352907, 
      0.3319781671268654, -0.8005768314926267}, {0.7062732501270081, 
      0.27117347723021934`, -0.6539442188764301}, {0.7062732501270081, 
      0.35429063186269755`, -0.6129080227320924}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.27117347723021923`, -0.6539442188764301}, {0.498865947352907, 
      0.3319781671268653, -0.8005768314926267}, {0.498865947352907, 
      0.22453222971805, -0.8370890301452572}, {0.7062732501270081, 
      0.1834071981596006, -0.6837688906482055}, {0.7062732501270081, 
      0.27117347723021923`, -0.6539442188764301}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.1834071981596007, -0.6837688906482055}, {0.498865947352907, 
      0.2245322297180501, -0.8370890301452572}, {0.498865947352907, 
      0.11323680714942272`, -0.859249784450535}, {0.7062732501270081, 
      0.09249650063108553, -0.7018707099787226}, {0.7062732501270081, 
      0.1834071981596007, -0.6837688906482055}}], 
     Polygon3DBox[{{0.7062732501270081, 
      0.09249650063108547, -0.7018707099787226}, {0.498865947352907, 
      0.11323680714942265`, -0.859249784450535}, {0.498865947352907, 
      7.216553688889884*^-17, -0.8666791601115643}, {0.7062732501270081, 
      5.894779088550702*^-17, -0.7079393308434223}, {0.7062732501270081, 
      0.09249650063108547, -0.7018707099787226}}], 
     Polygon3DBox[{{0.7062732501270081, 0., -0.7079393308434223}, {
      0.498865947352907, 0., -0.8666791601115643}, {
      0.498865947352907, -0.11323680714942258`, -0.8592497844505351}, {
      0.7062732501270081, -0.0924965006310854, -0.7018707099787227}, {
      0.7062732501270081, 0., -0.7079393308434223}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.0924965006310853, -0.7018707099787227}, {
      0.498865947352907, -0.11323680714942246`, -0.8592497844505351}, {
      0.498865947352907, -0.22453222971804981`, -0.8370890301452573}, {
      0.7062732501270081, -0.18340719815960044`, -0.6837688906482056}, {
      0.7062732501270081, -0.0924965006310853, -0.7018707099787227}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.18340719815960052`, -0.6837688906482056}, {
      0.498865947352907, -0.2245322297180499, -0.8370890301452573}, {
      0.498865947352907, -0.3319781671268652, -0.8005768314926267}, {
      0.7062732501270081, -0.2711734772302192, -0.6539442188764301}, {
      0.7062732501270081, -0.18340719815960052`, -0.6837688906482056}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.27117347723021906`, -0.6539442188764302}, {
      0.498865947352907, -0.33197816712686506`, -0.8005768314926268}, {
      0.498865947352907, -0.4337325161639745, -0.7503391706380217}, {
      0.7062732501270081, -0.3542906318626974, -0.6129080227320926}, {
      0.7062732501270081, -0.27117347723021906`, -0.6539442188764302}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.3542906318626974, -0.6129080227320924}, {
      0.498865947352907, -0.4337325161639745, -0.7503391706380216}, {
      0.498865947352907, -0.52805075286034, -0.6872373454457453}, {
      0.7062732501270081, -0.43133366283226776`, -0.5613638458813786}, {
      0.7062732501270081, -0.3542906318626974, -0.6129080227320924}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.4313336628322678, -0.5613638458813784}, {
      0.498865947352907, -0.5280507528603401, -0.6872373454457452}, {
      0.498865947352907, -0.6133158414215092, -0.6123532030071475}, {
      0.7062732501270081, -0.500981708520281, -0.500195385707558}, {
      0.7062732501270081, -0.4313336628322678, -0.5613638458813784}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.5009817085202811, -0.500195385707558}, {
      0.498865947352907, -0.6133158414215093, -0.6123532030071474}, {
      0.498865947352907, -0.6880659574426808, -0.5269705919500381}, {
      0.7062732501270081, -0.5620406903812092, -0.4304513427913152}, {
      0.7062732501270081, -0.5009817085202811, -0.500195385707558}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.5620406903812091, -0.43045134279131536`}, {
      0.498865947352907, -0.6880659574426806, -0.5269705919500383}, {
      0.498865947352907, -0.7510195501073904, -0.43255335153964486`}, {
      0.7062732501270081, -0.6134637847815717, -0.35332744149938605`}, {
      0.7062732501270081, -0.5620406903812091, -0.43045134279131536`}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.6134637847815717, -0.35332744149938605`}, {
      0.498865947352907, -0.7510195501073904, -0.43255335153964486`}, {
      0.498865947352907, -0.8010973136918053, -0.3307202149362205}, {
      0.7062732501270081, -0.6543693702320424, -0.27014592992890485`}, {
      0.7062732501270081, -0.6134637847815717, -0.35332744149938605`}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.6543693702320424, -0.27014592992890485`}, {
      0.498865947352907, -0.8010973136918053, -0.3307202149362205}, {
      0.498865947352907, -0.837440691684921, -0.2232170568795488}, {
      0.7062732501270081, -0.6840561423170247, -0.18233291066996932`}, {
      0.7062732501270081, -0.6543693702320424, -0.27014592992890485`}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.6840561423170247, -0.18233291066996932`}, {
      0.498865947352907, -0.837440691684921, -0.2232170568795488}, {
      0.498865947352907, -0.8594265962814026, -0.11188696159897046`}, {
      0.7062732501270081, -0.7020151371843029, -0.09139389103838905}, {
      0.7062732501270081, -0.6840561423170247, -0.18233291066996932`}}], 
     Polygon3DBox[{{
      0.7062732501270081, -0.7020151371843029, -0.09139389103838905}, {
      0.498865947352907, -0.8594265962814026, -0.11188696159897046`}, {
      0.498865947352907, -0.8666780908892275, 0.001361375881369241}, {
      0.7062732501270081, -0.70793845745846, 0.0011120280431790378`}, {
      0.7062732501270081, -0.7020151371843029, -0.09139389103838905}}], 
     Polygon3DBox[{{0.4988659473529066, 0.8666780908892278, 
      0.0013613758813692414`}, {0.25742794393320656`, 0.9662963053824023, 
      0.0015178559354766773`}, {0.25742794393320656`, 
      0.958211305286401, -0.12474753746528765`}, {0.4988659473529066, 
      0.8594265962814028, -0.1118869615989705}, {0.4988659473529066, 
      0.8666780908892278, 0.0013613758813692414`}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.8594265962814028, -0.1118869615989705}, {0.25742794393320656`, 
      0.958211305286401, -0.12474753746528765`}, {0.25742794393320656`, 
      0.9336982841250232, -0.24887420096166935`}, {0.4988659473529066, 
      0.8374406916849212, -0.22321705687954885`}, {0.4988659473529066, 
      0.8594265962814028, -0.1118869615989705}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.8374406916849212, -0.22321705687954865`}, {0.25742794393320656`, 
      0.9336982841250232, -0.24887420096166912`}, {0.25742794393320656`, 
      0.8931775045541083, -0.3687340492018844}, {0.4988659473529066, 
      0.8010973136918056, -0.3307202149362204}, {0.4988659473529066, 
      0.8374406916849212, -0.22321705687954865`}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.8010973136918056, -0.3307202149362204}, {0.25742794393320656`, 
      0.8931775045541083, -0.3687340492018844}, {0.25742794393320656`, 
      0.8373436736979659, -0.48227214910288596`}, {0.4988659473529066, 
      0.7510195501073906, -0.43255335153964475`}, {0.4988659473529066, 
      0.8010973136918056, -0.3307202149362204}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.7510195501073907, -0.43255335153964464`}, {0.25742794393320656`, 
      0.837343673697966, -0.4822721491028858}, {0.25742794393320656`, 
      0.7671540327667604, -0.5875419505805676}, {0.4988659473529066, 
      0.6880659574426811, -0.526970591950038}, {0.4988659473529066, 
      0.7510195501073907, -0.43255335153964464`}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.688065957442681, -0.5269705919500381}, {0.25742794393320656`, 
      0.7671540327667603, -0.5875419505805677}, {0.25742794393320656`, 
      0.6838119456672078, -0.6827386591113392}, {0.4988659473529066, 
      0.6133158414215095, -0.6123532030071475}, {0.4988659473529066, 
      0.688065957442681, -0.5269705919500381}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.6133158414215094, -0.6123532030071476}, {0.25742794393320656`, 
      0.6838119456672077, -0.6827386591113394}, {0.25742794393320656`, 
      0.5887462679710911, -0.7662301779703239}, {0.4988659473529066, 
      0.5280507528603403, -0.6872373454457454}, {0.4988659473529066, 
      0.6133158414215094, -0.6123532030071476}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.5280507528603403, -0.6872373454457454}, {0.25742794393320656`, 
      0.5887462679710911, -0.7662301779703239}, {0.25742794393320656`, 
      0.4835868499496083, -0.8365850896580316}, {0.4988659473529066, 
      0.43373251616397485`, -0.7503391706380217}, {0.4988659473529066, 
      0.5280507528603403, -0.6872373454457454}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.43373251616397485`, -0.7503391706380217}, {0.25742794393320656`, 
      0.4835868499496083, -0.8365850896580316}, {0.25742794393320656`, 
      0.3701365936609475, -0.8925971967888946}, {0.4988659473529066, 
      0.33197816712686545`, -0.8005768314926269}, {0.4988659473529066, 
      0.43373251616397485`, -0.7503391706380217}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.33197816712686534`, -0.8005768314926269}, {0.25742794393320656`, 
      0.37013659366094737`, -0.8925971967888946}, {0.25742794393320656`, 
      0.25034054315739634`, -0.9333062017012325}, {0.4988659473529066, 
      0.22453222971805006`, -0.8370890301452574}, {0.4988659473529066, 
      0.33197816712686534`, -0.8005768314926269}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.22453222971805015`, -0.8370890301452574}, {0.25742794393320656`, 
      0.25034054315739646`, -0.9333062017012325}, {0.25742794393320656`, 
      0.12625253774388082`, -0.9580141702477848}, {0.4988659473529066, 
      0.11323680714942275`, -0.8592497844505352}, {0.4988659473529066, 
      0.22453222971805015`, -0.8370890301452574}}], 
     Polygon3DBox[{{0.4988659473529066, 
      0.11323680714942268`, -0.8592497844505352}, {0.25742794393320656`, 
      0.12625253774388073`, -0.9580141702477848}, {0.25742794393320656`, 
      8.046042977748842*^-17, -0.9662974975039115}, {0.4988659473529066, 
      7.216553688889887*^-17, -0.8666791601115645}, {0.4988659473529066, 
      0.11323680714942268`, -0.8592497844505352}}], 
     Polygon3DBox[{{0.4988659473529066, 0., -0.8666791601115645}, {
      0.25742794393320656`, 0., -0.9662974975039115}, {
      0.25742794393320656`, -0.12625253774388068`, -0.9580141702477849}, {
      0.4988659473529066, -0.11323680714942261`, -0.8592497844505353}, {
      0.4988659473529066, 0., -0.8666791601115645}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.11323680714942248`, -0.8592497844505353}, {
      0.25742794393320656`, -0.12625253774388054`, -0.9580141702477849}, {
      0.25742794393320656`, -0.2503405431573961, -0.9333062017012326}, {
      0.4988659473529066, -0.22453222971804987`, -0.8370890301452575}, {
      0.4988659473529066, -0.11323680714942248`, -0.8592497844505353}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.22453222971804995`, -0.8370890301452575}, {
      0.25742794393320656`, -0.25034054315739623`, -0.9333062017012326}, {
      0.25742794393320656`, -0.37013659366094726`, -0.8925971967888946}, {
      0.4988659473529066, -0.3319781671268653, -0.8005768314926269}, {
      0.4988659473529066, -0.22453222971804995`, -0.8370890301452575}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.3319781671268652, -0.800576831492627}, {
      0.25742794393320656`, -0.37013659366094714`, -0.8925971967888947}, {
      0.25742794393320656`, -0.4835868499496081, -0.8365850896580318}, {
      0.4988659473529066, -0.4337325161639746, -0.7503391706380219}, {
      0.4988659473529066, -0.3319781671268652, -0.800576831492627}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.4337325161639746, -0.7503391706380218}, {
      0.25742794393320656`, -0.4835868499496081, -0.8365850896580317}, {
      0.25742794393320656`, -0.5887462679710909, -0.766230177970324}, {
      0.4988659473529066, -0.5280507528603402, -0.6872373454457454}, {
      0.4988659473529066, -0.4337325161639746, -0.7503391706380218}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.5280507528603402, -0.6872373454457454}, {
      0.25742794393320656`, -0.588746267971091, -0.7662301779703239}, {
      0.25742794393320656`, -0.6838119456672076, -0.6827386591113395}, {
      0.4988659473529066, -0.6133158414215093, -0.6123532030071476}, {
      0.4988659473529066, -0.5280507528603402, -0.6872373454457454}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.6133158414215094, -0.6123532030071476}, {
      0.25742794393320656`, -0.6838119456672077, -0.6827386591113394}, {
      0.25742794393320656`, -0.7671540327667603, -0.5875419505805678}, {
      0.4988659473529066, -0.688065957442681, -0.5269705919500383}, {
      0.4988659473529066, -0.6133158414215094, -0.6123532030071476}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.6880659574426808, -0.5269705919500385}, {
      0.25742794393320656`, -0.7671540327667601, -0.587541950580568}, {
      0.25742794393320656`, -0.8373436736979658, -0.4822721491028862}, {
      0.4988659473529066, -0.7510195501073905, -0.43255335153964497`}, {
      0.4988659473529066, -0.6880659574426808, -0.5269705919500385}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.7510195501073905, -0.43255335153964497`}, {
      0.25742794393320656`, -0.8373436736979658, -0.4822721491028862}, {
      0.25742794393320656`, -0.8931775045541082, -0.36873404920188463`}, {
      0.4988659473529066, -0.8010973136918055, -0.3307202149362206}, {
      0.4988659473529066, -0.7510195501073905, -0.43255335153964497`}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.8010973136918055, -0.3307202149362206}, {
      0.25742794393320656`, -0.8931775045541082, -0.36873404920188463`}, {
      0.25742794393320656`, -0.9336982841250232, -0.24887420096166935`}, {
      0.4988659473529066, -0.8374406916849212, -0.22321705687954885`}, {
      0.4988659473529066, -0.8010973136918055, -0.3307202149362206}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.8374406916849212, -0.22321705687954885`}, {
      0.25742794393320656`, -0.9336982841250232, -0.24887420096166935`}, {
      0.25742794393320656`, -0.958211305286401, -0.12474753746528765`}, {
      0.4988659473529066, -0.8594265962814028, -0.1118869615989705}, {
      0.4988659473529066, -0.8374406916849212, -0.22321705687954885`}}], 
     Polygon3DBox[{{
      0.4988659473529066, -0.8594265962814028, -0.1118869615989705}, {
      0.25742794393320656`, -0.958211305286401, -0.12474753746528765`}, {
      0.25742794393320656`, -0.9662963053824023, 0.0015178559354766773`}, {
      0.4988659473529066, -0.8666780908892278, 0.0013613758813692414`}, {
      0.4988659473529066, -0.8594265962814028, -0.1118869615989705}}], 
     Polygon3DBox[{{0.257427943933207, 0.9662963053824022, 
      0.0015178559354766773`}, {-0.0015707956808311027`, 0.999997532600929, 
      0.0015707937429396226`}, {-0.0015707956808311027`, 
      0.9916305543748455, -0.12909832001682145`}, {0.257427943933207, 
      0.9582113052864009, -0.12474753746528763`}, {0.257427943933207, 
      0.9662963053824022, 0.0015178559354766773`}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.9582113052864009, -0.12474753746528763`}, {-0.0015707956808311027`, 
      0.9916305543748455, -0.12909832001682145`}, {-0.0015707956808311027`, 
      0.9662625999063955, -0.25755411202903006`}, {0.257427943933207, 
      0.9336982841250231, -0.24887420096166932`}, {0.257427943933207, 
      0.9582113052864009, -0.12474753746528763`}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.9336982841250231, -0.2488742009616691}, {-0.0015707956808311027`, 
      0.9662625999063955, -0.25755411202902984`}, {-0.0015707956808311027`, 
      0.9243285892263636, -0.3815942763456096}, {0.257427943933207, 
      0.8931775045541082, -0.36873404920188435`}, {0.257427943933207, 
      0.9336982841250231, -0.2488742009616691}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.8931775045541082, -0.36873404920188435`}, {-0.0015707956808311027`, 
      0.9243285892263636, -0.3815942763456096}, {-0.0015707956808311027`, 
      0.8665474585516433, -0.4990922105970169}, {0.257427943933207, 
      0.8373436736979658, -0.4822721491028859}, {0.257427943933207, 
      0.8931775045541082, -0.36873404920188435`}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.8373436736979659, -0.48227214910288574`}, {-0.0015707956808311027`, 
      0.8665474585516434, -0.49909221059701675`}, {-0.0015707956808311027`, 
      0.7939098345077701, -0.6080334754540856}, {0.257427943933207, 
      0.7671540327667603, -0.5875419505805675}, {0.257427943933207, 
      0.8373436736979659, -0.48227214910288574`}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.7671540327667602, -0.5875419505805676}, {-0.0015707956808311027`, 
      0.79390983450777, -0.6080334754540857}, {-0.0015707956808311027`, 
      0.707661050364502, -0.70655033111445}, {0.257427943933207, 
      0.6838119456672077, -0.6827386591113391}, {0.257427943933207, 
      0.7671540327667602, -0.5875419505805676}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.6838119456672076, -0.6827386591113392}, {-0.0015707956808311027`, 
      0.7076610503645019, -0.7065503311144501}, {-0.0015707956808311027`, 
      0.6092797954620207, -0.792953758703928}, {0.257427943933207, 
      0.588746267971091, -0.7662301779703238}, {0.257427943933207, 
      0.6838119456672076, -0.6827386591113392}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.588746267971091, -0.7662301779703238}, {-0.0015707956808311027`, 
      0.6092797954620207, -0.792953758703928}, {-0.0015707956808311027`, 
      0.5004527638719365, -0.8657624176030447}, {0.257427943933207, 
      0.48358684994960827`, -0.8365850896580315}, {0.257427943933207, 
      0.588746267971091, -0.7662301779703238}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.48358684994960827`, -0.8365850896580315}, {-0.0015707956808311027`, 
      0.5004527638719365, -0.8657624176030447}, {-0.0015707956808311027`, 
      0.383045736928263, -0.9237280422407956}, {0.257427943933207, 
      0.3701365936609474, -0.8925971967888945}, {0.257427943933207, 
      0.48358684994960827`, -0.8365850896580315}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.3701365936609473, -0.8925971967888945}, {-0.0015707956808311027`, 
      0.3830457369282629, -0.9237280422407956}, {-0.0015707956808311027`, 
      0.25907159540292685`, -0.9658568429411841}, {0.257427943933207, 
      0.25034054315739634`, -0.9333062017012324}, {0.257427943933207, 
      0.3701365936609473, -0.8925971967888945}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.25034054315739646`, -0.9333062017012324}, {-0.0015707956808311027`, 
      0.25907159540292696`, -0.9658568429411841}, {-0.0015707956808311027`, 
      0.13065580973997765`, -0.9914265439164516}, {0.257427943933207, 
      0.12625253774388082`, -0.9580141702477847}, {0.257427943933207, 
      0.25034054315739646`, -0.9333062017012324}}], 
     Polygon3DBox[{{0.257427943933207, 
      0.12625253774388073`, -0.9580141702477847}, {-0.0015707956808311027`, 
      0.13065580973997756`, -0.9914265439164516}, {-0.0015707956808311027`, 
      8.326662412070115*^-17, -0.9999987662997035}, {0.257427943933207, 
      8.046042977748841*^-17, -0.9662974975039114}, {0.257427943933207, 
      0.12625253774388073`, -0.9580141702477847}}], 
     Polygon3DBox[{{0.257427943933207, 
      0., -0.9662974975039114}, {-0.0015707956808311027`, 
      0., -0.9999987662997035}, {-0.0015707956808311027`, \
-0.13065580973997748`, -0.9914265439164517}, {
      0.257427943933207, -0.12625253774388065`, -0.9580141702477848}, {
      0.257427943933207, 0., -0.9662974975039114}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.1262525377438805, -0.9580141702477848}, \
{-0.0015707956808311027`, -0.13065580973997734`, -0.9914265439164517}, \
{-0.0015707956808311027`, -0.2590715954029266, -0.9658568429411842}, {
      0.257427943933207, -0.2503405431573961, -0.9333062017012325}, {
      0.257427943933207, -0.1262525377438805, -0.9580141702477848}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.25034054315739623`, -0.9333062017012325}, \
{-0.0015707956808311027`, -0.25907159540292674`, -0.9658568429411842}, \
{-0.0015707956808311027`, -0.38304573692826277`, -0.9237280422407956}, {
      0.257427943933207, -0.3701365936609472, -0.8925971967888945}, {
      0.257427943933207, -0.25034054315739623`, -0.9333062017012325}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.3701365936609471, -0.8925971967888946}, \
{-0.0015707956808311027`, -0.38304573692826266`, -0.9237280422407957}, \
{-0.0015707956808311027`, -0.5004527638719363, -0.865762417603045}, {
      0.257427943933207, -0.48358684994960804`, -0.8365850896580317}, {
      0.257427943933207, -0.3701365936609471, -0.8925971967888946}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.48358684994960804`, -0.8365850896580316}, \
{-0.0015707956808311027`, -0.5004527638719363, -0.8657624176030448}, \
{-0.0015707956808311027`, -0.6092797954620205, -0.7929537587039281}, {
      0.257427943933207, -0.5887462679710908, -0.7662301779703239}, {
      0.257427943933207, -0.48358684994960804`, -0.8365850896580316}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.5887462679710909, -0.7662301779703238}, \
{-0.0015707956808311027`, -0.6092797954620206, -0.792953758703928}, \
{-0.0015707956808311027`, -0.7076610503645018, -0.7065503311144502}, {
      0.257427943933207, -0.6838119456672075, -0.6827386591113394}, {
      0.257427943933207, -0.5887462679710909, -0.7662301779703238}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.6838119456672076, -0.6827386591113392}, \
{-0.0015707956808311027`, -0.7076610503645019, -0.7065503311144501}, \
{-0.0015707956808311027`, -0.79390983450777, -0.6080334754540858}, {
      0.257427943933207, -0.7671540327667602, -0.5875419505805677}, {
      0.257427943933207, -0.6838119456672076, -0.6827386591113392}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.76715403276676, -0.5875419505805679}, \
{-0.0015707956808311027`, -0.7939098345077698, -0.608033475454086}, \
{-0.0015707956808311027`, -0.8665474585516432, -0.49909221059701714`}, {
      0.257427943933207, -0.8373436736979657, -0.4822721491028861}, {
      0.257427943933207, -0.76715403276676, -0.5875419505805679}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.8373436736979657, -0.4822721491028861}, \
{-0.0015707956808311027`, -0.8665474585516432, -0.49909221059701714`}, \
{-0.0015707956808311027`, -0.9243285892263635, -0.38159427634560983`}, {
      0.257427943933207, -0.893177504554108, -0.3687340492018846}, {
      0.257427943933207, -0.8373436736979657, -0.4822721491028861}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.893177504554108, -0.3687340492018846}, \
{-0.0015707956808311027`, -0.9243285892263635, -0.38159427634560983`}, \
{-0.0015707956808311027`, -0.9662625999063955, -0.25755411202903006`}, {
      0.257427943933207, -0.9336982841250231, -0.24887420096166932`}, {
      0.257427943933207, -0.893177504554108, -0.3687340492018846}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.9336982841250231, -0.24887420096166932`}, \
{-0.0015707956808311027`, -0.9662625999063955, -0.25755411202903006`}, \
{-0.0015707956808311027`, -0.9916305543748455, -0.12909832001682145`}, {
      0.257427943933207, -0.9582113052864009, -0.12474753746528763`}, {
      0.257427943933207, -0.9336982841250231, -0.24887420096166932`}}], 
     Polygon3DBox[{{
      0.257427943933207, -0.9582113052864009, -0.12474753746528763`}, \
{-0.0015707956808311027`, -0.9916305543748455, -0.12909832001682145`}, \
{-0.0015707956808311027`, -0.999997532600929, 0.0015707937429396226`}, {
      0.257427943933207, -0.9662963053824022, 0.0015178559354766773`}, {
      0.257427943933207, -0.9582113052864009, -0.12474753746528763`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx11ntIk3sYB/CVmWRQnYooupCF54hUav3RsNrXSKih1dFCs5vkUbsYNSjp
BgVFBl00SroZ81Qc0ijCzNVy8SyJw7GT8NqKxKAtqqW9uBl0o9sa/R7fP556
B/tjDy8/nt/3efbZEoo255b0t1gsxdF3TPRd6f08oMRTgEjGEt+nSJiS/8/u
LYp+7pr725DGHRoNdzanB/UQbR57orTg6TLcttgcZT1+mtQzrMHXrNO/rkfW
gYvyUOx+veLe6SBNv5x1ZNPFINV0fhyQYs1F1um9HSnXdFrTFjNoY1yAuid9
y87/zw4tvm2EHgxR8UHnrC9OjeaGYrMSPOloKdywPBLt49327eV/eex0od/4
tY3XrttcrQWjM16HaJTPWzWxQkPl0OSCxOp0WtgysqH2pk6xH85Zqz76kZq8
KqXMZaeHJ8/XvjgfJFts3YQ8ZxC9QxrWPE3NpcA2zfGkX4C2+etGlTbpeJh/
nDoX5FFLffnwo8c0ejY403W8K4Q/pp0pvPJkGVl+vLyz3fvr13+NhFF350de
1K6eh5+fT+TnX6nzsYXPb+fzO1U/sHI/OveTo/rHh/eq/0Tu363ui8gDdd/1
fF/OB++Oqnx6R6p82lSe2Mp5ruA87Sp/lHD+Yc5/tZoXrDyvv3leV9V88TvP
t5XnG1D7gBG8Dw7eh0pN5SH3h/fKtJ4zebTF0Rym9jLrjKwKL/XVfZm2Q7XR
82eujLPd3aUZ9QP7rx4eU91DAxsWl8Zv7DDqlLTKc+eWTvPfH9468Y3fqG8I
vDzVtLabMpbvdvYvf27Uc77tbk36J0iZly44hp4NGvW08JZ8657n1P22pipQ
2G3UT93y7muKCdACr6toyXXdqN+ot2U+2NdBO//cOW5aVY9RfxwpjjtXrVFa
TcLZ7K6QUR98P7R6qdtLU+ZoSXfdYaNu4Rfvl1GPUc9jqnjep87HdHF+o+oH
u0Q/J1T/sIv+U9V9Ie/L+UDms07liXkiz9sqfywS+VeoeSFezIvni1livrwP
kPvA+wOTvYLwCuwVhFdgryC8AnsF4RXYKwivwF5BeAX2CsIrsFckvAJ7RcIr
sFckvAJ7RcIrsFckvPL07ZPwitgrEl4Re0XCK2KvSHhF7BUJr4i9IuEVsVcQ
XhF7BeEVsVcQXhF7BeEVsVcQXhF7BeEVTPbKtG6yn+jbZ+EV2CsIr8BeQXgF
9grCK5h8H5H26+8v2CsIr8BeQXgF9grCK7BXEF7BxCuwVyS8AntFwiuwVyS8
AntFwiuk/tpnmHgO9oqEV2CvSHgF9oqEV33zJeEVTH6/fvof9R0RQg42
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2., 1., -1.}, {2., -1., -1.}, {2., -1., 1.}, {2., 1., 1.}, {
       2., 1., -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2., -1., -1.}, {0., -1., -1.}, {0., -1., 1.}, {2., -1., 
       1.}, {2., -1., -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -1, -1}, {0, 1, -1}, {0, 1, 1}, {0, -1, 1}, {
       0, -1, -1}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 1., -1.}, {2., 1., -1.}, {2., 1., 1.}, {0., 1., 1.}, {
       0., 1., -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2., -1., -1.}, {2., 1., -1.}, {0., 1., -1.}, {
       0., -1., -1.}, {2., -1., -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2., 1., 1.}, {2., -1., 1.}, {0., -1., 1.}, {0., 1., 1.}, {
       2., 1., 1.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFk01IVFEUx4dKBAkxqqVKMGEWaVBEYHjGyiLdVItwoYsCXUhkIU2kxNAi
QS2D0KKFLaKNo5KRmEFyjWAMckgcexg4wTQ1DkP1pjTmQ/rQ3jk37nld3oUH
jx8/7j1/Dv9tZ1tONa53uVylq9+61W/tH4/H9f/jwF8JAvmtJbvHzpvAOfnp
8NRsk39YCGjtqQkFYCP6nJN/NfV49F7zS+jJHekY3f8c6H7Oyfchv2FxQT7n
5H/Hdyetd6XPuZp3Xuaaj/jNcv8X4FzNO4G5DCCfczVvCHNNS59zNW8Ic00L
8jlX805gLkP6nKt5P8hc7qfHeosvJYBz8ttiW4uCEBBvWozE5aIIkM85+QeX
8m7FisMwmLOhMbf0rfQ5J78S+YDFBfmck+/Fd2esd6XPuZo3LnMl0rMDvp2f
gHN1v0HcYwzI51zdbxT3uCB9ztX9RnGPCyKOPufqfoO4x5ig+zl36ml2pilT
u/hvv0493fury/2kYUr4Lnx+dzEbcexpwYmh7u133kM6NV5pHjDAqadb0E9Z
vmNPy3Cea9Y8QtfTyYrO6zd3ZZAnbb229ffrszxvThZGzhxfaX89h35S29MC
b0XAvfkn/P57TDj6o7/QgEXQ9TQffbr3kOVre2rgPH51HqHr6f2aTYXLK6Yt
r66nY23x6j0nk7a8up4+aK4PPGr/Juc/jHl1PX3IfA/m1fV0HOcZZHl1PfVk
uvuu7Phoy6vr6XD5i3P1S1FbXl1P68J3b8/ti8r5j2BeXU9PM78K8+p6SvPw
/f4Bemw+ag==
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQBGJmBjhwYEADfMXqutvy3ttDeCf2w8R5oOI/7h6/lLZq
7f799sV9XpeP2cPU137fuGVm1mH7PvYNbVvM9sDF66HiPRDx/TDxT1BzDkDM
2X/j4ar3+qveQu29AbcXJg6xdy/U3mv2MHGIvZeh9p6Bi9dDxSH2noGb/wlq
DsTea/tVtrtPkS99BbX3EdxemHjVM1G5s/bH9p/Pv/aqXO6hPUzc5jNX/zP5
u/arWVlS2TWvwsXtoOIrIeJw88ug5lyAmLP/1Y9LK+u1nkLtfQG3FyYO8e9Z
qH+f2cPEIf59DPXvHfsXUPF6qDjEv3fg5n+CmgPx7zOYPQ6/LqT99H6O8C9M
3Phfl8rm2OP76wve3Cz89dAeJi4QsKZbddo9+x/fd9i9t7gGFxeBin+HiMPN
14Oa0wgxZ/8B687WXu2fUH0fEPH7bidXGesv+w2Jnr+rT1+Bin+wFyizPqYi
/Nf+Pxi8t3f7Olf2mv1zez6oOEydE0R8/zWoOatQzdk/z0tQ9svv9xj2bqt6
4WoQ+AHD3kVZMcfWV3+Em+8MtXcJmrgD1N4dUHNWo9nr8LN7aqXGEwx71+of
zIn5/BjD3oi70yddMXkMN98Fam8Ymrgj1F6YOej+BQAb8rA+
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  AxesLabel:>{
    FormBox["\"x-axis\"", TraditionalForm], 
    FormBox["\"y-axis\"", TraditionalForm], 
    FormBox["\"z-axis\"", TraditionalForm]},
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301502427375*^9, 3.614709268935939*^9, 
  3.614729124031513*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"},
 CellLabel->"During evaluation of In[183]:="]
}, Open  ]],

Cell["\<\
Vector parametric function format of an enclosed spherical mirror.\
\>", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell["\<\
 Although such vector surface functions do not have parametric correspondence \
with the Cartesian space coordinates, the resulting ray trace is still \
reported in rectangular coordinates.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}],

Cell[CellGroupData[{

Cell["4.3.1 Working from a Derived Symbolic Surface Equation", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[TextData[{
 "Sometimes, you may want to use a derived symbolic equation in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ". As an example, we can derive the equation for an ellipse and then create \
a mirror with it. First we need to determine the general mathematical form \
for the ellipsoid surface. We can start with the three-dimensional ellipse \
equation ",
 StyleBox["(x/a)^2 + (y/b)^2 + (z/c)^2 = r^2",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and solve for ",
 StyleBox["z",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["solution = Solve[(x/a)^2 + (y/b)^2 + (z/c)^2 == r^2,z]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[184]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"c", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["r", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["y", "2"]}]}]]}], 
       RowBox[{"a", " ", "b"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", 
     FractionBox[
      RowBox[{"c", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["y", "2"]}]}]]}], 
      RowBox[{"a", " ", "b"}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563404255135222*^9, 3.563458149188016*^9, 
  3.564487591285027*^9, 3.5661006922234707`*^9, 3.601301241427308*^9, 
  3.6013015025363617`*^9, 3.614709269073235*^9, 3.614729124773731*^9},
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[184]="]
}, Open  ]],

Cell[TextData[{
 "Notice that there are two solutions: one positive valued and the other \
negative valued. Such solutions from ",
 StyleBox["Solve", "Input"],
 " are always reported as sets of replacement rules in the form of ",
 StyleBox["z -> ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["solution",
  FontSlant->"Italic"],
 ". As such, we need to extract the positive solution and discard the other \
solution. In addition, we will use ",
 StyleBox["ReplaceFor",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (",
 StyleBox["/.",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") in order to extract the desired solution. The final result is finally \
stored in the ",
 StyleBox["ellipse3D",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " variable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["ellipse3D[a_,b_,c_,r_,x_,y_] = z/.solution[[2]]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[185]:="],

Cell[BoxData[
 FractionBox[
  RowBox[{"c", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["r", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["y", "2"]}]}]]}], 
  RowBox[{"a", " ", "b"}]]], "Output",
 CellChangeTimes->{3.5634042552175694`*^9, 3.563458149272148*^9, 
  3.56448759132775*^9, 3.566100692397633*^9, 3.6013012414677353`*^9, 
  3.601301502566937*^9, 3.614709269103437*^9, 3.614729124829297*^9},
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[185]="]
}, Open  ]],

Cell[TextData[{
 "Before using the equation to define an optical surface, we need to test \
appropriate numeric values for the constants ",
 StyleBox["a",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["b",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["c",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", and ",
 StyleBox["r",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". We can use ",
 StyleBox["Plot3D",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " to visually verify our chosen parameter settings."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell["\<\
Plot3D[ellipse3D[10,10,10,20,s,t], {s,-100,100},{t,-100,100}];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[186]:="],

Cell[TextData[{
 "In order to create an elliptical mirror, we can directly pass this \
elliptical equation to ",
 StyleBox["CustomMirror", "Input"],
 ". Before doing this, however, the elliptical equation needs to be expressed \
as one of the three ",
 StyleBox["Function", "Input"],
 " formats described in the previous section. In this case, the elliptical \
function is single-valued and dependent on two rectangular parameters {s, t}. \
As such, we can use the single-valued ",
 StyleBox["Function", "Input"],
 " format of (1). However, before we can implement this format, we first need \
to learn more about the use of the ",
 StyleBox["Function", "Input"],
 " structure. In particular, ",
 StyleBox["Function", "Input"],
 " has the ",
 StyleBox["HoldAll", "Input"],
 " attribute. You can check this with the ",
 StyleBox["Attributes", "Input"],
 " command."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["Attributes[Function]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[187]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"HoldAll", ",", "Protected"}], "}"}]], "Output",
 CellChangeTimes->{3.563404256217825*^9, 3.5634581495732822`*^9, 
  3.564487591418838*^9, 3.566100692575348*^9, 3.601301241688512*^9, 
  3.601301502770977*^9, 3.6147092691645308`*^9, 3.614729124896429*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[187]="]
}, Open  ]],

Cell[TextData[{
 "As a result of this ",
 StyleBox["HoldAll", "Input"],
 " attribute, all of the arguments for ",
 StyleBox["Function", "Input"],
 " are maintained in an unevaluated form. Therefore, if we directly pass ",
 StyleBox["ellipse3D", "Input"],
 " to ",
 StyleBox["Function", "Input"],
 ", it does not get converted into the underlaying equation, but instead \
remains in an unevaluated state:"
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["Function[{s,t},ellipse3D[10,10,10,20,s,t]]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[188]:="],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], ",", 
   RowBox[{"ellipse3D", "[", 
    RowBox[{"10", ",", "10", ",", "10", ",", "20", ",", "s", ",", "t"}], 
    "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.563404256294649*^9, 3.563458150341934*^9, 
  3.564487591462223*^9, 3.566100692697776*^9, 3.6013012418063107`*^9, 
  3.601301502888928*^9, 3.614709269205318*^9, 3.6147291249386263`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[188]="]
}, Open  ]],

Cell[TextData[{
 "This becomes a problem for ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " because it expects to receive the actual surface equation and not an \
unevaluated intermediate expression. Therefore, we must use the ",
 StyleBox["Evaluate", "Input"],
 " command to evaluate ",
 StyleBox["ellipse3D", "Input"],
 " variable and directly express the surface equation within the ",
 StyleBox["Function", "Input"],
 ": "
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["Function[{s,t}, Evaluate[ellipse3D[10,10,10,20,s,t]] ]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], ",", 
   RowBox[{
    FractionBox["1", "10"], " ", 
    SqrtBox[
     RowBox[{"4000000", "-", 
      RowBox[{"100", " ", 
       SuperscriptBox["s", "2"]}], "-", 
      RowBox[{"100", " ", 
       SuperscriptBox["t", "2"]}]}]]}]}], "]"}]], "Output",
 CellChangeTimes->{3.563404256327471*^9, 3.5634581504727163`*^9, 
  3.564487591494392*^9, 3.566100692759197*^9, 3.6013012419570208`*^9, 
  3.6013015029356947`*^9, 3.614709269237973*^9, 3.6147291249782476`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[189]="]
}, Open  ]],

Cell[TextData[{
 "With this, we can now define a ",
 StyleBox["CustomMirror", "Input"],
 " component."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["\<\
custommirror = 
\tCustomMirror[
\t\tFunction[{s,t}, Evaluate[ellipse3D[10,10,10,20,s,t]] ], 
\t\t{100,100}
\t]\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[190]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomMirror", "[", 
     RowBox[{
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}], ",", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"4000000", "-", 
           RowBox[{"100", " ", 
            SuperscriptBox["s", "2"]}], "-", 
           RowBox[{"100", " ", 
            SuperscriptBox["t", "2"]}]}]]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "100"}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5634042564708977`*^9, 3.563458151527534*^9, 
  3.564487591716218*^9, 3.5661006934436283`*^9, 3.601301242057226*^9, 
  3.601301503327115*^9, 3.614709269590787*^9, 3.614729125288252*^9},
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"Out[190]="]
}, Open  ]],

Cell["We can now immediately use this new optic for ray tracing.", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tMove[WedgeOfRays[20],30,5],
\tcustommirror,
\tMove[Boundary[300,150],-50]}
];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"In[191]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ79tfXXUZMMBwYw8DzAAAUfpizRr1mW4bB6FQg4
wMXnJ1gb732Z4bAGLG4AF4eATKg5DHthIgug6ldA1MPk4eZDxB3g4jD3/PsP
Ah4Y4lB3YpizGs0cNHfCxdHcaYvDnRjhsAItHNDciSEOdSdcHACiYXCn
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ79tfXXUZMMBwYU4Hngw5Ql+jXLEOKrV4GAw4H5
CdbGe18ixNeAxQ0OQHiZaOYw7F2Apn4FRL0DuvkQcQcHdPf8+w8CHhjiUHdi
mAN1pwMOdzrgcKctDndihAPUnQdwuBNDHOrOAwDsm3Cn
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{187.08286933869707`, -50., -50.}, {
      190.75871903765994`, -33.33333333333333, -50.}, {
      194.36506316151002`, -33.33333333333333, -33.33333333333333}, {
      190.75871903765994`, -50., -33.33333333333333}, {
      187.08286933869707`, -50., -50.}}], 
     Polygon3DBox[{{190.75871903765994`, -50., -33.33333333333333}, {
      194.36506316151002`, -33.33333333333333, -33.33333333333333}, {
      196.49710204252662`, -33.33333333333333, -16.66666666666666}, {
      192.93061504650376`, -50., -16.66666666666666}, {
      190.75871903765994`, -50., -33.33333333333333}}], 
     Polygon3DBox[{{192.93061504650376`, -50., -16.666666666666664`}, {
      196.49710204252662`, -33.33333333333333, -16.666666666666664`}, {
      197.2026594366539, -33.33333333333333, 3.552713678800501*^-15}, {
      193.64916731037087`, -50., 3.552713678800501*^-15}, {
      192.93061504650376`, -50., -16.666666666666664`}}], 
     Polygon3DBox[{{193.64916731037087`, -50., 0.}, {
      197.2026594366539, -33.33333333333333, 0.}, {
      196.49710204252662`, -33.33333333333333, 16.666666666666668`}, {
      192.93061504650376`, -50., 16.666666666666668`}, {
      193.64916731037087`, -50., 0.}}], 
     Polygon3DBox[{{192.93061504650376`, -50., 16.66666666666667}, {
      196.49710204252662`, -33.33333333333333, 16.66666666666667}, {
      194.36506316151002`, -33.33333333333333, 33.33333333333334}, {
      190.75871903765994`, -50., 33.33333333333334}, {
      192.93061504650376`, -50., 16.66666666666667}}], 
     Polygon3DBox[{{190.75871903765994`, -50., 33.33333333333334}, {
      194.36506316151002`, -33.33333333333333, 33.33333333333334}, {
      190.75871903765994`, -33.33333333333333, 50.000000000000014`}, {
      187.08286933869707`, -50., 50.000000000000014`}, {
      190.75871903765994`, -50., 33.33333333333334}}], 
     Polygon3DBox[{{190.75871903765994`, -33.33333333333333, -50.}, {
      192.93061504650376`, -16.66666666666666, -50.}, {
      196.49710204252662`, -16.66666666666666, -33.33333333333333}, {
      194.36506316151002`, -33.33333333333333, -33.33333333333333}, {
      190.75871903765994`, -33.33333333333333, -50.}}], 
     Polygon3DBox[{{
      194.36506316151002`, -33.33333333333333, -33.33333333333333}, {
      196.49710204252662`, -16.66666666666666, -33.33333333333333}, {
      198.6062547968831, -16.66666666666666, -16.66666666666666}, {
      196.49710204252662`, -33.33333333333333, -16.66666666666666}, {
      194.36506316151002`, -33.33333333333333, -33.33333333333333}}], 
     Polygon3DBox[{{
      196.49710204252662`, -33.33333333333333, -16.666666666666664`}, {
      198.6062547968831, -16.66666666666666, -16.666666666666664`}, {
      199.30434571835664`, -16.66666666666666, 3.552713678800501*^-15}, {
      197.2026594366539, -33.33333333333333, 3.552713678800501*^-15}, {
      196.49710204252662`, -33.33333333333333, -16.666666666666664`}}], 
     Polygon3DBox[{{197.2026594366539, -33.33333333333333, 0.}, {
      199.30434571835664`, -16.66666666666666, 0.}, {
      198.6062547968831, -16.66666666666666, 16.666666666666668`}, {
      196.49710204252662`, -33.33333333333333, 16.666666666666668`}, {
      197.2026594366539, -33.33333333333333, 0.}}], 
     Polygon3DBox[{{196.49710204252662`, -33.33333333333333, 
      16.66666666666667}, {198.6062547968831, -16.66666666666666, 
      16.66666666666667}, {196.49710204252662`, -16.66666666666666, 
      33.33333333333334}, {194.36506316151002`, -33.33333333333333, 
      33.33333333333334}, {196.49710204252662`, -33.33333333333333, 
      16.66666666666667}}], 
     Polygon3DBox[{{194.36506316151002`, -33.33333333333333, 
      33.33333333333334}, {196.49710204252662`, -16.66666666666666, 
      33.33333333333334}, {192.93061504650376`, -16.66666666666666, 
      50.000000000000014`}, {190.75871903765994`, -33.33333333333333, 
      50.000000000000014`}, {194.36506316151002`, -33.33333333333333, 
      33.33333333333334}}], 
     Polygon3DBox[{{192.93061504650376`, -16.666666666666664`, -50.}, {
      193.64916731037087`, 3.552713678800501*^-15, -50.}, {197.2026594366539, 
      3.552713678800501*^-15, -33.33333333333333}, {
      196.49710204252662`, -16.666666666666664`, -33.33333333333333}, {
      192.93061504650376`, -16.666666666666664`, -50.}}], 
     Polygon3DBox[{{
      196.49710204252662`, -16.666666666666664`, -33.33333333333333}, {
      197.2026594366539, 3.552713678800501*^-15, -33.33333333333333}, {
      199.30434571835664`, 3.552713678800501*^-15, -16.66666666666666}, {
      198.6062547968831, -16.666666666666664`, -16.66666666666666}, {
      196.49710204252662`, -16.666666666666664`, -33.33333333333333}}], 
     Polygon3DBox[{{
      198.6062547968831, -16.666666666666664`, -16.666666666666664`}, {
      199.30434571835664`, 3.552713678800501*^-15, -16.666666666666664`}, {
      200., 3.552713678800501*^-15, 3.552713678800501*^-15}, {
      199.30434571835664`, -16.666666666666664`, 3.552713678800501*^-15}, {
      198.6062547968831, -16.666666666666664`, -16.666666666666664`}}], 
     Polygon3DBox[{{199.30434571835664`, -16.666666666666664`, 0.}, {200., 
      3.552713678800501*^-15, 0.}, {199.30434571835664`, 
      3.552713678800501*^-15, 16.666666666666668`}, {
      198.6062547968831, -16.666666666666664`, 16.666666666666668`}, {
      199.30434571835664`, -16.666666666666664`, 0.}}], 
     Polygon3DBox[{{198.6062547968831, -16.666666666666664`, 
      16.66666666666667}, {199.30434571835664`, 3.552713678800501*^-15, 
      16.66666666666667}, {197.2026594366539, 3.552713678800501*^-15, 
      33.33333333333334}, {196.49710204252662`, -16.666666666666664`, 
      33.33333333333334}, {198.6062547968831, -16.666666666666664`, 
      16.66666666666667}}], 
     Polygon3DBox[{{196.49710204252662`, -16.666666666666664`, 
      33.33333333333334}, {197.2026594366539, 3.552713678800501*^-15, 
      33.33333333333334}, {193.64916731037087`, 3.552713678800501*^-15, 
      50.000000000000014`}, {192.93061504650376`, -16.666666666666664`, 
      50.000000000000014`}, {196.49710204252662`, -16.666666666666664`, 
      33.33333333333334}}], 
     Polygon3DBox[{{193.64916731037087`, 0., -50.}, {192.93061504650376`, 
      16.666666666666668`, -50.}, {196.49710204252662`, 
      16.666666666666668`, -33.33333333333333}, {197.2026594366539, 
      0., -33.33333333333333}, {193.64916731037087`, 0., -50.}}], 
     Polygon3DBox[{{197.2026594366539, 0., -33.33333333333333}, {
      196.49710204252662`, 16.666666666666668`, -33.33333333333333}, {
      198.6062547968831, 16.666666666666668`, -16.66666666666666}, {
      199.30434571835664`, 0., -16.66666666666666}, {197.2026594366539, 
      0., -33.33333333333333}}], 
     Polygon3DBox[{{199.30434571835664`, 0., -16.666666666666664`}, {
      198.6062547968831, 16.666666666666668`, -16.666666666666664`}, {
      199.30434571835664`, 16.666666666666668`, 3.552713678800501*^-15}, {
      200., 0., 3.552713678800501*^-15}, {199.30434571835664`, 
      0., -16.666666666666664`}}], 
     Polygon3DBox[{{200., 0., 0.}, {199.30434571835664`, 16.666666666666668`, 
      0.}, {198.6062547968831, 16.666666666666668`, 16.666666666666668`}, {
      199.30434571835664`, 0., 16.666666666666668`}, {200., 0., 0.}}], 
     Polygon3DBox[{{199.30434571835664`, 0., 16.66666666666667}, {
      198.6062547968831, 16.666666666666668`, 16.66666666666667}, {
      196.49710204252662`, 16.666666666666668`, 33.33333333333334}, {
      197.2026594366539, 0., 33.33333333333334}, {199.30434571835664`, 0., 
      16.66666666666667}}], 
     Polygon3DBox[{{197.2026594366539, 0., 33.33333333333334}, {
      196.49710204252662`, 16.666666666666668`, 33.33333333333334}, {
      192.93061504650376`, 16.666666666666668`, 50.000000000000014`}, {
      193.64916731037087`, 0., 50.000000000000014`}, {197.2026594366539, 0., 
      33.33333333333334}}], 
     Polygon3DBox[{{192.93061504650376`, 16.66666666666667, -50.}, {
      190.75871903765994`, 33.33333333333334, -50.}, {194.36506316151002`, 
      33.33333333333334, -33.33333333333333}, {196.49710204252662`, 
      16.66666666666667, -33.33333333333333}, {192.93061504650376`, 
      16.66666666666667, -50.}}], 
     Polygon3DBox[{{196.49710204252662`, 
      16.66666666666667, -33.33333333333333}, {194.36506316151002`, 
      33.33333333333334, -33.33333333333333}, {196.49710204252662`, 
      33.33333333333334, -16.66666666666666}, {198.6062547968831, 
      16.66666666666667, -16.66666666666666}, {196.49710204252662`, 
      16.66666666666667, -33.33333333333333}}], 
     Polygon3DBox[{{198.6062547968831, 
      16.66666666666667, -16.666666666666664`}, {196.49710204252662`, 
      33.33333333333334, -16.666666666666664`}, {197.2026594366539, 
      33.33333333333334, 3.552713678800501*^-15}, {199.30434571835664`, 
      16.66666666666667, 3.552713678800501*^-15}, {198.6062547968831, 
      16.66666666666667, -16.666666666666664`}}], 
     Polygon3DBox[{{199.30434571835664`, 16.66666666666667, 0.}, {
      197.2026594366539, 33.33333333333334, 0.}, {196.49710204252662`, 
      33.33333333333334, 16.666666666666668`}, {198.6062547968831, 
      16.66666666666667, 16.666666666666668`}, {199.30434571835664`, 
      16.66666666666667, 0.}}], 
     Polygon3DBox[{{198.6062547968831, 16.66666666666667, 
      16.66666666666667}, {196.49710204252662`, 33.33333333333334, 
      16.66666666666667}, {194.36506316151002`, 33.33333333333334, 
      33.33333333333334}, {196.49710204252662`, 16.66666666666667, 
      33.33333333333334}, {198.6062547968831, 16.66666666666667, 
      16.66666666666667}}], 
     Polygon3DBox[{{196.49710204252662`, 16.66666666666667, 
      33.33333333333334}, {194.36506316151002`, 33.33333333333334, 
      33.33333333333334}, {190.75871903765994`, 33.33333333333334, 
      50.000000000000014`}, {192.93061504650376`, 16.66666666666667, 
      50.000000000000014`}, {196.49710204252662`, 16.66666666666667, 
      33.33333333333334}}], 
     Polygon3DBox[{{190.75871903765994`, 33.33333333333334, -50.}, {
      187.08286933869707`, 50.000000000000014`, -50.}, {190.75871903765994`, 
      50.000000000000014`, -33.33333333333333}, {194.36506316151002`, 
      33.33333333333334, -33.33333333333333}, {190.75871903765994`, 
      33.33333333333334, -50.}}], 
     Polygon3DBox[{{194.36506316151002`, 
      33.33333333333334, -33.33333333333333}, {190.75871903765994`, 
      50.000000000000014`, -33.33333333333333}, {192.93061504650376`, 
      50.000000000000014`, -16.66666666666666}, {196.49710204252662`, 
      33.33333333333334, -16.66666666666666}, {194.36506316151002`, 
      33.33333333333334, -33.33333333333333}}], 
     Polygon3DBox[{{196.49710204252662`, 
      33.33333333333334, -16.666666666666664`}, {192.93061504650376`, 
      50.000000000000014`, -16.666666666666664`}, {193.64916731037087`, 
      50.000000000000014`, 3.552713678800501*^-15}, {197.2026594366539, 
      33.33333333333334, 3.552713678800501*^-15}, {196.49710204252662`, 
      33.33333333333334, -16.666666666666664`}}], 
     Polygon3DBox[{{197.2026594366539, 33.33333333333334, 0.}, {
      193.64916731037087`, 50.000000000000014`, 0.}, {192.93061504650376`, 
      50.000000000000014`, 16.666666666666668`}, {196.49710204252662`, 
      33.33333333333334, 16.666666666666668`}, {197.2026594366539, 
      33.33333333333334, 0.}}], 
     Polygon3DBox[{{196.49710204252662`, 33.33333333333334, 
      16.66666666666667}, {192.93061504650376`, 50.000000000000014`, 
      16.66666666666667}, {190.75871903765994`, 50.000000000000014`, 
      33.33333333333334}, {194.36506316151002`, 33.33333333333334, 
      33.33333333333334}, {196.49710204252662`, 33.33333333333334, 
      16.66666666666667}}], 
     Polygon3DBox[{{194.36506316151002`, 33.33333333333334, 
      33.33333333333334}, {190.75871903765994`, 50.000000000000014`, 
      33.33333333333334}, {187.08286933869707`, 50.000000000000014`, 
      50.000000000000014`}, {190.75871903765994`, 33.33333333333334, 
      50.000000000000014`}, {194.36506316151002`, 33.33333333333334, 
      33.33333333333334}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{187.08286933869707`, -50., 50}, {
        190.75871903765994`, -33.33333333333333, 50}, {
        192.93061504650376`, -16.666666666666664`, 50}, {
        193.64916731037087`, 0., 50}, {
        192.93061504650376`, 16.66666666666667, 50}, {
        190.75871903765994`, 33.33333333333334, 50}, {
        187.08286933869707`, 50., 50}, {187.08286933869707`, 50, 50.}, {
        190.75871903765994`, 50, 33.33333333333333}, {
        192.93061504650376`, 50, 16.666666666666664`}, {
        193.64916731037087`, 50, 0.}, {
        192.93061504650376`, 50, -16.66666666666667}, {
        190.75871903765994`, 50, -33.33333333333334}, {
        187.08286933869707`, 50, -50.}, {187.08286933869707`, 50., -50}, {
        190.75871903765994`, 33.33333333333333, -50}, {
        192.93061504650376`, 16.666666666666664`, -50}, {
        193.64916731037087`, 0., -50}, {
        192.93061504650376`, -16.66666666666667, -50}, {
        190.75871903765994`, -33.33333333333334, -50}, {
        187.08286933869707`, -50., -50}, {187.08286933869707`, -50, -50.}, {
        190.75871903765994`, -50, -33.33333333333333}, {
        192.93061504650376`, -50, -16.666666666666664`}, {
        193.64916731037087`, -50, 0.}, {
        192.93061504650376`, -50, 16.66666666666667}, {
        190.75871903765994`, -50, 33.33333333333334}, {
        187.08286933869707`, -50, 50.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 75., -75.}, {250., -75., -75.}, {250., -75., 75.}, {
       250., 75., 75.}, {250., 75., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -75., -75.}, {-50., -75., -75.}, {-50., -75., 75.}, {
       250., -75., 75.}, {250., -75., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-50., -75., -75.}, {-50., 75., -75.}, {-50., 75., 
       75.}, {-50., -75., 75.}, {-50., -75., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-50., 75., -75.}, {250., 75., -75.}, {250., 75., 
       75.}, {-50., 75., 75.}, {-50., 75., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -75., -75.}, {250., 75., -75.}, {-50., 
       75., -75.}, {-50., -75., -75.}, {250., -75., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 75., 75.}, {250., -75., 75.}, {-50., -75., 
       75.}, {-50., 75., 75.}, {250., 75., 75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{30., 0., 0.}, {195.04914358958342`, 44.22478473627729, 
      0.}}, {{30., 0., 0.}, {199.4497963552143, 14.824936217857687`, 0.}}, {{
      30., 0., 0.}, {199.4497963552143, -14.824936217857683`, 0.}}, {{
      195.04914358958342`, 44.22478473627729, 0.}, {-50., -1.414103628290441, 
      0.}}, {{199.4497963552143, 14.824936217857687`, 
      0.}, {-50., -0.440197148543902, 0.}}, {{
      199.4497963552143, -14.824936217857683`, 0.}, {-50., 0.4401971485439091,
       0.}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     Point3DBox[{{195.04914358958342`, 44.22478473627729, 0.}, {
      199.4497963552143, 14.824936217857687`, 0.}, {
      199.4497963552143, -14.824936217857683`, 0.}, {-50., -1.414103628290441,
       0.}, {-50., -0.440197148543902, 0.}, {-50., 0.4401971485439091, 
      0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015036855993`*^9, 3.614709270095704*^9, 
  3.614729125742798*^9},
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"},
 CellLabel->"During evaluation of In[191]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3.2 ModelSurfaceShape", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell[TextData[{
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " can be used to define new forms of optical surfaces. This is an \
alternative to directly passing the surface function to custom components \
such as ",
 StyleBox["CustomMirror",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". In particular, ",
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " allows you to set-up a generalized surface function with symbolic entries. \
As you will see shortly, you can even set up your own generic component \
function with your own built-in surface shapes."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell[TextData[{
 StyleBox["ModelSurfaceShape[",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["surfacelabel",
  FontSlant->"Italic"],
 ", ",
 StyleBox["value",
  FontSlant->"Italic"],
 StyleBox["]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " = ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " is a global function that defines a ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " with the ",
 StyleBox["surfacelabel",
  FontSlant->"Italic"],
 " as a reference tag."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell[TextData[{
 "Using the same ellipse equation result from the previous section, we will \
next create a new ",
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " definition using ",
 StyleBox["ellipticalshape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " for the ",
 StyleBox["surfacelabel",
  FontSlant->"Italic"],
 " parameter of ",
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". Here we use lower case letters to distinguish ",
 StyleBox["ellipticalshape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " from a potential built-in ",
 StyleBox["EllipticalShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " label.  Before the user can define new ",
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " functions, the ",
 StyleBox["ModelSurfaceShape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " must first be unprotected."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell["Unprotect[ModelSurfaceShape];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"In[192]:="],

Cell[CellGroupData[{

Cell["\<\
ModelSurfaceShape[ellipticalshape,{a_,b_,c_,r_}] = \
Function[Evaluate[ellipse3D[a,b,c,r,#1,#2]]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"In[193]:="],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"c", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["r", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["#1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["#2", "2"]}]}]]}], 
   RowBox[{"a", " ", "b"}]], "&"}]], "Output",
 CellChangeTimes->{3.563404256994836*^9, 3.5634581536327877`*^9, 
  3.5644875922299232`*^9, 3.5661006952593517`*^9, 3.601301242124631*^9, 
  3.601301503807682*^9, 3.614709270246931*^9, 3.614729125765066*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"Out[193]="]
}, Open  ]],

Cell["Protect[ModelSurfaceShape];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"In[194]:="],

Cell[TextData[{
 "Now we can create a new ",
 StyleBox["ellipticalMirror", "Input"],
 " function that uses this new surface model. For this, we use ",
 StyleBox["CustomMirror", "Input"],
 " together with ",
 StyleBox["SurfaceLabel->ellipticalshape",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell[TextData[{
 "ellipticalMirror[{a_,b_,c_,r_}, aperture_, options___] := \n\t\
CustomMirror[{a, b, c, r}, aperture, SurfaceLabel->",
 StyleBox["ellipticalshape, options",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "]"
}], "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"In[195]:="],

Cell[TextData[{
 "Here is a ray trace that uses our new ",
 StyleBox["ellipticalMirror", "Input"],
 " function."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tMove[WedgeOfRays[20],30,5],
\tellipticalMirror[{10.,10.,10.,20.},{100,100}],
\tMove[Boundary[300,150],-50]}, 
\tPlotType->TopView
];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"In[196]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{193.6491673103709, -50.}, {
       197.20265943665393`, -33.333333333333336`}, {
       199.30434571835667`, -16.66666666666667}, {
       200.00000000000003`, -7.105427357601002*^-15}, {199.30434571835667`, 
       16.666666666666657`}, {197.20265943665393`, 33.333333333333314`}, {
       193.6491673103709, 49.999999999999986`}, {193.6491673103709, 50.}, {
       197.20265943665393`, 33.333333333333336`}, {199.30434571835667`, 
       16.66666666666667}, {200.00000000000003`, 7.105427357601002*^-15}, {
       199.30434571835667`, -16.666666666666657`}, {
       197.20265943665393`, -33.333333333333314`}, {
       193.6491673103709, -49.999999999999986`}, {193.6491673103709, -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{193.6491673103709, 0.}, {197.20265943665393`, 0.}, {
       199.30434571835667`, 0.}, {200.00000000000003`, 0.}, {
       199.30434571835667`, 0.}, {197.20265943665393`, 0.}, {
       193.6491673103709, 0.}, {193.6491673103709, 0.}, {197.20265943665393`, 
       0.}, {199.30434571835667`, 0.}, {200.00000000000003`, 0.}, {
       199.30434571835667`, 0.}, {197.20265943665393`, 0.}, {
       193.6491673103709, 0.}, {193.6491673103709, 0.}}]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{187.0828693386971, -50.}, {
      190.75871903765997`, -33.33333333333333}, {
      194.36506316151005`, -33.33333333333333}, {190.75871903765997`, -50.}, {
      187.0828693386971, -50.}}], 
     PolygonBox[{{190.75871903765997`, -50.}, {
      194.36506316151005`, -33.33333333333333}, {
      196.49710204252665`, -33.33333333333333}, {192.93061504650376`, -50.}, {
      190.75871903765997`, -50.}}], 
     PolygonBox[{{192.93061504650376`, -50.}, {
      196.49710204252665`, -33.33333333333333}, {
      197.20265943665393`, -33.33333333333333}, {193.6491673103709, -50.}, {
      192.93061504650376`, -50.}}], 
     PolygonBox[{{193.6491673103709, -50.}, {
      197.20265943665393`, -33.33333333333333}, {
      196.49710204252665`, -33.33333333333333}, {192.93061504650376`, -50.}, {
      193.6491673103709, -50.}}], 
     PolygonBox[{{192.93061504650376`, -50.}, {
      196.49710204252665`, -33.33333333333333}, {
      194.36506316151005`, -33.33333333333333}, {190.75871903765997`, -50.}, {
      192.93061504650376`, -50.}}], 
     PolygonBox[{{190.75871903765997`, -50.}, {
      194.36506316151005`, -33.33333333333333}, {
      190.75871903765997`, -33.33333333333333}, {187.0828693386971, -50.}, {
      190.75871903765997`, -50.}}], 
     PolygonBox[{{190.75871903765997`, -33.33333333333333}, {
      192.93061504650376`, -16.66666666666666}, {
      196.49710204252665`, -16.66666666666666}, {
      194.36506316151005`, -33.33333333333333}, {
      190.75871903765997`, -33.33333333333333}}], 
     PolygonBox[{{194.36506316151005`, -33.33333333333333}, {
      196.49710204252665`, -16.66666666666666}, {
      198.60625479688312`, -16.66666666666666}, {
      196.49710204252665`, -33.33333333333333}, {
      194.36506316151005`, -33.33333333333333}}], 
     PolygonBox[{{196.49710204252665`, -33.33333333333333}, {
      198.60625479688312`, -16.66666666666666}, {
      199.30434571835667`, -16.66666666666666}, {
      197.20265943665393`, -33.33333333333333}, {
      196.49710204252665`, -33.33333333333333}}], 
     PolygonBox[{{197.20265943665393`, -33.33333333333333}, {
      199.30434571835667`, -16.66666666666666}, {
      198.60625479688312`, -16.66666666666666}, {
      196.49710204252665`, -33.33333333333333}, {
      197.20265943665393`, -33.33333333333333}}], 
     PolygonBox[{{196.49710204252665`, -33.33333333333333}, {
      198.60625479688312`, -16.66666666666666}, {
      196.49710204252665`, -16.66666666666666}, {
      194.36506316151005`, -33.33333333333333}, {
      196.49710204252665`, -33.33333333333333}}], 
     PolygonBox[{{194.36506316151005`, -33.33333333333333}, {
      196.49710204252665`, -16.66666666666666}, {
      192.93061504650376`, -16.66666666666666}, {
      190.75871903765997`, -33.33333333333333}, {
      194.36506316151005`, -33.33333333333333}}], 
     PolygonBox[{{192.93061504650376`, -16.666666666666664`}, {
      193.6491673103709, 3.552713678800501*^-15}, {197.20265943665393`, 
      3.552713678800501*^-15}, {196.49710204252665`, -16.666666666666664`}, {
      192.93061504650376`, -16.666666666666664`}}], 
     PolygonBox[{{196.49710204252665`, -16.666666666666664`}, {
      197.20265943665393`, 3.552713678800501*^-15}, {199.30434571835667`, 
      3.552713678800501*^-15}, {198.60625479688312`, -16.666666666666664`}, {
      196.49710204252665`, -16.666666666666664`}}], 
     PolygonBox[{{198.60625479688312`, -16.666666666666664`}, {
      199.30434571835667`, 3.552713678800501*^-15}, {200.00000000000003`, 
      3.552713678800501*^-15}, {199.30434571835667`, -16.666666666666664`}, {
      198.60625479688312`, -16.666666666666664`}}], 
     PolygonBox[{{199.30434571835667`, -16.666666666666664`}, {
      200.00000000000003`, 3.552713678800501*^-15}, {199.30434571835667`, 
      3.552713678800501*^-15}, {198.60625479688312`, -16.666666666666664`}, {
      199.30434571835667`, -16.666666666666664`}}], 
     PolygonBox[{{198.60625479688312`, -16.666666666666664`}, {
      199.30434571835667`, 3.552713678800501*^-15}, {197.20265943665393`, 
      3.552713678800501*^-15}, {196.49710204252665`, -16.666666666666664`}, {
      198.60625479688312`, -16.666666666666664`}}], 
     PolygonBox[{{196.49710204252665`, -16.666666666666664`}, {
      197.20265943665393`, 3.552713678800501*^-15}, {193.6491673103709, 
      3.552713678800501*^-15}, {192.93061504650376`, -16.666666666666664`}, {
      196.49710204252665`, -16.666666666666664`}}], 
     PolygonBox[{{193.6491673103709, 0.}, {192.93061504650376`, 
      16.666666666666668`}, {196.49710204252665`, 16.666666666666668`}, {
      197.20265943665393`, 0.}, {193.6491673103709, 0.}}], 
     PolygonBox[{{197.20265943665393`, 0.}, {196.49710204252665`, 
      16.666666666666668`}, {198.60625479688312`, 16.666666666666668`}, {
      199.30434571835667`, 0.}, {197.20265943665393`, 0.}}], 
     PolygonBox[{{199.30434571835667`, 0.}, {198.60625479688312`, 
      16.666666666666668`}, {199.30434571835667`, 16.666666666666668`}, {
      200.00000000000003`, 0.}, {199.30434571835667`, 0.}}], 
     PolygonBox[{{200.00000000000003`, 0.}, {199.30434571835667`, 
      16.666666666666668`}, {198.60625479688312`, 16.666666666666668`}, {
      199.30434571835667`, 0.}, {200.00000000000003`, 0.}}], 
     PolygonBox[{{199.30434571835667`, 0.}, {198.60625479688312`, 
      16.666666666666668`}, {196.49710204252665`, 16.666666666666668`}, {
      197.20265943665393`, 0.}, {199.30434571835667`, 0.}}], 
     PolygonBox[{{197.20265943665393`, 0.}, {196.49710204252665`, 
      16.666666666666668`}, {192.93061504650376`, 16.666666666666668`}, {
      193.6491673103709, 0.}, {197.20265943665393`, 0.}}], 
     PolygonBox[{{192.93061504650376`, 16.66666666666667}, {
      190.75871903765997`, 33.33333333333334}, {194.36506316151005`, 
      33.33333333333334}, {196.49710204252665`, 16.66666666666667}, {
      192.93061504650376`, 16.66666666666667}}], 
     PolygonBox[{{196.49710204252665`, 16.66666666666667}, {
      194.36506316151005`, 33.33333333333334}, {196.49710204252665`, 
      33.33333333333334}, {198.60625479688312`, 16.66666666666667}, {
      196.49710204252665`, 16.66666666666667}}], 
     PolygonBox[{{198.60625479688312`, 16.66666666666667}, {
      196.49710204252665`, 33.33333333333334}, {197.20265943665393`, 
      33.33333333333334}, {199.30434571835667`, 16.66666666666667}, {
      198.60625479688312`, 16.66666666666667}}], 
     PolygonBox[{{199.30434571835667`, 16.66666666666667}, {
      197.20265943665393`, 33.33333333333334}, {196.49710204252665`, 
      33.33333333333334}, {198.60625479688312`, 16.66666666666667}, {
      199.30434571835667`, 16.66666666666667}}], 
     PolygonBox[{{198.60625479688312`, 16.66666666666667}, {
      196.49710204252665`, 33.33333333333334}, {194.36506316151005`, 
      33.33333333333334}, {196.49710204252665`, 16.66666666666667}, {
      198.60625479688312`, 16.66666666666667}}], 
     PolygonBox[{{196.49710204252665`, 16.66666666666667}, {
      194.36506316151005`, 33.33333333333334}, {190.75871903765997`, 
      33.33333333333334}, {192.93061504650376`, 16.66666666666667}, {
      196.49710204252665`, 16.66666666666667}}], 
     PolygonBox[{{190.75871903765997`, 33.33333333333334}, {187.0828693386971,
       50.000000000000014`}, {190.75871903765997`, 50.000000000000014`}, {
      194.36506316151005`, 33.33333333333334}, {190.75871903765997`, 
      33.33333333333334}}], 
     PolygonBox[{{194.36506316151005`, 33.33333333333334}, {
      190.75871903765997`, 50.000000000000014`}, {192.93061504650376`, 
      50.000000000000014`}, {196.49710204252665`, 33.33333333333334}, {
      194.36506316151005`, 33.33333333333334}}], 
     PolygonBox[{{196.49710204252665`, 33.33333333333334}, {
      192.93061504650376`, 50.000000000000014`}, {193.6491673103709, 
      50.000000000000014`}, {197.20265943665393`, 33.33333333333334}, {
      196.49710204252665`, 33.33333333333334}}], 
     PolygonBox[{{197.20265943665393`, 33.33333333333334}, {193.6491673103709,
       50.000000000000014`}, {192.93061504650376`, 50.000000000000014`}, {
      196.49710204252665`, 33.33333333333334}, {197.20265943665393`, 
      33.33333333333334}}], 
     PolygonBox[{{196.49710204252665`, 33.33333333333334}, {
      192.93061504650376`, 50.000000000000014`}, {190.75871903765997`, 
      50.000000000000014`}, {194.36506316151005`, 33.33333333333334}, {
      196.49710204252665`, 33.33333333333334}}], 
     PolygonBox[{{194.36506316151005`, 33.33333333333334}, {
      190.75871903765997`, 50.000000000000014`}, {187.0828693386971, 
      50.000000000000014`}, {190.75871903765997`, 33.33333333333334}, {
      194.36506316151005`, 33.33333333333334}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{187.0828693386971, -50.}, {
        190.75871903765997`, -33.33333333333333}, {
        192.93061504650376`, -16.666666666666664`}, {193.6491673103709, 0.}, {
        192.93061504650376`, 16.66666666666667}, {190.75871903765997`, 
        33.33333333333334}, {187.0828693386971, 50.}, {
        187.0828693386971, 50}, {190.75871903765997`, 50}, {
        192.93061504650376`, 50}, {193.6491673103709, 50}, {
        192.93061504650376`, 50}, {190.75871903765997`, 50}, {
        187.0828693386971, 50}, {187.0828693386971, 50.}, {
        190.75871903765997`, 33.33333333333333}, {192.93061504650376`, 
        16.666666666666664`}, {193.6491673103709, 0.}, {
        192.93061504650376`, -16.66666666666667}, {
        190.75871903765997`, -33.33333333333334}, {187.0828693386971, -50.}, {
        187.0828693386971, -50}, {190.75871903765997`, -50}, {
        192.93061504650376`, -50}, {193.6491673103709, -50}, {
        192.93061504650376`, -50}, {190.75871903765997`, -50}, {
        187.0828693386971, -50}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., 75.}, {250., -75.}, {250., -75.}, {250., 75.}, {250., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -75.}, {-50., -75.}, {-50., -75.}, {250., -75.}, {
       250., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -75.}, {-50., 75.}, {-50., 
       75.}, {-50., -75.}, {-50., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 75.}, {250., 75.}, {250., 75.}, {-50., 75.}, {-50., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -75.}, {250., 75.}, {-50., 75.}, {-50., -75.}, {
       250., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., 75.}, {250., -75.}, {-50., -75.}, {-50., 75.}, {250., 
       75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{30., 0.}, {195.04914358958345`, 44.2247847362773}}], 
     {Arrowheads[Small], 
      ArrowBox[{{30., 0.}, {199.44979635521432`, 14.824936217857688`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{30., 0.}, {199.44979635521432`, -14.824936217857687`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{195.04914358958345`, 
       44.2247847362773}, {-50., -1.4141036282904835`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{199.44979635521432`, 
       14.824936217857688`}, {-50., -0.44019714854391623`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{199.44979635521432`, -14.824936217857687`}, {-50., 
       0.44019714854391445`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{195.04914358958345`, 44.2247847362773}, {199.44979635521432`, 
      14.824936217857688`}, {
      199.44979635521432`, -14.824936217857687`}, {-50., \
-1.4141036282904835`}, {-50., -0.44019714854391623`}, {-50., 
      0.44019714854391445`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301504495479*^9, 3.6147092710134153`*^9, 
  3.614729126845779*^9},
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"},
 CellLabel->"During evaluation of In[196]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3.3 SurfaceRayIntersections", "Subsection",
 CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " offers many alternative methods for calculating the ray-surface \
intersection point. You can use the ",
 StyleBox["SurfaceRayIntersections", "Input"],
 " option to choose a particular method to work with custom surfaces. Note, \
however, that all of ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s built-in surface shapes (",
 StyleBox["PlanarShape", "Input"],
 ", ",
 StyleBox["SphericalShape", "Input"],
 ", and ",
 StyleBox["ParabolicShape", "Input"],
 ") already have built-in solutions that cannot be altered by the ",
 StyleBox["SurfaceRayIntersections", "Input"],
 " setting."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.3"}],

Cell[TextData[{
 StyleBox["SurfaceRayIntersections ->", "Input"],
 " ",
 StyleBox["method",
  FontSlant->"Italic"],
 " is an option of all component functions that specifies the ",
 StyleBox["method",
  FontSlant->"Italic"],
 " for finding the surface-ray intersection point."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[{
 "Currently, there are seven different ",
 StyleBox["method",
  FontSlant->"Italic"],
 " settings available for ",
 StyleBox["SurfaceRayIntersections", "Input"],
 ": ",
 StyleBox["Symbol", "Input"],
 ", ",
 StyleBox["Numeric", "Input"],
 ", ",
 StyleBox["FindRoot", "Input"],
 ", ",
 StyleBox["FindMinimum", "Input"],
 ", ",
 StyleBox["Solve", "Input"],
 ", ",
 StyleBox["NSolve", "Input"],
 ", and ",
 StyleBox["Automatic", "Input"],
 ". In general, the optimal choice of ",
 StyleBox["method",
  FontSlant->"Italic"],
 " depends on the particular ray-trace circumstances. While all of these \
settings work transparently within ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", only ",
 StyleBox["Symbol", "Input"],
 " and ",
 StyleBox["Numeric", "Input"],
 " can be compiled together with the compiled ray-trace code generated by ",
 StyleBox["TurboTrace", "Input"],
 ". Therefore, these two settings are the fastest with ",
 StyleBox["TurboTrace", "Input"],
 ". Nevertheless, the other settings can still be used with ",
 StyleBox["TurboTrace", "Input"],
 " although they will run less efficiently. ",
 StyleBox["Symbol", "Input"],
 " constructs an analytic, closed-form solution for the intersection point \
and exhibits the fastest ray-trace response. ",
 StyleBox["Symbol", "Input"],
 " is also used by all of ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s built-in surface shapes. Unfortunately, ",
 StyleBox["Symbol", "Input"],
 " does not work with surface functions that lack a closed-form inverse \
solution and the build-time of ",
 StyleBox["Symbol", "Input"],
 " is much longer than the other methods."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[{
 StyleBox["SurfaceRayIntersections -> Numeric", "Input"],
 " constructs a numerical solution that can be directly compiled by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ". The ",
 StyleBox["Numeric", "Input"],
 " setting invokes numerical algorithms that are specifically built for use \
with ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", whereas the ",
 StyleBox["FindRoot", "Input"],
 " and ",
 StyleBox["FindMinimum", "Input"],
 " settings use the standard built-in ",
 StyleBox["FindRoot", "Input"],
 " and ",
 StyleBox["FindMinimum", "Input"],
 " functions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". This is why the ",
 StyleBox["Numeric", "Input"],
 " setting can be directly compiled into the ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " source code whereas ",
 StyleBox["FindRoot", "Input"],
 " and ",
 StyleBox["FindMinimum", "Input"],
 " must be internally maintained as external functions to ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 StyleBox["-",
  FontSlant->"Italic"],
 "compiled code. Although ",
 StyleBox["Numeric", "Input"],
 " is designed to have the same functional capabilities of both ",
 StyleBox["FindRoot", "Input"],
 " and ",
 StyleBox["FindMinimum", "Input"],
 ", the internal algorithms are not shared so these two settings may \
outperform ",
 StyleBox["Numeric", "Input"],
 " in some instances."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[{
 "In cases involving interpolated surfacefunctions or when ",
 StyleBox["Symbol", "Input"],
 " and ",
 StyleBox["Numeric", "Input"],
 " fail to perform, one of the remaining methods can work more effectively. \
",
 StyleBox["SurfaceRayIntersections -> FindRoot", "Input"],
 " uses ",
 StyleBox["FindRoot", "Input"],
 " internally and is usually the most robust numerical ray-trace method. For \
this reason, ",
 StyleBox["SurfaceRayIntersections -> Automatic", "Input"],
 " generally invokes the ",
 StyleBox["FindRoot", "Input"],
 " setting internally.  ",
 StyleBox["SurfaceRayIntersections -> FindMinimum", "Input"],
 " uses ",
 StyleBox["FindMinimum", "Input"],
 " internally and, in special cases, can work better than ",
 StyleBox["FindRoot", "Input"],
 " (although not in most cases). ",
 StyleBox["SurfaceRayIntersections -> Solve", "Input"],
 " uses ",
 StyleBox["Solve", "Input"],
 " internally to dynamically find the analytic ray-surface solution. ",
 StyleBox["SurfaceRayIntersections -> NSolve", "Input"],
 " uses ",
 StyleBox["NSolve", "Input"],
 " internally and works exclusively with polynomial surface equations. For \
qualified surface functions, ",
 StyleBox["Solve", "Input"],
 " and ",
 StyleBox["NSolve", "Input"],
 " will always find the globally correct intersection point. For further \
information, see the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " book on ",
 StyleBox["FindRoot", "Input"],
 ", ",
 StyleBox["FindMinimum", "Input"],
 ", ",
 StyleBox["Solve", "Input"],
 ", and ",
 StyleBox["NSolve", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[{
 "Next, we will examine the effects of five different ",
 StyleBox["SurfaceRayIntersections", "Input"],
 " settings on the component creation and ray-trace process, namely: ",
 StyleBox["Automatic/FindRoot", "Input"],
 ", ",
 StyleBox["Symbol", "Input"],
 ", ",
 StyleBox["Numeric", "Input"],
 ", and ",
 StyleBox["Solve", "Input"],
 ". In particular, we shall see how each of these settings affect both the \
component creation time as well as the ray-trace calculation time in \
different ways. For this, we will use a custom mirror that is shaped to form \
an elliptical tube. To build this customized shape into a mirror, we again \
use the ",
 StyleBox["CustomMirror", "Input"],
 " function. To give this new component a tube shape, we pass the parametric \
vector function ",
 StyleBox["{10*Cos[s], 5*Sin[s], t}", "Input"],
 " (for ",
 StyleBox["{", "Input"],
 StyleBox["fx", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fy", "Input",
  FontSlant->"Italic"],
 StyleBox[", ", "Input"],
 StyleBox["fz", "Input",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 ") to the ",
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 " in ",
 StyleBox["CustomMirror", "Input"],
 ". By default, ",
 StyleBox["CustomMirror", "Input"],
 " uses the ",
 StyleBox["SurfaceRayIntersections -> Automatic", "Input"],
 " setting:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.3"}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SurfaceRayIntersections/.Options[CustomMirror]", \
"Input"]], "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[197]:="],

Cell[BoxData["Automatic"], "Output",
 CellChangeTimes->{3.5634042574822598`*^9, 3.563458155132131*^9, 
  3.564487593686957*^9, 3.566100696678594*^9, 3.601301242203816*^9, 
  3.601301504509704*^9, 3.614709271130616*^9, 3.6147291269396343`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[197]="]
}, Open  ]],

Cell[TextData[{
 "We will first create the ",
 StyleBox["CustomMirror", "Input"],
 " with this default setting. However, we will store its component creation \
time in a variable for future comparison with the other methods."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
creationtime[1] = 
Timing[
\tellipticalmirror[1] = CustomMirror[ Function[{s,t}, {10*Cos[s], 5*Sin[s], \
t}], {2*Pi,10}]
][[1]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[198]:="],

Cell[BoxData["0.30849199999999998844657511654077097774`5.509843819409324"], \
"Output",
 CellChangeTimes->{3.563404258043496*^9, 3.563458155468068*^9, 
  3.564487593971602*^9, 3.566100697235754*^9, 3.6013012422543163`*^9, 
  3.601301504844984*^9, 3.61470927159476*^9, 3.61472912725423*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[198]="]
}, Open  ]],

Cell["Here is a plot of the mirror's three-dimensional shape.", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["ShowSystem[ellipticalmirror[1], PlotPoints->60];", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[199]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFlL1KA0EUhYdkGyUgspYBWbQURRQVEXIhFhY25hEEO6OFhe8g+Ag+g41l
YG8hwdbSV0gsBbHxh7n3HvCEJQNJ4GNm9szJN1udXw8uWimlnb9PO8VY14Wb
t/pxaTwKcnl7f3p3tqaHL5/bD08fdfDp1v5rZ1DpTx5tDV4vrqbxSVc1/3bA
W/l7RSd53TL4Xt630GF+TgnuOY6Srwu+a/OF51uOUqa0v+XoSk15LEcllqsA
9/PKAZ3X+5FEY+jzN21+j/qRb+sH6549z8jygBd2TvF+wPt+XstVglM/4Bve
5xXN/7J+9J32p/8L3PtRy1WAhw/HdF7vR//naubkFfcWXs3NSV6Bk1dzeyOv
wMkrcPKKewuvuLfwinuTRIO84nsXXmlw8gqcvAInr8Cb7h15BU5egTe9B8gr
cPKK793Me6mJ/wLlkzqj
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyNlM0Jg0AUhBcVAh5ExAYC6SAFxBrCagGBnNNSjsuuBztI6kgJXpOThPy4
TwnuMJABPXw8Zv/mvfXhtD9GSqnt94vVrE2lFiqvIa+9CuDOjsqBizJSnwJv
vP+K+CTERwFvPR8uIY/8/wG88/U94TfgS/34Wep3ITfiD/z5HnUn9QNwK+et
Qv7yPjFwLfcJXPxT4KIMuKybE/+C+JR/85r4OLIu26cj52rIPYgS4oP33JJ3
mXIFvCPv3pGcLAW5ghwaktspV6Qe+8KSPppyBVyTPjWkr0U4ByyZG5rMGRHO
pZl/ABLaxi4=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -5.}, {-9.659258262890681, \
-1.294095225512605, -5.}, {-9.659258262890681, -1.294095225512605, \
-4.583333333333333}, {-10., -6.123233995736766*^-16, -4.583333333333333}, \
{-10., -6.123233995736766*^-16, -5.}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -4.583333333333333}, \
{-9.659258262890681, -1.294095225512605, -4.583333333333333}, \
{-9.659258262890681, -1.294095225512605, -4.166666666666666}, {-10., \
-6.123233995736766*^-16, -4.166666666666666}, {-10., -6.123233995736766*^-16, \
-4.583333333333333}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -4.166666666666667}, \
{-9.659258262890681, -1.294095225512605, -4.166666666666667}, \
{-9.659258262890681, -1.294095225512605, -3.7500000000000004`}, {-10., \
-6.123233995736766*^-16, -3.7500000000000004`}, {-10., \
-6.123233995736766*^-16, -4.166666666666667}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -3.75}, \
{-9.659258262890681, -1.294095225512605, -3.75}, {-9.659258262890681, \
-1.294095225512605, -3.3333333333333335`}, {-10., -6.123233995736766*^-16, \
-3.3333333333333335`}, {-10., -6.123233995736766*^-16, -3.75}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -3.333333333333333}, \
{-9.659258262890681, -1.294095225512605, -3.333333333333333}, \
{-9.659258262890681, -1.294095225512605, -2.9166666666666665`}, {-10., \
-6.123233995736766*^-16, -2.9166666666666665`}, {-10., \
-6.123233995736766*^-16, -3.333333333333333}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -2.9166666666666665`}, \
{-9.659258262890681, -1.294095225512605, -2.9166666666666665`}, \
{-9.659258262890681, -1.294095225512605, -2.5}, {-10., \
-6.123233995736766*^-16, -2.5}, {-10., -6.123233995736766*^-16, \
-2.9166666666666665`}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -2.5}, \
{-9.659258262890681, -1.294095225512605, -2.5}, {-9.659258262890681, \
-1.294095225512605, -2.0833333333333335`}, {-10., -6.123233995736766*^-16, \
-2.0833333333333335`}, {-10., -6.123233995736766*^-16, -2.5}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -2.083333333333333}, \
{-9.659258262890681, -1.294095225512605, -2.083333333333333}, \
{-9.659258262890681, -1.294095225512605, -1.6666666666666663`}, {-10., \
-6.123233995736766*^-16, -1.6666666666666663`}, {-10., \
-6.123233995736766*^-16, -2.083333333333333}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -1.6666666666666665`}, \
{-9.659258262890681, -1.294095225512605, -1.6666666666666665`}, \
{-9.659258262890681, -1.294095225512605, -1.2499999999999998`}, {-10., \
-6.123233995736766*^-16, -1.2499999999999998`}, {-10., \
-6.123233995736766*^-16, -1.6666666666666665`}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -1.25}, \
{-9.659258262890681, -1.294095225512605, -1.25}, {-9.659258262890681, \
-1.294095225512605, -0.8333333333333333}, {-10., -6.123233995736766*^-16, \
-0.8333333333333333}, {-10., -6.123233995736766*^-16, -1.25}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -0.833333333333333}, \
{-9.659258262890681, -1.294095225512605, -0.833333333333333}, \
{-9.659258262890681, -1.294095225512605, -0.41666666666666635`}, {-10., \
-6.123233995736766*^-16, -0.41666666666666635`}, {-10., \
-6.123233995736766*^-16, -0.833333333333333}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, -0.4166666666666661}, \
{-9.659258262890681, -1.294095225512605, -0.4166666666666661}, \
{-9.659258262890681, -1.294095225512605, 
      6.106226635438361*^-16}, {-10., -6.123233995736766*^-16, 
      6.106226635438361*^-16}, {-10., -6.123233995736766*^-16, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      0.}, {-9.659258262890681, -1.294095225512605, 
      0.}, {-9.659258262890681, -1.294095225512605, 
      0.4166666666666667}, {-10., -6.123233995736766*^-16, 
      0.4166666666666667}, {-10., -6.123233995736766*^-16, 0.}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      0.41666666666666696`}, {-9.659258262890681, -1.294095225512605, 
      0.41666666666666696`}, {-9.659258262890681, -1.294095225512605, 
      0.8333333333333337}, {-10., -6.123233995736766*^-16, 
      0.8333333333333337}, {-10., -6.123233995736766*^-16, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      0.8333333333333339}, {-9.659258262890681, -1.294095225512605, 
      0.8333333333333339}, {-9.659258262890681, -1.294095225512605, 
      1.2500000000000007`}, {-10., -6.123233995736766*^-16, 
      1.2500000000000007`}, {-10., -6.123233995736766*^-16, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      1.25}, {-9.659258262890681, -1.294095225512605, 
      1.25}, {-9.659258262890681, -1.294095225512605, 
      1.6666666666666667`}, {-10., -6.123233995736766*^-16, 
      1.6666666666666667`}, {-10., -6.123233995736766*^-16, 1.25}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      1.666666666666667}, {-9.659258262890681, -1.294095225512605, 
      1.666666666666667}, {-9.659258262890681, -1.294095225512605, 
      2.0833333333333335`}, {-10., -6.123233995736766*^-16, 
      2.0833333333333335`}, {-10., -6.123233995736766*^-16, 
      1.666666666666667}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      2.083333333333334}, {-9.659258262890681, -1.294095225512605, 
      2.083333333333334}, {-9.659258262890681, -1.294095225512605, 
      2.5000000000000004`}, {-10., -6.123233995736766*^-16, 
      2.5000000000000004`}, {-10., -6.123233995736766*^-16, 
      2.083333333333334}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      2.5}, {-9.659258262890681, -1.294095225512605, 
      2.5}, {-9.659258262890681, -1.294095225512605, 
      2.9166666666666665`}, {-10., -6.123233995736766*^-16, 
      2.9166666666666665`}, {-10., -6.123233995736766*^-16, 2.5}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      2.916666666666667}, {-9.659258262890681, -1.294095225512605, 
      2.916666666666667}, {-9.659258262890681, -1.294095225512605, 
      3.3333333333333335`}, {-10., -6.123233995736766*^-16, 
      3.3333333333333335`}, {-10., -6.123233995736766*^-16, 
      2.916666666666667}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      3.333333333333334}, {-9.659258262890681, -1.294095225512605, 
      3.333333333333334}, {-9.659258262890681, -1.294095225512605, 
      3.7500000000000004`}, {-10., -6.123233995736766*^-16, 
      3.7500000000000004`}, {-10., -6.123233995736766*^-16, 
      3.333333333333334}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      3.75}, {-9.659258262890681, -1.294095225512605, 
      3.75}, {-9.659258262890681, -1.294095225512605, 
      4.166666666666667}, {-10., -6.123233995736766*^-16, 
      4.166666666666667}, {-10., -6.123233995736766*^-16, 3.75}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      4.166666666666668}, {-9.659258262890681, -1.294095225512605, 
      4.166666666666668}, {-9.659258262890681, -1.294095225512605, 
      4.583333333333335}, {-10., -6.123233995736766*^-16, 
      4.583333333333335}, {-10., -6.123233995736766*^-16, 
      4.166666666666668}}], 
     Polygon3DBox[{{-10., -6.123233995736766*^-16, 
      4.583333333333334}, {-9.659258262890681, -1.294095225512605, 
      4.583333333333334}, {-9.659258262890681, -1.294095225512605, 
      5.000000000000001}, {-10., -6.123233995736766*^-16, 
      5.000000000000001}, {-10., -6.123233995736766*^-16, 
      4.583333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, -5.}, \
{-8.660254037844386, -2.5000000000000018`, -5.}, {-8.660254037844386, \
-2.5000000000000018`, -4.583333333333333}, {-9.659258262890681, \
-1.294095225512605, -4.583333333333333}, {-9.659258262890681, \
-1.294095225512605, -5.}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-4.583333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-4.583333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-4.166666666666666}, {-9.659258262890681, -1.294095225512605, \
-4.166666666666666}, {-9.659258262890681, -1.294095225512605, \
-4.583333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-4.166666666666667}, {-8.660254037844386, -2.5000000000000018`, \
-4.166666666666667}, {-8.660254037844386, -2.5000000000000018`, \
-3.7500000000000004`}, {-9.659258262890681, -1.294095225512605, \
-3.7500000000000004`}, {-9.659258262890681, -1.294095225512605, \
-4.166666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, -3.75}, \
{-8.660254037844386, -2.5000000000000018`, -3.75}, {-8.660254037844386, \
-2.5000000000000018`, -3.3333333333333335`}, {-9.659258262890681, \
-1.294095225512605, -3.3333333333333335`}, {-9.659258262890681, \
-1.294095225512605, -3.75}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-3.333333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-3.333333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-2.9166666666666665`}, {-9.659258262890681, -1.294095225512605, \
-2.9166666666666665`}, {-9.659258262890681, -1.294095225512605, \
-3.333333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-2.9166666666666665`}, {-8.660254037844386, -2.5000000000000018`, \
-2.9166666666666665`}, {-8.660254037844386, -2.5000000000000018`, -2.5}, \
{-9.659258262890681, -1.294095225512605, -2.5}, {-9.659258262890681, \
-1.294095225512605, -2.9166666666666665`}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, -2.5}, \
{-8.660254037844386, -2.5000000000000018`, -2.5}, {-8.660254037844386, \
-2.5000000000000018`, -2.0833333333333335`}, {-9.659258262890681, \
-1.294095225512605, -2.0833333333333335`}, {-9.659258262890681, \
-1.294095225512605, -2.5}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-2.083333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-2.083333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-1.6666666666666663`}, {-9.659258262890681, -1.294095225512605, \
-1.6666666666666663`}, {-9.659258262890681, -1.294095225512605, \
-2.083333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-1.6666666666666665`}, {-8.660254037844386, -2.5000000000000018`, \
-1.6666666666666665`}, {-8.660254037844386, -2.5000000000000018`, \
-1.2499999999999998`}, {-9.659258262890681, -1.294095225512605, \
-1.2499999999999998`}, {-9.659258262890681, -1.294095225512605, \
-1.6666666666666665`}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, -1.25}, \
{-8.660254037844386, -2.5000000000000018`, -1.25}, {-8.660254037844386, \
-2.5000000000000018`, -0.8333333333333333}, {-9.659258262890681, \
-1.294095225512605, -0.8333333333333333}, {-9.659258262890681, \
-1.294095225512605, -1.25}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-0.833333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-0.833333333333333}, {-8.660254037844386, -2.5000000000000018`, \
-0.41666666666666635`}, {-9.659258262890681, -1.294095225512605, \
-0.41666666666666635`}, {-9.659258262890681, -1.294095225512605, \
-0.833333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, \
-0.4166666666666661}, {-8.660254037844386, -2.5000000000000018`, \
-0.4166666666666661}, {-8.660254037844386, -2.5000000000000018`, 
      6.106226635438361*^-16}, {-9.659258262890681, -1.294095225512605, 
      6.106226635438361*^-16}, {-9.659258262890681, -1.294095225512605, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      0.}, {-8.660254037844386, -2.5000000000000018`, 
      0.}, {-8.660254037844386, -2.5000000000000018`, 
      0.4166666666666667}, {-9.659258262890681, -1.294095225512605, 
      0.4166666666666667}, {-9.659258262890681, -1.294095225512605, 0.}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      0.41666666666666696`}, {-8.660254037844386, -2.5000000000000018`, 
      0.41666666666666696`}, {-8.660254037844386, -2.5000000000000018`, 
      0.8333333333333337}, {-9.659258262890681, -1.294095225512605, 
      0.8333333333333337}, {-9.659258262890681, -1.294095225512605, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      0.8333333333333339}, {-8.660254037844386, -2.5000000000000018`, 
      0.8333333333333339}, {-8.660254037844386, -2.5000000000000018`, 
      1.2500000000000007`}, {-9.659258262890681, -1.294095225512605, 
      1.2500000000000007`}, {-9.659258262890681, -1.294095225512605, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      1.25}, {-8.660254037844386, -2.5000000000000018`, 
      1.25}, {-8.660254037844386, -2.5000000000000018`, 
      1.6666666666666667`}, {-9.659258262890681, -1.294095225512605, 
      1.6666666666666667`}, {-9.659258262890681, -1.294095225512605, 1.25}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      1.666666666666667}, {-8.660254037844386, -2.5000000000000018`, 
      1.666666666666667}, {-8.660254037844386, -2.5000000000000018`, 
      2.0833333333333335`}, {-9.659258262890681, -1.294095225512605, 
      2.0833333333333335`}, {-9.659258262890681, -1.294095225512605, 
      1.666666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      2.083333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      2.083333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      2.5000000000000004`}, {-9.659258262890681, -1.294095225512605, 
      2.5000000000000004`}, {-9.659258262890681, -1.294095225512605, 
      2.083333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      2.5}, {-8.660254037844386, -2.5000000000000018`, 
      2.5}, {-8.660254037844386, -2.5000000000000018`, 
      2.9166666666666665`}, {-9.659258262890681, -1.294095225512605, 
      2.9166666666666665`}, {-9.659258262890681, -1.294095225512605, 2.5}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      2.916666666666667}, {-8.660254037844386, -2.5000000000000018`, 
      2.916666666666667}, {-8.660254037844386, -2.5000000000000018`, 
      3.3333333333333335`}, {-9.659258262890681, -1.294095225512605, 
      3.3333333333333335`}, {-9.659258262890681, -1.294095225512605, 
      2.916666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      3.333333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      3.333333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      3.7500000000000004`}, {-9.659258262890681, -1.294095225512605, 
      3.7500000000000004`}, {-9.659258262890681, -1.294095225512605, 
      3.333333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      3.75}, {-8.660254037844386, -2.5000000000000018`, 
      3.75}, {-8.660254037844386, -2.5000000000000018`, 
      4.166666666666667}, {-9.659258262890681, -1.294095225512605, 
      4.166666666666667}, {-9.659258262890681, -1.294095225512605, 3.75}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      4.166666666666668}, {-8.660254037844386, -2.5000000000000018`, 
      4.166666666666668}, {-8.660254037844386, -2.5000000000000018`, 
      4.583333333333335}, {-9.659258262890681, -1.294095225512605, 
      4.583333333333335}, {-9.659258262890681, -1.294095225512605, 
      4.166666666666668}}], 
     Polygon3DBox[{{-9.659258262890681, -1.294095225512605, 
      4.583333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      4.583333333333334}, {-8.660254037844386, -2.5000000000000018`, 
      5.000000000000001}, {-9.659258262890681, -1.294095225512605, 
      5.000000000000001}, {-9.659258262890681, -1.294095225512605, 
      4.583333333333334}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, -5.}, \
{-7.071067811865475, -3.5355339059327378`, -5.}, {-7.071067811865475, \
-3.5355339059327378`, -4.583333333333333}, {-8.660254037844387, \
-2.4999999999999996`, -4.583333333333333}, {-8.660254037844387, \
-2.4999999999999996`, -5.}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-4.583333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-4.583333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-4.166666666666666}, {-8.660254037844387, -2.4999999999999996`, \
-4.166666666666666}, {-8.660254037844387, -2.4999999999999996`, \
-4.583333333333333}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-4.166666666666667}, {-7.071067811865475, -3.5355339059327378`, \
-4.166666666666667}, {-7.071067811865475, -3.5355339059327378`, \
-3.7500000000000004`}, {-8.660254037844387, -2.4999999999999996`, \
-3.7500000000000004`}, {-8.660254037844387, -2.4999999999999996`, \
-4.166666666666667}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, -3.75}, \
{-7.071067811865475, -3.5355339059327378`, -3.75}, {-7.071067811865475, \
-3.5355339059327378`, -3.3333333333333335`}, {-8.660254037844387, \
-2.4999999999999996`, -3.3333333333333335`}, {-8.660254037844387, \
-2.4999999999999996`, -3.75}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-3.333333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-3.333333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-2.9166666666666665`}, {-8.660254037844387, -2.4999999999999996`, \
-2.9166666666666665`}, {-8.660254037844387, -2.4999999999999996`, \
-3.333333333333333}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, \
-2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, -2.5}, \
{-8.660254037844387, -2.4999999999999996`, -2.5}, {-8.660254037844387, \
-2.4999999999999996`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, -2.5}, \
{-7.071067811865475, -3.5355339059327378`, -2.5}, {-7.071067811865475, \
-3.5355339059327378`, -2.0833333333333335`}, {-8.660254037844387, \
-2.4999999999999996`, -2.0833333333333335`}, {-8.660254037844387, \
-2.4999999999999996`, -2.5}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-2.083333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-2.083333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-1.6666666666666663`}, {-8.660254037844387, -2.4999999999999996`, \
-1.6666666666666663`}, {-8.660254037844387, -2.4999999999999996`, \
-2.083333333333333}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-1.6666666666666665`}, {-7.071067811865475, -3.5355339059327378`, \
-1.6666666666666665`}, {-7.071067811865475, -3.5355339059327378`, \
-1.2499999999999998`}, {-8.660254037844387, -2.4999999999999996`, \
-1.2499999999999998`}, {-8.660254037844387, -2.4999999999999996`, \
-1.6666666666666665`}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, -1.25}, \
{-7.071067811865475, -3.5355339059327378`, -1.25}, {-7.071067811865475, \
-3.5355339059327378`, -0.8333333333333333}, {-8.660254037844387, \
-2.4999999999999996`, -0.8333333333333333}, {-8.660254037844387, \
-2.4999999999999996`, -1.25}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-0.833333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-0.833333333333333}, {-7.071067811865475, -3.5355339059327378`, \
-0.41666666666666635`}, {-8.660254037844387, -2.4999999999999996`, \
-0.41666666666666635`}, {-8.660254037844387, -2.4999999999999996`, \
-0.833333333333333}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, \
-0.4166666666666661}, {-7.071067811865475, -3.5355339059327378`, \
-0.4166666666666661}, {-7.071067811865475, -3.5355339059327378`, 
      6.106226635438361*^-16}, {-8.660254037844387, -2.4999999999999996`, 
      6.106226635438361*^-16}, {-8.660254037844387, -2.4999999999999996`, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      0.}, {-7.071067811865475, -3.5355339059327378`, 
      0.}, {-7.071067811865475, -3.5355339059327378`, 
      0.4166666666666667}, {-8.660254037844387, -2.4999999999999996`, 
      0.4166666666666667}, {-8.660254037844387, -2.4999999999999996`, 0.}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      0.41666666666666696`}, {-7.071067811865475, -3.5355339059327378`, 
      0.41666666666666696`}, {-7.071067811865475, -3.5355339059327378`, 
      0.8333333333333337}, {-8.660254037844387, -2.4999999999999996`, 
      0.8333333333333337}, {-8.660254037844387, -2.4999999999999996`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      0.8333333333333339}, {-7.071067811865475, -3.5355339059327378`, 
      0.8333333333333339}, {-7.071067811865475, -3.5355339059327378`, 
      1.2500000000000007`}, {-8.660254037844387, -2.4999999999999996`, 
      1.2500000000000007`}, {-8.660254037844387, -2.4999999999999996`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      1.25}, {-7.071067811865475, -3.5355339059327378`, 
      1.25}, {-7.071067811865475, -3.5355339059327378`, 
      1.6666666666666667`}, {-8.660254037844387, -2.4999999999999996`, 
      1.6666666666666667`}, {-8.660254037844387, -2.4999999999999996`, 
      1.25}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      1.666666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      1.666666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      2.0833333333333335`}, {-8.660254037844387, -2.4999999999999996`, 
      2.0833333333333335`}, {-8.660254037844387, -2.4999999999999996`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      2.083333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      2.083333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      2.5000000000000004`}, {-8.660254037844387, -2.4999999999999996`, 
      2.5000000000000004`}, {-8.660254037844387, -2.4999999999999996`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      2.5}, {-7.071067811865475, -3.5355339059327378`, 
      2.5}, {-7.071067811865475, -3.5355339059327378`, 
      2.9166666666666665`}, {-8.660254037844387, -2.4999999999999996`, 
      2.9166666666666665`}, {-8.660254037844387, -2.4999999999999996`, 2.5}}],
      Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      2.916666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      2.916666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      3.3333333333333335`}, {-8.660254037844387, -2.4999999999999996`, 
      3.3333333333333335`}, {-8.660254037844387, -2.4999999999999996`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      3.333333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      3.333333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      3.7500000000000004`}, {-8.660254037844387, -2.4999999999999996`, 
      3.7500000000000004`}, {-8.660254037844387, -2.4999999999999996`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      3.75}, {-7.071067811865475, -3.5355339059327378`, 
      3.75}, {-7.071067811865475, -3.5355339059327378`, 
      4.166666666666667}, {-8.660254037844387, -2.4999999999999996`, 
      4.166666666666667}, {-8.660254037844387, -2.4999999999999996`, 3.75}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      4.166666666666668}, {-7.071067811865475, -3.5355339059327378`, 
      4.166666666666668}, {-7.071067811865475, -3.5355339059327378`, 
      4.583333333333335}, {-8.660254037844387, -2.4999999999999996`, 
      4.583333333333335}, {-8.660254037844387, -2.4999999999999996`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-8.660254037844387, -2.4999999999999996`, 
      4.583333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      4.583333333333334}, {-7.071067811865475, -3.5355339059327378`, 
      5.000000000000001}, {-8.660254037844387, -2.4999999999999996`, 
      5.000000000000001}, {-8.660254037844387, -2.4999999999999996`, 
      4.583333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, -5.}, \
{-4.999999999999998, -4.330127018922194, -5.}, {-4.999999999999998, \
-4.330127018922194, -4.583333333333333}, {-7.071067811865475, \
-3.5355339059327378`, -4.583333333333333}, {-7.071067811865475, \
-3.5355339059327378`, -5.}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-4.583333333333333}, {-4.999999999999998, -4.330127018922194, \
-4.583333333333333}, {-4.999999999999998, -4.330127018922194, \
-4.166666666666666}, {-7.071067811865475, -3.5355339059327378`, \
-4.166666666666666}, {-7.071067811865475, -3.5355339059327378`, \
-4.583333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-4.166666666666667}, {-4.999999999999998, -4.330127018922194, \
-4.166666666666667}, {-4.999999999999998, -4.330127018922194, \
-3.7500000000000004`}, {-7.071067811865475, -3.5355339059327378`, \
-3.7500000000000004`}, {-7.071067811865475, -3.5355339059327378`, \
-4.166666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, -3.75}, \
{-4.999999999999998, -4.330127018922194, -3.75}, {-4.999999999999998, \
-4.330127018922194, -3.3333333333333335`}, {-7.071067811865475, \
-3.5355339059327378`, -3.3333333333333335`}, {-7.071067811865475, \
-3.5355339059327378`, -3.75}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-3.333333333333333}, {-4.999999999999998, -4.330127018922194, \
-3.333333333333333}, {-4.999999999999998, -4.330127018922194, \
-2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, \
-2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, \
-3.333333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-2.9166666666666665`}, {-4.999999999999998, -4.330127018922194, \
-2.9166666666666665`}, {-4.999999999999998, -4.330127018922194, -2.5}, \
{-7.071067811865475, -3.5355339059327378`, -2.5}, {-7.071067811865475, \
-3.5355339059327378`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, -2.5}, \
{-4.999999999999998, -4.330127018922194, -2.5}, {-4.999999999999998, \
-4.330127018922194, -2.0833333333333335`}, {-7.071067811865475, \
-3.5355339059327378`, -2.0833333333333335`}, {-7.071067811865475, \
-3.5355339059327378`, -2.5}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-2.083333333333333}, {-4.999999999999998, -4.330127018922194, \
-2.083333333333333}, {-4.999999999999998, -4.330127018922194, \
-1.6666666666666663`}, {-7.071067811865475, -3.5355339059327378`, \
-1.6666666666666663`}, {-7.071067811865475, -3.5355339059327378`, \
-2.083333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-1.6666666666666665`}, {-4.999999999999998, -4.330127018922194, \
-1.6666666666666665`}, {-4.999999999999998, -4.330127018922194, \
-1.2499999999999998`}, {-7.071067811865475, -3.5355339059327378`, \
-1.2499999999999998`}, {-7.071067811865475, -3.5355339059327378`, \
-1.6666666666666665`}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, -1.25}, \
{-4.999999999999998, -4.330127018922194, -1.25}, {-4.999999999999998, \
-4.330127018922194, -0.8333333333333333}, {-7.071067811865475, \
-3.5355339059327378`, -0.8333333333333333}, {-7.071067811865475, \
-3.5355339059327378`, -1.25}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-0.833333333333333}, {-4.999999999999998, -4.330127018922194, \
-0.833333333333333}, {-4.999999999999998, -4.330127018922194, \
-0.41666666666666635`}, {-7.071067811865475, -3.5355339059327378`, \
-0.41666666666666635`}, {-7.071067811865475, -3.5355339059327378`, \
-0.833333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, \
-0.4166666666666661}, {-4.999999999999998, -4.330127018922194, \
-0.4166666666666661}, {-4.999999999999998, -4.330127018922194, 
      6.106226635438361*^-16}, {-7.071067811865475, -3.5355339059327378`, 
      6.106226635438361*^-16}, {-7.071067811865475, -3.5355339059327378`, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      0.}, {-4.999999999999998, -4.330127018922194, 
      0.}, {-4.999999999999998, -4.330127018922194, 
      0.4166666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      0.4166666666666667}, {-7.071067811865475, -3.5355339059327378`, 0.}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      0.41666666666666696`}, {-4.999999999999998, -4.330127018922194, 
      0.41666666666666696`}, {-4.999999999999998, -4.330127018922194, 
      0.8333333333333337}, {-7.071067811865475, -3.5355339059327378`, 
      0.8333333333333337}, {-7.071067811865475, -3.5355339059327378`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      0.8333333333333339}, {-4.999999999999998, -4.330127018922194, 
      0.8333333333333339}, {-4.999999999999998, -4.330127018922194, 
      1.2500000000000007`}, {-7.071067811865475, -3.5355339059327378`, 
      1.2500000000000007`}, {-7.071067811865475, -3.5355339059327378`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      1.25}, {-4.999999999999998, -4.330127018922194, 
      1.25}, {-4.999999999999998, -4.330127018922194, 
      1.6666666666666667`}, {-7.071067811865475, -3.5355339059327378`, 
      1.6666666666666667`}, {-7.071067811865475, -3.5355339059327378`, 
      1.25}}], Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      1.666666666666667}, {-4.999999999999998, -4.330127018922194, 
      1.666666666666667}, {-4.999999999999998, -4.330127018922194, 
      2.0833333333333335`}, {-7.071067811865475, -3.5355339059327378`, 
      2.0833333333333335`}, {-7.071067811865475, -3.5355339059327378`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      2.083333333333334}, {-4.999999999999998, -4.330127018922194, 
      2.083333333333334}, {-4.999999999999998, -4.330127018922194, 
      2.5000000000000004`}, {-7.071067811865475, -3.5355339059327378`, 
      2.5000000000000004`}, {-7.071067811865475, -3.5355339059327378`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      2.5}, {-4.999999999999998, -4.330127018922194, 
      2.5}, {-4.999999999999998, -4.330127018922194, 
      2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, 
      2.9166666666666665`}, {-7.071067811865475, -3.5355339059327378`, 2.5}}],
      Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      2.916666666666667}, {-4.999999999999998, -4.330127018922194, 
      2.916666666666667}, {-4.999999999999998, -4.330127018922194, 
      3.3333333333333335`}, {-7.071067811865475, -3.5355339059327378`, 
      3.3333333333333335`}, {-7.071067811865475, -3.5355339059327378`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      3.333333333333334}, {-4.999999999999998, -4.330127018922194, 
      3.333333333333334}, {-4.999999999999998, -4.330127018922194, 
      3.7500000000000004`}, {-7.071067811865475, -3.5355339059327378`, 
      3.7500000000000004`}, {-7.071067811865475, -3.5355339059327378`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      3.75}, {-4.999999999999998, -4.330127018922194, 
      3.75}, {-4.999999999999998, -4.330127018922194, 
      4.166666666666667}, {-7.071067811865475, -3.5355339059327378`, 
      4.166666666666667}, {-7.071067811865475, -3.5355339059327378`, 3.75}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      4.166666666666668}, {-4.999999999999998, -4.330127018922194, 
      4.166666666666668}, {-4.999999999999998, -4.330127018922194, 
      4.583333333333335}, {-7.071067811865475, -3.5355339059327378`, 
      4.583333333333335}, {-7.071067811865475, -3.5355339059327378`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-7.071067811865475, -3.5355339059327378`, 
      4.583333333333334}, {-4.999999999999998, -4.330127018922194, 
      4.583333333333334}, {-4.999999999999998, -4.330127018922194, 
      5.000000000000001}, {-7.071067811865475, -3.5355339059327378`, 
      5.000000000000001}, {-7.071067811865475, -3.5355339059327378`, 
      4.583333333333334}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, -5.}, \
{-2.588190451025211, -4.829629131445341, -5.}, {-2.588190451025211, \
-4.829629131445341, -4.583333333333333}, {-5.000000000000002, \
-4.330127018922193, -4.583333333333333}, {-5.000000000000002, \
-4.330127018922193, -5.}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-4.583333333333333}, {-2.588190451025211, -4.829629131445341, \
-4.583333333333333}, {-2.588190451025211, -4.829629131445341, \
-4.166666666666666}, {-5.000000000000002, -4.330127018922193, \
-4.166666666666666}, {-5.000000000000002, -4.330127018922193, \
-4.583333333333333}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-4.166666666666667}, {-2.588190451025211, -4.829629131445341, \
-4.166666666666667}, {-2.588190451025211, -4.829629131445341, \
-3.7500000000000004`}, {-5.000000000000002, -4.330127018922193, \
-3.7500000000000004`}, {-5.000000000000002, -4.330127018922193, \
-4.166666666666667}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, -3.75}, \
{-2.588190451025211, -4.829629131445341, -3.75}, {-2.588190451025211, \
-4.829629131445341, -3.3333333333333335`}, {-5.000000000000002, \
-4.330127018922193, -3.3333333333333335`}, {-5.000000000000002, \
-4.330127018922193, -3.75}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-3.333333333333333}, {-2.588190451025211, -4.829629131445341, \
-3.333333333333333}, {-2.588190451025211, -4.829629131445341, \
-2.9166666666666665`}, {-5.000000000000002, -4.330127018922193, \
-2.9166666666666665`}, {-5.000000000000002, -4.330127018922193, \
-3.333333333333333}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-2.9166666666666665`}, {-2.588190451025211, -4.829629131445341, \
-2.9166666666666665`}, {-2.588190451025211, -4.829629131445341, -2.5}, \
{-5.000000000000002, -4.330127018922193, -2.5}, {-5.000000000000002, \
-4.330127018922193, -2.9166666666666665`}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, -2.5}, \
{-2.588190451025211, -4.829629131445341, -2.5}, {-2.588190451025211, \
-4.829629131445341, -2.0833333333333335`}, {-5.000000000000002, \
-4.330127018922193, -2.0833333333333335`}, {-5.000000000000002, \
-4.330127018922193, -2.5}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-2.083333333333333}, {-2.588190451025211, -4.829629131445341, \
-2.083333333333333}, {-2.588190451025211, -4.829629131445341, \
-1.6666666666666663`}, {-5.000000000000002, -4.330127018922193, \
-1.6666666666666663`}, {-5.000000000000002, -4.330127018922193, \
-2.083333333333333}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-1.6666666666666665`}, {-2.588190451025211, -4.829629131445341, \
-1.6666666666666665`}, {-2.588190451025211, -4.829629131445341, \
-1.2499999999999998`}, {-5.000000000000002, -4.330127018922193, \
-1.2499999999999998`}, {-5.000000000000002, -4.330127018922193, \
-1.6666666666666665`}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, -1.25}, \
{-2.588190451025211, -4.829629131445341, -1.25}, {-2.588190451025211, \
-4.829629131445341, -0.8333333333333333}, {-5.000000000000002, \
-4.330127018922193, -0.8333333333333333}, {-5.000000000000002, \
-4.330127018922193, -1.25}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-0.833333333333333}, {-2.588190451025211, -4.829629131445341, \
-0.833333333333333}, {-2.588190451025211, -4.829629131445341, \
-0.41666666666666635`}, {-5.000000000000002, -4.330127018922193, \
-0.41666666666666635`}, {-5.000000000000002, -4.330127018922193, \
-0.833333333333333}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, \
-0.4166666666666661}, {-2.588190451025211, -4.829629131445341, \
-0.4166666666666661}, {-2.588190451025211, -4.829629131445341, 
      6.106226635438361*^-16}, {-5.000000000000002, -4.330127018922193, 
      6.106226635438361*^-16}, {-5.000000000000002, -4.330127018922193, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      0.}, {-2.588190451025211, -4.829629131445341, 
      0.}, {-2.588190451025211, -4.829629131445341, 
      0.4166666666666667}, {-5.000000000000002, -4.330127018922193, 
      0.4166666666666667}, {-5.000000000000002, -4.330127018922193, 0.}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      0.41666666666666696`}, {-2.588190451025211, -4.829629131445341, 
      0.41666666666666696`}, {-2.588190451025211, -4.829629131445341, 
      0.8333333333333337}, {-5.000000000000002, -4.330127018922193, 
      0.8333333333333337}, {-5.000000000000002, -4.330127018922193, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      0.8333333333333339}, {-2.588190451025211, -4.829629131445341, 
      0.8333333333333339}, {-2.588190451025211, -4.829629131445341, 
      1.2500000000000007`}, {-5.000000000000002, -4.330127018922193, 
      1.2500000000000007`}, {-5.000000000000002, -4.330127018922193, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      1.25}, {-2.588190451025211, -4.829629131445341, 
      1.25}, {-2.588190451025211, -4.829629131445341, 
      1.6666666666666667`}, {-5.000000000000002, -4.330127018922193, 
      1.6666666666666667`}, {-5.000000000000002, -4.330127018922193, 1.25}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      1.666666666666667}, {-2.588190451025211, -4.829629131445341, 
      1.666666666666667}, {-2.588190451025211, -4.829629131445341, 
      2.0833333333333335`}, {-5.000000000000002, -4.330127018922193, 
      2.0833333333333335`}, {-5.000000000000002, -4.330127018922193, 
      1.666666666666667}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      2.083333333333334}, {-2.588190451025211, -4.829629131445341, 
      2.083333333333334}, {-2.588190451025211, -4.829629131445341, 
      2.5000000000000004`}, {-5.000000000000002, -4.330127018922193, 
      2.5000000000000004`}, {-5.000000000000002, -4.330127018922193, 
      2.083333333333334}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      2.5}, {-2.588190451025211, -4.829629131445341, 
      2.5}, {-2.588190451025211, -4.829629131445341, 
      2.9166666666666665`}, {-5.000000000000002, -4.330127018922193, 
      2.9166666666666665`}, {-5.000000000000002, -4.330127018922193, 2.5}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      2.916666666666667}, {-2.588190451025211, -4.829629131445341, 
      2.916666666666667}, {-2.588190451025211, -4.829629131445341, 
      3.3333333333333335`}, {-5.000000000000002, -4.330127018922193, 
      3.3333333333333335`}, {-5.000000000000002, -4.330127018922193, 
      2.916666666666667}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      3.333333333333334}, {-2.588190451025211, -4.829629131445341, 
      3.333333333333334}, {-2.588190451025211, -4.829629131445341, 
      3.7500000000000004`}, {-5.000000000000002, -4.330127018922193, 
      3.7500000000000004`}, {-5.000000000000002, -4.330127018922193, 
      3.333333333333334}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      3.75}, {-2.588190451025211, -4.829629131445341, 
      3.75}, {-2.588190451025211, -4.829629131445341, 
      4.166666666666667}, {-5.000000000000002, -4.330127018922193, 
      4.166666666666667}, {-5.000000000000002, -4.330127018922193, 3.75}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      4.166666666666668}, {-2.588190451025211, -4.829629131445341, 
      4.166666666666668}, {-2.588190451025211, -4.829629131445341, 
      4.583333333333335}, {-5.000000000000002, -4.330127018922193, 
      4.583333333333335}, {-5.000000000000002, -4.330127018922193, 
      4.166666666666668}}], 
     Polygon3DBox[{{-5.000000000000002, -4.330127018922193, 
      4.583333333333334}, {-2.588190451025211, -4.829629131445341, 
      4.583333333333334}, {-2.588190451025211, -4.829629131445341, 
      5.000000000000001}, {-5.000000000000002, -4.330127018922193, 
      5.000000000000001}, {-5.000000000000002, -4.330127018922193, 
      4.583333333333334}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, -5.}, \
{-1.6081226496766366`*^-15, -5., -5.}, {-1.6081226496766366`*^-15, -5., \
-4.583333333333333}, {-2.5881904510252083`, -4.8296291314453415`, \
-4.583333333333333}, {-2.5881904510252083`, -4.8296291314453415`, -5.}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-4.583333333333333}, {-1.6081226496766366`*^-15, -5., -4.583333333333333}, \
{-1.6081226496766366`*^-15, -5., -4.166666666666666}, {-2.5881904510252083`, \
-4.8296291314453415`, -4.166666666666666}, {-2.5881904510252083`, \
-4.8296291314453415`, -4.583333333333333}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-4.166666666666667}, {-1.6081226496766366`*^-15, -5., -4.166666666666667}, \
{-1.6081226496766366`*^-15, -5., -3.7500000000000004`}, \
{-2.5881904510252083`, -4.8296291314453415`, -3.7500000000000004`}, \
{-2.5881904510252083`, -4.8296291314453415`, -4.166666666666667}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, -3.75}, \
{-1.6081226496766366`*^-15, -5., -3.75}, {-1.6081226496766366`*^-15, -5., \
-3.3333333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, \
-3.3333333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, -3.75}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-3.333333333333333}, {-1.6081226496766366`*^-15, -5., -3.333333333333333}, \
{-1.6081226496766366`*^-15, -5., -2.9166666666666665`}, \
{-2.5881904510252083`, -4.8296291314453415`, -2.9166666666666665`}, \
{-2.5881904510252083`, -4.8296291314453415`, -3.333333333333333}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-2.9166666666666665`}, {-1.6081226496766366`*^-15, -5., \
-2.9166666666666665`}, {-1.6081226496766366`*^-15, -5., -2.5}, \
{-2.5881904510252083`, -4.8296291314453415`, -2.5}, {-2.5881904510252083`, \
-4.8296291314453415`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, -2.5}, \
{-1.6081226496766366`*^-15, -5., -2.5}, {-1.6081226496766366`*^-15, -5., \
-2.0833333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, \
-2.0833333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, -2.5}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-2.083333333333333}, {-1.6081226496766366`*^-15, -5., -2.083333333333333}, \
{-1.6081226496766366`*^-15, -5., -1.6666666666666663`}, \
{-2.5881904510252083`, -4.8296291314453415`, -1.6666666666666663`}, \
{-2.5881904510252083`, -4.8296291314453415`, -2.083333333333333}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-1.6666666666666665`}, {-1.6081226496766366`*^-15, -5., \
-1.6666666666666665`}, {-1.6081226496766366`*^-15, -5., \
-1.2499999999999998`}, {-2.5881904510252083`, -4.8296291314453415`, \
-1.2499999999999998`}, {-2.5881904510252083`, -4.8296291314453415`, \
-1.6666666666666665`}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, -1.25}, \
{-1.6081226496766366`*^-15, -5., -1.25}, {-1.6081226496766366`*^-15, -5., \
-0.8333333333333333}, {-2.5881904510252083`, -4.8296291314453415`, \
-0.8333333333333333}, {-2.5881904510252083`, -4.8296291314453415`, -1.25}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-0.833333333333333}, {-1.6081226496766366`*^-15, -5., -0.833333333333333}, \
{-1.6081226496766366`*^-15, -5., -0.41666666666666635`}, \
{-2.5881904510252083`, -4.8296291314453415`, -0.41666666666666635`}, \
{-2.5881904510252083`, -4.8296291314453415`, -0.833333333333333}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, \
-0.4166666666666661}, {-1.6081226496766366`*^-15, -5., -0.4166666666666661}, \
{-1.6081226496766366`*^-15, -5., 
      6.106226635438361*^-16}, {-2.5881904510252083`, -4.8296291314453415`, 
      6.106226635438361*^-16}, {-2.5881904510252083`, -4.8296291314453415`, \
-0.4166666666666661}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      0.}, {-1.6081226496766366`*^-15, -5., 
      0.}, {-1.6081226496766366`*^-15, -5., 
      0.4166666666666667}, {-2.5881904510252083`, -4.8296291314453415`, 
      0.4166666666666667}, {-2.5881904510252083`, -4.8296291314453415`, 0.}}],
      Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      0.41666666666666696`}, {-1.6081226496766366`*^-15, -5., 
      0.41666666666666696`}, {-1.6081226496766366`*^-15, -5., 
      0.8333333333333337}, {-2.5881904510252083`, -4.8296291314453415`, 
      0.8333333333333337}, {-2.5881904510252083`, -4.8296291314453415`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      0.8333333333333339}, {-1.6081226496766366`*^-15, -5., 
      0.8333333333333339}, {-1.6081226496766366`*^-15, -5., 
      1.2500000000000007`}, {-2.5881904510252083`, -4.8296291314453415`, 
      1.2500000000000007`}, {-2.5881904510252083`, -4.8296291314453415`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      1.25}, {-1.6081226496766366`*^-15, -5., 
      1.25}, {-1.6081226496766366`*^-15, -5., 
      1.6666666666666667`}, {-2.5881904510252083`, -4.8296291314453415`, 
      1.6666666666666667`}, {-2.5881904510252083`, -4.8296291314453415`, 
      1.25}}], Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      1.666666666666667}, {-1.6081226496766366`*^-15, -5., 
      1.666666666666667}, {-1.6081226496766366`*^-15, -5., 
      2.0833333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.0833333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      2.083333333333334}, {-1.6081226496766366`*^-15, -5., 
      2.083333333333334}, {-1.6081226496766366`*^-15, -5., 
      2.5000000000000004`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.5000000000000004`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      2.5}, {-1.6081226496766366`*^-15, -5., 
      2.5}, {-1.6081226496766366`*^-15, -5., 
      2.9166666666666665`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.9166666666666665`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.5}}], Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      2.916666666666667}, {-1.6081226496766366`*^-15, -5., 
      2.916666666666667}, {-1.6081226496766366`*^-15, -5., 
      3.3333333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, 
      3.3333333333333335`}, {-2.5881904510252083`, -4.8296291314453415`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      3.333333333333334}, {-1.6081226496766366`*^-15, -5., 
      3.333333333333334}, {-1.6081226496766366`*^-15, -5., 
      3.7500000000000004`}, {-2.5881904510252083`, -4.8296291314453415`, 
      3.7500000000000004`}, {-2.5881904510252083`, -4.8296291314453415`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      3.75}, {-1.6081226496766366`*^-15, -5., 
      3.75}, {-1.6081226496766366`*^-15, -5., 
      4.166666666666667}, {-2.5881904510252083`, -4.8296291314453415`, 
      4.166666666666667}, {-2.5881904510252083`, -4.8296291314453415`, 
      3.75}}], Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      4.166666666666668}, {-1.6081226496766366`*^-15, -5., 
      4.166666666666668}, {-1.6081226496766366`*^-15, -5., 
      4.583333333333335}, {-2.5881904510252083`, -4.8296291314453415`, 
      4.583333333333335}, {-2.5881904510252083`, -4.8296291314453415`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-2.5881904510252083`, -4.8296291314453415`, 
      4.583333333333334}, {-1.6081226496766366`*^-15, -5., 
      4.583333333333334}, {-1.6081226496766366`*^-15, -5., 
      5.000000000000001}, {-2.5881904510252083`, -4.8296291314453415`, 
      5.000000000000001}, {-2.5881904510252083`, -4.8296291314453415`, 
      4.583333333333334}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -5.}, {
      2.5881904510252074`, -4.8296291314453415`, -5.}, {
      2.5881904510252074`, -4.8296291314453415`, -4.583333333333333}, {
      6.123233995736766*^-16, -5., -4.583333333333333}, {
      6.123233995736766*^-16, -5., -5.}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -4.583333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -4.583333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -4.166666666666666}, {
      6.123233995736766*^-16, -5., -4.166666666666666}, {
      6.123233995736766*^-16, -5., -4.583333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -4.166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, -4.166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, -3.7500000000000004`}, {
      6.123233995736766*^-16, -5., -3.7500000000000004`}, {
      6.123233995736766*^-16, -5., -4.166666666666667}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -3.75}, {
      2.5881904510252074`, -4.8296291314453415`, -3.75}, {
      2.5881904510252074`, -4.8296291314453415`, -3.3333333333333335`}, {
      6.123233995736766*^-16, -5., -3.3333333333333335`}, {
      6.123233995736766*^-16, -5., -3.75}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -3.333333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -3.333333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -2.9166666666666665`}, {
      6.123233995736766*^-16, -5., -2.9166666666666665`}, {
      6.123233995736766*^-16, -5., -3.333333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.5}, {
      6.123233995736766*^-16, -5., -2.5}, {
      6.123233995736766*^-16, -5., -2.9166666666666665`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -2.5}, {
      2.5881904510252074`, -4.8296291314453415`, -2.5}, {
      2.5881904510252074`, -4.8296291314453415`, -2.0833333333333335`}, {
      6.123233995736766*^-16, -5., -2.0833333333333335`}, {
      6.123233995736766*^-16, -5., -2.5}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -2.083333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -2.083333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -1.6666666666666663`}, {
      6.123233995736766*^-16, -5., -1.6666666666666663`}, {
      6.123233995736766*^-16, -5., -2.083333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -1.6666666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -1.6666666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -1.2499999999999998`}, {
      6.123233995736766*^-16, -5., -1.2499999999999998`}, {
      6.123233995736766*^-16, -5., -1.6666666666666665`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -1.25}, {
      2.5881904510252074`, -4.8296291314453415`, -1.25}, {
      2.5881904510252074`, -4.8296291314453415`, -0.8333333333333333}, {
      6.123233995736766*^-16, -5., -0.8333333333333333}, {
      6.123233995736766*^-16, -5., -1.25}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -0.833333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -0.833333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -0.41666666666666635`}, {
      6.123233995736766*^-16, -5., -0.41666666666666635`}, {
      6.123233995736766*^-16, -5., -0.833333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., -0.4166666666666661}, {
      2.5881904510252074`, -4.8296291314453415`, -0.4166666666666661}, {
      2.5881904510252074`, -4.8296291314453415`, 6.106226635438361*^-16}, {
      6.123233995736766*^-16, -5., 6.106226635438361*^-16}, {
      6.123233995736766*^-16, -5., -0.4166666666666661}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 0.}, {
      2.5881904510252074`, -4.8296291314453415`, 0.}, {
      2.5881904510252074`, -4.8296291314453415`, 0.4166666666666667}, {
      6.123233995736766*^-16, -5., 0.4166666666666667}, {
      6.123233995736766*^-16, -5., 0.}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 0.41666666666666696`}, {
      2.5881904510252074`, -4.8296291314453415`, 0.41666666666666696`}, {
      2.5881904510252074`, -4.8296291314453415`, 0.8333333333333337}, {
      6.123233995736766*^-16, -5., 0.8333333333333337}, {
      6.123233995736766*^-16, -5., 0.41666666666666696`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 0.8333333333333339}, {
      2.5881904510252074`, -4.8296291314453415`, 0.8333333333333339}, {
      2.5881904510252074`, -4.8296291314453415`, 1.2500000000000007`}, {
      6.123233995736766*^-16, -5., 1.2500000000000007`}, {
      6.123233995736766*^-16, -5., 0.8333333333333339}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 1.25}, {
      2.5881904510252074`, -4.8296291314453415`, 1.25}, {
      2.5881904510252074`, -4.8296291314453415`, 1.6666666666666667`}, {
      6.123233995736766*^-16, -5., 1.6666666666666667`}, {
      6.123233995736766*^-16, -5., 1.25}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 1.666666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 1.666666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 2.0833333333333335`}, {
      6.123233995736766*^-16, -5., 2.0833333333333335`}, {
      6.123233995736766*^-16, -5., 1.666666666666667}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 2.083333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 2.083333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 2.5000000000000004`}, {
      6.123233995736766*^-16, -5., 2.5000000000000004`}, {
      6.123233995736766*^-16, -5., 2.083333333333334}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 2.5}, {
      2.5881904510252074`, -4.8296291314453415`, 2.5}, {
      2.5881904510252074`, -4.8296291314453415`, 2.9166666666666665`}, {
      6.123233995736766*^-16, -5., 2.9166666666666665`}, {
      6.123233995736766*^-16, -5., 2.5}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 2.916666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 2.916666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 3.3333333333333335`}, {
      6.123233995736766*^-16, -5., 3.3333333333333335`}, {
      6.123233995736766*^-16, -5., 2.916666666666667}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 3.333333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 3.333333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 3.7500000000000004`}, {
      6.123233995736766*^-16, -5., 3.7500000000000004`}, {
      6.123233995736766*^-16, -5., 3.333333333333334}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 3.75}, {
      2.5881904510252074`, -4.8296291314453415`, 3.75}, {
      2.5881904510252074`, -4.8296291314453415`, 4.166666666666667}, {
      6.123233995736766*^-16, -5., 4.166666666666667}, {
      6.123233995736766*^-16, -5., 3.75}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 4.166666666666668}, {
      2.5881904510252074`, -4.8296291314453415`, 4.166666666666668}, {
      2.5881904510252074`, -4.8296291314453415`, 4.583333333333335}, {
      6.123233995736766*^-16, -5., 4.583333333333335}, {
      6.123233995736766*^-16, -5., 4.166666666666668}}], 
     Polygon3DBox[{{6.123233995736766*^-16, -5., 4.583333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 4.583333333333334}, {
      2.5881904510252074`, -4.8296291314453415`, 5.000000000000001}, {
      6.123233995736766*^-16, -5., 5.000000000000001}, {
      6.123233995736766*^-16, -5., 4.583333333333334}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, -5.}, {
      4.999999999999999, -4.330127018922194, -5.}, {
      4.999999999999999, -4.330127018922194, -4.583333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -4.583333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -5.}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -4.583333333333333}, {
      4.999999999999999, -4.330127018922194, -4.583333333333333}, {
      4.999999999999999, -4.330127018922194, -4.166666666666666}, {
      2.5881904510252074`, -4.8296291314453415`, -4.166666666666666}, {
      2.5881904510252074`, -4.8296291314453415`, -4.583333333333333}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -4.166666666666667}, {
      4.999999999999999, -4.330127018922194, -4.166666666666667}, {
      4.999999999999999, -4.330127018922194, -3.7500000000000004`}, {
      2.5881904510252074`, -4.8296291314453415`, -3.7500000000000004`}, {
      2.5881904510252074`, -4.8296291314453415`, -4.166666666666667}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, -3.75}, {
      4.999999999999999, -4.330127018922194, -3.75}, {
      4.999999999999999, -4.330127018922194, -3.3333333333333335`}, {
      2.5881904510252074`, -4.8296291314453415`, -3.3333333333333335`}, {
      2.5881904510252074`, -4.8296291314453415`, -3.75}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -3.333333333333333}, {
      4.999999999999999, -4.330127018922194, -3.333333333333333}, {
      4.999999999999999, -4.330127018922194, -2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, -3.333333333333333}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, -2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, -2.5}, {
      2.5881904510252074`, -4.8296291314453415`, -2.5}, {
      2.5881904510252074`, -4.8296291314453415`, -2.9166666666666665`}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, -2.5}, {
      4.999999999999999, -4.330127018922194, -2.5}, {
      4.999999999999999, -4.330127018922194, -2.0833333333333335`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.0833333333333335`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.5}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -2.083333333333333}, {
      4.999999999999999, -4.330127018922194, -2.083333333333333}, {
      4.999999999999999, -4.330127018922194, -1.6666666666666663`}, {
      2.5881904510252074`, -4.8296291314453415`, -1.6666666666666663`}, {
      2.5881904510252074`, -4.8296291314453415`, -2.083333333333333}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -1.6666666666666665`}, {
      4.999999999999999, -4.330127018922194, -1.6666666666666665`}, {
      4.999999999999999, -4.330127018922194, -1.2499999999999998`}, {
      2.5881904510252074`, -4.8296291314453415`, -1.2499999999999998`}, {
      2.5881904510252074`, -4.8296291314453415`, -1.6666666666666665`}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, -1.25}, {
      4.999999999999999, -4.330127018922194, -1.25}, {
      4.999999999999999, -4.330127018922194, -0.8333333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -0.8333333333333333}, {
      2.5881904510252074`, -4.8296291314453415`, -1.25}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -0.833333333333333}, {
      4.999999999999999, -4.330127018922194, -0.833333333333333}, {
      4.999999999999999, -4.330127018922194, -0.41666666666666635`}, {
      2.5881904510252074`, -4.8296291314453415`, -0.41666666666666635`}, {
      2.5881904510252074`, -4.8296291314453415`, -0.833333333333333}}], 
     Polygon3DBox[{{
      2.5881904510252074`, -4.8296291314453415`, -0.4166666666666661}, {
      4.999999999999999, -4.330127018922194, -0.4166666666666661}, {
      4.999999999999999, -4.330127018922194, 6.106226635438361*^-16}, {
      2.5881904510252074`, -4.8296291314453415`, 6.106226635438361*^-16}, {
      2.5881904510252074`, -4.8296291314453415`, -0.4166666666666661}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 0.}, {
      4.999999999999999, -4.330127018922194, 0.}, {
      4.999999999999999, -4.330127018922194, 0.4166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 0.4166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 0.}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      0.41666666666666696`}, {4.999999999999999, -4.330127018922194, 
      0.41666666666666696`}, {4.999999999999999, -4.330127018922194, 
      0.8333333333333337}, {2.5881904510252074`, -4.8296291314453415`, 
      0.8333333333333337}, {2.5881904510252074`, -4.8296291314453415`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      0.8333333333333339}, {4.999999999999999, -4.330127018922194, 
      0.8333333333333339}, {4.999999999999999, -4.330127018922194, 
      1.2500000000000007`}, {2.5881904510252074`, -4.8296291314453415`, 
      1.2500000000000007`}, {2.5881904510252074`, -4.8296291314453415`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 1.25}, {
      4.999999999999999, -4.330127018922194, 1.25}, {
      4.999999999999999, -4.330127018922194, 1.6666666666666667`}, {
      2.5881904510252074`, -4.8296291314453415`, 1.6666666666666667`}, {
      2.5881904510252074`, -4.8296291314453415`, 1.25}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      1.666666666666667}, {4.999999999999999, -4.330127018922194, 
      1.666666666666667}, {4.999999999999999, -4.330127018922194, 
      2.0833333333333335`}, {2.5881904510252074`, -4.8296291314453415`, 
      2.0833333333333335`}, {2.5881904510252074`, -4.8296291314453415`, 
      1.666666666666667}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      2.083333333333334}, {4.999999999999999, -4.330127018922194, 
      2.083333333333334}, {4.999999999999999, -4.330127018922194, 
      2.5000000000000004`}, {2.5881904510252074`, -4.8296291314453415`, 
      2.5000000000000004`}, {2.5881904510252074`, -4.8296291314453415`, 
      2.083333333333334}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 2.5}, {
      4.999999999999999, -4.330127018922194, 2.5}, {
      4.999999999999999, -4.330127018922194, 2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, 2.9166666666666665`}, {
      2.5881904510252074`, -4.8296291314453415`, 2.5}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      2.916666666666667}, {4.999999999999999, -4.330127018922194, 
      2.916666666666667}, {4.999999999999999, -4.330127018922194, 
      3.3333333333333335`}, {2.5881904510252074`, -4.8296291314453415`, 
      3.3333333333333335`}, {2.5881904510252074`, -4.8296291314453415`, 
      2.916666666666667}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      3.333333333333334}, {4.999999999999999, -4.330127018922194, 
      3.333333333333334}, {4.999999999999999, -4.330127018922194, 
      3.7500000000000004`}, {2.5881904510252074`, -4.8296291314453415`, 
      3.7500000000000004`}, {2.5881904510252074`, -4.8296291314453415`, 
      3.333333333333334}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 3.75}, {
      4.999999999999999, -4.330127018922194, 3.75}, {
      4.999999999999999, -4.330127018922194, 4.166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 4.166666666666667}, {
      2.5881904510252074`, -4.8296291314453415`, 3.75}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      4.166666666666668}, {4.999999999999999, -4.330127018922194, 
      4.166666666666668}, {4.999999999999999, -4.330127018922194, 
      4.583333333333335}, {2.5881904510252074`, -4.8296291314453415`, 
      4.583333333333335}, {2.5881904510252074`, -4.8296291314453415`, 
      4.166666666666668}}], 
     Polygon3DBox[{{2.5881904510252074`, -4.8296291314453415`, 
      4.583333333333334}, {4.999999999999999, -4.330127018922194, 
      4.583333333333334}, {4.999999999999999, -4.330127018922194, 
      5.000000000000001}, {2.5881904510252074`, -4.8296291314453415`, 
      5.000000000000001}, {2.5881904510252074`, -4.8296291314453415`, 
      4.583333333333334}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, -5.}, {
      7.071067811865474, -3.5355339059327386`, -5.}, {
      7.071067811865474, -3.5355339059327386`, -4.583333333333333}, {
      4.999999999999999, -4.330127018922194, -4.583333333333333}, {
      4.999999999999999, -4.330127018922194, -5.}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -4.583333333333333}, {
      7.071067811865474, -3.5355339059327386`, -4.583333333333333}, {
      7.071067811865474, -3.5355339059327386`, -4.166666666666666}, {
      4.999999999999999, -4.330127018922194, -4.166666666666666}, {
      4.999999999999999, -4.330127018922194, -4.583333333333333}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -4.166666666666667}, {
      7.071067811865474, -3.5355339059327386`, -4.166666666666667}, {
      7.071067811865474, -3.5355339059327386`, -3.7500000000000004`}, {
      4.999999999999999, -4.330127018922194, -3.7500000000000004`}, {
      4.999999999999999, -4.330127018922194, -4.166666666666667}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, -3.75}, {
      7.071067811865474, -3.5355339059327386`, -3.75}, {
      7.071067811865474, -3.5355339059327386`, -3.3333333333333335`}, {
      4.999999999999999, -4.330127018922194, -3.3333333333333335`}, {
      4.999999999999999, -4.330127018922194, -3.75}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -3.333333333333333}, {
      7.071067811865474, -3.5355339059327386`, -3.333333333333333}, {
      7.071067811865474, -3.5355339059327386`, -2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, -2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, -3.333333333333333}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -2.9166666666666665`}, {
      7.071067811865474, -3.5355339059327386`, -2.9166666666666665`}, {
      7.071067811865474, -3.5355339059327386`, -2.5}, {
      4.999999999999999, -4.330127018922194, -2.5}, {
      4.999999999999999, -4.330127018922194, -2.9166666666666665`}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, -2.5}, {
      7.071067811865474, -3.5355339059327386`, -2.5}, {
      7.071067811865474, -3.5355339059327386`, -2.0833333333333335`}, {
      4.999999999999999, -4.330127018922194, -2.0833333333333335`}, {
      4.999999999999999, -4.330127018922194, -2.5}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -2.083333333333333}, {
      7.071067811865474, -3.5355339059327386`, -2.083333333333333}, {
      7.071067811865474, -3.5355339059327386`, -1.6666666666666663`}, {
      4.999999999999999, -4.330127018922194, -1.6666666666666663`}, {
      4.999999999999999, -4.330127018922194, -2.083333333333333}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -1.6666666666666665`}, {
      7.071067811865474, -3.5355339059327386`, -1.6666666666666665`}, {
      7.071067811865474, -3.5355339059327386`, -1.2499999999999998`}, {
      4.999999999999999, -4.330127018922194, -1.2499999999999998`}, {
      4.999999999999999, -4.330127018922194, -1.6666666666666665`}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, -1.25}, {
      7.071067811865474, -3.5355339059327386`, -1.25}, {
      7.071067811865474, -3.5355339059327386`, -0.8333333333333333}, {
      4.999999999999999, -4.330127018922194, -0.8333333333333333}, {
      4.999999999999999, -4.330127018922194, -1.25}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -0.833333333333333}, {
      7.071067811865474, -3.5355339059327386`, -0.833333333333333}, {
      7.071067811865474, -3.5355339059327386`, -0.41666666666666635`}, {
      4.999999999999999, -4.330127018922194, -0.41666666666666635`}, {
      4.999999999999999, -4.330127018922194, -0.833333333333333}}], 
     Polygon3DBox[{{
      4.999999999999999, -4.330127018922194, -0.4166666666666661}, {
      7.071067811865474, -3.5355339059327386`, -0.4166666666666661}, {
      7.071067811865474, -3.5355339059327386`, 6.106226635438361*^-16}, {
      4.999999999999999, -4.330127018922194, 6.106226635438361*^-16}, {
      4.999999999999999, -4.330127018922194, -0.4166666666666661}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 0.}, {
      7.071067811865474, -3.5355339059327386`, 0.}, {
      7.071067811865474, -3.5355339059327386`, 0.4166666666666667}, {
      4.999999999999999, -4.330127018922194, 0.4166666666666667}, {
      4.999999999999999, -4.330127018922194, 0.}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      0.41666666666666696`}, {7.071067811865474, -3.5355339059327386`, 
      0.41666666666666696`}, {7.071067811865474, -3.5355339059327386`, 
      0.8333333333333337}, {4.999999999999999, -4.330127018922194, 
      0.8333333333333337}, {4.999999999999999, -4.330127018922194, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      0.8333333333333339}, {7.071067811865474, -3.5355339059327386`, 
      0.8333333333333339}, {7.071067811865474, -3.5355339059327386`, 
      1.2500000000000007`}, {4.999999999999999, -4.330127018922194, 
      1.2500000000000007`}, {4.999999999999999, -4.330127018922194, 
      0.8333333333333339}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 1.25}, {
      7.071067811865474, -3.5355339059327386`, 1.25}, {
      7.071067811865474, -3.5355339059327386`, 1.6666666666666667`}, {
      4.999999999999999, -4.330127018922194, 1.6666666666666667`}, {
      4.999999999999999, -4.330127018922194, 1.25}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      1.666666666666667}, {7.071067811865474, -3.5355339059327386`, 
      1.666666666666667}, {7.071067811865474, -3.5355339059327386`, 
      2.0833333333333335`}, {4.999999999999999, -4.330127018922194, 
      2.0833333333333335`}, {4.999999999999999, -4.330127018922194, 
      1.666666666666667}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      2.083333333333334}, {7.071067811865474, -3.5355339059327386`, 
      2.083333333333334}, {7.071067811865474, -3.5355339059327386`, 
      2.5000000000000004`}, {4.999999999999999, -4.330127018922194, 
      2.5000000000000004`}, {4.999999999999999, -4.330127018922194, 
      2.083333333333334}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 2.5}, {
      7.071067811865474, -3.5355339059327386`, 2.5}, {
      7.071067811865474, -3.5355339059327386`, 2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, 2.9166666666666665`}, {
      4.999999999999999, -4.330127018922194, 2.5}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      2.916666666666667}, {7.071067811865474, -3.5355339059327386`, 
      2.916666666666667}, {7.071067811865474, -3.5355339059327386`, 
      3.3333333333333335`}, {4.999999999999999, -4.330127018922194, 
      3.3333333333333335`}, {4.999999999999999, -4.330127018922194, 
      2.916666666666667}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      3.333333333333334}, {7.071067811865474, -3.5355339059327386`, 
      3.333333333333334}, {7.071067811865474, -3.5355339059327386`, 
      3.7500000000000004`}, {4.999999999999999, -4.330127018922194, 
      3.7500000000000004`}, {4.999999999999999, -4.330127018922194, 
      3.333333333333334}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 3.75}, {
      7.071067811865474, -3.5355339059327386`, 3.75}, {
      7.071067811865474, -3.5355339059327386`, 4.166666666666667}, {
      4.999999999999999, -4.330127018922194, 4.166666666666667}, {
      4.999999999999999, -4.330127018922194, 3.75}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      4.166666666666668}, {7.071067811865474, -3.5355339059327386`, 
      4.166666666666668}, {7.071067811865474, -3.5355339059327386`, 
      4.583333333333335}, {4.999999999999999, -4.330127018922194, 
      4.583333333333335}, {4.999999999999999, -4.330127018922194, 
      4.166666666666668}}], 
     Polygon3DBox[{{4.999999999999999, -4.330127018922194, 
      4.583333333333334}, {7.071067811865474, -3.5355339059327386`, 
      4.583333333333334}, {7.071067811865474, -3.5355339059327386`, 
      5.000000000000001}, {4.999999999999999, -4.330127018922194, 
      5.000000000000001}, {4.999999999999999, -4.330127018922194, 
      4.583333333333334}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, -5.}, {
      8.660254037844386, -2.5, -5.}, {
      8.660254037844386, -2.5, -4.583333333333333}, {
      7.0710678118654755`, -3.5355339059327373`, -4.583333333333333}, {
      7.0710678118654755`, -3.5355339059327373`, -5.}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -4.583333333333333}, {
      8.660254037844386, -2.5, -4.583333333333333}, {
      8.660254037844386, -2.5, -4.166666666666666}, {
      7.0710678118654755`, -3.5355339059327373`, -4.166666666666666}, {
      7.0710678118654755`, -3.5355339059327373`, -4.583333333333333}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -4.166666666666667}, {
      8.660254037844386, -2.5, -4.166666666666667}, {
      8.660254037844386, -2.5, -3.7500000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, -3.7500000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, -4.166666666666667}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, -3.75}, {
      8.660254037844386, -2.5, -3.75}, {
      8.660254037844386, -2.5, -3.3333333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, -3.3333333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, -3.75}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -3.333333333333333}, {
      8.660254037844386, -2.5, -3.333333333333333}, {
      8.660254037844386, -2.5, -2.9166666666666665`}, {
      7.0710678118654755`, -3.5355339059327373`, -2.9166666666666665`}, {
      7.0710678118654755`, -3.5355339059327373`, -3.333333333333333}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -2.9166666666666665`}, {
      8.660254037844386, -2.5, -2.9166666666666665`}, {
      8.660254037844386, -2.5, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`, -2.9166666666666665`}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, -2.5}, {
      8.660254037844386, -2.5, -2.5}, {
      8.660254037844386, -2.5, -2.0833333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, -2.0833333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, -2.5}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -2.083333333333333}, {
      8.660254037844386, -2.5, -2.083333333333333}, {
      8.660254037844386, -2.5, -1.6666666666666663`}, {
      7.0710678118654755`, -3.5355339059327373`, -1.6666666666666663`}, {
      7.0710678118654755`, -3.5355339059327373`, -2.083333333333333}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -1.6666666666666665`}, {
      8.660254037844386, -2.5, -1.6666666666666665`}, {
      8.660254037844386, -2.5, -1.2499999999999998`}, {
      7.0710678118654755`, -3.5355339059327373`, -1.2499999999999998`}, {
      7.0710678118654755`, -3.5355339059327373`, -1.6666666666666665`}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, -1.25}, {
      8.660254037844386, -2.5, -1.25}, {
      8.660254037844386, -2.5, -0.8333333333333333}, {
      7.0710678118654755`, -3.5355339059327373`, -0.8333333333333333}, {
      7.0710678118654755`, -3.5355339059327373`, -1.25}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -0.833333333333333}, {
      8.660254037844386, -2.5, -0.833333333333333}, {
      8.660254037844386, -2.5, -0.41666666666666635`}, {
      7.0710678118654755`, -3.5355339059327373`, -0.41666666666666635`}, {
      7.0710678118654755`, -3.5355339059327373`, -0.833333333333333}}], 
     Polygon3DBox[{{
      7.0710678118654755`, -3.5355339059327373`, -0.4166666666666661}, {
      8.660254037844386, -2.5, -0.4166666666666661}, {8.660254037844386, -2.5,
       6.106226635438361*^-16}, {7.0710678118654755`, -3.5355339059327373`, 
      6.106226635438361*^-16}, {
      7.0710678118654755`, -3.5355339059327373`, -0.4166666666666661}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 0.}, {
      8.660254037844386, -2.5, 0.}, {8.660254037844386, -2.5, 
      0.4166666666666667}, {7.0710678118654755`, -3.5355339059327373`, 
      0.4166666666666667}, {7.0710678118654755`, -3.5355339059327373`, 0.}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      0.41666666666666696`}, {8.660254037844386, -2.5, 
      0.41666666666666696`}, {8.660254037844386, -2.5, 0.8333333333333337}, {
      7.0710678118654755`, -3.5355339059327373`, 0.8333333333333337}, {
      7.0710678118654755`, -3.5355339059327373`, 0.41666666666666696`}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      0.8333333333333339}, {8.660254037844386, -2.5, 0.8333333333333339}, {
      8.660254037844386, -2.5, 1.2500000000000007`}, {
      7.0710678118654755`, -3.5355339059327373`, 1.2500000000000007`}, {
      7.0710678118654755`, -3.5355339059327373`, 0.8333333333333339}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 1.25}, {
      8.660254037844386, -2.5, 1.25}, {8.660254037844386, -2.5, 
      1.6666666666666667`}, {7.0710678118654755`, -3.5355339059327373`, 
      1.6666666666666667`}, {7.0710678118654755`, -3.5355339059327373`, 
      1.25}}], Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      1.666666666666667}, {8.660254037844386, -2.5, 1.666666666666667}, {
      8.660254037844386, -2.5, 2.0833333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, 2.0833333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, 1.666666666666667}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      2.083333333333334}, {8.660254037844386, -2.5, 2.083333333333334}, {
      8.660254037844386, -2.5, 2.5000000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, 2.5000000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, 2.083333333333334}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 2.5}, {
      8.660254037844386, -2.5, 2.5}, {8.660254037844386, -2.5, 
      2.9166666666666665`}, {7.0710678118654755`, -3.5355339059327373`, 
      2.9166666666666665`}, {7.0710678118654755`, -3.5355339059327373`, 
      2.5}}], Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      2.916666666666667}, {8.660254037844386, -2.5, 2.916666666666667}, {
      8.660254037844386, -2.5, 3.3333333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, 3.3333333333333335`}, {
      7.0710678118654755`, -3.5355339059327373`, 2.916666666666667}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      3.333333333333334}, {8.660254037844386, -2.5, 3.333333333333334}, {
      8.660254037844386, -2.5, 3.7500000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, 3.7500000000000004`}, {
      7.0710678118654755`, -3.5355339059327373`, 3.333333333333334}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 3.75}, {
      8.660254037844386, -2.5, 3.75}, {8.660254037844386, -2.5, 
      4.166666666666667}, {7.0710678118654755`, -3.5355339059327373`, 
      4.166666666666667}, {7.0710678118654755`, -3.5355339059327373`, 3.75}}],
      Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      4.166666666666668}, {8.660254037844386, -2.5, 4.166666666666668}, {
      8.660254037844386, -2.5, 4.583333333333335}, {
      7.0710678118654755`, -3.5355339059327373`, 4.583333333333335}, {
      7.0710678118654755`, -3.5355339059327373`, 4.166666666666668}}], 
     Polygon3DBox[{{7.0710678118654755`, -3.5355339059327373`, 
      4.583333333333334}, {8.660254037844386, -2.5, 4.583333333333334}, {
      8.660254037844386, -2.5, 5.000000000000001}, {
      7.0710678118654755`, -3.5355339059327373`, 5.000000000000001}, {
      7.0710678118654755`, -3.5355339059327373`, 4.583333333333334}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, -5.}, {
      9.659258262890681, -1.2940952255126055`, -5.}, {
      9.659258262890681, -1.2940952255126055`, -4.583333333333333}, {
      8.660254037844386, -2.500000000000001, -4.583333333333333}, {
      8.660254037844386, -2.500000000000001, -5.}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -4.583333333333333}, {
      9.659258262890681, -1.2940952255126055`, -4.583333333333333}, {
      9.659258262890681, -1.2940952255126055`, -4.166666666666666}, {
      8.660254037844386, -2.500000000000001, -4.166666666666666}, {
      8.660254037844386, -2.500000000000001, -4.583333333333333}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -4.166666666666667}, {
      9.659258262890681, -1.2940952255126055`, -4.166666666666667}, {
      9.659258262890681, -1.2940952255126055`, -3.7500000000000004`}, {
      8.660254037844386, -2.500000000000001, -3.7500000000000004`}, {
      8.660254037844386, -2.500000000000001, -4.166666666666667}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, -3.75}, {
      9.659258262890681, -1.2940952255126055`, -3.75}, {
      9.659258262890681, -1.2940952255126055`, -3.3333333333333335`}, {
      8.660254037844386, -2.500000000000001, -3.3333333333333335`}, {
      8.660254037844386, -2.500000000000001, -3.75}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -3.333333333333333}, {
      9.659258262890681, -1.2940952255126055`, -3.333333333333333}, {
      9.659258262890681, -1.2940952255126055`, -2.9166666666666665`}, {
      8.660254037844386, -2.500000000000001, -2.9166666666666665`}, {
      8.660254037844386, -2.500000000000001, -3.333333333333333}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -2.9166666666666665`}, {
      9.659258262890681, -1.2940952255126055`, -2.9166666666666665`}, {
      9.659258262890681, -1.2940952255126055`, -2.5}, {
      8.660254037844386, -2.500000000000001, -2.5}, {
      8.660254037844386, -2.500000000000001, -2.9166666666666665`}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, -2.5}, {
      9.659258262890681, -1.2940952255126055`, -2.5}, {
      9.659258262890681, -1.2940952255126055`, -2.0833333333333335`}, {
      8.660254037844386, -2.500000000000001, -2.0833333333333335`}, {
      8.660254037844386, -2.500000000000001, -2.5}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -2.083333333333333}, {
      9.659258262890681, -1.2940952255126055`, -2.083333333333333}, {
      9.659258262890681, -1.2940952255126055`, -1.6666666666666663`}, {
      8.660254037844386, -2.500000000000001, -1.6666666666666663`}, {
      8.660254037844386, -2.500000000000001, -2.083333333333333}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -1.6666666666666665`}, {
      9.659258262890681, -1.2940952255126055`, -1.6666666666666665`}, {
      9.659258262890681, -1.2940952255126055`, -1.2499999999999998`}, {
      8.660254037844386, -2.500000000000001, -1.2499999999999998`}, {
      8.660254037844386, -2.500000000000001, -1.6666666666666665`}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, -1.25}, {
      9.659258262890681, -1.2940952255126055`, -1.25}, {
      9.659258262890681, -1.2940952255126055`, -0.8333333333333333}, {
      8.660254037844386, -2.500000000000001, -0.8333333333333333}, {
      8.660254037844386, -2.500000000000001, -1.25}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -0.833333333333333}, {
      9.659258262890681, -1.2940952255126055`, -0.833333333333333}, {
      9.659258262890681, -1.2940952255126055`, -0.41666666666666635`}, {
      8.660254037844386, -2.500000000000001, -0.41666666666666635`}, {
      8.660254037844386, -2.500000000000001, -0.833333333333333}}], 
     Polygon3DBox[{{
      8.660254037844386, -2.500000000000001, -0.4166666666666661}, {
      9.659258262890681, -1.2940952255126055`, -0.4166666666666661}, {
      9.659258262890681, -1.2940952255126055`, 6.106226635438361*^-16}, {
      8.660254037844386, -2.500000000000001, 6.106226635438361*^-16}, {
      8.660254037844386, -2.500000000000001, -0.4166666666666661}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 0.}, {
      9.659258262890681, -1.2940952255126055`, 0.}, {
      9.659258262890681, -1.2940952255126055`, 0.4166666666666667}, {
      8.660254037844386, -2.500000000000001, 0.4166666666666667}, {
      8.660254037844386, -2.500000000000001, 0.}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      0.41666666666666696`}, {9.659258262890681, -1.2940952255126055`, 
      0.41666666666666696`}, {9.659258262890681, -1.2940952255126055`, 
      0.8333333333333337}, {8.660254037844386, -2.500000000000001, 
      0.8333333333333337}, {8.660254037844386, -2.500000000000001, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      0.8333333333333339}, {9.659258262890681, -1.2940952255126055`, 
      0.8333333333333339}, {9.659258262890681, -1.2940952255126055`, 
      1.2500000000000007`}, {8.660254037844386, -2.500000000000001, 
      1.2500000000000007`}, {8.660254037844386, -2.500000000000001, 
      0.8333333333333339}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 1.25}, {
      9.659258262890681, -1.2940952255126055`, 1.25}, {
      9.659258262890681, -1.2940952255126055`, 1.6666666666666667`}, {
      8.660254037844386, -2.500000000000001, 1.6666666666666667`}, {
      8.660254037844386, -2.500000000000001, 1.25}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      1.666666666666667}, {9.659258262890681, -1.2940952255126055`, 
      1.666666666666667}, {9.659258262890681, -1.2940952255126055`, 
      2.0833333333333335`}, {8.660254037844386, -2.500000000000001, 
      2.0833333333333335`}, {8.660254037844386, -2.500000000000001, 
      1.666666666666667}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      2.083333333333334}, {9.659258262890681, -1.2940952255126055`, 
      2.083333333333334}, {9.659258262890681, -1.2940952255126055`, 
      2.5000000000000004`}, {8.660254037844386, -2.500000000000001, 
      2.5000000000000004`}, {8.660254037844386, -2.500000000000001, 
      2.083333333333334}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 2.5}, {
      9.659258262890681, -1.2940952255126055`, 2.5}, {
      9.659258262890681, -1.2940952255126055`, 2.9166666666666665`}, {
      8.660254037844386, -2.500000000000001, 2.9166666666666665`}, {
      8.660254037844386, -2.500000000000001, 2.5}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      2.916666666666667}, {9.659258262890681, -1.2940952255126055`, 
      2.916666666666667}, {9.659258262890681, -1.2940952255126055`, 
      3.3333333333333335`}, {8.660254037844386, -2.500000000000001, 
      3.3333333333333335`}, {8.660254037844386, -2.500000000000001, 
      2.916666666666667}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      3.333333333333334}, {9.659258262890681, -1.2940952255126055`, 
      3.333333333333334}, {9.659258262890681, -1.2940952255126055`, 
      3.7500000000000004`}, {8.660254037844386, -2.500000000000001, 
      3.7500000000000004`}, {8.660254037844386, -2.500000000000001, 
      3.333333333333334}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 3.75}, {
      9.659258262890681, -1.2940952255126055`, 3.75}, {
      9.659258262890681, -1.2940952255126055`, 4.166666666666667}, {
      8.660254037844386, -2.500000000000001, 4.166666666666667}, {
      8.660254037844386, -2.500000000000001, 3.75}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      4.166666666666668}, {9.659258262890681, -1.2940952255126055`, 
      4.166666666666668}, {9.659258262890681, -1.2940952255126055`, 
      4.583333333333335}, {8.660254037844386, -2.500000000000001, 
      4.583333333333335}, {8.660254037844386, -2.500000000000001, 
      4.166666666666668}}], 
     Polygon3DBox[{{8.660254037844386, -2.500000000000001, 
      4.583333333333334}, {9.659258262890681, -1.2940952255126055`, 
      4.583333333333334}, {9.659258262890681, -1.2940952255126055`, 
      5.000000000000001}, {8.660254037844386, -2.500000000000001, 
      5.000000000000001}, {8.660254037844386, -2.500000000000001, 
      4.583333333333334}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, -5.}, {
      10., -8.326672684688674*^-16, -5.}, {
      10., -8.326672684688674*^-16, -4.583333333333333}, {
      9.659258262890681, -1.2940952255126046`, -4.583333333333333}, {
      9.659258262890681, -1.2940952255126046`, -5.}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -4.583333333333333}, {
      10., -8.326672684688674*^-16, -4.583333333333333}, {
      10., -8.326672684688674*^-16, -4.166666666666666}, {
      9.659258262890681, -1.2940952255126046`, -4.166666666666666}, {
      9.659258262890681, -1.2940952255126046`, -4.583333333333333}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -4.166666666666667}, {
      10., -8.326672684688674*^-16, -4.166666666666667}, {
      10., -8.326672684688674*^-16, -3.7500000000000004`}, {
      9.659258262890681, -1.2940952255126046`, -3.7500000000000004`}, {
      9.659258262890681, -1.2940952255126046`, -4.166666666666667}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, -3.75}, {
      10., -8.326672684688674*^-16, -3.75}, {
      10., -8.326672684688674*^-16, -3.3333333333333335`}, {
      9.659258262890681, -1.2940952255126046`, -3.3333333333333335`}, {
      9.659258262890681, -1.2940952255126046`, -3.75}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -3.333333333333333}, {
      10., -8.326672684688674*^-16, -3.333333333333333}, {
      10., -8.326672684688674*^-16, -2.9166666666666665`}, {
      9.659258262890681, -1.2940952255126046`, -2.9166666666666665`}, {
      9.659258262890681, -1.2940952255126046`, -3.333333333333333}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -2.9166666666666665`}, {
      10., -8.326672684688674*^-16, -2.9166666666666665`}, {
      10., -8.326672684688674*^-16, -2.5}, {
      9.659258262890681, -1.2940952255126046`, -2.5}, {
      9.659258262890681, -1.2940952255126046`, -2.9166666666666665`}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, -2.5}, {
      10., -8.326672684688674*^-16, -2.5}, {
      10., -8.326672684688674*^-16, -2.0833333333333335`}, {
      9.659258262890681, -1.2940952255126046`, -2.0833333333333335`}, {
      9.659258262890681, -1.2940952255126046`, -2.5}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -2.083333333333333}, {
      10., -8.326672684688674*^-16, -2.083333333333333}, {
      10., -8.326672684688674*^-16, -1.6666666666666663`}, {
      9.659258262890681, -1.2940952255126046`, -1.6666666666666663`}, {
      9.659258262890681, -1.2940952255126046`, -2.083333333333333}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -1.6666666666666665`}, {
      10., -8.326672684688674*^-16, -1.6666666666666665`}, {
      10., -8.326672684688674*^-16, -1.2499999999999998`}, {
      9.659258262890681, -1.2940952255126046`, -1.2499999999999998`}, {
      9.659258262890681, -1.2940952255126046`, -1.6666666666666665`}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, -1.25}, {
      10., -8.326672684688674*^-16, -1.25}, {
      10., -8.326672684688674*^-16, -0.8333333333333333}, {
      9.659258262890681, -1.2940952255126046`, -0.8333333333333333}, {
      9.659258262890681, -1.2940952255126046`, -1.25}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -0.833333333333333}, {
      10., -8.326672684688674*^-16, -0.833333333333333}, {
      10., -8.326672684688674*^-16, -0.41666666666666635`}, {
      9.659258262890681, -1.2940952255126046`, -0.41666666666666635`}, {
      9.659258262890681, -1.2940952255126046`, -0.833333333333333}}], 
     Polygon3DBox[{{
      9.659258262890681, -1.2940952255126046`, -0.4166666666666661}, {
      10., -8.326672684688674*^-16, -0.4166666666666661}, {
      10., -8.326672684688674*^-16, 6.106226635438361*^-16}, {
      9.659258262890681, -1.2940952255126046`, 6.106226635438361*^-16}, {
      9.659258262890681, -1.2940952255126046`, -0.4166666666666661}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 0.}, {
      10., -8.326672684688674*^-16, 0.}, {10., -8.326672684688674*^-16, 
      0.4166666666666667}, {9.659258262890681, -1.2940952255126046`, 
      0.4166666666666667}, {9.659258262890681, -1.2940952255126046`, 0.}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      0.41666666666666696`}, {10., -8.326672684688674*^-16, 
      0.41666666666666696`}, {10., -8.326672684688674*^-16, 
      0.8333333333333337}, {9.659258262890681, -1.2940952255126046`, 
      0.8333333333333337}, {9.659258262890681, -1.2940952255126046`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      0.8333333333333339}, {10., -8.326672684688674*^-16, 
      0.8333333333333339}, {10., -8.326672684688674*^-16, 
      1.2500000000000007`}, {9.659258262890681, -1.2940952255126046`, 
      1.2500000000000007`}, {9.659258262890681, -1.2940952255126046`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 1.25}, {
      10., -8.326672684688674*^-16, 1.25}, {10., -8.326672684688674*^-16, 
      1.6666666666666667`}, {9.659258262890681, -1.2940952255126046`, 
      1.6666666666666667`}, {9.659258262890681, -1.2940952255126046`, 1.25}}],
      Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      1.666666666666667}, {10., -8.326672684688674*^-16, 1.666666666666667}, {
      10., -8.326672684688674*^-16, 2.0833333333333335`}, {
      9.659258262890681, -1.2940952255126046`, 2.0833333333333335`}, {
      9.659258262890681, -1.2940952255126046`, 1.666666666666667}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      2.083333333333334}, {10., -8.326672684688674*^-16, 2.083333333333334}, {
      10., -8.326672684688674*^-16, 2.5000000000000004`}, {
      9.659258262890681, -1.2940952255126046`, 2.5000000000000004`}, {
      9.659258262890681, -1.2940952255126046`, 2.083333333333334}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 2.5}, {
      10., -8.326672684688674*^-16, 2.5}, {10., -8.326672684688674*^-16, 
      2.9166666666666665`}, {9.659258262890681, -1.2940952255126046`, 
      2.9166666666666665`}, {9.659258262890681, -1.2940952255126046`, 2.5}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      2.916666666666667}, {10., -8.326672684688674*^-16, 2.916666666666667}, {
      10., -8.326672684688674*^-16, 3.3333333333333335`}, {
      9.659258262890681, -1.2940952255126046`, 3.3333333333333335`}, {
      9.659258262890681, -1.2940952255126046`, 2.916666666666667}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      3.333333333333334}, {10., -8.326672684688674*^-16, 3.333333333333334}, {
      10., -8.326672684688674*^-16, 3.7500000000000004`}, {
      9.659258262890681, -1.2940952255126046`, 3.7500000000000004`}, {
      9.659258262890681, -1.2940952255126046`, 3.333333333333334}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 3.75}, {
      10., -8.326672684688674*^-16, 3.75}, {10., -8.326672684688674*^-16, 
      4.166666666666667}, {9.659258262890681, -1.2940952255126046`, 
      4.166666666666667}, {9.659258262890681, -1.2940952255126046`, 3.75}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      4.166666666666668}, {10., -8.326672684688674*^-16, 4.166666666666668}, {
      10., -8.326672684688674*^-16, 4.583333333333335}, {
      9.659258262890681, -1.2940952255126046`, 4.583333333333335}, {
      9.659258262890681, -1.2940952255126046`, 4.166666666666668}}], 
     Polygon3DBox[{{9.659258262890681, -1.2940952255126046`, 
      4.583333333333334}, {10., -8.326672684688674*^-16, 4.583333333333334}, {
      10., -8.326672684688674*^-16, 5.000000000000001}, {
      9.659258262890681, -1.2940952255126046`, 5.000000000000001}, {
      9.659258262890681, -1.2940952255126046`, 4.583333333333334}}], 
     Polygon3DBox[{{10., 0., -5.}, {9.659258262890683, 
      1.2940952255126037`, -5.}, {9.659258262890683, 
      1.2940952255126037`, -4.583333333333333}, {10., 
      0., -4.583333333333333}, {10., 0., -5.}}], 
     Polygon3DBox[{{10., 0., -4.583333333333333}, {9.659258262890683, 
      1.2940952255126037`, -4.583333333333333}, {9.659258262890683, 
      1.2940952255126037`, -4.166666666666666}, {10., 
      0., -4.166666666666666}, {10., 0., -4.583333333333333}}], 
     Polygon3DBox[{{10., 0., -4.166666666666667}, {9.659258262890683, 
      1.2940952255126037`, -4.166666666666667}, {9.659258262890683, 
      1.2940952255126037`, -3.7500000000000004`}, {10., 
      0., -3.7500000000000004`}, {10., 0., -4.166666666666667}}], 
     Polygon3DBox[{{10., 0., -3.75}, {9.659258262890683, 
      1.2940952255126037`, -3.75}, {9.659258262890683, 
      1.2940952255126037`, -3.3333333333333335`}, {10., 
      0., -3.3333333333333335`}, {10., 0., -3.75}}], 
     Polygon3DBox[{{10., 0., -3.333333333333333}, {9.659258262890683, 
      1.2940952255126037`, -3.333333333333333}, {9.659258262890683, 
      1.2940952255126037`, -2.9166666666666665`}, {10., 
      0., -2.9166666666666665`}, {10., 0., -3.333333333333333}}], 
     Polygon3DBox[{{10., 0., -2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126037`, -2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126037`, -2.5}, {10., 0., -2.5}, {10., 
      0., -2.9166666666666665`}}], 
     Polygon3DBox[{{10., 0., -2.5}, {9.659258262890683, 
      1.2940952255126037`, -2.5}, {9.659258262890683, 
      1.2940952255126037`, -2.0833333333333335`}, {10., 
      0., -2.0833333333333335`}, {10., 0., -2.5}}], 
     Polygon3DBox[{{10., 0., -2.083333333333333}, {9.659258262890683, 
      1.2940952255126037`, -2.083333333333333}, {9.659258262890683, 
      1.2940952255126037`, -1.6666666666666663`}, {10., 
      0., -1.6666666666666663`}, {10., 0., -2.083333333333333}}], 
     Polygon3DBox[{{10., 0., -1.6666666666666665`}, {9.659258262890683, 
      1.2940952255126037`, -1.6666666666666665`}, {9.659258262890683, 
      1.2940952255126037`, -1.2499999999999998`}, {10., 
      0., -1.2499999999999998`}, {10., 0., -1.6666666666666665`}}], 
     Polygon3DBox[{{10., 0., -1.25}, {9.659258262890683, 
      1.2940952255126037`, -1.25}, {9.659258262890683, 
      1.2940952255126037`, -0.8333333333333333}, {10., 
      0., -0.8333333333333333}, {10., 0., -1.25}}], 
     Polygon3DBox[{{10., 0., -0.833333333333333}, {9.659258262890683, 
      1.2940952255126037`, -0.833333333333333}, {9.659258262890683, 
      1.2940952255126037`, -0.41666666666666635`}, {10., 
      0., -0.41666666666666635`}, {10., 0., -0.833333333333333}}], 
     Polygon3DBox[{{10., 0., -0.4166666666666661}, {9.659258262890683, 
      1.2940952255126037`, -0.4166666666666661}, {9.659258262890683, 
      1.2940952255126037`, 6.106226635438361*^-16}, {10., 0., 
      6.106226635438361*^-16}, {10., 0., -0.4166666666666661}}], 
     Polygon3DBox[{{10., 0., 0.}, {9.659258262890683, 1.2940952255126037`, 
      0.}, {9.659258262890683, 1.2940952255126037`, 0.4166666666666667}, {10.,
       0., 0.4166666666666667}, {10., 0., 0.}}], 
     Polygon3DBox[{{10., 0., 0.41666666666666696`}, {9.659258262890683, 
      1.2940952255126037`, 0.41666666666666696`}, {9.659258262890683, 
      1.2940952255126037`, 0.8333333333333337}, {10., 0., 
      0.8333333333333337}, {10., 0., 0.41666666666666696`}}], 
     Polygon3DBox[{{10., 0., 0.8333333333333339}, {9.659258262890683, 
      1.2940952255126037`, 0.8333333333333339}, {9.659258262890683, 
      1.2940952255126037`, 1.2500000000000007`}, {10., 0., 
      1.2500000000000007`}, {10., 0., 0.8333333333333339}}], 
     Polygon3DBox[{{10., 0., 1.25}, {9.659258262890683, 1.2940952255126037`, 
      1.25}, {9.659258262890683, 1.2940952255126037`, 1.6666666666666667`}, {
      10., 0., 1.6666666666666667`}, {10., 0., 1.25}}], 
     Polygon3DBox[{{10., 0., 1.666666666666667}, {9.659258262890683, 
      1.2940952255126037`, 1.666666666666667}, {9.659258262890683, 
      1.2940952255126037`, 2.0833333333333335`}, {10., 0., 
      2.0833333333333335`}, {10., 0., 1.666666666666667}}], 
     Polygon3DBox[{{10., 0., 2.083333333333334}, {9.659258262890683, 
      1.2940952255126037`, 2.083333333333334}, {9.659258262890683, 
      1.2940952255126037`, 2.5000000000000004`}, {10., 0., 
      2.5000000000000004`}, {10., 0., 2.083333333333334}}], 
     Polygon3DBox[{{10., 0., 2.5}, {9.659258262890683, 1.2940952255126037`, 
      2.5}, {9.659258262890683, 1.2940952255126037`, 2.9166666666666665`}, {
      10., 0., 2.9166666666666665`}, {10., 0., 2.5}}], 
     Polygon3DBox[{{10., 0., 2.916666666666667}, {9.659258262890683, 
      1.2940952255126037`, 2.916666666666667}, {9.659258262890683, 
      1.2940952255126037`, 3.3333333333333335`}, {10., 0., 
      3.3333333333333335`}, {10., 0., 2.916666666666667}}], 
     Polygon3DBox[{{10., 0., 3.333333333333334}, {9.659258262890683, 
      1.2940952255126037`, 3.333333333333334}, {9.659258262890683, 
      1.2940952255126037`, 3.7500000000000004`}, {10., 0., 
      3.7500000000000004`}, {10., 0., 3.333333333333334}}], 
     Polygon3DBox[{{10., 0., 3.75}, {9.659258262890683, 1.2940952255126037`, 
      3.75}, {9.659258262890683, 1.2940952255126037`, 4.166666666666667}, {
      10., 0., 4.166666666666667}, {10., 0., 3.75}}], 
     Polygon3DBox[{{10., 0., 4.166666666666668}, {9.659258262890683, 
      1.2940952255126037`, 4.166666666666668}, {9.659258262890683, 
      1.2940952255126037`, 4.583333333333335}, {10., 0., 4.583333333333335}, {
      10., 0., 4.166666666666668}}], 
     Polygon3DBox[{{10., 0., 4.583333333333334}, {9.659258262890683, 
      1.2940952255126037`, 4.583333333333334}, {9.659258262890683, 
      1.2940952255126037`, 5.000000000000001}, {10., 0., 5.000000000000001}, {
      10., 0., 4.583333333333334}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, -5.}, {
      8.660254037844389, 2.4999999999999982`, -5.}, {8.660254037844389, 
      2.4999999999999982`, -4.583333333333333}, {9.659258262890683, 
      1.2940952255126024`, -4.583333333333333}, {9.659258262890683, 
      1.2940952255126024`, -5.}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -4.583333333333333}, {8.660254037844389, 
      2.4999999999999982`, -4.583333333333333}, {8.660254037844389, 
      2.4999999999999982`, -4.166666666666666}, {9.659258262890683, 
      1.2940952255126024`, -4.166666666666666}, {9.659258262890683, 
      1.2940952255126024`, -4.583333333333333}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -4.166666666666667}, {8.660254037844389, 
      2.4999999999999982`, -4.166666666666667}, {8.660254037844389, 
      2.4999999999999982`, -3.7500000000000004`}, {9.659258262890683, 
      1.2940952255126024`, -3.7500000000000004`}, {9.659258262890683, 
      1.2940952255126024`, -4.166666666666667}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, -3.75}, {
      8.660254037844389, 2.4999999999999982`, -3.75}, {8.660254037844389, 
      2.4999999999999982`, -3.3333333333333335`}, {9.659258262890683, 
      1.2940952255126024`, -3.3333333333333335`}, {9.659258262890683, 
      1.2940952255126024`, -3.75}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -3.333333333333333}, {8.660254037844389, 
      2.4999999999999982`, -3.333333333333333}, {8.660254037844389, 
      2.4999999999999982`, -2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126024`, -2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126024`, -3.333333333333333}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -2.9166666666666665`}, {8.660254037844389, 
      2.4999999999999982`, -2.9166666666666665`}, {8.660254037844389, 
      2.4999999999999982`, -2.5}, {9.659258262890683, 
      1.2940952255126024`, -2.5}, {9.659258262890683, 
      1.2940952255126024`, -2.9166666666666665`}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, -2.5}, {
      8.660254037844389, 2.4999999999999982`, -2.5}, {8.660254037844389, 
      2.4999999999999982`, -2.0833333333333335`}, {9.659258262890683, 
      1.2940952255126024`, -2.0833333333333335`}, {9.659258262890683, 
      1.2940952255126024`, -2.5}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -2.083333333333333}, {8.660254037844389, 
      2.4999999999999982`, -2.083333333333333}, {8.660254037844389, 
      2.4999999999999982`, -1.6666666666666663`}, {9.659258262890683, 
      1.2940952255126024`, -1.6666666666666663`}, {9.659258262890683, 
      1.2940952255126024`, -2.083333333333333}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -1.6666666666666665`}, {8.660254037844389, 
      2.4999999999999982`, -1.6666666666666665`}, {8.660254037844389, 
      2.4999999999999982`, -1.2499999999999998`}, {9.659258262890683, 
      1.2940952255126024`, -1.2499999999999998`}, {9.659258262890683, 
      1.2940952255126024`, -1.6666666666666665`}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, -1.25}, {
      8.660254037844389, 2.4999999999999982`, -1.25}, {8.660254037844389, 
      2.4999999999999982`, -0.8333333333333333}, {9.659258262890683, 
      1.2940952255126024`, -0.8333333333333333}, {9.659258262890683, 
      1.2940952255126024`, -1.25}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -0.833333333333333}, {8.660254037844389, 
      2.4999999999999982`, -0.833333333333333}, {8.660254037844389, 
      2.4999999999999982`, -0.41666666666666635`}, {9.659258262890683, 
      1.2940952255126024`, -0.41666666666666635`}, {9.659258262890683, 
      1.2940952255126024`, -0.833333333333333}}], 
     Polygon3DBox[{{9.659258262890683, 
      1.2940952255126024`, -0.4166666666666661}, {8.660254037844389, 
      2.4999999999999982`, -0.4166666666666661}, {8.660254037844389, 
      2.4999999999999982`, 6.106226635438361*^-16}, {9.659258262890683, 
      1.2940952255126024`, 6.106226635438361*^-16}, {9.659258262890683, 
      1.2940952255126024`, -0.4166666666666661}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 0.}, {
      8.660254037844389, 2.4999999999999982`, 0.}, {8.660254037844389, 
      2.4999999999999982`, 0.4166666666666667}, {9.659258262890683, 
      1.2940952255126024`, 0.4166666666666667}, {9.659258262890683, 
      1.2940952255126024`, 0.}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      0.41666666666666696`}, {8.660254037844389, 2.4999999999999982`, 
      0.41666666666666696`}, {8.660254037844389, 2.4999999999999982`, 
      0.8333333333333337}, {9.659258262890683, 1.2940952255126024`, 
      0.8333333333333337}, {9.659258262890683, 1.2940952255126024`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      0.8333333333333339}, {8.660254037844389, 2.4999999999999982`, 
      0.8333333333333339}, {8.660254037844389, 2.4999999999999982`, 
      1.2500000000000007`}, {9.659258262890683, 1.2940952255126024`, 
      1.2500000000000007`}, {9.659258262890683, 1.2940952255126024`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 1.25}, {
      8.660254037844389, 2.4999999999999982`, 1.25}, {8.660254037844389, 
      2.4999999999999982`, 1.6666666666666667`}, {9.659258262890683, 
      1.2940952255126024`, 1.6666666666666667`}, {9.659258262890683, 
      1.2940952255126024`, 1.25}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      1.666666666666667}, {8.660254037844389, 2.4999999999999982`, 
      1.666666666666667}, {8.660254037844389, 2.4999999999999982`, 
      2.0833333333333335`}, {9.659258262890683, 1.2940952255126024`, 
      2.0833333333333335`}, {9.659258262890683, 1.2940952255126024`, 
      1.666666666666667}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      2.083333333333334}, {8.660254037844389, 2.4999999999999982`, 
      2.083333333333334}, {8.660254037844389, 2.4999999999999982`, 
      2.5000000000000004`}, {9.659258262890683, 1.2940952255126024`, 
      2.5000000000000004`}, {9.659258262890683, 1.2940952255126024`, 
      2.083333333333334}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 2.5}, {
      8.660254037844389, 2.4999999999999982`, 2.5}, {8.660254037844389, 
      2.4999999999999982`, 2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126024`, 2.9166666666666665`}, {9.659258262890683, 
      1.2940952255126024`, 2.5}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      2.916666666666667}, {8.660254037844389, 2.4999999999999982`, 
      2.916666666666667}, {8.660254037844389, 2.4999999999999982`, 
      3.3333333333333335`}, {9.659258262890683, 1.2940952255126024`, 
      3.3333333333333335`}, {9.659258262890683, 1.2940952255126024`, 
      2.916666666666667}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      3.333333333333334}, {8.660254037844389, 2.4999999999999982`, 
      3.333333333333334}, {8.660254037844389, 2.4999999999999982`, 
      3.7500000000000004`}, {9.659258262890683, 1.2940952255126024`, 
      3.7500000000000004`}, {9.659258262890683, 1.2940952255126024`, 
      3.333333333333334}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 3.75}, {
      8.660254037844389, 2.4999999999999982`, 3.75}, {8.660254037844389, 
      2.4999999999999982`, 4.166666666666667}, {9.659258262890683, 
      1.2940952255126024`, 4.166666666666667}, {9.659258262890683, 
      1.2940952255126024`, 3.75}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      4.166666666666668}, {8.660254037844389, 2.4999999999999982`, 
      4.166666666666668}, {8.660254037844389, 2.4999999999999982`, 
      4.583333333333335}, {9.659258262890683, 1.2940952255126024`, 
      4.583333333333335}, {9.659258262890683, 1.2940952255126024`, 
      4.166666666666668}}], 
     Polygon3DBox[{{9.659258262890683, 1.2940952255126024`, 
      4.583333333333334}, {8.660254037844389, 2.4999999999999982`, 
      4.583333333333334}, {8.660254037844389, 2.4999999999999982`, 
      5.000000000000001}, {9.659258262890683, 1.2940952255126024`, 
      5.000000000000001}, {9.659258262890683, 1.2940952255126024`, 
      4.583333333333334}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, -5.}, {
      7.071067811865477, 3.535533905932737, -5.}, {7.071067811865477, 
      3.535533905932737, -4.583333333333333}, {8.660254037844387, 
      2.499999999999999, -4.583333333333333}, {8.660254037844387, 
      2.499999999999999, -5.}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -4.583333333333333}, {7.071067811865477, 
      3.535533905932737, -4.583333333333333}, {7.071067811865477, 
      3.535533905932737, -4.166666666666666}, {8.660254037844387, 
      2.499999999999999, -4.166666666666666}, {8.660254037844387, 
      2.499999999999999, -4.583333333333333}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -4.166666666666667}, {7.071067811865477, 
      3.535533905932737, -4.166666666666667}, {7.071067811865477, 
      3.535533905932737, -3.7500000000000004`}, {8.660254037844387, 
      2.499999999999999, -3.7500000000000004`}, {8.660254037844387, 
      2.499999999999999, -4.166666666666667}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, -3.75}, {
      7.071067811865477, 3.535533905932737, -3.75}, {7.071067811865477, 
      3.535533905932737, -3.3333333333333335`}, {8.660254037844387, 
      2.499999999999999, -3.3333333333333335`}, {8.660254037844387, 
      2.499999999999999, -3.75}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -3.333333333333333}, {7.071067811865477, 
      3.535533905932737, -3.333333333333333}, {7.071067811865477, 
      3.535533905932737, -2.9166666666666665`}, {8.660254037844387, 
      2.499999999999999, -2.9166666666666665`}, {8.660254037844387, 
      2.499999999999999, -3.333333333333333}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -2.9166666666666665`}, {7.071067811865477, 
      3.535533905932737, -2.9166666666666665`}, {7.071067811865477, 
      3.535533905932737, -2.5}, {8.660254037844387, 
      2.499999999999999, -2.5}, {8.660254037844387, 
      2.499999999999999, -2.9166666666666665`}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, -2.5}, {
      7.071067811865477, 3.535533905932737, -2.5}, {7.071067811865477, 
      3.535533905932737, -2.0833333333333335`}, {8.660254037844387, 
      2.499999999999999, -2.0833333333333335`}, {8.660254037844387, 
      2.499999999999999, -2.5}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -2.083333333333333}, {7.071067811865477, 
      3.535533905932737, -2.083333333333333}, {7.071067811865477, 
      3.535533905932737, -1.6666666666666663`}, {8.660254037844387, 
      2.499999999999999, -1.6666666666666663`}, {8.660254037844387, 
      2.499999999999999, -2.083333333333333}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -1.6666666666666665`}, {7.071067811865477, 
      3.535533905932737, -1.6666666666666665`}, {7.071067811865477, 
      3.535533905932737, -1.2499999999999998`}, {8.660254037844387, 
      2.499999999999999, -1.2499999999999998`}, {8.660254037844387, 
      2.499999999999999, -1.6666666666666665`}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, -1.25}, {
      7.071067811865477, 3.535533905932737, -1.25}, {7.071067811865477, 
      3.535533905932737, -0.8333333333333333}, {8.660254037844387, 
      2.499999999999999, -0.8333333333333333}, {8.660254037844387, 
      2.499999999999999, -1.25}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -0.833333333333333}, {7.071067811865477, 
      3.535533905932737, -0.833333333333333}, {7.071067811865477, 
      3.535533905932737, -0.41666666666666635`}, {8.660254037844387, 
      2.499999999999999, -0.41666666666666635`}, {8.660254037844387, 
      2.499999999999999, -0.833333333333333}}], 
     Polygon3DBox[{{8.660254037844387, 
      2.499999999999999, -0.4166666666666661}, {7.071067811865477, 
      3.535533905932737, -0.4166666666666661}, {7.071067811865477, 
      3.535533905932737, 6.106226635438361*^-16}, {8.660254037844387, 
      2.499999999999999, 6.106226635438361*^-16}, {8.660254037844387, 
      2.499999999999999, -0.4166666666666661}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 0.}, {
      7.071067811865477, 3.535533905932737, 0.}, {7.071067811865477, 
      3.535533905932737, 0.4166666666666667}, {8.660254037844387, 
      2.499999999999999, 0.4166666666666667}, {8.660254037844387, 
      2.499999999999999, 0.}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      0.41666666666666696`}, {7.071067811865477, 3.535533905932737, 
      0.41666666666666696`}, {7.071067811865477, 3.535533905932737, 
      0.8333333333333337}, {8.660254037844387, 2.499999999999999, 
      0.8333333333333337}, {8.660254037844387, 2.499999999999999, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      0.8333333333333339}, {7.071067811865477, 3.535533905932737, 
      0.8333333333333339}, {7.071067811865477, 3.535533905932737, 
      1.2500000000000007`}, {8.660254037844387, 2.499999999999999, 
      1.2500000000000007`}, {8.660254037844387, 2.499999999999999, 
      0.8333333333333339}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 1.25}, {
      7.071067811865477, 3.535533905932737, 1.25}, {7.071067811865477, 
      3.535533905932737, 1.6666666666666667`}, {8.660254037844387, 
      2.499999999999999, 1.6666666666666667`}, {8.660254037844387, 
      2.499999999999999, 1.25}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      1.666666666666667}, {7.071067811865477, 3.535533905932737, 
      1.666666666666667}, {7.071067811865477, 3.535533905932737, 
      2.0833333333333335`}, {8.660254037844387, 2.499999999999999, 
      2.0833333333333335`}, {8.660254037844387, 2.499999999999999, 
      1.666666666666667}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      2.083333333333334}, {7.071067811865477, 3.535533905932737, 
      2.083333333333334}, {7.071067811865477, 3.535533905932737, 
      2.5000000000000004`}, {8.660254037844387, 2.499999999999999, 
      2.5000000000000004`}, {8.660254037844387, 2.499999999999999, 
      2.083333333333334}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 2.5}, {
      7.071067811865477, 3.535533905932737, 2.5}, {7.071067811865477, 
      3.535533905932737, 2.9166666666666665`}, {8.660254037844387, 
      2.499999999999999, 2.9166666666666665`}, {8.660254037844387, 
      2.499999999999999, 2.5}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      2.916666666666667}, {7.071067811865477, 3.535533905932737, 
      2.916666666666667}, {7.071067811865477, 3.535533905932737, 
      3.3333333333333335`}, {8.660254037844387, 2.499999999999999, 
      3.3333333333333335`}, {8.660254037844387, 2.499999999999999, 
      2.916666666666667}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      3.333333333333334}, {7.071067811865477, 3.535533905932737, 
      3.333333333333334}, {7.071067811865477, 3.535533905932737, 
      3.7500000000000004`}, {8.660254037844387, 2.499999999999999, 
      3.7500000000000004`}, {8.660254037844387, 2.499999999999999, 
      3.333333333333334}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 3.75}, {
      7.071067811865477, 3.535533905932737, 3.75}, {7.071067811865477, 
      3.535533905932737, 4.166666666666667}, {8.660254037844387, 
      2.499999999999999, 4.166666666666667}, {8.660254037844387, 
      2.499999999999999, 3.75}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      4.166666666666668}, {7.071067811865477, 3.535533905932737, 
      4.166666666666668}, {7.071067811865477, 3.535533905932737, 
      4.583333333333335}, {8.660254037844387, 2.499999999999999, 
      4.583333333333335}, {8.660254037844387, 2.499999999999999, 
      4.166666666666668}}], 
     Polygon3DBox[{{8.660254037844387, 2.499999999999999, 
      4.583333333333334}, {7.071067811865477, 3.535533905932737, 
      4.583333333333334}, {7.071067811865477, 3.535533905932737, 
      5.000000000000001}, {8.660254037844387, 2.499999999999999, 
      5.000000000000001}, {8.660254037844387, 2.499999999999999, 
      4.583333333333334}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, -5.}, {
      5.000000000000004, 4.330127018922192, -5.}, {5.000000000000004, 
      4.330127018922192, -4.583333333333333}, {7.071067811865479, 
      3.535533905932736, -4.583333333333333}, {7.071067811865479, 
      3.535533905932736, -5.}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -4.583333333333333}, {5.000000000000004, 
      4.330127018922192, -4.583333333333333}, {5.000000000000004, 
      4.330127018922192, -4.166666666666666}, {7.071067811865479, 
      3.535533905932736, -4.166666666666666}, {7.071067811865479, 
      3.535533905932736, -4.583333333333333}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -4.166666666666667}, {5.000000000000004, 
      4.330127018922192, -4.166666666666667}, {5.000000000000004, 
      4.330127018922192, -3.7500000000000004`}, {7.071067811865479, 
      3.535533905932736, -3.7500000000000004`}, {7.071067811865479, 
      3.535533905932736, -4.166666666666667}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, -3.75}, {
      5.000000000000004, 4.330127018922192, -3.75}, {5.000000000000004, 
      4.330127018922192, -3.3333333333333335`}, {7.071067811865479, 
      3.535533905932736, -3.3333333333333335`}, {7.071067811865479, 
      3.535533905932736, -3.75}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -3.333333333333333}, {5.000000000000004, 
      4.330127018922192, -3.333333333333333}, {5.000000000000004, 
      4.330127018922192, -2.9166666666666665`}, {7.071067811865479, 
      3.535533905932736, -2.9166666666666665`}, {7.071067811865479, 
      3.535533905932736, -3.333333333333333}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -2.9166666666666665`}, {5.000000000000004, 
      4.330127018922192, -2.9166666666666665`}, {5.000000000000004, 
      4.330127018922192, -2.5}, {7.071067811865479, 
      3.535533905932736, -2.5}, {7.071067811865479, 
      3.535533905932736, -2.9166666666666665`}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, -2.5}, {
      5.000000000000004, 4.330127018922192, -2.5}, {5.000000000000004, 
      4.330127018922192, -2.0833333333333335`}, {7.071067811865479, 
      3.535533905932736, -2.0833333333333335`}, {7.071067811865479, 
      3.535533905932736, -2.5}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -2.083333333333333}, {5.000000000000004, 
      4.330127018922192, -2.083333333333333}, {5.000000000000004, 
      4.330127018922192, -1.6666666666666663`}, {7.071067811865479, 
      3.535533905932736, -1.6666666666666663`}, {7.071067811865479, 
      3.535533905932736, -2.083333333333333}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -1.6666666666666665`}, {5.000000000000004, 
      4.330127018922192, -1.6666666666666665`}, {5.000000000000004, 
      4.330127018922192, -1.2499999999999998`}, {7.071067811865479, 
      3.535533905932736, -1.2499999999999998`}, {7.071067811865479, 
      3.535533905932736, -1.6666666666666665`}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, -1.25}, {
      5.000000000000004, 4.330127018922192, -1.25}, {5.000000000000004, 
      4.330127018922192, -0.8333333333333333}, {7.071067811865479, 
      3.535533905932736, -0.8333333333333333}, {7.071067811865479, 
      3.535533905932736, -1.25}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -0.833333333333333}, {5.000000000000004, 
      4.330127018922192, -0.833333333333333}, {5.000000000000004, 
      4.330127018922192, -0.41666666666666635`}, {7.071067811865479, 
      3.535533905932736, -0.41666666666666635`}, {7.071067811865479, 
      3.535533905932736, -0.833333333333333}}], 
     Polygon3DBox[{{7.071067811865479, 
      3.535533905932736, -0.4166666666666661}, {5.000000000000004, 
      4.330127018922192, -0.4166666666666661}, {5.000000000000004, 
      4.330127018922192, 6.106226635438361*^-16}, {7.071067811865479, 
      3.535533905932736, 6.106226635438361*^-16}, {7.071067811865479, 
      3.535533905932736, -0.4166666666666661}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 0.}, {
      5.000000000000004, 4.330127018922192, 0.}, {5.000000000000004, 
      4.330127018922192, 0.4166666666666667}, {7.071067811865479, 
      3.535533905932736, 0.4166666666666667}, {7.071067811865479, 
      3.535533905932736, 0.}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      0.41666666666666696`}, {5.000000000000004, 4.330127018922192, 
      0.41666666666666696`}, {5.000000000000004, 4.330127018922192, 
      0.8333333333333337}, {7.071067811865479, 3.535533905932736, 
      0.8333333333333337}, {7.071067811865479, 3.535533905932736, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      0.8333333333333339}, {5.000000000000004, 4.330127018922192, 
      0.8333333333333339}, {5.000000000000004, 4.330127018922192, 
      1.2500000000000007`}, {7.071067811865479, 3.535533905932736, 
      1.2500000000000007`}, {7.071067811865479, 3.535533905932736, 
      0.8333333333333339}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 1.25}, {
      5.000000000000004, 4.330127018922192, 1.25}, {5.000000000000004, 
      4.330127018922192, 1.6666666666666667`}, {7.071067811865479, 
      3.535533905932736, 1.6666666666666667`}, {7.071067811865479, 
      3.535533905932736, 1.25}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      1.666666666666667}, {5.000000000000004, 4.330127018922192, 
      1.666666666666667}, {5.000000000000004, 4.330127018922192, 
      2.0833333333333335`}, {7.071067811865479, 3.535533905932736, 
      2.0833333333333335`}, {7.071067811865479, 3.535533905932736, 
      1.666666666666667}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      2.083333333333334}, {5.000000000000004, 4.330127018922192, 
      2.083333333333334}, {5.000000000000004, 4.330127018922192, 
      2.5000000000000004`}, {7.071067811865479, 3.535533905932736, 
      2.5000000000000004`}, {7.071067811865479, 3.535533905932736, 
      2.083333333333334}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 2.5}, {
      5.000000000000004, 4.330127018922192, 2.5}, {5.000000000000004, 
      4.330127018922192, 2.9166666666666665`}, {7.071067811865479, 
      3.535533905932736, 2.9166666666666665`}, {7.071067811865479, 
      3.535533905932736, 2.5}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      2.916666666666667}, {5.000000000000004, 4.330127018922192, 
      2.916666666666667}, {5.000000000000004, 4.330127018922192, 
      3.3333333333333335`}, {7.071067811865479, 3.535533905932736, 
      3.3333333333333335`}, {7.071067811865479, 3.535533905932736, 
      2.916666666666667}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      3.333333333333334}, {5.000000000000004, 4.330127018922192, 
      3.333333333333334}, {5.000000000000004, 4.330127018922192, 
      3.7500000000000004`}, {7.071067811865479, 3.535533905932736, 
      3.7500000000000004`}, {7.071067811865479, 3.535533905932736, 
      3.333333333333334}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 3.75}, {
      5.000000000000004, 4.330127018922192, 3.75}, {5.000000000000004, 
      4.330127018922192, 4.166666666666667}, {7.071067811865479, 
      3.535533905932736, 4.166666666666667}, {7.071067811865479, 
      3.535533905932736, 3.75}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      4.166666666666668}, {5.000000000000004, 4.330127018922192, 
      4.166666666666668}, {5.000000000000004, 4.330127018922192, 
      4.583333333333335}, {7.071067811865479, 3.535533905932736, 
      4.583333333333335}, {7.071067811865479, 3.535533905932736, 
      4.166666666666668}}], 
     Polygon3DBox[{{7.071067811865479, 3.535533905932736, 
      4.583333333333334}, {5.000000000000004, 4.330127018922192, 
      4.583333333333334}, {5.000000000000004, 4.330127018922192, 
      5.000000000000001}, {7.071067811865479, 3.535533905932736, 
      5.000000000000001}, {7.071067811865479, 3.535533905932736, 
      4.583333333333334}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, -5.}, {
      2.588190451025212, 4.829629131445341, -5.}, {2.588190451025212, 
      4.829629131445341, -4.583333333333333}, {5.0000000000000036`, 
      4.330127018922193, -4.583333333333333}, {5.0000000000000036`, 
      4.330127018922193, -5.}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -4.583333333333333}, {2.588190451025212, 
      4.829629131445341, -4.583333333333333}, {2.588190451025212, 
      4.829629131445341, -4.166666666666666}, {5.0000000000000036`, 
      4.330127018922193, -4.166666666666666}, {5.0000000000000036`, 
      4.330127018922193, -4.583333333333333}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -4.166666666666667}, {2.588190451025212, 
      4.829629131445341, -4.166666666666667}, {2.588190451025212, 
      4.829629131445341, -3.7500000000000004`}, {5.0000000000000036`, 
      4.330127018922193, -3.7500000000000004`}, {5.0000000000000036`, 
      4.330127018922193, -4.166666666666667}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, -3.75}, {
      2.588190451025212, 4.829629131445341, -3.75}, {2.588190451025212, 
      4.829629131445341, -3.3333333333333335`}, {5.0000000000000036`, 
      4.330127018922193, -3.3333333333333335`}, {5.0000000000000036`, 
      4.330127018922193, -3.75}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -3.333333333333333}, {2.588190451025212, 
      4.829629131445341, -3.333333333333333}, {2.588190451025212, 
      4.829629131445341, -2.9166666666666665`}, {5.0000000000000036`, 
      4.330127018922193, -2.9166666666666665`}, {5.0000000000000036`, 
      4.330127018922193, -3.333333333333333}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -2.9166666666666665`}, {2.588190451025212, 
      4.829629131445341, -2.9166666666666665`}, {2.588190451025212, 
      4.829629131445341, -2.5}, {5.0000000000000036`, 
      4.330127018922193, -2.5}, {5.0000000000000036`, 
      4.330127018922193, -2.9166666666666665`}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, -2.5}, {
      2.588190451025212, 4.829629131445341, -2.5}, {2.588190451025212, 
      4.829629131445341, -2.0833333333333335`}, {5.0000000000000036`, 
      4.330127018922193, -2.0833333333333335`}, {5.0000000000000036`, 
      4.330127018922193, -2.5}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -2.083333333333333}, {2.588190451025212, 
      4.829629131445341, -2.083333333333333}, {2.588190451025212, 
      4.829629131445341, -1.6666666666666663`}, {5.0000000000000036`, 
      4.330127018922193, -1.6666666666666663`}, {5.0000000000000036`, 
      4.330127018922193, -2.083333333333333}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -1.6666666666666665`}, {2.588190451025212, 
      4.829629131445341, -1.6666666666666665`}, {2.588190451025212, 
      4.829629131445341, -1.2499999999999998`}, {5.0000000000000036`, 
      4.330127018922193, -1.2499999999999998`}, {5.0000000000000036`, 
      4.330127018922193, -1.6666666666666665`}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, -1.25}, {
      2.588190451025212, 4.829629131445341, -1.25}, {2.588190451025212, 
      4.829629131445341, -0.8333333333333333}, {5.0000000000000036`, 
      4.330127018922193, -0.8333333333333333}, {5.0000000000000036`, 
      4.330127018922193, -1.25}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -0.833333333333333}, {2.588190451025212, 
      4.829629131445341, -0.833333333333333}, {2.588190451025212, 
      4.829629131445341, -0.41666666666666635`}, {5.0000000000000036`, 
      4.330127018922193, -0.41666666666666635`}, {5.0000000000000036`, 
      4.330127018922193, -0.833333333333333}}], 
     Polygon3DBox[{{5.0000000000000036`, 
      4.330127018922193, -0.4166666666666661}, {2.588190451025212, 
      4.829629131445341, -0.4166666666666661}, {2.588190451025212, 
      4.829629131445341, 6.106226635438361*^-16}, {5.0000000000000036`, 
      4.330127018922193, 6.106226635438361*^-16}, {5.0000000000000036`, 
      4.330127018922193, -0.4166666666666661}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 0.}, {
      2.588190451025212, 4.829629131445341, 0.}, {2.588190451025212, 
      4.829629131445341, 0.4166666666666667}, {5.0000000000000036`, 
      4.330127018922193, 0.4166666666666667}, {5.0000000000000036`, 
      4.330127018922193, 0.}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      0.41666666666666696`}, {2.588190451025212, 4.829629131445341, 
      0.41666666666666696`}, {2.588190451025212, 4.829629131445341, 
      0.8333333333333337}, {5.0000000000000036`, 4.330127018922193, 
      0.8333333333333337}, {5.0000000000000036`, 4.330127018922193, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      0.8333333333333339}, {2.588190451025212, 4.829629131445341, 
      0.8333333333333339}, {2.588190451025212, 4.829629131445341, 
      1.2500000000000007`}, {5.0000000000000036`, 4.330127018922193, 
      1.2500000000000007`}, {5.0000000000000036`, 4.330127018922193, 
      0.8333333333333339}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 1.25}, {
      2.588190451025212, 4.829629131445341, 1.25}, {2.588190451025212, 
      4.829629131445341, 1.6666666666666667`}, {5.0000000000000036`, 
      4.330127018922193, 1.6666666666666667`}, {5.0000000000000036`, 
      4.330127018922193, 1.25}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      1.666666666666667}, {2.588190451025212, 4.829629131445341, 
      1.666666666666667}, {2.588190451025212, 4.829629131445341, 
      2.0833333333333335`}, {5.0000000000000036`, 4.330127018922193, 
      2.0833333333333335`}, {5.0000000000000036`, 4.330127018922193, 
      1.666666666666667}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      2.083333333333334}, {2.588190451025212, 4.829629131445341, 
      2.083333333333334}, {2.588190451025212, 4.829629131445341, 
      2.5000000000000004`}, {5.0000000000000036`, 4.330127018922193, 
      2.5000000000000004`}, {5.0000000000000036`, 4.330127018922193, 
      2.083333333333334}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 2.5}, {
      2.588190451025212, 4.829629131445341, 2.5}, {2.588190451025212, 
      4.829629131445341, 2.9166666666666665`}, {5.0000000000000036`, 
      4.330127018922193, 2.9166666666666665`}, {5.0000000000000036`, 
      4.330127018922193, 2.5}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      2.916666666666667}, {2.588190451025212, 4.829629131445341, 
      2.916666666666667}, {2.588190451025212, 4.829629131445341, 
      3.3333333333333335`}, {5.0000000000000036`, 4.330127018922193, 
      3.3333333333333335`}, {5.0000000000000036`, 4.330127018922193, 
      2.916666666666667}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      3.333333333333334}, {2.588190451025212, 4.829629131445341, 
      3.333333333333334}, {2.588190451025212, 4.829629131445341, 
      3.7500000000000004`}, {5.0000000000000036`, 4.330127018922193, 
      3.7500000000000004`}, {5.0000000000000036`, 4.330127018922193, 
      3.333333333333334}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 3.75}, {
      2.588190451025212, 4.829629131445341, 3.75}, {2.588190451025212, 
      4.829629131445341, 4.166666666666667}, {5.0000000000000036`, 
      4.330127018922193, 4.166666666666667}, {5.0000000000000036`, 
      4.330127018922193, 3.75}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      4.166666666666668}, {2.588190451025212, 4.829629131445341, 
      4.166666666666668}, {2.588190451025212, 4.829629131445341, 
      4.583333333333335}, {5.0000000000000036`, 4.330127018922193, 
      4.583333333333335}, {5.0000000000000036`, 4.330127018922193, 
      4.166666666666668}}], 
     Polygon3DBox[{{5.0000000000000036`, 4.330127018922193, 
      4.583333333333334}, {2.588190451025212, 4.829629131445341, 
      4.583333333333334}, {2.588190451025212, 4.829629131445341, 
      5.000000000000001}, {5.0000000000000036`, 4.330127018922193, 
      5.000000000000001}, {5.0000000000000036`, 4.330127018922193, 
      4.583333333333334}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, -5.}, {
      7.273661547324617*^-15, 5., -5.}, {7.273661547324617*^-15, 
      5., -4.583333333333333}, {2.588190451025214, 
      4.829629131445341, -4.583333333333333}, {2.588190451025214, 
      4.829629131445341, -5.}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -4.583333333333333}, {7.273661547324617*^-15, 
      5., -4.583333333333333}, {7.273661547324617*^-15, 
      5., -4.166666666666666}, {2.588190451025214, 
      4.829629131445341, -4.166666666666666}, {2.588190451025214, 
      4.829629131445341, -4.583333333333333}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -4.166666666666667}, {7.273661547324617*^-15, 
      5., -4.166666666666667}, {7.273661547324617*^-15, 
      5., -3.7500000000000004`}, {2.588190451025214, 
      4.829629131445341, -3.7500000000000004`}, {2.588190451025214, 
      4.829629131445341, -4.166666666666667}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, -3.75}, {
      7.273661547324617*^-15, 5., -3.75}, {7.273661547324617*^-15, 
      5., -3.3333333333333335`}, {2.588190451025214, 
      4.829629131445341, -3.3333333333333335`}, {2.588190451025214, 
      4.829629131445341, -3.75}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -3.333333333333333}, {7.273661547324617*^-15, 
      5., -3.333333333333333}, {7.273661547324617*^-15, 
      5., -2.9166666666666665`}, {2.588190451025214, 
      4.829629131445341, -2.9166666666666665`}, {2.588190451025214, 
      4.829629131445341, -3.333333333333333}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -2.9166666666666665`}, {7.273661547324617*^-15, 
      5., -2.9166666666666665`}, {7.273661547324617*^-15, 5., -2.5}, {
      2.588190451025214, 4.829629131445341, -2.5}, {2.588190451025214, 
      4.829629131445341, -2.9166666666666665`}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, -2.5}, {
      7.273661547324617*^-15, 5., -2.5}, {7.273661547324617*^-15, 
      5., -2.0833333333333335`}, {2.588190451025214, 
      4.829629131445341, -2.0833333333333335`}, {2.588190451025214, 
      4.829629131445341, -2.5}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -2.083333333333333}, {7.273661547324617*^-15, 
      5., -2.083333333333333}, {7.273661547324617*^-15, 
      5., -1.6666666666666663`}, {2.588190451025214, 
      4.829629131445341, -1.6666666666666663`}, {2.588190451025214, 
      4.829629131445341, -2.083333333333333}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -1.6666666666666665`}, {7.273661547324617*^-15, 
      5., -1.6666666666666665`}, {7.273661547324617*^-15, 
      5., -1.2499999999999998`}, {2.588190451025214, 
      4.829629131445341, -1.2499999999999998`}, {2.588190451025214, 
      4.829629131445341, -1.6666666666666665`}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, -1.25}, {
      7.273661547324617*^-15, 5., -1.25}, {7.273661547324617*^-15, 
      5., -0.8333333333333333}, {2.588190451025214, 
      4.829629131445341, -0.8333333333333333}, {2.588190451025214, 
      4.829629131445341, -1.25}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -0.833333333333333}, {7.273661547324617*^-15, 
      5., -0.833333333333333}, {7.273661547324617*^-15, 
      5., -0.41666666666666635`}, {2.588190451025214, 
      4.829629131445341, -0.41666666666666635`}, {2.588190451025214, 
      4.829629131445341, -0.833333333333333}}], 
     Polygon3DBox[{{2.588190451025214, 
      4.829629131445341, -0.4166666666666661}, {7.273661547324617*^-15, 
      5., -0.4166666666666661}, {7.273661547324617*^-15, 5., 
      6.106226635438361*^-16}, {2.588190451025214, 4.829629131445341, 
      6.106226635438361*^-16}, {2.588190451025214, 
      4.829629131445341, -0.4166666666666661}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 0.}, {
      7.273661547324617*^-15, 5., 0.}, {7.273661547324617*^-15, 5., 
      0.4166666666666667}, {2.588190451025214, 4.829629131445341, 
      0.4166666666666667}, {2.588190451025214, 4.829629131445341, 0.}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      0.41666666666666696`}, {7.273661547324617*^-15, 5., 
      0.41666666666666696`}, {7.273661547324617*^-15, 5., 
      0.8333333333333337}, {2.588190451025214, 4.829629131445341, 
      0.8333333333333337}, {2.588190451025214, 4.829629131445341, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      0.8333333333333339}, {7.273661547324617*^-15, 5., 0.8333333333333339}, {
      7.273661547324617*^-15, 5., 1.2500000000000007`}, {2.588190451025214, 
      4.829629131445341, 1.2500000000000007`}, {2.588190451025214, 
      4.829629131445341, 0.8333333333333339}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 1.25}, {
      7.273661547324617*^-15, 5., 1.25}, {7.273661547324617*^-15, 5., 
      1.6666666666666667`}, {2.588190451025214, 4.829629131445341, 
      1.6666666666666667`}, {2.588190451025214, 4.829629131445341, 1.25}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      1.666666666666667}, {7.273661547324617*^-15, 5., 1.666666666666667}, {
      7.273661547324617*^-15, 5., 2.0833333333333335`}, {2.588190451025214, 
      4.829629131445341, 2.0833333333333335`}, {2.588190451025214, 
      4.829629131445341, 1.666666666666667}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      2.083333333333334}, {7.273661547324617*^-15, 5., 2.083333333333334}, {
      7.273661547324617*^-15, 5., 2.5000000000000004`}, {2.588190451025214, 
      4.829629131445341, 2.5000000000000004`}, {2.588190451025214, 
      4.829629131445341, 2.083333333333334}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 2.5}, {
      7.273661547324617*^-15, 5., 2.5}, {7.273661547324617*^-15, 5., 
      2.9166666666666665`}, {2.588190451025214, 4.829629131445341, 
      2.9166666666666665`}, {2.588190451025214, 4.829629131445341, 2.5}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      2.916666666666667}, {7.273661547324617*^-15, 5., 2.916666666666667}, {
      7.273661547324617*^-15, 5., 3.3333333333333335`}, {2.588190451025214, 
      4.829629131445341, 3.3333333333333335`}, {2.588190451025214, 
      4.829629131445341, 2.916666666666667}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      3.333333333333334}, {7.273661547324617*^-15, 5., 3.333333333333334}, {
      7.273661547324617*^-15, 5., 3.7500000000000004`}, {2.588190451025214, 
      4.829629131445341, 3.7500000000000004`}, {2.588190451025214, 
      4.829629131445341, 3.333333333333334}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 3.75}, {
      7.273661547324617*^-15, 5., 3.75}, {7.273661547324617*^-15, 5., 
      4.166666666666667}, {2.588190451025214, 4.829629131445341, 
      4.166666666666667}, {2.588190451025214, 4.829629131445341, 3.75}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      4.166666666666668}, {7.273661547324617*^-15, 5., 4.166666666666668}, {
      7.273661547324617*^-15, 5., 4.583333333333335}, {2.588190451025214, 
      4.829629131445341, 4.583333333333335}, {2.588190451025214, 
      4.829629131445341, 4.166666666666668}}], 
     Polygon3DBox[{{2.588190451025214, 4.829629131445341, 
      4.583333333333334}, {7.273661547324617*^-15, 5., 4.583333333333334}, {
      7.273661547324617*^-15, 5., 5.000000000000001}, {2.588190451025214, 
      4.829629131445341, 5.000000000000001}, {2.588190451025214, 
      4.829629131445341, 4.583333333333334}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., -5.}, {-2.5881904510252065`, 
      4.8296291314453415`, -5.}, {-2.5881904510252065`, 
      4.8296291314453415`, -4.583333333333333}, {6.123233995736766*^-16, 
      5., -4.583333333333333}, {6.123233995736766*^-16, 5., -5.}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -4.583333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -4.583333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -4.166666666666666}, {6.123233995736766*^-16, 
      5., -4.166666666666666}, {6.123233995736766*^-16, 
      5., -4.583333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -4.166666666666667}, {-2.5881904510252065`, 
      4.8296291314453415`, -4.166666666666667}, {-2.5881904510252065`, 
      4.8296291314453415`, -3.7500000000000004`}, {6.123233995736766*^-16, 
      5., -3.7500000000000004`}, {6.123233995736766*^-16, 
      5., -4.166666666666667}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., -3.75}, {-2.5881904510252065`,
       4.8296291314453415`, -3.75}, {-2.5881904510252065`, 
      4.8296291314453415`, -3.3333333333333335`}, {6.123233995736766*^-16, 
      5., -3.3333333333333335`}, {6.123233995736766*^-16, 5., -3.75}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -3.333333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -3.333333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.9166666666666665`}, {6.123233995736766*^-16, 
      5., -2.9166666666666665`}, {6.123233995736766*^-16, 
      5., -3.333333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -2.9166666666666665`}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.9166666666666665`}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.5}, {6.123233995736766*^-16, 5., -2.5}, {
      6.123233995736766*^-16, 5., -2.9166666666666665`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., -2.5}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.5}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.0833333333333335`}, {6.123233995736766*^-16, 
      5., -2.0833333333333335`}, {6.123233995736766*^-16, 5., -2.5}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -2.083333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -2.083333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -1.6666666666666663`}, {6.123233995736766*^-16, 
      5., -1.6666666666666663`}, {6.123233995736766*^-16, 
      5., -2.083333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -1.6666666666666665`}, {-2.5881904510252065`, 
      4.8296291314453415`, -1.6666666666666665`}, {-2.5881904510252065`, 
      4.8296291314453415`, -1.2499999999999998`}, {6.123233995736766*^-16, 
      5., -1.2499999999999998`}, {6.123233995736766*^-16, 
      5., -1.6666666666666665`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., -1.25}, {-2.5881904510252065`,
       4.8296291314453415`, -1.25}, {-2.5881904510252065`, 
      4.8296291314453415`, -0.8333333333333333}, {6.123233995736766*^-16, 
      5., -0.8333333333333333}, {6.123233995736766*^-16, 5., -1.25}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -0.833333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -0.833333333333333}, {-2.5881904510252065`, 
      4.8296291314453415`, -0.41666666666666635`}, {6.123233995736766*^-16, 
      5., -0.41666666666666635`}, {6.123233995736766*^-16, 
      5., -0.833333333333333}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 
      5., -0.4166666666666661}, {-2.5881904510252065`, 
      4.8296291314453415`, -0.4166666666666661}, {-2.5881904510252065`, 
      4.8296291314453415`, 6.106226635438361*^-16}, {6.123233995736766*^-16, 
      5., 6.106226635438361*^-16}, {6.123233995736766*^-16, 
      5., -0.4166666666666661}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 0.}, {-2.5881904510252065`, 
      4.8296291314453415`, 0.}, {-2.5881904510252065`, 4.8296291314453415`, 
      0.4166666666666667}, {6.123233995736766*^-16, 5., 0.4166666666666667}, {
      6.123233995736766*^-16, 5., 0.}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      0.41666666666666696`}, {-2.5881904510252065`, 4.8296291314453415`, 
      0.41666666666666696`}, {-2.5881904510252065`, 4.8296291314453415`, 
      0.8333333333333337}, {6.123233995736766*^-16, 5., 0.8333333333333337}, {
      6.123233995736766*^-16, 5., 0.41666666666666696`}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      0.8333333333333339}, {-2.5881904510252065`, 4.8296291314453415`, 
      0.8333333333333339}, {-2.5881904510252065`, 4.8296291314453415`, 
      1.2500000000000007`}, {6.123233995736766*^-16, 5., 
      1.2500000000000007`}, {6.123233995736766*^-16, 5., 
      0.8333333333333339}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 1.25}, {-2.5881904510252065`, 
      4.8296291314453415`, 1.25}, {-2.5881904510252065`, 4.8296291314453415`, 
      1.6666666666666667`}, {6.123233995736766*^-16, 5., 
      1.6666666666666667`}, {6.123233995736766*^-16, 5., 1.25}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      1.666666666666667}, {-2.5881904510252065`, 4.8296291314453415`, 
      1.666666666666667}, {-2.5881904510252065`, 4.8296291314453415`, 
      2.0833333333333335`}, {6.123233995736766*^-16, 5., 
      2.0833333333333335`}, {6.123233995736766*^-16, 5., 1.666666666666667}}],
      Polygon3DBox[{{6.123233995736766*^-16, 5., 
      2.083333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      2.083333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      2.5000000000000004`}, {6.123233995736766*^-16, 5., 
      2.5000000000000004`}, {6.123233995736766*^-16, 5., 2.083333333333334}}],
      Polygon3DBox[{{6.123233995736766*^-16, 5., 2.5}, {-2.5881904510252065`, 
      4.8296291314453415`, 2.5}, {-2.5881904510252065`, 4.8296291314453415`, 
      2.9166666666666665`}, {6.123233995736766*^-16, 5., 
      2.9166666666666665`}, {6.123233995736766*^-16, 5., 2.5}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      2.916666666666667}, {-2.5881904510252065`, 4.8296291314453415`, 
      2.916666666666667}, {-2.5881904510252065`, 4.8296291314453415`, 
      3.3333333333333335`}, {6.123233995736766*^-16, 5., 
      3.3333333333333335`}, {6.123233995736766*^-16, 5., 2.916666666666667}}],
      Polygon3DBox[{{6.123233995736766*^-16, 5., 
      3.333333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      3.333333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      3.7500000000000004`}, {6.123233995736766*^-16, 5., 
      3.7500000000000004`}, {6.123233995736766*^-16, 5., 3.333333333333334}}],
      Polygon3DBox[{{6.123233995736766*^-16, 5., 3.75}, {-2.5881904510252065`,
       4.8296291314453415`, 3.75}, {-2.5881904510252065`, 4.8296291314453415`,
       4.166666666666667}, {6.123233995736766*^-16, 5., 4.166666666666667}, {
      6.123233995736766*^-16, 5., 3.75}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      4.166666666666668}, {-2.5881904510252065`, 4.8296291314453415`, 
      4.166666666666668}, {-2.5881904510252065`, 4.8296291314453415`, 
      4.583333333333335}, {6.123233995736766*^-16, 5., 4.583333333333335}, {
      6.123233995736766*^-16, 5., 4.166666666666668}}], 
     Polygon3DBox[{{6.123233995736766*^-16, 5., 
      4.583333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      4.583333333333334}, {-2.5881904510252065`, 4.8296291314453415`, 
      5.000000000000001}, {6.123233995736766*^-16, 5., 5.000000000000001}, {
      6.123233995736766*^-16, 5., 4.583333333333334}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -5.}, {-4.999999999999998, 
      4.330127018922194, -5.}, {-4.999999999999998, 
      4.330127018922194, -4.583333333333333}, {-2.588190451025204, 
      4.829629131445342, -4.583333333333333}, {-2.588190451025204, 
      4.829629131445342, -5.}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -4.583333333333333}, {-4.999999999999998, 
      4.330127018922194, -4.583333333333333}, {-4.999999999999998, 
      4.330127018922194, -4.166666666666666}, {-2.588190451025204, 
      4.829629131445342, -4.166666666666666}, {-2.588190451025204, 
      4.829629131445342, -4.583333333333333}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -4.166666666666667}, {-4.999999999999998, 
      4.330127018922194, -4.166666666666667}, {-4.999999999999998, 
      4.330127018922194, -3.7500000000000004`}, {-2.588190451025204, 
      4.829629131445342, -3.7500000000000004`}, {-2.588190451025204, 
      4.829629131445342, -4.166666666666667}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -3.75}, {-4.999999999999998, 
      4.330127018922194, -3.75}, {-4.999999999999998, 
      4.330127018922194, -3.3333333333333335`}, {-2.588190451025204, 
      4.829629131445342, -3.3333333333333335`}, {-2.588190451025204, 
      4.829629131445342, -3.75}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -3.333333333333333}, {-4.999999999999998, 
      4.330127018922194, -3.333333333333333}, {-4.999999999999998, 
      4.330127018922194, -2.9166666666666665`}, {-2.588190451025204, 
      4.829629131445342, -2.9166666666666665`}, {-2.588190451025204, 
      4.829629131445342, -3.333333333333333}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -2.9166666666666665`}, {-4.999999999999998, 
      4.330127018922194, -2.9166666666666665`}, {-4.999999999999998, 
      4.330127018922194, -2.5}, {-2.588190451025204, 
      4.829629131445342, -2.5}, {-2.588190451025204, 
      4.829629131445342, -2.9166666666666665`}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -2.5}, {-4.999999999999998, 
      4.330127018922194, -2.5}, {-4.999999999999998, 
      4.330127018922194, -2.0833333333333335`}, {-2.588190451025204, 
      4.829629131445342, -2.0833333333333335`}, {-2.588190451025204, 
      4.829629131445342, -2.5}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -2.083333333333333}, {-4.999999999999998, 
      4.330127018922194, -2.083333333333333}, {-4.999999999999998, 
      4.330127018922194, -1.6666666666666663`}, {-2.588190451025204, 
      4.829629131445342, -1.6666666666666663`}, {-2.588190451025204, 
      4.829629131445342, -2.083333333333333}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -1.6666666666666665`}, {-4.999999999999998, 
      4.330127018922194, -1.6666666666666665`}, {-4.999999999999998, 
      4.330127018922194, -1.2499999999999998`}, {-2.588190451025204, 
      4.829629131445342, -1.2499999999999998`}, {-2.588190451025204, 
      4.829629131445342, -1.6666666666666665`}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -1.25}, {-4.999999999999998, 
      4.330127018922194, -1.25}, {-4.999999999999998, 
      4.330127018922194, -0.8333333333333333}, {-2.588190451025204, 
      4.829629131445342, -0.8333333333333333}, {-2.588190451025204, 
      4.829629131445342, -1.25}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -0.833333333333333}, {-4.999999999999998, 
      4.330127018922194, -0.833333333333333}, {-4.999999999999998, 
      4.330127018922194, -0.41666666666666635`}, {-2.588190451025204, 
      4.829629131445342, -0.41666666666666635`}, {-2.588190451025204, 
      4.829629131445342, -0.833333333333333}}], 
     Polygon3DBox[{{-2.588190451025204, 
      4.829629131445342, -0.4166666666666661}, {-4.999999999999998, 
      4.330127018922194, -0.4166666666666661}, {-4.999999999999998, 
      4.330127018922194, 6.106226635438361*^-16}, {-2.588190451025204, 
      4.829629131445342, 6.106226635438361*^-16}, {-2.588190451025204, 
      4.829629131445342, -0.4166666666666661}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      0.}, {-4.999999999999998, 4.330127018922194, 0.}, {-4.999999999999998, 
      4.330127018922194, 0.4166666666666667}, {-2.588190451025204, 
      4.829629131445342, 0.4166666666666667}, {-2.588190451025204, 
      4.829629131445342, 0.}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      0.41666666666666696`}, {-4.999999999999998, 4.330127018922194, 
      0.41666666666666696`}, {-4.999999999999998, 4.330127018922194, 
      0.8333333333333337}, {-2.588190451025204, 4.829629131445342, 
      0.8333333333333337}, {-2.588190451025204, 4.829629131445342, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      0.8333333333333339}, {-4.999999999999998, 4.330127018922194, 
      0.8333333333333339}, {-4.999999999999998, 4.330127018922194, 
      1.2500000000000007`}, {-2.588190451025204, 4.829629131445342, 
      1.2500000000000007`}, {-2.588190451025204, 4.829629131445342, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      1.25}, {-4.999999999999998, 4.330127018922194, 
      1.25}, {-4.999999999999998, 4.330127018922194, 
      1.6666666666666667`}, {-2.588190451025204, 4.829629131445342, 
      1.6666666666666667`}, {-2.588190451025204, 4.829629131445342, 1.25}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      1.666666666666667}, {-4.999999999999998, 4.330127018922194, 
      1.666666666666667}, {-4.999999999999998, 4.330127018922194, 
      2.0833333333333335`}, {-2.588190451025204, 4.829629131445342, 
      2.0833333333333335`}, {-2.588190451025204, 4.829629131445342, 
      1.666666666666667}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      2.083333333333334}, {-4.999999999999998, 4.330127018922194, 
      2.083333333333334}, {-4.999999999999998, 4.330127018922194, 
      2.5000000000000004`}, {-2.588190451025204, 4.829629131445342, 
      2.5000000000000004`}, {-2.588190451025204, 4.829629131445342, 
      2.083333333333334}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      2.5}, {-4.999999999999998, 4.330127018922194, 2.5}, {-4.999999999999998,
       4.330127018922194, 2.9166666666666665`}, {-2.588190451025204, 
      4.829629131445342, 2.9166666666666665`}, {-2.588190451025204, 
      4.829629131445342, 2.5}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      2.916666666666667}, {-4.999999999999998, 4.330127018922194, 
      2.916666666666667}, {-4.999999999999998, 4.330127018922194, 
      3.3333333333333335`}, {-2.588190451025204, 4.829629131445342, 
      3.3333333333333335`}, {-2.588190451025204, 4.829629131445342, 
      2.916666666666667}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      3.333333333333334}, {-4.999999999999998, 4.330127018922194, 
      3.333333333333334}, {-4.999999999999998, 4.330127018922194, 
      3.7500000000000004`}, {-2.588190451025204, 4.829629131445342, 
      3.7500000000000004`}, {-2.588190451025204, 4.829629131445342, 
      3.333333333333334}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      3.75}, {-4.999999999999998, 4.330127018922194, 
      3.75}, {-4.999999999999998, 4.330127018922194, 
      4.166666666666667}, {-2.588190451025204, 4.829629131445342, 
      4.166666666666667}, {-2.588190451025204, 4.829629131445342, 3.75}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      4.166666666666668}, {-4.999999999999998, 4.330127018922194, 
      4.166666666666668}, {-4.999999999999998, 4.330127018922194, 
      4.583333333333335}, {-2.588190451025204, 4.829629131445342, 
      4.583333333333335}, {-2.588190451025204, 4.829629131445342, 
      4.166666666666668}}], 
     Polygon3DBox[{{-2.588190451025204, 4.829629131445342, 
      4.583333333333334}, {-4.999999999999998, 4.330127018922194, 
      4.583333333333334}, {-4.999999999999998, 4.330127018922194, 
      5.000000000000001}, {-2.588190451025204, 4.829629131445342, 
      5.000000000000001}, {-2.588190451025204, 4.829629131445342, 
      4.583333333333334}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -5.}, {-7.071067811865471, 
      3.5355339059327395`, -5.}, {-7.071067811865471, 
      3.5355339059327395`, -4.583333333333333}, {-4.999999999999994, 
      4.3301270189221945`, -4.583333333333333}, {-4.999999999999994, 
      4.3301270189221945`, -5.}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -4.583333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -4.583333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -4.166666666666666}, {-4.999999999999994, 
      4.3301270189221945`, -4.166666666666666}, {-4.999999999999994, 
      4.3301270189221945`, -4.583333333333333}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -4.166666666666667}, {-7.071067811865471, 
      3.5355339059327395`, -4.166666666666667}, {-7.071067811865471, 
      3.5355339059327395`, -3.7500000000000004`}, {-4.999999999999994, 
      4.3301270189221945`, -3.7500000000000004`}, {-4.999999999999994, 
      4.3301270189221945`, -4.166666666666667}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -3.75}, {-7.071067811865471, 
      3.5355339059327395`, -3.75}, {-7.071067811865471, 
      3.5355339059327395`, -3.3333333333333335`}, {-4.999999999999994, 
      4.3301270189221945`, -3.3333333333333335`}, {-4.999999999999994, 
      4.3301270189221945`, -3.75}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -3.333333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -3.333333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -2.9166666666666665`}, {-4.999999999999994, 
      4.3301270189221945`, -2.9166666666666665`}, {-4.999999999999994, 
      4.3301270189221945`, -3.333333333333333}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -2.9166666666666665`}, {-7.071067811865471, 
      3.5355339059327395`, -2.9166666666666665`}, {-7.071067811865471, 
      3.5355339059327395`, -2.5}, {-4.999999999999994, 
      4.3301270189221945`, -2.5}, {-4.999999999999994, 
      4.3301270189221945`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -2.5}, {-7.071067811865471, 
      3.5355339059327395`, -2.5}, {-7.071067811865471, 
      3.5355339059327395`, -2.0833333333333335`}, {-4.999999999999994, 
      4.3301270189221945`, -2.0833333333333335`}, {-4.999999999999994, 
      4.3301270189221945`, -2.5}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -2.083333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -2.083333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -1.6666666666666663`}, {-4.999999999999994, 
      4.3301270189221945`, -1.6666666666666663`}, {-4.999999999999994, 
      4.3301270189221945`, -2.083333333333333}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -1.6666666666666665`}, {-7.071067811865471, 
      3.5355339059327395`, -1.6666666666666665`}, {-7.071067811865471, 
      3.5355339059327395`, -1.2499999999999998`}, {-4.999999999999994, 
      4.3301270189221945`, -1.2499999999999998`}, {-4.999999999999994, 
      4.3301270189221945`, -1.6666666666666665`}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -1.25}, {-7.071067811865471, 
      3.5355339059327395`, -1.25}, {-7.071067811865471, 
      3.5355339059327395`, -0.8333333333333333}, {-4.999999999999994, 
      4.3301270189221945`, -0.8333333333333333}, {-4.999999999999994, 
      4.3301270189221945`, -1.25}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -0.833333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -0.833333333333333}, {-7.071067811865471, 
      3.5355339059327395`, -0.41666666666666635`}, {-4.999999999999994, 
      4.3301270189221945`, -0.41666666666666635`}, {-4.999999999999994, 
      4.3301270189221945`, -0.833333333333333}}], 
     Polygon3DBox[{{-4.999999999999994, 
      4.3301270189221945`, -0.4166666666666661}, {-7.071067811865471, 
      3.5355339059327395`, -0.4166666666666661}, {-7.071067811865471, 
      3.5355339059327395`, 6.106226635438361*^-16}, {-4.999999999999994, 
      4.3301270189221945`, 6.106226635438361*^-16}, {-4.999999999999994, 
      4.3301270189221945`, -0.4166666666666661}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      0.}, {-7.071067811865471, 3.5355339059327395`, 0.}, {-7.071067811865471,
       3.5355339059327395`, 0.4166666666666667}, {-4.999999999999994, 
      4.3301270189221945`, 0.4166666666666667}, {-4.999999999999994, 
      4.3301270189221945`, 0.}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      0.41666666666666696`}, {-7.071067811865471, 3.5355339059327395`, 
      0.41666666666666696`}, {-7.071067811865471, 3.5355339059327395`, 
      0.8333333333333337}, {-4.999999999999994, 4.3301270189221945`, 
      0.8333333333333337}, {-4.999999999999994, 4.3301270189221945`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      0.8333333333333339}, {-7.071067811865471, 3.5355339059327395`, 
      0.8333333333333339}, {-7.071067811865471, 3.5355339059327395`, 
      1.2500000000000007`}, {-4.999999999999994, 4.3301270189221945`, 
      1.2500000000000007`}, {-4.999999999999994, 4.3301270189221945`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      1.25}, {-7.071067811865471, 3.5355339059327395`, 
      1.25}, {-7.071067811865471, 3.5355339059327395`, 
      1.6666666666666667`}, {-4.999999999999994, 4.3301270189221945`, 
      1.6666666666666667`}, {-4.999999999999994, 4.3301270189221945`, 1.25}}],
      Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      1.666666666666667}, {-7.071067811865471, 3.5355339059327395`, 
      1.666666666666667}, {-7.071067811865471, 3.5355339059327395`, 
      2.0833333333333335`}, {-4.999999999999994, 4.3301270189221945`, 
      2.0833333333333335`}, {-4.999999999999994, 4.3301270189221945`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      2.083333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      2.083333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      2.5000000000000004`}, {-4.999999999999994, 4.3301270189221945`, 
      2.5000000000000004`}, {-4.999999999999994, 4.3301270189221945`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      2.5}, {-7.071067811865471, 3.5355339059327395`, 
      2.5}, {-7.071067811865471, 3.5355339059327395`, 
      2.9166666666666665`}, {-4.999999999999994, 4.3301270189221945`, 
      2.9166666666666665`}, {-4.999999999999994, 4.3301270189221945`, 2.5}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      2.916666666666667}, {-7.071067811865471, 3.5355339059327395`, 
      2.916666666666667}, {-7.071067811865471, 3.5355339059327395`, 
      3.3333333333333335`}, {-4.999999999999994, 4.3301270189221945`, 
      3.3333333333333335`}, {-4.999999999999994, 4.3301270189221945`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      3.333333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      3.333333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      3.7500000000000004`}, {-4.999999999999994, 4.3301270189221945`, 
      3.7500000000000004`}, {-4.999999999999994, 4.3301270189221945`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      3.75}, {-7.071067811865471, 3.5355339059327395`, 
      3.75}, {-7.071067811865471, 3.5355339059327395`, 
      4.166666666666667}, {-4.999999999999994, 4.3301270189221945`, 
      4.166666666666667}, {-4.999999999999994, 4.3301270189221945`, 3.75}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      4.166666666666668}, {-7.071067811865471, 3.5355339059327395`, 
      4.166666666666668}, {-7.071067811865471, 3.5355339059327395`, 
      4.583333333333335}, {-4.999999999999994, 4.3301270189221945`, 
      4.583333333333335}, {-4.999999999999994, 4.3301270189221945`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-4.999999999999994, 4.3301270189221945`, 
      4.583333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      4.583333333333334}, {-7.071067811865471, 3.5355339059327395`, 
      5.000000000000001}, {-4.999999999999994, 4.3301270189221945`, 
      5.000000000000001}, {-4.999999999999994, 4.3301270189221945`, 
      4.583333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -5.}, {-8.660254037844387, 
      2.4999999999999996`, -5.}, {-8.660254037844387, 
      2.4999999999999996`, -4.583333333333333}, {-7.071067811865475, 
      3.5355339059327378`, -4.583333333333333}, {-7.071067811865475, 
      3.5355339059327378`, -5.}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -4.583333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -4.583333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -4.166666666666666}, {-7.071067811865475, 
      3.5355339059327378`, -4.166666666666666}, {-7.071067811865475, 
      3.5355339059327378`, -4.583333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -4.166666666666667}, {-8.660254037844387, 
      2.4999999999999996`, -4.166666666666667}, {-8.660254037844387, 
      2.4999999999999996`, -3.7500000000000004`}, {-7.071067811865475, 
      3.5355339059327378`, -3.7500000000000004`}, {-7.071067811865475, 
      3.5355339059327378`, -4.166666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -3.75}, {-8.660254037844387, 
      2.4999999999999996`, -3.75}, {-8.660254037844387, 
      2.4999999999999996`, -3.3333333333333335`}, {-7.071067811865475, 
      3.5355339059327378`, -3.3333333333333335`}, {-7.071067811865475, 
      3.5355339059327378`, -3.75}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -3.333333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -3.333333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -2.9166666666666665`}, {-7.071067811865475, 
      3.5355339059327378`, -2.9166666666666665`}, {-7.071067811865475, 
      3.5355339059327378`, -3.333333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -2.9166666666666665`}, {-8.660254037844387, 
      2.4999999999999996`, -2.9166666666666665`}, {-8.660254037844387, 
      2.4999999999999996`, -2.5}, {-7.071067811865475, 
      3.5355339059327378`, -2.5}, {-7.071067811865475, 
      3.5355339059327378`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -2.5}, {-8.660254037844387, 
      2.4999999999999996`, -2.5}, {-8.660254037844387, 
      2.4999999999999996`, -2.0833333333333335`}, {-7.071067811865475, 
      3.5355339059327378`, -2.0833333333333335`}, {-7.071067811865475, 
      3.5355339059327378`, -2.5}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -2.083333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -2.083333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -1.6666666666666663`}, {-7.071067811865475, 
      3.5355339059327378`, -1.6666666666666663`}, {-7.071067811865475, 
      3.5355339059327378`, -2.083333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -1.6666666666666665`}, {-8.660254037844387, 
      2.4999999999999996`, -1.6666666666666665`}, {-8.660254037844387, 
      2.4999999999999996`, -1.2499999999999998`}, {-7.071067811865475, 
      3.5355339059327378`, -1.2499999999999998`}, {-7.071067811865475, 
      3.5355339059327378`, -1.6666666666666665`}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -1.25}, {-8.660254037844387, 
      2.4999999999999996`, -1.25}, {-8.660254037844387, 
      2.4999999999999996`, -0.8333333333333333}, {-7.071067811865475, 
      3.5355339059327378`, -0.8333333333333333}, {-7.071067811865475, 
      3.5355339059327378`, -1.25}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -0.833333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -0.833333333333333}, {-8.660254037844387, 
      2.4999999999999996`, -0.41666666666666635`}, {-7.071067811865475, 
      3.5355339059327378`, -0.41666666666666635`}, {-7.071067811865475, 
      3.5355339059327378`, -0.833333333333333}}], 
     Polygon3DBox[{{-7.071067811865475, 
      3.5355339059327378`, -0.4166666666666661}, {-8.660254037844387, 
      2.4999999999999996`, -0.4166666666666661}, {-8.660254037844387, 
      2.4999999999999996`, 6.106226635438361*^-16}, {-7.071067811865475, 
      3.5355339059327378`, 6.106226635438361*^-16}, {-7.071067811865475, 
      3.5355339059327378`, -0.4166666666666661}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      0.}, {-8.660254037844387, 2.4999999999999996`, 0.}, {-8.660254037844387,
       2.4999999999999996`, 0.4166666666666667}, {-7.071067811865475, 
      3.5355339059327378`, 0.4166666666666667}, {-7.071067811865475, 
      3.5355339059327378`, 0.}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      0.41666666666666696`}, {-8.660254037844387, 2.4999999999999996`, 
      0.41666666666666696`}, {-8.660254037844387, 2.4999999999999996`, 
      0.8333333333333337}, {-7.071067811865475, 3.5355339059327378`, 
      0.8333333333333337}, {-7.071067811865475, 3.5355339059327378`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      0.8333333333333339}, {-8.660254037844387, 2.4999999999999996`, 
      0.8333333333333339}, {-8.660254037844387, 2.4999999999999996`, 
      1.2500000000000007`}, {-7.071067811865475, 3.5355339059327378`, 
      1.2500000000000007`}, {-7.071067811865475, 3.5355339059327378`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      1.25}, {-8.660254037844387, 2.4999999999999996`, 
      1.25}, {-8.660254037844387, 2.4999999999999996`, 
      1.6666666666666667`}, {-7.071067811865475, 3.5355339059327378`, 
      1.6666666666666667`}, {-7.071067811865475, 3.5355339059327378`, 1.25}}],
      Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      1.666666666666667}, {-8.660254037844387, 2.4999999999999996`, 
      1.666666666666667}, {-8.660254037844387, 2.4999999999999996`, 
      2.0833333333333335`}, {-7.071067811865475, 3.5355339059327378`, 
      2.0833333333333335`}, {-7.071067811865475, 3.5355339059327378`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      2.083333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      2.083333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      2.5000000000000004`}, {-7.071067811865475, 3.5355339059327378`, 
      2.5000000000000004`}, {-7.071067811865475, 3.5355339059327378`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      2.5}, {-8.660254037844387, 2.4999999999999996`, 
      2.5}, {-8.660254037844387, 2.4999999999999996`, 
      2.9166666666666665`}, {-7.071067811865475, 3.5355339059327378`, 
      2.9166666666666665`}, {-7.071067811865475, 3.5355339059327378`, 2.5}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      2.916666666666667}, {-8.660254037844387, 2.4999999999999996`, 
      2.916666666666667}, {-8.660254037844387, 2.4999999999999996`, 
      3.3333333333333335`}, {-7.071067811865475, 3.5355339059327378`, 
      3.3333333333333335`}, {-7.071067811865475, 3.5355339059327378`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      3.333333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      3.333333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      3.7500000000000004`}, {-7.071067811865475, 3.5355339059327378`, 
      3.7500000000000004`}, {-7.071067811865475, 3.5355339059327378`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      3.75}, {-8.660254037844387, 2.4999999999999996`, 
      3.75}, {-8.660254037844387, 2.4999999999999996`, 
      4.166666666666667}, {-7.071067811865475, 3.5355339059327378`, 
      4.166666666666667}, {-7.071067811865475, 3.5355339059327378`, 3.75}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      4.166666666666668}, {-8.660254037844387, 2.4999999999999996`, 
      4.166666666666668}, {-8.660254037844387, 2.4999999999999996`, 
      4.583333333333335}, {-7.071067811865475, 3.5355339059327378`, 
      4.583333333333335}, {-7.071067811865475, 3.5355339059327378`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-7.071067811865475, 3.5355339059327378`, 
      4.583333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      4.583333333333334}, {-8.660254037844387, 2.4999999999999996`, 
      5.000000000000001}, {-7.071067811865475, 3.5355339059327378`, 
      5.000000000000001}, {-7.071067811865475, 3.5355339059327378`, 
      4.583333333333334}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -5.}, {-9.659258262890681, 
      1.294095225512605, -5.}, {-9.659258262890681, 
      1.294095225512605, -4.583333333333333}, {-8.660254037844386, 
      2.5000000000000018`, -4.583333333333333}, {-8.660254037844386, 
      2.5000000000000018`, -5.}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -4.583333333333333}, {-9.659258262890681, 
      1.294095225512605, -4.583333333333333}, {-9.659258262890681, 
      1.294095225512605, -4.166666666666666}, {-8.660254037844386, 
      2.5000000000000018`, -4.166666666666666}, {-8.660254037844386, 
      2.5000000000000018`, -4.583333333333333}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -4.166666666666667}, {-9.659258262890681, 
      1.294095225512605, -4.166666666666667}, {-9.659258262890681, 
      1.294095225512605, -3.7500000000000004`}, {-8.660254037844386, 
      2.5000000000000018`, -3.7500000000000004`}, {-8.660254037844386, 
      2.5000000000000018`, -4.166666666666667}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -3.75}, {-9.659258262890681, 
      1.294095225512605, -3.75}, {-9.659258262890681, 
      1.294095225512605, -3.3333333333333335`}, {-8.660254037844386, 
      2.5000000000000018`, -3.3333333333333335`}, {-8.660254037844386, 
      2.5000000000000018`, -3.75}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -3.333333333333333}, {-9.659258262890681, 
      1.294095225512605, -3.333333333333333}, {-9.659258262890681, 
      1.294095225512605, -2.9166666666666665`}, {-8.660254037844386, 
      2.5000000000000018`, -2.9166666666666665`}, {-8.660254037844386, 
      2.5000000000000018`, -3.333333333333333}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -2.9166666666666665`}, {-9.659258262890681, 
      1.294095225512605, -2.9166666666666665`}, {-9.659258262890681, 
      1.294095225512605, -2.5}, {-8.660254037844386, 
      2.5000000000000018`, -2.5}, {-8.660254037844386, 
      2.5000000000000018`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -2.5}, {-9.659258262890681, 
      1.294095225512605, -2.5}, {-9.659258262890681, 
      1.294095225512605, -2.0833333333333335`}, {-8.660254037844386, 
      2.5000000000000018`, -2.0833333333333335`}, {-8.660254037844386, 
      2.5000000000000018`, -2.5}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -2.083333333333333}, {-9.659258262890681, 
      1.294095225512605, -2.083333333333333}, {-9.659258262890681, 
      1.294095225512605, -1.6666666666666663`}, {-8.660254037844386, 
      2.5000000000000018`, -1.6666666666666663`}, {-8.660254037844386, 
      2.5000000000000018`, -2.083333333333333}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -1.6666666666666665`}, {-9.659258262890681, 
      1.294095225512605, -1.6666666666666665`}, {-9.659258262890681, 
      1.294095225512605, -1.2499999999999998`}, {-8.660254037844386, 
      2.5000000000000018`, -1.2499999999999998`}, {-8.660254037844386, 
      2.5000000000000018`, -1.6666666666666665`}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -1.25}, {-9.659258262890681, 
      1.294095225512605, -1.25}, {-9.659258262890681, 
      1.294095225512605, -0.8333333333333333}, {-8.660254037844386, 
      2.5000000000000018`, -0.8333333333333333}, {-8.660254037844386, 
      2.5000000000000018`, -1.25}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -0.833333333333333}, {-9.659258262890681, 
      1.294095225512605, -0.833333333333333}, {-9.659258262890681, 
      1.294095225512605, -0.41666666666666635`}, {-8.660254037844386, 
      2.5000000000000018`, -0.41666666666666635`}, {-8.660254037844386, 
      2.5000000000000018`, -0.833333333333333}}], 
     Polygon3DBox[{{-8.660254037844386, 
      2.5000000000000018`, -0.4166666666666661}, {-9.659258262890681, 
      1.294095225512605, -0.4166666666666661}, {-9.659258262890681, 
      1.294095225512605, 6.106226635438361*^-16}, {-8.660254037844386, 
      2.5000000000000018`, 6.106226635438361*^-16}, {-8.660254037844386, 
      2.5000000000000018`, -0.4166666666666661}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      0.}, {-9.659258262890681, 1.294095225512605, 0.}, {-9.659258262890681, 
      1.294095225512605, 0.4166666666666667}, {-8.660254037844386, 
      2.5000000000000018`, 0.4166666666666667}, {-8.660254037844386, 
      2.5000000000000018`, 0.}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      0.41666666666666696`}, {-9.659258262890681, 1.294095225512605, 
      0.41666666666666696`}, {-9.659258262890681, 1.294095225512605, 
      0.8333333333333337}, {-8.660254037844386, 2.5000000000000018`, 
      0.8333333333333337}, {-8.660254037844386, 2.5000000000000018`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      0.8333333333333339}, {-9.659258262890681, 1.294095225512605, 
      0.8333333333333339}, {-9.659258262890681, 1.294095225512605, 
      1.2500000000000007`}, {-8.660254037844386, 2.5000000000000018`, 
      1.2500000000000007`}, {-8.660254037844386, 2.5000000000000018`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      1.25}, {-9.659258262890681, 1.294095225512605, 
      1.25}, {-9.659258262890681, 1.294095225512605, 
      1.6666666666666667`}, {-8.660254037844386, 2.5000000000000018`, 
      1.6666666666666667`}, {-8.660254037844386, 2.5000000000000018`, 1.25}}],
      Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      1.666666666666667}, {-9.659258262890681, 1.294095225512605, 
      1.666666666666667}, {-9.659258262890681, 1.294095225512605, 
      2.0833333333333335`}, {-8.660254037844386, 2.5000000000000018`, 
      2.0833333333333335`}, {-8.660254037844386, 2.5000000000000018`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      2.083333333333334}, {-9.659258262890681, 1.294095225512605, 
      2.083333333333334}, {-9.659258262890681, 1.294095225512605, 
      2.5000000000000004`}, {-8.660254037844386, 2.5000000000000018`, 
      2.5000000000000004`}, {-8.660254037844386, 2.5000000000000018`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      2.5}, {-9.659258262890681, 1.294095225512605, 2.5}, {-9.659258262890681,
       1.294095225512605, 2.9166666666666665`}, {-8.660254037844386, 
      2.5000000000000018`, 2.9166666666666665`}, {-8.660254037844386, 
      2.5000000000000018`, 2.5}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      2.916666666666667}, {-9.659258262890681, 1.294095225512605, 
      2.916666666666667}, {-9.659258262890681, 1.294095225512605, 
      3.3333333333333335`}, {-8.660254037844386, 2.5000000000000018`, 
      3.3333333333333335`}, {-8.660254037844386, 2.5000000000000018`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      3.333333333333334}, {-9.659258262890681, 1.294095225512605, 
      3.333333333333334}, {-9.659258262890681, 1.294095225512605, 
      3.7500000000000004`}, {-8.660254037844386, 2.5000000000000018`, 
      3.7500000000000004`}, {-8.660254037844386, 2.5000000000000018`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      3.75}, {-9.659258262890681, 1.294095225512605, 
      3.75}, {-9.659258262890681, 1.294095225512605, 
      4.166666666666667}, {-8.660254037844386, 2.5000000000000018`, 
      4.166666666666667}, {-8.660254037844386, 2.5000000000000018`, 3.75}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      4.166666666666668}, {-9.659258262890681, 1.294095225512605, 
      4.166666666666668}, {-9.659258262890681, 1.294095225512605, 
      4.583333333333335}, {-8.660254037844386, 2.5000000000000018`, 
      4.583333333333335}, {-8.660254037844386, 2.5000000000000018`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-8.660254037844386, 2.5000000000000018`, 
      4.583333333333334}, {-9.659258262890681, 1.294095225512605, 
      4.583333333333334}, {-9.659258262890681, 1.294095225512605, 
      5.000000000000001}, {-8.660254037844386, 2.5000000000000018`, 
      5.000000000000001}, {-8.660254037844386, 2.5000000000000018`, 
      4.583333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, -5.}, {-10., 
      2.8327694488239896`*^-15, -5.}, {-10., 
      2.8327694488239896`*^-15, -4.583333333333333}, {-9.659258262890681, 
      1.2940952255126073`, -4.583333333333333}, {-9.659258262890681, 
      1.2940952255126073`, -5.}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -4.583333333333333}, {-10., 
      2.8327694488239896`*^-15, -4.583333333333333}, {-10., 
      2.8327694488239896`*^-15, -4.166666666666666}, {-9.659258262890681, 
      1.2940952255126073`, -4.166666666666666}, {-9.659258262890681, 
      1.2940952255126073`, -4.583333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -4.166666666666667}, {-10., 
      2.8327694488239896`*^-15, -4.166666666666667}, {-10., 
      2.8327694488239896`*^-15, -3.7500000000000004`}, {-9.659258262890681, 
      1.2940952255126073`, -3.7500000000000004`}, {-9.659258262890681, 
      1.2940952255126073`, -4.166666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, -3.75}, {-10., 
      2.8327694488239896`*^-15, -3.75}, {-10., 
      2.8327694488239896`*^-15, -3.3333333333333335`}, {-9.659258262890681, 
      1.2940952255126073`, -3.3333333333333335`}, {-9.659258262890681, 
      1.2940952255126073`, -3.75}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -3.333333333333333}, {-10., 
      2.8327694488239896`*^-15, -3.333333333333333}, {-10., 
      2.8327694488239896`*^-15, -2.9166666666666665`}, {-9.659258262890681, 
      1.2940952255126073`, -2.9166666666666665`}, {-9.659258262890681, 
      1.2940952255126073`, -3.333333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -2.9166666666666665`}, {-10., 
      2.8327694488239896`*^-15, -2.9166666666666665`}, {-10., 
      2.8327694488239896`*^-15, -2.5}, {-9.659258262890681, 
      1.2940952255126073`, -2.5}, {-9.659258262890681, 
      1.2940952255126073`, -2.9166666666666665`}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, -2.5}, {-10., 
      2.8327694488239896`*^-15, -2.5}, {-10., 
      2.8327694488239896`*^-15, -2.0833333333333335`}, {-9.659258262890681, 
      1.2940952255126073`, -2.0833333333333335`}, {-9.659258262890681, 
      1.2940952255126073`, -2.5}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -2.083333333333333}, {-10., 
      2.8327694488239896`*^-15, -2.083333333333333}, {-10., 
      2.8327694488239896`*^-15, -1.6666666666666663`}, {-9.659258262890681, 
      1.2940952255126073`, -1.6666666666666663`}, {-9.659258262890681, 
      1.2940952255126073`, -2.083333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -1.6666666666666665`}, {-10., 
      2.8327694488239896`*^-15, -1.6666666666666665`}, {-10., 
      2.8327694488239896`*^-15, -1.2499999999999998`}, {-9.659258262890681, 
      1.2940952255126073`, -1.2499999999999998`}, {-9.659258262890681, 
      1.2940952255126073`, -1.6666666666666665`}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, -1.25}, {-10., 
      2.8327694488239896`*^-15, -1.25}, {-10., 
      2.8327694488239896`*^-15, -0.8333333333333333}, {-9.659258262890681, 
      1.2940952255126073`, -0.8333333333333333}, {-9.659258262890681, 
      1.2940952255126073`, -1.25}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -0.833333333333333}, {-10., 
      2.8327694488239896`*^-15, -0.833333333333333}, {-10., 
      2.8327694488239896`*^-15, -0.41666666666666635`}, {-9.659258262890681, 
      1.2940952255126073`, -0.41666666666666635`}, {-9.659258262890681, 
      1.2940952255126073`, -0.833333333333333}}], 
     Polygon3DBox[{{-9.659258262890681, 
      1.2940952255126073`, -0.4166666666666661}, {-10., 
      2.8327694488239896`*^-15, -0.4166666666666661}, {-10., 
      2.8327694488239896`*^-15, 6.106226635438361*^-16}, {-9.659258262890681, 
      1.2940952255126073`, 6.106226635438361*^-16}, {-9.659258262890681, 
      1.2940952255126073`, -0.4166666666666661}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 0.}, {-10., 
      2.8327694488239896`*^-15, 0.}, {-10., 2.8327694488239896`*^-15, 
      0.4166666666666667}, {-9.659258262890681, 1.2940952255126073`, 
      0.4166666666666667}, {-9.659258262890681, 1.2940952255126073`, 0.}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      0.41666666666666696`}, {-10., 2.8327694488239896`*^-15, 
      0.41666666666666696`}, {-10., 2.8327694488239896`*^-15, 
      0.8333333333333337}, {-9.659258262890681, 1.2940952255126073`, 
      0.8333333333333337}, {-9.659258262890681, 1.2940952255126073`, 
      0.41666666666666696`}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      0.8333333333333339}, {-10., 2.8327694488239896`*^-15, 
      0.8333333333333339}, {-10., 2.8327694488239896`*^-15, 
      1.2500000000000007`}, {-9.659258262890681, 1.2940952255126073`, 
      1.2500000000000007`}, {-9.659258262890681, 1.2940952255126073`, 
      0.8333333333333339}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 1.25}, {-10., 
      2.8327694488239896`*^-15, 1.25}, {-10., 2.8327694488239896`*^-15, 
      1.6666666666666667`}, {-9.659258262890681, 1.2940952255126073`, 
      1.6666666666666667`}, {-9.659258262890681, 1.2940952255126073`, 1.25}}],
      Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      1.666666666666667}, {-10., 2.8327694488239896`*^-15, 
      1.666666666666667}, {-10., 2.8327694488239896`*^-15, 
      2.0833333333333335`}, {-9.659258262890681, 1.2940952255126073`, 
      2.0833333333333335`}, {-9.659258262890681, 1.2940952255126073`, 
      1.666666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      2.083333333333334}, {-10., 2.8327694488239896`*^-15, 
      2.083333333333334}, {-10., 2.8327694488239896`*^-15, 
      2.5000000000000004`}, {-9.659258262890681, 1.2940952255126073`, 
      2.5000000000000004`}, {-9.659258262890681, 1.2940952255126073`, 
      2.083333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 2.5}, {-10., 
      2.8327694488239896`*^-15, 2.5}, {-10., 2.8327694488239896`*^-15, 
      2.9166666666666665`}, {-9.659258262890681, 1.2940952255126073`, 
      2.9166666666666665`}, {-9.659258262890681, 1.2940952255126073`, 2.5}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      2.916666666666667}, {-10., 2.8327694488239896`*^-15, 
      2.916666666666667}, {-10., 2.8327694488239896`*^-15, 
      3.3333333333333335`}, {-9.659258262890681, 1.2940952255126073`, 
      3.3333333333333335`}, {-9.659258262890681, 1.2940952255126073`, 
      2.916666666666667}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      3.333333333333334}, {-10., 2.8327694488239896`*^-15, 
      3.333333333333334}, {-10., 2.8327694488239896`*^-15, 
      3.7500000000000004`}, {-9.659258262890681, 1.2940952255126073`, 
      3.7500000000000004`}, {-9.659258262890681, 1.2940952255126073`, 
      3.333333333333334}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 3.75}, {-10., 
      2.8327694488239896`*^-15, 3.75}, {-10., 2.8327694488239896`*^-15, 
      4.166666666666667}, {-9.659258262890681, 1.2940952255126073`, 
      4.166666666666667}, {-9.659258262890681, 1.2940952255126073`, 3.75}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      4.166666666666668}, {-10., 2.8327694488239896`*^-15, 
      4.166666666666668}, {-10., 2.8327694488239896`*^-15, 
      4.583333333333335}, {-9.659258262890681, 1.2940952255126073`, 
      4.583333333333335}, {-9.659258262890681, 1.2940952255126073`, 
      4.166666666666668}}], 
     Polygon3DBox[{{-9.659258262890681, 1.2940952255126073`, 
      4.583333333333334}, {-10., 2.8327694488239896`*^-15, 
      4.583333333333334}, {-10., 2.8327694488239896`*^-15, 
      5.000000000000001}, {-9.659258262890681, 1.2940952255126073`, 
      5.000000000000001}, {-9.659258262890681, 1.2940952255126073`, 
      4.583333333333334}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-10., -6.123233995736766*^-16, 
         5}, {-9.659258262890681, -1.294095225512605, 
         5}, {-8.660254037844387, -2.4999999999999996`, 
         5}, {-7.071067811865475, -3.5355339059327378`, 
         5}, {-5.000000000000002, -4.330127018922193, 
         5}, {-2.5881904510252083`, -4.8296291314453415`, 5}, {
        6.123233995736766*^-16, -5., 5}, {
        2.5881904510252074`, -4.8296291314453415`, 5}, {
        4.999999999999999, -4.330127018922194, 5}, {
        7.0710678118654755`, -3.5355339059327373`, 5}, {
        8.660254037844386, -2.500000000000001, 5}, {
        9.659258262890681, -1.2940952255126046`, 5}, {10., 0., 5}, {
        9.659258262890683, 1.2940952255126024`, 5}, {
        8.660254037844387, 2.499999999999999, 5}, {
        7.071067811865479, 3.535533905932736, 5}, {
        5.0000000000000036`, 4.330127018922193, 5}, {
        2.588190451025214, 4.829629131445341, 5}, {
        6.123233995736766*^-16, 5., 5}, {-2.588190451025204, 
         4.829629131445342, 5}, {-4.999999999999994, 4.3301270189221945`, 
         5}, {-7.071067811865475, 3.5355339059327378`, 
         5}, {-8.660254037844386, 2.5000000000000018`, 
         5}, {-9.659258262890681, 1.2940952255126073`, 5}, {-10., 
         6.123233995736766*^-16, 5}, {-10, 0, 5.}, {-10, 0, 
         4.583333333333333}, {-10, 0, 4.166666666666667}, {-10, 0, 
         3.75}, {-10, 0, 3.333333333333333}, {-10, 0, 
         2.9166666666666665`}, {-10, 0, 2.5}, {-10, 0, 
         2.083333333333333}, {-10, 0, 1.6666666666666665`}, {-10, 0, 
         1.25}, {-10, 0, 0.833333333333333}, {-10, 0, 
         0.4166666666666661}, {-10, 0, 0.}, {-10, 
         0, -0.41666666666666696`}, {-10, 0, -0.8333333333333339}, {-10, 
         0, -1.25}, {-10, 0, -1.666666666666667}, {-10, 
         0, -2.083333333333334}, {-10, 0, -2.5}, {-10, 
         0, -2.916666666666667}, {-10, 0, -3.333333333333334}, {-10, 
         0, -3.75}, {-10, 0, -4.166666666666668}, {-10, 
         0, -4.583333333333334}, {-10, 0, -5.}, {-10., 
         6.123233995736766*^-16, -5}, {-9.659258262890681, 
         1.294095225512605, -5}, {-8.660254037844387, 
         2.4999999999999996`, -5}, {-7.071067811865475, 
         3.5355339059327378`, -5}, {-5.000000000000002, 
         4.330127018922193, -5}, {-2.5881904510252083`, 
         4.8296291314453415`, -5}, {6.123233995736766*^-16, 5., -5}, {
        2.5881904510252074`, 4.8296291314453415`, -5}, {
        4.999999999999999, 4.330127018922194, -5}, {
        7.0710678118654755`, 3.5355339059327373`, -5}, {
        8.660254037844386, 2.500000000000001, -5}, {
        9.659258262890681, 1.2940952255126046`, -5}, {10., 0., -5}, {
        9.659258262890683, -1.2940952255126024`, -5}, {
        8.660254037844387, -2.499999999999999, -5}, {
        7.071067811865479, -3.535533905932736, -5}, {
        5.0000000000000036`, -4.330127018922193, -5}, {
        2.588190451025214, -4.829629131445341, -5}, {
        6.123233995736766*^-16, -5., -5}, {-2.588190451025204, \
-4.829629131445342, -5}, {-4.999999999999994, -4.3301270189221945`, -5}, \
{-7.071067811865475, -3.5355339059327378`, -5}, {-8.660254037844386, \
-2.5000000000000018`, -5}, {-9.659258262890681, -1.2940952255126073`, -5}, \
{-10., -6.123233995736766*^-16, -5}, {-10, 0, -5.}, {-10, 
         0, -4.583333333333333}, {-10, 0, -4.166666666666667}, {-10, 
         0, -3.75}, {-10, 0, -3.333333333333333}, {-10, 
         0, -2.9166666666666665`}, {-10, 0, -2.5}, {-10, 
         0, -2.083333333333333}, {-10, 0, -1.6666666666666665`}, {-10, 
         0, -1.25}, {-10, 0, -0.833333333333333}, {-10, 
         0, -0.4166666666666661}, {-10, 0, 0.}, {-10, 0, 
         0.41666666666666696`}, {-10, 0, 0.8333333333333339}, {-10, 0, 
         1.25}, {-10, 0, 1.666666666666667}, {-10, 0, 
         2.083333333333334}, {-10, 0, 2.5}, {-10, 0, 2.916666666666667}, {-10,
          0, 3.333333333333334}, {-10, 0, 3.75}, {-10, 0, 
         4.166666666666668}, {-10, 0, 4.583333333333334}, {-10, 0, 5.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301505150639*^9, 3.6147092717806377`*^9, 
  3.614729127490982*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[199]:="]
}, Open  ]],

Cell[TextData[{
 "By tracing a ",
 StyleBox["SingleRay", "Input"],
 " within the ",
 StyleBox["ellipticalmirror", "Input"],
 " that has the ",
 StyleBox["Resonate", "Input"],
 " feature added, we can observe its resulting the caustic caused by repeated \
bounces around the mirror's interior. We will store the total ray-trace time \
in a variable for future comparison with other settings."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
tracedtiming[1] = 
Timing[sys = PropagateSystem[{
\tMove[SingleRay[],{0,2}],
\tResonate[ellipticalmirror[1]]}];][[1]]
ShowSystem[sys,PlotType->TopView, PlotPoints->60];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[200]:="],

Cell[BoxData["0.94888300000000003198152853656210936606`5.997812579250738"], \
"Output",
 CellChangeTimes->{3.563404260016699*^9, 3.56345815941261*^9, 
  3.564487595275694*^9, 3.5661006991750603`*^9, 3.601301242356431*^9, 
  3.601301506087216*^9, 3.614709272776526*^9, 3.6147291285106993`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[200]="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1k71KQ0EQhRe9jSEgci0D4RJLiYhBRQI5oIWFjXkEwS7RwsJ3EHyEPION
ZWBPIcHW0lcwlkKw8W9nNsW5uHBZltk5c2a/udXF9fByJYSw9/v97ba2uHbz
Gh/WZ9PR7f3Z3XmHR8+L3cnjR5zvHLw0hxW/01plbLTD7LRFpr1J09jkW7q3
wf2UV3CcdMqs2w9+r2dx5Ljplph7vum2EF3fdCtYnYLuD4fuz/0jdzL2eNfi
A/ePL/OPJ9efmj4K8wX3j2P3Z3VKiH9se39XHv80/3z3fHkf161odbJuhyfu
T96/r2fhMRAetXrCA8Kj1o/wgPCA8IDwgPDI/fzHIwoPCg8KDwqP2jwJDwqP
2rwKDwqPPE/L/0HPP5BKOqI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEqDgwoYJQ/yh/lY+MDAPTLFc0=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-5.000000000000002, \
-4.330127018922193}, {-2.5881904510252083`, -4.8296291314453415`}, {
        6.123233995736766*^-16, -5.}, {
        2.5881904510252074`, -4.8296291314453415`}, {
        4.999999999999999, -4.330127018922194}, {
        7.0710678118654755`, -3.5355339059327373`}, {
        8.660254037844386, -2.500000000000001}, {
        9.659258262890681, -1.2940952255126046`}, {10., 0.}, {
        9.659258262890683, 1.2940952255126024`}, {8.660254037844387, 
        2.499999999999999}, {7.071067811865479, 3.535533905932736}, {
        5.0000000000000036`, 4.330127018922193}, {2.588190451025214, 
        4.829629131445341}, {6.123233995736766*^-16, 5.}, {-2.588190451025204,
         4.829629131445342}, {-4.999999999999994, 
        4.3301270189221945`}, {-7.071067811865475, 
        3.5355339059327378`}, {-8.660254037844386, 
        2.5000000000000018`}, {-9.659258262890681, 
        1.2940952255126073`}, {-10., 6.123233995736766*^-16}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10., 
        6.123233995736766*^-16}, {-9.659258262890681, 
        1.294095225512605}, {-8.660254037844387, 
        2.4999999999999996`}, {-7.071067811865475, 
        3.5355339059327378`}, {-5.000000000000002, 
        4.330127018922193}, {-2.5881904510252083`, 4.8296291314453415`}, {
        6.123233995736766*^-16, 5.}, {2.5881904510252074`, 
        4.8296291314453415`}, {4.999999999999999, 4.330127018922194}, {
        7.0710678118654755`, 3.5355339059327373`}, {8.660254037844386, 
        2.500000000000001}, {9.659258262890681, 1.2940952255126046`}, {10., 
        0.}, {9.659258262890683, -1.2940952255126024`}, {
        8.660254037844387, -2.499999999999999}, {
        7.071067811865479, -3.535533905932736}, {
        5.0000000000000036`, -4.330127018922193}, {
        2.588190451025214, -4.829629131445341}, {
        6.123233995736766*^-16, -5.}, {-2.588190451025204, \
-4.829629131445342}, {-4.999999999999994, -4.3301270189221945`}, \
{-7.071067811865475, -3.5355339059327378`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.2940952255126073`}, {-10., \
-6.123233995736766*^-16}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx112k4lesaB/CVZc6wBsNCWGu9yNTOlkqF90lUIkVCSKltaFCUZtqGJlTb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      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwllnk4lWsXxjfbnGEPho2w936RqZMjlQrvkygiU0JIqWNoUEiDomNoMvU5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      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301506351719*^9, 3.614709272998313*^9, 
  3.614729128735755*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[200]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["SurfaceRayIntersections -> Automatic", "Input"],
 " is in fact not a unique method of its own, but, rather, enables ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " to internally select one of the six other methods. The advantage of the ",
 StyleBox["Automatic", "Input"],
 " setting is that it gives ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " the opportunity to choose different settings according to the character of \
the specified surface function. This frees the user from having to manipulate \
the ray-trace operation details at this low level. However, this has a \
disadvantage in that the user does not have control over ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s final selection. This becomes a problem if ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " happens to make a poor internal choice. In practise, ",
 StyleBox["SurfaceRayIntersections -> Automatic", "Input"],
 " usually invokes the ",
 StyleBox["FindRoot", "Input"],
 " setting since it is the most robust and handles a widest range of custom \
surface functions. Unfortunately, the ",
 StyleBox["FindRoot", "Input"],
 " setting can be sigificantly slower at tracing than some other selections \
such as ",
 StyleBox["Symbol", "Input"],
 ". However, ",
 StyleBox["Symbol", "Input"],
 " requires a closed-form symbolic solution to exist and, as such, can only \
be used with a limited range of surface functions. In addition, when a \
closed-form solution does exist, the component creation time is much longer \
with ",
 StyleBox["Symbol", "Input"],
 ". Here is the same mirror system with ",
 StyleBox["SurfaceRayIntersections -> Symbol", "Input"],
 " instead of ",
 StyleBox["SurfaceRayIntersections -> Automatic", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell["Off[Solve::ifun];", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[202]:="],

Cell[CellGroupData[{

Cell["\<\
creationtime[2] = 
Timing[
\tellipticalmirror[2] = 
\tCustomMirror[ Function[{s,t}, {10*Cos[s], 5*Sin[s], t}], {2*Pi,10}, \
SurfaceRayIntersections->Symbol]
][[1]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[203]:="],

Cell[BoxData["1.9787030000000001006554839477757923305`6.316980525504771"], \
"Output",
 CellChangeTimes->{3.563404262820203*^9, 3.563458162151307*^9, 
  3.5644875991020737`*^9, 3.566100702892939*^9, 3.601301242390976*^9, 
  3.601301508518276*^9, 3.614709275103476*^9, 3.614729130800558*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[203]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["creationtime[2]/creationtime[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[204]:="],

Cell[BoxData["6.41411446650156300571967386645607611971`5.446921238687645"], \
"Output",
 CellChangeTimes->{3.563404262908287*^9, 3.563458162334902*^9, 
  3.5644875993210087`*^9, 3.5661007030732937`*^9, 3.60130124243671*^9, 
  3.60130150862346*^9, 3.614709275205505*^9, 3.614729130904208*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[204]="]
}, Open  ]],

Cell[TextData[{
 "In this case, the mirror creation time was nearly seven time longer than \
before. For some custom surface functions, the component creation time for ",
 StyleBox["Symbol", "Input"],
 " can consume unreasonable amounts of time (and memory). For this reason, \
the ",
 StyleBox["Symbol", "Input"],
 " setting must be used with care. In cases where it can successfully be \
employed, however, the ",
 StyleBox["Symbol", "Input"],
 " setting often works the best, both in terms of time and accuracy."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
tracedtiming[2] = 
Timing[sys = PropagateSystem[{
\tMove[SingleRay[],{0,2}],
\tResonate[ellipticalmirror[2]]}];][[1]]
ShowSystem[sys,PlotType->TopView, PlotPoints->60];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[205]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CompiledFunction", "::", "cfse"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Compiled expression \[NoBreak]\\!\\(ConditionalExpression[\
\\(\\(\\(\\(\\(\\(2.7300758075223053` \[VeryThinSpace]\\)\\) + \
\\(\\(6.283185307179586`\\\\ \\(\\(C[1]\\)\\)\\)\\)\\)\\), \
\\(\\(\\(\\(C[1]\\)\\) \[Element] Integers\\)\\)\\)\\)]\\)\[NoBreak] should \
be a \[NoBreak]\\!\\(\\\"machine-size integer\\\"\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/CompiledFunction/cfse\\\
\", ButtonNote -> \\\"CompiledFunction::cfse\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301508721547*^9, 3.601301797849957*^9, 
  3.6147092753554773`*^9, 3.614729131049067*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[205]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CompiledFunction", "::", "cfex"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Could not complete external evaluation at instruction \
\[NoBreak]\\!\\(33\\)\[NoBreak]; proceeding with uncompiled evaluation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/CompiledFunction/cfex\\\
\", ButtonNote -> \\\"CompiledFunction::cfex\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301508721547*^9, 3.601301797849957*^9, 
  3.6147092753554773`*^9, 3.614729131054948*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[205]:="],

Cell[BoxData["0.13548399999999999332445099753385875374`5.152487923456848"], \
"Output",
 CellChangeTimes->{3.5634042635422897`*^9, 3.5634581624724007`*^9, 
  3.5644875995531683`*^9, 3.566100704311358*^9, 3.601301242523341*^9, 
  3.601301508771956*^9, 3.601301797898438*^9, 3.614709275365539*^9, 
  3.6147291310578613`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[205]="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1k71KQ0EQhRe9jSEgci0D4RJLiYhBRQI5oIWFjXkEwS7RwsJ3EHyEPION
ZWBPIcHW0lcwlkKw8W9nNsW5uHBZltk5c2a/udXF9fByJYSw9/v97ba2uHbz
Gh/WZ9PR7f3Z3XmHR8+L3cnjR5zvHLw0hxW/01plbLTD7LRFpr1J09jkW7q3
wf2UV3CcdMqs2w9+r2dx5Ljplph7vum2EF3fdCtYnYLuD4fuz/0jdzL2eNfi
A/ePL/OPJ9efmj4K8wX3j2P3Z3VKiH9se39XHv80/3z3fHkf161odbJuhyfu
T96/r2fhMRAetXrCA8Kj1o/wgPCA8IDwgPDI/fzHIwoPCg8KDwqP2jwJDwqP
2rwKDwqPPE/L/0HPP5BKOqI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEqDgwoYJQ/yh/lY+MDAPTLFc0=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-5.000000000000002, \
-4.330127018922193}, {-2.5881904510252083`, -4.8296291314453415`}, {
        6.123233995736766*^-16, -5.}, {
        2.5881904510252074`, -4.8296291314453415`}, {
        4.999999999999999, -4.330127018922194}, {
        7.0710678118654755`, -3.5355339059327373`}, {
        8.660254037844386, -2.500000000000001}, {
        9.659258262890681, -1.2940952255126046`}, {10., 0.}, {
        9.659258262890683, 1.2940952255126024`}, {8.660254037844387, 
        2.499999999999999}, {7.071067811865479, 3.535533905932736}, {
        5.0000000000000036`, 4.330127018922193}, {2.588190451025214, 
        4.829629131445341}, {6.123233995736766*^-16, 5.}, {-2.588190451025204,
         4.829629131445342}, {-4.999999999999994, 
        4.3301270189221945`}, {-7.071067811865475, 
        3.5355339059327378`}, {-8.660254037844386, 
        2.5000000000000018`}, {-9.659258262890681, 
        1.2940952255126073`}, {-10., 6.123233995736766*^-16}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10., 
        6.123233995736766*^-16}, {-9.659258262890681, 
        1.294095225512605}, {-8.660254037844387, 
        2.4999999999999996`}, {-7.071067811865475, 
        3.5355339059327378`}, {-5.000000000000002, 
        4.330127018922193}, {-2.5881904510252083`, 4.8296291314453415`}, {
        6.123233995736766*^-16, 5.}, {2.5881904510252074`, 
        4.8296291314453415`}, {4.999999999999999, 4.330127018922194}, {
        7.0710678118654755`, 3.5355339059327373`}, {8.660254037844386, 
        2.500000000000001}, {9.659258262890681, 1.2940952255126046`}, {10., 
        0.}, {9.659258262890683, -1.2940952255126024`}, {
        8.660254037844387, -2.499999999999999}, {
        7.071067811865479, -3.535533905932736}, {
        5.0000000000000036`, -4.330127018922193}, {
        2.588190451025214, -4.829629131445341}, {
        6.123233995736766*^-16, -5.}, {-2.588190451025204, \
-4.829629131445342}, {-4.999999999999994, -4.3301270189221945`}, \
{-7.071067811865475, -3.5355339059327378`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.2940952255126073`}, {-10., \
-6.123233995736766*^-16}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[{{0., 2.}, {0., 2.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[{0., 2.}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301508914267*^9, 3.6013017980332527`*^9, 
  3.614709275515296*^9, 3.614729131197289*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[205]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["tracedtiming[2]/tracedtiming[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[207]:="],

Cell[BoxData["0.14278261914271832118189975887009616646`5.094524296985738"], \
"Output",
 CellChangeTimes->{3.5634042637170486`*^9, 3.563458163153202*^9, 
  3.564487599754088*^9, 3.5661007049077682`*^9, 3.601301242535941*^9, 
  3.601301508952318*^9, 3.61470927555239*^9, 3.6147291312424307`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[207]="]
}, Open  ]],

Cell[TextData[{
 "In this setting, the ray-trace time was sixty percent of the ",
 StyleBox["Automatic", "Input"],
 " setting. Next, we will use the ",
 StyleBox["SurfaceRayIntersections -> Numeric", "Input"],
 " setting on the same system."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
creationtime[3] = 
Timing[
\tellipticalmirror[3] = 
\tCustomMirror[ Function[{s,t}, {10*Cos[s], 5*Sin[s], t}], {2*Pi,10}, \
SurfaceRayIntersections->Numeric]
][[1]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[208]:="],

Cell[BoxData["0.30731599999999997807620388812210876495`5.508185085090899"], \
"Output",
 CellChangeTimes->{3.563404263977138*^9, 3.563458163436532*^9, 
  3.564487600073039*^9, 3.5661007055022287`*^9, 3.601301242590931*^9, 
  3.601301509265134*^9, 3.614709275860732*^9, 3.614729131555743*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[208]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["creationtime[3]/creationtime[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[209]:="],

Cell[BoxData["0.99618790762807460026706056790286218075`5.207983664670166"], \
"Output",
 CellChangeTimes->{3.563404264198421*^9, 3.563458163607444*^9, 
  3.564487600155284*^9, 3.566100705566283*^9, 3.601301242715805*^9, 
  3.601301509302001*^9, 3.6147092759060793`*^9, 3.6147291315934896`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[209]="]
}, Open  ]],

Cell[TextData[{
 "Here we see that the ",
 StyleBox["Numeric", "Input"],
 " setting took slightly longer than the ",
 StyleBox["Automatic", "Input"],
 " (",
 StyleBox["FindRoot", "Input"],
 ") setting for the component creation."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
tracedtiming[3] = 
Timing[sys = PropagateSystem[{
\tMove[SingleRay[],{0,2}],
\tResonate[ellipticalmirror[3]]}];][[1]]
ShowSystem[sys,PlotType->TopView, PlotPoints->60];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[210]:="],

Cell[BoxData["0.95728100000000004854427970713004469872`6.001639352452858"], \
"Output",
 CellChangeTimes->{3.563404265194151*^9, 3.563458164661623*^9, 
  3.564487601411396*^9, 3.566100707467045*^9, 3.6013012428128977`*^9, 
  3.6013015106298447`*^9, 3.614709276917941*^9, 3.614729132607692*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[210]="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1k71KQ0EQhRe9jSEgci0D4RJLiYhBRQI5oIWFjXkEwS7RwsJ3EHyEPION
ZWBPIcHW0lcwlkKw8W9nNsW5uHBZltk5c2a/udXF9fByJYSw9/v97ba2uHbz
Gh/WZ9PR7f3Z3XmHR8+L3cnjR5zvHLw0hxW/01plbLTD7LRFpr1J09jkW7q3
wf2UV3CcdMqs2w9+r2dx5Ljplph7vum2EF3fdCtYnYLuD4fuz/0jdzL2eNfi
A/ePL/OPJ9efmj4K8wX3j2P3Z3VKiH9se39XHv80/3z3fHkf161odbJuhyfu
T96/r2fhMRAetXrCA8Kj1o/wgPCA8IDwgPDI/fzHIwoPCg8KDwqP2jwJDwqP
2rwKDwqPPE/L/0HPP5BKOqI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEqDgwoYJQ/yh/lY+MDAPTLFc0=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-5.000000000000002, \
-4.330127018922193}, {-2.5881904510252083`, -4.8296291314453415`}, {
        6.123233995736766*^-16, -5.}, {
        2.5881904510252074`, -4.8296291314453415`}, {
        4.999999999999999, -4.330127018922194}, {
        7.0710678118654755`, -3.5355339059327373`}, {
        8.660254037844386, -2.500000000000001}, {
        9.659258262890681, -1.2940952255126046`}, {10., 0.}, {
        9.659258262890683, 1.2940952255126024`}, {8.660254037844387, 
        2.499999999999999}, {7.071067811865479, 3.535533905932736}, {
        5.0000000000000036`, 4.330127018922193}, {2.588190451025214, 
        4.829629131445341}, {6.123233995736766*^-16, 5.}, {-2.588190451025204,
         4.829629131445342}, {-4.999999999999994, 
        4.3301270189221945`}, {-7.071067811865475, 
        3.5355339059327378`}, {-8.660254037844386, 
        2.5000000000000018`}, {-9.659258262890681, 
        1.2940952255126073`}, {-10., 6.123233995736766*^-16}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10., 
        6.123233995736766*^-16}, {-9.659258262890681, 
        1.294095225512605}, {-8.660254037844387, 
        2.4999999999999996`}, {-7.071067811865475, 
        3.5355339059327378`}, {-5.000000000000002, 
        4.330127018922193}, {-2.5881904510252083`, 4.8296291314453415`}, {
        6.123233995736766*^-16, 5.}, {2.5881904510252074`, 
        4.8296291314453415`}, {4.999999999999999, 4.330127018922194}, {
        7.0710678118654755`, 3.5355339059327373`}, {8.660254037844386, 
        2.500000000000001}, {9.659258262890681, 1.2940952255126046`}, {10., 
        0.}, {9.659258262890683, -1.2940952255126024`}, {
        8.660254037844387, -2.499999999999999}, {
        7.071067811865479, -3.535533905932736}, {
        5.0000000000000036`, -4.330127018922193}, {
        2.588190451025214, -4.829629131445341}, {
        6.123233995736766*^-16, -5.}, {-2.588190451025204, \
-4.829629131445342}, {-4.999999999999994, -4.3301270189221945`}, \
{-7.071067811865475, -3.5355339059327378`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.2940952255126073`}, {-10., \
-6.123233995736766*^-16}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx112k4lesaB/CVZc6wBsNCWGu9yNTOlkqF90lUIkVCSKltaFCUZtqGJlTb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      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwllnk4lWsXxjfbnGEPho2w936RqZMjlQrvkygiU0JIqWNoUEiDomNoMvU5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      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015106919127`*^9, 3.614709277146472*^9, 
  3.614729132837289*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[210]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["tracedtiming[3]/tracedtiming[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[212]:="],

Cell[BoxData["1.00885040621446481418647151615095037592`5.698691755263849"], \
"Output",
 CellChangeTimes->{3.563404265601163*^9, 3.563458166317054*^9, 
  3.564487602138385*^9, 3.5661007082988787`*^9, 3.601301242825837*^9, 
  3.601301510816081*^9, 3.614709277294367*^9, 3.614729132969467*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[212]="]
}, Open  ]],

Cell[TextData[{
 "The resulting ray-trace is slightly faster than the ",
 StyleBox["Automatic", "Input"],
 " setting. Finally, we will test the ",
 StyleBox["Solve", "Input"],
 " setting."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
creationtime[4] = 
Timing[
\tellipticalmirror[4] = 
\tCustomMirror[ Function[{s,t}, {10*Cos[s], 5*Sin[s], t}], {2*Pi,10}, \
SurfaceRayIntersections -> Solve]
][[1]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[213]:="],

Cell[BoxData["0.05010699999999999876276746135772555135`4.720498314775884"], \
"Output",
 CellChangeTimes->{3.5634042656575947`*^9, 3.563458167481617*^9, 
  3.564487602427558*^9, 3.56610070841008*^9, 3.601301242925395*^9, 
  3.601301510869388*^9, 3.614709277354088*^9, 3.6147291330240707`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[213]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["creationtime[4]/creationtime[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[214]:="],

Cell[BoxData["0.16242560585039482592527358148871951537`4.655133146764437"], \
"Output",
 CellChangeTimes->{3.563404265705792*^9, 3.5634581685843554`*^9, 
  3.564487602461816*^9, 3.566100708476676*^9, 3.601301243058638*^9, 
  3.601301510910426*^9, 3.614709277391478*^9, 3.614729133065402*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[214]="]
}, Open  ]],

Cell[TextData[{
 "For this ",
 StyleBox["SurfaceRayIntersections -> Solve", "Input"],
 " setting, the component creation time was the fastest of all previous \
tests. We will now test the ray-trace time for ",
 StyleBox["Solve", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[CellGroupData[{

Cell["\<\
tracedtiming[4] = 
Timing[sys = PropagateSystem[{
\tMove[SingleRay[],{0,2}],
\tResonate[ellipticalmirror[4]]}];][[1]]
ShowSystem[sys,PlotType->TopView, PlotPoints->60];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[215]:="],

Cell[BoxData["2.24165400000000003544187165971379727125`6.37116849322148"], \
"Output",
 CellChangeTimes->{3.563404267773855*^9, 3.56345817097368*^9, 
  3.5644876048342*^9, 3.566100711686458*^9, 3.601301243194826*^9, 
  3.601301513126356*^9, 3.614709279626039*^9, 3.614729135320421*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[215]="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1k71KQ0EQhRe9jSEgci0D4RJLiYhBRQI5oIWFjXkEwS7RwsJ3EHyEPION
ZWBPIcHW0lcwlkKw8W9nNsW5uHBZltk5c2a/udXF9fByJYSw9/v97ba2uHbz
Gh/WZ9PR7f3Z3XmHR8+L3cnjR5zvHLw0hxW/01plbLTD7LRFpr1J09jkW7q3
wf2UV3CcdMqs2w9+r2dx5Ljplph7vum2EF3fdCtYnYLuD4fuz/0jdzL2eNfi
A/ePL/OPJ9efmj4K8wX3j2P3Z3VKiH9se39XHv80/3z3fHkf161odbJuhyfu
T96/r2fhMRAetXrCA8Kj1o/wgPCA8IDwgPDI/fzHIwoPCg8KDwqP2jwJDwqP
2rwKDwqPPE/L/0HPP5BKOqI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEqDgwoYJQ/yh/lY+MDAPTLFc0=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-9.659258262890681, -1.294095225512605}, {-10., \
-6.123233995736766*^-16}, {-10., -6.123233995736766*^-16}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-9.659258262890681, -1.294095225512605}, \
{-8.660254037844386, -2.5000000000000018`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.294095225512605}, \
{-9.659258262890681, -1.294095225512605}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-7.071067811865475, \
-3.5355339059327378`}, {-8.660254037844387, -2.4999999999999996`}, \
{-8.660254037844387, -2.4999999999999996`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, -3.5355339059327378`}, \
{-4.999999999999998, -4.330127018922194}, {-4.999999999999998, \
-4.330127018922194}, {-7.071067811865475, -3.5355339059327378`}, \
{-7.071067811865475, -3.5355339059327378`}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-5.000000000000002, -4.330127018922193}, \
{-2.588190451025211, -4.829629131445341}, {-2.588190451025211, \
-4.829629131445341}, {-5.000000000000002, -4.330127018922193}, \
{-5.000000000000002, -4.330127018922193}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{-2.5881904510252083`, -4.8296291314453415`}, \
{-1.6081226496766366`*^-15, -5.}, {-1.6081226496766366`*^-15, -5.}, \
{-2.5881904510252083`, -4.8296291314453415`}, {-2.5881904510252083`, \
-4.8296291314453415`}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{6.123233995736766*^-16, -5.}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      6.123233995736766*^-16, -5.}, {6.123233995736766*^-16, -5.}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{2.5881904510252074`, -4.8296291314453415`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}, {
      2.5881904510252074`, -4.8296291314453415`}, {
      2.5881904510252074`, -4.8296291314453415`}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{4.999999999999999, -4.330127018922194}, {
      7.071067811865474, -3.5355339059327386`}, {
      7.071067811865474, -3.5355339059327386`}, {
      4.999999999999999, -4.330127018922194}, {
      4.999999999999999, -4.330127018922194}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{7.0710678118654755`, -3.5355339059327373`}, {
      8.660254037844386, -2.5}, {8.660254037844386, -2.5}, {
      7.0710678118654755`, -3.5355339059327373`}, {
      7.0710678118654755`, -3.5355339059327373`}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{8.660254037844386, -2.500000000000001}, {
      9.659258262890681, -1.2940952255126055`}, {
      9.659258262890681, -1.2940952255126055`}, {
      8.660254037844386, -2.500000000000001}, {
      8.660254037844386, -2.500000000000001}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{9.659258262890681, -1.2940952255126046`}, {
      10., -8.326672684688674*^-16}, {10., -8.326672684688674*^-16}, {
      9.659258262890681, -1.2940952255126046`}, {
      9.659258262890681, -1.2940952255126046`}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{10., 0.}, {9.659258262890683, 1.2940952255126037`}, {
      9.659258262890683, 1.2940952255126037`}, {10., 0.}, {10., 0.}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{9.659258262890683, 1.2940952255126024`}, {8.660254037844389,
       2.4999999999999982`}, {8.660254037844389, 2.4999999999999982`}, {
      9.659258262890683, 1.2940952255126024`}, {9.659258262890683, 
      1.2940952255126024`}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{8.660254037844387, 2.499999999999999}, {7.071067811865477, 
      3.535533905932737}, {7.071067811865477, 3.535533905932737}, {
      8.660254037844387, 2.499999999999999}, {8.660254037844387, 
      2.499999999999999}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{7.071067811865479, 3.535533905932736}, {5.000000000000004, 
      4.330127018922192}, {5.000000000000004, 4.330127018922192}, {
      7.071067811865479, 3.535533905932736}, {7.071067811865479, 
      3.535533905932736}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{5.0000000000000036`, 4.330127018922193}, {2.588190451025212,
       4.829629131445341}, {2.588190451025212, 4.829629131445341}, {
      5.0000000000000036`, 4.330127018922193}, {5.0000000000000036`, 
      4.330127018922193}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{2.588190451025214, 4.829629131445341}, {
      7.273661547324617*^-15, 5.}, {7.273661547324617*^-15, 5.}, {
      2.588190451025214, 4.829629131445341}, {2.588190451025214, 
      4.829629131445341}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{6.123233995736766*^-16, 5.}, {-2.5881904510252065`, 
      4.8296291314453415`}, {-2.5881904510252065`, 4.8296291314453415`}, {
      6.123233995736766*^-16, 5.}, {6.123233995736766*^-16, 5.}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-2.588190451025204, 4.829629131445342}, {-4.999999999999998,
       4.330127018922194}, {-4.999999999999998, 
      4.330127018922194}, {-2.588190451025204, 
      4.829629131445342}, {-2.588190451025204, 4.829629131445342}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-4.999999999999994, 
      4.3301270189221945`}, {-7.071067811865471, 
      3.5355339059327395`}, {-7.071067811865471, 
      3.5355339059327395`}, {-4.999999999999994, 
      4.3301270189221945`}, {-4.999999999999994, 4.3301270189221945`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-7.071067811865475, 
      3.5355339059327378`}, {-8.660254037844387, 
      2.4999999999999996`}, {-8.660254037844387, 
      2.4999999999999996`}, {-7.071067811865475, 
      3.5355339059327378`}, {-7.071067811865475, 3.5355339059327378`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-8.660254037844386, 
      2.5000000000000018`}, {-9.659258262890681, 
      1.294095225512605}, {-9.659258262890681, 
      1.294095225512605}, {-8.660254037844386, 
      2.5000000000000018`}, {-8.660254037844386, 2.5000000000000018`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     PolygonBox[{{-9.659258262890681, 1.2940952255126073`}, {-10., 
      2.8327694488239896`*^-15}, {-10., 
      2.8327694488239896`*^-15}, {-9.659258262890681, 
      1.2940952255126073`}, {-9.659258262890681, 1.2940952255126073`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-10., -6.123233995736766*^-16}, {-9.659258262890681, \
-1.294095225512605}, {-8.660254037844387, -2.4999999999999996`}, \
{-7.071067811865475, -3.5355339059327378`}, {-5.000000000000002, \
-4.330127018922193}, {-2.5881904510252083`, -4.8296291314453415`}, {
        6.123233995736766*^-16, -5.}, {
        2.5881904510252074`, -4.8296291314453415`}, {
        4.999999999999999, -4.330127018922194}, {
        7.0710678118654755`, -3.5355339059327373`}, {
        8.660254037844386, -2.500000000000001}, {
        9.659258262890681, -1.2940952255126046`}, {10., 0.}, {
        9.659258262890683, 1.2940952255126024`}, {8.660254037844387, 
        2.499999999999999}, {7.071067811865479, 3.535533905932736}, {
        5.0000000000000036`, 4.330127018922193}, {2.588190451025214, 
        4.829629131445341}, {6.123233995736766*^-16, 5.}, {-2.588190451025204,
         4.829629131445342}, {-4.999999999999994, 
        4.3301270189221945`}, {-7.071067811865475, 
        3.5355339059327378`}, {-8.660254037844386, 
        2.5000000000000018`}, {-9.659258262890681, 
        1.2940952255126073`}, {-10., 6.123233995736766*^-16}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10., 
        6.123233995736766*^-16}, {-9.659258262890681, 
        1.294095225512605}, {-8.660254037844387, 
        2.4999999999999996`}, {-7.071067811865475, 
        3.5355339059327378`}, {-5.000000000000002, 
        4.330127018922193}, {-2.5881904510252083`, 4.8296291314453415`}, {
        6.123233995736766*^-16, 5.}, {2.5881904510252074`, 
        4.8296291314453415`}, {4.999999999999999, 4.330127018922194}, {
        7.0710678118654755`, 3.5355339059327373`}, {8.660254037844386, 
        2.500000000000001}, {9.659258262890681, 1.2940952255126046`}, {10., 
        0.}, {9.659258262890683, -1.2940952255126024`}, {
        8.660254037844387, -2.499999999999999}, {
        7.071067811865479, -3.535533905932736}, {
        5.0000000000000036`, -4.330127018922193}, {
        2.588190451025214, -4.829629131445341}, {
        6.123233995736766*^-16, -5.}, {-2.588190451025204, \
-4.829629131445342}, {-4.999999999999994, -4.3301270189221945`}, \
{-7.071067811865475, -3.5355339059327378`}, {-8.660254037844386, \
-2.5000000000000018`}, {-9.659258262890681, -1.2940952255126073`}, {-10., \
-6.123233995736766*^-16}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 
        0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}, {-10, 0}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx113k01WkfAPDLta93wbUk994fBmlSaTHk9yS0kLKEZLTSqkHSLkKFakwh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      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwlVnk0lekfv/adu+Baknvvi7E1SVqM5X0SUiRbCKMQadEgqVQiVKjGZEmo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      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301513361998*^9, 3.614709279825158*^9, 
  3.61472913552297*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"During evaluation of In[215]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["tracedtiming[4]/tracedtiming[1]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"In[217]:="],

Cell[BoxData["2.36241349038817215598580352024978105653`5.844517373781383"], \
"Output",
 CellChangeTimes->{3.563404268256357*^9, 3.563458171367176*^9, 
  3.5644876064045877`*^9, 3.5661007123577747`*^9, 3.60130124326081*^9, 
  3.601301513499063*^9, 3.6147092799502296`*^9, 3.614729135659251*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"},
 CellLabel->"Out[217]="]
}, Open  ]],

Cell[TextData[{
 "The trace time for this setting, however, was the slowest of all previous \
settings. In general, both ",
 StyleBox["Solve", "Input"],
 " and ",
 StyleBox["Symbol", "Input"],
 " find the closed-form solution to a ray-surface intersection point. ",
 StyleBox["Symbol", "Input"],
 " operates by finding the generalized solution only once during the \
component creation and then storing this solution inside the component prior \
to the ray-trace run time. ",
 StyleBox["Solve", "Input"],
 ", on the other hand, works by symbolically solving the ray-surface \
equations at each new intersection point during the actual ray-trace process. \
Because of this, the ",
 StyleBox["Solve", "Input"],
 " ray-trace operates much more slowly than ",
 StyleBox["Symbol", "Input"],
 ", but ",
 StyleBox["Solve", "Input"],
 " can handle far more complex surface functions than ",
 StyleBox["Symbol", "Input"],
 " since the run-time symbolic equations presented to ",
 StyleBox["Solve", "Input"],
 " can be simplified to a much greater extent than the equations presented to \
",
 StyleBox["Symbol", "Input"],
 ". In fact, ",
 StyleBox["SurfaceRayIntersections -> Solve", "Input"],
 " is one of the most robust settings of all. Unfortunately, it is also the \
slowest."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3.4 Building a \"Black Hole\"", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "4.3.4", "Custom Surface Shapes", 
   "PR4.3", "PR4.3.4"}],

Cell["\<\
In this next example, we will create a new component that acts as a \
reflective tapered tube, similar in nature to an optical fiber. To give this \
new component a tube shape, we use the hyperbolic function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell["S[x_,y_] = 100/(x^2 + y^2);", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[218]:="],

Cell[TextData[{
 "A simple plot of ",
 StyleBox["100/x^2",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " reveals its basic nature."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell["Plot[100./x^2,{x,-5,5},PlotRange->{0,100}];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[219]:="],

Cell[TextData[{
 "Note the singularity at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0. This singularity must be carefully treated when defining the new \
component in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ". Since our component will be three-dimensional, we next plot the \
three-dimensional hyperbolic function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell["\<\
Plot3D[S[x,y], {x,-2,2}, {y,-2,2}, PlotRange->{0,1000}, PlotPoints->50];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[220]:="],

Cell[TextData[{
 "Having seen the basic nature of the hyperbolic function, we are nearly \
ready to fully define the component function. The pole in our function will \
be masked by putting a hole at its center. In addition, the option ",
 StyleBox["FunctionCenter->0",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " will be used to redefine the surface function at ",
 StyleBox["S[0,0]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " to be zero, instead of infinity. We give the new component function the \
name ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " for its geometric likeness to the gravitation field around a black hole in \
space."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "FreezeIncrement", "FunctionCenter", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],

Cell[TextData[{
 "In addition to ",
 StyleBox["Resonate",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", we use ",
 StyleBox["CustomMirror",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Hole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " to put a hole in the component center. ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " takes arguments for the size of its mouth and the size of its hole at the \
center."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "FreezeIncrement", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],

Cell["\<\
Clear[BlackHole];

BlackHole[aperture_,holeaperture_,opts___] := 
Block[{options},
\toptions = Flatten[{opts,Options[CustomMirror]}];
\tResonate[
\t\tCustomMirror[
\t\t\tFunction[100./(#1^2 + #2^2)], 
\t\t\taperture, 
\t\t\tFunctionCenter -> 0.,
\t\t\tHole -> holeaperture,
\t\t\toptions],
\t\toptions
\t]
];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[221]:="],

Cell[TextData[{
 "Notice that we use the ",
 StyleBox["CustomMirror",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " options to define ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". This eliminates the need to create a special options listing for ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". First let's just make a three-dimensional plot of ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell[CellGroupData[{

Cell["ShowSystem[BlackHole[5,2.5,GraphicDesign->Wire]];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[224]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{64., 1.25, 0.}, {36.00000000000001, 1.6666666666666665`, 
      0.}, {36.00000000000002, 1.6098763771484468`, 0.4313650751708678}, {
      64.00000000000003, 1.2074072828613351`, 0.32352380637815087`}, {64., 
      1.25, 0.}}], 
     Line3DBox[{{64.00000000000003, 1.2074072828613351`, 
      0.32352380637815087`}, {36.00000000000002, 1.6098763771484468`, 
      0.4313650751708678}, {36.000000000000014`, 1.443375672974064, 
      0.8333333333333333}, {64.00000000000001, 1.0825317547305482`, 0.625}, {
      64.00000000000003, 1.2074072828613351`, 0.32352380637815087`}}], 
     Line3DBox[{{64.00000000000001, 1.0825317547305482`, 0.625}, {
      36.000000000000014`, 1.443375672974064, 0.8333333333333333}, {
      36.000000000000014`, 1.178511301977579, 1.178511301977579}, {
      64.00000000000001, 0.8838834764831843, 0.8838834764831843}, {
      64.00000000000001, 1.0825317547305482`, 0.625}}], 
     Line3DBox[{{64.00000000000001, 0.8838834764831843, 0.8838834764831843}, {
      36.000000000000014`, 1.178511301977579, 1.178511301977579}, {
      36.000000000000014`, 0.8333333333333333, 1.443375672974064}, {
      64.00000000000001, 0.625, 1.0825317547305482`}, {64.00000000000001, 
      0.8838834764831843, 0.8838834764831843}}], 
     Line3DBox[{{64.00000000000001, 0.625, 1.0825317547305482`}, {
      36.000000000000014`, 0.8333333333333333, 1.443375672974064}, {
      36.00000000000002, 0.4313650751708678, 1.6098763771484468`}, {
      64.00000000000003, 0.32352380637815087`, 1.2074072828613351`}, {
      64.00000000000001, 0.625, 1.0825317547305482`}}], 
     Line3DBox[{{64.00000000000003, 0.32352380637815087`, 
      1.2074072828613351`}, {36.00000000000002, 0.4313650751708678, 
      1.6098763771484468`}, {36.00000000000001, 0., 1.6666666666666665`}, {
      64., 0., 1.25}, {64.00000000000003, 0.32352380637815087`, 
      1.2074072828613351`}}], 
     Line3DBox[{{64., 0., 1.25}, {36.00000000000001, 0., 
      1.6666666666666665`}, {36.00000000000002, -0.4313650751708678, 
      1.6098763771484468`}, {64.00000000000003, -0.32352380637815087`, 
      1.2074072828613351`}, {64., 0., 1.25}}], 
     Line3DBox[{{64.00000000000003, -0.32352380637815087`, 
      1.2074072828613351`}, {36.00000000000002, -0.4313650751708678, 
      1.6098763771484468`}, {36.000000000000014`, -0.8333333333333333, 
      1.443375672974064}, {64.00000000000001, -0.625, 1.0825317547305482`}, {
      64.00000000000003, -0.32352380637815087`, 1.2074072828613351`}}], 
     Line3DBox[{{64.00000000000001, -0.625, 1.0825317547305482`}, {
      36.000000000000014`, -0.8333333333333333, 1.443375672974064}, {
      36.000000000000014`, -1.178511301977579, 1.178511301977579}, {
      64.00000000000001, -0.8838834764831843, 0.8838834764831843}, {
      64.00000000000001, -0.625, 1.0825317547305482`}}], 
     Line3DBox[{{64.00000000000001, -0.8838834764831843, 
      0.8838834764831843}, {36.000000000000014`, -1.178511301977579, 
      1.178511301977579}, {36.000000000000014`, -1.443375672974064, 
      0.8333333333333333}, {64.00000000000001, -1.0825317547305482`, 0.625}, {
      64.00000000000001, -0.8838834764831843, 0.8838834764831843}}], 
     Line3DBox[{{64.00000000000001, -1.0825317547305482`, 0.625}, {
      36.000000000000014`, -1.443375672974064, 0.8333333333333333}, {
      36.00000000000002, -1.6098763771484468`, 0.4313650751708678}, {
      64.00000000000003, -1.2074072828613351`, 0.32352380637815087`}, {
      64.00000000000001, -1.0825317547305482`, 0.625}}], 
     Line3DBox[{{64.00000000000003, -1.2074072828613351`, 
      0.32352380637815087`}, {36.00000000000002, -1.6098763771484468`, 
      0.4313650751708678}, {36.00000000000001, -1.6666666666666665`, 0.}, {
      64., -1.25, 0.}, {64.00000000000003, -1.2074072828613351`, 
      0.32352380637815087`}}], 
     Line3DBox[{{64., -1.25, 0.}, {36.00000000000001, -1.6666666666666665`, 
      0.}, {36.00000000000002, -1.6098763771484468`, -0.4313650751708678}, {
      64.00000000000003, -1.2074072828613351`, -0.32352380637815087`}, {
      64., -1.25, 0.}}], 
     Line3DBox[{{
      64.00000000000003, -1.2074072828613351`, -0.32352380637815087`}, {
      36.00000000000002, -1.6098763771484468`, -0.4313650751708678}, {
      36.000000000000014`, -1.443375672974064, -0.8333333333333333}, {
      64.00000000000001, -1.0825317547305482`, -0.625}, {
      64.00000000000003, -1.2074072828613351`, -0.32352380637815087`}}], 
     Line3DBox[{{64.00000000000001, -1.0825317547305482`, -0.625}, {
      36.000000000000014`, -1.443375672974064, -0.8333333333333333}, {
      36.000000000000014`, -1.178511301977579, -1.178511301977579}, {
      64.00000000000001, -0.8838834764831843, -0.8838834764831843}, {
      64.00000000000001, -1.0825317547305482`, -0.625}}], 
     Line3DBox[{{
      64.00000000000001, -0.8838834764831843, -0.8838834764831843}, {
      36.000000000000014`, -1.178511301977579, -1.178511301977579}, {
      36.000000000000014`, -0.8333333333333333, -1.443375672974064}, {
      64.00000000000001, -0.625, -1.0825317547305482`}, {
      64.00000000000001, -0.8838834764831843, -0.8838834764831843}}], 
     Line3DBox[{{64.00000000000001, -0.625, -1.0825317547305482`}, {
      36.000000000000014`, -0.8333333333333333, -1.443375672974064}, {
      36.00000000000002, -0.4313650751708678, -1.6098763771484468`}, {
      64.00000000000003, -0.32352380637815087`, -1.2074072828613351`}, {
      64.00000000000001, -0.625, -1.0825317547305482`}}], 
     Line3DBox[{{
      64.00000000000003, -0.32352380637815087`, -1.2074072828613351`}, {
      36.00000000000002, -0.4313650751708678, -1.6098763771484468`}, {
      36.00000000000001, 0., -1.6666666666666665`}, {64., 0., -1.25}, {
      64.00000000000003, -0.32352380637815087`, -1.2074072828613351`}}], 
     Line3DBox[{{64., 0., -1.25}, {36.00000000000001, 
      0., -1.6666666666666665`}, {36.00000000000002, 
      0.4313650751708678, -1.6098763771484468`}, {64.00000000000003, 
      0.32352380637815087`, -1.2074072828613351`}, {64., 0., -1.25}}], 
     Line3DBox[{{64.00000000000003, 
      0.32352380637815087`, -1.2074072828613351`}, {36.00000000000002, 
      0.4313650751708678, -1.6098763771484468`}, {36.000000000000014`, 
      0.8333333333333333, -1.443375672974064}, {64.00000000000001, 
      0.625, -1.0825317547305482`}, {64.00000000000003, 
      0.32352380637815087`, -1.2074072828613351`}}], 
     Line3DBox[{{64.00000000000001, 0.625, -1.0825317547305482`}, {
      36.000000000000014`, 0.8333333333333333, -1.443375672974064}, {
      36.000000000000014`, 1.178511301977579, -1.178511301977579}, {
      64.00000000000001, 0.8838834764831843, -0.8838834764831843}, {
      64.00000000000001, 0.625, -1.0825317547305482`}}], 
     Line3DBox[{{64.00000000000001, 
      0.8838834764831843, -0.8838834764831843}, {36.000000000000014`, 
      1.178511301977579, -1.178511301977579}, {36.000000000000014`, 
      1.443375672974064, -0.8333333333333333}, {64.00000000000001, 
      1.0825317547305482`, -0.625}, {64.00000000000001, 
      0.8838834764831843, -0.8838834764831843}}], 
     Line3DBox[{{64.00000000000001, 1.0825317547305482`, -0.625}, {
      36.000000000000014`, 1.443375672974064, -0.8333333333333333}, {
      36.00000000000002, 1.6098763771484468`, -0.4313650751708678}, {
      64.00000000000003, 1.2074072828613351`, -0.32352380637815087`}, {
      64.00000000000001, 1.0825317547305482`, -0.625}}], 
     Line3DBox[{{64.00000000000003, 
      1.2074072828613351`, -0.32352380637815087`}, {36.00000000000002, 
      1.6098763771484468`, -0.4313650751708678}, {36.00000000000001, 
      1.6666666666666665`, 0.}, {64., 1.25, 0.}, {64.00000000000003, 
      1.2074072828613351`, -0.32352380637815087`}}], 
     Line3DBox[{{36.00000000000001, 1.6666666666666665`, 0.}, {
      23.040000000000006`, 2.083333333333333, 0.}, {23.040000000000017`, 
      2.0123454714355584`, 0.5392063439635848}, {36.00000000000002, 
      1.6098763771484468`, 0.4313650751708678}, {36.00000000000001, 
      1.6666666666666665`, 0.}}], 
     Line3DBox[{{36.00000000000002, 1.6098763771484468`, 
      0.4313650751708678}, {23.040000000000017`, 2.0123454714355584`, 
      0.5392063439635848}, {23.040000000000006`, 1.8042195912175802`, 
      1.0416666666666665`}, {36.000000000000014`, 1.443375672974064, 
      0.8333333333333333}, {36.00000000000002, 1.6098763771484468`, 
      0.4313650751708678}}], 
     Line3DBox[{{36.000000000000014`, 1.443375672974064, 
      0.8333333333333333}, {23.040000000000006`, 1.8042195912175802`, 
      1.0416666666666665`}, {23.040000000000006`, 1.4731391274719738`, 
      1.4731391274719738`}, {36.000000000000014`, 1.178511301977579, 
      1.178511301977579}, {36.000000000000014`, 1.443375672974064, 
      0.8333333333333333}}], 
     Line3DBox[{{36.000000000000014`, 1.178511301977579, 1.178511301977579}, {
      23.040000000000006`, 1.4731391274719738`, 1.4731391274719738`}, {
      23.040000000000006`, 1.0416666666666665`, 1.8042195912175802`}, {
      36.000000000000014`, 0.8333333333333333, 1.443375672974064}, {
      36.000000000000014`, 1.178511301977579, 1.178511301977579}}], 
     Line3DBox[{{36.000000000000014`, 0.8333333333333333, 
      1.443375672974064}, {23.040000000000006`, 1.0416666666666665`, 
      1.8042195912175802`}, {23.040000000000017`, 0.5392063439635848, 
      2.0123454714355584`}, {36.00000000000002, 0.4313650751708678, 
      1.6098763771484468`}, {36.000000000000014`, 0.8333333333333333, 
      1.443375672974064}}], 
     Line3DBox[{{36.00000000000002, 0.4313650751708678, 
      1.6098763771484468`}, {23.040000000000017`, 0.5392063439635848, 
      2.0123454714355584`}, {23.040000000000006`, 0., 2.083333333333333}, {
      36.00000000000001, 0., 1.6666666666666665`}, {36.00000000000002, 
      0.4313650751708678, 1.6098763771484468`}}], 
     Line3DBox[{{36.00000000000001, 0., 1.6666666666666665`}, {
      23.040000000000006`, 0., 2.083333333333333}, {
      23.040000000000017`, -0.5392063439635848, 2.0123454714355584`}, {
      36.00000000000002, -0.4313650751708678, 1.6098763771484468`}, {
      36.00000000000001, 0., 1.6666666666666665`}}], 
     Line3DBox[{{36.00000000000002, -0.4313650751708678, 
      1.6098763771484468`}, {23.040000000000017`, -0.5392063439635848, 
      2.0123454714355584`}, {23.040000000000006`, -1.0416666666666665`, 
      1.8042195912175802`}, {36.000000000000014`, -0.8333333333333333, 
      1.443375672974064}, {36.00000000000002, -0.4313650751708678, 
      1.6098763771484468`}}], 
     Line3DBox[{{36.000000000000014`, -0.8333333333333333, 
      1.443375672974064}, {23.040000000000006`, -1.0416666666666665`, 
      1.8042195912175802`}, {23.040000000000006`, -1.4731391274719738`, 
      1.4731391274719738`}, {36.000000000000014`, -1.178511301977579, 
      1.178511301977579}, {36.000000000000014`, -0.8333333333333333, 
      1.443375672974064}}], 
     Line3DBox[{{36.000000000000014`, -1.178511301977579, 
      1.178511301977579}, {23.040000000000006`, -1.4731391274719738`, 
      1.4731391274719738`}, {23.040000000000006`, -1.8042195912175802`, 
      1.0416666666666665`}, {36.000000000000014`, -1.443375672974064, 
      0.8333333333333333}, {36.000000000000014`, -1.178511301977579, 
      1.178511301977579}}], 
     Line3DBox[{{36.000000000000014`, -1.443375672974064, 
      0.8333333333333333}, {23.040000000000006`, -1.8042195912175802`, 
      1.0416666666666665`}, {23.040000000000017`, -2.0123454714355584`, 
      0.5392063439635848}, {36.00000000000002, -1.6098763771484468`, 
      0.4313650751708678}, {36.000000000000014`, -1.443375672974064, 
      0.8333333333333333}}], 
     Line3DBox[{{36.00000000000002, -1.6098763771484468`, 
      0.4313650751708678}, {23.040000000000017`, -2.0123454714355584`, 
      0.5392063439635848}, {23.040000000000006`, -2.083333333333333, 0.}, {
      36.00000000000001, -1.6666666666666665`, 0.}, {
      36.00000000000002, -1.6098763771484468`, 0.4313650751708678}}], 
     Line3DBox[{{36.00000000000001, -1.6666666666666665`, 0.}, {
      23.040000000000006`, -2.083333333333333, 0.}, {
      23.040000000000017`, -2.0123454714355584`, -0.5392063439635848}, {
      36.00000000000002, -1.6098763771484468`, -0.4313650751708678}, {
      36.00000000000001, -1.6666666666666665`, 0.}}], 
     Line3DBox[{{
      36.00000000000002, -1.6098763771484468`, -0.4313650751708678}, {
      23.040000000000017`, -2.0123454714355584`, -0.5392063439635848}, {
      23.040000000000006`, -1.8042195912175802`, -1.0416666666666665`}, {
      36.000000000000014`, -1.443375672974064, -0.8333333333333333}, {
      36.00000000000002, -1.6098763771484468`, -0.4313650751708678}}], 
     Line3DBox[{{
      36.000000000000014`, -1.443375672974064, -0.8333333333333333}, {
      23.040000000000006`, -1.8042195912175802`, -1.0416666666666665`}, {
      23.040000000000006`, -1.4731391274719738`, -1.4731391274719738`}, {
      36.000000000000014`, -1.178511301977579, -1.178511301977579}, {
      36.000000000000014`, -1.443375672974064, -0.8333333333333333}}], 
     Line3DBox[{{
      36.000000000000014`, -1.178511301977579, -1.178511301977579}, {
      23.040000000000006`, -1.4731391274719738`, -1.4731391274719738`}, {
      23.040000000000006`, -1.0416666666666665`, -1.8042195912175802`}, {
      36.000000000000014`, -0.8333333333333333, -1.443375672974064}, {
      36.000000000000014`, -1.178511301977579, -1.178511301977579}}], 
     Line3DBox[{{
      36.000000000000014`, -0.8333333333333333, -1.443375672974064}, {
      23.040000000000006`, -1.0416666666666665`, -1.8042195912175802`}, {
      23.040000000000017`, -0.5392063439635848, -2.0123454714355584`}, {
      36.00000000000002, -0.4313650751708678, -1.6098763771484468`}, {
      36.000000000000014`, -0.8333333333333333, -1.443375672974064}}], 
     Line3DBox[{{
      36.00000000000002, -0.4313650751708678, -1.6098763771484468`}, {
      23.040000000000017`, -0.5392063439635848, -2.0123454714355584`}, {
      23.040000000000006`, 0., -2.083333333333333}, {36.00000000000001, 
      0., -1.6666666666666665`}, {
      36.00000000000002, -0.4313650751708678, -1.6098763771484468`}}], 
     Line3DBox[{{36.00000000000001, 0., -1.6666666666666665`}, {
      23.040000000000006`, 0., -2.083333333333333}, {23.040000000000017`, 
      0.5392063439635848, -2.0123454714355584`}, {36.00000000000002, 
      0.4313650751708678, -1.6098763771484468`}, {36.00000000000001, 
      0., -1.6666666666666665`}}], 
     Line3DBox[{{36.00000000000002, 
      0.4313650751708678, -1.6098763771484468`}, {23.040000000000017`, 
      0.5392063439635848, -2.0123454714355584`}, {23.040000000000006`, 
      1.0416666666666665`, -1.8042195912175802`}, {36.000000000000014`, 
      0.8333333333333333, -1.443375672974064}, {36.00000000000002, 
      0.4313650751708678, -1.6098763771484468`}}], 
     Line3DBox[{{36.000000000000014`, 
      0.8333333333333333, -1.443375672974064}, {23.040000000000006`, 
      1.0416666666666665`, -1.8042195912175802`}, {23.040000000000006`, 
      1.4731391274719738`, -1.4731391274719738`}, {36.000000000000014`, 
      1.178511301977579, -1.178511301977579}, {36.000000000000014`, 
      0.8333333333333333, -1.443375672974064}}], 
     Line3DBox[{{36.000000000000014`, 
      1.178511301977579, -1.178511301977579}, {23.040000000000006`, 
      1.4731391274719738`, -1.4731391274719738`}, {23.040000000000006`, 
      1.8042195912175802`, -1.0416666666666665`}, {36.000000000000014`, 
      1.443375672974064, -0.8333333333333333}, {36.000000000000014`, 
      1.178511301977579, -1.178511301977579}}], 
     Line3DBox[{{36.000000000000014`, 
      1.443375672974064, -0.8333333333333333}, {23.040000000000006`, 
      1.8042195912175802`, -1.0416666666666665`}, {23.040000000000017`, 
      2.0123454714355584`, -0.5392063439635848}, {36.00000000000002, 
      1.6098763771484468`, -0.4313650751708678}, {36.000000000000014`, 
      1.443375672974064, -0.8333333333333333}}], 
     Line3DBox[{{36.00000000000002, 
      1.6098763771484468`, -0.4313650751708678}, {23.040000000000017`, 
      2.0123454714355584`, -0.5392063439635848}, {23.040000000000006`, 
      2.083333333333333, 0.}, {36.00000000000001, 1.6666666666666665`, 0.}, {
      36.00000000000002, 1.6098763771484468`, -0.4313650751708678}}], 
     Line3DBox[{{23.040000000000006`, 2.083333333333333, 0.}, {16., 2.5, 
      0.}, {16.000000000000007`, 2.4148145657226703`, 0.6470476127563017}, {
      23.040000000000017`, 2.0123454714355584`, 0.5392063439635848}, {
      23.040000000000006`, 2.083333333333333, 0.}}], 
     Line3DBox[{{23.040000000000017`, 2.0123454714355584`, 
      0.5392063439635848}, {16.000000000000007`, 2.4148145657226703`, 
      0.6470476127563017}, {16.000000000000004`, 2.1650635094610964`, 1.25}, {
      23.040000000000006`, 1.8042195912175802`, 1.0416666666666665`}, {
      23.040000000000017`, 2.0123454714355584`, 0.5392063439635848}}], 
     Line3DBox[{{23.040000000000006`, 1.8042195912175802`, 
      1.0416666666666665`}, {16.000000000000004`, 2.1650635094610964`, 
      1.25}, {16.000000000000004`, 1.7677669529663687`, 
      1.7677669529663687`}, {23.040000000000006`, 1.4731391274719738`, 
      1.4731391274719738`}, {23.040000000000006`, 1.8042195912175802`, 
      1.0416666666666665`}}], 
     Line3DBox[{{23.040000000000006`, 1.4731391274719738`, 
      1.4731391274719738`}, {16.000000000000004`, 1.7677669529663687`, 
      1.7677669529663687`}, {16.000000000000004`, 1.25, 
      2.1650635094610964`}, {23.040000000000006`, 1.0416666666666665`, 
      1.8042195912175802`}, {23.040000000000006`, 1.4731391274719738`, 
      1.4731391274719738`}}], 
     Line3DBox[{{23.040000000000006`, 1.0416666666666665`, 
      1.8042195912175802`}, {16.000000000000004`, 1.25, 
      2.1650635094610964`}, {16.000000000000007`, 0.6470476127563017, 
      2.4148145657226703`}, {23.040000000000017`, 0.5392063439635848, 
      2.0123454714355584`}, {23.040000000000006`, 1.0416666666666665`, 
      1.8042195912175802`}}], 
     Line3DBox[{{23.040000000000017`, 0.5392063439635848, 
      2.0123454714355584`}, {16.000000000000007`, 0.6470476127563017, 
      2.4148145657226703`}, {16., 0., 2.5}, {23.040000000000006`, 0., 
      2.083333333333333}, {23.040000000000017`, 0.5392063439635848, 
      2.0123454714355584`}}], 
     Line3DBox[{{23.040000000000006`, 0., 2.083333333333333}, {16., 0., 
      2.5}, {16.000000000000007`, -0.6470476127563017, 2.4148145657226703`}, {
      23.040000000000017`, -0.5392063439635848, 2.0123454714355584`}, {
      23.040000000000006`, 0., 2.083333333333333}}], 
     Line3DBox[{{23.040000000000017`, -0.5392063439635848, 
      2.0123454714355584`}, {16.000000000000007`, -0.6470476127563017, 
      2.4148145657226703`}, {16.000000000000004`, -1.25, 
      2.1650635094610964`}, {23.040000000000006`, -1.0416666666666665`, 
      1.8042195912175802`}, {23.040000000000017`, -0.5392063439635848, 
      2.0123454714355584`}}], 
     Line3DBox[{{23.040000000000006`, -1.0416666666666665`, 
      1.8042195912175802`}, {16.000000000000004`, -1.25, 
      2.1650635094610964`}, {16.000000000000004`, -1.7677669529663687`, 
      1.7677669529663687`}, {23.040000000000006`, -1.4731391274719738`, 
      1.4731391274719738`}, {23.040000000000006`, -1.0416666666666665`, 
      1.8042195912175802`}}], 
     Line3DBox[{{23.040000000000006`, -1.4731391274719738`, 
      1.4731391274719738`}, {16.000000000000004`, -1.7677669529663687`, 
      1.7677669529663687`}, {16.000000000000004`, -2.1650635094610964`, 
      1.25}, {23.040000000000006`, -1.8042195912175802`, 
      1.0416666666666665`}, {23.040000000000006`, -1.4731391274719738`, 
      1.4731391274719738`}}], 
     Line3DBox[{{23.040000000000006`, -1.8042195912175802`, 
      1.0416666666666665`}, {16.000000000000004`, -2.1650635094610964`, 
      1.25}, {16.000000000000007`, -2.4148145657226703`, 
      0.6470476127563017}, {23.040000000000017`, -2.0123454714355584`, 
      0.5392063439635848}, {23.040000000000006`, -1.8042195912175802`, 
      1.0416666666666665`}}], 
     Line3DBox[{{23.040000000000017`, -2.0123454714355584`, 
      0.5392063439635848}, {16.000000000000007`, -2.4148145657226703`, 
      0.6470476127563017}, {16., -2.5, 0.}, {
      23.040000000000006`, -2.083333333333333, 0.}, {
      23.040000000000017`, -2.0123454714355584`, 0.5392063439635848}}], 
     Line3DBox[{{23.040000000000006`, -2.083333333333333, 0.}, {16., -2.5, 
      0.}, {16.000000000000007`, -2.4148145657226703`, -0.6470476127563017}, {
      23.040000000000017`, -2.0123454714355584`, -0.5392063439635848}, {
      23.040000000000006`, -2.083333333333333, 0.}}], 
     Line3DBox[{{
      23.040000000000017`, -2.0123454714355584`, -0.5392063439635848}, {
      16.000000000000007`, -2.4148145657226703`, -0.6470476127563017}, {
      16.000000000000004`, -2.1650635094610964`, -1.25}, {
      23.040000000000006`, -1.8042195912175802`, -1.0416666666666665`}, {
      23.040000000000017`, -2.0123454714355584`, -0.5392063439635848}}], 
     Line3DBox[{{
      23.040000000000006`, -1.8042195912175802`, -1.0416666666666665`}, {
      16.000000000000004`, -2.1650635094610964`, -1.25}, {
      16.000000000000004`, -1.7677669529663687`, -1.7677669529663687`}, {
      23.040000000000006`, -1.4731391274719738`, -1.4731391274719738`}, {
      23.040000000000006`, -1.8042195912175802`, -1.0416666666666665`}}], 
     Line3DBox[{{
      23.040000000000006`, -1.4731391274719738`, -1.4731391274719738`}, {
      16.000000000000004`, -1.7677669529663687`, -1.7677669529663687`}, {
      16.000000000000004`, -1.25, -2.1650635094610964`}, {
      23.040000000000006`, -1.0416666666666665`, -1.8042195912175802`}, {
      23.040000000000006`, -1.4731391274719738`, -1.4731391274719738`}}], 
     Line3DBox[{{
      23.040000000000006`, -1.0416666666666665`, -1.8042195912175802`}, {
      16.000000000000004`, -1.25, -2.1650635094610964`}, {
      16.000000000000007`, -0.6470476127563017, -2.4148145657226703`}, {
      23.040000000000017`, -0.5392063439635848, -2.0123454714355584`}, {
      23.040000000000006`, -1.0416666666666665`, -1.8042195912175802`}}], 
     Line3DBox[{{
      23.040000000000017`, -0.5392063439635848, -2.0123454714355584`}, {
      16.000000000000007`, -0.6470476127563017, -2.4148145657226703`}, {16., 
      0., -2.5}, {23.040000000000006`, 0., -2.083333333333333}, {
      23.040000000000017`, -0.5392063439635848, -2.0123454714355584`}}], 
     Line3DBox[{{23.040000000000006`, 0., -2.083333333333333}, {16., 
      0., -2.5}, {16.000000000000007`, 
      0.6470476127563017, -2.4148145657226703`}, {23.040000000000017`, 
      0.5392063439635848, -2.0123454714355584`}, {23.040000000000006`, 
      0., -2.083333333333333}}], 
     Line3DBox[{{23.040000000000017`, 
      0.5392063439635848, -2.0123454714355584`}, {16.000000000000007`, 
      0.6470476127563017, -2.4148145657226703`}, {16.000000000000004`, 
      1.25, -2.1650635094610964`}, {23.040000000000006`, 
      1.0416666666666665`, -1.8042195912175802`}, {23.040000000000017`, 
      0.5392063439635848, -2.0123454714355584`}}], 
     Line3DBox[{{23.040000000000006`, 
      1.0416666666666665`, -1.8042195912175802`}, {16.000000000000004`, 
      1.25, -2.1650635094610964`}, {16.000000000000004`, 
      1.7677669529663687`, -1.7677669529663687`}, {23.040000000000006`, 
      1.4731391274719738`, -1.4731391274719738`}, {23.040000000000006`, 
      1.0416666666666665`, -1.8042195912175802`}}], 
     Line3DBox[{{23.040000000000006`, 
      1.4731391274719738`, -1.4731391274719738`}, {16.000000000000004`, 
      1.7677669529663687`, -1.7677669529663687`}, {16.000000000000004`, 
      2.1650635094610964`, -1.25}, {23.040000000000006`, 
      1.8042195912175802`, -1.0416666666666665`}, {23.040000000000006`, 
      1.4731391274719738`, -1.4731391274719738`}}], 
     Line3DBox[{{23.040000000000006`, 
      1.8042195912175802`, -1.0416666666666665`}, {16.000000000000004`, 
      2.1650635094610964`, -1.25}, {16.000000000000007`, 
      2.4148145657226703`, -0.6470476127563017}, {23.040000000000017`, 
      2.0123454714355584`, -0.5392063439635848}, {23.040000000000006`, 
      1.8042195912175802`, -1.0416666666666665`}}], 
     Line3DBox[{{23.040000000000017`, 
      2.0123454714355584`, -0.5392063439635848}, {16.000000000000007`, 
      2.4148145657226703`, -0.6470476127563017}, {16., 2.5, 0.}, {
      23.040000000000006`, 2.083333333333333, 0.}, {23.040000000000017`, 
      2.0123454714355584`, -0.5392063439635848}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301514276643*^9, 3.6147092806997213`*^9, 
  3.614729136412191*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[224]:="]
}, Open  ]],

Cell[TextData[{
 "Next we view the mouth of ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell[CellGroupData[{

Cell["ShowSystem[%,PlotType->FrontView];", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[225]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{1.25, 0.}, {1.6666666666666665`, 0.}, {1.6098763771484468`, 
      0.4313650751708678}, {1.2074072828613351`, 0.32352380637815087`}, {1.25,
       0.}}], LineBox[{{1.2074072828613351`, 0.32352380637815087`}, {
      1.6098763771484468`, 0.4313650751708678}, {1.443375672974064, 
      0.8333333333333333}, {1.0825317547305482`, 0.625}, {1.2074072828613351`,
       0.32352380637815087`}}], 
     LineBox[{{1.0825317547305482`, 0.625}, {1.443375672974064, 
      0.8333333333333333}, {1.178511301977579, 1.178511301977579}, {
      0.8838834764831843, 0.8838834764831843}, {1.0825317547305482`, 0.625}}],
      LineBox[{{0.8838834764831843, 0.8838834764831843}, {1.178511301977579, 
      1.178511301977579}, {0.8333333333333333, 1.443375672974064}, {0.625, 
      1.0825317547305482`}, {0.8838834764831843, 0.8838834764831843}}], 
     LineBox[{{0.625, 1.0825317547305482`}, {0.8333333333333333, 
      1.443375672974064}, {0.4313650751708678, 1.6098763771484468`}, {
      0.32352380637815087`, 1.2074072828613351`}, {0.625, 
      1.0825317547305482`}}], 
     LineBox[{{0.32352380637815087`, 1.2074072828613351`}, {
      0.4313650751708678, 1.6098763771484468`}, {0., 1.6666666666666665`}, {
      0., 1.25}, {0.32352380637815087`, 1.2074072828613351`}}], 
     LineBox[{{0., 1.25}, {0., 1.6666666666666665`}, {-0.4313650751708678, 
      1.6098763771484468`}, {-0.32352380637815087`, 1.2074072828613351`}, {0.,
       1.25}}], 
     LineBox[{{-0.32352380637815087`, 
      1.2074072828613351`}, {-0.4313650751708678, 
      1.6098763771484468`}, {-0.8333333333333333, 1.443375672974064}, {-0.625,
       1.0825317547305482`}, {-0.32352380637815087`, 1.2074072828613351`}}], 
     LineBox[{{-0.625, 1.0825317547305482`}, {-0.8333333333333333, 
      1.443375672974064}, {-1.178511301977579, 
      1.178511301977579}, {-0.8838834764831843, 0.8838834764831843}, {-0.625, 
      1.0825317547305482`}}], 
     LineBox[{{-0.8838834764831843, 0.8838834764831843}, {-1.178511301977579, 
      1.178511301977579}, {-1.443375672974064, 
      0.8333333333333333}, {-1.0825317547305482`, 
      0.625}, {-0.8838834764831843, 0.8838834764831843}}], 
     LineBox[{{-1.0825317547305482`, 0.625}, {-1.443375672974064, 
      0.8333333333333333}, {-1.6098763771484468`, 
      0.4313650751708678}, {-1.2074072828613351`, 
      0.32352380637815087`}, {-1.0825317547305482`, 0.625}}], 
     LineBox[{{-1.2074072828613351`, 
      0.32352380637815087`}, {-1.6098763771484468`, 
      0.4313650751708678}, {-1.6666666666666665`, 0.}, {-1.25, 
      0.}, {-1.2074072828613351`, 0.32352380637815087`}}], 
     LineBox[{{-1.25, 0.}, {-1.6666666666666665`, 
      0.}, {-1.6098763771484468`, -0.4313650751708678}, \
{-1.2074072828613351`, -0.32352380637815087`}, {-1.25, 0.}}], 
     LineBox[{{-1.2074072828613351`, -0.32352380637815087`}, \
{-1.6098763771484468`, -0.4313650751708678}, {-1.443375672974064, \
-0.8333333333333333}, {-1.0825317547305482`, -0.625}, {-1.2074072828613351`, \
-0.32352380637815087`}}], 
     LineBox[{{-1.0825317547305482`, -0.625}, {-1.443375672974064, \
-0.8333333333333333}, {-1.178511301977579, -1.178511301977579}, \
{-0.8838834764831843, -0.8838834764831843}, {-1.0825317547305482`, -0.625}}], 
     LineBox[{{-0.8838834764831843, -0.8838834764831843}, \
{-1.178511301977579, -1.178511301977579}, {-0.8333333333333333, \
-1.443375672974064}, {-0.625, -1.0825317547305482`}, {-0.8838834764831843, \
-0.8838834764831843}}], 
     LineBox[{{-0.625, -1.0825317547305482`}, {-0.8333333333333333, \
-1.443375672974064}, {-0.4313650751708678, -1.6098763771484468`}, \
{-0.32352380637815087`, -1.2074072828613351`}, {-0.625, \
-1.0825317547305482`}}], 
     LineBox[{{-0.32352380637815087`, -1.2074072828613351`}, \
{-0.4313650751708678, -1.6098763771484468`}, {0., -1.6666666666666665`}, {
      0., -1.25}, {-0.32352380637815087`, -1.2074072828613351`}}], 
     LineBox[{{0., -1.25}, {0., -1.6666666666666665`}, {
      0.4313650751708678, -1.6098763771484468`}, {
      0.32352380637815087`, -1.2074072828613351`}, {0., -1.25}}], 
     LineBox[{{0.32352380637815087`, -1.2074072828613351`}, {
      0.4313650751708678, -1.6098763771484468`}, {
      0.8333333333333333, -1.443375672974064}, {
      0.625, -1.0825317547305482`}, {
      0.32352380637815087`, -1.2074072828613351`}}], 
     LineBox[{{0.625, -1.0825317547305482`}, {
      0.8333333333333333, -1.443375672974064}, {
      1.178511301977579, -1.178511301977579}, {
      0.8838834764831843, -0.8838834764831843}, {
      0.625, -1.0825317547305482`}}], 
     LineBox[{{0.8838834764831843, -0.8838834764831843}, {
      1.178511301977579, -1.178511301977579}, {
      1.443375672974064, -0.8333333333333333}, {
      1.0825317547305482`, -0.625}, {
      0.8838834764831843, -0.8838834764831843}}], 
     LineBox[{{1.0825317547305482`, -0.625}, {
      1.443375672974064, -0.8333333333333333}, {
      1.6098763771484468`, -0.4313650751708678}, {
      1.2074072828613351`, -0.32352380637815087`}, {
      1.0825317547305482`, -0.625}}], 
     LineBox[{{1.2074072828613351`, -0.32352380637815087`}, {
      1.6098763771484468`, -0.4313650751708678}, {1.6666666666666665`, 0.}, {
      1.25, 0.}, {1.2074072828613351`, -0.32352380637815087`}}], 
     LineBox[{{1.6666666666666665`, 0.}, {2.083333333333333, 0.}, {
      2.0123454714355584`, 0.5392063439635848}, {1.6098763771484468`, 
      0.4313650751708678}, {1.6666666666666665`, 0.}}], 
     LineBox[{{1.6098763771484468`, 0.4313650751708678}, {2.0123454714355584`,
       0.5392063439635848}, {1.8042195912175802`, 1.0416666666666665`}, {
      1.443375672974064, 0.8333333333333333}, {1.6098763771484468`, 
      0.4313650751708678}}], 
     LineBox[{{1.443375672974064, 0.8333333333333333}, {1.8042195912175802`, 
      1.0416666666666665`}, {1.4731391274719738`, 1.4731391274719738`}, {
      1.178511301977579, 1.178511301977579}, {1.443375672974064, 
      0.8333333333333333}}], 
     LineBox[{{1.178511301977579, 1.178511301977579}, {1.4731391274719738`, 
      1.4731391274719738`}, {1.0416666666666665`, 1.8042195912175802`}, {
      0.8333333333333333, 1.443375672974064}, {1.178511301977579, 
      1.178511301977579}}], 
     LineBox[{{0.8333333333333333, 1.443375672974064}, {1.0416666666666665`, 
      1.8042195912175802`}, {0.5392063439635848, 2.0123454714355584`}, {
      0.4313650751708678, 1.6098763771484468`}, {0.8333333333333333, 
      1.443375672974064}}], 
     LineBox[{{0.4313650751708678, 1.6098763771484468`}, {0.5392063439635848, 
      2.0123454714355584`}, {0., 2.083333333333333}, {0., 
      1.6666666666666665`}, {0.4313650751708678, 1.6098763771484468`}}], 
     LineBox[{{0., 1.6666666666666665`}, {0., 
      2.083333333333333}, {-0.5392063439635848, 
      2.0123454714355584`}, {-0.4313650751708678, 1.6098763771484468`}, {0., 
      1.6666666666666665`}}], 
     LineBox[{{-0.4313650751708678, 
      1.6098763771484468`}, {-0.5392063439635848, 
      2.0123454714355584`}, {-1.0416666666666665`, 
      1.8042195912175802`}, {-0.8333333333333333, 
      1.443375672974064}, {-0.4313650751708678, 1.6098763771484468`}}], 
     LineBox[{{-0.8333333333333333, 1.443375672974064}, {-1.0416666666666665`,
       1.8042195912175802`}, {-1.4731391274719738`, 
      1.4731391274719738`}, {-1.178511301977579, 
      1.178511301977579}, {-0.8333333333333333, 1.443375672974064}}], 
     LineBox[{{-1.178511301977579, 1.178511301977579}, {-1.4731391274719738`, 
      1.4731391274719738`}, {-1.8042195912175802`, 
      1.0416666666666665`}, {-1.443375672974064, 
      0.8333333333333333}, {-1.178511301977579, 1.178511301977579}}], 
     LineBox[{{-1.443375672974064, 0.8333333333333333}, {-1.8042195912175802`,
       1.0416666666666665`}, {-2.0123454714355584`, 
      0.5392063439635848}, {-1.6098763771484468`, 
      0.4313650751708678}, {-1.443375672974064, 0.8333333333333333}}], 
     LineBox[{{-1.6098763771484468`, 
      0.4313650751708678}, {-2.0123454714355584`, 
      0.5392063439635848}, {-2.083333333333333, 0.}, {-1.6666666666666665`, 
      0.}, {-1.6098763771484468`, 0.4313650751708678}}], 
     LineBox[{{-1.6666666666666665`, 0.}, {-2.083333333333333, 
      0.}, {-2.0123454714355584`, -0.5392063439635848}, \
{-1.6098763771484468`, -0.4313650751708678}, {-1.6666666666666665`, 0.}}], 
     LineBox[{{-1.6098763771484468`, -0.4313650751708678}, \
{-2.0123454714355584`, -0.5392063439635848}, {-1.8042195912175802`, \
-1.0416666666666665`}, {-1.443375672974064, -0.8333333333333333}, \
{-1.6098763771484468`, -0.4313650751708678}}], 
     LineBox[{{-1.443375672974064, -0.8333333333333333}, \
{-1.8042195912175802`, -1.0416666666666665`}, {-1.4731391274719738`, \
-1.4731391274719738`}, {-1.178511301977579, -1.178511301977579}, \
{-1.443375672974064, -0.8333333333333333}}], 
     LineBox[{{-1.178511301977579, -1.178511301977579}, \
{-1.4731391274719738`, -1.4731391274719738`}, {-1.0416666666666665`, \
-1.8042195912175802`}, {-0.8333333333333333, -1.443375672974064}, \
{-1.178511301977579, -1.178511301977579}}], 
     LineBox[{{-0.8333333333333333, -1.443375672974064}, \
{-1.0416666666666665`, -1.8042195912175802`}, {-0.5392063439635848, \
-2.0123454714355584`}, {-0.4313650751708678, -1.6098763771484468`}, \
{-0.8333333333333333, -1.443375672974064}}], 
     LineBox[{{-0.4313650751708678, -1.6098763771484468`}, \
{-0.5392063439635848, -2.0123454714355584`}, {0., -2.083333333333333}, {
      0., -1.6666666666666665`}, {-0.4313650751708678, \
-1.6098763771484468`}}], 
     LineBox[{{0., -1.6666666666666665`}, {0., -2.083333333333333}, {
      0.5392063439635848, -2.0123454714355584`}, {
      0.4313650751708678, -1.6098763771484468`}, {0., -1.6666666666666665`}}],
      LineBox[{{0.4313650751708678, -1.6098763771484468`}, {
      0.5392063439635848, -2.0123454714355584`}, {
      1.0416666666666665`, -1.8042195912175802`}, {
      0.8333333333333333, -1.443375672974064}, {
      0.4313650751708678, -1.6098763771484468`}}], 
     LineBox[{{0.8333333333333333, -1.443375672974064}, {
      1.0416666666666665`, -1.8042195912175802`}, {
      1.4731391274719738`, -1.4731391274719738`}, {
      1.178511301977579, -1.178511301977579}, {
      0.8333333333333333, -1.443375672974064}}], 
     LineBox[{{1.178511301977579, -1.178511301977579}, {
      1.4731391274719738`, -1.4731391274719738`}, {
      1.8042195912175802`, -1.0416666666666665`}, {
      1.443375672974064, -0.8333333333333333}, {
      1.178511301977579, -1.178511301977579}}], 
     LineBox[{{1.443375672974064, -0.8333333333333333}, {
      1.8042195912175802`, -1.0416666666666665`}, {
      2.0123454714355584`, -0.5392063439635848}, {
      1.6098763771484468`, -0.4313650751708678}, {
      1.443375672974064, -0.8333333333333333}}], 
     LineBox[{{1.6098763771484468`, -0.4313650751708678}, {
      2.0123454714355584`, -0.5392063439635848}, {2.083333333333333, 0.}, {
      1.6666666666666665`, 0.}, {1.6098763771484468`, -0.4313650751708678}}], 
     LineBox[{{2.083333333333333, 0.}, {2.5, 0.}, {2.4148145657226703`, 
      0.6470476127563017}, {2.0123454714355584`, 0.5392063439635848}, {
      2.083333333333333, 0.}}], 
     LineBox[{{2.0123454714355584`, 0.5392063439635848}, {2.4148145657226703`,
       0.6470476127563017}, {2.1650635094610964`, 1.25}, {1.8042195912175802`,
       1.0416666666666665`}, {2.0123454714355584`, 0.5392063439635848}}], 
     LineBox[{{1.8042195912175802`, 1.0416666666666665`}, {
      2.1650635094610964`, 1.25}, {1.7677669529663687`, 
      1.7677669529663687`}, {1.4731391274719738`, 1.4731391274719738`}, {
      1.8042195912175802`, 1.0416666666666665`}}], 
     LineBox[{{1.4731391274719738`, 1.4731391274719738`}, {
      1.7677669529663687`, 1.7677669529663687`}, {1.25, 
      2.1650635094610964`}, {1.0416666666666665`, 1.8042195912175802`}, {
      1.4731391274719738`, 1.4731391274719738`}}], 
     LineBox[{{1.0416666666666665`, 1.8042195912175802`}, {1.25, 
      2.1650635094610964`}, {0.6470476127563017, 2.4148145657226703`}, {
      0.5392063439635848, 2.0123454714355584`}, {1.0416666666666665`, 
      1.8042195912175802`}}], 
     LineBox[{{0.5392063439635848, 2.0123454714355584`}, {0.6470476127563017, 
      2.4148145657226703`}, {0., 2.5}, {0., 2.083333333333333}, {
      0.5392063439635848, 2.0123454714355584`}}], 
     LineBox[{{0., 2.083333333333333}, {0., 2.5}, {-0.6470476127563017, 
      2.4148145657226703`}, {-0.5392063439635848, 2.0123454714355584`}, {0., 
      2.083333333333333}}], 
     LineBox[{{-0.5392063439635848, 
      2.0123454714355584`}, {-0.6470476127563017, 
      2.4148145657226703`}, {-1.25, 
      2.1650635094610964`}, {-1.0416666666666665`, 
      1.8042195912175802`}, {-0.5392063439635848, 2.0123454714355584`}}], 
     LineBox[{{-1.0416666666666665`, 1.8042195912175802`}, {-1.25, 
      2.1650635094610964`}, {-1.7677669529663687`, 
      1.7677669529663687`}, {-1.4731391274719738`, 
      1.4731391274719738`}, {-1.0416666666666665`, 1.8042195912175802`}}], 
     LineBox[{{-1.4731391274719738`, 
      1.4731391274719738`}, {-1.7677669529663687`, 
      1.7677669529663687`}, {-2.1650635094610964`, 
      1.25}, {-1.8042195912175802`, 
      1.0416666666666665`}, {-1.4731391274719738`, 1.4731391274719738`}}], 
     LineBox[{{-1.8042195912175802`, 
      1.0416666666666665`}, {-2.1650635094610964`, 
      1.25}, {-2.4148145657226703`, 
      0.6470476127563017}, {-2.0123454714355584`, 
      0.5392063439635848}, {-1.8042195912175802`, 1.0416666666666665`}}], 
     LineBox[{{-2.0123454714355584`, 
      0.5392063439635848}, {-2.4148145657226703`, 0.6470476127563017}, {-2.5, 
      0.}, {-2.083333333333333, 0.}, {-2.0123454714355584`, 
      0.5392063439635848}}], 
     LineBox[{{-2.083333333333333, 0.}, {-2.5, 
      0.}, {-2.4148145657226703`, -0.6470476127563017}, \
{-2.0123454714355584`, -0.5392063439635848}, {-2.083333333333333, 0.}}], 
     LineBox[{{-2.0123454714355584`, -0.5392063439635848}, \
{-2.4148145657226703`, -0.6470476127563017}, {-2.1650635094610964`, -1.25}, \
{-1.8042195912175802`, -1.0416666666666665`}, {-2.0123454714355584`, \
-0.5392063439635848}}], 
     LineBox[{{-1.8042195912175802`, -1.0416666666666665`}, \
{-2.1650635094610964`, -1.25}, {-1.7677669529663687`, -1.7677669529663687`}, \
{-1.4731391274719738`, -1.4731391274719738`}, {-1.8042195912175802`, \
-1.0416666666666665`}}], 
     LineBox[{{-1.4731391274719738`, -1.4731391274719738`}, \
{-1.7677669529663687`, -1.7677669529663687`}, {-1.25, -2.1650635094610964`}, \
{-1.0416666666666665`, -1.8042195912175802`}, {-1.4731391274719738`, \
-1.4731391274719738`}}], 
     LineBox[{{-1.0416666666666665`, -1.8042195912175802`}, {-1.25, \
-2.1650635094610964`}, {-0.6470476127563017, -2.4148145657226703`}, \
{-0.5392063439635848, -2.0123454714355584`}, {-1.0416666666666665`, \
-1.8042195912175802`}}], 
     LineBox[{{-0.5392063439635848, -2.0123454714355584`}, \
{-0.6470476127563017, -2.4148145657226703`}, {0., -2.5}, {
      0., -2.083333333333333}, {-0.5392063439635848, -2.0123454714355584`}}], 
     LineBox[{{0., -2.083333333333333}, {0., -2.5}, {
      0.6470476127563017, -2.4148145657226703`}, {
      0.5392063439635848, -2.0123454714355584`}, {0., -2.083333333333333}}], 
     LineBox[{{0.5392063439635848, -2.0123454714355584`}, {
      0.6470476127563017, -2.4148145657226703`}, {
      1.25, -2.1650635094610964`}, {
      1.0416666666666665`, -1.8042195912175802`}, {
      0.5392063439635848, -2.0123454714355584`}}], 
     LineBox[{{1.0416666666666665`, -1.8042195912175802`}, {
      1.25, -2.1650635094610964`}, {
      1.7677669529663687`, -1.7677669529663687`}, {
      1.4731391274719738`, -1.4731391274719738`}, {
      1.0416666666666665`, -1.8042195912175802`}}], 
     LineBox[{{1.4731391274719738`, -1.4731391274719738`}, {
      1.7677669529663687`, -1.7677669529663687`}, {
      2.1650635094610964`, -1.25}, {
      1.8042195912175802`, -1.0416666666666665`}, {
      1.4731391274719738`, -1.4731391274719738`}}], 
     LineBox[{{1.8042195912175802`, -1.0416666666666665`}, {
      2.1650635094610964`, -1.25}, {
      2.4148145657226703`, -0.6470476127563017}, {
      2.0123454714355584`, -0.5392063439635848}, {
      1.8042195912175802`, -1.0416666666666665`}}], 
     LineBox[{{2.0123454714355584`, -0.5392063439635848}, {
      2.4148145657226703`, -0.6470476127563017}, {2.5, 0.}, {
      2.083333333333333, 0.}, {
      2.0123454714355584`, -0.5392063439635848}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301514360763*^9, 3.614709280771167*^9, 
  3.614729136485647*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[225]:="]
}, Open  ]],

Cell[TextData[{
 "Finally we test out the effects of a single ray sent into the enlarged \
mouth of ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell[CellGroupData[{

Cell["\<\
sys = 
AnalyzeSystem[{
\tMove[SingleRay[],{15,0},30],
\tBlackHole[5,2.5,GraphicDesign->Sketch],
\tBoundary[100, GraphicDesign->False]},
\tPlotType->TopView];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[226]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{15., 0.}, {18.97609874622562, 2.2956016814578946`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{18.97609874622562, 2.2956016814578946`}, {
       24.708227076441645`, -2.011774078485027}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{24.708227076441645`, -2.011774078485027}, {
       29.065563842285048`, 1.8548578137154004`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{29.065563842285048`, 1.8548578137154004`}, {
       32.64061458295236, -1.7503336264788834`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{32.64061458295236, -1.7503336264788834`}, {35.690171757421, 
       1.6738852444393952`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{35.690171757421, 1.6738852444393952`}, {
       38.35333682619564, -1.614724455090823}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{38.35333682619564, -1.614724455090823}, {40.71550030855434, 
       1.5671844438802816`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.71550030855434, 1.5671844438802816`}, {
       42.83351868710235, -1.5279464151380373`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.83351868710235, -1.5279464151380373`}, {44.74748032503371,
        1.4949122720519346`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{44.74748032503371, 1.4949122720519346`}, {
       46.48687852801156, -1.466678100035518}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{46.48687852801156, -1.466678100035518}, {48.07413407297118, 
       1.4422623445362577`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{48.07413407297118, 1.4422623445362577`}, {
       49.52673820883341, -1.4209543853429736`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.52673820883341, -1.4209543853429736`}, {
       50.858624003037875`, 1.402224971566603}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.858624003037875`, 1.402224971566603}, {
       52.08108058185825, -1.385670613465726}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.08108058185825, -1.385670613465726}, {53.20338361228904, 
       1.370977645182641}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.20338361228904, 1.370977645182641}, {
       54.2332426212932, -1.3578982045943522`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.2332426212932, -1.3578982045943522`}, {55.17712610467413, 
       1.3462337116648566`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.17712610467413, 1.3462337116648566`}, {
       56.04050273573131, -1.3358232210309189`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{56.04050273573131, -1.3358232210309189`}, {56.82802352295252,
        1.3265350338944382`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{56.82802352295252, 1.3265350338944382`}, {
       57.54366148122485, -1.3182605443053066`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.54366148122485, -1.3182605443053066`}, {58.19082012518172,
        1.3109096515734686`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{58.19082012518172, 1.3109096515734686`}, {
       58.772418668489856`, -1.3044072926136678`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{58.772418668489856`, -1.3044072926136678`}, {
       59.29095952717778, 1.2986907899808835`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.29095952717778, 1.2986907899808835`}, {
       59.74858216628155, -1.2937078042747396`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.74858216628155, -1.2937078042747396`}, {60.14710624466464,
        1.289414741742278}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.14710624466464, 1.289414741742278}, {
       60.488066244332, -1.285775510318718}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.488066244332, -1.285775510318718}, {60.77273921607008, 
       1.2827605468394463`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.77273921607008, 1.2827605468394463`}, {
       61.002166865988386`, -1.2803460590528006`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.002166865988386`, -1.2803460590528006`}, {
       61.17717290277308, 1.2785134411553631`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.17717290277308, 1.2785134411553631`}, {
       61.29837633261518, -1.2772488327040108`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.29837633261518, -1.2772488327040108`}, {61.36620120649427,
        1.2765427991772187`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.36620120649427, 1.2765427991772187`}, {
       61.38088317749012, -1.276390119024441}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.38088317749012, -1.276390119024441}, {61.34247310274756, 
       1.2767896673736745`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.34247310274756, 1.2767896673736745`}, {
       61.25083781689549, -1.2777443911249557`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.25083781689549, -1.2777443911249557`}, {61.10565810395296,
        1.2792613743095518`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.10565810395296, 1.2792613743095518`}, {
       60.906423796689296`, -1.2813519966612925`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.906423796689296`, -1.2813519966612925`}, {
       60.652425829855254`, 1.284032192638235}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.652425829855254`, 1.284032192638235}, {
       60.3427449600359, -1.2873228229863445`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.3427449600359, -1.2873228229863445`}, {59.97623673232878, 
       1.291250176755375}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.97623673232878, 1.291250176755375}, {
       59.551512112878356`, -1.2958466289825896`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.551512112878356`, -1.2958466289825896`}, {
       59.06691300361518, 1.301151488765485}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.06691300361518, 1.301151488765485}, {
       58.5204815936654, -1.3072120851630031`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{58.5204815936654, -1.3072120851630031`}, {57.90992215581825, 
       1.314085155775885}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.90992215581825, 1.314085155775885}, {
       57.23255343001422, -1.3218386271752585`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.23255343001422, -1.3218386271752585`}, {56.48524909565684,
        1.3305539109592592`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{56.48524909565684, 1.3305539109592592`}, {
       55.664362940200405`, -1.3403288894048986`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.664362940200405`, -1.3403288894048986`}, {
       54.765634059160725`, 1.3512818388786578`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.765634059160725`, 1.3512818388786578`}, {
       53.784065577839904`, -1.3635566511477735`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.784065577839904`, -1.3635566511477735`}, {
       52.71376765435625, 1.3773298855746345`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.71376765435625, 1.3773298855746345`}, {
       51.54775138931828, -1.39282045865981}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.54775138931828, -1.39282045865981}, {50.27765384901496, 
       1.4103032222830167`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.27765384901496, 1.4103032222830167`}, {
       48.89336415865654, -1.430128428667783}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{48.89336415865654, -1.430128428667783}, {47.38250371789971, 
       1.4527503787014293`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.38250371789971, 1.4527503787014293`}, {
       45.72968466448326, -1.4787709032513061`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{45.72968466448326, -1.4787709032513061`}, {43.91541903978648,
        1.509007799307832}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{43.91541903978648, 1.509007799307832}, {
       41.91445400422654, -1.5446073368203925`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{41.91445400422654, -1.5446073368203925`}, {
       39.693114502100656`, 1.5872393126329296`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{39.693114502100656`, 1.5872393126329296`}, {
       37.204817360755136`, -1.6394584388272455`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{37.204817360755136`, -1.6394584388272455`}, {
       34.38193373193568, 1.705433739221029}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{34.38193373193568, 1.705433739221029}, {
       31.11953634268087, -1.7926002024927832`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{31.11953634268087, -1.7926002024927832`}, {
       27.238191425908553`, 1.916067771909883}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.238191425908553`, 1.916067771909883}, {
       22.378537951656234`, -2.113898571324889}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{22.378537951656234`, -2.113898571324889}, {0., 
       13.128658786495313`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwBAQT++yFib1JlAgAAAD8AAAACAAAApbSAm+H5MkC9CBRqZF0CQGR1o15O
tThAE0UQAh0YAMAVar7KyBA9QAo0CmN/rf0/f4+dqP9RQEDcDS3VXQH8v35f
U4xX2EFAmPzh5DvI+j/JfSAkOi1DQAKqak/p1fm/aMKcg5VbRECKQNT+LxP5
P8/ahr2wakVA1u6w8Hdy+L8tNm9vrV9GQEKibSEp6/c/lncdCVI+R0Bql5Z0
g3f3vxp3rTl9CUhAdJEgroET9z8eP1oobMNIQGB+Yqo6vPa/3E0uZOdtSUCe
Nahzg2/2P/+1N9lgCkpAGtH98rQr9r9xqWV5CJpKQF60WUGG7/U/aj7r5Nod
S0BOesB387n1v/BrdRGslktA2PhFXCyK9T+orpIxLwVMQPYKeSuIX/W/LLO/
rPxpTECkMrnMfDn1P1P6DLOWxUxADmBWXpgX9b99iTrLbBhNQARNGGZ8+fQ/
7f1rnd5iTUCgCGcu2t70vxfYaik+pU1ASllp/m/H9D8oRlmK0d9NQCQKX/QG
s/S/nu+eYNQSTkDENixacaH0PwDYZvR4Pk5A0BBtV4mS9L/IrV4e6WJOQFhk
VOwvhvQ/CEf9AEeATkC0GzMmTHz0v+qSB5qtlk5AqCOUgsp09D/GPRcyMaZO
QCAW1Xicb/S/BtNert+uTkA0kWYkuGz0P1R1q8fAsE5AQFyiCxhs9L+8B5wo
1qtOQLTZkwC7bfQ/RRUedBugTkBEd0gapHH0v4aEajSGjU5A7iBbxtp39D9g
jOmxBXROQF4xhfNqgPS/oSWJsIJTTkA8RyZXZYv0P4wcHRHfK05AlO4B0d+Y
9L/FQENT9fxNQJrlAfL1qPQ/iBTs8pfGTUAIy8Gsybv0vyca9ZqQiE1ARDs2
OYTR9D8/ew8kn0JNQIZgKzhX6vS/lpJGVHj0TEDAdgMofgb1P+o9kE/EnUxA
luqkQkAm9b8+IXKkHD5MQJwo0uXySfU/5mpG2AnVS0B0DJ60/HH1v0dm/ksA
YktA6pmatNme9T/xXsdCXORKQHrEbscg0fW/jTMOvVxbSkAsi+UPiwn2P/S6
r7ccxklANEzyGv5I9r9bkEwpiiNJQDRikhyakPY/mGy6wVlySED0U+NYzuH2
vyR9v+H1sEdAWGNcLnc+9z+WLJ1OZt1GQBLau60Lqfe/YwJ7cyz1RUAk+rZc
5ST4P7TsLNQM9URARuLMLra2+L/sc9v5t9hDQHjxqgxVZfk/VQyNdDeaQkC2
oJ7FODv6v5XzWzTjMEFAYjB343RJ+z9vfwrvmR4/QNYmyIx9rvy/AHcAHfo8
O0BOXBSuNqj+P4qo+tznYDZAUTZ3p0PpAMAAAAAAAAAAAEuugJDfQSpAmN7m
dQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301515472081*^9, 3.614709281796406*^9, 
  3.6147291375397673`*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[226]:="]
}, Open  ]],

Cell[TextData[{
 "For a better view, the image might need to be expanded using the mouse \
cursor to drag the corner of the graphics frame. We see that the ray bounced \
around inside the tube, and did not leave the other side. Instead, it seems \
to have turned around and bounced back out the entrance. We next see the \
process in better detail by creating an animation. The basic ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "code used below is typical for making ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "animations."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],

Cell[TextData[{
 "To see how many frames we need, we check the number of ",
 StyleBox["Ray",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " objects in the system."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],

Cell[CellGroupData[{

Cell["Length[RaySelect[sys]]", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"In[227]:="],

Cell[BoxData["63"], "Output",
 CellChangeTimes->{3.5634042694171247`*^9, 3.563458172477199*^9, 
  3.564487608225233*^9, 3.566100716319941*^9, 3.601301243737945*^9, 
  3.601301515564165*^9, 3.6147092818887653`*^9, 3.6147291376221*^9},
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"Out[227]="]
}, Open  ]],

Cell[TextData[{
 "We use ",
 StyleBox["RayChoice->{IntersectionNumber->i}",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " to display a different ray segment in each frame."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],

Cell[CellGroupData[{

Cell["\<\
Do[ShowSystem[
\t\tsys,
\t\tRayChoice->{IntersectionNumber->i},
\t\tPlotType->TopView,
\t\tPlotRange->{{-1,65},{-3,14}}],{i,1,63}];\
\>", "Input",
 AspectRatioFixed->True,
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{15., 0.}, {18.97609874622562, 2.2956016814578946`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{18.97609874622562, 2.2956016814578946`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.61472913784444*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{18.97609874622562, 2.2956016814578946`}, {
      24.708227076441645`, -2.011774078485027}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{24.708227076441645`, -2.011774078485027}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729137850601*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{24.708227076441645`, -2.011774078485027}, {
      29.065563842285048`, 1.8548578137154004`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{29.065563842285048`, 1.8548578137154004`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291379201593`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{29.065563842285048`, 1.8548578137154004`}, {
      32.64061458295236, -1.7503336264788834`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{32.64061458295236, -1.7503336264788834`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729138011498*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{32.64061458295236, -1.7503336264788834`}, {35.690171757421, 
      1.6738852444393952`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{35.690171757421, 1.6738852444393952`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729138103456*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{35.690171757421, 1.6738852444393952`}, {
      38.35333682619564, -1.614724455090823}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{38.35333682619564, -1.614724455090823}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291381926527`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{38.35333682619564, -1.614724455090823}, {40.71550030855434, 
      1.5671844438802816`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{40.71550030855434, 1.5671844438802816`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729138279106*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{40.71550030855434, 1.5671844438802816`}, {
      42.83351868710235, -1.5279464151380373`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{42.83351868710235, -1.5279464151380373`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291383700943`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{42.83351868710235, -1.5279464151380373`}, {44.74748032503371, 
      1.4949122720519346`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{44.74748032503371, 1.4949122720519346`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291384556847`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{44.74748032503371, 1.4949122720519346`}, {
      46.48687852801156, -1.466678100035518}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{46.48687852801156, -1.466678100035518}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729138548135*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{46.48687852801156, -1.466678100035518}, {48.07413407297118, 
      1.4422623445362577`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{48.07413407297118, 1.4422623445362577`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291386398087`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmGlMVFcUx0fRpDFp06gfmpoo0VSNlg+NH1pjTWMairbpp0a7WBIR2VTE
IMYlKioGtYqCxiUoUQwuiGvdcY1CUKPiQhTiEjfUsFQlAjIop/M7zJk8dGCw
fmsk4c28O/ede87//z/nnvt+jkiKjYqPSIqLjAgOS4yYHBsXOSX4h4REz1BQ
B5erQ6zL5QoPdvFdPF+9F/2L4+K98X7/Uz8+ldevX8vQoUMlPj5epk+fLikp
KbJs2TLJzMyUnJwc2b17t+Tn50thYaEUFxfLzZs35dGjR/L8+XN55flzWust
JSUlsnjxYv2VWcy+cuWKPo0VrG3evFmtswqrseqkSZMkMjJSoqOjpVevXjJz
5kz9benSpbJy5UpZv369Prdjxw45cOCAnDhxQm1eunRJbty4IXfu3JHHjx/L
06dPpb6+vsLpVZAcPXpUwsLC9O5jvQ5gljx48ED/b926JdeuXZPz58/LmTNn
1NO9e/fK9u3bJTs7W9auXSsZGRmyaNEiSU5OVo8TEhLU2zFjxkhsbKxMnjxZ
ZsyYIfPmzdO1mL9mzRrJysqSTZs2SW5urkaP9/hz+vRpOXv2rEYAaiB17949
jaK6ulpevHghbrf7astImLlkyRK9C9br11JXV6dPgPft27fl+PHjahXrrMJq
rMrqeIE34Ll69WpJT09XewsWLJA5c+ZoZImJiTJhwgSJiorS6PjknnF+Zx7z
ec4ZJYhs3bpV8vLyZM+ePbJ//345cuSI+oMf8AXC+Aba8Abyd+/elfLycqmo
qNA4ampqNKbGxkbX3y3Dx1RoaKjefaPXn6ShoUEfqaqqUggwV1ZWpktcvHjR
B8OqVavk8OHDsm/fPoUCcrds2aIE4z4kMwdIkN3ChQtVgoQLsVOnTlWSSRQI
HzdunMLDJ/eM8zvzmM9z8+fPVzvYwy72WYf1WJf18QN/8CstLU3FR5ynTp1S
MRYVFcm5c+fkwoULmoBXr16V69evS2lpqYoG6SMcIEQ8BuOzZ89UREDpERLJ
6kptXU2/6TUO1PURIMUM5jDNErDFskALi7AJq8CLy7AN67CPCoCCrCXUDRs2
yLp163wwr1ixwgc1FSM1NVXhJn9mz56tFWDatGmSlJSkyqNCoEKgRpFUC+Dn
k/u4uDj9nXnM5znUih3sYRf70MF6Rgl+kAn4hX/4ib/4jZqhZ9euXT5FHzx4
0EfRyZMnlSIwgCJoBBcqHjSBLyo3qsAPupDo/fv3tfYg2SdPnijOSNioo4Ia
fdQqKISbpqYm1/DWaVyg17mwrZnB45jBpNGJSoxS3ME1XMQObqMy1EZIhEaI
qJGQCR0IgIISCTRQDVRARnEBwpjDMZKanarQjhw5UqGm4AM7vlJKoZxCQpZA
Dxlj1EOd0T9lyhTNLAoMWQbN0E35NSlERESoHPg0SSAVkwXP8Tx2sIc0sU+m
mkRYHz/wB7+QCn7iL37jv0kGCZts2MwoqGT1xo0bVT5snWS3SQiMwAqJgBv4
UZSpSKQNRdokZZkP9pb9pBrVzORFCrYhr85v103bAHO8Y2WNZZJZl6mC6qFj
3/NdRYZyEF1tba2qBzGaghCpqQjxImLEjKhZHS+ov3hFnTJV4TXeEwXRUJeJ
rqCgwKcwojeVgQpKAyVqI6iBnimOrcxUB9qgDvqwQCLDClsTLNFCWMExFVIE
/KmQeu5Z39Wp9STb7B3Lrs+Wy42X9W60d4wSjria7wKaKH9VLhm1GdLY1NjC
BNr0Y8JJ5Bbv2M6XO6XQXah3fwQ24fTCTFS/rpa02jSpa6rzmQB78A1gwiYc
enlI8hvy9e739nkxYsQI8sf1iV6DZPz48ZpP3HXzjpHDNtbDz7y+fsYGe8ei
E6Jl1PFRsjxrucel5rGJEyeqWlrBtmvXrhIeHu5xiWuQ9OnTh296183PWA8/
Y339jA12jA1PHi7D/hrmcal5bNCgQVqaAgC9Ta+dxN3klvTadClxl0jKi5Rf
341xs1LsLlbdhVSFSP+q/malDdKdvVezlc5S2lgqPSt7SpeKLvr/8NVD16h3
S4Rch0OfVX6mZnLrc51W2hHWdu9YkbtIuld0l4SaBJ8j7Ywpzzt2rOGYDPln
iN4N1OuXWhfZUdmEbVelNtIkURs5dlAXKysrdTO3HZbayC5LbaQ1D1Qb2XUD
1UZ2CmojOwe10XZiauPYsWPZ0dooXSv1GuqLxvoDoqC6E4F5T1V3VnQ8Zt+h
P7Aqbl5ScfGMyo1ngD63YK7kHWg+DOAdhzer3OyN1i9Ye/i+ldvZP7CvoxsU
yH5PS0iSWRtJX2CtJBXf0ze4OtJBeDinf2CM/oI51BZrLbFh7SW26VNYa9as
Wbo2x0NrNVvrITg0tbeHsDYUzMAODK2H4IDUBtVj9fqjbuhs5ogVobJ5s3Ej
TESJGBEWInRuztBKZ89Z20RnmzGU4oodomwDNgqdXb6TtvZ2+dDj7PJp66yl
Mypo5XjO2jiDH/usA+xOyPEHWeFfTEyMSg948d8Db0d9XzLA1+xbl4aSUTTK
BgbgIBeBJlCX9i6HADu7kYFkIlTZIYBaA4XUHuj0ZO9Xb1cyawy+0+svOpMn
sQTRrGT9PrmMd3iL55BNlSHC/3pKhkxyAiLptyHRTskQaeQZcUYa+Qth+P8m
WeSF5QSEeclqkQfWR8MQ7BAH8RgrxPjmydlYCHRyBnFOzp+DqUpkdOsZ94Ve
v9XCigGMYRiaWZDFcQSnkA6kIS/kBtBkEYUQkMkcAAYYVA1YFDKAtfdOgEtx
AtB+/fppEWIuhQf1s3kCJkUGILENiO/zlobtjbiQpvfVwrbWpdhVryE6Exna
OyqQgBZWYz5eQCkIkJ+UfVBFWsgKSRFpUFBQi6jJfSTEPOoLsiRaSimSJVIS
GvvIA2kgC9YmOrY1ZEBkJB5RkWgcis63TnRHvfbWXdRedQKS81Un4DpfdULK
wIEDdQchE5wvDtlFKImEAGE8A1GIgkzEHoKhP8Bt1sJleg5Phpc7Pe2u8goJ
CVFgAI5VKKBvvuJFZs5XvOSMveIFGO/L1JfN1sO9jRrQkTWsDVT8fdQ8Rb/7
edf84fuH7/+n764O/wIZPpzf\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{48.07413407297118, 1.4422623445362577`}, {
      49.52673820883341, -1.4209543853429736`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{49.52673820883341, -1.4209543853429736`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291387351847`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{49.52673820883341, -1.4209543853429736`}, {
      50.858624003037875`, 1.402224971566603}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{50.858624003037875`, 1.402224971566603}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729138822294*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.858624003037875`, 1.402224971566603}, {
      52.08108058185825, -1.385670613465726}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{52.08108058185825, -1.385670613465726}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.61472913891263*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{52.08108058185825, -1.385670613465726}, {53.20338361228904, 
      1.370977645182641}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{53.20338361228904, 1.370977645182641}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139007077*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.20338361228904, 1.370977645182641}, {
      54.2332426212932, -1.3578982045943522`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{54.2332426212932, -1.3578982045943522`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139094696*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.2332426212932, -1.3578982045943522`}, {55.17712610467413, 
      1.3462337116648566`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{55.17712610467413, 1.3462337116648566`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139185739*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{55.17712610467413, 1.3462337116648566`}, {
      56.04050273573131, -1.3358232210309189`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{56.04050273573131, -1.3358232210309189`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139393854*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{56.04050273573131, -1.3358232210309189`}, {56.82802352295252, 
      1.3265350338944382`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{56.82802352295252, 1.3265350338944382`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291394348097`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{56.82802352295252, 1.3265350338944382`}, {
      57.54366148122485, -1.3182605443053066`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{57.54366148122485, -1.3182605443053066`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139512109*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{57.54366148122485, -1.3182605443053066`}, {58.19082012518172, 
      1.3109096515734686`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{58.19082012518172, 1.3109096515734686`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139601324*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{58.19082012518172, 1.3109096515734686`}, {
      58.772418668489856`, -1.3044072926136678`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{58.772418668489856`, -1.3044072926136678`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291396915493`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{58.772418668489856`, -1.3044072926136678`}, {
      59.29095952717778, 1.2986907899808835`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{59.29095952717778, 1.2986907899808835`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139779043*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{59.29095952717778, 1.2986907899808835`}, {
      59.74858216628155, -1.2937078042747396`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{59.74858216628155, -1.2937078042747396`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139873535*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{59.74858216628155, -1.2937078042747396`}, {60.14710624466464, 
      1.289414741742278}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.14710624466464, 1.289414741742278}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729139967008*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->
  "During evaluation of \
In[228]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.14710624466464, 1.289414741742278}, {
      60.488066244332, -1.285775510318718}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.488066244332, -1.285775510318718}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291400547323`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.488066244332, -1.285775510318718}, {60.77273921607008, 
      1.2827605468394463`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.77273921607008, 1.2827605468394463`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.61472914015066*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.77273921607008, 1.2827605468394463`}, {
      61.002166865988386`, -1.2803460590528006`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.002166865988386`, -1.2803460590528006`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140243967*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.002166865988386`, -1.2803460590528006`}, {
      61.17717290277308, 1.2785134411553631`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.17717290277308, 1.2785134411553631`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140337834*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.17717290277308, 1.2785134411553631`}, {
      61.29837633261518, -1.2772488327040108`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.29837633261518, -1.2772488327040108`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140423979*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.29837633261518, -1.2772488327040108`}, {61.36620120649427, 
      1.2765427991772187`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.36620120649427, 1.2765427991772187`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291405212383`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.36620120649427, 1.2765427991772187`}, {
      61.38088317749012, -1.276390119024441}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.38088317749012, -1.276390119024441}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291406155167`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.38088317749012, -1.276390119024441}, {61.34247310274756, 
      1.2767896673736745`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.34247310274756, 1.2767896673736745`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140705381*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.34247310274756, 1.2767896673736745`}, {
      61.25083781689549, -1.2777443911249557`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.25083781689549, -1.2777443911249557`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291408025846`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.25083781689549, -1.2777443911249557`}, {61.10565810395296, 
      1.2792613743095518`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{61.10565810395296, 1.2792613743095518`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140900484*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{61.10565810395296, 1.2792613743095518`}, {
      60.906423796689296`, -1.2813519966612925`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.906423796689296`, -1.2813519966612925`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729140992548*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.906423796689296`, -1.2813519966612925`}, {
      60.652425829855254`, 1.284032192638235}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.652425829855254`, 1.284032192638235}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141080883*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.652425829855254`, 1.284032192638235}, {
      60.3427449600359, -1.2873228229863445`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{60.3427449600359, -1.2873228229863445`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141179235*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60.3427449600359, -1.2873228229863445`}, {59.97623673232878, 
      1.291250176755375}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{59.97623673232878, 1.291250176755375}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141271245*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{59.97623673232878, 1.291250176755375}, {
      59.551512112878356`, -1.2958466289825896`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{59.551512112878356`, -1.2958466289825896`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141359921*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{59.551512112878356`, -1.2958466289825896`}, {
      59.06691300361518, 1.301151488765485}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{59.06691300361518, 1.301151488765485}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291414499693`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{59.06691300361518, 1.301151488765485}, {
      58.5204815936654, -1.3072120851630031`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{58.5204815936654, -1.3072120851630031`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141542671*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{58.5204815936654, -1.3072120851630031`}, {57.90992215581825, 
      1.314085155775885}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{57.90992215581825, 1.314085155775885}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141629036*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{57.90992215581825, 1.314085155775885}, {
      57.23255343001422, -1.3218386271752585`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{57.23255343001422, -1.3218386271752585`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729141717203*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{57.23255343001422, -1.3218386271752585`}, {56.48524909565684, 
      1.3305539109592592`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{56.48524909565684, 1.3305539109592592`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729142159252*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{56.48524909565684, 1.3305539109592592`}, {
      55.664362940200405`, -1.3403288894048986`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{55.664362940200405`, -1.3403288894048986`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291421642036`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{55.664362940200405`, -1.3403288894048986`}, {
      54.765634059160725`, 1.3512818388786578`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{54.765634059160725`, 1.3512818388786578`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291421689987`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{54.765634059160725`, 1.3512818388786578`}, {
      53.784065577839904`, -1.3635566511477735`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{53.784065577839904`, -1.3635566511477735`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291421989813`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{53.784065577839904`, -1.3635566511477735`}, {
      52.71376765435625, 1.3773298855746345`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{52.71376765435625, 1.3773298855746345`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.61472914228533*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{52.71376765435625, 1.3773298855746345`}, {
      51.54775138931828, -1.39282045865981}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{51.54775138931828, -1.39282045865981}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729142373602*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{51.54775138931828, -1.39282045865981}, {50.27765384901496, 
      1.4103032222830167`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{50.27765384901496, 1.4103032222830167`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.61472914246418*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50.27765384901496, 1.4103032222830167`}, {
      48.89336415865654, -1.430128428667783}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{48.89336415865654, -1.430128428667783}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729142559668*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{48.89336415865654, -1.430128428667783}, {47.38250371789971, 
      1.4527503787014293`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{47.38250371789971, 1.4527503787014293`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291426529503`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{47.38250371789971, 1.4527503787014293`}, {
      45.72968466448326, -1.4787709032513061`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{45.72968466448326, -1.4787709032513061`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291427431393`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{45.72968466448326, -1.4787709032513061`}, {43.91541903978648, 
      1.509007799307832}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{43.91541903978648, 1.509007799307832}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291428344173`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{43.91541903978648, 1.509007799307832}, {
      41.91445400422654, -1.5446073368203925`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{41.91445400422654, -1.5446073368203925`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729142928523*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{41.91445400422654, -1.5446073368203925`}, {
      39.693114502100656`, 1.5872393126329296`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{39.693114502100656`, 1.5872393126329296`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729143017631*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{39.693114502100656`, 1.5872393126329296`}, {
      37.204817360755136`, -1.6394584388272455`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{37.204817360755136`, -1.6394584388272455`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291431099787`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{37.204817360755136`, -1.6394584388272455`}, {
      34.38193373193568, 1.705433739221029}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{34.38193373193568, 1.705433739221029}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729143200399*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{34.38193373193568, 1.705433739221029}, {
      31.11953634268087, -1.7926002024927832`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{31.11953634268087, -1.7926002024927832`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729143465816*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{31.11953634268087, -1.7926002024927832`}, {
      27.238191425908553`, 1.916067771909883}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{27.238191425908553`, 1.916067771909883}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291434703197`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{27.238191425908553`, 1.916067771909883}, {
      22.378537951656234`, -2.113898571324889}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{22.378537951656234`, -2.113898571324889}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.614729143518878*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.041322314049587`, -2.2916666666666665`}, {
       23.039999999999996`, -2.0833333333333335`}, {
       28.444444444444443`, -1.875}, {
       35.99999999999999, -1.6666666666666667`}, {
       47.020408163265294`, -1.4583333333333335`}, {64., -1.25}, {
       64., -1.25}, {47.020408163265316`, -1.4583333333333333`}, {
       36.00000000000001, -1.6666666666666665`}, {
       28.444444444444443`, -1.875}, {
       23.040000000000006`, -2.083333333333333}, {
       19.041322314049587`, -2.2916666666666665`}, {16., -2.5}, {
       16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 1.25}, {47.020408163265316`, 1.4583333333333333`}, {
       36.00000000000001, 1.6666666666666665`}, {28.444444444444443`, 
       1.875}, {23.040000000000006`, 2.083333333333333}, {19.041322314049587`,
        2.2916666666666665`}, {16., 2.5}, {16., 2.5}, {19.041322314049587`, 
       2.2916666666666665`}, {23.039999999999996`, 2.0833333333333335`}, {
       28.444444444444443`, 1.875}, {35.99999999999999, 
       1.6666666666666667`}, {47.020408163265294`, 1.4583333333333335`}, {64.,
        1.25}, {64., 1.25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.041322314049587`, 0.}, {23.039999999999996`, 
       0.}, {28.444444444444443`, 0.}, {35.99999999999999, 0.}, {
       47.020408163265294`, 0.}, {64., 0.}, {64., 0.}, {47.020408163265316`, 
       0.}, {36.00000000000001, 0.}, {28.444444444444443`, 0.}, {
       23.040000000000006`, 0.}, {19.041322314049587`, 0.}, {16., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{64., 0.}, {47.020408163265316`, 0.}, {36.00000000000001, 
       0.}, {28.444444444444443`, 0.}, {23.040000000000006`, 0.}, {
       19.041322314049587`, 0.}, {16., 0.}, {16., 0.}, {19.041322314049587`, 
       0.}, {23.039999999999996`, 0.}, {28.444444444444443`, 0.}, {
       35.99999999999999, 0.}, {47.020408163265294`, 0.}, {64., 0.}, {64., 
       0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEBDhD6iz2Mn1ve69MV+BnOf61vfpEn6COcf4BL
nuGYxxs4nxFMP7FngvItT3w3nLvlClyes/jm/vX802xgfCOI/H4Y/99/EHgM
5++HmL//L1jc3+EVxP79MPNzIO6Dq4e6f/9/qPo8qDyM/waqH6b+CNR8GJ8V
4n443w3NfW5ij88f7t6wB2aeFpr/fkDcD+fvQwufl2jhl4MWvrDwBwC/FoZX

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{22.378537951656234`, -2.113898571324889}, {0., 
      13.128658786495313`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{0., 13.128658786495313`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>{{-1, 65}, {-3, 14}}]], "Print",
 CellChangeTimes->{3.601301515656723*^9, 3.6147092821109743`*^9, 
  3.6147291436130857`*^9},
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"},
 CellLabel->"During evaluation of In[228]:="]
}, Open  ]],

Cell[TextData[{
 "In the previous ray tracing, we sent the ray into the component defined by ",
 StyleBox["BlackHole",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with an initial angle of 30 degrees. Let us now use a wedge of rays having \
angles shallower then 30 degrees."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell[CellGroupData[{

Cell[TextData[{
 "sys =\nAnalyzeSystem[\n\t{Move[WedgeOfRays[30, NumberOfRays->6],{15,0,0}],\n\
\tBlackHole[5,2,GraphicDesign->Sketch, ",
 StyleBox["SurfaceRayIntersections -> FindRoot", "Input"],
 "],\n\tBoundary[{0,-100,-100},{120,100,100}, GraphicDesign->Off]},\n\
PlotType->TopView];"
}], "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[229]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.753086419753085`, -2.25}, {25., -2.}, {
       32.6530612244898, -1.75}, {44.44444444444444, -1.5}, {64., -1.25}, {
       100., -1.}, {100., -1.}, {64., -1.25}, {44.44444444444444, -1.5}, {
       32.6530612244898, -1.75}, {25., -2.}, {19.753086419753085`, -2.25}, {
       16., -2.5}, {16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 1.}, {64., 1.25}, {44.44444444444444, 1.5}, {
       32.6530612244898, 1.75}, {25., 2.}, {19.753086419753085`, 2.25}, {16., 
       2.5}, {16., 2.5}, {19.753086419753085`, 2.25}, {25., 2.}, {
       32.6530612244898, 1.75}, {44.44444444444444, 1.5}, {64., 1.25}, {100., 
       1.}, {100., 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.753086419753085`, 0.}, {25., 0.}, {
       32.6530612244898, 0.}, {44.44444444444444, 0.}, {64., 0.}, {100., 
       0.}, {100., 0.}, {64., 0.}, {44.44444444444444, 0.}, {32.6530612244898,
        0.}, {25., 0.}, {19.753086419753085`, 0.}, {16., 0.}, {16., 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 0.}, {64., 0.}, {44.44444444444444, 0.}, {
       32.6530612244898, 0.}, {25., 0.}, {19.753086419753085`, 0.}, {16., 
       0.}, {16., 0.}, {19.753086419753085`, 0.}, {25., 0.}, {
       32.6530612244898, 0.}, {44.44444444444444, 0.}, {64., 0.}, {100., 
       0.}, {100., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGRDhD6gz2ML7rfw/3ui3dw/mqfiBdV217D+Wet
69PmLXgG5zOC6Qdw/hS2yQdrJ1yA89ljRIzVlk20gfH7IPL7maD8P/9B4P5+
mPwZiPlw/kqI/XC+CMR9cD7U/XC+GJr8GjT9F9DMZ4G4H86fB3UfjM/VNc/H
snLVHhi/A81/XyDuh/NPo4XPCrTwE0YLX1j4AwB3PHT3
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{15., 0.}, {22.8135917283435, 2.0936455935961407`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {27.12319435591933, 1.9201253530078608`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {43.82369963567034, 1.5105860886268865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {43.82369963567034, -1.5105860886268865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {27.12319435591933, -1.9201253530078608`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {22.8135917283435, -2.0936455935961407`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{22.8135917283435, 2.0936455935961407`}, {
       33.19115593829819, -1.7357565434871538`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.12319435591933, 1.9201253530078608`}, {
       42.05470229099571, -1.542029629318077}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{43.82369963567034, 1.5105860886268865`}, {
       74.48880652192142, -1.1586559388816513`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{43.82369963567034, -1.5105860886268865`}, {74.48880652192142,
        1.1586559388816513`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.12319435591933, -1.9201253530078608`}, {42.05470229099572,
        1.542029629318077}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{22.8135917283435, -2.0936455935961407`}, {
       33.191155938298195`, 1.7357565434871538`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{33.19115593829819, -1.7357565434871538`}, {40.87193579751132,
        1.564182404732616}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.05470229099571, -1.542029629318077}, {52.82764133860748, 
       1.375844619182621}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{74.48880652192142, -1.1586559388816513`}, {95.71519648540584,
        1.0221380424924982`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{74.48880652192142, 1.1586559388816513`}, {
       95.71519648540584, -1.0221380424924982`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.05470229099572, 1.542029629318077}, {
       52.82764133860749, -1.3758446191826206`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{33.191155938298195`, 1.7357565434871538`}, {
       40.871935797511334`, -1.5641824047326165`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.87193579751132, 1.564182404732616}, {
       47.2187121961477, -1.455267836225957}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.82764133860748, 1.375844619182621}, {
       61.687080115984955`, -1.273218361329259}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.71519648540584, 1.0221380424924982`}, {
       120., -1.7352455963567082`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.71519648540584, -1.0221380424924982`}, {120., 
       1.7352455963567082`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.82764133860749, -1.3758446191826206`}, {61.68708011598497,
        1.273218361329259}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.871935797511334`, -1.5641824047326165`}, {
       47.21871219614772, 1.455267836225957}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.2187121961477, -1.455267836225957}, {52.72803515312923, 
       1.3771435294748575`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.687080115984955`, -1.273218361329259}, {69.37831406634908,
        1.2005717748653963`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.68708011598497, 1.273218361329259}, {
       69.37831406634909, -1.2005717748653968`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.21871219614772, 1.455267836225957}, {
       52.728035153129255`, -1.377143529474857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.72803515312923, 1.3771435294748575`}, {
       57.648166651905655`, -1.3170651243699836`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{69.37831406634908, 1.2005717748653963`}, {
       76.2603840937224, -1.1451186973814398`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{69.37831406634909, -1.2005717748653968`}, {76.2603840937224, 
       1.1451186973814393`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.728035153129255`, -1.377143529474857}, {57.64816665190568,
        1.3170651243699836`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.648166651905655`, -1.3170651243699836`}, {62.124443358106,
        1.2687286433274965`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{76.2603840937224, -1.1451186973814398`}, {82.53909490213606, 
       1.1007029967676547`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{76.2603840937224, 1.1451186973814393`}, {
       82.53909490213606, -1.1007029967676543`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.64816665190568, 1.3170651243699836`}, {
       62.124443358106035`, -1.268728643327496}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{62.124443358106, 1.2687286433274965`}, {
       66.25065385832208, -1.2285841708905259`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.53909490213606, 1.1007029967676547`}, {
       88.34543648534684, -1.0639174684027846`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.53909490213606, -1.1007029967676543`}, {88.34543648534684,
        1.063917468402785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{62.124443358106035`, -1.268728643327496}, {66.25065385832211,
        1.228584170890525}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{66.25065385832208, -1.2285841708905259`}, {70.09150111234901,
        1.1944481975764667`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.34543648534684, -1.0639174684027846`}, {93.76889439364352,
        1.032691499806289}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.34543648534684, 1.063917468402785}, {
       93.76889439364352, -1.032691499806289}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{66.25065385832211, 1.228584170890525}, {
       70.09150111234904, -1.1944481975764663`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70.09150111234901, 1.1944481975764667`}, {
       73.69385596308567, -1.1648885041914467`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.76889439364352, 1.032691499806289}, {
       98.87381633793849, -1.005678929967492}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.76889439364352, -1.032691499806289}, {98.8738163379385, 
       1.0056789299674915`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70.09150111234904, -1.1944481975764663`}, {73.6938559630857, 
       1.1648885041914467`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{73.69385596308567, -1.1648885041914467`}, {77.09296330968384,
        1.1389184549121336`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.87381633793849, -1.005678929967492}, {120., 
       7.680067146472694}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.8738163379385, 1.0056789299674915`}, {
       120., -7.680067146472684}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{73.6938559630857, 1.1648885041914467`}, {
       77.09296330968387, -1.1389184549121327`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{77.09296330968384, 1.1389184549121336`}, {
       80.31611962922592, -1.1158315607055402`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{77.09296330968387, -1.1389184549121327`}, {80.31611962922595,
        1.1158315607055402`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{80.31611962922592, -1.1158315607055402`}, {83.3849775388973, 
       1.0951058323438225`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{80.31611962922595, 1.1158315607055402`}, {
       83.38497753889733, -1.0951058323438225`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{83.3849775388973, 1.0951058323438225`}, {
       86.31705632705096, -1.0763454751243193`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{83.38497753889733, -1.0951058323438225`}, {86.31705632705099,
        1.0763454751243193`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{86.31705632705096, -1.0763454751243193`}, {89.12676925571236,
        1.0592437689829093`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{86.31705632705099, 1.0763454751243193`}, {
       89.12676925571239, -1.0592437689829093`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.12676925571236, 1.0592437689829093`}, {
       91.82614413944185, -1.0435585624929944`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.12676925571239, -1.0592437689829093`}, {91.82614413944188,
        1.043558562492994}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.82614413944185, -1.0435585624929944`}, {94.42534222230807,
        1.0290955879489379`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.82614413944188, 1.043558562492994}, {
       94.4253422223081, -1.0290955879489379`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{94.42534222230807, 1.0290955879489379`}, {
       96.9330403499884, -1.0156967962835841`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{94.4253422223081, -1.0290955879489379`}, {96.93304034998843, 
       1.0156967962835837`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.9330403499884, -1.0156967962835841`}, {99.35671804148484, 
       1.003232011388214}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.93304034998843, 1.0156967962835837`}, {
       99.35671804148487, -1.0032320113882136`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.35671804148484, 1.003232011388214}, {
       120., -16.548747474150332`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.35671804148487, -1.0032320113882136`}, {120., 
       16.548747474150296`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxd0n8s1HEcx/HDxJjSZbXp5tfCmmzS/Mixz5u6SCRH3EwpTRLRD7+itsL5
cYfdGmXONL9/9WNM31Tmg4ZIfnVhrPyYTcbpe0dHU1b5ftm+990+++6xPff6
5/MxD4/jR2iyWKxT/87/v0H24VzPIUcQeQ569GIWvHjjX59jygVXFyL0S8sm
sk8K+RO7wIOvJln+oTbr6sZqPVbba68iuP1JRQCJme41tV0beDZ63z2WDg/i
LQkP62frOCjWSur1lA8PNXwHJ3KU6kZzzB5VM/fQoof0iTTuJNjNGpnP7fqF
0vZ2WJFR3hDCa61K0FIhw86Uni55MDjpZ0c/DyHVjTPoXkD1WE7v2VN7OGp8
unNT6gntts7ybq81/EjR4aYcOwv9jlFOxmGrmLX1XYRPRsuzkvcb6kYFzB7F
MPdQeXqau90Fbwif8avp0VWhtKpjPo4Cf+juHMcihxWUTvsDZVxN95eoHsdb
qkzXRnygmnSbaWL/xEvv9C3qDQOgqK55I5Kv3PFjyiiZ2SNheW6nfI8fyG4u
RBI+qyg4az7rQXkgDJROtqWUKHbcTxmL6H6E6rGWTiqhJzkHxFvLac/aFcyd
KCs7uD8Ivsm7+QPaih1PU0badN9E9UjMS7WeFPqDhCgkEjgr6FWjTOJwKxhc
ImuF80JS3TiP7vOpHhdHjFlci+HD1eFBs/AKJdYQhUqXXgsgsNe6z+MAiTVp
8ymjEmaPUpsvc1Z4AcDO6cvXPK5E2/f3srVSeKXFBLZdSbn9Pt3vpnqcc/qz
L9coEJbth4/enlBgMdNIPCRLrhgPBInD3cY8oQLlMY1NF0urvQvOQ2jzDV3C
WYHNmUaGkx9/c7yCoC3sUFGdkkRsprHMpkE8tRoERnOFidebSDxKm00ZrRYX
DjhLgyHcNvrHkSQSqZjGnBNTywRXABy9Bq8zQGIT2saUUUbG9yTZqAAsIu9o
uhmQKJO2GeWd985ymydScu3at61y3TL8BdnpItk=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301523765079*^9, 3.6147092889293222`*^9, 
  3.614729144949903*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[229]:="]
}, Open  ]],

Cell[TextData[{
 "This time all of the rays made it through the tube without turning around. \
Unfortunately, the ray trace has generated error messages. Here is a case \
where the default settings in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " has failed. This is a result of the default ",
 StyleBox["SurfaceRayIntersections -> FindRoot", "Input"],
 " option setting in ",
 StyleBox["CustomMirror", "Input"],
 ". It is therefore necessary to choose a different setting. The problem is \
finally resolved with the ",
 StyleBox["SurfaceRayIntersections -> Solve", "Input"],
 " setting."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],

Cell[CellGroupData[{

Cell[TextData[{
 "sys =\nAnalyzeSystem[\n\t{Move[WedgeOfRays[30, NumberOfRays->6],{15,0,0}],\n\
\tBlackHole[5,2,GraphicDesign->Sketch, ",
 StyleBox["SurfaceRayIntersections", "Input"],
 " -> Solve],\n\tBoundary[{0,-100,-100},{120,100,100}, GraphicDesign->Off]},\n\
PlotType->TopView];"
}], "Input",
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"In[230]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Solve was unable to solve the system with inexact \
coefficients. The answer was obtained by solving a corresponding exact system \
and numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6013015257331142`*^9, 3.61470928942892*^9, 
  3.614729145677462*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[230]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Solve was unable to solve the system with inexact \
coefficients. The answer was obtained by solving a corresponding exact system \
and numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6013015257331142`*^9, 3.61470928942892*^9, 
  3.614729145821433*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[230]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Solve was unable to solve the system with inexact \
coefficients. The answer was obtained by solving a corresponding exact system \
and numericizing the result. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::ratnz\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6013015257331142`*^9, 3.61470928942892*^9, 
  3.614729145959519*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[230]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Solve :: \
ratnz\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6013015257331142`*^9, 3.61470928942892*^9, 
  3.6147291459899273`*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[230]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., -2.5}, {19.753086419753085`, -2.25}, {25., -2.}, {
       32.6530612244898, -1.75}, {44.44444444444444, -1.5}, {64., -1.25}, {
       100., -1.}, {100., -1.}, {64., -1.25}, {44.44444444444444, -1.5}, {
       32.6530612244898, -1.75}, {25., -2.}, {19.753086419753085`, -2.25}, {
       16., -2.5}, {16., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 1.}, {64., 1.25}, {44.44444444444444, 1.5}, {
       32.6530612244898, 1.75}, {25., 2.}, {19.753086419753085`, 2.25}, {16., 
       2.5}, {16., 2.5}, {19.753086419753085`, 2.25}, {25., 2.}, {
       32.6530612244898, 1.75}, {44.44444444444444, 1.5}, {64., 1.25}, {100., 
       1.}, {100., 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{16., 0.}, {19.753086419753085`, 0.}, {25., 0.}, {
       32.6530612244898, 0.}, {44.44444444444444, 0.}, {64., 0.}, {100., 
       0.}, {100., 0.}, {64., 0.}, {44.44444444444444, 0.}, {32.6530612244898,
        0.}, {25., 0.}, {19.753086419753085`, 0.}, {16., 0.}, {16., 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 0.}, {64., 0.}, {44.44444444444444, 0.}, {
       32.6530612244898, 0.}, {25., 0.}, {19.753086419753085`, 0.}, {16., 
       0.}, {16., 0.}, {19.753086419753085`, 0.}, {25., 0.}, {
       32.6530612244898, 0.}, {44.44444444444444, 0.}, {64., 0.}, {100., 
       0.}, {100., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGRDhD6gz2ML7rfw/3ui3dw/mqfiBdV217D+Wet
69PmLXgG5zOC6Qdw/hS2yQdrJ1yA89ljRIzVlk20gfH7IPL7maD8P/9B4P5+
mPwZiPlw/kqI/XC+CMR9cD7U/XC+GJr8GjT9F9DMZ4G4H86fB3UfjM/VNc/H
snLVHhi/A81/XyDuh/NPo4XPCrTwE0YLX1j4AwB3PHT3
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEGDhCaxQHGzy3v9ekKZIbzX+ubX+QJYoTzD3DJ
Mxzz+GMP4zOC6S/2TFC+5YnvhnO3PIHLcxbf3L+ef5kNjG8Ekd8P4//7DwKf
4fz9EPP3/wWL6zu8gth/AGZ+DsR9B9Dcf+A/VH0eVB7GfwPVD1N/BGo+jM8K
cT+c74bmPjexx+cPdx/YAzNPC81/PyDuh/P3oYXPS7Twy0ELX1j4AwAounnS

      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{15., 0.}, {22.8135917283435, 2.0936455935961407`}}], 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {27.12319435591933, 1.9201253530078608`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {43.82369963567034, 1.5105860886268865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {43.82369963567034, -1.5105860886268865`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {27.12319435591933, -1.9201253530078608`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{15., 0.}, {22.8135917283435, -2.0936455935961407`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{22.8135917283435, 2.0936455935961407`}, {
       33.191155938298195`, -1.7357565434871538`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.12319435591933, 1.9201253530078608`}, {
       42.05470229099572, -1.542029629318078}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{43.82369963567034, 1.5105860886268865`}, {
       74.48880652192142, -1.1586559388816517`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{43.82369963567034, -1.5105860886268865`}, {74.48880652192142,
        1.1586559388816517`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{27.12319435591933, -1.9201253530078608`}, {42.05470229099572,
        1.542029629318078}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{22.8135917283435, -2.0936455935961407`}, {
       33.191155938298195`, 1.7357565434871538`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{33.191155938298195`, -1.7357565434871538`}, {
       40.871935797511334`, 1.5641824047326165`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.05470229099572, -1.542029629318078}, {52.82764133860749, 
       1.375844619182621}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{74.48880652192142, -1.1586559388816517`}, {95.71519648540584,
        1.0221380424924977`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{74.48880652192142, 1.1586559388816517`}, {
       95.71519648540584, -1.0221380424924977`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.05470229099572, 1.542029629318078}, {
       52.82764133860749, -1.375844619182621}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{33.191155938298195`, 1.7357565434871538`}, {
       40.871935797511334`, -1.5641824047326165`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.871935797511334`, 1.5641824047326165`}, {
       47.21871219614772, -1.4552678362259575`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.82764133860749, 1.375844619182621}, {
       61.68708011598497, -1.2732183613292594`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.71519648540584, 1.0221380424924977`}, {
       120., -1.7352455963567086`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.71519648540584, -1.0221380424924977`}, {120., 
       1.7352455963567086`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.82764133860749, -1.375844619182621}, {61.68708011598497, 
       1.2732183613292594`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.871935797511334`, -1.5641824047326165`}, {
       47.21871219614772, 1.4552678362259575`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.21871219614772, -1.4552678362259575`}, {
       52.728035153129255`, 1.377143529474857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.68708011598497, -1.2732183613292594`}, {69.37831406634909,
        1.2005717748653968`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.68708011598497, 1.2732183613292594`}, {
       69.37831406634909, -1.2005717748653968`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.21871219614772, 1.4552678362259575`}, {
       52.728035153129255`, -1.377143529474857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.728035153129255`, 1.377143529474857}, {
       57.64816665190568, -1.3170651243699831`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{69.37831406634909, 1.2005717748653968`}, {
       76.2603840937224, -1.1451186973814393`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{69.37831406634909, -1.2005717748653968`}, {76.2603840937224, 
       1.1451186973814393`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.728035153129255`, -1.377143529474857}, {57.64816665190568,
        1.3170651243699831`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.64816665190568, -1.3170651243699831`}, {
       62.124443358106035`, 1.268728643327496}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{76.2603840937224, -1.1451186973814393`}, {82.53909490213606, 
       1.1007029967676547`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{76.2603840937224, 1.1451186973814393`}, {
       82.53909490213606, -1.1007029967676547`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{57.64816665190568, 1.3170651243699831`}, {
       62.124443358106035`, -1.268728643327496}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{62.124443358106035`, 1.268728643327496}, {
       66.25065385832211, -1.2285841708905254`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.53909490213606, 1.1007029967676547`}, {
       88.34543648534684, -1.063917468402785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.53909490213606, -1.1007029967676547`}, {88.34543648534684,
        1.063917468402785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{62.124443358106035`, -1.268728643327496}, {66.25065385832211,
        1.2285841708905254`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{66.25065385832211, -1.2285841708905254`}, {70.09150111234904,
        1.1944481975764667`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.34543648534684, -1.063917468402785}, {93.76889439364352, 
       1.0326914998062895`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.34543648534684, 1.063917468402785}, {
       93.76889439364352, -1.0326914998062895`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{66.25065385832211, 1.2285841708905254`}, {
       70.09150111234904, -1.1944481975764667`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70.09150111234904, 1.1944481975764667`}, {
       73.6938559630857, -1.1648885041914467`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.76889439364352, 1.0326914998062895`}, {
       98.87381633793849, -1.0056789299674915`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.76889439364352, -1.0326914998062895`}, {98.87381633793849,
        1.0056789299674915`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{70.09150111234904, -1.1944481975764667`}, {73.6938559630857, 
       1.1648885041914467`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{73.6938559630857, -1.1648885041914467`}, {77.09296330968387, 
       1.1389184549121332`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.87381633793849, -1.0056789299674915`}, {120., 
       7.680067146472696}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.87381633793849, 1.0056789299674915`}, {
       120., -7.680067146472696}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{73.6938559630857, 1.1648885041914467`}, {
       77.09296330968387, -1.1389184549121332`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{77.09296330968387, 1.1389184549121332`}, {
       80.31611962922595, -1.1158315607055402`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{77.09296330968387, -1.1389184549121332`}, {80.31611962922595,
        1.1158315607055402`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{80.31611962922595, -1.1158315607055402`}, {83.38497753889733,
        1.0951058323438225`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{80.31611962922595, 1.1158315607055402`}, {
       83.38497753889733, -1.0951058323438225`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{83.38497753889733, 1.0951058323438225`}, {
       86.31705632705099, -1.0763454751243193`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{83.38497753889733, -1.0951058323438225`}, {86.31705632705099,
        1.0763454751243193`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{86.31705632705099, -1.0763454751243193`}, {89.12676925571239,
        1.0592437689829093`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{86.31705632705099, 1.0763454751243193`}, {
       89.12676925571239, -1.0592437689829093`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.12676925571239, 1.0592437689829093`}, {91.82614413944188,
        -1.0435585624929944`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.12676925571239, -1.0592437689829093`}, {91.82614413944188,
        1.0435585624929944`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.82614413944188, -1.0435585624929944`}, {94.4253422223081, 
       1.0290955879489383`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.82614413944188, 1.0435585624929944`}, {
       94.4253422223081, -1.0290955879489383`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{94.4253422223081, 1.0290955879489383`}, {
       96.93304034998843, -1.0156967962835832`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{94.4253422223081, -1.0290955879489383`}, {96.93304034998843, 
       1.0156967962835832`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.93304034998843, -1.0156967962835832`}, {99.35671804148487,
        1.003232011388214}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.93304034998843, 1.0156967962835832`}, {
       99.35671804148487, -1.003232011388214}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.35671804148487, 1.003232011388214}, {
       120., -16.548747474150296`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.35671804148487, -1.003232011388214}, {120., 
       16.548747474150296`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxl0mtIk1Ecx/FpWKJIZqOiRFNSCRPMmFlTzt/V2jLNNk2HrCzLlmnaBZ1p
QaTzMjX2QkuaGN5vFSj2ZCUeXahp4dRMRQkvCCY528WmYUkXqBf/PXB4+MCX
35tz3OJSxPHWLBbr2O/z5++Qt7dQMOgPSoGW10dZ8OylqDHflQuBhxnpx7Z1
4ieP+Zm8wIdPLrkiqfcqNkU9RXudtQz3vbwUIC0nuK6+e43OJW69zdrEh3QP
huf1ZJVGJXuqhY/FkGUVpp3IN2IT1BO0R3Q89UN1ylHwm2W7zW38TrK3dHnq
E0Ight9ek7rBTBw1Gb3dumjg2OclPo3RY1PUU7RHk8anNetqAWh8AnQ9whVa
bOgKMo6dhAH/hIM7Y5cp6+93FrTspVnVmzVsgnqC9kht1r1g3zMhcG4mvK7X
1kyyag6E+ktE8FYzTpUcEzZFPU33MLuuDIdCtT5opsXpG118be/e6BgBDxpa
12RiIzZBPVFWFmp0m8Nh+NqCjAldJtG587l3KyNhoHyyI6PMgE1RT202ZTJ2
qlPQ+spjWlBvotyJiopd26JgWtcjHrAxYBPUkyJ+ptekQgQqpoRJdTaR580j
Ks71aAiU1SvmFXpsinpaFj/mfjlJDJeGtLvjqozUSilVL76QgLjPq5+3XY9N
UE/utJ53NvEjwDG//771ISP5d38t7dWKC20ugNyJelpw/EMYlx0JS35D+29M
GLBJ0eBIetV4JKg4t5qLFBambl/Ka0OKT4O09aotE2Bh4jT57oezMAo6YveU
Nhj12HTUu6lgajkK2HMlaVdaLEzMj0oGAtTRcNEn8es+uYWpy5GpJYYrgR12
TcITYGGSk/1ZPjIqAXfZTesgBwv/f+/mwHkmo9C3Exl+AbtZJCo=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301533648376*^9, 3.6147092990690193`*^9, 
  3.614729155124814*^9},
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"},
 CellLabel->"During evaluation of In[230]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3.5 ",
 StyleBox["SurfaceApproximation", "Input"],
 " and ",
 StyleBox["SurfacePoints", "Input"]
}], "Subsection",
 CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "In this section, we will examine the ",
 StyleBox["SurfaceApproximation", "Input"],
 " and ",
 StyleBox["SurfacePoints", "Input"],
 " options. These two options can greatly influence the behavior of iterative \
ray-surface intercept calculations in custom surfaces."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.5"}],

Cell[TextData[{
 StyleBox["SurfaceApproximation ->", "Input"],
 " ",
 StyleBox["method",
  FontSlant->"Italic"],
 " specifies the ",
 StyleBox["method",
  FontSlant->"Italic"],
 " used to determine an approximate starting point for numerical ray-surface \
intersection calculations.\n",
 StyleBox["SurfacePoints -> ", "Input"],
 StyleBox["number",
  FontSlant->"Italic"],
 " specifies the number of points of a surface net used by ",
 StyleBox["SurfaceApproximation -> TriangleNet", "Input"],
 "."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 StyleBox["SurfaceApproximation", "Input"],
 " becomes active for iterative settings of ",
 StyleBox["SurfaceRayIntersection", "Input"],
 ". These include: ",
 StyleBox["SurfaceRayIntersection -> Automatic", "Input"],
 ", ",
 StyleBox["Numeric", "Input"],
 ", ",
 StyleBox["FindRoot", "Input"],
 ", and ",
 StyleBox["FindMinimum", "Input"],
 ". Note that the non-iterative settings of ",
 StyleBox["SurfaceRayIntersection", "Input"],
 " such as ",
 StyleBox["Symbol", "Input"],
 ", ",
 StyleBox["Solve", "Input"],
 ", and ",
 StyleBox["NSolve", "Input"],
 " do not depend on ",
 StyleBox["SurfaceApproximation", "Input"],
 " at all!  For many iterative techniques, having a reasonable initial \
estimate makes the difference between having a good trace or not. In \
particular, settings which involve iterative numerical methods for solving \
systems of equations first require an initial starting point to begin its \
iterative solution search. In such methods, it is critical that the initial \
starting point is sufficiently close to the global optimal solution in order \
for the correct solution to be determined. Otherwise the correct solution may \
be overlooked in favor of a local minimum that happens to lie closer to the \
initial starting point and corrupts the ray-surface calculation. When ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " uses an iterative numeric procedure to calculate the ray-surface \
intersection point, it first uses a secondary procedure to get a rough \
estimate of the solution. It is the ",
 StyleBox["SurfaceApproximation", "Input"],
 " option that specifies this secondary procedure. There are presently ten \
different methods available for ",
 StyleBox["SurfaceApproximation", "Input"],
 ", shown below."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "(1) ",
 StyleBox["SurfaceApproximation -> TriangleNet", "Input"],
 " (or ",
 StyleBox["Automatic", "Input"],
 ") constructs a triangular fishnet of starting points based on the original \
optical surfacefunction. For this, the ",
 StyleBox["SurfacePoints", "Input"],
 " option specifies the number of fishnet elements. \n(2) ",
 StyleBox["SurfaceApproximation -> {TriangleNet -> ", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " denotes an alternative surface function to generate the fish-net of \
numerical starting points. \n(3) ",
 StyleBox["SurfaceApproximation -> {Symbol -> ", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " indicates an alternative surface function which has an analytic \
ray-surface intersection solution (determined by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "). \n(4) ",
 StyleBox["SurfaceApproximation -> PlanarShape", "Input"],
 " uses the intersection point with a plane for a starting condition. \n(5)",
 StyleBox[" SurfaceApproximation -> {SphericalShape -> ", "Input"],
 StyleBox["radius",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " uses the intersection point with a hemi-spherical surface that has a given \
radius. \n(6) ",
 StyleBox["SurfaceApproximation -> {CylindricalShape -> ", "Input"],
 StyleBox["radius",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " uses the intersection point with a half-cylinder that has a given radius. \
\n(7) ",
 StyleBox["SurfaceApproximation -> {ParabolicShape -> ", "Input"],
 StyleBox["focus",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " uses the intersection point with a paraboloid that has a given focus. \n\
(8) ",
 StyleBox["SurfaceApproximation -> {SurfaceIntersectionFunction-> ", 
  "Input"],
 StyleBox["intersectionfunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " directly specifies an alternative ray-surface intersection solution. In \
this case, the intersectionfunction need not be analytic. \nFor ",
 StyleBox["SurfaceRayIntersection -> FindRoot/FindMinimum", "Input"],
 " only, there are two additional settings available: \n(9) ",
 StyleBox["SurfaceApproximation -> {Solve -> ", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " dynamically uses the ",
 StyleBox["Solve", "Input"],
 " function to determine an initial condition. \n(10) ",
 StyleBox["SurfaceApproximation -> {NSolve -> ", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " uses the ",
 StyleBox["NSolve", "Input"],
 " function to dynamically determine an approximate intersection point for \
surfacefunction. "
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "The ten different settings of ",
 StyleBox["SurfaceApproximation", "Input",
  FontSlant->"Plain"],
 " that find the approximate ray-surface intersection point."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "Together, these ten different methods offer a nearly endless combination of \
settings. The optimal choice of setting is very much dependent on the \
particular surface function shape. However, since the ",
 StyleBox["SurfaceApproximation -> ", "Input",
  FontSlant->"Plain"],
 StyleBox["TriangleNet", "Input"],
 " setting behaves robustly for nearly all surface shapes, it is usually \
invoked for the default ",
 StyleBox["SurfaceApproximation -> Automatic", "Input"],
 " setting.  As such, we will examine this setting in more detail. When this ",
 StyleBox["TriangleNet", "Input"],
 " method is invoked, during the initial component creation process (when you \
first evaluate the component function), the optical surface function is first \
sampled across a grid of points that lie within the specified surface \
aperture. The values of these grid points are then stored in the component \
surface information for later use during the ray-trace.  During the ray \
trace, the precalculated grid points are assembled into a model of triangular \
planar facets that span the optical surface. These facets are used to obtain \
the approximate location of the ray intercept point on the actual optical \
surface by finding the closest facet to the passing ray. With the default ",
 StyleBox["Interpolation -> True", "Input"],
 " setting, the intercept estimate is further improved by interpolating the \
intercept value between the facet's three grid-point locations."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "The ",
 StyleBox["SurfacePoints", "Input"],
 " option is used in conjunction with ",
 StyleBox["SurfaceApproximation -> TriangleNet", "Input"],
 ". Here, the ",
 StyleBox["SurfacePoints", "Input"],
 " setting can specify either a single integer or a pair of integer numbers. \
When two numbers are given, ",
 StyleBox["SurfacePoints", "Input"],
 " ",
 StyleBox["->", "Input"],
 " {",
 StyleBox["n",
  FontSlant->"Italic"],
 ", ",
 StyleBox["m",
  FontSlant->"Italic"],
 "}, each value separately specifies the number of points along each of the \
two parametric coordinate directions. Increasing the number helps to deal \
with steeply curved custom surfaces. In order to visualize the resulting ",
 StyleBox["SurfaceApproximation", "Input"],
 " behavior, you can use option to ",
 StyleBox["SurfacePoints -> True|Fill|Mesh", "Input"],
 " with ",
 StyleBox["ShowSystem", "Input"],
 " and ",
 StyleBox["AnalyzeSystem", "Input"],
 " to render the actual ",
 StyleBox["TriangleNet", "Input"],
 " facets (Note that ",
 StyleBox["SurfacePoints", "Input"],
 " does not work with settings other than ",
 StyleBox["TriangleNet", "Input"],
 "). Here is an example that shows two views of a circular conic mirror. The \
bottom image shows a projection of the triangular surface facets present."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],50],
\tSurfacePoints -> Mesh
];
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],50, GraphicDesign -> False],
\tSurfacePoints -> Mesh,
\tPlotType->FrontView
];\
\>", "Input",
 CellChangeTimes->{{3.5634578383562517`*^9, 3.563457863148793*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[231]:="],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{25.00000136602541, 12.500001, 21.650636094610967`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{25.00000136602541, 12.500001, 21.650636094610967`}], 
   Point3DBox[{25.00000136602541, 12.500001, 21.650636094610967`}], 
   Point3DBox[{25.000000366025443`, -12.499999, 21.650636094610967`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{25.000000366025443`, -12.499999, 21.650636094610967`}], 
   Point3DBox[{25.000000366025443`, -12.499999, 21.650636094610967`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{25.00000136602541, 12.500001, 21.650636094610967`}], 
   Point3DBox[{43.75000100961208, 32.812501, 18.944306707784595`}], 
   Point3DBox[{25.00000136602541, 12.500001, 21.650636094610967`}], 
   Point3DBox[{25.000000366025443`, -12.499999, 21.650636094610967`}], 
   Point3DBox[{43.75000045488432, 1.*^-6, 37.888612415569185`}], 
   Point3DBox[{25.000000366025443`, -12.499999, 21.650636094610967`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{43.749998384612105`, -32.812499, 18.944306707784595`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{43.749996869067616`, -32.812499, -18.944304707784593`}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{43.749997423795406`, 1.*^-6, -37.88861041556919}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{43.749999494067644`, 32.812501, -18.944304707784593`}], 
   Line3DBox[{{4.166667666666786, 4.166667666666666, 1.*^-6}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}}], 
   Line3DBox[{{4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {4.166668032692086, 
    2.083334333333333, 3.6084401824351606`}}], 
   Line3DBox[{{4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {1.414213562373095*^-6, 
    1.*^-6, 1.*^-6}, {4.166667032692294, -2.083332333333333, 
    3.6084401824351606`}}], 
   Line3DBox[{{4.166665666666786, -4.166665666666666, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}}], 
   Line3DBox[{{4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}}], 
   Line3DBox[{{4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    4.166667666666786, 4.166667666666666, 1.*^-6}, {1.414213562373095*^-6, 
    1.*^-6, 1.*^-6}, {4.166666300641486, 
    2.083334333333333, -3.6084381824351603`}}], 
   Line3DBox[{{4.166667666666786, 4.166667666666666, 1.*^-6}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}}], 
   Line3DBox[{{8.333334333333392, 8.333334333333331, 1.*^-6}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}}], 
   Line3DBox[{{4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}}], 
   Line3DBox[{{8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}}], 
   Line3DBox[{{4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}}], 
   Line3DBox[{{8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}}], 
   Line3DBox[{{4.166665666666786, -4.166665666666666, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}}], 
   Line3DBox[{{8.333332333333393, -8.333332333333333, 1.*^-6}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}}], 
   Line3DBox[{{4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}}], 
   Line3DBox[{{8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}}], 
   Line3DBox[{{4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    4.166667666666786, 4.166667666666666, 1.*^-6}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}, {4.166666300641486, 
    2.083334333333333, -3.6084381824351603`}}], 
   Line3DBox[{{8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}}], 
   Line3DBox[{{8.333334333333392, 8.333334333333331, 1.*^-6}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    12.50000100000004, 12.500001, 1.*^-6}, {8.333334333333392, 
    8.333334333333331, 1.*^-6}}], 
   Line3DBox[{{12.50000100000004, 12.500001, 1.*^-6}, {12.500001366025408`, 
    6.250001, 10.825318547305482`}, {8.333334699358744, 4.166667666666666, 
    7.216879364870321}, {12.50000100000004, 12.500001, 1.*^-6}}], 
   Line3DBox[{{8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}, {8.333334699358744, 
    4.166667666666666, 7.216879364870321}}], 
   Line3DBox[{{12.500001366025408`, 6.250001, 10.825318547305482`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}}], 
   Line3DBox[{{8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}}], 
   Line3DBox[{{12.500000366025478`, -6.249999, 10.825318547305482`}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}}], 
   Line3DBox[{{8.333332333333393, -8.333332333333333, 1.*^-6}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}}], 
   Line3DBox[{{12.499999000000042`, -12.499999, 1.*^-6}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    12.499999000000042`, -12.499999, 1.*^-6}}], 
   Line3DBox[{{8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}}], 
   Line3DBox[{{12.499998633974602`, -6.249999, -10.825316547305484`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}}], 
   Line3DBox[{{8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {12.49999963397467, 
    6.250001, -10.825316547305484`}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}}], 
   Line3DBox[{{12.49999963397467, 6.250001, -10.825316547305484`}, {
    12.50000100000004, 12.500001, 1.*^-6}, {8.333334333333392, 
    8.333334333333331, 1.*^-6}, {12.49999963397467, 
    6.250001, -10.825316547305484`}}], 
   Line3DBox[{{12.50000100000004, 12.500001, 1.*^-6}, {12.500001366025408`, 
    6.250001, 10.825318547305482`}, {16.666667666666694`, 16.666667666666665`,
     1.*^-6}, {12.50000100000004, 12.500001, 1.*^-6}}], 
   Line3DBox[{{16.666667666666694`, 16.666667666666665`, 1.*^-6}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}, {16.666667666666694`,
     16.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{12.500001366025408`, 6.250001, 10.825318547305482`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {16.66666803269207, 
    8.333334333333331, 14.433757729740641`}, {12.500001366025408`, 6.250001, 
    10.825318547305482`}}], 
   Line3DBox[{{16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {16.66666803269207, 
    8.333334333333331, 14.433757729740641`}}], 
   Line3DBox[{{12.500000366025478`, -6.249999, 10.825318547305482`}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}}], 
   Line3DBox[{{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {16.666665666666695`, -16.666665666666663`, 
    1.*^-6}, {12.499999000000042`, -12.499999, 1.*^-6}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}}], 
   Line3DBox[{{12.499999000000042`, -12.499999, 1.*^-6}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    12.499999000000042`, -12.499999, 1.*^-6}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{12.499998633974602`, -6.249999, -10.825316547305484`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}}], 
   Line3DBox[{{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}}], 
   Line3DBox[{{12.49999963397467, 6.250001, -10.825316547305484`}, {
    12.50000100000004, 12.500001, 1.*^-6}, {16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {12.49999963397467, 
    6.250001, -10.825316547305484`}}], 
   Line3DBox[{{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}, {12.50000100000004, 12.500001, 1.*^-6}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}}], 
   Line3DBox[{{16.666667666666694`, 16.666667666666665`, 1.*^-6}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    20.83333433333336, 20.833334333333337`, 1.*^-6}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{20.83333433333336, 20.833334333333337`, 1.*^-6}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    20.83333433333336, 20.833334333333337`, 1.*^-6}}], 
   Line3DBox[{{16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}}], 
   Line3DBox[{{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}}], 
   Line3DBox[{{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {16.666665666666695`, -16.666665666666663`, 
    1.*^-6}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}}], 
   Line3DBox[{{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}}], 
   Line3DBox[{{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}}], 
   Line3DBox[{{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    20.833332967307975`, 10.416667666666667`, -18.042194912175805`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}}], 
   Line3DBox[{{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}}], 
   Line3DBox[{{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {16.666667666666694`, 16.666667666666665`, 
    1.*^-6}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}}], 
   Line3DBox[{{20.83333433333336, 20.833334333333337`, 1.*^-6}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    25.000001000000022`, 25.000001, 1.*^-6}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}}], 
   Line3DBox[{{25.000001000000022`, 25.000001, 1.*^-6}, {25.00000136602541, 
    12.500001, 21.650636094610967`}, {20.833334699358744`, 
    10.416667666666667`, 18.042196912175807`}, {25.000001000000022`, 
    25.000001, 1.*^-6}}], 
   Line3DBox[{{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {25.00000136602541, 12.500001, 
    21.650636094610967`}, {20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}}], 
   Line3DBox[{{25.00000136602541, 12.500001, 21.650636094610967`}, {
    25.000000366025443`, -12.499999, 21.650636094610967`}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}, {
    25.00000136602541, 12.500001, 21.650636094610967`}}], 
   Line3DBox[{{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    25.000000366025443`, -12.499999, 21.650636094610967`}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}}], 
   Line3DBox[{{25.000000366025443`, -12.499999, 21.650636094610967`}, {
    24.99999900000002, -24.999999, 1.*^-6}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    25.000000366025443`, -12.499999, 21.650636094610967`}}], 
   Line3DBox[{{20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    24.99999900000002, -24.999999, 1.*^-6}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}}], 
   Line3DBox[{{24.99999900000002, -24.999999, 1.*^-6}, {
    24.9999986339746, -12.499999, -21.650634094610965`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    24.99999900000002, -24.999999, 1.*^-6}}], 
   Line3DBox[{{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    20.833332967307975`, 10.416667666666667`, -18.042194912175805`}, {
    24.9999986339746, -12.499999, -21.650634094610965`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}}], 
   Line3DBox[{{24.9999986339746, -12.499999, -21.650634094610965`}, {
    24.99999963397463, 12.500001, -21.650634094610965`}, {20.833332967307975`,
     10.416667666666667`, -18.042194912175805`}, {
    24.9999986339746, -12.499999, -21.650634094610965`}}], 
   Line3DBox[{{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {24.99999963397463, 
    12.500001, -21.650634094610965`}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}}], 
   Line3DBox[{{24.99999963397463, 12.500001, -21.650634094610965`}, {
    25.000001000000022`, 25.000001, 1.*^-6}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {24.99999963397463, 
    12.500001, -21.650634094610965`}}], 
   Line3DBox[{{25.000001000000022`, 25.000001, 1.*^-6}, {25.00000136602541, 
    12.500001, 21.650636094610967`}, {43.75000100961208, 32.812501, 
    18.944306707784595`}, {25.000001000000022`, 25.000001, 1.*^-6}}], 
   Line3DBox[{{25.00000136602541, 12.500001, 21.650636094610967`}, {
    25.000000366025443`, -12.499999, 21.650636094610967`}, {43.75000045488432,
     1.*^-6, 37.888612415569185`}, {25.00000136602541, 12.500001, 
    21.650636094610967`}}], 
   Line3DBox[{{25.000000366025443`, -12.499999, 21.650636094610967`}, {
    24.99999900000002, -24.999999, 1.*^-6}, {43.749998384612105`, -32.812499, 
    18.944306707784595`}, {25.000000366025443`, -12.499999, 
    21.650636094610967`}}], 
   Line3DBox[{{24.99999900000002, -24.999999, 1.*^-6}, {
    24.9999986339746, -12.499999, -21.650634094610965`}, {
    43.749996869067616`, -32.812499, -18.944304707784593`}, {
    24.99999900000002, -24.999999, 1.*^-6}}], 
   Line3DBox[{{24.9999986339746, -12.499999, -21.650634094610965`}, {
    24.99999963397463, 12.500001, -21.650634094610965`}, {43.749997423795406`,
     1.*^-6, -37.88861041556919}, {
    24.9999986339746, -12.499999, -21.650634094610965`}}], 
   Line3DBox[{{24.99999963397463, 12.500001, -21.650634094610965`}, {
    25.000001000000022`, 25.000001, 1.*^-6}, {43.749999494067644`, 
    32.812501, -18.944304707784593`}, {24.99999963397463, 
    12.500001, -21.650634094610965`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB2Aiq1eBgIEDlIaLrwHzFRygNFwcAj7Y
QOk9MJEVUPUwGlXcwAFGw8T//QcBCwcYjWo+3J1wcTR3wsXR3IlmDtydNjjc
eQBVHO5OuDiaO9HCATM8AZYfbUQ=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdGBAAZYHVq8CAQO4OJR/YA2YVoCLQ/kHILwP
NqjmfNizAk09jL8CzXwY/99/ELCAi6PyMdzpgMOdDjjc6YDDnTY43HkAhzsP
4HDnARzuPAAA1+ltRA==
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.333333333333332, 0.}, {
      8.333333333333332, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.333333333333332, 0.}, {
      16.666666666666664`, 16.666666666666664`, 0.}, {16.666666666666664`, 
      16.09876377148447, 4.313650751708678}, {8.333333333333332, 
      8.049381885742235, 2.156825375854339}, {8.333333333333332, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{16.666666666666664`, 16.666666666666664`, 0.}, {25., 25., 
      0.}, {24.999999999999996`, 24.148145657226706`, 6.4704761275630185`}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}, {
      16.666666666666664`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {24.999999999999996`, 24.148145657226706`, 
      6.4704761275630185`}, {25., 21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {25., 21.65063509461097, 12.499999999999998`}, {
      24.999999999999996`, 17.67766952966369, 17.677669529663685`}, {
      16.666666666666664`, 11.785113019775793`, 11.785113019775789`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {24.999999999999996`, 17.67766952966369, 
      17.677669529663685`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {25., 6.470476127563024, 24.148145657226706`}, {
      16.666666666666668`, 4.313650751708682, 16.09876377148447}, {
      16.666666666666668`, 8.333333333333336, 14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {16.666666666666664`, 4.721282414706649*^-15, 
      16.666666666666664`}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {25., 6.470476127563024, 24.148145657226706`}, {25.,
       7.0819236220599744`*^-15, 25.}, {16.666666666666664`, 
      4.721282414706649*^-15, 16.666666666666664`}, {16.666666666666668`, 
      4.313650751708682, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {25., 1.5308084989341915`*^-15, 25.}, {
      24.999999999999996`, -6.470476127563016, 24.148145657226706`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}, {
      16.666666666666664`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {24.999999999999996`, -6.470476127563016, 
      24.148145657226706`}, {25., -12.499999999999995`, 21.65063509461097}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {25., -12.499999999999995`, 21.65063509461097}, {
      24.999999999999996`, -17.677669529663685`, 17.67766952966369}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {16.666666666666668`, -14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {24.999999999999996`, -17.677669529663685`, 
      17.67766952966369}, {25., -21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, -14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -7.21687836487032, 
      4.16666666666667}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -7.21687836487032, 4.16666666666667}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      8.333333333333334, -8.049381885742235, 2.156825375854342}, {
      8.333333333333334, -7.21687836487032, 4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666668`, -14.43375672974064, 
      8.33333333333334}, {25., -21.650635094610962`, 12.500000000000009`}, {
      25., -24.148145657226706`, 6.470476127563026}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {25., -24.148145657226706`, 6.470476127563026}, {
      25., -25., 3.061616997868383*^-15}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {
      8.333333333333332, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {25., -25., 3.061616997868383*^-15}, {
      25., -24.148145657226706`, -6.47047612756302}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      25., -24.14814565722671, -6.470476127563009}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      25., -17.677669529663692`, -17.677669529663685`}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      25., -17.677669529663696`, -17.677669529663678`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      25., -2.6796885989305705`*^-14, -25.}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      16.666666666666664`, 4.313650751708671, -16.09876377148447}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      25., -4.592425496802574*^-15, -25.}, {25., 
      6.470476127563007, -24.14814565722671}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {25., 
      6.470476127563007, -24.14814565722671}, {25., 
      12.499999999999984`, -21.650635094610976`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {25., 
      12.499999999999984`, -21.650635094610976`}, {25.000000000000004`, 
      17.67766952966367, -17.67766952966371}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {25., 
      17.677669529663685`, -17.677669529663692`}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {25., 
      25., -2.8327694488239898`*^-14}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwdEClGRj+g4GFg8fVDfffqFo4OO4qrTvyUBKu
7tnvFtYJy0wdIOo0HGDqd6QJH6hea+iwHUozQtUzgWlNh6dQfTBz3KHmwuyB
iZ8+f3797Mm3bWB8mPl2EPUH0NX/hbjjAKq7LGDuOABzF0z9E4i6A6xQd8HE
oeYe8ETzL5Q+AHHXa7i7PKHqzaDuQgufA3+g7oKJ74K6ZyuUhrmTDeKOA4+h
+mDhFg411x1qD8ycG7dvH96y7ssemLtg4iZQd3uiqf8OjacXUPNh4rB42onm
Hqg74O6CuQfqDocINP+ixtvvPQBgjO9B
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015341861553`*^9, 3.61470929984875*^9, 
  3.614729155652544*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[231]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{2.083334333333333, 3.6084401824351606`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{2.083334333333333, 3.6084401824351606`}], 
   PointBox[{-2.083332333333333, 3.6084401824351606`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-2.083332333333333, 3.6084401824351606`}], 
   PointBox[{-4.166665666666666, 1.*^-6}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-2.083332333333333, -3.6084381824351603`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-2.083332333333333, -3.6084381824351603`}], 
   PointBox[{2.083334333333333, -3.6084381824351603`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{2.083334333333333, -3.6084381824351603`}], 
   PointBox[{4.166667666666666, 1.*^-6}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{2.083334333333333, 3.6084401824351606`}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{2.083334333333333, 3.6084401824351606`}], 
   PointBox[{2.083334333333333, 3.6084401824351606`}], 
   PointBox[{-2.083332333333333, 3.6084401824351606`}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{-2.083332333333333, 3.6084401824351606`}], 
   PointBox[{-2.083332333333333, 3.6084401824351606`}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-2.083332333333333, -3.6084381824351603`}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{-2.083332333333333, -3.6084381824351603`}], 
   PointBox[{-2.083332333333333, -3.6084381824351603`}], 
   PointBox[{2.083334333333333, -3.6084381824351603`}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{2.083334333333333, -3.6084381824351603`}], 
   PointBox[{2.083334333333333, -3.6084381824351603`}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{12.500001, 1.*^-6}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{4.166667666666666, 7.216879364870321}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{-6.249999, 10.825318547305482`}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{-4.166665666666666, 7.216879364870321}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-6.249999, 10.825318547305482`}], 
   PointBox[{-6.249999, 10.825318547305482`}], PointBox[{-12.499999, 1.*^-6}],
    PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{-12.499999, 1.*^-6}], PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{-4.166665666666666, -7.216877364870321}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{6.250001, -10.825316547305484`}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{4.166667666666666, -7.216877364870321}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{6.250001, -10.825316547305484`}], 
   PointBox[{6.250001, -10.825316547305484`}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{8.333334333333331, 1.*^-6}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{6.250001, 10.825318547305482`}], 
   PointBox[{-6.249999, 10.825318547305482`}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{-6.249999, 10.825318547305482`}], 
   PointBox[{-6.249999, 10.825318547305482`}], PointBox[{-12.499999, 1.*^-6}],
    PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{-6.249999, -10.825316547305484`}], 
   PointBox[{6.250001, -10.825316547305484`}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{6.250001, -10.825316547305484`}], 
   PointBox[{6.250001, -10.825316547305484`}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{16.666667666666665`, 1.*^-6}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{8.333334333333331, 14.433757729740641`}], 
   PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{-8.333332333333333, 14.433757729740641`}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{-8.333332333333333, -14.433755729740643`}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{8.333334333333331, -14.433755729740643`}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{25.000001, 1.*^-6}], PointBox[{25.000001, 1.*^-6}], 
   PointBox[{12.500001, 21.650636094610967`}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{10.416667666666667`, 18.042196912175807`}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{12.500001, 21.650636094610967`}], 
   PointBox[{12.500001, 21.650636094610967`}], 
   PointBox[{-12.499999, 21.650636094610967`}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{-10.416665666666669`, 18.042196912175807`}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-12.499999, 21.650636094610967`}], 
   PointBox[{-12.499999, 21.650636094610967`}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-12.499999, -21.650634094610965`}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{-10.416665666666669`, -18.042194912175805`}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{-12.499999, -21.650634094610965`}], 
   PointBox[{-12.499999, -21.650634094610965`}], 
   PointBox[{12.500001, -21.650634094610965`}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{10.416667666666667`, -18.042194912175805`}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{12.500001, -21.650634094610965`}], 
   PointBox[{12.500001, -21.650634094610965`}], PointBox[{25.000001, 1.*^-6}],
    PointBox[{20.833334333333337`, 1.*^-6}], PointBox[{25.000001, 1.*^-6}], 
   PointBox[{12.500001, 21.650636094610967`}], 
   PointBox[{32.812501, 18.944306707784595`}], 
   PointBox[{12.500001, 21.650636094610967`}], 
   PointBox[{-12.499999, 21.650636094610967`}], 
   PointBox[{1.*^-6, 37.888612415569185`}], 
   PointBox[{-12.499999, 21.650636094610967`}], 
   PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-32.812499, 18.944306707784595`}], 
   PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-12.499999, -21.650634094610965`}], 
   PointBox[{-32.812499, -18.944304707784593`}], 
   PointBox[{-12.499999, -21.650634094610965`}], 
   PointBox[{12.500001, -21.650634094610965`}], 
   PointBox[{1.*^-6, -37.88861041556919}], 
   PointBox[{12.500001, -21.650634094610965`}], PointBox[{25.000001, 1.*^-6}],
    PointBox[{32.812501, -18.944304707784593`}], 
   LineBox[{{4.166667666666666, 1.*^-6}, {2.083334333333333, 
    3.6084401824351606`}, {1.*^-6, 1.*^-6}, {4.166667666666666, 1.*^-6}}], 
   LineBox[{{2.083334333333333, 3.6084401824351606`}, {-2.083332333333333, 
    3.6084401824351606`}, {1.*^-6, 1.*^-6}, {2.083334333333333, 
    3.6084401824351606`}}], 
   LineBox[{{-2.083332333333333, 3.6084401824351606`}, {-4.166665666666666, 
    1.*^-6}, {1.*^-6, 1.*^-6}, {-2.083332333333333, 3.6084401824351606`}}], 
   LineBox[{{-4.166665666666666, 
    1.*^-6}, {-2.083332333333333, -3.6084381824351603`}, {1.*^-6, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}}], 
   LineBox[{{-2.083332333333333, -3.6084381824351603`}, {
    2.083334333333333, -3.6084381824351603`}, {1.*^-6, 
    1.*^-6}, {-2.083332333333333, -3.6084381824351603`}}], 
   LineBox[{{2.083334333333333, -3.6084381824351603`}, {4.166667666666666, 
    1.*^-6}, {1.*^-6, 1.*^-6}, {2.083334333333333, -3.6084381824351603`}}], 
   LineBox[{{4.166667666666666, 1.*^-6}, {2.083334333333333, 
    3.6084401824351606`}, {8.333334333333331, 1.*^-6}, {4.166667666666666, 
    1.*^-6}}], 
   LineBox[{{8.333334333333331, 1.*^-6}, {4.166667666666666, 
    7.216879364870321}, {2.083334333333333, 3.6084401824351606`}, {
    8.333334333333331, 1.*^-6}}], 
   LineBox[{{2.083334333333333, 3.6084401824351606`}, {-2.083332333333333, 
    3.6084401824351606`}, {4.166667666666666, 7.216879364870321}, {
    2.083334333333333, 3.6084401824351606`}}], 
   LineBox[{{4.166667666666666, 7.216879364870321}, {-4.166665666666666, 
    7.216879364870321}, {-2.083332333333333, 3.6084401824351606`}, {
    4.166667666666666, 7.216879364870321}}], 
   LineBox[{{-2.083332333333333, 3.6084401824351606`}, {-4.166665666666666, 
    1.*^-6}, {-4.166665666666666, 7.216879364870321}, {-2.083332333333333, 
    3.6084401824351606`}}], 
   LineBox[{{-4.166665666666666, 7.216879364870321}, {-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}, {-4.166665666666666, 
    7.216879364870321}}], 
   LineBox[{{-4.166665666666666, 
    1.*^-6}, {-2.083332333333333, -3.6084381824351603`}, {-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}}], 
   LineBox[{{-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, -7.216877364870321}, {-2.083332333333333, \
-3.6084381824351603`}, {-8.333332333333333, 1.*^-6}}], 
   LineBox[{{-2.083332333333333, -3.6084381824351603`}, {
    2.083334333333333, -3.6084381824351603`}, {-4.166665666666666, \
-7.216877364870321}, {-2.083332333333333, -3.6084381824351603`}}], 
   LineBox[{{-4.166665666666666, -7.216877364870321}, {
    4.166667666666666, -7.216877364870321}, {
    2.083334333333333, -3.6084381824351603`}, {-4.166665666666666, \
-7.216877364870321}}], 
   LineBox[{{2.083334333333333, -3.6084381824351603`}, {4.166667666666666, 
    1.*^-6}, {4.166667666666666, -7.216877364870321}, {
    2.083334333333333, -3.6084381824351603`}}], 
   LineBox[{{4.166667666666666, -7.216877364870321}, {8.333334333333331, 
    1.*^-6}, {4.166667666666666, 1.*^-6}, {
    4.166667666666666, -7.216877364870321}}], 
   LineBox[{{8.333334333333331, 1.*^-6}, {4.166667666666666, 
    7.216879364870321}, {12.500001, 1.*^-6}, {8.333334333333331, 1.*^-6}}], 
   LineBox[{{12.500001, 1.*^-6}, {6.250001, 10.825318547305482`}, {
    4.166667666666666, 7.216879364870321}, {12.500001, 1.*^-6}}], 
   LineBox[{{4.166667666666666, 7.216879364870321}, {-4.166665666666666, 
    7.216879364870321}, {6.250001, 10.825318547305482`}, {4.166667666666666, 
    7.216879364870321}}], 
   LineBox[{{6.250001, 10.825318547305482`}, {-6.249999, 
    10.825318547305482`}, {-4.166665666666666, 7.216879364870321}, {6.250001, 
    10.825318547305482`}}], 
   LineBox[{{-4.166665666666666, 7.216879364870321}, {-8.333332333333333, 
    1.*^-6}, {-6.249999, 10.825318547305482`}, {-4.166665666666666, 
    7.216879364870321}}], 
   LineBox[{{-6.249999, 10.825318547305482`}, {-12.499999, 
    1.*^-6}, {-8.333332333333333, 1.*^-6}, {-6.249999, 10.825318547305482`}}],
    LineBox[{{-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, -7.216877364870321}, {-12.499999, 
    1.*^-6}, {-8.333332333333333, 1.*^-6}}], 
   LineBox[{{-12.499999, 
    1.*^-6}, {-6.249999, -10.825316547305484`}, {-4.166665666666666, \
-7.216877364870321}, {-12.499999, 1.*^-6}}], 
   LineBox[{{-4.166665666666666, -7.216877364870321}, {
    4.166667666666666, -7.216877364870321}, {-6.249999, \
-10.825316547305484`}, {-4.166665666666666, -7.216877364870321}}], 
   LineBox[{{-6.249999, -10.825316547305484`}, {
    6.250001, -10.825316547305484`}, {
    4.166667666666666, -7.216877364870321}, {-6.249999, \
-10.825316547305484`}}], 
   LineBox[{{4.166667666666666, -7.216877364870321}, {8.333334333333331, 
    1.*^-6}, {6.250001, -10.825316547305484`}, {
    4.166667666666666, -7.216877364870321}}], 
   LineBox[{{6.250001, -10.825316547305484`}, {12.500001, 1.*^-6}, {
    8.333334333333331, 1.*^-6}, {6.250001, -10.825316547305484`}}], 
   LineBox[{{12.500001, 1.*^-6}, {6.250001, 10.825318547305482`}, {
    16.666667666666665`, 1.*^-6}, {12.500001, 1.*^-6}}], 
   LineBox[{{16.666667666666665`, 1.*^-6}, {8.333334333333331, 
    14.433757729740641`}, {6.250001, 10.825318547305482`}, {
    16.666667666666665`, 1.*^-6}}], 
   LineBox[{{6.250001, 10.825318547305482`}, {-6.249999, 
    10.825318547305482`}, {8.333334333333331, 14.433757729740641`}, {6.250001,
     10.825318547305482`}}], 
   LineBox[{{8.333334333333331, 14.433757729740641`}, {-8.333332333333333, 
    14.433757729740641`}, {-6.249999, 10.825318547305482`}, {
    8.333334333333331, 14.433757729740641`}}], 
   LineBox[{{-6.249999, 10.825318547305482`}, {-12.499999, 
    1.*^-6}, {-8.333332333333333, 14.433757729740641`}, {-6.249999, 
    10.825318547305482`}}], 
   LineBox[{{-8.333332333333333, 14.433757729740641`}, {-16.666665666666663`, 
    1.*^-6}, {-12.499999, 1.*^-6}, {-8.333332333333333, 
    14.433757729740641`}}], 
   LineBox[{{-12.499999, 
    1.*^-6}, {-6.249999, -10.825316547305484`}, {-16.666665666666663`, 
    1.*^-6}, {-12.499999, 1.*^-6}}], 
   LineBox[{{-16.666665666666663`, 
    1.*^-6}, {-8.333332333333333, -14.433755729740643`}, {-6.249999, \
-10.825316547305484`}, {-16.666665666666663`, 1.*^-6}}], 
   LineBox[{{-6.249999, -10.825316547305484`}, {
    6.250001, -10.825316547305484`}, {-8.333332333333333, \
-14.433755729740643`}, {-6.249999, -10.825316547305484`}}], 
   LineBox[{{-8.333332333333333, -14.433755729740643`}, {
    8.333334333333331, -14.433755729740643`}, {
    6.250001, -10.825316547305484`}, {-8.333332333333333, \
-14.433755729740643`}}], 
   LineBox[{{6.250001, -10.825316547305484`}, {12.500001, 1.*^-6}, {
    8.333334333333331, -14.433755729740643`}, {
    6.250001, -10.825316547305484`}}], 
   LineBox[{{8.333334333333331, -14.433755729740643`}, {16.666667666666665`, 
    1.*^-6}, {12.500001, 1.*^-6}, {8.333334333333331, -14.433755729740643`}}],
    LineBox[{{16.666667666666665`, 1.*^-6}, {8.333334333333331, 
    14.433757729740641`}, {20.833334333333337`, 1.*^-6}, {16.666667666666665`,
     1.*^-6}}], 
   LineBox[{{20.833334333333337`, 1.*^-6}, {10.416667666666667`, 
    18.042196912175807`}, {8.333334333333331, 14.433757729740641`}, {
    20.833334333333337`, 1.*^-6}}], 
   LineBox[{{8.333334333333331, 14.433757729740641`}, {-8.333332333333333, 
    14.433757729740641`}, {10.416667666666667`, 18.042196912175807`}, {
    8.333334333333331, 14.433757729740641`}}], 
   LineBox[{{10.416667666666667`, 18.042196912175807`}, {-10.416665666666669`,
     18.042196912175807`}, {-8.333332333333333, 14.433757729740641`}, {
    10.416667666666667`, 18.042196912175807`}}], 
   LineBox[{{-8.333332333333333, 14.433757729740641`}, {-16.666665666666663`, 
    1.*^-6}, {-10.416665666666669`, 18.042196912175807`}, {-8.333332333333333,
     14.433757729740641`}}], 
   LineBox[{{-10.416665666666669`, 
    18.042196912175807`}, {-20.833332333333335`, 
    1.*^-6}, {-16.666665666666663`, 1.*^-6}, {-10.416665666666669`, 
    18.042196912175807`}}], 
   LineBox[{{-16.666665666666663`, 
    1.*^-6}, {-8.333332333333333, -14.433755729740643`}, \
{-20.833332333333335`, 1.*^-6}, {-16.666665666666663`, 1.*^-6}}], 
   LineBox[{{-20.833332333333335`, 
    1.*^-6}, {-10.416665666666669`, -18.042194912175805`}, \
{-8.333332333333333, -14.433755729740643`}, {-20.833332333333335`, 1.*^-6}}], 
   LineBox[{{-8.333332333333333, -14.433755729740643`}, {
    8.333334333333331, -14.433755729740643`}, {-10.416665666666669`, \
-18.042194912175805`}, {-8.333332333333333, -14.433755729740643`}}], 
   LineBox[{{-10.416665666666669`, -18.042194912175805`}, {
    10.416667666666667`, -18.042194912175805`}, {
    8.333334333333331, -14.433755729740643`}, {-10.416665666666669`, \
-18.042194912175805`}}], 
   LineBox[{{8.333334333333331, -14.433755729740643`}, {16.666667666666665`, 
    1.*^-6}, {10.416667666666667`, -18.042194912175805`}, {
    8.333334333333331, -14.433755729740643`}}], 
   LineBox[{{10.416667666666667`, -18.042194912175805`}, {20.833334333333337`,
     1.*^-6}, {16.666667666666665`, 1.*^-6}, {
    10.416667666666667`, -18.042194912175805`}}], 
   LineBox[{{20.833334333333337`, 1.*^-6}, {10.416667666666667`, 
    18.042196912175807`}, {25.000001, 1.*^-6}, {20.833334333333337`, 
    1.*^-6}}], 
   LineBox[{{25.000001, 1.*^-6}, {12.500001, 21.650636094610967`}, {
    10.416667666666667`, 18.042196912175807`}, {25.000001, 1.*^-6}}], 
   LineBox[{{10.416667666666667`, 18.042196912175807`}, {-10.416665666666669`,
     18.042196912175807`}, {12.500001, 21.650636094610967`}, {
    10.416667666666667`, 18.042196912175807`}}], 
   LineBox[{{12.500001, 21.650636094610967`}, {-12.499999, 
    21.650636094610967`}, {-10.416665666666669`, 18.042196912175807`}, {
    12.500001, 21.650636094610967`}}], 
   LineBox[{{-10.416665666666669`, 
    18.042196912175807`}, {-20.833332333333335`, 1.*^-6}, {-12.499999, 
    21.650636094610967`}, {-10.416665666666669`, 18.042196912175807`}}], 
   LineBox[{{-12.499999, 21.650636094610967`}, {-24.999999, 
    1.*^-6}, {-20.833332333333335`, 1.*^-6}, {-12.499999, 
    21.650636094610967`}}], 
   LineBox[{{-20.833332333333335`, 
    1.*^-6}, {-10.416665666666669`, -18.042194912175805`}, {-24.999999, 
    1.*^-6}, {-20.833332333333335`, 1.*^-6}}], 
   LineBox[{{-24.999999, 
    1.*^-6}, {-12.499999, -21.650634094610965`}, {-10.416665666666669`, \
-18.042194912175805`}, {-24.999999, 1.*^-6}}], 
   LineBox[{{-10.416665666666669`, -18.042194912175805`}, {
    10.416667666666667`, -18.042194912175805`}, {-12.499999, \
-21.650634094610965`}, {-10.416665666666669`, -18.042194912175805`}}], 
   LineBox[{{-12.499999, -21.650634094610965`}, {
    12.500001, -21.650634094610965`}, {
    10.416667666666667`, -18.042194912175805`}, {-12.499999, \
-21.650634094610965`}}], 
   LineBox[{{10.416667666666667`, -18.042194912175805`}, {20.833334333333337`,
     1.*^-6}, {12.500001, -21.650634094610965`}, {
    10.416667666666667`, -18.042194912175805`}}], 
   LineBox[{{12.500001, -21.650634094610965`}, {25.000001, 1.*^-6}, {
    20.833334333333337`, 1.*^-6}, {12.500001, -21.650634094610965`}}], 
   LineBox[{{25.000001, 1.*^-6}, {12.500001, 21.650636094610967`}, {32.812501,
     18.944306707784595`}, {25.000001, 1.*^-6}}], 
   LineBox[{{12.500001, 21.650636094610967`}, {-12.499999, 
    21.650636094610967`}, {1.*^-6, 37.888612415569185`}, {12.500001, 
    21.650636094610967`}}], 
   LineBox[{{-12.499999, 21.650636094610967`}, {-24.999999, 
    1.*^-6}, {-32.812499, 18.944306707784595`}, {-12.499999, 
    21.650636094610967`}}], 
   LineBox[{{-24.999999, 
    1.*^-6}, {-12.499999, -21.650634094610965`}, {-32.812499, \
-18.944304707784593`}, {-24.999999, 1.*^-6}}], 
   LineBox[{{-12.499999, -21.650634094610965`}, {
    12.500001, -21.650634094610965`}, {
    1.*^-6, -37.88861041556919}, {-12.499999, -21.650634094610965`}}], 
   LineBox[{{12.500001, -21.650634094610965`}, {25.000001, 1.*^-6}, {
    32.812501, -18.944304707784593`}, {12.500001, -21.650634094610965`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015341861553`*^9, 3.61470929984875*^9, 
  3.61472915593438*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[231]:="]
}, Open  ]],

Cell[TextData[{
 "Triangular facets given by ",
 StyleBox["TriangleNet", "Input",
  FontSlant->"Plain"],
 " for a circular component aperture."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "For circular surface boundaries, the outer star-like facet protrusions are \
used to insure complete facet coverage near the surface edges. You can switch \
off these extra facets with the ",
 StyleBox["CircumscribeBoundary -> False", "Input"],
 " option. In most cases, however, there is no reason to do this."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell[TextData[{
 "ShowSystem[\n\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],50, ",
 StyleBox["CircumscribeBoundary -> False", "Input"],
 "],\n\tSurfacePoints -> Mesh\n];"
}], "Input",
 CellChangeTimes->{{3.5634578784684753`*^9, 3.563457879932493*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[233]:="],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{1.414213562373095*^-6, 1.*^-6, 1.*^-6}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166668032692086, 2.083334333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166667032692294, -2.083332333333333, 3.6084401824351606`}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665666666786, -4.166665666666666, 1.*^-6}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166665300641278, -2.083332333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166666300641486, 2.083334333333333, -3.6084381824351603`}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{4.166667666666786, 4.166667666666666, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333334699358744, 4.166667666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333333699358848, -4.166665666666666, 7.216879364870321}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333332333333393, -8.333332333333333, 1.*^-6}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.333331967307936, -4.166665666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.33333296730804, 4.166667666666666, -7.216877364870321}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{8.333334333333392, 8.333334333333331, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500001366025408`, 6.250001, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.500000366025478`, -6.249999, 10.825318547305482`}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499999000000042`, -12.499999, 1.*^-6}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.499998633974602`, -6.249999, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.49999963397467, 6.250001, -10.825316547305484`}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{12.50000100000004, 12.500001, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.66666803269207, 8.333334333333331, 14.433757729740641`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{16.666667032692125`, -8.333332333333333, 14.433757729740641`}],
    Point3DBox[{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{16.666665666666695`, -16.666665666666663`, 1.*^-6}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{16.666666300641317`, 8.333334333333331, -14.433755729740643`}],
    Point3DBox[{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{16.666667666666694`, 16.666667666666665`, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{25.000001366025405`, 12.500001, 21.650636094610967`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{25.000001366025405`, 12.500001, 21.650636094610967`}], 
   Point3DBox[{25.000001366025405`, 12.500001, 21.650636094610967`}], 
   Point3DBox[{25.00000036602544, -12.499999, 21.650636094610967`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{25.00000036602544, -12.499999, 21.650636094610967`}], 
   Point3DBox[{25.00000036602544, -12.499999, 21.650636094610967`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{20.83333233333336, -20.833332333333335`, 1.*^-6}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{24.99999900000002, -24.999999, 1.*^-6}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{24.9999986339746, -12.499999, -21.650634094610965`}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{24.99999963397463, 12.500001, -21.650634094610965`}], 
   Point3DBox[{25.000001000000022`, 25.000001, 1.*^-6}], 
   Point3DBox[{20.83333433333336, 20.833334333333337`, 1.*^-6}], 
   Line3DBox[{{4.166667666666786, 4.166667666666666, 1.*^-6}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}}], 
   Line3DBox[{{4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {4.166668032692086, 
    2.083334333333333, 3.6084401824351606`}}], 
   Line3DBox[{{4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {1.414213562373095*^-6, 
    1.*^-6, 1.*^-6}, {4.166667032692294, -2.083332333333333, 
    3.6084401824351606`}}], 
   Line3DBox[{{4.166665666666786, -4.166665666666666, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}}], 
   Line3DBox[{{4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    1.414213562373095*^-6, 1.*^-6, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}}], 
   Line3DBox[{{4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    4.166667666666786, 4.166667666666666, 1.*^-6}, {1.414213562373095*^-6, 
    1.*^-6, 1.*^-6}, {4.166666300641486, 
    2.083334333333333, -3.6084381824351603`}}], 
   Line3DBox[{{4.166667666666786, 4.166667666666666, 1.*^-6}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}}], 
   Line3DBox[{{8.333334333333392, 8.333334333333331, 1.*^-6}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}}], 
   Line3DBox[{{4.166668032692086, 2.083334333333333, 3.6084401824351606`}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    4.166668032692086, 2.083334333333333, 3.6084401824351606`}}], 
   Line3DBox[{{8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}}], 
   Line3DBox[{{4.166667032692294, -2.083332333333333, 3.6084401824351606`}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    4.166667032692294, -2.083332333333333, 3.6084401824351606`}}], 
   Line3DBox[{{8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}}], 
   Line3DBox[{{4.166665666666786, -4.166665666666666, 1.*^-6}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    4.166665666666786, -4.166665666666666, 1.*^-6}}], 
   Line3DBox[{{8.333332333333393, -8.333332333333333, 1.*^-6}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}}], 
   Line3DBox[{{4.166665300641278, -2.083332333333333, -3.6084381824351603`}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    4.166665300641278, -2.083332333333333, -3.6084381824351603`}}], 
   Line3DBox[{{8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}}], 
   Line3DBox[{{4.166666300641486, 2.083334333333333, -3.6084381824351603`}, {
    4.166667666666786, 4.166667666666666, 1.*^-6}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}, {4.166666300641486, 
    2.083334333333333, -3.6084381824351603`}}], 
   Line3DBox[{{8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {4.166667666666786, 
    4.166667666666666, 1.*^-6}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}}], 
   Line3DBox[{{8.333334333333392, 8.333334333333331, 1.*^-6}, {
    8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    12.50000100000004, 12.500001, 1.*^-6}, {8.333334333333392, 
    8.333334333333331, 1.*^-6}}], 
   Line3DBox[{{12.50000100000004, 12.500001, 1.*^-6}, {12.500001366025408`, 
    6.250001, 10.825318547305482`}, {8.333334699358744, 4.166667666666666, 
    7.216879364870321}, {12.50000100000004, 12.500001, 1.*^-6}}], 
   Line3DBox[{{8.333334699358744, 4.166667666666666, 7.216879364870321}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}, {8.333334699358744, 
    4.166667666666666, 7.216879364870321}}], 
   Line3DBox[{{12.500001366025408`, 6.250001, 10.825318547305482`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}}], 
   Line3DBox[{{8.333333699358848, -4.166665666666666, 7.216879364870321}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {
    8.333333699358848, -4.166665666666666, 7.216879364870321}}], 
   Line3DBox[{{12.500000366025478`, -6.249999, 10.825318547305482`}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}}], 
   Line3DBox[{{8.333332333333393, -8.333332333333333, 1.*^-6}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    8.333332333333393, -8.333332333333333, 1.*^-6}}], 
   Line3DBox[{{12.499999000000042`, -12.499999, 1.*^-6}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    12.499999000000042`, -12.499999, 1.*^-6}}], 
   Line3DBox[{{8.333331967307936, -4.166665666666666, -7.216877364870321}, {
    8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    8.333331967307936, -4.166665666666666, -7.216877364870321}}], 
   Line3DBox[{{12.499998633974602`, -6.249999, -10.825316547305484`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}}], 
   Line3DBox[{{8.33333296730804, 4.166667666666666, -7.216877364870321}, {
    8.333334333333392, 8.333334333333331, 1.*^-6}, {12.49999963397467, 
    6.250001, -10.825316547305484`}, {8.33333296730804, 
    4.166667666666666, -7.216877364870321}}], 
   Line3DBox[{{12.49999963397467, 6.250001, -10.825316547305484`}, {
    12.50000100000004, 12.500001, 1.*^-6}, {8.333334333333392, 
    8.333334333333331, 1.*^-6}, {12.49999963397467, 
    6.250001, -10.825316547305484`}}], 
   Line3DBox[{{12.50000100000004, 12.500001, 1.*^-6}, {12.500001366025408`, 
    6.250001, 10.825318547305482`}, {16.666667666666694`, 16.666667666666665`,
     1.*^-6}, {12.50000100000004, 12.500001, 1.*^-6}}], 
   Line3DBox[{{16.666667666666694`, 16.666667666666665`, 1.*^-6}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    12.500001366025408`, 6.250001, 10.825318547305482`}, {16.666667666666694`,
     16.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{12.500001366025408`, 6.250001, 10.825318547305482`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {16.66666803269207, 
    8.333334333333331, 14.433757729740641`}, {12.500001366025408`, 6.250001, 
    10.825318547305482`}}], 
   Line3DBox[{{16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}, {16.66666803269207, 
    8.333334333333331, 14.433757729740641`}}], 
   Line3DBox[{{12.500000366025478`, -6.249999, 10.825318547305482`}, {
    12.499999000000042`, -12.499999, 1.*^-6}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    12.500000366025478`, -6.249999, 10.825318547305482`}}], 
   Line3DBox[{{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {16.666665666666695`, -16.666665666666663`, 
    1.*^-6}, {12.499999000000042`, -12.499999, 1.*^-6}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}}], 
   Line3DBox[{{12.499999000000042`, -12.499999, 1.*^-6}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    12.499999000000042`, -12.499999, 1.*^-6}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{12.499998633974602`, -6.249999, -10.825316547305484`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    12.499998633974602`, -6.249999, -10.825316547305484`}}], 
   Line3DBox[{{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    12.49999963397467, 6.250001, -10.825316547305484`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}}], 
   Line3DBox[{{12.49999963397467, 6.250001, -10.825316547305484`}, {
    12.50000100000004, 12.500001, 1.*^-6}, {16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {12.49999963397467, 
    6.250001, -10.825316547305484`}}], 
   Line3DBox[{{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}, {12.50000100000004, 12.500001, 1.*^-6}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}}], 
   Line3DBox[{{16.666667666666694`, 16.666667666666665`, 1.*^-6}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    20.83333433333336, 20.833334333333337`, 1.*^-6}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{20.83333433333336, 20.833334333333337`, 1.*^-6}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    20.83333433333336, 20.833334333333337`, 1.*^-6}}], 
   Line3DBox[{{16.66666803269207, 8.333334333333331, 14.433757729740641`}, {
    16.666667032692125`, -8.333332333333333, 14.433757729740641`}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    16.66666803269207, 8.333334333333331, 14.433757729740641`}}], 
   Line3DBox[{{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}}], 
   Line3DBox[{{16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}, {16.666665666666695`, -16.666665666666663`, 
    1.*^-6}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {16.666667032692125`, -8.333332333333333, 
    14.433757729740641`}}], 
   Line3DBox[{{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666663`, 1.*^-6}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    16.666665666666695`, -16.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}}], 
   Line3DBox[{{
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    16.666665300641267`, -8.333332333333333, -14.433755729740643`}}], 
   Line3DBox[{{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    20.833332967307975`, 10.416667666666667`, -18.042194912175805`}, {
    16.666666300641317`, 8.333334333333331, -14.433755729740643`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}}], 
   Line3DBox[{{16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}, {16.666667666666694`, 
    16.666667666666665`, 1.*^-6}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {16.666666300641317`, 
    8.333334333333331, -14.433755729740643`}}], 
   Line3DBox[{{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {16.666667666666694`, 16.666667666666665`, 
    1.*^-6}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}}], 
   Line3DBox[{{20.83333433333336, 20.833334333333337`, 1.*^-6}, {
    20.833334699358744`, 10.416667666666667`, 18.042196912175807`}, {
    25.000001000000022`, 25.000001, 1.*^-6}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}}], 
   Line3DBox[{{25.000001000000022`, 25.000001, 1.*^-6}, {25.000001366025405`, 
    12.500001, 21.650636094610967`}, {20.833334699358744`, 
    10.416667666666667`, 18.042196912175807`}, {25.000001000000022`, 
    25.000001, 1.*^-6}}], 
   Line3DBox[{{20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}, {20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {25.000001366025405`, 12.500001, 
    21.650636094610967`}, {20.833334699358744`, 10.416667666666667`, 
    18.042196912175807`}}], 
   Line3DBox[{{25.000001366025405`, 12.500001, 21.650636094610967`}, {
    25.00000036602544, -12.499999, 21.650636094610967`}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}, {
    25.000001366025405`, 12.500001, 21.650636094610967`}}], 
   Line3DBox[{{20.833333699358786`, -10.416665666666669`, 
    18.042196912175807`}, {20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    25.00000036602544, -12.499999, 21.650636094610967`}, {
    20.833333699358786`, -10.416665666666669`, 18.042196912175807`}}], 
   Line3DBox[{{25.00000036602544, -12.499999, 21.650636094610967`}, {
    24.99999900000002, -24.999999, 1.*^-6}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    25.00000036602544, -12.499999, 21.650636094610967`}}], 
   Line3DBox[{{20.83333233333336, -20.833332333333335`, 1.*^-6}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    24.99999900000002, -24.999999, 1.*^-6}, {
    20.83333233333336, -20.833332333333335`, 1.*^-6}}], 
   Line3DBox[{{24.99999900000002, -24.999999, 1.*^-6}, {
    24.9999986339746, -12.499999, -21.650634094610965`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    24.99999900000002, -24.999999, 1.*^-6}}], 
   Line3DBox[{{
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}, {
    20.833332967307975`, 10.416667666666667`, -18.042194912175805`}, {
    24.9999986339746, -12.499999, -21.650634094610965`}, {
    20.833331967307934`, -10.416665666666669`, -18.042194912175805`}}], 
   Line3DBox[{{24.9999986339746, -12.499999, -21.650634094610965`}, {
    24.99999963397463, 12.500001, -21.650634094610965`}, {20.833332967307975`,
     10.416667666666667`, -18.042194912175805`}, {
    24.9999986339746, -12.499999, -21.650634094610965`}}], 
   Line3DBox[{{20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {24.99999963397463, 
    12.500001, -21.650634094610965`}, {20.833332967307975`, 
    10.416667666666667`, -18.042194912175805`}}], 
   Line3DBox[{{24.99999963397463, 12.500001, -21.650634094610965`}, {
    25.000001000000022`, 25.000001, 1.*^-6}, {20.83333433333336, 
    20.833334333333337`, 1.*^-6}, {24.99999963397463, 
    12.500001, -21.650634094610965`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdIDSB2Aiq1eBgIEDlIaLrwHzFRygNFwcAj7Y
QOk9MJEVUPUwGlXcwAFGw8T//QcBCwcYjWo+3J1wcTR3wsXR3IlmDtydNjjc
eQBVHO5OuDiaO9HCATM8AZYfbUQ=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhiwdGBAAZYHVq8CAQO4OJR/YA2YVoCLQ/kHILwP
NqjmfNizAk09jL8CzXwY/99/ELCAi6PyMdzpgMOdDjjc6YDDnTY43HkAhzsP
4HDnARzuPAAA1+ltRA==
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.333333333333332, 0.}, {
      8.333333333333332, 8.049381885742235, 2.156825375854339}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.333333333333332, 0.}, {
      16.666666666666664`, 16.666666666666664`, 0.}, {16.666666666666664`, 
      16.09876377148447, 4.313650751708678}, {8.333333333333332, 
      8.049381885742235, 2.156825375854339}, {8.333333333333332, 
      8.333333333333332, 0.}}], 
     Polygon3DBox[{{16.666666666666664`, 16.666666666666664`, 0.}, {25., 25., 
      0.}, {24.999999999999996`, 24.148145657226706`, 6.4704761275630185`}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}, {
      16.666666666666664`, 16.666666666666664`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 8.049381885742235, 
      2.156825375854339}, {16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 8.049381885742235, 
      2.156825375854339}}], 
     Polygon3DBox[{{16.666666666666664`, 16.09876377148447, 
      4.313650751708678}, {24.999999999999996`, 24.148145657226706`, 
      6.4704761275630185`}, {25., 21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, 16.09876377148447, 4.313650751708678}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 7.216878364870323, 
      4.166666666666666}, {16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 7.216878364870323, 
      4.166666666666666}}], 
     Polygon3DBox[{{16.666666666666668`, 14.433756729740645`, 
      8.333333333333332}, {25., 21.65063509461097, 12.499999999999998`}, {
      24.999999999999996`, 17.67766952966369, 17.677669529663685`}, {
      16.666666666666664`, 11.785113019775793`, 11.785113019775789`}, {
      16.666666666666668`, 14.433756729740645`, 8.333333333333332}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333332, 5.892556509887896, 
      5.8925565098878945`}}], 
     Polygon3DBox[{{16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}, {24.999999999999996`, 17.67766952966369, 
      17.677669529663685`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666664`, 11.785113019775793`, 
      11.785113019775789`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 4.166666666666668, 
      7.216878364870322}, {16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333334, 4.166666666666668, 
      7.216878364870322}}], 
     Polygon3DBox[{{16.666666666666668`, 8.333333333333336, 
      14.433756729740644`}, {25.000000000000004`, 12.500000000000004`, 
      21.650635094610966`}, {25., 6.470476127563024, 24.148145657226706`}, {
      16.666666666666668`, 4.313650751708682, 16.09876377148447}, {
      16.666666666666668`, 8.333333333333336, 14.433756729740644`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 2.156825375854341, 
      8.049381885742235}, {16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {16.666666666666664`, 4.721282414706649*^-15, 
      16.666666666666664`}, {8.333333333333332, 2.3606412073533245`*^-15, 
      8.333333333333332}, {8.333333333333334, 2.156825375854341, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666668`, 4.313650751708682, 
      16.09876377148447}, {25., 6.470476127563024, 24.148145657226706`}, {25.,
       7.0819236220599744`*^-15, 25.}, {16.666666666666664`, 
      4.721282414706649*^-15, 16.666666666666664`}, {16.666666666666668`, 
      4.313650751708682, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}, {16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, 5.102694996447305*^-16, 
      8.333333333333332}}], 
     Polygon3DBox[{{16.666666666666664`, 1.020538999289461*^-15, 
      16.666666666666664`}, {25., 1.5308084989341915`*^-15, 25.}, {
      24.999999999999996`, -6.470476127563016, 24.148145657226706`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}, {
      16.666666666666664`, 1.020538999289461*^-15, 16.666666666666664`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}, {16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -2.1568253758543383`, 
      8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, -4.313650751708677, 
      16.09876377148447}, {24.999999999999996`, -6.470476127563016, 
      24.148145657226706`}, {25., -12.499999999999995`, 21.65063509461097}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}, {
      16.666666666666664`, -4.313650751708677, 16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -4.166666666666664, 
      7.216878364870323}, {16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333332, -4.166666666666664, 
      7.216878364870323}}], 
     Polygon3DBox[{{16.666666666666664`, -8.333333333333329, 
      14.433756729740645`}, {25., -12.499999999999995`, 21.65063509461097}, {
      24.999999999999996`, -17.677669529663685`, 17.67766952966369}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}, {
      16.666666666666664`, -8.333333333333329, 14.433756729740645`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}, {16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {16.666666666666668`, -14.433756729740645`, 
      8.333333333333332}, {8.333333333333334, -7.216878364870323, 
      4.166666666666666}, {8.333333333333332, -5.8925565098878945`, 
      5.892556509887896}}], 
     Polygon3DBox[{{16.666666666666664`, -11.785113019775789`, 
      11.785113019775793`}, {24.999999999999996`, -17.677669529663685`, 
      17.67766952966369}, {25., -21.65063509461097, 12.499999999999998`}, {
      16.666666666666668`, -14.433756729740645`, 8.333333333333332}, {
      16.666666666666664`, -11.785113019775789`, 11.785113019775793`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -7.21687836487032, 
      4.16666666666667}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -7.21687836487032, 4.16666666666667}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      8.333333333333334, -8.049381885742235, 2.156825375854342}, {
      8.333333333333334, -7.21687836487032, 4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666668`, -14.43375672974064, 
      8.33333333333334}, {25., -21.650635094610962`, 12.500000000000009`}, {
      25., -24.148145657226706`, 6.470476127563026}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}, {
      16.666666666666668`, -14.43375672974064, 8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, -8.049381885742235, 
      2.156825375854342}, {16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {8.333333333333334, -8.049381885742235, 
      2.156825375854342}}], 
     Polygon3DBox[{{16.666666666666668`, -16.09876377148447, 
      4.313650751708684}, {25., -24.148145657226706`, 6.470476127563026}, {
      25., -25., 3.061616997868383*^-15}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, 4.313650751708684}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, -8.333333333333332, 
      1.020538999289461*^-15}, {16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      8.333333333333334, -8.049381885742235, -2.15682537585434}, {
      8.333333333333332, -8.333333333333332, 1.020538999289461*^-15}}], 
     Polygon3DBox[{{16.666666666666664`, -16.666666666666664`, 
      2.041077998578922*^-15}, {25., -25., 3.061616997868383*^-15}, {
      25., -24.148145657226706`, -6.47047612756302}, {
      16.666666666666668`, -16.09876377148447, -4.31365075170868}, {
      16.666666666666664`, -16.666666666666664`, 2.041077998578922*^-15}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -8.049381885742235, -2.156825375854336}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333332, -8.049381885742235, -2.156825375854336}}], 
     Polygon3DBox[{{
      16.666666666666664`, -16.09876377148447, -4.313650751708672}, {
      25., -24.14814565722671, -6.470476127563009}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666664`, -16.09876377148447, -4.313650751708672}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -7.216878364870323, -4.166666666666664}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      8.333333333333334, -5.892556509887897, -5.8925565098878945`}, {
      8.333333333333332, -7.216878364870323, -4.166666666666664}}], 
     Polygon3DBox[{{
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}, {
      25., -21.65063509461097, -12.499999999999993`}, {
      25., -17.677669529663692`, -17.677669529663685`}, {
      16.666666666666668`, -11.785113019775794`, -11.785113019775789`}, {
      16.666666666666664`, -14.433756729740645`, -8.333333333333329}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -5.892556509887898, -5.892556509887893}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -5.892556509887898, -5.892556509887893}}], 
     Polygon3DBox[{{
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}, {
      25., -17.677669529663696`, -17.677669529663678`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -11.785113019775796`, -11.785113019775785`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -4.16666666666667, -7.216878364870319}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -4.16666666666667, -7.216878364870319}}], 
     Polygon3DBox[{{
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}, {
      24.999999999999996`, -12.50000000000001, -21.65063509461096}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -8.33333333333334, -14.433756729740638`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {0., 
      0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -2.156825375854346, -8.049381885742234}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      8.333333333333332, -8.932295329768568*^-15, -8.333333333333332}, {
      8.333333333333332, -2.156825375854346, -8.049381885742234}}], 
     Polygon3DBox[{{
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}, {
      25.000000000000004`, -6.470476127563038, -24.148145657226703`}, {
      25., -2.6796885989305705`*^-14, -25.}, {
      16.666666666666664`, -1.7864590659537137`*^-14, -16.666666666666664`}, {
      16.666666666666664`, -4.313650751708692, -16.098763771484467`}}], 
     Polygon3DBox[{{0., 0., 0.}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {0., 0., 
      0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      16.666666666666664`, 4.313650751708671, -16.09876377148447}, {
      8.333333333333332, 2.1568253758543356`, -8.049381885742235}, {
      8.333333333333332, -1.5308084989341913`*^-15, -8.333333333333332}}], 
     Polygon3DBox[{{
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}, {
      25., -4.592425496802574*^-15, -25.}, {25., 
      6.470476127563007, -24.14814565722671}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {
      16.666666666666664`, -3.0616169978683826`*^-15, -16.666666666666664`}}],
      Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333332, 
      2.1568253758543356`, -8.049381885742235}}], 
     Polygon3DBox[{{16.666666666666664`, 
      4.313650751708671, -16.09876377148447}, {25., 
      6.470476127563007, -24.14814565722671}, {25., 
      12.499999999999984`, -21.650635094610976`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666664`, 
      4.313650751708671, -16.09876377148447}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      4.166666666666661, -7.216878364870325}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {8.333333333333334, 
      5.89255650988789, -5.892556509887903}, {8.333333333333334, 
      4.166666666666661, -7.216878364870325}}], 
     Polygon3DBox[{{16.666666666666668`, 
      8.333333333333321, -14.43375672974065}, {25., 
      12.499999999999984`, -21.650635094610976`}, {25.000000000000004`, 
      17.67766952966367, -17.67766952966371}, {16.666666666666668`, 
      11.78511301977578, -11.785113019775807`}, {16.666666666666668`, 
      8.333333333333321, -14.43375672974065}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      5.8925565098878945`, -5.892556509887897}}], 
     Polygon3DBox[{{16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}, {25., 
      17.677669529663685`, -17.677669529663692`}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      11.785113019775789`, -11.785113019775794`}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {0., 0., 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{8.333333333333332, 
      7.216878364870319, -4.16666666666667}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      7.216878364870319, -4.16666666666667}}], 
     Polygon3DBox[{{16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}, {24.999999999999996`, 
      21.65063509461096, -12.50000000000001}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      14.433756729740638`, -8.33333333333334}}], 
     Polygon3DBox[{{0., 0., 0.}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {0., 0., 0.}, {0., 0., 
      0.}}], Polygon3DBox[{{8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {8.333333333333332, 
      8.333333333333332, -9.442564829413298*^-15}, {8.333333333333334, 
      8.049381885742234, -2.1568253758543463`}}], 
     Polygon3DBox[{{16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}, {25.000000000000004`, 
      24.148145657226703`, -6.470476127563039}, {25., 
      25., -2.8327694488239898`*^-14}, {16.666666666666664`, 
      16.666666666666664`, -1.8885129658826596`*^-14}, {16.666666666666668`, 
      16.098763771484467`, -4.313650751708693}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiwdEClGRj+g4GFg8fVDfffqFo4OO4qrTvyUBKu
7tnvFtYJy0wdIOo0HGDqd6QJH6hea+iwHUozQtUzgWlNh6dQfTBz3KHmwuyB
iZ8+f3797Mm3bWB8mPl2EPUH0NX/hbjjAKq7LGDuOABzF0z9E4i6A6xQd8HE
oeYe8ETzL5Q+AHHXa7i7PKHqzaDuQgufA3+g7oKJ74K6ZyuUhrmTDeKOA4+h
+mDhFg411x1qD8ycG7dvH96y7ssemLtg4iZQd3uiqf8OjacXUPNh4rB42onm
Hqg74O6CuQfqDocINP+ixtvvPQBgjO9B
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015348492937`*^9, 3.6147093005513887`*^9, 
  3.614729156353986*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[233]:="]
}, Open  ]],

Cell["\<\
The facet arrangement is different for rectangular boundaries. Here are the \
facets of a square conic mirror.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],{50,50}],
\tSurfacePoints -> Mesh,
\tPlotPoints -> 50
];
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],{50,50}, GraphicDesign -> False],
\tSurfacePoints -> Mesh,
\tPlotType->FrontView
];\
\>", "Input",
 CellChangeTimes->{{3.563457888732071*^9, 3.563457895147957*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[234]:="],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{35.35533764511381, -24.999999, -24.999999}], 
   Point3DBox[{30.046259242116086`, -24.999999, -16.666665666666667`}], 
   Point3DBox[{30.046259242116086`, -16.666665666666667`, -24.999999}], 
   Point3DBox[{30.046259242116086`, -16.666665666666667`, -24.999999}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{30.046259242116086`, -24.999999, -16.666665666666667`}], 
   Point3DBox[{30.046259242116086`, -24.999999, -16.666665666666667`}], 
   Point3DBox[{26.35231256982544, -24.999999, -8.333332333333336}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{26.35231256982544, -24.999999, -8.333332333333336}], 
   Point3DBox[{26.35231256982544, -24.999999, -8.333332333333336}], 
   Point3DBox[{24.99999900000002, -24.999999, 9.999999964472863*^-7}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{24.99999900000002, -24.999999, 9.999999964472863*^-7}], 
   Point3DBox[{24.99999900000002, -24.999999, 9.999999964472863*^-7}], 
   Point3DBox[{26.35231320228099, -24.999999, 8.333334333333328}], 
   Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{18.633899365284698`, -16.666665666666667`, 8.333334333333328}],
    Point3DBox[{26.35231320228099, -24.999999, 8.333334333333328}], 
   Point3DBox[{26.35231320228099, -24.999999, 8.333334333333328}], 
   Point3DBox[{30.046260351516505`, -24.999999, 16.666667666666658`}], 
   Point3DBox[{18.633899365284698`, -16.666665666666667`, 8.333334333333328}],
    Point3DBox[{18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}], 
   Point3DBox[{23.57022603955162, -16.666665666666667`, 16.666667666666658`}],
    Point3DBox[{30.046260351516505`, -24.999999, 16.666667666666658`}], 
   Point3DBox[{30.046260351516505`, -24.999999, 16.666667666666658`}], 
   Point3DBox[{35.3553390593274, -24.999999, 25.000000999999994`}], 
   Point3DBox[{23.57022603955162, -16.666665666666667`, 16.666667666666658`}],
    Point3DBox[{23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}], 
   Point3DBox[{30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}], 
   Point3DBox[{35.3553390593274, -24.999999, 25.000000999999994`}], 
   Point3DBox[{30.046259242116086`, -16.666665666666667`, -24.999999}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{26.35231256982544, -8.333332333333336, -24.999999}], 
   Point3DBox[{26.35231256982544, -8.333332333333336, -24.999999}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}], 
   Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}], 
   Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}], 
   Point3DBox[{8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}],
    Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}], 
   Point3DBox[{18.633899365284698`, -16.666665666666667`, 8.333334333333328}],
    Point3DBox[{8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}],
    Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{18.633899365284698`, -16.666665666666667`, 8.333334333333328}],
    Point3DBox[{18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}], 
   Point3DBox[{23.57022603955162, -16.666665666666667`, 16.666667666666658`}],
    Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{18.633900259711883`, -8.333332333333336, 16.666667666666658`}],
    Point3DBox[{23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}], 
   Point3DBox[{23.57022603955162, -16.666665666666667`, 16.666667666666658`}],
    Point3DBox[{30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}], 
   Point3DBox[{18.633900259711883`, -8.333332333333336, 16.666667666666658`}],
    Point3DBox[{18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}], 
   Point3DBox[{26.352314467192052`, -8.333332333333336, 25.000000999999994`}],
    Point3DBox[{30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}], 
   Point3DBox[{26.35231256982544, -8.333332333333336, -24.999999}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{24.99999900000002, 9.999999964472863*^-7, -24.999999}], 
   Point3DBox[{24.99999900000002, 9.999999964472863*^-7, -24.999999}], 
   Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}], 
   Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}], 
   Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}],
    Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}],
    Point3DBox[{11.785111605562234`, -8.333332333333336, -8.333332333333336}],
    Point3DBox[{8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}],
    Point3DBox[{8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}],
    Point3DBox[{8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}], 
   Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}], 
   Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{11.785113019775876`, -8.333332333333336, 8.333334333333328}], 
   Point3DBox[{18.633900259711883`, -8.333332333333336, 16.666667666666658`}],
    Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}],
    Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}],
    Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{18.633900259711883`, -8.333332333333336, 16.666667666666658`}],
    Point3DBox[{18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}], 
   Point3DBox[{26.352314467192052`, -8.333332333333336, 25.000000999999994`}],
    Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{25.000001000000015`, 9.999999964472863*^-7, 
    25.000000999999994`}], 
   Point3DBox[{26.352314467192052`, -8.333332333333336, 25.000000999999994`}],
    Point3DBox[{24.99999900000002, 9.999999964472863*^-7, -24.999999}], 
   Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{26.35231320228099, 8.333334333333328, -24.999999}], 
   Point3DBox[{26.35231320228099, 8.333334333333328, -24.999999}], 
   Point3DBox[{18.633899365284698`, 8.333334333333328, -16.666665666666667`}],
    Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}], 
   Point3DBox[{8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}],
    Point3DBox[{18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}], 
   Point3DBox[{18.633899365284698`, 8.333334333333328, -16.666665666666667`}],
    Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}],
    Point3DBox[{8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}], 
   Point3DBox[{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}], 
   Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}], 
   Point3DBox[{25.000001000000015`, 9.999999964472863*^-7, 
    25.000000999999994`}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{26.35231509964756, 8.333334333333328, 25.000000999999994`}], 
   Point3DBox[{25.000001000000015`, 9.999999964472863*^-7, 
    25.000000999999994`}], 
   Point3DBox[{26.35231320228099, 8.333334333333328, -24.999999}], 
   Point3DBox[{18.633899365284698`, 8.333334333333328, -16.666665666666667`}],
    Point3DBox[{30.046260351516505`, 16.666667666666658`, -24.999999}], 
   Point3DBox[{30.046260351516505`, 16.666667666666658`, -24.999999}], 
   Point3DBox[{23.57022603955162, 16.666667666666658`, -16.666665666666667`}],
    Point3DBox[{18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}], 
   Point3DBox[{18.633899365284698`, 8.333334333333328, -16.666665666666667`}],
    Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{23.57022603955162, 16.666667666666658`, -16.666665666666667`}],
    Point3DBox[{23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}], 
   Point3DBox[{18.633900259711883`, 16.666667666666658`, -8.333332333333336}],
    Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{11.785113019775876`, 8.333334333333328, -8.333332333333336}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{18.633900259711883`, 16.666667666666658`, -8.333332333333336}],
    Point3DBox[{18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}], 
   Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{11.785114433989346`, 8.333334333333328, 8.333334333333328}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{18.63390115413903, 8.333334333333328, 16.666667666666658`}], 
   Point3DBox[{26.35231509964756, 8.333334333333328, 25.000000999999994`}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{30.04626201561706, 16.666667666666658`, 25.000000999999994`}], 
   Point3DBox[{26.35231509964756, 8.333334333333328, 25.000000999999994`}], 
   Point3DBox[{30.046260351516505`, 16.666667666666658`, -24.999999}], 
   Point3DBox[{23.57022603955162, 16.666667666666658`, -16.666665666666667`}],
    Point3DBox[{35.3553390593274, 25.000000999999994`, -24.999999}], 
   Point3DBox[{35.3553390593274, 25.000000999999994`, -24.999999}], 
   Point3DBox[{30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}], 
   Point3DBox[{23.57022603955162, 16.666667666666658`, -16.666665666666667`}],
    Point3DBox[{23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}], 
   Point3DBox[{18.633900259711883`, 16.666667666666658`, -8.333332333333336}],
    Point3DBox[{30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}], 
   Point3DBox[{30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}], 
   Point3DBox[{26.352314467192052`, 25.000000999999994`, -8.333332333333336}],
    Point3DBox[{18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}], 
   Point3DBox[{18.633900259711883`, 16.666667666666658`, -8.333332333333336}],
    Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{26.352314467192052`, 25.000000999999994`, -8.333332333333336}],
    Point3DBox[{26.352314467192052`, 
    25.000000999999994`, -8.333332333333336}], 
   Point3DBox[{25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}], 
   Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}], 
   Point3DBox[{25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}], 
   Point3DBox[{26.35231509964756, 25.000000999999994`, 8.333334333333328}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{18.63390115413903, 16.666667666666658`, 8.333334333333328}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{26.35231509964756, 25.000000999999994`, 8.333334333333328}], 
   Point3DBox[{26.35231509964756, 25.000000999999994`, 8.333334333333328}], 
   Point3DBox[{30.04626201561706, 25.000000999999994`, 16.666667666666658`}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}], 
   Point3DBox[{30.04626201561706, 16.666667666666658`, 25.000000999999994`}], 
   Point3DBox[{30.04626201561706, 25.000000999999994`, 16.666667666666658`}], 
   Point3DBox[{30.04626201561706, 25.000000999999994`, 16.666667666666658`}], 
   Point3DBox[{35.35534047354093, 25.000000999999994`, 25.000000999999994`}], 
   Point3DBox[{30.04626201561706, 16.666667666666658`, 25.000000999999994`}], 
   Line3DBox[{{35.35533764511381, -24.999999, -24.999999}, {
    30.046259242116086`, -24.999999, -16.666665666666667`}, {
    30.046259242116086`, -16.666665666666667`, -24.999999}, {
    35.35533764511381, -24.999999, -24.999999}}], 
   Line3DBox[{{30.046259242116086`, -16.666665666666667`, -24.999999}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    30.046259242116086`, -24.999999, -16.666665666666667`}, {
    30.046259242116086`, -16.666665666666667`, -24.999999}}], 
   Line3DBox[{{30.046259242116086`, -24.999999, -16.666665666666667`}, {
    26.35231256982544, -24.999999, -8.333332333333336}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    30.046259242116086`, -24.999999, -16.666665666666667`}}], 
   Line3DBox[{{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    26.35231256982544, -24.999999, -8.333332333333336}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}}], 
   Line3DBox[{{26.35231256982544, -24.999999, -8.333332333333336}, {
    24.99999900000002, -24.999999, 9.999999964472863*^-7}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    26.35231256982544, -24.999999, -8.333332333333336}}], 
   Line3DBox[{{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    16.666665666666695`, -16.666665666666667`, 9.999999964472863*^-7}, {
    24.99999900000002, -24.999999, 9.999999964472863*^-7}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}}], 
   Line3DBox[{{24.99999900000002, -24.999999, 9.999999964472863*^-7}, {
    26.35231320228099, -24.999999, 8.333334333333328}, {
    16.666665666666695`, -16.666665666666667`, 9.999999964472863*^-7}, {
    24.99999900000002, -24.999999, 9.999999964472863*^-7}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}, {18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}, {26.35231320228099, -24.999999, 8.333334333333328}, {
    16.666665666666695`, -16.666665666666667`, 9.999999964472863*^-7}}], 
   Line3DBox[{{26.35231320228099, -24.999999, 8.333334333333328}, {
    30.046260351516505`, -24.999999, 16.666667666666658`}, {
    18.633899365284698`, -16.666665666666667`, 8.333334333333328}, {
    26.35231320228099, -24.999999, 8.333334333333328}}], 
   Line3DBox[{{18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}, {23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}, {30.046260351516505`, -24.999999, 
    16.666667666666658`}, {18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}}], 
   Line3DBox[{{30.046260351516505`, -24.999999, 16.666667666666658`}, {
    35.3553390593274, -24.999999, 25.000000999999994`}, {
    23.57022603955162, -16.666665666666667`, 16.666667666666658`}, {
    30.046260351516505`, -24.999999, 16.666667666666658`}}], 
   Line3DBox[{{23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}, {30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}, {35.3553390593274, -24.999999, 
    25.000000999999994`}, {23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}}], 
   Line3DBox[{{30.046259242116086`, -16.666665666666667`, -24.999999}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    26.35231256982544, -8.333332333333336, -24.999999}, {
    30.046259242116086`, -16.666665666666667`, -24.999999}}], 
   Line3DBox[{{26.35231256982544, -8.333332333333336, -24.999999}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    26.35231256982544, -8.333332333333336, -24.999999}}], 
   Line3DBox[{{
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    23.57022462533802, -16.666665666666667`, -16.666665666666667`}}], 
   Line3DBox[{{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}}], 
   Line3DBox[{{
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}, {
    16.666665666666695`, -16.666665666666667`, 9.999999964472863*^-7}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    18.633898470857467`, -16.666665666666667`, -8.333332333333336}}], 
   Line3DBox[{{11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}, {
    16.666665666666695`, -16.666665666666667`, 9.999999964472863*^-7}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}}], 
   Line3DBox[{{16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}, {18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}, {8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}, {16.666665666666695`, -16.666665666666667`, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}, {11.785113019775876`, -8.333332333333336, 
    8.333334333333328}, {18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}, {8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}, {23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}, {11.785113019775876`, -8.333332333333336, 
    8.333334333333328}, {18.633899365284698`, -16.666665666666667`, 
    8.333334333333328}}], 
   Line3DBox[{{11.785113019775876`, -8.333332333333336, 8.333334333333328}, {
    18.633900259711883`, -8.333332333333336, 16.666667666666658`}, {
    23.57022603955162, -16.666665666666667`, 16.666667666666658`}, {
    11.785113019775876`, -8.333332333333336, 8.333334333333328}}], 
   Line3DBox[{{23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}, {30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}, {18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}, {23.57022603955162, -16.666665666666667`, 
    16.666667666666658`}}], 
   Line3DBox[{{18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}, {26.352314467192052`, -8.333332333333336, 
    25.000000999999994`}, {30.046260906216702`, -16.666665666666667`, 
    25.000000999999994`}, {18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}}], 
   Line3DBox[{{26.35231256982544, -8.333332333333336, -24.999999}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    24.99999900000002, 9.999999964472863*^-7, -24.999999}, {
    26.35231256982544, -8.333332333333336, -24.999999}}], 
   Line3DBox[{{24.99999900000002, 9.999999964472863*^-7, -24.999999}, {
    16.666665666666695`, 9.999999964472863*^-7, -16.666665666666667`}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    24.99999900000002, 9.999999964472863*^-7, -24.999999}}], 
   Line3DBox[{{
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    16.666665666666695`, 9.999999964472863*^-7, -16.666665666666667`}, {
    18.633898470857467`, -8.333332333333336, -16.666665666666667`}}], 
   Line3DBox[{{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}, {8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    16.666665666666695`, 9.999999964472863*^-7, -16.666665666666667`}}], 
   Line3DBox[{{11.785111605562234`, -8.333332333333336, -8.333332333333336}, {
    8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}, {
    8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}, {
    11.785111605562234`, -8.333332333333336, -8.333332333333336}}], 
   Line3DBox[{{8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}, {1.4142135573487992`*^-6, 
    9.999999964472863*^-7, 9.999999964472863*^-7}, {
    8.333332333333397, -8.333332333333336, 9.999999964472863*^-7}, {
    8.333332333333397, 9.999999964472863*^-7, -8.333332333333336}}], 
   Line3DBox[{{8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}, {11.785113019775876`, -8.333332333333336, 
    8.333334333333328}, {1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}, {8.333332333333397, -8.333332333333336, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}, {8.333334333333388, 9.999999964472863*^-7, 
    8.333334333333328}, {11.785113019775876`, -8.333332333333336, 
    8.333334333333328}, {1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{11.785113019775876`, -8.333332333333336, 8.333334333333328}, {
    18.633900259711883`, -8.333332333333336, 16.666667666666658`}, {
    8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}, {
    11.785113019775876`, -8.333332333333336, 8.333334333333328}}], 
   Line3DBox[{{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}, {
    16.66666766666669, 9.999999964472863*^-7, 16.666667666666658`}, {
    18.633900259711883`, -8.333332333333336, 16.666667666666658`}, {
    8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}}], 
   Line3DBox[{{18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}, {26.352314467192052`, -8.333332333333336, 
    25.000000999999994`}, {16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}, {18.633900259711883`, -8.333332333333336, 
    16.666667666666658`}}], 
   Line3DBox[{{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}, {25.000001000000015`, 9.999999964472863*^-7, 
    25.000000999999994`}, {26.352314467192052`, -8.333332333333336, 
    25.000000999999994`}, {16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}}], 
   Line3DBox[{{24.99999900000002, 9.999999964472863*^-7, -24.999999}, {
    16.666665666666695`, 9.999999964472863*^-7, -16.666665666666667`}, {
    26.35231320228099, 8.333334333333328, -24.999999}, {24.99999900000002, 
    9.999999964472863*^-7, -24.999999}}], 
   Line3DBox[{{26.35231320228099, 8.333334333333328, -24.999999}, {
    18.633899365284698`, 8.333334333333328, -16.666665666666667`}, {
    16.666665666666695`, 9.999999964472863*^-7, -16.666665666666667`}, {
    26.35231320228099, 8.333334333333328, -24.999999}}], 
   Line3DBox[{{16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}, {8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}, {18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}, {16.666665666666695`, 
    9.999999964472863*^-7, -16.666665666666667`}}], 
   Line3DBox[{{18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}, {11.785113019775876`, 
    8.333334333333328, -8.333332333333336}, {8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}, {18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}}], 
   Line3DBox[{{8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}, {1.4142135573487992`*^-6, 
    9.999999964472863*^-7, 9.999999964472863*^-7}, {11.785113019775876`, 
    8.333334333333328, -8.333332333333336}, {8.333332333333397, 
    9.999999964472863*^-7, -8.333332333333336}}], 
   Line3DBox[{{11.785113019775876`, 8.333334333333328, -8.333332333333336}, {
    8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}, {
    1.4142135573487992`*^-6, 9.999999964472863*^-7, 9.999999964472863*^-7}, {
    11.785113019775876`, 8.333334333333328, -8.333332333333336}}], 
   Line3DBox[{{1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}, {8.333334333333388, 9.999999964472863*^-7, 
    8.333334333333328}, {8.333334333333388, 8.333334333333328, 
    9.999999964472863*^-7}, {1.4142135573487992`*^-6, 9.999999964472863*^-7, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}, {
    11.785114433989346`, 8.333334333333328, 8.333334333333328}, {
    8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}, {
    8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}}], 
   Line3DBox[{{8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}, {
    16.66666766666669, 9.999999964472863*^-7, 16.666667666666658`}, {
    11.785114433989346`, 8.333334333333328, 8.333334333333328}, {
    8.333334333333388, 9.999999964472863*^-7, 8.333334333333328}}], 
   Line3DBox[{{11.785114433989346`, 8.333334333333328, 8.333334333333328}, {
    18.63390115413903, 8.333334333333328, 16.666667666666658`}, {
    16.66666766666669, 9.999999964472863*^-7, 16.666667666666658`}, {
    11.785114433989346`, 8.333334333333328, 8.333334333333328}}], 
   Line3DBox[{{16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}, {25.000001000000015`, 9.999999964472863*^-7, 
    25.000000999999994`}, {18.63390115413903, 8.333334333333328, 
    16.666667666666658`}, {16.66666766666669, 9.999999964472863*^-7, 
    16.666667666666658`}}], 
   Line3DBox[{{18.63390115413903, 8.333334333333328, 16.666667666666658`}, {
    26.35231509964756, 8.333334333333328, 25.000000999999994`}, {
    25.000001000000015`, 9.999999964472863*^-7, 25.000000999999994`}, {
    18.63390115413903, 8.333334333333328, 16.666667666666658`}}], 
   Line3DBox[{{26.35231320228099, 8.333334333333328, -24.999999}, {
    18.633899365284698`, 8.333334333333328, -16.666665666666667`}, {
    30.046260351516505`, 16.666667666666658`, -24.999999}, {26.35231320228099,
     8.333334333333328, -24.999999}}], 
   Line3DBox[{{30.046260351516505`, 16.666667666666658`, -24.999999}, {
    23.57022603955162, 16.666667666666658`, -16.666665666666667`}, {
    18.633899365284698`, 8.333334333333328, -16.666665666666667`}, {
    30.046260351516505`, 16.666667666666658`, -24.999999}}], 
   Line3DBox[{{18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}, {11.785113019775876`, 
    8.333334333333328, -8.333332333333336}, {23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}, {18.633899365284698`, 
    8.333334333333328, -16.666665666666667`}}], 
   Line3DBox[{{23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}, {18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}, {11.785113019775876`, 
    8.333334333333328, -8.333332333333336}, {23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}}], 
   Line3DBox[{{11.785113019775876`, 8.333334333333328, -8.333332333333336}, {
    8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}, {
    18.633900259711883`, 16.666667666666658`, -8.333332333333336}, {
    11.785113019775876`, 8.333334333333328, -8.333332333333336}}], 
   Line3DBox[{{18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}, {16.66666766666669, 
    16.666667666666658`, 9.999999964472863*^-7}, {8.333334333333388, 
    8.333334333333328, 9.999999964472863*^-7}, {18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}}], 
   Line3DBox[{{8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}, {
    11.785114433989346`, 8.333334333333328, 8.333334333333328}, {
    16.66666766666669, 16.666667666666658`, 9.999999964472863*^-7}, {
    8.333334333333388, 8.333334333333328, 9.999999964472863*^-7}}], 
   Line3DBox[{{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}, {18.63390115413903, 16.666667666666658`, 
    8.333334333333328}, {11.785114433989346`, 8.333334333333328, 
    8.333334333333328}, {16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{11.785114433989346`, 8.333334333333328, 8.333334333333328}, {
    18.63390115413903, 8.333334333333328, 16.666667666666658`}, {
    18.63390115413903, 16.666667666666658`, 8.333334333333328}, {
    11.785114433989346`, 8.333334333333328, 8.333334333333328}}], 
   Line3DBox[{{18.63390115413903, 16.666667666666658`, 8.333334333333328}, {
    23.570227453765135`, 16.666667666666658`, 16.666667666666658`}, {
    18.63390115413903, 8.333334333333328, 16.666667666666658`}, {
    18.63390115413903, 16.666667666666658`, 8.333334333333328}}], 
   Line3DBox[{{18.63390115413903, 8.333334333333328, 16.666667666666658`}, {
    26.35231509964756, 8.333334333333328, 25.000000999999994`}, {
    23.570227453765135`, 16.666667666666658`, 16.666667666666658`}, {
    18.63390115413903, 8.333334333333328, 16.666667666666658`}}], 
   Line3DBox[{{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}, {30.04626201561706, 16.666667666666658`, 
    25.000000999999994`}, {26.35231509964756, 8.333334333333328, 
    25.000000999999994`}, {23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}}], 
   Line3DBox[{{30.046260351516505`, 16.666667666666658`, -24.999999}, {
    23.57022603955162, 16.666667666666658`, -16.666665666666667`}, {
    35.3553390593274, 25.000000999999994`, -24.999999}, {30.046260351516505`, 
    16.666667666666658`, -24.999999}}], 
   Line3DBox[{{35.3553390593274, 25.000000999999994`, -24.999999}, {
    30.046260906216702`, 25.000000999999994`, -16.666665666666667`}, {
    23.57022603955162, 16.666667666666658`, -16.666665666666667`}, {
    35.3553390593274, 25.000000999999994`, -24.999999}}], 
   Line3DBox[{{23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}, {18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}, {30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}, {23.57022603955162, 
    16.666667666666658`, -16.666665666666667`}}], 
   Line3DBox[{{30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}, {26.352314467192052`, 
    25.000000999999994`, -8.333332333333336}, {18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}, {30.046260906216702`, 
    25.000000999999994`, -16.666665666666667`}}], 
   Line3DBox[{{18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}, {16.66666766666669, 
    16.666667666666658`, 9.999999964472863*^-7}, {26.352314467192052`, 
    25.000000999999994`, -8.333332333333336}, {18.633900259711883`, 
    16.666667666666658`, -8.333332333333336}}], 
   Line3DBox[{{26.352314467192052`, 
    25.000000999999994`, -8.333332333333336}, {25.000001000000015`, 
    25.000000999999994`, 9.999999964472863*^-7}, {16.66666766666669, 
    16.666667666666658`, 9.999999964472863*^-7}, {26.352314467192052`, 
    25.000000999999994`, -8.333332333333336}}], 
   Line3DBox[{{16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}, {18.63390115413903, 16.666667666666658`, 
    8.333334333333328}, {25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}, {16.66666766666669, 16.666667666666658`, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}, {26.35231509964756, 25.000000999999994`, 
    8.333334333333328}, {18.63390115413903, 16.666667666666658`, 
    8.333334333333328}, {25.000001000000015`, 25.000000999999994`, 
    9.999999964472863*^-7}}], 
   Line3DBox[{{18.63390115413903, 16.666667666666658`, 8.333334333333328}, {
    23.570227453765135`, 16.666667666666658`, 16.666667666666658`}, {
    26.35231509964756, 25.000000999999994`, 8.333334333333328}, {
    18.63390115413903, 16.666667666666658`, 8.333334333333328}}], 
   Line3DBox[{{26.35231509964756, 25.000000999999994`, 8.333334333333328}, {
    30.04626201561706, 25.000000999999994`, 16.666667666666658`}, {
    23.570227453765135`, 16.666667666666658`, 16.666667666666658`}, {
    26.35231509964756, 25.000000999999994`, 8.333334333333328}}], 
   Line3DBox[{{23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}, {30.04626201561706, 16.666667666666658`, 
    25.000000999999994`}, {30.04626201561706, 25.000000999999994`, 
    16.666667666666658`}, {23.570227453765135`, 16.666667666666658`, 
    16.666667666666658`}}], 
   Line3DBox[{{30.04626201561706, 25.000000999999994`, 16.666667666666658`}, {
    35.35534047354093, 25.000000999999994`, 25.000000999999994`}, {
    30.04626201561706, 16.666667666666658`, 25.000000999999994`}, {
    30.04626201561706, 25.000000999999994`, 16.666667666666658`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyNk0EKg0AQBIfEJ3gWAl4kIAgSyG3fkCcInv2CT8vTkkNn1MaCDMhC0ayz
PdO3aXnNl4i4f79r/OpZdL5jX+uj6DzyGKUfTT9IP5i+l7433ol3xlvx1ngj
3hivxWvjlXhlnCr1Be43nv0Yz/6N53uNpz9Hvvlp+vTf9Dkv0+d8/+N4D/2X
+oR3oQ/kG/lMc6E5UtGe0F7RHtLe0p5DLjBHlDvKKeT6hH8AQVk1dA==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx9k0sKg0AQRJvoEVwLghsJDAgiuJsz5AiBrHMFjzZHS9ByYbfPBpF6FDM9
/ene39fnYWbP/1fZEUu2Uyxl+63zma/zzm1y/kn+0flH+ZPzJ/HB8UG8d7wX
bx1vxRvHG/Ha8brYbQR/hvMz5CMd8pcO75UO9dl1rKd0qL/8oV/Sob/3HM+h
eylPeBfWgepGdaa+UB8paE5ormgOaW5pzmEvcI9o72hPYa8v+A9I4jV0
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{35.35533905932738, -25., -25.}, {
      33.63406011768428, -22.5, -25.}, {31.81980515339464, -22.5, -22.5}, {
      33.63406011768428, -25., -22.5}, {35.35533905932738, -25., -25.}}], 
     Polygon3DBox[{{33.63406011768428, -25., -22.5}, {
      31.81980515339464, -22.5, -22.5}, {30.103986446980738`, -22.5, -20.}, {
      32.01562118716424, -25., -20.}, {33.63406011768428, -25., -22.5}}], 
     Polygon3DBox[{{32.01562118716424, -25., -20.}, {
      30.103986446980738`, -22.5, -20.}, {28.50438562747845, -22.5, -17.5}, {
      30.516389039334257`, -25., -17.5}, {32.01562118716424, -25., -20.}}], 
     Polygon3DBox[{{30.516389039334257`, -25., -17.5}, {
      28.50438562747845, -22.5, -17.5}, {27.04163456597992, -22.5, -15.}, {
      29.154759474226502`, -25., -15.}, {30.516389039334257`, -25., -17.5}}], 
     Polygon3DBox[{{29.154759474226502`, -25., -15.}, {
      27.04163456597992, -22.5, -15.}, {25.739075352467502`, -22.5, -12.5}, {
      27.95084971874737, -25., -12.5}, {29.154759474226502`, -25., -15.}}], 
     Polygon3DBox[{{27.95084971874737, -25., -12.5}, {
      25.739075352467502`, -22.5, -12.5}, {24.62214450449026, -22.5, -10.}, {
      26.92582403567252, -25., -10.}, {27.95084971874737, -25., -12.5}}], 
     Polygon3DBox[{{26.92582403567252, -25., -10.}, {
      24.62214450449026, -22.5, -10.}, {23.717082451262844`, -22.5, -7.5}, {
      26.100766272276374`, -25., -7.5}, {26.92582403567252, -25., -10.}}], 
     Polygon3DBox[{{26.100766272276374`, -25., -7.5}, {
      23.717082451262844`, -22.5, -7.5}, {23.04886114323222, -22.5, -5.}, {
      25.495097567963924`, -25., -5.}, {26.100766272276374`, -25., -7.5}}], 
     Polygon3DBox[{{25.495097567963924`, -25., -5.}, {
      23.04886114323222, -22.5, -5.}, {22.638462845343543`, -22.5, -2.5}, {
      25.124689052802225`, -25., -2.5}, {25.495097567963924`, -25., -5.}}], 
     Polygon3DBox[{{25.124689052802225`, -25., -2.5}, {
      22.638462845343543`, -22.5, -2.5}, {22.5, -22.5, 0.}, {25., -25., 0.}, {
      25.124689052802225`, -25., -2.5}}], 
     Polygon3DBox[{{25., -25., 0.}, {22.5, -22.5, 0.}, {
      22.638462845343543`, -22.5, 2.5}, {25.124689052802225`, -25., 2.5}, {
      25., -25., 0.}}], 
     Polygon3DBox[{{25.124689052802225`, -25., 2.5}, {
      22.638462845343543`, -22.5, 2.5}, {23.04886114323222, -22.5, 5.}, {
      25.495097567963924`, -25., 5.}, {25.124689052802225`, -25., 2.5}}], 
     Polygon3DBox[{{25.495097567963924`, -25., 5.}, {23.04886114323222, -22.5,
       5.}, {23.717082451262844`, -22.5, 7.5}, {26.100766272276374`, -25., 
      7.5}, {25.495097567963924`, -25., 5.}}], 
     Polygon3DBox[{{26.100766272276374`, -25., 7.5}, {
      23.717082451262844`, -22.5, 7.5}, {24.62214450449026, -22.5, 10.}, {
      26.92582403567252, -25., 10.}, {26.100766272276374`, -25., 7.5}}], 
     Polygon3DBox[{{26.92582403567252, -25., 10.}, {24.62214450449026, -22.5, 
      10.}, {25.739075352467502`, -22.5, 12.5}, {27.95084971874737, -25., 
      12.5}, {26.92582403567252, -25., 10.}}], 
     Polygon3DBox[{{27.95084971874737, -25., 12.5}, {
      25.739075352467502`, -22.5, 12.5}, {27.04163456597992, -22.5, 15.}, {
      29.154759474226502`, -25., 15.}, {27.95084971874737, -25., 12.5}}], 
     Polygon3DBox[{{29.154759474226502`, -25., 15.}, {
      27.04163456597992, -22.5, 15.}, {28.50438562747845, -22.5, 17.5}, {
      30.516389039334257`, -25., 17.5}, {29.154759474226502`, -25., 15.}}], 
     Polygon3DBox[{{30.516389039334257`, -25., 17.5}, {
      28.50438562747845, -22.5, 17.5}, {30.103986446980738`, -22.5, 20.}, {
      32.01562118716424, -25., 20.}, {30.516389039334257`, -25., 17.5}}], 
     Polygon3DBox[{{32.01562118716424, -25., 20.}, {
      30.103986446980738`, -22.5, 20.}, {31.81980515339464, -22.5, 22.5}, {
      33.63406011768428, -25., 22.5}, {32.01562118716424, -25., 20.}}], 
     Polygon3DBox[{{33.63406011768428, -25., 22.5}, {31.81980515339464, -22.5,
       22.5}, {33.63406011768428, -22.5, 25.}, {35.35533905932738, -25., 
      25.}, {33.63406011768428, -25., 22.5}}], 
     Polygon3DBox[{{33.63406011768428, -22.5, -25.}, {
      32.01562118716424, -20., -25.}, {30.103986446980738`, -20., -22.5}, {
      31.81980515339464, -22.5, -22.5}, {33.63406011768428, -22.5, -25.}}], 
     Polygon3DBox[{{31.81980515339464, -22.5, -22.5}, {
      30.103986446980738`, -20., -22.5}, {28.284271247461902`, -20., -20.}, {
      30.103986446980738`, -22.5, -20.}, {31.81980515339464, -22.5, -22.5}}], 
     Polygon3DBox[{{30.103986446980738`, -22.5, -20.}, {
      28.284271247461902`, -20., -20.}, {26.575364531836623`, -20., -17.5}, {
      28.50438562747845, -22.5, -17.5}, {30.103986446980738`, -22.5, -20.}}], 
     Polygon3DBox[{{28.50438562747845, -22.5, -17.5}, {
      26.575364531836623`, -20., -17.5}, {25., -20., -15.}, {
      27.04163456597992, -22.5, -15.}, {28.50438562747845, -22.5, -17.5}}], 
     Polygon3DBox[{{27.04163456597992, -22.5, -15.}, {25., -20., -15.}, {
      23.58495283014151, -20., -12.5}, {25.739075352467502`, -22.5, -12.5}, {
      27.04163456597992, -22.5, -15.}}], 
     Polygon3DBox[{{25.739075352467502`, -22.5, -12.5}, {
      23.58495283014151, -20., -12.5}, {22.360679774997898`, -20., -10.}, {
      24.62214450449026, -22.5, -10.}, {25.739075352467502`, -22.5, -12.5}}], 
     Polygon3DBox[{{24.62214450449026, -22.5, -10.}, {
      22.360679774997898`, -20., -10.}, {21.360009363293827`, -20., -7.5}, {
      23.717082451262844`, -22.5, -7.5}, {24.62214450449026, -22.5, -10.}}], 
     Polygon3DBox[{{23.717082451262844`, -22.5, -7.5}, {
      21.360009363293827`, -20., -7.5}, {20.615528128088304`, -20., -5.}, {
      23.04886114323222, -22.5, -5.}, {23.717082451262844`, -22.5, -7.5}}], 
     Polygon3DBox[{{23.04886114323222, -22.5, -5.}, {
      20.615528128088304`, -20., -5.}, {20.155644370746373`, -20., -2.5}, {
      22.638462845343543`, -22.5, -2.5}, {23.04886114323222, -22.5, -5.}}], 
     Polygon3DBox[{{22.638462845343543`, -22.5, -2.5}, {
      20.155644370746373`, -20., -2.5}, {20., -20., 0.}, {22.5, -22.5, 0.}, {
      22.638462845343543`, -22.5, -2.5}}], 
     Polygon3DBox[{{22.5, -22.5, 0.}, {20., -20., 0.}, {
      20.155644370746373`, -20., 2.5}, {22.638462845343543`, -22.5, 2.5}, {
      22.5, -22.5, 0.}}], 
     Polygon3DBox[{{22.638462845343543`, -22.5, 2.5}, {
      20.155644370746373`, -20., 2.5}, {20.615528128088304`, -20., 5.}, {
      23.04886114323222, -22.5, 5.}, {22.638462845343543`, -22.5, 2.5}}], 
     Polygon3DBox[{{23.04886114323222, -22.5, 5.}, {20.615528128088304`, -20.,
       5.}, {21.360009363293827`, -20., 7.5}, {23.717082451262844`, -22.5, 
      7.5}, {23.04886114323222, -22.5, 5.}}], 
     Polygon3DBox[{{23.717082451262844`, -22.5, 7.5}, {
      21.360009363293827`, -20., 7.5}, {22.360679774997898`, -20., 10.}, {
      24.62214450449026, -22.5, 10.}, {23.717082451262844`, -22.5, 7.5}}], 
     Polygon3DBox[{{24.62214450449026, -22.5, 10.}, {
      22.360679774997898`, -20., 10.}, {23.58495283014151, -20., 12.5}, {
      25.739075352467502`, -22.5, 12.5}, {24.62214450449026, -22.5, 10.}}], 
     Polygon3DBox[{{25.739075352467502`, -22.5, 12.5}, {
      23.58495283014151, -20., 12.5}, {25., -20., 15.}, {
      27.04163456597992, -22.5, 15.}, {25.739075352467502`, -22.5, 12.5}}], 
     Polygon3DBox[{{27.04163456597992, -22.5, 15.}, {25., -20., 15.}, {
      26.575364531836623`, -20., 17.5}, {28.50438562747845, -22.5, 17.5}, {
      27.04163456597992, -22.5, 15.}}], 
     Polygon3DBox[{{28.50438562747845, -22.5, 17.5}, {
      26.575364531836623`, -20., 17.5}, {28.284271247461902`, -20., 20.}, {
      30.103986446980738`, -22.5, 20.}, {28.50438562747845, -22.5, 17.5}}], 
     Polygon3DBox[{{30.103986446980738`, -22.5, 20.}, {
      28.284271247461902`, -20., 20.}, {30.103986446980738`, -20., 22.5}, {
      31.81980515339464, -22.5, 22.5}, {30.103986446980738`, -22.5, 20.}}], 
     Polygon3DBox[{{31.81980515339464, -22.5, 22.5}, {
      30.103986446980738`, -20., 22.5}, {32.01562118716424, -20., 25.}, {
      33.63406011768428, -22.5, 25.}, {31.81980515339464, -22.5, 22.5}}], 
     Polygon3DBox[{{32.01562118716424, -20., -25.}, {
      30.516389039334257`, -17.5, -25.}, {28.50438562747845, -17.5, -22.5}, {
      30.103986446980738`, -20., -22.5}, {32.01562118716424, -20., -25.}}], 
     Polygon3DBox[{{30.103986446980738`, -20., -22.5}, {
      28.50438562747845, -17.5, -22.5}, {26.575364531836623`, -17.5, -20.}, {
      28.284271247461902`, -20., -20.}, {30.103986446980738`, -20., -22.5}}], 
     Polygon3DBox[{{28.284271247461902`, -20., -20.}, {
      26.575364531836623`, -17.5, -20.}, {
      24.748737341529164`, -17.5, -17.5}, {
      26.575364531836623`, -20., -17.5}, {28.284271247461902`, -20., -20.}}], 
     Polygon3DBox[{{26.575364531836623`, -20., -17.5}, {
      24.748737341529164`, -17.5, -17.5}, {23.04886114323222, -17.5, -15.}, {
      25., -20., -15.}, {26.575364531836623`, -20., -17.5}}], 
     Polygon3DBox[{{25., -20., -15.}, {23.04886114323222, -17.5, -15.}, {
      21.50581316760657, -17.5, -12.5}, {23.58495283014151, -20., -12.5}, {
      25., -20., -15.}}], 
     Polygon3DBox[{{23.58495283014151, -20., -12.5}, {
      21.50581316760657, -17.5, -12.5}, {20.155644370746373`, -17.5, -10.}, {
      22.360679774997898`, -20., -10.}, {23.58495283014151, -20., -12.5}}], 
     Polygon3DBox[{{22.360679774997898`, -20., -10.}, {
      20.155644370746373`, -17.5, -10.}, {19.03943276465977, -17.5, -7.5}, {
      21.360009363293827`, -20., -7.5}, {22.360679774997898`, -20., -10.}}], 
     Polygon3DBox[{{21.360009363293827`, -20., -7.5}, {
      19.03943276465977, -17.5, -7.5}, {18.200274723201296`, -17.5, -5.}, {
      20.615528128088304`, -20., -5.}, {21.360009363293827`, -20., -7.5}}], 
     Polygon3DBox[{{20.615528128088304`, -20., -5.}, {
      18.200274723201296`, -17.5, -5.}, {17.67766952966369, -17.5, -2.5}, {
      20.155644370746373`, -20., -2.5}, {20.615528128088304`, -20., -5.}}], 
     Polygon3DBox[{{20.155644370746373`, -20., -2.5}, {
      17.67766952966369, -17.5, -2.5}, {17.5, -17.5, 0.}, {20., -20., 0.}, {
      20.155644370746373`, -20., -2.5}}], 
     Polygon3DBox[{{20., -20., 0.}, {17.5, -17.5, 0.}, {
      17.67766952966369, -17.5, 2.5}, {20.155644370746373`, -20., 2.5}, {
      20., -20., 0.}}], 
     Polygon3DBox[{{20.155644370746373`, -20., 2.5}, {
      17.67766952966369, -17.5, 2.5}, {18.200274723201296`, -17.5, 5.}, {
      20.615528128088304`, -20., 5.}, {20.155644370746373`, -20., 2.5}}], 
     Polygon3DBox[{{20.615528128088304`, -20., 5.}, {
      18.200274723201296`, -17.5, 5.}, {19.03943276465977, -17.5, 7.5}, {
      21.360009363293827`, -20., 7.5}, {20.615528128088304`, -20., 5.}}], 
     Polygon3DBox[{{21.360009363293827`, -20., 7.5}, {
      19.03943276465977, -17.5, 7.5}, {20.155644370746373`, -17.5, 10.}, {
      22.360679774997898`, -20., 10.}, {21.360009363293827`, -20., 7.5}}], 
     Polygon3DBox[{{22.360679774997898`, -20., 10.}, {
      20.155644370746373`, -17.5, 10.}, {21.50581316760657, -17.5, 12.5}, {
      23.58495283014151, -20., 12.5}, {22.360679774997898`, -20., 10.}}], 
     Polygon3DBox[{{23.58495283014151, -20., 12.5}, {21.50581316760657, -17.5,
       12.5}, {23.04886114323222, -17.5, 15.}, {25., -20., 15.}, {
      23.58495283014151, -20., 12.5}}], 
     Polygon3DBox[{{25., -20., 15.}, {23.04886114323222, -17.5, 15.}, {
      24.748737341529164`, -17.5, 17.5}, {26.575364531836623`, -20., 17.5}, {
      25., -20., 15.}}], 
     Polygon3DBox[{{26.575364531836623`, -20., 17.5}, {
      24.748737341529164`, -17.5, 17.5}, {26.575364531836623`, -17.5, 20.}, {
      28.284271247461902`, -20., 20.}, {26.575364531836623`, -20., 17.5}}], 
     Polygon3DBox[{{28.284271247461902`, -20., 20.}, {
      26.575364531836623`, -17.5, 20.}, {28.50438562747845, -17.5, 22.5}, {
      30.103986446980738`, -20., 22.5}, {28.284271247461902`, -20., 20.}}], 
     Polygon3DBox[{{30.103986446980738`, -20., 22.5}, {
      28.50438562747845, -17.5, 22.5}, {30.516389039334257`, -17.5, 25.}, {
      32.01562118716424, -20., 25.}, {30.103986446980738`, -20., 22.5}}], 
     Polygon3DBox[{{30.516389039334257`, -17.5, -25.}, {
      29.154759474226502`, -15., -25.}, {27.04163456597992, -15., -22.5}, {
      28.50438562747845, -17.5, -22.5}, {30.516389039334257`, -17.5, -25.}}], 
     Polygon3DBox[{{28.50438562747845, -17.5, -22.5}, {
      27.04163456597992, -15., -22.5}, {25., -15., -20.}, {
      26.575364531836623`, -17.5, -20.}, {28.50438562747845, -17.5, -22.5}}], 
     Polygon3DBox[{{26.575364531836623`, -17.5, -20.}, {25., -15., -20.}, {
      23.04886114323222, -15., -17.5}, {24.748737341529164`, -17.5, -17.5}, {
      26.575364531836623`, -17.5, -20.}}], 
     Polygon3DBox[{{24.748737341529164`, -17.5, -17.5}, {
      23.04886114323222, -15., -17.5}, {21.213203435596427`, -15., -15.}, {
      23.04886114323222, -17.5, -15.}, {24.748737341529164`, -17.5, -17.5}}], 
     Polygon3DBox[{{23.04886114323222, -17.5, -15.}, {
      21.213203435596427`, -15., -15.}, {19.525624189766635`, -15., -12.5}, {
      21.50581316760657, -17.5, -12.5}, {23.04886114323222, -17.5, -15.}}], 
     Polygon3DBox[{{21.50581316760657, -17.5, -12.5}, {
      19.525624189766635`, -15., -12.5}, {18.027756377319946`, -15., -10.}, {
      20.155644370746373`, -17.5, -10.}, {21.50581316760657, -17.5, -12.5}}], 
     Polygon3DBox[{{20.155644370746373`, -17.5, -10.}, {
      18.027756377319946`, -15., -10.}, {16.77050983124842, -15., -7.5}, {
      19.03943276465977, -17.5, -7.5}, {20.155644370746373`, -17.5, -10.}}], 
     Polygon3DBox[{{19.03943276465977, -17.5, -7.5}, {
      16.77050983124842, -15., -7.5}, {15.811388300841896`, -15., -5.}, {
      18.200274723201296`, -17.5, -5.}, {19.03943276465977, -17.5, -7.5}}], 
     Polygon3DBox[{{18.200274723201296`, -17.5, -5.}, {
      15.811388300841896`, -15., -5.}, {15.20690632574555, -15., -2.5}, {
      17.67766952966369, -17.5, -2.5}, {18.200274723201296`, -17.5, -5.}}], 
     Polygon3DBox[{{17.67766952966369, -17.5, -2.5}, {
      15.20690632574555, -15., -2.5}, {15., -15., 0.}, {17.5, -17.5, 0.}, {
      17.67766952966369, -17.5, -2.5}}], 
     Polygon3DBox[{{17.5, -17.5, 0.}, {15., -15., 0.}, {
      15.20690632574555, -15., 2.5}, {17.67766952966369, -17.5, 2.5}, {
      17.5, -17.5, 0.}}], 
     Polygon3DBox[{{17.67766952966369, -17.5, 2.5}, {15.20690632574555, -15., 
      2.5}, {15.811388300841896`, -15., 5.}, {18.200274723201296`, -17.5, 
      5.}, {17.67766952966369, -17.5, 2.5}}], 
     Polygon3DBox[{{18.200274723201296`, -17.5, 5.}, {
      15.811388300841896`, -15., 5.}, {16.77050983124842, -15., 7.5}, {
      19.03943276465977, -17.5, 7.5}, {18.200274723201296`, -17.5, 5.}}], 
     Polygon3DBox[{{19.03943276465977, -17.5, 7.5}, {16.77050983124842, -15., 
      7.5}, {18.027756377319946`, -15., 10.}, {20.155644370746373`, -17.5, 
      10.}, {19.03943276465977, -17.5, 7.5}}], 
     Polygon3DBox[{{20.155644370746373`, -17.5, 10.}, {
      18.027756377319946`, -15., 10.}, {19.525624189766635`, -15., 12.5}, {
      21.50581316760657, -17.5, 12.5}, {20.155644370746373`, -17.5, 10.}}], 
     Polygon3DBox[{{21.50581316760657, -17.5, 12.5}, {
      19.525624189766635`, -15., 12.5}, {21.213203435596427`, -15., 15.}, {
      23.04886114323222, -17.5, 15.}, {21.50581316760657, -17.5, 12.5}}], 
     Polygon3DBox[{{23.04886114323222, -17.5, 15.}, {
      21.213203435596427`, -15., 15.}, {23.04886114323222, -15., 17.5}, {
      24.748737341529164`, -17.5, 17.5}, {23.04886114323222, -17.5, 15.}}], 
     Polygon3DBox[{{24.748737341529164`, -17.5, 17.5}, {
      23.04886114323222, -15., 17.5}, {25., -15., 20.}, {
      26.575364531836623`, -17.5, 20.}, {24.748737341529164`, -17.5, 17.5}}], 
     Polygon3DBox[{{26.575364531836623`, -17.5, 20.}, {25., -15., 20.}, {
      27.04163456597992, -15., 22.5}, {28.50438562747845, -17.5, 22.5}, {
      26.575364531836623`, -17.5, 20.}}], 
     Polygon3DBox[{{28.50438562747845, -17.5, 22.5}, {27.04163456597992, -15.,
       22.5}, {29.154759474226502`, -15., 25.}, {30.516389039334257`, -17.5, 
      25.}, {28.50438562747845, -17.5, 22.5}}], 
     Polygon3DBox[{{29.154759474226502`, -15., -25.}, {
      27.95084971874737, -12.5, -25.}, {25.739075352467502`, -12.5, -22.5}, {
      27.04163456597992, -15., -22.5}, {29.154759474226502`, -15., -25.}}], 
     Polygon3DBox[{{27.04163456597992, -15., -22.5}, {
      25.739075352467502`, -12.5, -22.5}, {23.58495283014151, -12.5, -20.}, {
      25., -15., -20.}, {27.04163456597992, -15., -22.5}}], 
     Polygon3DBox[{{25., -15., -20.}, {23.58495283014151, -12.5, -20.}, {
      21.50581316760657, -12.5, -17.5}, {23.04886114323222, -15., -17.5}, {
      25., -15., -20.}}], 
     Polygon3DBox[{{23.04886114323222, -15., -17.5}, {
      21.50581316760657, -12.5, -17.5}, {19.525624189766635`, -12.5, -15.}, {
      21.213203435596427`, -15., -15.}, {23.04886114323222, -15., -17.5}}], 
     Polygon3DBox[{{21.213203435596427`, -15., -15.}, {
      19.525624189766635`, -12.5, -15.}, {17.67766952966369, -12.5, -12.5}, {
      19.525624189766635`, -15., -12.5}, {21.213203435596427`, -15., -15.}}], 
     Polygon3DBox[{{19.525624189766635`, -15., -12.5}, {
      17.67766952966369, -12.5, -12.5}, {16.00781059358212, -12.5, -10.}, {
      18.027756377319946`, -15., -10.}, {19.525624189766635`, -15., -12.5}}], 
     Polygon3DBox[{{18.027756377319946`, -15., -10.}, {
      16.00781059358212, -12.5, -10.}, {14.577379737113251`, -12.5, -7.5}, {
      16.77050983124842, -15., -7.5}, {18.027756377319946`, -15., -10.}}], 
     Polygon3DBox[{{16.77050983124842, -15., -7.5}, {
      14.577379737113251`, -12.5, -7.5}, {13.46291201783626, -12.5, -5.}, {
      15.811388300841896`, -15., -5.}, {16.77050983124842, -15., -7.5}}], 
     Polygon3DBox[{{15.811388300841896`, -15., -5.}, {
      13.46291201783626, -12.5, -5.}, {12.747548783981962`, -12.5, -2.5}, {
      15.20690632574555, -15., -2.5}, {15.811388300841896`, -15., -5.}}], 
     Polygon3DBox[{{15.20690632574555, -15., -2.5}, {
      12.747548783981962`, -12.5, -2.5}, {12.5, -12.5, 0.}, {15., -15., 0.}, {
      15.20690632574555, -15., -2.5}}], 
     Polygon3DBox[{{15., -15., 0.}, {12.5, -12.5, 0.}, {
      12.747548783981962`, -12.5, 2.5}, {15.20690632574555, -15., 2.5}, {
      15., -15., 0.}}], 
     Polygon3DBox[{{15.20690632574555, -15., 2.5}, {
      12.747548783981962`, -12.5, 2.5}, {13.46291201783626, -12.5, 5.}, {
      15.811388300841896`, -15., 5.}, {15.20690632574555, -15., 2.5}}], 
     Polygon3DBox[{{15.811388300841896`, -15., 5.}, {13.46291201783626, -12.5,
       5.}, {14.577379737113251`, -12.5, 7.5}, {16.77050983124842, -15., 
      7.5}, {15.811388300841896`, -15., 5.}}], 
     Polygon3DBox[{{16.77050983124842, -15., 7.5}, {
      14.577379737113251`, -12.5, 7.5}, {16.00781059358212, -12.5, 10.}, {
      18.027756377319946`, -15., 10.}, {16.77050983124842, -15., 7.5}}], 
     Polygon3DBox[{{18.027756377319946`, -15., 10.}, {
      16.00781059358212, -12.5, 10.}, {17.67766952966369, -12.5, 12.5}, {
      19.525624189766635`, -15., 12.5}, {18.027756377319946`, -15., 10.}}], 
     Polygon3DBox[{{19.525624189766635`, -15., 12.5}, {
      17.67766952966369, -12.5, 12.5}, {19.525624189766635`, -12.5, 15.}, {
      21.213203435596427`, -15., 15.}, {19.525624189766635`, -15., 12.5}}], 
     Polygon3DBox[{{21.213203435596427`, -15., 15.}, {
      19.525624189766635`, -12.5, 15.}, {21.50581316760657, -12.5, 17.5}, {
      23.04886114323222, -15., 17.5}, {21.213203435596427`, -15., 15.}}], 
     Polygon3DBox[{{23.04886114323222, -15., 17.5}, {21.50581316760657, -12.5,
       17.5}, {23.58495283014151, -12.5, 20.}, {25., -15., 20.}, {
      23.04886114323222, -15., 17.5}}], 
     Polygon3DBox[{{25., -15., 20.}, {23.58495283014151, -12.5, 20.}, {
      25.739075352467502`, -12.5, 22.5}, {27.04163456597992, -15., 22.5}, {
      25., -15., 20.}}], 
     Polygon3DBox[{{27.04163456597992, -15., 22.5}, {
      25.739075352467502`, -12.5, 22.5}, {27.95084971874737, -12.5, 25.}, {
      29.154759474226502`, -15., 25.}, {27.04163456597992, -15., 22.5}}], 
     Polygon3DBox[{{27.95084971874737, -12.5, -25.}, {
      26.92582403567252, -10., -25.}, {24.62214450449026, -10., -22.5}, {
      25.739075352467502`, -12.5, -22.5}, {27.95084971874737, -12.5, -25.}}], 
     Polygon3DBox[{{25.739075352467502`, -12.5, -22.5}, {
      24.62214450449026, -10., -22.5}, {22.360679774997898`, -10., -20.}, {
      23.58495283014151, -12.5, -20.}, {25.739075352467502`, -12.5, -22.5}}], 
     Polygon3DBox[{{23.58495283014151, -12.5, -20.}, {
      22.360679774997898`, -10., -20.}, {20.155644370746373`, -10., -17.5}, {
      21.50581316760657, -12.5, -17.5}, {23.58495283014151, -12.5, -20.}}], 
     Polygon3DBox[{{21.50581316760657, -12.5, -17.5}, {
      20.155644370746373`, -10., -17.5}, {18.027756377319946`, -10., -15.}, {
      19.525624189766635`, -12.5, -15.}, {21.50581316760657, -12.5, -17.5}}], 
     Polygon3DBox[{{19.525624189766635`, -12.5, -15.}, {
      18.027756377319946`, -10., -15.}, {16.00781059358212, -10., -12.5}, {
      17.67766952966369, -12.5, -12.5}, {19.525624189766635`, -12.5, -15.}}], 
     Polygon3DBox[{{17.67766952966369, -12.5, -12.5}, {
      16.00781059358212, -10., -12.5}, {14.142135623730951`, -10., -10.}, {
      16.00781059358212, -12.5, -10.}, {17.67766952966369, -12.5, -12.5}}], 
     Polygon3DBox[{{16.00781059358212, -12.5, -10.}, {
      14.142135623730951`, -10., -10.}, {12.5, -10., -7.5}, {
      14.577379737113251`, -12.5, -7.5}, {16.00781059358212, -12.5, -10.}}], 
     Polygon3DBox[{{14.577379737113251`, -12.5, -7.5}, {12.5, -10., -7.5}, {
      11.180339887498949`, -10., -5.}, {13.46291201783626, -12.5, -5.}, {
      14.577379737113251`, -12.5, -7.5}}], 
     Polygon3DBox[{{13.46291201783626, -12.5, -5.}, {
      11.180339887498949`, -10., -5.}, {10.307764064044152`, -10., -2.5}, {
      12.747548783981962`, -12.5, -2.5}, {13.46291201783626, -12.5, -5.}}], 
     Polygon3DBox[{{12.747548783981962`, -12.5, -2.5}, {
      10.307764064044152`, -10., -2.5}, {10., -10., 0.}, {12.5, -12.5, 0.}, {
      12.747548783981962`, -12.5, -2.5}}], 
     Polygon3DBox[{{12.5, -12.5, 0.}, {10., -10., 0.}, {
      10.307764064044152`, -10., 2.5}, {12.747548783981962`, -12.5, 2.5}, {
      12.5, -12.5, 0.}}], 
     Polygon3DBox[{{12.747548783981962`, -12.5, 2.5}, {
      10.307764064044152`, -10., 2.5}, {11.180339887498949`, -10., 5.}, {
      13.46291201783626, -12.5, 5.}, {12.747548783981962`, -12.5, 2.5}}], 
     Polygon3DBox[{{13.46291201783626, -12.5, 5.}, {11.180339887498949`, -10.,
       5.}, {12.5, -10., 7.5}, {14.577379737113251`, -12.5, 7.5}, {
      13.46291201783626, -12.5, 5.}}], 
     Polygon3DBox[{{14.577379737113251`, -12.5, 7.5}, {12.5, -10., 7.5}, {
      14.142135623730951`, -10., 10.}, {16.00781059358212, -12.5, 10.}, {
      14.577379737113251`, -12.5, 7.5}}], 
     Polygon3DBox[{{16.00781059358212, -12.5, 10.}, {
      14.142135623730951`, -10., 10.}, {16.00781059358212, -10., 12.5}, {
      17.67766952966369, -12.5, 12.5}, {16.00781059358212, -12.5, 10.}}], 
     Polygon3DBox[{{17.67766952966369, -12.5, 12.5}, {16.00781059358212, -10.,
       12.5}, {18.027756377319946`, -10., 15.}, {19.525624189766635`, -12.5, 
      15.}, {17.67766952966369, -12.5, 12.5}}], 
     Polygon3DBox[{{19.525624189766635`, -12.5, 15.}, {
      18.027756377319946`, -10., 15.}, {20.155644370746373`, -10., 17.5}, {
      21.50581316760657, -12.5, 17.5}, {19.525624189766635`, -12.5, 15.}}], 
     Polygon3DBox[{{21.50581316760657, -12.5, 17.5}, {
      20.155644370746373`, -10., 17.5}, {22.360679774997898`, -10., 20.}, {
      23.58495283014151, -12.5, 20.}, {21.50581316760657, -12.5, 17.5}}], 
     Polygon3DBox[{{23.58495283014151, -12.5, 20.}, {
      22.360679774997898`, -10., 20.}, {24.62214450449026, -10., 22.5}, {
      25.739075352467502`, -12.5, 22.5}, {23.58495283014151, -12.5, 20.}}], 
     Polygon3DBox[{{25.739075352467502`, -12.5, 22.5}, {
      24.62214450449026, -10., 22.5}, {26.92582403567252, -10., 25.}, {
      27.95084971874737, -12.5, 25.}, {25.739075352467502`, -12.5, 22.5}}], 
     Polygon3DBox[{{26.92582403567252, -10., -25.}, {
      26.100766272276374`, -7.5, -25.}, {23.717082451262844`, -7.5, -22.5}, {
      24.62214450449026, -10., -22.5}, {26.92582403567252, -10., -25.}}], 
     Polygon3DBox[{{24.62214450449026, -10., -22.5}, {
      23.717082451262844`, -7.5, -22.5}, {21.360009363293827`, -7.5, -20.}, {
      22.360679774997898`, -10., -20.}, {24.62214450449026, -10., -22.5}}], 
     Polygon3DBox[{{22.360679774997898`, -10., -20.}, {
      21.360009363293827`, -7.5, -20.}, {19.03943276465977, -7.5, -17.5}, {
      20.155644370746373`, -10., -17.5}, {22.360679774997898`, -10., -20.}}], 
     Polygon3DBox[{{20.155644370746373`, -10., -17.5}, {
      19.03943276465977, -7.5, -17.5}, {16.77050983124842, -7.5, -15.}, {
      18.027756377319946`, -10., -15.}, {20.155644370746373`, -10., -17.5}}], 
     Polygon3DBox[{{18.027756377319946`, -10., -15.}, {
      16.77050983124842, -7.5, -15.}, {14.577379737113251`, -7.5, -12.5}, {
      16.00781059358212, -10., -12.5}, {18.027756377319946`, -10., -15.}}], 
     Polygon3DBox[{{16.00781059358212, -10., -12.5}, {
      14.577379737113251`, -7.5, -12.5}, {12.5, -7.5, -10.}, {
      14.142135623730951`, -10., -10.}, {16.00781059358212, -10., -12.5}}], 
     Polygon3DBox[{{14.142135623730951`, -10., -10.}, {12.5, -7.5, -10.}, {
      10.606601717798213`, -7.5, -7.5}, {12.5, -10., -7.5}, {
      14.142135623730951`, -10., -10.}}], 
     Polygon3DBox[{{12.5, -10., -7.5}, {10.606601717798213`, -7.5, -7.5}, {
      9.013878188659973, -7.5, -5.}, {11.180339887498949`, -10., -5.}, {
      12.5, -10., -7.5}}], 
     Polygon3DBox[{{11.180339887498949`, -10., -5.}, {
      9.013878188659973, -7.5, -5.}, {7.905694150420948, -7.5, -2.5}, {
      10.307764064044152`, -10., -2.5}, {11.180339887498949`, -10., -5.}}], 
     Polygon3DBox[{{10.307764064044152`, -10., -2.5}, {
      7.905694150420948, -7.5, -2.5}, {7.5, -7.5, 0.}, {10., -10., 0.}, {
      10.307764064044152`, -10., -2.5}}], 
     Polygon3DBox[{{10., -10., 0.}, {7.5, -7.5, 0.}, {7.905694150420948, -7.5,
       2.5}, {10.307764064044152`, -10., 2.5}, {10., -10., 0.}}], 
     Polygon3DBox[{{10.307764064044152`, -10., 2.5}, {7.905694150420948, -7.5,
       2.5}, {9.013878188659973, -7.5, 5.}, {11.180339887498949`, -10., 5.}, {
      10.307764064044152`, -10., 2.5}}], 
     Polygon3DBox[{{11.180339887498949`, -10., 5.}, {9.013878188659973, -7.5, 
      5.}, {10.606601717798213`, -7.5, 7.5}, {12.5, -10., 7.5}, {
      11.180339887498949`, -10., 5.}}], 
     Polygon3DBox[{{12.5, -10., 7.5}, {10.606601717798213`, -7.5, 7.5}, {
      12.5, -7.5, 10.}, {14.142135623730951`, -10., 10.}, {12.5, -10., 7.5}}],
      Polygon3DBox[{{14.142135623730951`, -10., 10.}, {12.5, -7.5, 10.}, {
      14.577379737113251`, -7.5, 12.5}, {16.00781059358212, -10., 12.5}, {
      14.142135623730951`, -10., 10.}}], 
     Polygon3DBox[{{16.00781059358212, -10., 12.5}, {
      14.577379737113251`, -7.5, 12.5}, {16.77050983124842, -7.5, 15.}, {
      18.027756377319946`, -10., 15.}, {16.00781059358212, -10., 12.5}}], 
     Polygon3DBox[{{18.027756377319946`, -10., 15.}, {16.77050983124842, -7.5,
       15.}, {19.03943276465977, -7.5, 17.5}, {20.155644370746373`, -10., 
      17.5}, {18.027756377319946`, -10., 15.}}], 
     Polygon3DBox[{{20.155644370746373`, -10., 17.5}, {
      19.03943276465977, -7.5, 17.5}, {21.360009363293827`, -7.5, 20.}, {
      22.360679774997898`, -10., 20.}, {20.155644370746373`, -10., 17.5}}], 
     Polygon3DBox[{{22.360679774997898`, -10., 20.}, {
      21.360009363293827`, -7.5, 20.}, {23.717082451262844`, -7.5, 22.5}, {
      24.62214450449026, -10., 22.5}, {22.360679774997898`, -10., 20.}}], 
     Polygon3DBox[{{24.62214450449026, -10., 22.5}, {
      23.717082451262844`, -7.5, 22.5}, {26.100766272276374`, -7.5, 25.}, {
      26.92582403567252, -10., 25.}, {24.62214450449026, -10., 22.5}}], 
     Polygon3DBox[{{26.100766272276374`, -7.5, -25.}, {
      25.495097567963924`, -5., -25.}, {23.04886114323222, -5., -22.5}, {
      23.717082451262844`, -7.5, -22.5}, {26.100766272276374`, -7.5, -25.}}], 
     Polygon3DBox[{{23.717082451262844`, -7.5, -22.5}, {
      23.04886114323222, -5., -22.5}, {20.615528128088304`, -5., -20.}, {
      21.360009363293827`, -7.5, -20.}, {23.717082451262844`, -7.5, -22.5}}], 
     Polygon3DBox[{{21.360009363293827`, -7.5, -20.}, {
      20.615528128088304`, -5., -20.}, {18.200274723201296`, -5., -17.5}, {
      19.03943276465977, -7.5, -17.5}, {21.360009363293827`, -7.5, -20.}}], 
     Polygon3DBox[{{19.03943276465977, -7.5, -17.5}, {
      18.200274723201296`, -5., -17.5}, {15.811388300841896`, -5., -15.}, {
      16.77050983124842, -7.5, -15.}, {19.03943276465977, -7.5, -17.5}}], 
     Polygon3DBox[{{16.77050983124842, -7.5, -15.}, {
      15.811388300841896`, -5., -15.}, {13.46291201783626, -5., -12.5}, {
      14.577379737113251`, -7.5, -12.5}, {16.77050983124842, -7.5, -15.}}], 
     Polygon3DBox[{{14.577379737113251`, -7.5, -12.5}, {
      13.46291201783626, -5., -12.5}, {11.180339887498949`, -5., -10.}, {
      12.5, -7.5, -10.}, {14.577379737113251`, -7.5, -12.5}}], 
     Polygon3DBox[{{12.5, -7.5, -10.}, {11.180339887498949`, -5., -10.}, {
      9.013878188659973, -5., -7.5}, {10.606601717798213`, -7.5, -7.5}, {
      12.5, -7.5, -10.}}], 
     Polygon3DBox[{{10.606601717798213`, -7.5, -7.5}, {
      9.013878188659973, -5., -7.5}, {7.0710678118654755`, -5., -5.}, {
      9.013878188659973, -7.5, -5.}, {10.606601717798213`, -7.5, -7.5}}], 
     Polygon3DBox[{{9.013878188659973, -7.5, -5.}, {
      7.0710678118654755`, -5., -5.}, {5.5901699437494745`, -5., -2.5}, {
      7.905694150420948, -7.5, -2.5}, {9.013878188659973, -7.5, -5.}}], 
     Polygon3DBox[{{7.905694150420948, -7.5, -2.5}, {
      5.5901699437494745`, -5., -2.5}, {5., -5., 0.}, {7.5, -7.5, 0.}, {
      7.905694150420948, -7.5, -2.5}}], 
     Polygon3DBox[{{7.5, -7.5, 0.}, {5., -5., 0.}, {5.5901699437494745`, -5., 
      2.5}, {7.905694150420948, -7.5, 2.5}, {7.5, -7.5, 0.}}], 
     Polygon3DBox[{{7.905694150420948, -7.5, 2.5}, {5.5901699437494745`, -5., 
      2.5}, {7.0710678118654755`, -5., 5.}, {9.013878188659973, -7.5, 5.}, {
      7.905694150420948, -7.5, 2.5}}], 
     Polygon3DBox[{{9.013878188659973, -7.5, 5.}, {7.0710678118654755`, -5., 
      5.}, {9.013878188659973, -5., 7.5}, {10.606601717798213`, -7.5, 7.5}, {
      9.013878188659973, -7.5, 5.}}], 
     Polygon3DBox[{{10.606601717798213`, -7.5, 7.5}, {9.013878188659973, -5., 
      7.5}, {11.180339887498949`, -5., 10.}, {12.5, -7.5, 10.}, {
      10.606601717798213`, -7.5, 7.5}}], 
     Polygon3DBox[{{12.5, -7.5, 10.}, {11.180339887498949`, -5., 10.}, {
      13.46291201783626, -5., 12.5}, {14.577379737113251`, -7.5, 12.5}, {
      12.5, -7.5, 10.}}], 
     Polygon3DBox[{{14.577379737113251`, -7.5, 12.5}, {13.46291201783626, -5.,
       12.5}, {15.811388300841896`, -5., 15.}, {16.77050983124842, -7.5, 
      15.}, {14.577379737113251`, -7.5, 12.5}}], 
     Polygon3DBox[{{16.77050983124842, -7.5, 15.}, {15.811388300841896`, -5., 
      15.}, {18.200274723201296`, -5., 17.5}, {19.03943276465977, -7.5, 
      17.5}, {16.77050983124842, -7.5, 15.}}], 
     Polygon3DBox[{{19.03943276465977, -7.5, 17.5}, {18.200274723201296`, -5.,
       17.5}, {20.615528128088304`, -5., 20.}, {21.360009363293827`, -7.5, 
      20.}, {19.03943276465977, -7.5, 17.5}}], 
     Polygon3DBox[{{21.360009363293827`, -7.5, 20.}, {
      20.615528128088304`, -5., 20.}, {23.04886114323222, -5., 22.5}, {
      23.717082451262844`, -7.5, 22.5}, {21.360009363293827`, -7.5, 20.}}], 
     Polygon3DBox[{{23.717082451262844`, -7.5, 22.5}, {23.04886114323222, -5.,
       22.5}, {25.495097567963924`, -5., 25.}, {26.100766272276374`, -7.5, 
      25.}, {23.717082451262844`, -7.5, 22.5}}], 
     Polygon3DBox[{{25.495097567963924`, -5., -25.}, {
      25.124689052802225`, -2.5, -25.}, {22.638462845343543`, -2.5, -22.5}, {
      23.04886114323222, -5., -22.5}, {25.495097567963924`, -5., -25.}}], 
     Polygon3DBox[{{23.04886114323222, -5., -22.5}, {
      22.638462845343543`, -2.5, -22.5}, {20.155644370746373`, -2.5, -20.}, {
      20.615528128088304`, -5., -20.}, {23.04886114323222, -5., -22.5}}], 
     Polygon3DBox[{{20.615528128088304`, -5., -20.}, {
      20.155644370746373`, -2.5, -20.}, {17.67766952966369, -2.5, -17.5}, {
      18.200274723201296`, -5., -17.5}, {20.615528128088304`, -5., -20.}}], 
     Polygon3DBox[{{18.200274723201296`, -5., -17.5}, {
      17.67766952966369, -2.5, -17.5}, {15.20690632574555, -2.5, -15.}, {
      15.811388300841896`, -5., -15.}, {18.200274723201296`, -5., -17.5}}], 
     Polygon3DBox[{{15.811388300841896`, -5., -15.}, {
      15.20690632574555, -2.5, -15.}, {12.747548783981962`, -2.5, -12.5}, {
      13.46291201783626, -5., -12.5}, {15.811388300841896`, -5., -15.}}], 
     Polygon3DBox[{{13.46291201783626, -5., -12.5}, {
      12.747548783981962`, -2.5, -12.5}, {10.307764064044152`, -2.5, -10.}, {
      11.180339887498949`, -5., -10.}, {13.46291201783626, -5., -12.5}}], 
     Polygon3DBox[{{11.180339887498949`, -5., -10.}, {
      10.307764064044152`, -2.5, -10.}, {7.905694150420948, -2.5, -7.5}, {
      9.013878188659973, -5., -7.5}, {11.180339887498949`, -5., -10.}}], 
     Polygon3DBox[{{9.013878188659973, -5., -7.5}, {
      7.905694150420948, -2.5, -7.5}, {5.5901699437494745`, -2.5, -5.}, {
      7.0710678118654755`, -5., -5.}, {9.013878188659973, -5., -7.5}}], 
     Polygon3DBox[{{7.0710678118654755`, -5., -5.}, {
      5.5901699437494745`, -2.5, -5.}, {3.5355339059327378`, -2.5, -2.5}, {
      5.5901699437494745`, -5., -2.5}, {7.0710678118654755`, -5., -5.}}], 
     Polygon3DBox[{{5.5901699437494745`, -5., -2.5}, {
      3.5355339059327378`, -2.5, -2.5}, {2.5, -2.5, 0.}, {5., -5., 0.}, {
      5.5901699437494745`, -5., -2.5}}], 
     Polygon3DBox[{{5., -5., 0.}, {2.5, -2.5, 0.}, {3.5355339059327378`, -2.5,
       2.5}, {5.5901699437494745`, -5., 2.5}, {5., -5., 0.}}], 
     Polygon3DBox[{{5.5901699437494745`, -5., 2.5}, {
      3.5355339059327378`, -2.5, 2.5}, {5.5901699437494745`, -2.5, 5.}, {
      7.0710678118654755`, -5., 5.}, {5.5901699437494745`, -5., 2.5}}], 
     Polygon3DBox[{{7.0710678118654755`, -5., 5.}, {5.5901699437494745`, -2.5,
       5.}, {7.905694150420948, -2.5, 7.5}, {9.013878188659973, -5., 7.5}, {
      7.0710678118654755`, -5., 5.}}], 
     Polygon3DBox[{{9.013878188659973, -5., 7.5}, {7.905694150420948, -2.5, 
      7.5}, {10.307764064044152`, -2.5, 10.}, {11.180339887498949`, -5., 
      10.}, {9.013878188659973, -5., 7.5}}], 
     Polygon3DBox[{{11.180339887498949`, -5., 10.}, {
      10.307764064044152`, -2.5, 10.}, {12.747548783981962`, -2.5, 12.5}, {
      13.46291201783626, -5., 12.5}, {11.180339887498949`, -5., 10.}}], 
     Polygon3DBox[{{13.46291201783626, -5., 12.5}, {12.747548783981962`, -2.5,
       12.5}, {15.20690632574555, -2.5, 15.}, {15.811388300841896`, -5., 
      15.}, {13.46291201783626, -5., 12.5}}], 
     Polygon3DBox[{{15.811388300841896`, -5., 15.}, {15.20690632574555, -2.5, 
      15.}, {17.67766952966369, -2.5, 17.5}, {18.200274723201296`, -5., 
      17.5}, {15.811388300841896`, -5., 15.}}], 
     Polygon3DBox[{{18.200274723201296`, -5., 17.5}, {17.67766952966369, -2.5,
       17.5}, {20.155644370746373`, -2.5, 20.}, {20.615528128088304`, -5., 
      20.}, {18.200274723201296`, -5., 17.5}}], 
     Polygon3DBox[{{20.615528128088304`, -5., 20.}, {
      20.155644370746373`, -2.5, 20.}, {22.638462845343543`, -2.5, 22.5}, {
      23.04886114323222, -5., 22.5}, {20.615528128088304`, -5., 20.}}], 
     Polygon3DBox[{{23.04886114323222, -5., 22.5}, {22.638462845343543`, -2.5,
       22.5}, {25.124689052802225`, -2.5, 25.}, {25.495097567963924`, -5., 
      25.}, {23.04886114323222, -5., 22.5}}], 
     Polygon3DBox[{{25.124689052802225`, -2.5, -25.}, {25., 0., -25.}, {22.5, 
      0., -22.5}, {22.638462845343543`, -2.5, -22.5}, {
      25.124689052802225`, -2.5, -25.}}], 
     Polygon3DBox[{{22.638462845343543`, -2.5, -22.5}, {22.5, 0., -22.5}, {
      20., 0., -20.}, {20.155644370746373`, -2.5, -20.}, {
      22.638462845343543`, -2.5, -22.5}}], 
     Polygon3DBox[{{20.155644370746373`, -2.5, -20.}, {20., 0., -20.}, {17.5, 
      0., -17.5}, {17.67766952966369, -2.5, -17.5}, {
      20.155644370746373`, -2.5, -20.}}], 
     Polygon3DBox[{{17.67766952966369, -2.5, -17.5}, {17.5, 0., -17.5}, {15., 
      0., -15.}, {15.20690632574555, -2.5, -15.}, {
      17.67766952966369, -2.5, -17.5}}], 
     Polygon3DBox[{{15.20690632574555, -2.5, -15.}, {15., 0., -15.}, {12.5, 
      0., -12.5}, {12.747548783981962`, -2.5, -12.5}, {
      15.20690632574555, -2.5, -15.}}], 
     Polygon3DBox[{{12.747548783981962`, -2.5, -12.5}, {12.5, 0., -12.5}, {
      10., 0., -10.}, {10.307764064044152`, -2.5, -10.}, {
      12.747548783981962`, -2.5, -12.5}}], 
     Polygon3DBox[{{10.307764064044152`, -2.5, -10.}, {10., 0., -10.}, {7.5, 
      0., -7.5}, {7.905694150420948, -2.5, -7.5}, {
      10.307764064044152`, -2.5, -10.}}], 
     Polygon3DBox[{{7.905694150420948, -2.5, -7.5}, {7.5, 0., -7.5}, {5., 
      0., -5.}, {5.5901699437494745`, -2.5, -5.}, {
      7.905694150420948, -2.5, -7.5}}], 
     Polygon3DBox[{{5.5901699437494745`, -2.5, -5.}, {5., 0., -5.}, {2.5, 
      0., -2.5}, {3.5355339059327378`, -2.5, -2.5}, {
      5.5901699437494745`, -2.5, -5.}}], 
     Polygon3DBox[{{3.5355339059327378`, -2.5, -2.5}, {2.5, 0., -2.5}, {0., 
      0., 0.}, {2.5, -2.5, 0.}, {3.5355339059327378`, -2.5, -2.5}}], 
     Polygon3DBox[{{2.5, -2.5, 0.}, {0., 0., 0.}, {2.5, 0., 2.5}, {
      3.5355339059327378`, -2.5, 2.5}, {2.5, -2.5, 0.}}], 
     Polygon3DBox[{{3.5355339059327378`, -2.5, 2.5}, {2.5, 0., 2.5}, {5., 0., 
      5.}, {5.5901699437494745`, -2.5, 5.}, {3.5355339059327378`, -2.5, 
      2.5}}], Polygon3DBox[{{5.5901699437494745`, -2.5, 5.}, {5., 0., 5.}, {
      7.5, 0., 7.5}, {7.905694150420948, -2.5, 7.5}, {
      5.5901699437494745`, -2.5, 5.}}], 
     Polygon3DBox[{{7.905694150420948, -2.5, 7.5}, {7.5, 0., 7.5}, {10., 0., 
      10.}, {10.307764064044152`, -2.5, 10.}, {7.905694150420948, -2.5, 
      7.5}}], Polygon3DBox[{{10.307764064044152`, -2.5, 10.}, {10., 0., 
      10.}, {12.5, 0., 12.5}, {12.747548783981962`, -2.5, 12.5}, {
      10.307764064044152`, -2.5, 10.}}], 
     Polygon3DBox[{{12.747548783981962`, -2.5, 12.5}, {12.5, 0., 12.5}, {15., 
      0., 15.}, {15.20690632574555, -2.5, 15.}, {12.747548783981962`, -2.5, 
      12.5}}], Polygon3DBox[{{15.20690632574555, -2.5, 15.}, {15., 0., 15.}, {
      17.5, 0., 17.5}, {17.67766952966369, -2.5, 17.5}, {
      15.20690632574555, -2.5, 15.}}], 
     Polygon3DBox[{{17.67766952966369, -2.5, 17.5}, {17.5, 0., 17.5}, {20., 
      0., 20.}, {20.155644370746373`, -2.5, 20.}, {17.67766952966369, -2.5, 
      17.5}}], Polygon3DBox[{{20.155644370746373`, -2.5, 20.}, {20., 0., 
      20.}, {22.5, 0., 22.5}, {22.638462845343543`, -2.5, 22.5}, {
      20.155644370746373`, -2.5, 20.}}], 
     Polygon3DBox[{{22.638462845343543`, -2.5, 22.5}, {22.5, 0., 22.5}, {25., 
      0., 25.}, {25.124689052802225`, -2.5, 25.}, {22.638462845343543`, -2.5, 
      22.5}}], Polygon3DBox[{{25., 0., -25.}, {25.124689052802225`, 
      2.5, -25.}, {22.638462845343543`, 2.5, -22.5}, {22.5, 0., -22.5}, {25., 
      0., -25.}}], 
     Polygon3DBox[{{22.5, 0., -22.5}, {22.638462845343543`, 2.5, -22.5}, {
      20.155644370746373`, 2.5, -20.}, {20., 0., -20.}, {22.5, 0., -22.5}}], 
     Polygon3DBox[{{20., 0., -20.}, {20.155644370746373`, 2.5, -20.}, {
      17.67766952966369, 2.5, -17.5}, {17.5, 0., -17.5}, {20., 0., -20.}}], 
     Polygon3DBox[{{17.5, 0., -17.5}, {17.67766952966369, 2.5, -17.5}, {
      15.20690632574555, 2.5, -15.}, {15., 0., -15.}, {17.5, 0., -17.5}}], 
     Polygon3DBox[{{15., 0., -15.}, {15.20690632574555, 2.5, -15.}, {
      12.747548783981962`, 2.5, -12.5}, {12.5, 0., -12.5}, {15., 0., -15.}}], 
     Polygon3DBox[{{12.5, 0., -12.5}, {12.747548783981962`, 2.5, -12.5}, {
      10.307764064044152`, 2.5, -10.}, {10., 0., -10.}, {12.5, 0., -12.5}}], 
     Polygon3DBox[{{10., 0., -10.}, {10.307764064044152`, 2.5, -10.}, {
      7.905694150420948, 2.5, -7.5}, {7.5, 0., -7.5}, {10., 0., -10.}}], 
     Polygon3DBox[{{7.5, 0., -7.5}, {7.905694150420948, 2.5, -7.5}, {
      5.5901699437494745`, 2.5, -5.}, {5., 0., -5.}, {7.5, 0., -7.5}}], 
     Polygon3DBox[{{5., 0., -5.}, {5.5901699437494745`, 2.5, -5.}, {
      3.5355339059327378`, 2.5, -2.5}, {2.5, 0., -2.5}, {5., 0., -5.}}], 
     Polygon3DBox[{{2.5, 0., -2.5}, {3.5355339059327378`, 2.5, -2.5}, {2.5, 
      2.5, 0.}, {0., 0., 0.}, {2.5, 0., -2.5}}], 
     Polygon3DBox[{{0., 0., 0.}, {2.5, 2.5, 0.}, {3.5355339059327378`, 2.5, 
      2.5}, {2.5, 0., 2.5}, {0., 0., 0.}}], 
     Polygon3DBox[{{2.5, 0., 2.5}, {3.5355339059327378`, 2.5, 2.5}, {
      5.5901699437494745`, 2.5, 5.}, {5., 0., 5.}, {2.5, 0., 2.5}}], 
     Polygon3DBox[{{5., 0., 5.}, {5.5901699437494745`, 2.5, 5.}, {
      7.905694150420948, 2.5, 7.5}, {7.5, 0., 7.5}, {5., 0., 5.}}], 
     Polygon3DBox[{{7.5, 0., 7.5}, {7.905694150420948, 2.5, 7.5}, {
      10.307764064044152`, 2.5, 10.}, {10., 0., 10.}, {7.5, 0., 7.5}}], 
     Polygon3DBox[{{10., 0., 10.}, {10.307764064044152`, 2.5, 10.}, {
      12.747548783981962`, 2.5, 12.5}, {12.5, 0., 12.5}, {10., 0., 10.}}], 
     Polygon3DBox[{{12.5, 0., 12.5}, {12.747548783981962`, 2.5, 12.5}, {
      15.20690632574555, 2.5, 15.}, {15., 0., 15.}, {12.5, 0., 12.5}}], 
     Polygon3DBox[{{15., 0., 15.}, {15.20690632574555, 2.5, 15.}, {
      17.67766952966369, 2.5, 17.5}, {17.5, 0., 17.5}, {15., 0., 15.}}], 
     Polygon3DBox[{{17.5, 0., 17.5}, {17.67766952966369, 2.5, 17.5}, {
      20.155644370746373`, 2.5, 20.}, {20., 0., 20.}, {17.5, 0., 17.5}}], 
     Polygon3DBox[{{20., 0., 20.}, {20.155644370746373`, 2.5, 20.}, {
      22.638462845343543`, 2.5, 22.5}, {22.5, 0., 22.5}, {20., 0., 20.}}], 
     Polygon3DBox[{{22.5, 0., 22.5}, {22.638462845343543`, 2.5, 22.5}, {
      25.124689052802225`, 2.5, 25.}, {25., 0., 25.}, {22.5, 0., 22.5}}], 
     Polygon3DBox[{{25.124689052802225`, 2.5, -25.}, {25.495097567963924`, 
      5., -25.}, {23.04886114323222, 5., -22.5}, {22.638462845343543`, 
      2.5, -22.5}, {25.124689052802225`, 2.5, -25.}}], 
     Polygon3DBox[{{22.638462845343543`, 2.5, -22.5}, {23.04886114323222, 
      5., -22.5}, {20.615528128088304`, 5., -20.}, {20.155644370746373`, 
      2.5, -20.}, {22.638462845343543`, 2.5, -22.5}}], 
     Polygon3DBox[{{20.155644370746373`, 2.5, -20.}, {20.615528128088304`, 
      5., -20.}, {18.200274723201296`, 5., -17.5}, {17.67766952966369, 
      2.5, -17.5}, {20.155644370746373`, 2.5, -20.}}], 
     Polygon3DBox[{{17.67766952966369, 2.5, -17.5}, {18.200274723201296`, 
      5., -17.5}, {15.811388300841896`, 5., -15.}, {15.20690632574555, 
      2.5, -15.}, {17.67766952966369, 2.5, -17.5}}], 
     Polygon3DBox[{{15.20690632574555, 2.5, -15.}, {15.811388300841896`, 
      5., -15.}, {13.46291201783626, 5., -12.5}, {12.747548783981962`, 
      2.5, -12.5}, {15.20690632574555, 2.5, -15.}}], 
     Polygon3DBox[{{12.747548783981962`, 2.5, -12.5}, {13.46291201783626, 
      5., -12.5}, {11.180339887498949`, 5., -10.}, {10.307764064044152`, 
      2.5, -10.}, {12.747548783981962`, 2.5, -12.5}}], 
     Polygon3DBox[{{10.307764064044152`, 2.5, -10.}, {11.180339887498949`, 
      5., -10.}, {9.013878188659973, 5., -7.5}, {7.905694150420948, 
      2.5, -7.5}, {10.307764064044152`, 2.5, -10.}}], 
     Polygon3DBox[{{7.905694150420948, 2.5, -7.5}, {9.013878188659973, 
      5., -7.5}, {7.0710678118654755`, 5., -5.}, {5.5901699437494745`, 
      2.5, -5.}, {7.905694150420948, 2.5, -7.5}}], 
     Polygon3DBox[{{5.5901699437494745`, 2.5, -5.}, {7.0710678118654755`, 
      5., -5.}, {5.5901699437494745`, 5., -2.5}, {3.5355339059327378`, 
      2.5, -2.5}, {5.5901699437494745`, 2.5, -5.}}], 
     Polygon3DBox[{{3.5355339059327378`, 2.5, -2.5}, {5.5901699437494745`, 
      5., -2.5}, {5., 5., 0.}, {2.5, 2.5, 0.}, {3.5355339059327378`, 
      2.5, -2.5}}], 
     Polygon3DBox[{{2.5, 2.5, 0.}, {5., 5., 0.}, {5.5901699437494745`, 5., 
      2.5}, {3.5355339059327378`, 2.5, 2.5}, {2.5, 2.5, 0.}}], 
     Polygon3DBox[{{3.5355339059327378`, 2.5, 2.5}, {5.5901699437494745`, 5., 
      2.5}, {7.0710678118654755`, 5., 5.}, {5.5901699437494745`, 2.5, 5.}, {
      3.5355339059327378`, 2.5, 2.5}}], 
     Polygon3DBox[{{5.5901699437494745`, 2.5, 5.}, {7.0710678118654755`, 5., 
      5.}, {9.013878188659973, 5., 7.5}, {7.905694150420948, 2.5, 7.5}, {
      5.5901699437494745`, 2.5, 5.}}], 
     Polygon3DBox[{{7.905694150420948, 2.5, 7.5}, {9.013878188659973, 5., 
      7.5}, {11.180339887498949`, 5., 10.}, {10.307764064044152`, 2.5, 10.}, {
      7.905694150420948, 2.5, 7.5}}], 
     Polygon3DBox[{{10.307764064044152`, 2.5, 10.}, {11.180339887498949`, 5., 
      10.}, {13.46291201783626, 5., 12.5}, {12.747548783981962`, 2.5, 12.5}, {
      10.307764064044152`, 2.5, 10.}}], 
     Polygon3DBox[{{12.747548783981962`, 2.5, 12.5}, {13.46291201783626, 5., 
      12.5}, {15.811388300841896`, 5., 15.}, {15.20690632574555, 2.5, 15.}, {
      12.747548783981962`, 2.5, 12.5}}], 
     Polygon3DBox[{{15.20690632574555, 2.5, 15.}, {15.811388300841896`, 5., 
      15.}, {18.200274723201296`, 5., 17.5}, {17.67766952966369, 2.5, 17.5}, {
      15.20690632574555, 2.5, 15.}}], 
     Polygon3DBox[{{17.67766952966369, 2.5, 17.5}, {18.200274723201296`, 5., 
      17.5}, {20.615528128088304`, 5., 20.}, {20.155644370746373`, 2.5, 
      20.}, {17.67766952966369, 2.5, 17.5}}], 
     Polygon3DBox[{{20.155644370746373`, 2.5, 20.}, {20.615528128088304`, 5., 
      20.}, {23.04886114323222, 5., 22.5}, {22.638462845343543`, 2.5, 22.5}, {
      20.155644370746373`, 2.5, 20.}}], 
     Polygon3DBox[{{22.638462845343543`, 2.5, 22.5}, {23.04886114323222, 5., 
      22.5}, {25.495097567963924`, 5., 25.}, {25.124689052802225`, 2.5, 
      25.}, {22.638462845343543`, 2.5, 22.5}}], 
     Polygon3DBox[{{25.495097567963924`, 5., -25.}, {26.100766272276374`, 
      7.5, -25.}, {23.717082451262844`, 7.5, -22.5}, {23.04886114323222, 
      5., -22.5}, {25.495097567963924`, 5., -25.}}], 
     Polygon3DBox[{{23.04886114323222, 5., -22.5}, {23.717082451262844`, 
      7.5, -22.5}, {21.360009363293827`, 7.5, -20.}, {20.615528128088304`, 
      5., -20.}, {23.04886114323222, 5., -22.5}}], 
     Polygon3DBox[{{20.615528128088304`, 5., -20.}, {21.360009363293827`, 
      7.5, -20.}, {19.03943276465977, 7.5, -17.5}, {18.200274723201296`, 
      5., -17.5}, {20.615528128088304`, 5., -20.}}], 
     Polygon3DBox[{{18.200274723201296`, 5., -17.5}, {19.03943276465977, 
      7.5, -17.5}, {16.77050983124842, 7.5, -15.}, {15.811388300841896`, 
      5., -15.}, {18.200274723201296`, 5., -17.5}}], 
     Polygon3DBox[{{15.811388300841896`, 5., -15.}, {16.77050983124842, 
      7.5, -15.}, {14.577379737113251`, 7.5, -12.5}, {13.46291201783626, 
      5., -12.5}, {15.811388300841896`, 5., -15.}}], 
     Polygon3DBox[{{13.46291201783626, 5., -12.5}, {14.577379737113251`, 
      7.5, -12.5}, {12.5, 7.5, -10.}, {11.180339887498949`, 5., -10.}, {
      13.46291201783626, 5., -12.5}}], 
     Polygon3DBox[{{11.180339887498949`, 5., -10.}, {12.5, 7.5, -10.}, {
      10.606601717798213`, 7.5, -7.5}, {9.013878188659973, 5., -7.5}, {
      11.180339887498949`, 5., -10.}}], 
     Polygon3DBox[{{9.013878188659973, 5., -7.5}, {10.606601717798213`, 
      7.5, -7.5}, {9.013878188659973, 7.5, -5.}, {7.0710678118654755`, 
      5., -5.}, {9.013878188659973, 5., -7.5}}], 
     Polygon3DBox[{{7.0710678118654755`, 5., -5.}, {9.013878188659973, 
      7.5, -5.}, {7.905694150420948, 7.5, -2.5}, {5.5901699437494745`, 
      5., -2.5}, {7.0710678118654755`, 5., -5.}}], 
     Polygon3DBox[{{5.5901699437494745`, 5., -2.5}, {7.905694150420948, 
      7.5, -2.5}, {7.5, 7.5, 0.}, {5., 5., 0.}, {5.5901699437494745`, 
      5., -2.5}}], 
     Polygon3DBox[{{5., 5., 0.}, {7.5, 7.5, 0.}, {7.905694150420948, 7.5, 
      2.5}, {5.5901699437494745`, 5., 2.5}, {5., 5., 0.}}], 
     Polygon3DBox[{{5.5901699437494745`, 5., 2.5}, {7.905694150420948, 7.5, 
      2.5}, {9.013878188659973, 7.5, 5.}, {7.0710678118654755`, 5., 5.}, {
      5.5901699437494745`, 5., 2.5}}], 
     Polygon3DBox[{{7.0710678118654755`, 5., 5.}, {9.013878188659973, 7.5, 
      5.}, {10.606601717798213`, 7.5, 7.5}, {9.013878188659973, 5., 7.5}, {
      7.0710678118654755`, 5., 5.}}], 
     Polygon3DBox[{{9.013878188659973, 5., 7.5}, {10.606601717798213`, 7.5, 
      7.5}, {12.5, 7.5, 10.}, {11.180339887498949`, 5., 10.}, {
      9.013878188659973, 5., 7.5}}], 
     Polygon3DBox[{{11.180339887498949`, 5., 10.}, {12.5, 7.5, 10.}, {
      14.577379737113251`, 7.5, 12.5}, {13.46291201783626, 5., 12.5}, {
      11.180339887498949`, 5., 10.}}], 
     Polygon3DBox[{{13.46291201783626, 5., 12.5}, {14.577379737113251`, 7.5, 
      12.5}, {16.77050983124842, 7.5, 15.}, {15.811388300841896`, 5., 15.}, {
      13.46291201783626, 5., 12.5}}], 
     Polygon3DBox[{{15.811388300841896`, 5., 15.}, {16.77050983124842, 7.5, 
      15.}, {19.03943276465977, 7.5, 17.5}, {18.200274723201296`, 5., 17.5}, {
      15.811388300841896`, 5., 15.}}], 
     Polygon3DBox[{{18.200274723201296`, 5., 17.5}, {19.03943276465977, 7.5, 
      17.5}, {21.360009363293827`, 7.5, 20.}, {20.615528128088304`, 5., 
      20.}, {18.200274723201296`, 5., 17.5}}], 
     Polygon3DBox[{{20.615528128088304`, 5., 20.}, {21.360009363293827`, 7.5, 
      20.}, {23.717082451262844`, 7.5, 22.5}, {23.04886114323222, 5., 22.5}, {
      20.615528128088304`, 5., 20.}}], 
     Polygon3DBox[{{23.04886114323222, 5., 22.5}, {23.717082451262844`, 7.5, 
      22.5}, {26.100766272276374`, 7.5, 25.}, {25.495097567963924`, 5., 
      25.}, {23.04886114323222, 5., 22.5}}], 
     Polygon3DBox[{{26.100766272276374`, 7.5, -25.}, {26.92582403567252, 
      10., -25.}, {24.62214450449026, 10., -22.5}, {23.717082451262844`, 
      7.5, -22.5}, {26.100766272276374`, 7.5, -25.}}], 
     Polygon3DBox[{{23.717082451262844`, 7.5, -22.5}, {24.62214450449026, 
      10., -22.5}, {22.360679774997898`, 10., -20.}, {21.360009363293827`, 
      7.5, -20.}, {23.717082451262844`, 7.5, -22.5}}], 
     Polygon3DBox[{{21.360009363293827`, 7.5, -20.}, {22.360679774997898`, 
      10., -20.}, {20.155644370746373`, 10., -17.5}, {19.03943276465977, 
      7.5, -17.5}, {21.360009363293827`, 7.5, -20.}}], 
     Polygon3DBox[{{19.03943276465977, 7.5, -17.5}, {20.155644370746373`, 
      10., -17.5}, {18.027756377319946`, 10., -15.}, {16.77050983124842, 
      7.5, -15.}, {19.03943276465977, 7.5, -17.5}}], 
     Polygon3DBox[{{16.77050983124842, 7.5, -15.}, {18.027756377319946`, 
      10., -15.}, {16.00781059358212, 10., -12.5}, {14.577379737113251`, 
      7.5, -12.5}, {16.77050983124842, 7.5, -15.}}], 
     Polygon3DBox[{{14.577379737113251`, 7.5, -12.5}, {16.00781059358212, 
      10., -12.5}, {14.142135623730951`, 10., -10.}, {12.5, 7.5, -10.}, {
      14.577379737113251`, 7.5, -12.5}}], 
     Polygon3DBox[{{12.5, 7.5, -10.}, {14.142135623730951`, 10., -10.}, {12.5,
       10., -7.5}, {10.606601717798213`, 7.5, -7.5}, {12.5, 7.5, -10.}}], 
     Polygon3DBox[{{10.606601717798213`, 7.5, -7.5}, {12.5, 10., -7.5}, {
      11.180339887498949`, 10., -5.}, {9.013878188659973, 7.5, -5.}, {
      10.606601717798213`, 7.5, -7.5}}], 
     Polygon3DBox[{{9.013878188659973, 7.5, -5.}, {11.180339887498949`, 
      10., -5.}, {10.307764064044152`, 10., -2.5}, {7.905694150420948, 
      7.5, -2.5}, {9.013878188659973, 7.5, -5.}}], 
     Polygon3DBox[{{7.905694150420948, 7.5, -2.5}, {10.307764064044152`, 
      10., -2.5}, {10., 10., 0.}, {7.5, 7.5, 0.}, {7.905694150420948, 
      7.5, -2.5}}], 
     Polygon3DBox[{{7.5, 7.5, 0.}, {10., 10., 0.}, {10.307764064044152`, 10., 
      2.5}, {7.905694150420948, 7.5, 2.5}, {7.5, 7.5, 0.}}], 
     Polygon3DBox[{{7.905694150420948, 7.5, 2.5}, {10.307764064044152`, 10., 
      2.5}, {11.180339887498949`, 10., 5.}, {9.013878188659973, 7.5, 5.}, {
      7.905694150420948, 7.5, 2.5}}], 
     Polygon3DBox[{{9.013878188659973, 7.5, 5.}, {11.180339887498949`, 10., 
      5.}, {12.5, 10., 7.5}, {10.606601717798213`, 7.5, 7.5}, {
      9.013878188659973, 7.5, 5.}}], 
     Polygon3DBox[{{10.606601717798213`, 7.5, 7.5}, {12.5, 10., 7.5}, {
      14.142135623730951`, 10., 10.}, {12.5, 7.5, 10.}, {10.606601717798213`, 
      7.5, 7.5}}], 
     Polygon3DBox[{{12.5, 7.5, 10.}, {14.142135623730951`, 10., 10.}, {
      16.00781059358212, 10., 12.5}, {14.577379737113251`, 7.5, 12.5}, {12.5, 
      7.5, 10.}}], 
     Polygon3DBox[{{14.577379737113251`, 7.5, 12.5}, {16.00781059358212, 10., 
      12.5}, {18.027756377319946`, 10., 15.}, {16.77050983124842, 7.5, 15.}, {
      14.577379737113251`, 7.5, 12.5}}], 
     Polygon3DBox[{{16.77050983124842, 7.5, 15.}, {18.027756377319946`, 10., 
      15.}, {20.155644370746373`, 10., 17.5}, {19.03943276465977, 7.5, 
      17.5}, {16.77050983124842, 7.5, 15.}}], 
     Polygon3DBox[{{19.03943276465977, 7.5, 17.5}, {20.155644370746373`, 10., 
      17.5}, {22.360679774997898`, 10., 20.}, {21.360009363293827`, 7.5, 
      20.}, {19.03943276465977, 7.5, 17.5}}], 
     Polygon3DBox[{{21.360009363293827`, 7.5, 20.}, {22.360679774997898`, 10.,
       20.}, {24.62214450449026, 10., 22.5}, {23.717082451262844`, 7.5, 
      22.5}, {21.360009363293827`, 7.5, 20.}}], 
     Polygon3DBox[{{23.717082451262844`, 7.5, 22.5}, {24.62214450449026, 10., 
      22.5}, {26.92582403567252, 10., 25.}, {26.100766272276374`, 7.5, 25.}, {
      23.717082451262844`, 7.5, 22.5}}], 
     Polygon3DBox[{{26.92582403567252, 10., -25.}, {27.95084971874737, 
      12.5, -25.}, {25.739075352467502`, 12.5, -22.5}, {24.62214450449026, 
      10., -22.5}, {26.92582403567252, 10., -25.}}], 
     Polygon3DBox[{{24.62214450449026, 10., -22.5}, {25.739075352467502`, 
      12.5, -22.5}, {23.58495283014151, 12.5, -20.}, {22.360679774997898`, 
      10., -20.}, {24.62214450449026, 10., -22.5}}], 
     Polygon3DBox[{{22.360679774997898`, 10., -20.}, {23.58495283014151, 
      12.5, -20.}, {21.50581316760657, 12.5, -17.5}, {20.155644370746373`, 
      10., -17.5}, {22.360679774997898`, 10., -20.}}], 
     Polygon3DBox[{{20.155644370746373`, 10., -17.5}, {21.50581316760657, 
      12.5, -17.5}, {19.525624189766635`, 12.5, -15.}, {18.027756377319946`, 
      10., -15.}, {20.155644370746373`, 10., -17.5}}], 
     Polygon3DBox[{{18.027756377319946`, 10., -15.}, {19.525624189766635`, 
      12.5, -15.}, {17.67766952966369, 12.5, -12.5}, {16.00781059358212, 
      10., -12.5}, {18.027756377319946`, 10., -15.}}], 
     Polygon3DBox[{{16.00781059358212, 10., -12.5}, {17.67766952966369, 
      12.5, -12.5}, {16.00781059358212, 12.5, -10.}, {14.142135623730951`, 
      10., -10.}, {16.00781059358212, 10., -12.5}}], 
     Polygon3DBox[{{14.142135623730951`, 10., -10.}, {16.00781059358212, 
      12.5, -10.}, {14.577379737113251`, 12.5, -7.5}, {12.5, 10., -7.5}, {
      14.142135623730951`, 10., -10.}}], 
     Polygon3DBox[{{12.5, 10., -7.5}, {14.577379737113251`, 12.5, -7.5}, {
      13.46291201783626, 12.5, -5.}, {11.180339887498949`, 10., -5.}, {12.5, 
      10., -7.5}}], 
     Polygon3DBox[{{11.180339887498949`, 10., -5.}, {13.46291201783626, 
      12.5, -5.}, {12.747548783981962`, 12.5, -2.5}, {10.307764064044152`, 
      10., -2.5}, {11.180339887498949`, 10., -5.}}], 
     Polygon3DBox[{{10.307764064044152`, 10., -2.5}, {12.747548783981962`, 
      12.5, -2.5}, {12.5, 12.5, 0.}, {10., 10., 0.}, {10.307764064044152`, 
      10., -2.5}}], 
     Polygon3DBox[{{10., 10., 0.}, {12.5, 12.5, 0.}, {12.747548783981962`, 
      12.5, 2.5}, {10.307764064044152`, 10., 2.5}, {10., 10., 0.}}], 
     Polygon3DBox[{{10.307764064044152`, 10., 2.5}, {12.747548783981962`, 
      12.5, 2.5}, {13.46291201783626, 12.5, 5.}, {11.180339887498949`, 10., 
      5.}, {10.307764064044152`, 10., 2.5}}], 
     Polygon3DBox[{{11.180339887498949`, 10., 5.}, {13.46291201783626, 12.5, 
      5.}, {14.577379737113251`, 12.5, 7.5}, {12.5, 10., 7.5}, {
      11.180339887498949`, 10., 5.}}], 
     Polygon3DBox[{{12.5, 10., 7.5}, {14.577379737113251`, 12.5, 7.5}, {
      16.00781059358212, 12.5, 10.}, {14.142135623730951`, 10., 10.}, {12.5, 
      10., 7.5}}], 
     Polygon3DBox[{{14.142135623730951`, 10., 10.}, {16.00781059358212, 12.5, 
      10.}, {17.67766952966369, 12.5, 12.5}, {16.00781059358212, 10., 12.5}, {
      14.142135623730951`, 10., 10.}}], 
     Polygon3DBox[{{16.00781059358212, 10., 12.5}, {17.67766952966369, 12.5, 
      12.5}, {19.525624189766635`, 12.5, 15.}, {18.027756377319946`, 10., 
      15.}, {16.00781059358212, 10., 12.5}}], 
     Polygon3DBox[{{18.027756377319946`, 10., 15.}, {19.525624189766635`, 
      12.5, 15.}, {21.50581316760657, 12.5, 17.5}, {20.155644370746373`, 10., 
      17.5}, {18.027756377319946`, 10., 15.}}], 
     Polygon3DBox[{{20.155644370746373`, 10., 17.5}, {21.50581316760657, 12.5,
       17.5}, {23.58495283014151, 12.5, 20.}, {22.360679774997898`, 10., 
      20.}, {20.155644370746373`, 10., 17.5}}], 
     Polygon3DBox[{{22.360679774997898`, 10., 20.}, {23.58495283014151, 12.5, 
      20.}, {25.739075352467502`, 12.5, 22.5}, {24.62214450449026, 10., 
      22.5}, {22.360679774997898`, 10., 20.}}], 
     Polygon3DBox[{{24.62214450449026, 10., 22.5}, {25.739075352467502`, 12.5,
       22.5}, {27.95084971874737, 12.5, 25.}, {26.92582403567252, 10., 25.}, {
      24.62214450449026, 10., 22.5}}], 
     Polygon3DBox[{{27.95084971874737, 12.5, -25.}, {29.154759474226502`, 
      15., -25.}, {27.04163456597992, 15., -22.5}, {25.739075352467502`, 
      12.5, -22.5}, {27.95084971874737, 12.5, -25.}}], 
     Polygon3DBox[{{25.739075352467502`, 12.5, -22.5}, {27.04163456597992, 
      15., -22.5}, {25., 15., -20.}, {23.58495283014151, 12.5, -20.}, {
      25.739075352467502`, 12.5, -22.5}}], 
     Polygon3DBox[{{23.58495283014151, 12.5, -20.}, {25., 15., -20.}, {
      23.04886114323222, 15., -17.5}, {21.50581316760657, 12.5, -17.5}, {
      23.58495283014151, 12.5, -20.}}], 
     Polygon3DBox[{{21.50581316760657, 12.5, -17.5}, {23.04886114323222, 
      15., -17.5}, {21.213203435596427`, 15., -15.}, {19.525624189766635`, 
      12.5, -15.}, {21.50581316760657, 12.5, -17.5}}], 
     Polygon3DBox[{{19.525624189766635`, 12.5, -15.}, {21.213203435596427`, 
      15., -15.}, {19.525624189766635`, 15., -12.5}, {17.67766952966369, 
      12.5, -12.5}, {19.525624189766635`, 12.5, -15.}}], 
     Polygon3DBox[{{17.67766952966369, 12.5, -12.5}, {19.525624189766635`, 
      15., -12.5}, {18.027756377319946`, 15., -10.}, {16.00781059358212, 
      12.5, -10.}, {17.67766952966369, 12.5, -12.5}}], 
     Polygon3DBox[{{16.00781059358212, 12.5, -10.}, {18.027756377319946`, 
      15., -10.}, {16.77050983124842, 15., -7.5}, {14.577379737113251`, 
      12.5, -7.5}, {16.00781059358212, 12.5, -10.}}], 
     Polygon3DBox[{{14.577379737113251`, 12.5, -7.5}, {16.77050983124842, 
      15., -7.5}, {15.811388300841896`, 15., -5.}, {13.46291201783626, 
      12.5, -5.}, {14.577379737113251`, 12.5, -7.5}}], 
     Polygon3DBox[{{13.46291201783626, 12.5, -5.}, {15.811388300841896`, 
      15., -5.}, {15.20690632574555, 15., -2.5}, {12.747548783981962`, 
      12.5, -2.5}, {13.46291201783626, 12.5, -5.}}], 
     Polygon3DBox[{{12.747548783981962`, 12.5, -2.5}, {15.20690632574555, 
      15., -2.5}, {15., 15., 0.}, {12.5, 12.5, 0.}, {12.747548783981962`, 
      12.5, -2.5}}], 
     Polygon3DBox[{{12.5, 12.5, 0.}, {15., 15., 0.}, {15.20690632574555, 15., 
      2.5}, {12.747548783981962`, 12.5, 2.5}, {12.5, 12.5, 0.}}], 
     Polygon3DBox[{{12.747548783981962`, 12.5, 2.5}, {15.20690632574555, 15., 
      2.5}, {15.811388300841896`, 15., 5.}, {13.46291201783626, 12.5, 5.}, {
      12.747548783981962`, 12.5, 2.5}}], 
     Polygon3DBox[{{13.46291201783626, 12.5, 5.}, {15.811388300841896`, 15., 
      5.}, {16.77050983124842, 15., 7.5}, {14.577379737113251`, 12.5, 7.5}, {
      13.46291201783626, 12.5, 5.}}], 
     Polygon3DBox[{{14.577379737113251`, 12.5, 7.5}, {16.77050983124842, 15., 
      7.5}, {18.027756377319946`, 15., 10.}, {16.00781059358212, 12.5, 10.}, {
      14.577379737113251`, 12.5, 7.5}}], 
     Polygon3DBox[{{16.00781059358212, 12.5, 10.}, {18.027756377319946`, 15., 
      10.}, {19.525624189766635`, 15., 12.5}, {17.67766952966369, 12.5, 
      12.5}, {16.00781059358212, 12.5, 10.}}], 
     Polygon3DBox[{{17.67766952966369, 12.5, 12.5}, {19.525624189766635`, 15.,
       12.5}, {21.213203435596427`, 15., 15.}, {19.525624189766635`, 12.5, 
      15.}, {17.67766952966369, 12.5, 12.5}}], 
     Polygon3DBox[{{19.525624189766635`, 12.5, 15.}, {21.213203435596427`, 
      15., 15.}, {23.04886114323222, 15., 17.5}, {21.50581316760657, 12.5, 
      17.5}, {19.525624189766635`, 12.5, 15.}}], 
     Polygon3DBox[{{21.50581316760657, 12.5, 17.5}, {23.04886114323222, 15., 
      17.5}, {25., 15., 20.}, {23.58495283014151, 12.5, 20.}, {
      21.50581316760657, 12.5, 17.5}}], 
     Polygon3DBox[{{23.58495283014151, 12.5, 20.}, {25., 15., 20.}, {
      27.04163456597992, 15., 22.5}, {25.739075352467502`, 12.5, 22.5}, {
      23.58495283014151, 12.5, 20.}}], 
     Polygon3DBox[{{25.739075352467502`, 12.5, 22.5}, {27.04163456597992, 15.,
       22.5}, {29.154759474226502`, 15., 25.}, {27.95084971874737, 12.5, 
      25.}, {25.739075352467502`, 12.5, 22.5}}], 
     Polygon3DBox[{{29.154759474226502`, 15., -25.}, {30.516389039334257`, 
      17.5, -25.}, {28.50438562747845, 17.5, -22.5}, {27.04163456597992, 
      15., -22.5}, {29.154759474226502`, 15., -25.}}], 
     Polygon3DBox[{{27.04163456597992, 15., -22.5}, {28.50438562747845, 
      17.5, -22.5}, {26.575364531836623`, 17.5, -20.}, {25., 15., -20.}, {
      27.04163456597992, 15., -22.5}}], 
     Polygon3DBox[{{25., 15., -20.}, {26.575364531836623`, 17.5, -20.}, {
      24.748737341529164`, 17.5, -17.5}, {23.04886114323222, 15., -17.5}, {
      25., 15., -20.}}], 
     Polygon3DBox[{{23.04886114323222, 15., -17.5}, {24.748737341529164`, 
      17.5, -17.5}, {23.04886114323222, 17.5, -15.}, {21.213203435596427`, 
      15., -15.}, {23.04886114323222, 15., -17.5}}], 
     Polygon3DBox[{{21.213203435596427`, 15., -15.}, {23.04886114323222, 
      17.5, -15.}, {21.50581316760657, 17.5, -12.5}, {19.525624189766635`, 
      15., -12.5}, {21.213203435596427`, 15., -15.}}], 
     Polygon3DBox[{{19.525624189766635`, 15., -12.5}, {21.50581316760657, 
      17.5, -12.5}, {20.155644370746373`, 17.5, -10.}, {18.027756377319946`, 
      15., -10.}, {19.525624189766635`, 15., -12.5}}], 
     Polygon3DBox[{{18.027756377319946`, 15., -10.}, {20.155644370746373`, 
      17.5, -10.}, {19.03943276465977, 17.5, -7.5}, {16.77050983124842, 
      15., -7.5}, {18.027756377319946`, 15., -10.}}], 
     Polygon3DBox[{{16.77050983124842, 15., -7.5}, {19.03943276465977, 
      17.5, -7.5}, {18.200274723201296`, 17.5, -5.}, {15.811388300841896`, 
      15., -5.}, {16.77050983124842, 15., -7.5}}], 
     Polygon3DBox[{{15.811388300841896`, 15., -5.}, {18.200274723201296`, 
      17.5, -5.}, {17.67766952966369, 17.5, -2.5}, {15.20690632574555, 
      15., -2.5}, {15.811388300841896`, 15., -5.}}], 
     Polygon3DBox[{{15.20690632574555, 15., -2.5}, {17.67766952966369, 
      17.5, -2.5}, {17.5, 17.5, 0.}, {15., 15., 0.}, {15.20690632574555, 
      15., -2.5}}], 
     Polygon3DBox[{{15., 15., 0.}, {17.5, 17.5, 0.}, {17.67766952966369, 17.5,
       2.5}, {15.20690632574555, 15., 2.5}, {15., 15., 0.}}], 
     Polygon3DBox[{{15.20690632574555, 15., 2.5}, {17.67766952966369, 17.5, 
      2.5}, {18.200274723201296`, 17.5, 5.}, {15.811388300841896`, 15., 5.}, {
      15.20690632574555, 15., 2.5}}], 
     Polygon3DBox[{{15.811388300841896`, 15., 5.}, {18.200274723201296`, 17.5,
       5.}, {19.03943276465977, 17.5, 7.5}, {16.77050983124842, 15., 7.5}, {
      15.811388300841896`, 15., 5.}}], 
     Polygon3DBox[{{16.77050983124842, 15., 7.5}, {19.03943276465977, 17.5, 
      7.5}, {20.155644370746373`, 17.5, 10.}, {18.027756377319946`, 15., 
      10.}, {16.77050983124842, 15., 7.5}}], 
     Polygon3DBox[{{18.027756377319946`, 15., 10.}, {20.155644370746373`, 
      17.5, 10.}, {21.50581316760657, 17.5, 12.5}, {19.525624189766635`, 15., 
      12.5}, {18.027756377319946`, 15., 10.}}], 
     Polygon3DBox[{{19.525624189766635`, 15., 12.5}, {21.50581316760657, 17.5,
       12.5}, {23.04886114323222, 17.5, 15.}, {21.213203435596427`, 15., 
      15.}, {19.525624189766635`, 15., 12.5}}], 
     Polygon3DBox[{{21.213203435596427`, 15., 15.}, {23.04886114323222, 17.5, 
      15.}, {24.748737341529164`, 17.5, 17.5}, {23.04886114323222, 15., 
      17.5}, {21.213203435596427`, 15., 15.}}], 
     Polygon3DBox[{{23.04886114323222, 15., 17.5}, {24.748737341529164`, 17.5,
       17.5}, {26.575364531836623`, 17.5, 20.}, {25., 15., 20.}, {
      23.04886114323222, 15., 17.5}}], 
     Polygon3DBox[{{25., 15., 20.}, {26.575364531836623`, 17.5, 20.}, {
      28.50438562747845, 17.5, 22.5}, {27.04163456597992, 15., 22.5}, {25., 
      15., 20.}}], 
     Polygon3DBox[{{27.04163456597992, 15., 22.5}, {28.50438562747845, 17.5, 
      22.5}, {30.516389039334257`, 17.5, 25.}, {29.154759474226502`, 15., 
      25.}, {27.04163456597992, 15., 22.5}}], 
     Polygon3DBox[{{30.516389039334257`, 17.5, -25.}, {32.01562118716424, 
      20., -25.}, {30.103986446980738`, 20., -22.5}, {28.50438562747845, 
      17.5, -22.5}, {30.516389039334257`, 17.5, -25.}}], 
     Polygon3DBox[{{28.50438562747845, 17.5, -22.5}, {30.103986446980738`, 
      20., -22.5}, {28.284271247461902`, 20., -20.}, {26.575364531836623`, 
      17.5, -20.}, {28.50438562747845, 17.5, -22.5}}], 
     Polygon3DBox[{{26.575364531836623`, 17.5, -20.}, {28.284271247461902`, 
      20., -20.}, {26.575364531836623`, 20., -17.5}, {24.748737341529164`, 
      17.5, -17.5}, {26.575364531836623`, 17.5, -20.}}], 
     Polygon3DBox[{{24.748737341529164`, 17.5, -17.5}, {26.575364531836623`, 
      20., -17.5}, {25., 20., -15.}, {23.04886114323222, 17.5, -15.}, {
      24.748737341529164`, 17.5, -17.5}}], 
     Polygon3DBox[{{23.04886114323222, 17.5, -15.}, {25., 20., -15.}, {
      23.58495283014151, 20., -12.5}, {21.50581316760657, 17.5, -12.5}, {
      23.04886114323222, 17.5, -15.}}], 
     Polygon3DBox[{{21.50581316760657, 17.5, -12.5}, {23.58495283014151, 
      20., -12.5}, {22.360679774997898`, 20., -10.}, {20.155644370746373`, 
      17.5, -10.}, {21.50581316760657, 17.5, -12.5}}], 
     Polygon3DBox[{{20.155644370746373`, 17.5, -10.}, {22.360679774997898`, 
      20., -10.}, {21.360009363293827`, 20., -7.5}, {19.03943276465977, 
      17.5, -7.5}, {20.155644370746373`, 17.5, -10.}}], 
     Polygon3DBox[{{19.03943276465977, 17.5, -7.5}, {21.360009363293827`, 
      20., -7.5}, {20.615528128088304`, 20., -5.}, {18.200274723201296`, 
      17.5, -5.}, {19.03943276465977, 17.5, -7.5}}], 
     Polygon3DBox[{{18.200274723201296`, 17.5, -5.}, {20.615528128088304`, 
      20., -5.}, {20.155644370746373`, 20., -2.5}, {17.67766952966369, 
      17.5, -2.5}, {18.200274723201296`, 17.5, -5.}}], 
     Polygon3DBox[{{17.67766952966369, 17.5, -2.5}, {20.155644370746373`, 
      20., -2.5}, {20., 20., 0.}, {17.5, 17.5, 0.}, {17.67766952966369, 
      17.5, -2.5}}], 
     Polygon3DBox[{{17.5, 17.5, 0.}, {20., 20., 0.}, {20.155644370746373`, 
      20., 2.5}, {17.67766952966369, 17.5, 2.5}, {17.5, 17.5, 0.}}], 
     Polygon3DBox[{{17.67766952966369, 17.5, 2.5}, {20.155644370746373`, 20., 
      2.5}, {20.615528128088304`, 20., 5.}, {18.200274723201296`, 17.5, 5.}, {
      17.67766952966369, 17.5, 2.5}}], 
     Polygon3DBox[{{18.200274723201296`, 17.5, 5.}, {20.615528128088304`, 20.,
       5.}, {21.360009363293827`, 20., 7.5}, {19.03943276465977, 17.5, 7.5}, {
      18.200274723201296`, 17.5, 5.}}], 
     Polygon3DBox[{{19.03943276465977, 17.5, 7.5}, {21.360009363293827`, 20., 
      7.5}, {22.360679774997898`, 20., 10.}, {20.155644370746373`, 17.5, 
      10.}, {19.03943276465977, 17.5, 7.5}}], 
     Polygon3DBox[{{20.155644370746373`, 17.5, 10.}, {22.360679774997898`, 
      20., 10.}, {23.58495283014151, 20., 12.5}, {21.50581316760657, 17.5, 
      12.5}, {20.155644370746373`, 17.5, 10.}}], 
     Polygon3DBox[{{21.50581316760657, 17.5, 12.5}, {23.58495283014151, 20., 
      12.5}, {25., 20., 15.}, {23.04886114323222, 17.5, 15.}, {
      21.50581316760657, 17.5, 12.5}}], 
     Polygon3DBox[{{23.04886114323222, 17.5, 15.}, {25., 20., 15.}, {
      26.575364531836623`, 20., 17.5}, {24.748737341529164`, 17.5, 17.5}, {
      23.04886114323222, 17.5, 15.}}], 
     Polygon3DBox[{{24.748737341529164`, 17.5, 17.5}, {26.575364531836623`, 
      20., 17.5}, {28.284271247461902`, 20., 20.}, {26.575364531836623`, 17.5,
       20.}, {24.748737341529164`, 17.5, 17.5}}], 
     Polygon3DBox[{{26.575364531836623`, 17.5, 20.}, {28.284271247461902`, 
      20., 20.}, {30.103986446980738`, 20., 22.5}, {28.50438562747845, 17.5, 
      22.5}, {26.575364531836623`, 17.5, 20.}}], 
     Polygon3DBox[{{28.50438562747845, 17.5, 22.5}, {30.103986446980738`, 20.,
       22.5}, {32.01562118716424, 20., 25.}, {30.516389039334257`, 17.5, 
      25.}, {28.50438562747845, 17.5, 22.5}}], 
     Polygon3DBox[{{32.01562118716424, 20., -25.}, {33.63406011768428, 
      22.5, -25.}, {31.81980515339464, 22.5, -22.5}, {30.103986446980738`, 
      20., -22.5}, {32.01562118716424, 20., -25.}}], 
     Polygon3DBox[{{30.103986446980738`, 20., -22.5}, {31.81980515339464, 
      22.5, -22.5}, {30.103986446980738`, 22.5, -20.}, {28.284271247461902`, 
      20., -20.}, {30.103986446980738`, 20., -22.5}}], 
     Polygon3DBox[{{28.284271247461902`, 20., -20.}, {30.103986446980738`, 
      22.5, -20.}, {28.50438562747845, 22.5, -17.5}, {26.575364531836623`, 
      20., -17.5}, {28.284271247461902`, 20., -20.}}], 
     Polygon3DBox[{{26.575364531836623`, 20., -17.5}, {28.50438562747845, 
      22.5, -17.5}, {27.04163456597992, 22.5, -15.}, {25., 20., -15.}, {
      26.575364531836623`, 20., -17.5}}], 
     Polygon3DBox[{{25., 20., -15.}, {27.04163456597992, 22.5, -15.}, {
      25.739075352467502`, 22.5, -12.5}, {23.58495283014151, 20., -12.5}, {
      25., 20., -15.}}], 
     Polygon3DBox[{{23.58495283014151, 20., -12.5}, {25.739075352467502`, 
      22.5, -12.5}, {24.62214450449026, 22.5, -10.}, {22.360679774997898`, 
      20., -10.}, {23.58495283014151, 20., -12.5}}], 
     Polygon3DBox[{{22.360679774997898`, 20., -10.}, {24.62214450449026, 
      22.5, -10.}, {23.717082451262844`, 22.5, -7.5}, {21.360009363293827`, 
      20., -7.5}, {22.360679774997898`, 20., -10.}}], 
     Polygon3DBox[{{21.360009363293827`, 20., -7.5}, {23.717082451262844`, 
      22.5, -7.5}, {23.04886114323222, 22.5, -5.}, {20.615528128088304`, 
      20., -5.}, {21.360009363293827`, 20., -7.5}}], 
     Polygon3DBox[{{20.615528128088304`, 20., -5.}, {23.04886114323222, 
      22.5, -5.}, {22.638462845343543`, 22.5, -2.5}, {20.155644370746373`, 
      20., -2.5}, {20.615528128088304`, 20., -5.}}], 
     Polygon3DBox[{{20.155644370746373`, 20., -2.5}, {22.638462845343543`, 
      22.5, -2.5}, {22.5, 22.5, 0.}, {20., 20., 0.}, {20.155644370746373`, 
      20., -2.5}}], 
     Polygon3DBox[{{20., 20., 0.}, {22.5, 22.5, 0.}, {22.638462845343543`, 
      22.5, 2.5}, {20.155644370746373`, 20., 2.5}, {20., 20., 0.}}], 
     Polygon3DBox[{{20.155644370746373`, 20., 2.5}, {22.638462845343543`, 
      22.5, 2.5}, {23.04886114323222, 22.5, 5.}, {20.615528128088304`, 20., 
      5.}, {20.155644370746373`, 20., 2.5}}], 
     Polygon3DBox[{{20.615528128088304`, 20., 5.}, {23.04886114323222, 22.5, 
      5.}, {23.717082451262844`, 22.5, 7.5}, {21.360009363293827`, 20., 
      7.5}, {20.615528128088304`, 20., 5.}}], 
     Polygon3DBox[{{21.360009363293827`, 20., 7.5}, {23.717082451262844`, 
      22.5, 7.5}, {24.62214450449026, 22.5, 10.}, {22.360679774997898`, 20., 
      10.}, {21.360009363293827`, 20., 7.5}}], 
     Polygon3DBox[{{22.360679774997898`, 20., 10.}, {24.62214450449026, 22.5, 
      10.}, {25.739075352467502`, 22.5, 12.5}, {23.58495283014151, 20., 
      12.5}, {22.360679774997898`, 20., 10.}}], 
     Polygon3DBox[{{23.58495283014151, 20., 12.5}, {25.739075352467502`, 22.5,
       12.5}, {27.04163456597992, 22.5, 15.}, {25., 20., 15.}, {
      23.58495283014151, 20., 12.5}}], 
     Polygon3DBox[{{25., 20., 15.}, {27.04163456597992, 22.5, 15.}, {
      28.50438562747845, 22.5, 17.5}, {26.575364531836623`, 20., 17.5}, {25., 
      20., 15.}}], 
     Polygon3DBox[{{26.575364531836623`, 20., 17.5}, {28.50438562747845, 22.5,
       17.5}, {30.103986446980738`, 22.5, 20.}, {28.284271247461902`, 20., 
      20.}, {26.575364531836623`, 20., 17.5}}], 
     Polygon3DBox[{{28.284271247461902`, 20., 20.}, {30.103986446980738`, 
      22.5, 20.}, {31.81980515339464, 22.5, 22.5}, {30.103986446980738`, 20., 
      22.5}, {28.284271247461902`, 20., 20.}}], 
     Polygon3DBox[{{30.103986446980738`, 20., 22.5}, {31.81980515339464, 22.5,
       22.5}, {33.63406011768428, 22.5, 25.}, {32.01562118716424, 20., 25.}, {
      30.103986446980738`, 20., 22.5}}], 
     Polygon3DBox[{{33.63406011768428, 22.5, -25.}, {35.35533905932738, 
      25., -25.}, {33.63406011768428, 25., -22.5}, {31.81980515339464, 
      22.5, -22.5}, {33.63406011768428, 22.5, -25.}}], 
     Polygon3DBox[{{31.81980515339464, 22.5, -22.5}, {33.63406011768428, 
      25., -22.5}, {32.01562118716424, 25., -20.}, {30.103986446980738`, 
      22.5, -20.}, {31.81980515339464, 22.5, -22.5}}], 
     Polygon3DBox[{{30.103986446980738`, 22.5, -20.}, {32.01562118716424, 
      25., -20.}, {30.516389039334257`, 25., -17.5}, {28.50438562747845, 
      22.5, -17.5}, {30.103986446980738`, 22.5, -20.}}], 
     Polygon3DBox[{{28.50438562747845, 22.5, -17.5}, {30.516389039334257`, 
      25., -17.5}, {29.154759474226502`, 25., -15.}, {27.04163456597992, 
      22.5, -15.}, {28.50438562747845, 22.5, -17.5}}], 
     Polygon3DBox[{{27.04163456597992, 22.5, -15.}, {29.154759474226502`, 
      25., -15.}, {27.95084971874737, 25., -12.5}, {25.739075352467502`, 
      22.5, -12.5}, {27.04163456597992, 22.5, -15.}}], 
     Polygon3DBox[{{25.739075352467502`, 22.5, -12.5}, {27.95084971874737, 
      25., -12.5}, {26.92582403567252, 25., -10.}, {24.62214450449026, 
      22.5, -10.}, {25.739075352467502`, 22.5, -12.5}}], 
     Polygon3DBox[{{24.62214450449026, 22.5, -10.}, {26.92582403567252, 
      25., -10.}, {26.100766272276374`, 25., -7.5}, {23.717082451262844`, 
      22.5, -7.5}, {24.62214450449026, 22.5, -10.}}], 
     Polygon3DBox[{{23.717082451262844`, 22.5, -7.5}, {26.100766272276374`, 
      25., -7.5}, {25.495097567963924`, 25., -5.}, {23.04886114323222, 
      22.5, -5.}, {23.717082451262844`, 22.5, -7.5}}], 
     Polygon3DBox[{{23.04886114323222, 22.5, -5.}, {25.495097567963924`, 
      25., -5.}, {25.124689052802225`, 25., -2.5}, {22.638462845343543`, 
      22.5, -2.5}, {23.04886114323222, 22.5, -5.}}], 
     Polygon3DBox[{{22.638462845343543`, 22.5, -2.5}, {25.124689052802225`, 
      25., -2.5}, {25., 25., 0.}, {22.5, 22.5, 0.}, {22.638462845343543`, 
      22.5, -2.5}}], 
     Polygon3DBox[{{22.5, 22.5, 0.}, {25., 25., 0.}, {25.124689052802225`, 
      25., 2.5}, {22.638462845343543`, 22.5, 2.5}, {22.5, 22.5, 0.}}], 
     Polygon3DBox[{{22.638462845343543`, 22.5, 2.5}, {25.124689052802225`, 
      25., 2.5}, {25.495097567963924`, 25., 5.}, {23.04886114323222, 22.5, 
      5.}, {22.638462845343543`, 22.5, 2.5}}], 
     Polygon3DBox[{{23.04886114323222, 22.5, 5.}, {25.495097567963924`, 25., 
      5.}, {26.100766272276374`, 25., 7.5}, {23.717082451262844`, 22.5, 
      7.5}, {23.04886114323222, 22.5, 5.}}], 
     Polygon3DBox[{{23.717082451262844`, 22.5, 7.5}, {26.100766272276374`, 
      25., 7.5}, {26.92582403567252, 25., 10.}, {24.62214450449026, 22.5, 
      10.}, {23.717082451262844`, 22.5, 7.5}}], 
     Polygon3DBox[{{24.62214450449026, 22.5, 10.}, {26.92582403567252, 25., 
      10.}, {27.95084971874737, 25., 12.5}, {25.739075352467502`, 22.5, 
      12.5}, {24.62214450449026, 22.5, 10.}}], 
     Polygon3DBox[{{25.739075352467502`, 22.5, 12.5}, {27.95084971874737, 25.,
       12.5}, {29.154759474226502`, 25., 15.}, {27.04163456597992, 22.5, 
      15.}, {25.739075352467502`, 22.5, 12.5}}], 
     Polygon3DBox[{{27.04163456597992, 22.5, 15.}, {29.154759474226502`, 25., 
      15.}, {30.516389039334257`, 25., 17.5}, {28.50438562747845, 22.5, 
      17.5}, {27.04163456597992, 22.5, 15.}}], 
     Polygon3DBox[{{28.50438562747845, 22.5, 17.5}, {30.516389039334257`, 25.,
       17.5}, {32.01562118716424, 25., 20.}, {30.103986446980738`, 22.5, 
      20.}, {28.50438562747845, 22.5, 17.5}}], 
     Polygon3DBox[{{30.103986446980738`, 22.5, 20.}, {32.01562118716424, 25., 
      20.}, {33.63406011768428, 25., 22.5}, {31.81980515339464, 22.5, 22.5}, {
      30.103986446980738`, 22.5, 20.}}], 
     Polygon3DBox[{{31.81980515339464, 22.5, 22.5}, {33.63406011768428, 25., 
      22.5}, {35.35533905932738, 25., 25.}, {33.63406011768428, 22.5, 25.}, {
      31.81980515339464, 22.5, 22.5}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{35.35533905932738, -25., 25}, {
        33.63406011768428, -22.5, 25}, {32.01562118716424, -20., 25}, {
        30.516389039334257`, -17.5, 25}, {29.154759474226502`, -15., 25}, {
        27.95084971874737, -12.5, 25}, {26.92582403567252, -10., 25}, {
        26.100766272276374`, -7.5, 25}, {25.495097567963924`, -5., 25}, {
        25.124689052802225`, -2.5, 25}, {25., 0., 25}, {
        25.124689052802225`, 2.5, 25}, {25.495097567963924`, 5., 25}, {
        26.100766272276374`, 7.5, 25}, {26.92582403567252, 10., 25}, {
        27.95084971874737, 12.5, 25}, {29.154759474226502`, 15., 25}, {
        30.516389039334257`, 17.5, 25}, {32.01562118716424, 20., 25}, {
        33.63406011768428, 22.5, 25}, {35.35533905932738, 25., 25}, {
        35.35533905932738, 25, 25.}, {33.63406011768428, 25, 22.5}, {
        32.01562118716424, 25, 20.}, {30.516389039334257`, 25, 17.5}, {
        29.154759474226502`, 25, 15.}, {27.95084971874737, 25, 12.5}, {
        26.92582403567252, 25, 10.}, {26.100766272276374`, 25, 7.5}, {
        25.495097567963924`, 25, 5.}, {25.124689052802225`, 25, 2.5}, {
        25., 25, 0.}, {25.124689052802225`, 25, -2.5}, {
        25.495097567963924`, 25, -5.}, {26.100766272276374`, 25, -7.5}, {
        26.92582403567252, 25, -10.}, {27.95084971874737, 25, -12.5}, {
        29.154759474226502`, 25, -15.}, {30.516389039334257`, 25, -17.5}, {
        32.01562118716424, 25, -20.}, {33.63406011768428, 25, -22.5}, {
        35.35533905932738, 25, -25.}, {35.35533905932738, 25., -25}, {
        33.63406011768428, 22.5, -25}, {32.01562118716424, 20., -25}, {
        30.516389039334257`, 17.5, -25}, {29.154759474226502`, 15., -25}, {
        27.95084971874737, 12.5, -25}, {26.92582403567252, 10., -25}, {
        26.100766272276374`, 7.5, -25}, {25.495097567963924`, 5., -25}, {
        25.124689052802225`, 2.5, -25}, {25., 0., -25}, {
        25.124689052802225`, -2.5, -25}, {25.495097567963924`, -5., -25}, {
        26.100766272276374`, -7.5, -25}, {26.92582403567252, -10., -25}, {
        27.95084971874737, -12.5, -25}, {29.154759474226502`, -15., -25}, {
        30.516389039334257`, -17.5, -25}, {32.01562118716424, -20., -25}, {
        33.63406011768428, -22.5, -25}, {35.35533905932738, -25., -25}, {
        35.35533905932738, -25, -25.}, {33.63406011768428, -25, -22.5}, {
        32.01562118716424, -25, -20.}, {30.516389039334257`, -25, -17.5}, {
        29.154759474226502`, -25, -15.}, {27.95084971874737, -25, -12.5}, {
        26.92582403567252, -25, -10.}, {26.100766272276374`, -25, -7.5}, {
        25.495097567963924`, -25, -5.}, {25.124689052802225`, -25, -2.5}, {
        25., -25, 0.}, {25.124689052802225`, -25, 2.5}, {
        25.495097567963924`, -25, 5.}, {26.100766272276374`, -25, 7.5}, {
        26.92582403567252, -25, 10.}, {27.95084971874737, -25, 12.5}, {
        29.154759474226502`, -25, 15.}, {30.516389039334257`, -25, 17.5}, {
        32.01562118716424, -25, 20.}, {33.63406011768428, -25, 22.5}, {
        35.35533905932738, -25, 25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015353838167`*^9, 3.6147093012165823`*^9, 
  3.6147291569406147`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[234]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{-24.999999, -24.999999}], 
   PointBox[{-24.999999, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -24.999999}], 
   PointBox[{-16.666665666666667`, -24.999999}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-24.999999, -16.666665666666667`}], 
   PointBox[{-24.999999, -16.666665666666667`}], 
   PointBox[{-24.999999, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-24.999999, -8.333332333333336}], 
   PointBox[{-24.999999, -8.333332333333336}], 
   PointBox[{-24.999999, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-24.999999, 9.999999964472863*^-7}], 
   PointBox[{-24.999999, 9.999999964472863*^-7}], 
   PointBox[{-24.999999, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-24.999999, 8.333334333333328}], 
   PointBox[{-24.999999, 8.333334333333328}], 
   PointBox[{-24.999999, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-24.999999, 16.666667666666658`}], 
   PointBox[{-24.999999, 16.666667666666658`}], 
   PointBox[{-24.999999, 25.000000999999994`}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 25.000000999999994`}], 
   PointBox[{-24.999999, 25.000000999999994`}], 
   PointBox[{-16.666665666666667`, -24.999999}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -24.999999}], 
   PointBox[{-8.333332333333336, -24.999999}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -16.666665666666667`}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, -8.333332333333336}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, 9.999999964472863*^-7}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 8.333334333333328}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 16.666667666666658`}], 
   PointBox[{-16.666665666666667`, 25.000000999999994`}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 25.000000999999994`}], 
   PointBox[{-16.666665666666667`, 25.000000999999994`}], 
   PointBox[{-8.333332333333336, -24.999999}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -24.999999}], 
   PointBox[{9.999999964472863*^-7, -24.999999}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -16.666665666666667`}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{-8.333332333333336, -8.333332333333336}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, 9.999999964472863*^-7}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 8.333334333333328}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 16.666667666666658`}], 
   PointBox[{-8.333332333333336, 25.000000999999994`}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 25.000000999999994`}], 
   PointBox[{-8.333332333333336, 25.000000999999994`}], 
   PointBox[{9.999999964472863*^-7, -24.999999}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -24.999999}], 
   PointBox[{8.333334333333328, -24.999999}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -16.666665666666667`}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, -8.333332333333336}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, 9.999999964472863*^-7}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 8.333334333333328}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 16.666667666666658`}], 
   PointBox[{9.999999964472863*^-7, 25.000000999999994`}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 25.000000999999994`}], 
   PointBox[{9.999999964472863*^-7, 25.000000999999994`}], 
   PointBox[{8.333334333333328, -24.999999}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -24.999999}], 
   PointBox[{16.666667666666658`, -24.999999}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -16.666665666666667`}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{8.333334333333328, -8.333332333333336}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, 9.999999964472863*^-7}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{8.333334333333328, 8.333334333333328}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 16.666667666666658`}], 
   PointBox[{8.333334333333328, 25.000000999999994`}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 25.000000999999994`}], 
   PointBox[{8.333334333333328, 25.000000999999994`}], 
   PointBox[{16.666667666666658`, -24.999999}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{25.000000999999994`, -24.999999}], 
   PointBox[{25.000000999999994`, -24.999999}], 
   PointBox[{25.000000999999994`, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -16.666665666666667`}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{25.000000999999994`, -16.666665666666667`}], 
   PointBox[{25.000000999999994`, -16.666665666666667`}], 
   PointBox[{25.000000999999994`, -8.333332333333336}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{16.666667666666658`, -8.333332333333336}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{25.000000999999994`, -8.333332333333336}], 
   PointBox[{25.000000999999994`, -8.333332333333336}], 
   PointBox[{25.000000999999994`, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, 9.999999964472863*^-7}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{25.000000999999994`, 9.999999964472863*^-7}], 
   PointBox[{25.000000999999994`, 9.999999964472863*^-7}], 
   PointBox[{25.000000999999994`, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 8.333334333333328}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{25.000000999999994`, 8.333334333333328}], 
   PointBox[{25.000000999999994`, 8.333334333333328}], 
   PointBox[{25.000000999999994`, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 16.666667666666658`}], 
   PointBox[{16.666667666666658`, 25.000000999999994`}], 
   PointBox[{25.000000999999994`, 16.666667666666658`}], 
   PointBox[{25.000000999999994`, 16.666667666666658`}], 
   PointBox[{25.000000999999994`, 25.000000999999994`}], 
   PointBox[{16.666667666666658`, 25.000000999999994`}], 
   LineBox[{{-24.999999, -24.999999}, {-24.999999, -16.666665666666667`}, \
{-16.666665666666667`, -24.999999}, {-24.999999, -24.999999}}], 
   LineBox[{{-16.666665666666667`, -24.999999}, {-16.666665666666667`, \
-16.666665666666667`}, {-24.999999, -16.666665666666667`}, \
{-16.666665666666667`, -24.999999}}], 
   LineBox[{{-24.999999, -16.666665666666667`}, {-24.999999, \
-8.333332333333336}, {-16.666665666666667`, -16.666665666666667`}, \
{-24.999999, -16.666665666666667`}}], 
   LineBox[{{-16.666665666666667`, -16.666665666666667`}, \
{-16.666665666666667`, -8.333332333333336}, {-24.999999, -8.333332333333336}, \
{-16.666665666666667`, -16.666665666666667`}}], 
   LineBox[{{-24.999999, -8.333332333333336}, {-24.999999, 
    9.999999964472863*^-7}, {-16.666665666666667`, -8.333332333333336}, \
{-24.999999, -8.333332333333336}}], 
   LineBox[{{-16.666665666666667`, -8.333332333333336}, {-16.666665666666667`,
     9.999999964472863*^-7}, {-24.999999, 
    9.999999964472863*^-7}, {-16.666665666666667`, -8.333332333333336}}], 
   LineBox[{{-24.999999, 9.999999964472863*^-7}, {-24.999999, 
    8.333334333333328}, {-16.666665666666667`, 
    9.999999964472863*^-7}, {-24.999999, 9.999999964472863*^-7}}], 
   LineBox[{{-16.666665666666667`, 
    9.999999964472863*^-7}, {-16.666665666666667`, 
    8.333334333333328}, {-24.999999, 
    8.333334333333328}, {-16.666665666666667`, 9.999999964472863*^-7}}], 
   LineBox[{{-24.999999, 8.333334333333328}, {-24.999999, 
    16.666667666666658`}, {-16.666665666666667`, 
    8.333334333333328}, {-24.999999, 8.333334333333328}}], 
   LineBox[{{-16.666665666666667`, 8.333334333333328}, {-16.666665666666667`, 
    16.666667666666658`}, {-24.999999, 
    16.666667666666658`}, {-16.666665666666667`, 8.333334333333328}}], 
   LineBox[{{-24.999999, 16.666667666666658`}, {-24.999999, 
    25.000000999999994`}, {-16.666665666666667`, 
    16.666667666666658`}, {-24.999999, 16.666667666666658`}}], 
   LineBox[{{-16.666665666666667`, 
    16.666667666666658`}, {-16.666665666666667`, 
    25.000000999999994`}, {-24.999999, 
    25.000000999999994`}, {-16.666665666666667`, 16.666667666666658`}}], 
   LineBox[{{-16.666665666666667`, -24.999999}, {-16.666665666666667`, \
-16.666665666666667`}, {-8.333332333333336, -24.999999}, \
{-16.666665666666667`, -24.999999}}], 
   LineBox[{{-8.333332333333336, -24.999999}, {-8.333332333333336, \
-16.666665666666667`}, {-16.666665666666667`, -16.666665666666667`}, \
{-8.333332333333336, -24.999999}}], 
   LineBox[{{-16.666665666666667`, -16.666665666666667`}, \
{-16.666665666666667`, -8.333332333333336}, {-8.333332333333336, \
-16.666665666666667`}, {-16.666665666666667`, -16.666665666666667`}}], 
   LineBox[{{-8.333332333333336, -16.666665666666667`}, {-8.333332333333336, \
-8.333332333333336}, {-16.666665666666667`, -8.333332333333336}, \
{-8.333332333333336, -16.666665666666667`}}], 
   LineBox[{{-16.666665666666667`, -8.333332333333336}, {-16.666665666666667`,
     9.999999964472863*^-7}, {-8.333332333333336, -8.333332333333336}, \
{-16.666665666666667`, -8.333332333333336}}], 
   LineBox[{{-8.333332333333336, -8.333332333333336}, {-8.333332333333336, 
    9.999999964472863*^-7}, {-16.666665666666667`, 
    9.999999964472863*^-7}, {-8.333332333333336, -8.333332333333336}}], 
   LineBox[{{-16.666665666666667`, 
    9.999999964472863*^-7}, {-16.666665666666667`, 
    8.333334333333328}, {-8.333332333333336, 
    9.999999964472863*^-7}, {-16.666665666666667`, 9.999999964472863*^-7}}], 
   LineBox[{{-8.333332333333336, 9.999999964472863*^-7}, {-8.333332333333336, 
    8.333334333333328}, {-16.666665666666667`, 
    8.333334333333328}, {-8.333332333333336, 9.999999964472863*^-7}}], 
   LineBox[{{-16.666665666666667`, 8.333334333333328}, {-16.666665666666667`, 
    16.666667666666658`}, {-8.333332333333336, 
    8.333334333333328}, {-16.666665666666667`, 8.333334333333328}}], 
   LineBox[{{-8.333332333333336, 8.333334333333328}, {-8.333332333333336, 
    16.666667666666658`}, {-16.666665666666667`, 
    16.666667666666658`}, {-8.333332333333336, 8.333334333333328}}], 
   LineBox[{{-16.666665666666667`, 
    16.666667666666658`}, {-16.666665666666667`, 
    25.000000999999994`}, {-8.333332333333336, 
    16.666667666666658`}, {-16.666665666666667`, 16.666667666666658`}}], 
   LineBox[{{-8.333332333333336, 16.666667666666658`}, {-8.333332333333336, 
    25.000000999999994`}, {-16.666665666666667`, 
    25.000000999999994`}, {-8.333332333333336, 16.666667666666658`}}], 
   LineBox[{{-8.333332333333336, -24.999999}, {-8.333332333333336, \
-16.666665666666667`}, {
    9.999999964472863*^-7, -24.999999}, {-8.333332333333336, -24.999999}}], 
   LineBox[{{9.999999964472863*^-7, -24.999999}, {
    9.999999964472863*^-7, -16.666665666666667`}, {-8.333332333333336, \
-16.666665666666667`}, {9.999999964472863*^-7, -24.999999}}], 
   LineBox[{{-8.333332333333336, -16.666665666666667`}, {-8.333332333333336, \
-8.333332333333336}, {
    9.999999964472863*^-7, -16.666665666666667`}, {-8.333332333333336, \
-16.666665666666667`}}], 
   LineBox[{{9.999999964472863*^-7, -16.666665666666667`}, {
    9.999999964472863*^-7, -8.333332333333336}, {-8.333332333333336, \
-8.333332333333336}, {9.999999964472863*^-7, -16.666665666666667`}}], 
   LineBox[{{-8.333332333333336, -8.333332333333336}, {-8.333332333333336, 
    9.999999964472863*^-7}, {
    9.999999964472863*^-7, -8.333332333333336}, {-8.333332333333336, \
-8.333332333333336}}], 
   LineBox[{{9.999999964472863*^-7, -8.333332333333336}, {
    9.999999964472863*^-7, 9.999999964472863*^-7}, {-8.333332333333336, 
    9.999999964472863*^-7}, {9.999999964472863*^-7, -8.333332333333336}}], 
   LineBox[{{-8.333332333333336, 9.999999964472863*^-7}, {-8.333332333333336, 
    8.333334333333328}, {9.999999964472863*^-7, 
    9.999999964472863*^-7}, {-8.333332333333336, 9.999999964472863*^-7}}], 
   LineBox[{{9.999999964472863*^-7, 9.999999964472863*^-7}, {
    9.999999964472863*^-7, 8.333334333333328}, {-8.333332333333336, 
    8.333334333333328}, {9.999999964472863*^-7, 9.999999964472863*^-7}}], 
   LineBox[{{-8.333332333333336, 8.333334333333328}, {-8.333332333333336, 
    16.666667666666658`}, {9.999999964472863*^-7, 
    8.333334333333328}, {-8.333332333333336, 8.333334333333328}}], 
   LineBox[{{9.999999964472863*^-7, 8.333334333333328}, {
    9.999999964472863*^-7, 16.666667666666658`}, {-8.333332333333336, 
    16.666667666666658`}, {9.999999964472863*^-7, 8.333334333333328}}], 
   LineBox[{{-8.333332333333336, 16.666667666666658`}, {-8.333332333333336, 
    25.000000999999994`}, {9.999999964472863*^-7, 
    16.666667666666658`}, {-8.333332333333336, 16.666667666666658`}}], 
   LineBox[{{9.999999964472863*^-7, 16.666667666666658`}, {
    9.999999964472863*^-7, 25.000000999999994`}, {-8.333332333333336, 
    25.000000999999994`}, {9.999999964472863*^-7, 16.666667666666658`}}], 
   LineBox[{{9.999999964472863*^-7, -24.999999}, {
    9.999999964472863*^-7, -16.666665666666667`}, {
    8.333334333333328, -24.999999}, {9.999999964472863*^-7, -24.999999}}], 
   LineBox[{{8.333334333333328, -24.999999}, {
    8.333334333333328, -16.666665666666667`}, {
    9.999999964472863*^-7, -16.666665666666667`}, {
    8.333334333333328, -24.999999}}], 
   LineBox[{{9.999999964472863*^-7, -16.666665666666667`}, {
    9.999999964472863*^-7, -8.333332333333336}, {
    8.333334333333328, -16.666665666666667`}, {
    9.999999964472863*^-7, -16.666665666666667`}}], 
   LineBox[{{8.333334333333328, -16.666665666666667`}, {
    8.333334333333328, -8.333332333333336}, {
    9.999999964472863*^-7, -8.333332333333336}, {
    8.333334333333328, -16.666665666666667`}}], 
   LineBox[{{9.999999964472863*^-7, -8.333332333333336}, {
    9.999999964472863*^-7, 9.999999964472863*^-7}, {
    8.333334333333328, -8.333332333333336}, {
    9.999999964472863*^-7, -8.333332333333336}}], 
   LineBox[{{8.333334333333328, -8.333332333333336}, {8.333334333333328, 
    9.999999964472863*^-7}, {9.999999964472863*^-7, 9.999999964472863*^-7}, {
    8.333334333333328, -8.333332333333336}}], 
   LineBox[{{9.999999964472863*^-7, 9.999999964472863*^-7}, {
    9.999999964472863*^-7, 8.333334333333328}, {8.333334333333328, 
    9.999999964472863*^-7}, {9.999999964472863*^-7, 9.999999964472863*^-7}}], 
   LineBox[{{8.333334333333328, 9.999999964472863*^-7}, {8.333334333333328, 
    8.333334333333328}, {9.999999964472863*^-7, 8.333334333333328}, {
    8.333334333333328, 9.999999964472863*^-7}}], 
   LineBox[{{9.999999964472863*^-7, 8.333334333333328}, {
    9.999999964472863*^-7, 16.666667666666658`}, {8.333334333333328, 
    8.333334333333328}, {9.999999964472863*^-7, 8.333334333333328}}], 
   LineBox[{{8.333334333333328, 8.333334333333328}, {8.333334333333328, 
    16.666667666666658`}, {9.999999964472863*^-7, 16.666667666666658`}, {
    8.333334333333328, 8.333334333333328}}], 
   LineBox[{{9.999999964472863*^-7, 16.666667666666658`}, {
    9.999999964472863*^-7, 25.000000999999994`}, {8.333334333333328, 
    16.666667666666658`}, {9.999999964472863*^-7, 16.666667666666658`}}], 
   LineBox[{{8.333334333333328, 16.666667666666658`}, {8.333334333333328, 
    25.000000999999994`}, {9.999999964472863*^-7, 25.000000999999994`}, {
    8.333334333333328, 16.666667666666658`}}], 
   LineBox[{{8.333334333333328, -24.999999}, {
    8.333334333333328, -16.666665666666667`}, {
    16.666667666666658`, -24.999999}, {8.333334333333328, -24.999999}}], 
   LineBox[{{16.666667666666658`, -24.999999}, {
    16.666667666666658`, -16.666665666666667`}, {
    8.333334333333328, -16.666665666666667`}, {
    16.666667666666658`, -24.999999}}], 
   LineBox[{{8.333334333333328, -16.666665666666667`}, {
    8.333334333333328, -8.333332333333336}, {
    16.666667666666658`, -16.666665666666667`}, {
    8.333334333333328, -16.666665666666667`}}], 
   LineBox[{{16.666667666666658`, -16.666665666666667`}, {
    16.666667666666658`, -8.333332333333336}, {
    8.333334333333328, -8.333332333333336}, {
    16.666667666666658`, -16.666665666666667`}}], 
   LineBox[{{8.333334333333328, -8.333332333333336}, {8.333334333333328, 
    9.999999964472863*^-7}, {16.666667666666658`, -8.333332333333336}, {
    8.333334333333328, -8.333332333333336}}], 
   LineBox[{{16.666667666666658`, -8.333332333333336}, {16.666667666666658`, 
    9.999999964472863*^-7}, {8.333334333333328, 9.999999964472863*^-7}, {
    16.666667666666658`, -8.333332333333336}}], 
   LineBox[{{8.333334333333328, 9.999999964472863*^-7}, {8.333334333333328, 
    8.333334333333328}, {16.666667666666658`, 9.999999964472863*^-7}, {
    8.333334333333328, 9.999999964472863*^-7}}], 
   LineBox[{{16.666667666666658`, 9.999999964472863*^-7}, {
    16.666667666666658`, 8.333334333333328}, {8.333334333333328, 
    8.333334333333328}, {16.666667666666658`, 9.999999964472863*^-7}}], 
   LineBox[{{8.333334333333328, 8.333334333333328}, {8.333334333333328, 
    16.666667666666658`}, {16.666667666666658`, 8.333334333333328}, {
    8.333334333333328, 8.333334333333328}}], 
   LineBox[{{16.666667666666658`, 8.333334333333328}, {16.666667666666658`, 
    16.666667666666658`}, {8.333334333333328, 16.666667666666658`}, {
    16.666667666666658`, 8.333334333333328}}], 
   LineBox[{{8.333334333333328, 16.666667666666658`}, {8.333334333333328, 
    25.000000999999994`}, {16.666667666666658`, 16.666667666666658`}, {
    8.333334333333328, 16.666667666666658`}}], 
   LineBox[{{16.666667666666658`, 16.666667666666658`}, {16.666667666666658`, 
    25.000000999999994`}, {8.333334333333328, 25.000000999999994`}, {
    16.666667666666658`, 16.666667666666658`}}], 
   LineBox[{{16.666667666666658`, -24.999999}, {
    16.666667666666658`, -16.666665666666667`}, {
    25.000000999999994`, -24.999999}, {16.666667666666658`, -24.999999}}], 
   LineBox[{{25.000000999999994`, -24.999999}, {
    25.000000999999994`, -16.666665666666667`}, {
    16.666667666666658`, -16.666665666666667`}, {
    25.000000999999994`, -24.999999}}], 
   LineBox[{{16.666667666666658`, -16.666665666666667`}, {
    16.666667666666658`, -8.333332333333336}, {
    25.000000999999994`, -16.666665666666667`}, {
    16.666667666666658`, -16.666665666666667`}}], 
   LineBox[{{25.000000999999994`, -16.666665666666667`}, {
    25.000000999999994`, -8.333332333333336}, {
    16.666667666666658`, -8.333332333333336}, {
    25.000000999999994`, -16.666665666666667`}}], 
   LineBox[{{16.666667666666658`, -8.333332333333336}, {16.666667666666658`, 
    9.999999964472863*^-7}, {25.000000999999994`, -8.333332333333336}, {
    16.666667666666658`, -8.333332333333336}}], 
   LineBox[{{25.000000999999994`, -8.333332333333336}, {25.000000999999994`, 
    9.999999964472863*^-7}, {16.666667666666658`, 9.999999964472863*^-7}, {
    25.000000999999994`, -8.333332333333336}}], 
   LineBox[{{16.666667666666658`, 9.999999964472863*^-7}, {
    16.666667666666658`, 8.333334333333328}, {25.000000999999994`, 
    9.999999964472863*^-7}, {16.666667666666658`, 9.999999964472863*^-7}}], 
   LineBox[{{25.000000999999994`, 9.999999964472863*^-7}, {
    25.000000999999994`, 8.333334333333328}, {16.666667666666658`, 
    8.333334333333328}, {25.000000999999994`, 9.999999964472863*^-7}}], 
   LineBox[{{16.666667666666658`, 8.333334333333328}, {16.666667666666658`, 
    16.666667666666658`}, {25.000000999999994`, 8.333334333333328}, {
    16.666667666666658`, 8.333334333333328}}], 
   LineBox[{{25.000000999999994`, 8.333334333333328}, {25.000000999999994`, 
    16.666667666666658`}, {16.666667666666658`, 16.666667666666658`}, {
    25.000000999999994`, 8.333334333333328}}], 
   LineBox[{{16.666667666666658`, 16.666667666666658`}, {16.666667666666658`, 
    25.000000999999994`}, {25.000000999999994`, 16.666667666666658`}, {
    16.666667666666658`, 16.666667666666658`}}], 
   LineBox[{{25.000000999999994`, 16.666667666666658`}, {25.000000999999994`, 
    25.000000999999994`}, {16.666667666666658`, 25.000000999999994`}, {
    25.000000999999994`, 16.666667666666658`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015353838167`*^9, 3.6147093012165823`*^9, 
  3.614729157189314*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[234]:="]
}, Open  ]],

Cell[TextData[{
 "Triangular facets given by ",
 StyleBox["TriangleNet", "Input",
  FontSlant->"Plain"],
 " for a rectangular component aperture."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[TextData[{
 "Sometimes, you can obtain a more accurate estimate of the ray-surface \
intercept if you increase the ",
 StyleBox["SurfacePoints", "Input"],
 " value beyond its default setting, given by:"
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["SurfacePoints/.Options[CustomMirror]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[236]:="],

Cell[BoxData["7"], "Output",
 CellChangeTimes->{3.563404281547512*^9, 3.563458188888041*^9, 
  3.56448762449829*^9, 3.56610076138686*^9, 3.601301243862833*^9, 
  3.601301535722538*^9, 3.614709301606131*^9, 3.614729157225767*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"Out[236]="]
}, Open  ]],

Cell[TextData[{
 "For example If we increase the ",
 StyleBox["SurfacePoints", "Input"],
 " setting from 7 to 11, we obtain the following result."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],{50,50}, GraphicDesign -> False, \
SurfacePoints -> 11],
\tSurfacePoints -> Mesh,
\tPlotType->FrontView
];\
\>", "Input",
 CellChangeTimes->{{3.563457912696615*^9, 3.563457915395398*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[237]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{-24.999999, -24.999999}], 
   PointBox[{-24.999999, -19.999999}], PointBox[{-19.999999, -24.999999}], 
   PointBox[{-19.999999, -24.999999}], PointBox[{-19.999999, -19.999999}], 
   PointBox[{-24.999999, -19.999999}], PointBox[{-24.999999, -19.999999}], 
   PointBox[{-24.999999, -14.999999}], PointBox[{-19.999999, -19.999999}], 
   PointBox[{-19.999999, -19.999999}], PointBox[{-19.999999, -14.999999}], 
   PointBox[{-24.999999, -14.999999}], PointBox[{-24.999999, -14.999999}], 
   PointBox[{-24.999999, -9.999999}], PointBox[{-19.999999, -14.999999}], 
   PointBox[{-19.999999, -14.999999}], PointBox[{-19.999999, -9.999999}], 
   PointBox[{-24.999999, -9.999999}], PointBox[{-24.999999, -9.999999}], 
   PointBox[{-24.999999, -4.999999}], PointBox[{-19.999999, -9.999999}], 
   PointBox[{-19.999999, -9.999999}], PointBox[{-19.999999, -4.999999}], 
   PointBox[{-24.999999, -4.999999}], PointBox[{-24.999999, -4.999999}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-19.999999, -4.999999}], 
   PointBox[{-19.999999, -4.999999}], PointBox[{-19.999999, 1.*^-6}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-24.999999, 5.000001}], PointBox[{-19.999999, 1.*^-6}], 
   PointBox[{-19.999999, 1.*^-6}], PointBox[{-19.999999, 5.000001}], 
   PointBox[{-24.999999, 5.000001}], PointBox[{-24.999999, 5.000001}], 
   PointBox[{-24.999999, 10.000001}], PointBox[{-19.999999, 5.000001}], 
   PointBox[{-19.999999, 5.000001}], PointBox[{-19.999999, 10.000001}], 
   PointBox[{-24.999999, 10.000001}], PointBox[{-24.999999, 10.000001}], 
   PointBox[{-24.999999, 15.000001}], PointBox[{-19.999999, 10.000001}], 
   PointBox[{-19.999999, 10.000001}], PointBox[{-19.999999, 15.000001}], 
   PointBox[{-24.999999, 15.000001}], PointBox[{-24.999999, 15.000001}], 
   PointBox[{-24.999999, 20.000001}], PointBox[{-19.999999, 15.000001}], 
   PointBox[{-19.999999, 15.000001}], PointBox[{-19.999999, 20.000001}], 
   PointBox[{-24.999999, 20.000001}], PointBox[{-24.999999, 20.000001}], 
   PointBox[{-24.999999, 25.000001}], PointBox[{-19.999999, 20.000001}], 
   PointBox[{-19.999999, 20.000001}], PointBox[{-19.999999, 25.000001}], 
   PointBox[{-24.999999, 25.000001}], PointBox[{-19.999999, -24.999999}], 
   PointBox[{-19.999999, -19.999999}], PointBox[{-14.999999, -24.999999}], 
   PointBox[{-14.999999, -24.999999}], PointBox[{-14.999999, -19.999999}], 
   PointBox[{-19.999999, -19.999999}], PointBox[{-19.999999, -19.999999}], 
   PointBox[{-19.999999, -14.999999}], PointBox[{-14.999999, -19.999999}], 
   PointBox[{-14.999999, -19.999999}], PointBox[{-14.999999, -14.999999}], 
   PointBox[{-19.999999, -14.999999}], PointBox[{-19.999999, -14.999999}], 
   PointBox[{-19.999999, -9.999999}], PointBox[{-14.999999, -14.999999}], 
   PointBox[{-14.999999, -14.999999}], PointBox[{-14.999999, -9.999999}], 
   PointBox[{-19.999999, -9.999999}], PointBox[{-19.999999, -9.999999}], 
   PointBox[{-19.999999, -4.999999}], PointBox[{-14.999999, -9.999999}], 
   PointBox[{-14.999999, -9.999999}], PointBox[{-14.999999, -4.999999}], 
   PointBox[{-19.999999, -4.999999}], PointBox[{-19.999999, -4.999999}], 
   PointBox[{-19.999999, 1.*^-6}], PointBox[{-14.999999, -4.999999}], 
   PointBox[{-14.999999, -4.999999}], PointBox[{-14.999999, 1.*^-6}], 
   PointBox[{-19.999999, 1.*^-6}], PointBox[{-19.999999, 1.*^-6}], 
   PointBox[{-19.999999, 5.000001}], PointBox[{-14.999999, 1.*^-6}], 
   PointBox[{-14.999999, 1.*^-6}], PointBox[{-14.999999, 5.000001}], 
   PointBox[{-19.999999, 5.000001}], PointBox[{-19.999999, 5.000001}], 
   PointBox[{-19.999999, 10.000001}], PointBox[{-14.999999, 5.000001}], 
   PointBox[{-14.999999, 5.000001}], PointBox[{-14.999999, 10.000001}], 
   PointBox[{-19.999999, 10.000001}], PointBox[{-19.999999, 10.000001}], 
   PointBox[{-19.999999, 15.000001}], PointBox[{-14.999999, 10.000001}], 
   PointBox[{-14.999999, 10.000001}], PointBox[{-14.999999, 15.000001}], 
   PointBox[{-19.999999, 15.000001}], PointBox[{-19.999999, 15.000001}], 
   PointBox[{-19.999999, 20.000001}], PointBox[{-14.999999, 15.000001}], 
   PointBox[{-14.999999, 15.000001}], PointBox[{-14.999999, 20.000001}], 
   PointBox[{-19.999999, 20.000001}], PointBox[{-19.999999, 20.000001}], 
   PointBox[{-19.999999, 25.000001}], PointBox[{-14.999999, 20.000001}], 
   PointBox[{-14.999999, 20.000001}], PointBox[{-14.999999, 25.000001}], 
   PointBox[{-19.999999, 25.000001}], PointBox[{-14.999999, -24.999999}], 
   PointBox[{-14.999999, -19.999999}], PointBox[{-9.999999, -24.999999}], 
   PointBox[{-9.999999, -24.999999}], PointBox[{-9.999999, -19.999999}], 
   PointBox[{-14.999999, -19.999999}], PointBox[{-14.999999, -19.999999}], 
   PointBox[{-14.999999, -14.999999}], PointBox[{-9.999999, -19.999999}], 
   PointBox[{-9.999999, -19.999999}], PointBox[{-9.999999, -14.999999}], 
   PointBox[{-14.999999, -14.999999}], PointBox[{-14.999999, -14.999999}], 
   PointBox[{-14.999999, -9.999999}], PointBox[{-9.999999, -14.999999}], 
   PointBox[{-9.999999, -14.999999}], PointBox[{-9.999999, -9.999999}], 
   PointBox[{-14.999999, -9.999999}], PointBox[{-14.999999, -9.999999}], 
   PointBox[{-14.999999, -4.999999}], PointBox[{-9.999999, -9.999999}], 
   PointBox[{-9.999999, -9.999999}], PointBox[{-9.999999, -4.999999}], 
   PointBox[{-14.999999, -4.999999}], PointBox[{-14.999999, -4.999999}], 
   PointBox[{-14.999999, 1.*^-6}], PointBox[{-9.999999, -4.999999}], 
   PointBox[{-9.999999, -4.999999}], PointBox[{-9.999999, 1.*^-6}], 
   PointBox[{-14.999999, 1.*^-6}], PointBox[{-14.999999, 1.*^-6}], 
   PointBox[{-14.999999, 5.000001}], PointBox[{-9.999999, 1.*^-6}], 
   PointBox[{-9.999999, 1.*^-6}], PointBox[{-9.999999, 5.000001}], 
   PointBox[{-14.999999, 5.000001}], PointBox[{-14.999999, 5.000001}], 
   PointBox[{-14.999999, 10.000001}], PointBox[{-9.999999, 5.000001}], 
   PointBox[{-9.999999, 5.000001}], PointBox[{-9.999999, 10.000001}], 
   PointBox[{-14.999999, 10.000001}], PointBox[{-14.999999, 10.000001}], 
   PointBox[{-14.999999, 15.000001}], PointBox[{-9.999999, 10.000001}], 
   PointBox[{-9.999999, 10.000001}], PointBox[{-9.999999, 15.000001}], 
   PointBox[{-14.999999, 15.000001}], PointBox[{-14.999999, 15.000001}], 
   PointBox[{-14.999999, 20.000001}], PointBox[{-9.999999, 15.000001}], 
   PointBox[{-9.999999, 15.000001}], PointBox[{-9.999999, 20.000001}], 
   PointBox[{-14.999999, 20.000001}], PointBox[{-14.999999, 20.000001}], 
   PointBox[{-14.999999, 25.000001}], PointBox[{-9.999999, 20.000001}], 
   PointBox[{-9.999999, 20.000001}], PointBox[{-9.999999, 25.000001}], 
   PointBox[{-14.999999, 25.000001}], PointBox[{-9.999999, -24.999999}], 
   PointBox[{-9.999999, -19.999999}], PointBox[{-4.999999, -24.999999}], 
   PointBox[{-4.999999, -24.999999}], PointBox[{-4.999999, -19.999999}], 
   PointBox[{-9.999999, -19.999999}], PointBox[{-9.999999, -19.999999}], 
   PointBox[{-9.999999, -14.999999}], PointBox[{-4.999999, -19.999999}], 
   PointBox[{-4.999999, -19.999999}], PointBox[{-4.999999, -14.999999}], 
   PointBox[{-9.999999, -14.999999}], PointBox[{-9.999999, -14.999999}], 
   PointBox[{-9.999999, -9.999999}], PointBox[{-4.999999, -14.999999}], 
   PointBox[{-4.999999, -14.999999}], PointBox[{-4.999999, -9.999999}], 
   PointBox[{-9.999999, -9.999999}], PointBox[{-9.999999, -9.999999}], 
   PointBox[{-9.999999, -4.999999}], PointBox[{-4.999999, -9.999999}], 
   PointBox[{-4.999999, -9.999999}], PointBox[{-4.999999, -4.999999}], 
   PointBox[{-9.999999, -4.999999}], PointBox[{-9.999999, -4.999999}], 
   PointBox[{-9.999999, 1.*^-6}], PointBox[{-4.999999, -4.999999}], 
   PointBox[{-4.999999, -4.999999}], PointBox[{-4.999999, 1.*^-6}], 
   PointBox[{-9.999999, 1.*^-6}], PointBox[{-9.999999, 1.*^-6}], 
   PointBox[{-9.999999, 5.000001}], PointBox[{-4.999999, 1.*^-6}], 
   PointBox[{-4.999999, 1.*^-6}], PointBox[{-4.999999, 5.000001}], 
   PointBox[{-9.999999, 5.000001}], PointBox[{-9.999999, 5.000001}], 
   PointBox[{-9.999999, 10.000001}], PointBox[{-4.999999, 5.000001}], 
   PointBox[{-4.999999, 5.000001}], PointBox[{-4.999999, 10.000001}], 
   PointBox[{-9.999999, 10.000001}], PointBox[{-9.999999, 10.000001}], 
   PointBox[{-9.999999, 15.000001}], PointBox[{-4.999999, 10.000001}], 
   PointBox[{-4.999999, 10.000001}], PointBox[{-4.999999, 15.000001}], 
   PointBox[{-9.999999, 15.000001}], PointBox[{-9.999999, 15.000001}], 
   PointBox[{-9.999999, 20.000001}], PointBox[{-4.999999, 15.000001}], 
   PointBox[{-4.999999, 15.000001}], PointBox[{-4.999999, 20.000001}], 
   PointBox[{-9.999999, 20.000001}], PointBox[{-9.999999, 20.000001}], 
   PointBox[{-9.999999, 25.000001}], PointBox[{-4.999999, 20.000001}], 
   PointBox[{-4.999999, 20.000001}], PointBox[{-4.999999, 25.000001}], 
   PointBox[{-9.999999, 25.000001}], PointBox[{-4.999999, -24.999999}], 
   PointBox[{-4.999999, -19.999999}], PointBox[{1.*^-6, -24.999999}], 
   PointBox[{1.*^-6, -24.999999}], PointBox[{1.*^-6, -19.999999}], 
   PointBox[{-4.999999, -19.999999}], PointBox[{-4.999999, -19.999999}], 
   PointBox[{-4.999999, -14.999999}], PointBox[{1.*^-6, -19.999999}], 
   PointBox[{1.*^-6, -19.999999}], PointBox[{1.*^-6, -14.999999}], 
   PointBox[{-4.999999, -14.999999}], PointBox[{-4.999999, -14.999999}], 
   PointBox[{-4.999999, -9.999999}], PointBox[{1.*^-6, -14.999999}], 
   PointBox[{1.*^-6, -14.999999}], PointBox[{1.*^-6, -9.999999}], 
   PointBox[{-4.999999, -9.999999}], PointBox[{-4.999999, -9.999999}], 
   PointBox[{-4.999999, -4.999999}], PointBox[{1.*^-6, -9.999999}], 
   PointBox[{1.*^-6, -9.999999}], PointBox[{1.*^-6, -4.999999}], 
   PointBox[{-4.999999, -4.999999}], PointBox[{-4.999999, -4.999999}], 
   PointBox[{-4.999999, 1.*^-6}], PointBox[{1.*^-6, -4.999999}], 
   PointBox[{1.*^-6, -4.999999}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-4.999999, 1.*^-6}], PointBox[{-4.999999, 1.*^-6}], 
   PointBox[{-4.999999, 5.000001}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{1.*^-6, 1.*^-6}], PointBox[{1.*^-6, 5.000001}], 
   PointBox[{-4.999999, 5.000001}], PointBox[{-4.999999, 5.000001}], 
   PointBox[{-4.999999, 10.000001}], PointBox[{1.*^-6, 5.000001}], 
   PointBox[{1.*^-6, 5.000001}], PointBox[{1.*^-6, 10.000001}], 
   PointBox[{-4.999999, 10.000001}], PointBox[{-4.999999, 10.000001}], 
   PointBox[{-4.999999, 15.000001}], PointBox[{1.*^-6, 10.000001}], 
   PointBox[{1.*^-6, 10.000001}], PointBox[{1.*^-6, 15.000001}], 
   PointBox[{-4.999999, 15.000001}], PointBox[{-4.999999, 15.000001}], 
   PointBox[{-4.999999, 20.000001}], PointBox[{1.*^-6, 15.000001}], 
   PointBox[{1.*^-6, 15.000001}], PointBox[{1.*^-6, 20.000001}], 
   PointBox[{-4.999999, 20.000001}], PointBox[{-4.999999, 20.000001}], 
   PointBox[{-4.999999, 25.000001}], PointBox[{1.*^-6, 20.000001}], 
   PointBox[{1.*^-6, 20.000001}], PointBox[{1.*^-6, 25.000001}], 
   PointBox[{-4.999999, 25.000001}], PointBox[{1.*^-6, -24.999999}], 
   PointBox[{1.*^-6, -19.999999}], PointBox[{5.000001, -24.999999}], 
   PointBox[{5.000001, -24.999999}], PointBox[{5.000001, -19.999999}], 
   PointBox[{1.*^-6, -19.999999}], PointBox[{1.*^-6, -19.999999}], 
   PointBox[{1.*^-6, -14.999999}], PointBox[{5.000001, -19.999999}], 
   PointBox[{5.000001, -19.999999}], PointBox[{5.000001, -14.999999}], 
   PointBox[{1.*^-6, -14.999999}], PointBox[{1.*^-6, -14.999999}], 
   PointBox[{1.*^-6, -9.999999}], PointBox[{5.000001, -14.999999}], 
   PointBox[{5.000001, -14.999999}], PointBox[{5.000001, -9.999999}], 
   PointBox[{1.*^-6, -9.999999}], PointBox[{1.*^-6, -9.999999}], 
   PointBox[{1.*^-6, -4.999999}], PointBox[{5.000001, -9.999999}], 
   PointBox[{5.000001, -9.999999}], PointBox[{5.000001, -4.999999}], 
   PointBox[{1.*^-6, -4.999999}], PointBox[{1.*^-6, -4.999999}], 
   PointBox[{1.*^-6, 1.*^-6}], PointBox[{5.000001, -4.999999}], 
   PointBox[{5.000001, -4.999999}], PointBox[{5.000001, 1.*^-6}], 
   PointBox[{1.*^-6, 1.*^-6}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{1.*^-6, 5.000001}], PointBox[{5.000001, 1.*^-6}], 
   PointBox[{5.000001, 1.*^-6}], PointBox[{5.000001, 5.000001}], 
   PointBox[{1.*^-6, 5.000001}], PointBox[{1.*^-6, 5.000001}], 
   PointBox[{1.*^-6, 10.000001}], PointBox[{5.000001, 5.000001}], 
   PointBox[{5.000001, 5.000001}], PointBox[{5.000001, 10.000001}], 
   PointBox[{1.*^-6, 10.000001}], PointBox[{1.*^-6, 10.000001}], 
   PointBox[{1.*^-6, 15.000001}], PointBox[{5.000001, 10.000001}], 
   PointBox[{5.000001, 10.000001}], PointBox[{5.000001, 15.000001}], 
   PointBox[{1.*^-6, 15.000001}], PointBox[{1.*^-6, 15.000001}], 
   PointBox[{1.*^-6, 20.000001}], PointBox[{5.000001, 15.000001}], 
   PointBox[{5.000001, 15.000001}], PointBox[{5.000001, 20.000001}], 
   PointBox[{1.*^-6, 20.000001}], PointBox[{1.*^-6, 20.000001}], 
   PointBox[{1.*^-6, 25.000001}], PointBox[{5.000001, 20.000001}], 
   PointBox[{5.000001, 20.000001}], PointBox[{5.000001, 25.000001}], 
   PointBox[{1.*^-6, 25.000001}], PointBox[{5.000001, -24.999999}], 
   PointBox[{5.000001, -19.999999}], PointBox[{10.000001, -24.999999}], 
   PointBox[{10.000001, -24.999999}], PointBox[{10.000001, -19.999999}], 
   PointBox[{5.000001, -19.999999}], PointBox[{5.000001, -19.999999}], 
   PointBox[{5.000001, -14.999999}], PointBox[{10.000001, -19.999999}], 
   PointBox[{10.000001, -19.999999}], PointBox[{10.000001, -14.999999}], 
   PointBox[{5.000001, -14.999999}], PointBox[{5.000001, -14.999999}], 
   PointBox[{5.000001, -9.999999}], PointBox[{10.000001, -14.999999}], 
   PointBox[{10.000001, -14.999999}], PointBox[{10.000001, -9.999999}], 
   PointBox[{5.000001, -9.999999}], PointBox[{5.000001, -9.999999}], 
   PointBox[{5.000001, -4.999999}], PointBox[{10.000001, -9.999999}], 
   PointBox[{10.000001, -9.999999}], PointBox[{10.000001, -4.999999}], 
   PointBox[{5.000001, -4.999999}], PointBox[{5.000001, -4.999999}], 
   PointBox[{5.000001, 1.*^-6}], PointBox[{10.000001, -4.999999}], 
   PointBox[{10.000001, -4.999999}], PointBox[{10.000001, 1.*^-6}], 
   PointBox[{5.000001, 1.*^-6}], PointBox[{5.000001, 1.*^-6}], 
   PointBox[{5.000001, 5.000001}], PointBox[{10.000001, 1.*^-6}], 
   PointBox[{10.000001, 1.*^-6}], PointBox[{10.000001, 5.000001}], 
   PointBox[{5.000001, 5.000001}], PointBox[{5.000001, 5.000001}], 
   PointBox[{5.000001, 10.000001}], PointBox[{10.000001, 5.000001}], 
   PointBox[{10.000001, 5.000001}], PointBox[{10.000001, 10.000001}], 
   PointBox[{5.000001, 10.000001}], PointBox[{5.000001, 10.000001}], 
   PointBox[{5.000001, 15.000001}], PointBox[{10.000001, 10.000001}], 
   PointBox[{10.000001, 10.000001}], PointBox[{10.000001, 15.000001}], 
   PointBox[{5.000001, 15.000001}], PointBox[{5.000001, 15.000001}], 
   PointBox[{5.000001, 20.000001}], PointBox[{10.000001, 15.000001}], 
   PointBox[{10.000001, 15.000001}], PointBox[{10.000001, 20.000001}], 
   PointBox[{5.000001, 20.000001}], PointBox[{5.000001, 20.000001}], 
   PointBox[{5.000001, 25.000001}], PointBox[{10.000001, 20.000001}], 
   PointBox[{10.000001, 20.000001}], PointBox[{10.000001, 25.000001}], 
   PointBox[{5.000001, 25.000001}], PointBox[{10.000001, -24.999999}], 
   PointBox[{10.000001, -19.999999}], PointBox[{15.000001, -24.999999}], 
   PointBox[{15.000001, -24.999999}], PointBox[{15.000001, -19.999999}], 
   PointBox[{10.000001, -19.999999}], PointBox[{10.000001, -19.999999}], 
   PointBox[{10.000001, -14.999999}], PointBox[{15.000001, -19.999999}], 
   PointBox[{15.000001, -19.999999}], PointBox[{15.000001, -14.999999}], 
   PointBox[{10.000001, -14.999999}], PointBox[{10.000001, -14.999999}], 
   PointBox[{10.000001, -9.999999}], PointBox[{15.000001, -14.999999}], 
   PointBox[{15.000001, -14.999999}], PointBox[{15.000001, -9.999999}], 
   PointBox[{10.000001, -9.999999}], PointBox[{10.000001, -9.999999}], 
   PointBox[{10.000001, -4.999999}], PointBox[{15.000001, -9.999999}], 
   PointBox[{15.000001, -9.999999}], PointBox[{15.000001, -4.999999}], 
   PointBox[{10.000001, -4.999999}], PointBox[{10.000001, -4.999999}], 
   PointBox[{10.000001, 1.*^-6}], PointBox[{15.000001, -4.999999}], 
   PointBox[{15.000001, -4.999999}], PointBox[{15.000001, 1.*^-6}], 
   PointBox[{10.000001, 1.*^-6}], PointBox[{10.000001, 1.*^-6}], 
   PointBox[{10.000001, 5.000001}], PointBox[{15.000001, 1.*^-6}], 
   PointBox[{15.000001, 1.*^-6}], PointBox[{15.000001, 5.000001}], 
   PointBox[{10.000001, 5.000001}], PointBox[{10.000001, 5.000001}], 
   PointBox[{10.000001, 10.000001}], PointBox[{15.000001, 5.000001}], 
   PointBox[{15.000001, 5.000001}], PointBox[{15.000001, 10.000001}], 
   PointBox[{10.000001, 10.000001}], PointBox[{10.000001, 10.000001}], 
   PointBox[{10.000001, 15.000001}], PointBox[{15.000001, 10.000001}], 
   PointBox[{15.000001, 10.000001}], PointBox[{15.000001, 15.000001}], 
   PointBox[{10.000001, 15.000001}], PointBox[{10.000001, 15.000001}], 
   PointBox[{10.000001, 20.000001}], PointBox[{15.000001, 15.000001}], 
   PointBox[{15.000001, 15.000001}], PointBox[{15.000001, 20.000001}], 
   PointBox[{10.000001, 20.000001}], PointBox[{10.000001, 20.000001}], 
   PointBox[{10.000001, 25.000001}], PointBox[{15.000001, 20.000001}], 
   PointBox[{15.000001, 20.000001}], PointBox[{15.000001, 25.000001}], 
   PointBox[{10.000001, 25.000001}], PointBox[{15.000001, -24.999999}], 
   PointBox[{15.000001, -19.999999}], PointBox[{20.000001, -24.999999}], 
   PointBox[{20.000001, -24.999999}], PointBox[{20.000001, -19.999999}], 
   PointBox[{15.000001, -19.999999}], PointBox[{15.000001, -19.999999}], 
   PointBox[{15.000001, -14.999999}], PointBox[{20.000001, -19.999999}], 
   PointBox[{20.000001, -19.999999}], PointBox[{20.000001, -14.999999}], 
   PointBox[{15.000001, -14.999999}], PointBox[{15.000001, -14.999999}], 
   PointBox[{15.000001, -9.999999}], PointBox[{20.000001, -14.999999}], 
   PointBox[{20.000001, -14.999999}], PointBox[{20.000001, -9.999999}], 
   PointBox[{15.000001, -9.999999}], PointBox[{15.000001, -9.999999}], 
   PointBox[{15.000001, -4.999999}], PointBox[{20.000001, -9.999999}], 
   PointBox[{20.000001, -9.999999}], PointBox[{20.000001, -4.999999}], 
   PointBox[{15.000001, -4.999999}], PointBox[{15.000001, -4.999999}], 
   PointBox[{15.000001, 1.*^-6}], PointBox[{20.000001, -4.999999}], 
   PointBox[{20.000001, -4.999999}], PointBox[{20.000001, 1.*^-6}], 
   PointBox[{15.000001, 1.*^-6}], PointBox[{15.000001, 1.*^-6}], 
   PointBox[{15.000001, 5.000001}], PointBox[{20.000001, 1.*^-6}], 
   PointBox[{20.000001, 1.*^-6}], PointBox[{20.000001, 5.000001}], 
   PointBox[{15.000001, 5.000001}], PointBox[{15.000001, 5.000001}], 
   PointBox[{15.000001, 10.000001}], PointBox[{20.000001, 5.000001}], 
   PointBox[{20.000001, 5.000001}], PointBox[{20.000001, 10.000001}], 
   PointBox[{15.000001, 10.000001}], PointBox[{15.000001, 10.000001}], 
   PointBox[{15.000001, 15.000001}], PointBox[{20.000001, 10.000001}], 
   PointBox[{20.000001, 10.000001}], PointBox[{20.000001, 15.000001}], 
   PointBox[{15.000001, 15.000001}], PointBox[{15.000001, 15.000001}], 
   PointBox[{15.000001, 20.000001}], PointBox[{20.000001, 15.000001}], 
   PointBox[{20.000001, 15.000001}], PointBox[{20.000001, 20.000001}], 
   PointBox[{15.000001, 20.000001}], PointBox[{15.000001, 20.000001}], 
   PointBox[{15.000001, 25.000001}], PointBox[{20.000001, 20.000001}], 
   PointBox[{20.000001, 20.000001}], PointBox[{20.000001, 25.000001}], 
   PointBox[{15.000001, 25.000001}], PointBox[{20.000001, -24.999999}], 
   PointBox[{20.000001, -19.999999}], PointBox[{25.000001, -24.999999}], 
   PointBox[{25.000001, -24.999999}], PointBox[{25.000001, -19.999999}], 
   PointBox[{20.000001, -19.999999}], PointBox[{20.000001, -19.999999}], 
   PointBox[{20.000001, -14.999999}], PointBox[{25.000001, -19.999999}], 
   PointBox[{25.000001, -19.999999}], PointBox[{25.000001, -14.999999}], 
   PointBox[{20.000001, -14.999999}], PointBox[{20.000001, -14.999999}], 
   PointBox[{20.000001, -9.999999}], PointBox[{25.000001, -14.999999}], 
   PointBox[{25.000001, -14.999999}], PointBox[{25.000001, -9.999999}], 
   PointBox[{20.000001, -9.999999}], PointBox[{20.000001, -9.999999}], 
   PointBox[{20.000001, -4.999999}], PointBox[{25.000001, -9.999999}], 
   PointBox[{25.000001, -9.999999}], PointBox[{25.000001, -4.999999}], 
   PointBox[{20.000001, -4.999999}], PointBox[{20.000001, -4.999999}], 
   PointBox[{20.000001, 1.*^-6}], PointBox[{25.000001, -4.999999}], 
   PointBox[{25.000001, -4.999999}], PointBox[{25.000001, 1.*^-6}], 
   PointBox[{20.000001, 1.*^-6}], PointBox[{20.000001, 1.*^-6}], 
   PointBox[{20.000001, 5.000001}], PointBox[{25.000001, 1.*^-6}], 
   PointBox[{25.000001, 1.*^-6}], PointBox[{25.000001, 5.000001}], 
   PointBox[{20.000001, 5.000001}], PointBox[{20.000001, 5.000001}], 
   PointBox[{20.000001, 10.000001}], PointBox[{25.000001, 5.000001}], 
   PointBox[{25.000001, 5.000001}], PointBox[{25.000001, 10.000001}], 
   PointBox[{20.000001, 10.000001}], PointBox[{20.000001, 10.000001}], 
   PointBox[{20.000001, 15.000001}], PointBox[{25.000001, 10.000001}], 
   PointBox[{25.000001, 10.000001}], PointBox[{25.000001, 15.000001}], 
   PointBox[{20.000001, 15.000001}], PointBox[{20.000001, 15.000001}], 
   PointBox[{20.000001, 20.000001}], PointBox[{25.000001, 15.000001}], 
   PointBox[{25.000001, 15.000001}], PointBox[{25.000001, 20.000001}], 
   PointBox[{20.000001, 20.000001}], PointBox[{20.000001, 20.000001}], 
   PointBox[{20.000001, 25.000001}], PointBox[{25.000001, 20.000001}], 
   PointBox[{25.000001, 20.000001}], PointBox[{25.000001, 25.000001}], 
   PointBox[{20.000001, 25.000001}], 
   LineBox[{{-24.999999, -24.999999}, {-24.999999, -19.999999}, {-19.999999, \
-24.999999}, {-24.999999, -24.999999}}], 
   LineBox[{{-19.999999, -24.999999}, {-19.999999, -19.999999}, {-24.999999, \
-19.999999}, {-19.999999, -24.999999}}], 
   LineBox[{{-24.999999, -19.999999}, {-24.999999, -14.999999}, {-19.999999, \
-19.999999}, {-24.999999, -19.999999}}], 
   LineBox[{{-19.999999, -19.999999}, {-19.999999, -14.999999}, {-24.999999, \
-14.999999}, {-19.999999, -19.999999}}], 
   LineBox[{{-24.999999, -14.999999}, {-24.999999, -9.999999}, {-19.999999, \
-14.999999}, {-24.999999, -14.999999}}], 
   LineBox[{{-19.999999, -14.999999}, {-19.999999, -9.999999}, {-24.999999, \
-9.999999}, {-19.999999, -14.999999}}], 
   LineBox[{{-24.999999, -9.999999}, {-24.999999, -4.999999}, {-19.999999, \
-9.999999}, {-24.999999, -9.999999}}], 
   LineBox[{{-19.999999, -9.999999}, {-19.999999, -4.999999}, {-24.999999, \
-4.999999}, {-19.999999, -9.999999}}], 
   LineBox[{{-24.999999, -4.999999}, {-24.999999, 
    1.*^-6}, {-19.999999, -4.999999}, {-24.999999, -4.999999}}], 
   LineBox[{{-19.999999, -4.999999}, {-19.999999, 1.*^-6}, {-24.999999, 
    1.*^-6}, {-19.999999, -4.999999}}], 
   LineBox[{{-24.999999, 1.*^-6}, {-24.999999, 5.000001}, {-19.999999, 
    1.*^-6}, {-24.999999, 1.*^-6}}], 
   LineBox[{{-19.999999, 1.*^-6}, {-19.999999, 5.000001}, {-24.999999, 
    5.000001}, {-19.999999, 1.*^-6}}], 
   LineBox[{{-24.999999, 5.000001}, {-24.999999, 10.000001}, {-19.999999, 
    5.000001}, {-24.999999, 5.000001}}], 
   LineBox[{{-19.999999, 5.000001}, {-19.999999, 10.000001}, {-24.999999, 
    10.000001}, {-19.999999, 5.000001}}], 
   LineBox[{{-24.999999, 10.000001}, {-24.999999, 15.000001}, {-19.999999, 
    10.000001}, {-24.999999, 10.000001}}], 
   LineBox[{{-19.999999, 10.000001}, {-19.999999, 15.000001}, {-24.999999, 
    15.000001}, {-19.999999, 10.000001}}], 
   LineBox[{{-24.999999, 15.000001}, {-24.999999, 20.000001}, {-19.999999, 
    15.000001}, {-24.999999, 15.000001}}], 
   LineBox[{{-19.999999, 15.000001}, {-19.999999, 20.000001}, {-24.999999, 
    20.000001}, {-19.999999, 15.000001}}], 
   LineBox[{{-24.999999, 20.000001}, {-24.999999, 25.000001}, {-19.999999, 
    20.000001}, {-24.999999, 20.000001}}], 
   LineBox[{{-19.999999, 20.000001}, {-19.999999, 25.000001}, {-24.999999, 
    25.000001}, {-19.999999, 20.000001}}], 
   LineBox[{{-19.999999, -24.999999}, {-19.999999, -19.999999}, {-14.999999, \
-24.999999}, {-19.999999, -24.999999}}], 
   LineBox[{{-14.999999, -24.999999}, {-14.999999, -19.999999}, {-19.999999, \
-19.999999}, {-14.999999, -24.999999}}], 
   LineBox[{{-19.999999, -19.999999}, {-19.999999, -14.999999}, {-14.999999, \
-19.999999}, {-19.999999, -19.999999}}], 
   LineBox[{{-14.999999, -19.999999}, {-14.999999, -14.999999}, {-19.999999, \
-14.999999}, {-14.999999, -19.999999}}], 
   LineBox[{{-19.999999, -14.999999}, {-19.999999, -9.999999}, {-14.999999, \
-14.999999}, {-19.999999, -14.999999}}], 
   LineBox[{{-14.999999, -14.999999}, {-14.999999, -9.999999}, {-19.999999, \
-9.999999}, {-14.999999, -14.999999}}], 
   LineBox[{{-19.999999, -9.999999}, {-19.999999, -4.999999}, {-14.999999, \
-9.999999}, {-19.999999, -9.999999}}], 
   LineBox[{{-14.999999, -9.999999}, {-14.999999, -4.999999}, {-19.999999, \
-4.999999}, {-14.999999, -9.999999}}], 
   LineBox[{{-19.999999, -4.999999}, {-19.999999, 
    1.*^-6}, {-14.999999, -4.999999}, {-19.999999, -4.999999}}], 
   LineBox[{{-14.999999, -4.999999}, {-14.999999, 1.*^-6}, {-19.999999, 
    1.*^-6}, {-14.999999, -4.999999}}], 
   LineBox[{{-19.999999, 1.*^-6}, {-19.999999, 5.000001}, {-14.999999, 
    1.*^-6}, {-19.999999, 1.*^-6}}], 
   LineBox[{{-14.999999, 1.*^-6}, {-14.999999, 5.000001}, {-19.999999, 
    5.000001}, {-14.999999, 1.*^-6}}], 
   LineBox[{{-19.999999, 5.000001}, {-19.999999, 10.000001}, {-14.999999, 
    5.000001}, {-19.999999, 5.000001}}], 
   LineBox[{{-14.999999, 5.000001}, {-14.999999, 10.000001}, {-19.999999, 
    10.000001}, {-14.999999, 5.000001}}], 
   LineBox[{{-19.999999, 10.000001}, {-19.999999, 15.000001}, {-14.999999, 
    10.000001}, {-19.999999, 10.000001}}], 
   LineBox[{{-14.999999, 10.000001}, {-14.999999, 15.000001}, {-19.999999, 
    15.000001}, {-14.999999, 10.000001}}], 
   LineBox[{{-19.999999, 15.000001}, {-19.999999, 20.000001}, {-14.999999, 
    15.000001}, {-19.999999, 15.000001}}], 
   LineBox[{{-14.999999, 15.000001}, {-14.999999, 20.000001}, {-19.999999, 
    20.000001}, {-14.999999, 15.000001}}], 
   LineBox[{{-19.999999, 20.000001}, {-19.999999, 25.000001}, {-14.999999, 
    20.000001}, {-19.999999, 20.000001}}], 
   LineBox[{{-14.999999, 20.000001}, {-14.999999, 25.000001}, {-19.999999, 
    25.000001}, {-14.999999, 20.000001}}], 
   LineBox[{{-14.999999, -24.999999}, {-14.999999, -19.999999}, {-9.999999, \
-24.999999}, {-14.999999, -24.999999}}], 
   LineBox[{{-9.999999, -24.999999}, {-9.999999, -19.999999}, {-14.999999, \
-19.999999}, {-9.999999, -24.999999}}], 
   LineBox[{{-14.999999, -19.999999}, {-14.999999, -14.999999}, {-9.999999, \
-19.999999}, {-14.999999, -19.999999}}], 
   LineBox[{{-9.999999, -19.999999}, {-9.999999, -14.999999}, {-14.999999, \
-14.999999}, {-9.999999, -19.999999}}], 
   LineBox[{{-14.999999, -14.999999}, {-14.999999, -9.999999}, {-9.999999, \
-14.999999}, {-14.999999, -14.999999}}], 
   LineBox[{{-9.999999, -14.999999}, {-9.999999, -9.999999}, {-14.999999, \
-9.999999}, {-9.999999, -14.999999}}], 
   LineBox[{{-14.999999, -9.999999}, {-14.999999, -4.999999}, {-9.999999, \
-9.999999}, {-14.999999, -9.999999}}], 
   LineBox[{{-9.999999, -9.999999}, {-9.999999, -4.999999}, {-14.999999, \
-4.999999}, {-9.999999, -9.999999}}], 
   LineBox[{{-14.999999, -4.999999}, {-14.999999, 
    1.*^-6}, {-9.999999, -4.999999}, {-14.999999, -4.999999}}], 
   LineBox[{{-9.999999, -4.999999}, {-9.999999, 1.*^-6}, {-14.999999, 
    1.*^-6}, {-9.999999, -4.999999}}], 
   LineBox[{{-14.999999, 1.*^-6}, {-14.999999, 5.000001}, {-9.999999, 
    1.*^-6}, {-14.999999, 1.*^-6}}], 
   LineBox[{{-9.999999, 1.*^-6}, {-9.999999, 5.000001}, {-14.999999, 
    5.000001}, {-9.999999, 1.*^-6}}], 
   LineBox[{{-14.999999, 5.000001}, {-14.999999, 10.000001}, {-9.999999, 
    5.000001}, {-14.999999, 5.000001}}], 
   LineBox[{{-9.999999, 5.000001}, {-9.999999, 10.000001}, {-14.999999, 
    10.000001}, {-9.999999, 5.000001}}], 
   LineBox[{{-14.999999, 10.000001}, {-14.999999, 15.000001}, {-9.999999, 
    10.000001}, {-14.999999, 10.000001}}], 
   LineBox[{{-9.999999, 10.000001}, {-9.999999, 15.000001}, {-14.999999, 
    15.000001}, {-9.999999, 10.000001}}], 
   LineBox[{{-14.999999, 15.000001}, {-14.999999, 20.000001}, {-9.999999, 
    15.000001}, {-14.999999, 15.000001}}], 
   LineBox[{{-9.999999, 15.000001}, {-9.999999, 20.000001}, {-14.999999, 
    20.000001}, {-9.999999, 15.000001}}], 
   LineBox[{{-14.999999, 20.000001}, {-14.999999, 25.000001}, {-9.999999, 
    20.000001}, {-14.999999, 20.000001}}], 
   LineBox[{{-9.999999, 20.000001}, {-9.999999, 25.000001}, {-14.999999, 
    25.000001}, {-9.999999, 20.000001}}], 
   LineBox[{{-9.999999, -24.999999}, {-9.999999, -19.999999}, {-4.999999, \
-24.999999}, {-9.999999, -24.999999}}], 
   LineBox[{{-4.999999, -24.999999}, {-4.999999, -19.999999}, {-9.999999, \
-19.999999}, {-4.999999, -24.999999}}], 
   LineBox[{{-9.999999, -19.999999}, {-9.999999, -14.999999}, {-4.999999, \
-19.999999}, {-9.999999, -19.999999}}], 
   LineBox[{{-4.999999, -19.999999}, {-4.999999, -14.999999}, {-9.999999, \
-14.999999}, {-4.999999, -19.999999}}], 
   LineBox[{{-9.999999, -14.999999}, {-9.999999, -9.999999}, {-4.999999, \
-14.999999}, {-9.999999, -14.999999}}], 
   LineBox[{{-4.999999, -14.999999}, {-4.999999, -9.999999}, {-9.999999, \
-9.999999}, {-4.999999, -14.999999}}], 
   LineBox[{{-9.999999, -9.999999}, {-9.999999, -4.999999}, {-4.999999, \
-9.999999}, {-9.999999, -9.999999}}], 
   LineBox[{{-4.999999, -9.999999}, {-4.999999, -4.999999}, {-9.999999, \
-4.999999}, {-4.999999, -9.999999}}], 
   LineBox[{{-9.999999, -4.999999}, {-9.999999, 
    1.*^-6}, {-4.999999, -4.999999}, {-9.999999, -4.999999}}], 
   LineBox[{{-4.999999, -4.999999}, {-4.999999, 1.*^-6}, {-9.999999, 
    1.*^-6}, {-4.999999, -4.999999}}], 
   LineBox[{{-9.999999, 1.*^-6}, {-9.999999, 5.000001}, {-4.999999, 
    1.*^-6}, {-9.999999, 1.*^-6}}], 
   LineBox[{{-4.999999, 1.*^-6}, {-4.999999, 5.000001}, {-9.999999, 
    5.000001}, {-4.999999, 1.*^-6}}], 
   LineBox[{{-9.999999, 5.000001}, {-9.999999, 10.000001}, {-4.999999, 
    5.000001}, {-9.999999, 5.000001}}], 
   LineBox[{{-4.999999, 5.000001}, {-4.999999, 10.000001}, {-9.999999, 
    10.000001}, {-4.999999, 5.000001}}], 
   LineBox[{{-9.999999, 10.000001}, {-9.999999, 15.000001}, {-4.999999, 
    10.000001}, {-9.999999, 10.000001}}], 
   LineBox[{{-4.999999, 10.000001}, {-4.999999, 15.000001}, {-9.999999, 
    15.000001}, {-4.999999, 10.000001}}], 
   LineBox[{{-9.999999, 15.000001}, {-9.999999, 20.000001}, {-4.999999, 
    15.000001}, {-9.999999, 15.000001}}], 
   LineBox[{{-4.999999, 15.000001}, {-4.999999, 20.000001}, {-9.999999, 
    20.000001}, {-4.999999, 15.000001}}], 
   LineBox[{{-9.999999, 20.000001}, {-9.999999, 25.000001}, {-4.999999, 
    20.000001}, {-9.999999, 20.000001}}], 
   LineBox[{{-4.999999, 20.000001}, {-4.999999, 25.000001}, {-9.999999, 
    25.000001}, {-4.999999, 20.000001}}], 
   LineBox[{{-4.999999, -24.999999}, {-4.999999, -19.999999}, {
    1.*^-6, -24.999999}, {-4.999999, -24.999999}}], 
   LineBox[{{1.*^-6, -24.999999}, {
    1.*^-6, -19.999999}, {-4.999999, -19.999999}, {1.*^-6, -24.999999}}], 
   LineBox[{{-4.999999, -19.999999}, {-4.999999, -14.999999}, {
    1.*^-6, -19.999999}, {-4.999999, -19.999999}}], 
   LineBox[{{1.*^-6, -19.999999}, {
    1.*^-6, -14.999999}, {-4.999999, -14.999999}, {1.*^-6, -19.999999}}], 
   LineBox[{{-4.999999, -14.999999}, {-4.999999, -9.999999}, {
    1.*^-6, -14.999999}, {-4.999999, -14.999999}}], 
   LineBox[{{1.*^-6, -14.999999}, {
    1.*^-6, -9.999999}, {-4.999999, -9.999999}, {1.*^-6, -14.999999}}], 
   LineBox[{{-4.999999, -9.999999}, {-4.999999, -4.999999}, {
    1.*^-6, -9.999999}, {-4.999999, -9.999999}}], 
   LineBox[{{1.*^-6, -9.999999}, {
    1.*^-6, -4.999999}, {-4.999999, -4.999999}, {1.*^-6, -9.999999}}], 
   LineBox[{{-4.999999, -4.999999}, {-4.999999, 1.*^-6}, {
    1.*^-6, -4.999999}, {-4.999999, -4.999999}}], 
   LineBox[{{1.*^-6, -4.999999}, {1.*^-6, 1.*^-6}, {-4.999999, 1.*^-6}, {
    1.*^-6, -4.999999}}], 
   LineBox[{{-4.999999, 1.*^-6}, {-4.999999, 5.000001}, {1.*^-6, 
    1.*^-6}, {-4.999999, 1.*^-6}}], 
   LineBox[{{1.*^-6, 1.*^-6}, {1.*^-6, 5.000001}, {-4.999999, 5.000001}, {
    1.*^-6, 1.*^-6}}], 
   LineBox[{{-4.999999, 5.000001}, {-4.999999, 10.000001}, {1.*^-6, 
    5.000001}, {-4.999999, 5.000001}}], 
   LineBox[{{1.*^-6, 5.000001}, {1.*^-6, 10.000001}, {-4.999999, 10.000001}, {
    1.*^-6, 5.000001}}], 
   LineBox[{{-4.999999, 10.000001}, {-4.999999, 15.000001}, {1.*^-6, 
    10.000001}, {-4.999999, 10.000001}}], 
   LineBox[{{1.*^-6, 10.000001}, {1.*^-6, 15.000001}, {-4.999999, 
    15.000001}, {1.*^-6, 10.000001}}], 
   LineBox[{{-4.999999, 15.000001}, {-4.999999, 20.000001}, {1.*^-6, 
    15.000001}, {-4.999999, 15.000001}}], 
   LineBox[{{1.*^-6, 15.000001}, {1.*^-6, 20.000001}, {-4.999999, 
    20.000001}, {1.*^-6, 15.000001}}], 
   LineBox[{{-4.999999, 20.000001}, {-4.999999, 25.000001}, {1.*^-6, 
    20.000001}, {-4.999999, 20.000001}}], 
   LineBox[{{1.*^-6, 20.000001}, {1.*^-6, 25.000001}, {-4.999999, 
    25.000001}, {1.*^-6, 20.000001}}], 
   LineBox[{{1.*^-6, -24.999999}, {1.*^-6, -19.999999}, {
    5.000001, -24.999999}, {1.*^-6, -24.999999}}], 
   LineBox[{{5.000001, -24.999999}, {5.000001, -19.999999}, {
    1.*^-6, -19.999999}, {5.000001, -24.999999}}], 
   LineBox[{{1.*^-6, -19.999999}, {1.*^-6, -14.999999}, {
    5.000001, -19.999999}, {1.*^-6, -19.999999}}], 
   LineBox[{{5.000001, -19.999999}, {5.000001, -14.999999}, {
    1.*^-6, -14.999999}, {5.000001, -19.999999}}], 
   LineBox[{{1.*^-6, -14.999999}, {1.*^-6, -9.999999}, {
    5.000001, -14.999999}, {1.*^-6, -14.999999}}], 
   LineBox[{{5.000001, -14.999999}, {5.000001, -9.999999}, {
    1.*^-6, -9.999999}, {5.000001, -14.999999}}], 
   LineBox[{{1.*^-6, -9.999999}, {1.*^-6, -4.999999}, {5.000001, -9.999999}, {
    1.*^-6, -9.999999}}], 
   LineBox[{{5.000001, -9.999999}, {5.000001, -4.999999}, {
    1.*^-6, -4.999999}, {5.000001, -9.999999}}], 
   LineBox[{{1.*^-6, -4.999999}, {1.*^-6, 1.*^-6}, {5.000001, -4.999999}, {
    1.*^-6, -4.999999}}], 
   LineBox[{{5.000001, -4.999999}, {5.000001, 1.*^-6}, {1.*^-6, 1.*^-6}, {
    5.000001, -4.999999}}], 
   LineBox[{{1.*^-6, 1.*^-6}, {1.*^-6, 5.000001}, {5.000001, 1.*^-6}, {1.*^-6,
     1.*^-6}}], 
   LineBox[{{5.000001, 1.*^-6}, {5.000001, 5.000001}, {1.*^-6, 5.000001}, {
    5.000001, 1.*^-6}}], 
   LineBox[{{1.*^-6, 5.000001}, {1.*^-6, 10.000001}, {5.000001, 5.000001}, {
    1.*^-6, 5.000001}}], 
   LineBox[{{5.000001, 5.000001}, {5.000001, 10.000001}, {1.*^-6, 
    10.000001}, {5.000001, 5.000001}}], 
   LineBox[{{1.*^-6, 10.000001}, {1.*^-6, 15.000001}, {5.000001, 10.000001}, {
    1.*^-6, 10.000001}}], 
   LineBox[{{5.000001, 10.000001}, {5.000001, 15.000001}, {1.*^-6, 
    15.000001}, {5.000001, 10.000001}}], 
   LineBox[{{1.*^-6, 15.000001}, {1.*^-6, 20.000001}, {5.000001, 15.000001}, {
    1.*^-6, 15.000001}}], 
   LineBox[{{5.000001, 15.000001}, {5.000001, 20.000001}, {1.*^-6, 
    20.000001}, {5.000001, 15.000001}}], 
   LineBox[{{1.*^-6, 20.000001}, {1.*^-6, 25.000001}, {5.000001, 20.000001}, {
    1.*^-6, 20.000001}}], 
   LineBox[{{5.000001, 20.000001}, {5.000001, 25.000001}, {1.*^-6, 
    25.000001}, {5.000001, 20.000001}}], 
   LineBox[{{5.000001, -24.999999}, {5.000001, -19.999999}, {
    10.000001, -24.999999}, {5.000001, -24.999999}}], 
   LineBox[{{10.000001, -24.999999}, {10.000001, -19.999999}, {
    5.000001, -19.999999}, {10.000001, -24.999999}}], 
   LineBox[{{5.000001, -19.999999}, {5.000001, -14.999999}, {
    10.000001, -19.999999}, {5.000001, -19.999999}}], 
   LineBox[{{10.000001, -19.999999}, {10.000001, -14.999999}, {
    5.000001, -14.999999}, {10.000001, -19.999999}}], 
   LineBox[{{5.000001, -14.999999}, {5.000001, -9.999999}, {
    10.000001, -14.999999}, {5.000001, -14.999999}}], 
   LineBox[{{10.000001, -14.999999}, {10.000001, -9.999999}, {
    5.000001, -9.999999}, {10.000001, -14.999999}}], 
   LineBox[{{5.000001, -9.999999}, {5.000001, -4.999999}, {
    10.000001, -9.999999}, {5.000001, -9.999999}}], 
   LineBox[{{10.000001, -9.999999}, {10.000001, -4.999999}, {
    5.000001, -4.999999}, {10.000001, -9.999999}}], 
   LineBox[{{5.000001, -4.999999}, {5.000001, 1.*^-6}, {
    10.000001, -4.999999}, {5.000001, -4.999999}}], 
   LineBox[{{10.000001, -4.999999}, {10.000001, 1.*^-6}, {5.000001, 1.*^-6}, {
    10.000001, -4.999999}}], 
   LineBox[{{5.000001, 1.*^-6}, {5.000001, 5.000001}, {10.000001, 1.*^-6}, {
    5.000001, 1.*^-6}}], 
   LineBox[{{10.000001, 1.*^-6}, {10.000001, 5.000001}, {5.000001, 
    5.000001}, {10.000001, 1.*^-6}}], 
   LineBox[{{5.000001, 5.000001}, {5.000001, 10.000001}, {10.000001, 
    5.000001}, {5.000001, 5.000001}}], 
   LineBox[{{10.000001, 5.000001}, {10.000001, 10.000001}, {5.000001, 
    10.000001}, {10.000001, 5.000001}}], 
   LineBox[{{5.000001, 10.000001}, {5.000001, 15.000001}, {10.000001, 
    10.000001}, {5.000001, 10.000001}}], 
   LineBox[{{10.000001, 10.000001}, {10.000001, 15.000001}, {5.000001, 
    15.000001}, {10.000001, 10.000001}}], 
   LineBox[{{5.000001, 15.000001}, {5.000001, 20.000001}, {10.000001, 
    15.000001}, {5.000001, 15.000001}}], 
   LineBox[{{10.000001, 15.000001}, {10.000001, 20.000001}, {5.000001, 
    20.000001}, {10.000001, 15.000001}}], 
   LineBox[{{5.000001, 20.000001}, {5.000001, 25.000001}, {10.000001, 
    20.000001}, {5.000001, 20.000001}}], 
   LineBox[{{10.000001, 20.000001}, {10.000001, 25.000001}, {5.000001, 
    25.000001}, {10.000001, 20.000001}}], 
   LineBox[{{10.000001, -24.999999}, {10.000001, -19.999999}, {
    15.000001, -24.999999}, {10.000001, -24.999999}}], 
   LineBox[{{15.000001, -24.999999}, {15.000001, -19.999999}, {
    10.000001, -19.999999}, {15.000001, -24.999999}}], 
   LineBox[{{10.000001, -19.999999}, {10.000001, -14.999999}, {
    15.000001, -19.999999}, {10.000001, -19.999999}}], 
   LineBox[{{15.000001, -19.999999}, {15.000001, -14.999999}, {
    10.000001, -14.999999}, {15.000001, -19.999999}}], 
   LineBox[{{10.000001, -14.999999}, {10.000001, -9.999999}, {
    15.000001, -14.999999}, {10.000001, -14.999999}}], 
   LineBox[{{15.000001, -14.999999}, {15.000001, -9.999999}, {
    10.000001, -9.999999}, {15.000001, -14.999999}}], 
   LineBox[{{10.000001, -9.999999}, {10.000001, -4.999999}, {
    15.000001, -9.999999}, {10.000001, -9.999999}}], 
   LineBox[{{15.000001, -9.999999}, {15.000001, -4.999999}, {
    10.000001, -4.999999}, {15.000001, -9.999999}}], 
   LineBox[{{10.000001, -4.999999}, {10.000001, 1.*^-6}, {
    15.000001, -4.999999}, {10.000001, -4.999999}}], 
   LineBox[{{15.000001, -4.999999}, {15.000001, 1.*^-6}, {10.000001, 
    1.*^-6}, {15.000001, -4.999999}}], 
   LineBox[{{10.000001, 1.*^-6}, {10.000001, 5.000001}, {15.000001, 1.*^-6}, {
    10.000001, 1.*^-6}}], 
   LineBox[{{15.000001, 1.*^-6}, {15.000001, 5.000001}, {10.000001, 
    5.000001}, {15.000001, 1.*^-6}}], 
   LineBox[{{10.000001, 5.000001}, {10.000001, 10.000001}, {15.000001, 
    5.000001}, {10.000001, 5.000001}}], 
   LineBox[{{15.000001, 5.000001}, {15.000001, 10.000001}, {10.000001, 
    10.000001}, {15.000001, 5.000001}}], 
   LineBox[{{10.000001, 10.000001}, {10.000001, 15.000001}, {15.000001, 
    10.000001}, {10.000001, 10.000001}}], 
   LineBox[{{15.000001, 10.000001}, {15.000001, 15.000001}, {10.000001, 
    15.000001}, {15.000001, 10.000001}}], 
   LineBox[{{10.000001, 15.000001}, {10.000001, 20.000001}, {15.000001, 
    15.000001}, {10.000001, 15.000001}}], 
   LineBox[{{15.000001, 15.000001}, {15.000001, 20.000001}, {10.000001, 
    20.000001}, {15.000001, 15.000001}}], 
   LineBox[{{10.000001, 20.000001}, {10.000001, 25.000001}, {15.000001, 
    20.000001}, {10.000001, 20.000001}}], 
   LineBox[{{15.000001, 20.000001}, {15.000001, 25.000001}, {10.000001, 
    25.000001}, {15.000001, 20.000001}}], 
   LineBox[{{15.000001, -24.999999}, {15.000001, -19.999999}, {
    20.000001, -24.999999}, {15.000001, -24.999999}}], 
   LineBox[{{20.000001, -24.999999}, {20.000001, -19.999999}, {
    15.000001, -19.999999}, {20.000001, -24.999999}}], 
   LineBox[{{15.000001, -19.999999}, {15.000001, -14.999999}, {
    20.000001, -19.999999}, {15.000001, -19.999999}}], 
   LineBox[{{20.000001, -19.999999}, {20.000001, -14.999999}, {
    15.000001, -14.999999}, {20.000001, -19.999999}}], 
   LineBox[{{15.000001, -14.999999}, {15.000001, -9.999999}, {
    20.000001, -14.999999}, {15.000001, -14.999999}}], 
   LineBox[{{20.000001, -14.999999}, {20.000001, -9.999999}, {
    15.000001, -9.999999}, {20.000001, -14.999999}}], 
   LineBox[{{15.000001, -9.999999}, {15.000001, -4.999999}, {
    20.000001, -9.999999}, {15.000001, -9.999999}}], 
   LineBox[{{20.000001, -9.999999}, {20.000001, -4.999999}, {
    15.000001, -4.999999}, {20.000001, -9.999999}}], 
   LineBox[{{15.000001, -4.999999}, {15.000001, 1.*^-6}, {
    20.000001, -4.999999}, {15.000001, -4.999999}}], 
   LineBox[{{20.000001, -4.999999}, {20.000001, 1.*^-6}, {15.000001, 
    1.*^-6}, {20.000001, -4.999999}}], 
   LineBox[{{15.000001, 1.*^-6}, {15.000001, 5.000001}, {20.000001, 1.*^-6}, {
    15.000001, 1.*^-6}}], 
   LineBox[{{20.000001, 1.*^-6}, {20.000001, 5.000001}, {15.000001, 
    5.000001}, {20.000001, 1.*^-6}}], 
   LineBox[{{15.000001, 5.000001}, {15.000001, 10.000001}, {20.000001, 
    5.000001}, {15.000001, 5.000001}}], 
   LineBox[{{20.000001, 5.000001}, {20.000001, 10.000001}, {15.000001, 
    10.000001}, {20.000001, 5.000001}}], 
   LineBox[{{15.000001, 10.000001}, {15.000001, 15.000001}, {20.000001, 
    10.000001}, {15.000001, 10.000001}}], 
   LineBox[{{20.000001, 10.000001}, {20.000001, 15.000001}, {15.000001, 
    15.000001}, {20.000001, 10.000001}}], 
   LineBox[{{15.000001, 15.000001}, {15.000001, 20.000001}, {20.000001, 
    15.000001}, {15.000001, 15.000001}}], 
   LineBox[{{20.000001, 15.000001}, {20.000001, 20.000001}, {15.000001, 
    20.000001}, {20.000001, 15.000001}}], 
   LineBox[{{15.000001, 20.000001}, {15.000001, 25.000001}, {20.000001, 
    20.000001}, {15.000001, 20.000001}}], 
   LineBox[{{20.000001, 20.000001}, {20.000001, 25.000001}, {15.000001, 
    25.000001}, {20.000001, 20.000001}}], 
   LineBox[{{20.000001, -24.999999}, {20.000001, -19.999999}, {
    25.000001, -24.999999}, {20.000001, -24.999999}}], 
   LineBox[{{25.000001, -24.999999}, {25.000001, -19.999999}, {
    20.000001, -19.999999}, {25.000001, -24.999999}}], 
   LineBox[{{20.000001, -19.999999}, {20.000001, -14.999999}, {
    25.000001, -19.999999}, {20.000001, -19.999999}}], 
   LineBox[{{25.000001, -19.999999}, {25.000001, -14.999999}, {
    20.000001, -14.999999}, {25.000001, -19.999999}}], 
   LineBox[{{20.000001, -14.999999}, {20.000001, -9.999999}, {
    25.000001, -14.999999}, {20.000001, -14.999999}}], 
   LineBox[{{25.000001, -14.999999}, {25.000001, -9.999999}, {
    20.000001, -9.999999}, {25.000001, -14.999999}}], 
   LineBox[{{20.000001, -9.999999}, {20.000001, -4.999999}, {
    25.000001, -9.999999}, {20.000001, -9.999999}}], 
   LineBox[{{25.000001, -9.999999}, {25.000001, -4.999999}, {
    20.000001, -4.999999}, {25.000001, -9.999999}}], 
   LineBox[{{20.000001, -4.999999}, {20.000001, 1.*^-6}, {
    25.000001, -4.999999}, {20.000001, -4.999999}}], 
   LineBox[{{25.000001, -4.999999}, {25.000001, 1.*^-6}, {20.000001, 
    1.*^-6}, {25.000001, -4.999999}}], 
   LineBox[{{20.000001, 1.*^-6}, {20.000001, 5.000001}, {25.000001, 1.*^-6}, {
    20.000001, 1.*^-6}}], 
   LineBox[{{25.000001, 1.*^-6}, {25.000001, 5.000001}, {20.000001, 
    5.000001}, {25.000001, 1.*^-6}}], 
   LineBox[{{20.000001, 5.000001}, {20.000001, 10.000001}, {25.000001, 
    5.000001}, {20.000001, 5.000001}}], 
   LineBox[{{25.000001, 5.000001}, {25.000001, 10.000001}, {20.000001, 
    10.000001}, {25.000001, 5.000001}}], 
   LineBox[{{20.000001, 10.000001}, {20.000001, 15.000001}, {25.000001, 
    10.000001}, {20.000001, 10.000001}}], 
   LineBox[{{25.000001, 10.000001}, {25.000001, 15.000001}, {20.000001, 
    15.000001}, {25.000001, 10.000001}}], 
   LineBox[{{20.000001, 15.000001}, {20.000001, 20.000001}, {25.000001, 
    15.000001}, {20.000001, 15.000001}}], 
   LineBox[{{25.000001, 15.000001}, {25.000001, 20.000001}, {20.000001, 
    20.000001}, {25.000001, 15.000001}}], 
   LineBox[{{20.000001, 20.000001}, {20.000001, 25.000001}, {25.000001, 
    20.000001}, {20.000001, 20.000001}}], 
   LineBox[{{25.000001, 20.000001}, {25.000001, 25.000001}, {20.000001, 
    25.000001}, {25.000001, 20.000001}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301536174473*^9, 3.614709302359707*^9, 
  3.614729157895958*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[237]:="]
}, Open  ]],

Cell[TextData[{
 "You can also specify two numbers in the ",
 StyleBox["SurfacePoints", "Input"],
 " setting in order to control the two sample dimensions independently. Here \
is the circular conic mirror again with a ",
 StyleBox["SurfacePoints -> {7, 11}", "Input"],
 " setting. Note that the number of radial spokes has increased while the \
number of concentric lines has remained unchanged."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[
\tCustomMirror[Function[Sqrt[#1^2 + #2^2]],50, GraphicDesign -> False, \
SurfacePoints -> {7, 11}],
\tSurfacePoints -> Mesh,
\tPlotType->FrontView
];\
\>", "Input",
 CellChangeTimes->{{3.563457927347467*^9, 3.563457928923504*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[238]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{3.3709051432289474`, 2.4491062178853045`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{3.3709051432289474`, 2.4491062178853045`}], 
   PointBox[{1.2875718098956141`, 3.9627364845631394`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{1.2875718098956141`, 3.9627364845631394`}], 
   PointBox[{-1.2875698098956143`, 3.9627364845631394`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-1.2875698098956143`, 3.9627364845631394`}], 
   PointBox[{-3.370903143228947, 2.4491062178853045`}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-3.370903143228947, 2.4491062178853045`}], 
   PointBox[{-4.166665666666666, 1.*^-6}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-3.370903143228947, -2.449104217885304}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-3.370903143228947, -2.449104217885304}], 
   PointBox[{-1.2875698098956143`, -3.962734484563139}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{-1.2875698098956143`, -3.962734484563139}], 
   PointBox[{1.2875718098956141`, -3.962734484563139}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{1.2875718098956141`, -3.962734484563139}], 
   PointBox[{3.3709051432289474`, -2.449104217885304}], 
   PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{3.3709051432289474`, -2.449104217885304}], 
   PointBox[{4.166667666666666, 1.*^-6}], PointBox[{1.*^-6, 1.*^-6}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{3.3709051432289474`, 2.4491062178853045`}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{3.3709051432289474`, 2.4491062178853045`}], 
   PointBox[{3.3709051432289474`, 2.4491062178853045`}], 
   PointBox[{1.2875718098956141`, 3.9627364845631394`}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{1.2875718098956141`, 3.9627364845631394`}], 
   PointBox[{1.2875718098956141`, 3.9627364845631394`}], 
   PointBox[{-1.2875698098956143`, 3.9627364845631394`}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{-1.2875698098956143`, 3.9627364845631394`}], 
   PointBox[{-1.2875698098956143`, 3.9627364845631394`}], 
   PointBox[{-3.370903143228947, 2.4491062178853045`}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-3.370903143228947, 2.4491062178853045`}], 
   PointBox[{-3.370903143228947, 2.4491062178853045`}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-4.166665666666666, 1.*^-6}], 
   PointBox[{-3.370903143228947, -2.449104217885304}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-3.370903143228947, -2.449104217885304}], 
   PointBox[{-3.370903143228947, -2.449104217885304}], 
   PointBox[{-1.2875698098956143`, -3.962734484563139}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{-1.2875698098956143`, -3.962734484563139}], 
   PointBox[{-1.2875698098956143`, -3.962734484563139}], 
   PointBox[{1.2875718098956141`, -3.962734484563139}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{1.2875718098956141`, -3.962734484563139}], 
   PointBox[{1.2875718098956141`, -3.962734484563139}], 
   PointBox[{3.3709051432289474`, -2.449104217885304}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{3.3709051432289474`, -2.449104217885304}], 
   PointBox[{3.3709051432289474`, -2.449104217885304}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{4.166667666666666, 1.*^-6}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{12.500001, 1.*^-6}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{6.741809286457895, 4.898211435770609}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{2.5751426197912286`, 7.925471969126279}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{-2.5751406197912283`, 7.925471969126279}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-6.741807286457894, 4.898211435770609}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-12.499999, 1.*^-6}], PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-8.333332333333333, 1.*^-6}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-12.499999, 1.*^-6}], PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-6.741807286457894, -4.8982094357706085`}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{-2.5751406197912283`, -7.925469969126278}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{2.5751426197912286`, -7.925469969126278}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{6.741809286457895, -4.8982094357706085`}], 
   PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{12.500001, 1.*^-6}], PointBox[{8.333334333333331, 1.*^-6}], 
   PointBox[{12.500001, 1.*^-6}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{10.112713429686842`, 7.3473166536559145`}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{3.8627134296868433`, 11.888207453689418`}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{-3.862711429686843, 11.888207453689418`}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-10.112711429686843`, 7.3473166536559145`}], 
   PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-12.499999, 1.*^-6}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-10.112711429686843`, -7.347314653655914}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{-3.862711429686843, -11.88820545368942}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{3.8627134296868433`, -11.88820545368942}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{10.112713429686842`, -7.347314653655914}], 
   PointBox[{12.500001, 1.*^-6}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{16.666667666666665`, 1.*^-6}], PointBox[{12.500001, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{13.483617572915788`, 9.796421871541217}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{5.150284239582457, 15.850942938252556`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{-5.150282239582457, 15.850942938252556`}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-13.48361557291579, 9.796421871541217}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-16.666665666666663`, 1.*^-6}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-13.48361557291579, -9.796419871541218}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{-5.150282239582457, -15.850940938252558`}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{5.150284239582457, -15.850940938252558`}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{13.483617572915788`, -9.796419871541218}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{16.666667666666665`, 1.*^-6}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{25.000001, 1.*^-6}], PointBox[{25.000001, 1.*^-6}], 
   PointBox[{20.225425859373686`, 14.694632307311828`}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{16.854521716144742`, 12.245527089426524`}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{20.225425859373686`, 14.694632307311828`}], 
   PointBox[{20.225425859373686`, 14.694632307311828`}], 
   PointBox[{7.725425859373686, 23.77641390737884}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{6.437855049478073, 19.813678422815702`}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{7.725425859373686, 23.77641390737884}], 
   PointBox[{7.725425859373686, 23.77641390737884}], 
   PointBox[{-7.725423859373686, 23.77641390737884}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{-6.437853049478073, 19.813678422815702`}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-7.725423859373686, 23.77641390737884}], 
   PointBox[{-7.725423859373686, 23.77641390737884}], 
   PointBox[{-20.225423859373684`, 14.694632307311828`}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-16.85451971614474, 12.245527089426524`}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-20.225423859373684`, 14.694632307311828`}], 
   PointBox[{-20.225423859373684`, 14.694632307311828`}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-20.833332333333335`, 1.*^-6}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-24.999999, 1.*^-6}], PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-20.225423859373684`, -14.69463030731183}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-16.85451971614474, -12.245525089426526`}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{-20.225423859373684`, -14.69463030731183}], 
   PointBox[{-20.225423859373684`, -14.69463030731183}], 
   PointBox[{-7.725423859373686, -23.776411907378836`}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{-6.437853049478073, -19.8136764228157}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{-7.725423859373686, -23.776411907378836`}], 
   PointBox[{-7.725423859373686, -23.776411907378836`}], 
   PointBox[{7.725425859373686, -23.776411907378836`}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{6.437855049478073, -19.8136764228157}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{7.725425859373686, -23.776411907378836`}], 
   PointBox[{7.725425859373686, -23.776411907378836`}], 
   PointBox[{20.225425859373686`, -14.69463030731183}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{16.854521716144742`, -12.245525089426526`}], 
   PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{20.225425859373686`, -14.69463030731183}], 
   PointBox[{20.225425859373686`, -14.69463030731183}], 
   PointBox[{25.000001, 1.*^-6}], PointBox[{20.833334333333337`, 1.*^-6}], 
   PointBox[{25.000001, 1.*^-6}], 
   PointBox[{20.225425859373686`, 14.694632307311828`}], 
   PointBox[{39.57224775195198, 12.85780339389785}], 
   PointBox[{20.225425859373686`, 14.694632307311828`}], 
   PointBox[{7.725425859373686, 23.77641390737884}], 
   PointBox[{24.45699450390395, 33.66216468785433}], 
   PointBox[{7.725425859373686, 23.77641390737884}], 
   PointBox[{-7.725423859373686, 23.77641390737884}], 
   PointBox[{1.*^-6, 41.60872358791296}], 
   PointBox[{-7.725423859373686, 23.77641390737884}], 
   PointBox[{-20.225423859373684`, 14.694632307311828`}], 
   PointBox[{-24.456992503903948`, 33.66216468785433}], 
   PointBox[{-20.225423859373684`, 14.694632307311828`}], 
   PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-39.57224575195198, 12.85780339389785}], 
   PointBox[{-24.999999, 1.*^-6}], 
   PointBox[{-20.225423859373684`, -14.69463030731183}], 
   PointBox[{-39.57224575195198, -12.857801393897851`}], 
   PointBox[{-20.225423859373684`, -14.69463030731183}], 
   PointBox[{-7.725423859373686, -23.776411907378836`}], 
   PointBox[{-24.456992503903948`, -33.662162687854334`}], 
   PointBox[{-7.725423859373686, -23.776411907378836`}], 
   PointBox[{7.725425859373686, -23.776411907378836`}], 
   PointBox[{1.*^-6, -41.60872158791297}], 
   PointBox[{7.725425859373686, -23.776411907378836`}], 
   PointBox[{20.225425859373686`, -14.69463030731183}], 
   PointBox[{24.45699450390395, -33.662162687854334`}], 
   PointBox[{20.225425859373686`, -14.69463030731183}], 
   PointBox[{25.000001, 1.*^-6}], 
   PointBox[{39.57224775195198, -12.857801393897851`}], 
   LineBox[{{4.166667666666666, 1.*^-6}, {3.3709051432289474`, 
    2.4491062178853045`}, {1.*^-6, 1.*^-6}, {4.166667666666666, 1.*^-6}}], 
   LineBox[{{3.3709051432289474`, 2.4491062178853045`}, {1.2875718098956141`, 
    3.9627364845631394`}, {1.*^-6, 1.*^-6}, {3.3709051432289474`, 
    2.4491062178853045`}}], 
   LineBox[{{1.2875718098956141`, 3.9627364845631394`}, {-1.2875698098956143`,
     3.9627364845631394`}, {1.*^-6, 1.*^-6}, {1.2875718098956141`, 
    3.9627364845631394`}}], 
   LineBox[{{-1.2875698098956143`, 3.9627364845631394`}, {-3.370903143228947, 
    2.4491062178853045`}, {1.*^-6, 1.*^-6}, {-1.2875698098956143`, 
    3.9627364845631394`}}], 
   LineBox[{{-3.370903143228947, 2.4491062178853045`}, {-4.166665666666666, 
    1.*^-6}, {1.*^-6, 1.*^-6}, {-3.370903143228947, 2.4491062178853045`}}], 
   LineBox[{{-4.166665666666666, 
    1.*^-6}, {-3.370903143228947, -2.449104217885304}, {1.*^-6, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}}], 
   LineBox[{{-3.370903143228947, -2.449104217885304}, {-1.2875698098956143`, \
-3.962734484563139}, {1.*^-6, 
    1.*^-6}, {-3.370903143228947, -2.449104217885304}}], 
   LineBox[{{-1.2875698098956143`, -3.962734484563139}, {
    1.2875718098956141`, -3.962734484563139}, {1.*^-6, 
    1.*^-6}, {-1.2875698098956143`, -3.962734484563139}}], 
   LineBox[{{1.2875718098956141`, -3.962734484563139}, {
    3.3709051432289474`, -2.449104217885304}, {1.*^-6, 1.*^-6}, {
    1.2875718098956141`, -3.962734484563139}}], 
   LineBox[{{3.3709051432289474`, -2.449104217885304}, {4.166667666666666, 
    1.*^-6}, {1.*^-6, 1.*^-6}, {3.3709051432289474`, -2.449104217885304}}], 
   LineBox[{{4.166667666666666, 1.*^-6}, {3.3709051432289474`, 
    2.4491062178853045`}, {8.333334333333331, 1.*^-6}, {4.166667666666666, 
    1.*^-6}}], 
   LineBox[{{8.333334333333331, 1.*^-6}, {6.741809286457895, 
    4.898211435770609}, {3.3709051432289474`, 2.4491062178853045`}, {
    8.333334333333331, 1.*^-6}}], 
   LineBox[{{3.3709051432289474`, 2.4491062178853045`}, {1.2875718098956141`, 
    3.9627364845631394`}, {6.741809286457895, 4.898211435770609}, {
    3.3709051432289474`, 2.4491062178853045`}}], 
   LineBox[{{6.741809286457895, 4.898211435770609}, {2.5751426197912286`, 
    7.925471969126279}, {1.2875718098956141`, 3.9627364845631394`}, {
    6.741809286457895, 4.898211435770609}}], 
   LineBox[{{1.2875718098956141`, 3.9627364845631394`}, {-1.2875698098956143`,
     3.9627364845631394`}, {2.5751426197912286`, 7.925471969126279}, {
    1.2875718098956141`, 3.9627364845631394`}}], 
   LineBox[{{2.5751426197912286`, 7.925471969126279}, {-2.5751406197912283`, 
    7.925471969126279}, {-1.2875698098956143`, 3.9627364845631394`}, {
    2.5751426197912286`, 7.925471969126279}}], 
   LineBox[{{-1.2875698098956143`, 3.9627364845631394`}, {-3.370903143228947, 
    2.4491062178853045`}, {-2.5751406197912283`, 
    7.925471969126279}, {-1.2875698098956143`, 3.9627364845631394`}}], 
   LineBox[{{-2.5751406197912283`, 7.925471969126279}, {-6.741807286457894, 
    4.898211435770609}, {-3.370903143228947, 
    2.4491062178853045`}, {-2.5751406197912283`, 7.925471969126279}}], 
   LineBox[{{-3.370903143228947, 2.4491062178853045`}, {-4.166665666666666, 
    1.*^-6}, {-6.741807286457894, 4.898211435770609}, {-3.370903143228947, 
    2.4491062178853045`}}], 
   LineBox[{{-6.741807286457894, 4.898211435770609}, {-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}, {-6.741807286457894, 
    4.898211435770609}}], 
   LineBox[{{-4.166665666666666, 
    1.*^-6}, {-3.370903143228947, -2.449104217885304}, {-8.333332333333333, 
    1.*^-6}, {-4.166665666666666, 1.*^-6}}], 
   LineBox[{{-8.333332333333333, 
    1.*^-6}, {-6.741807286457894, -4.8982094357706085`}, {-3.370903143228947, \
-2.449104217885304}, {-8.333332333333333, 1.*^-6}}], 
   LineBox[{{-3.370903143228947, -2.449104217885304}, {-1.2875698098956143`, \
-3.962734484563139}, {-6.741807286457894, -4.8982094357706085`}, \
{-3.370903143228947, -2.449104217885304}}], 
   LineBox[{{-6.741807286457894, -4.8982094357706085`}, \
{-2.5751406197912283`, -7.925469969126278}, {-1.2875698098956143`, \
-3.962734484563139}, {-6.741807286457894, -4.8982094357706085`}}], 
   LineBox[{{-1.2875698098956143`, -3.962734484563139}, {
    1.2875718098956141`, -3.962734484563139}, {-2.5751406197912283`, \
-7.925469969126278}, {-1.2875698098956143`, -3.962734484563139}}], 
   LineBox[{{-2.5751406197912283`, -7.925469969126278}, {
    2.5751426197912286`, -7.925469969126278}, {
    1.2875718098956141`, -3.962734484563139}, {-2.5751406197912283`, \
-7.925469969126278}}], 
   LineBox[{{1.2875718098956141`, -3.962734484563139}, {
    3.3709051432289474`, -2.449104217885304}, {
    2.5751426197912286`, -7.925469969126278}, {
    1.2875718098956141`, -3.962734484563139}}], 
   LineBox[{{2.5751426197912286`, -7.925469969126278}, {
    6.741809286457895, -4.8982094357706085`}, {
    3.3709051432289474`, -2.449104217885304}, {
    2.5751426197912286`, -7.925469969126278}}], 
   LineBox[{{3.3709051432289474`, -2.449104217885304}, {4.166667666666666, 
    1.*^-6}, {6.741809286457895, -4.8982094357706085`}, {
    3.3709051432289474`, -2.449104217885304}}], 
   LineBox[{{6.741809286457895, -4.8982094357706085`}, {8.333334333333331, 
    1.*^-6}, {4.166667666666666, 1.*^-6}, {
    6.741809286457895, -4.8982094357706085`}}], 
   LineBox[{{8.333334333333331, 1.*^-6}, {6.741809286457895, 
    4.898211435770609}, {12.500001, 1.*^-6}, {8.333334333333331, 1.*^-6}}], 
   LineBox[{{12.500001, 1.*^-6}, {10.112713429686842`, 7.3473166536559145`}, {
    6.741809286457895, 4.898211435770609}, {12.500001, 1.*^-6}}], 
   LineBox[{{6.741809286457895, 4.898211435770609}, {2.5751426197912286`, 
    7.925471969126279}, {10.112713429686842`, 7.3473166536559145`}, {
    6.741809286457895, 4.898211435770609}}], 
   LineBox[{{10.112713429686842`, 7.3473166536559145`}, {3.8627134296868433`, 
    11.888207453689418`}, {2.5751426197912286`, 7.925471969126279}, {
    10.112713429686842`, 7.3473166536559145`}}], 
   LineBox[{{2.5751426197912286`, 7.925471969126279}, {-2.5751406197912283`, 
    7.925471969126279}, {3.8627134296868433`, 11.888207453689418`}, {
    2.5751426197912286`, 7.925471969126279}}], 
   LineBox[{{3.8627134296868433`, 11.888207453689418`}, {-3.862711429686843, 
    11.888207453689418`}, {-2.5751406197912283`, 7.925471969126279}, {
    3.8627134296868433`, 11.888207453689418`}}], 
   LineBox[{{-2.5751406197912283`, 7.925471969126279}, {-6.741807286457894, 
    4.898211435770609}, {-3.862711429686843, 
    11.888207453689418`}, {-2.5751406197912283`, 7.925471969126279}}], 
   LineBox[{{-3.862711429686843, 11.888207453689418`}, {-10.112711429686843`, 
    7.3473166536559145`}, {-6.741807286457894, 
    4.898211435770609}, {-3.862711429686843, 11.888207453689418`}}], 
   LineBox[{{-6.741807286457894, 4.898211435770609}, {-8.333332333333333, 
    1.*^-6}, {-10.112711429686843`, 7.3473166536559145`}, {-6.741807286457894,
     4.898211435770609}}], 
   LineBox[{{-10.112711429686843`, 7.3473166536559145`}, {-12.499999, 
    1.*^-6}, {-8.333332333333333, 1.*^-6}, {-10.112711429686843`, 
    7.3473166536559145`}}], 
   LineBox[{{-8.333332333333333, 
    1.*^-6}, {-6.741807286457894, -4.8982094357706085`}, {-12.499999, 
    1.*^-6}, {-8.333332333333333, 1.*^-6}}], 
   LineBox[{{-12.499999, 
    1.*^-6}, {-10.112711429686843`, -7.347314653655914}, {-6.741807286457894, \
-4.8982094357706085`}, {-12.499999, 1.*^-6}}], 
   LineBox[{{-6.741807286457894, -4.8982094357706085`}, \
{-2.5751406197912283`, -7.925469969126278}, {-10.112711429686843`, \
-7.347314653655914}, {-6.741807286457894, -4.8982094357706085`}}], 
   LineBox[{{-10.112711429686843`, -7.347314653655914}, {-3.862711429686843, \
-11.88820545368942}, {-2.5751406197912283`, -7.925469969126278}, \
{-10.112711429686843`, -7.347314653655914}}], 
   LineBox[{{-2.5751406197912283`, -7.925469969126278}, {
    2.5751426197912286`, -7.925469969126278}, {-3.862711429686843, \
-11.88820545368942}, {-2.5751406197912283`, -7.925469969126278}}], 
   LineBox[{{-3.862711429686843, -11.88820545368942}, {
    3.8627134296868433`, -11.88820545368942}, {
    2.5751426197912286`, -7.925469969126278}, {-3.862711429686843, \
-11.88820545368942}}], 
   LineBox[{{2.5751426197912286`, -7.925469969126278}, {
    6.741809286457895, -4.8982094357706085`}, {
    3.8627134296868433`, -11.88820545368942}, {
    2.5751426197912286`, -7.925469969126278}}], 
   LineBox[{{3.8627134296868433`, -11.88820545368942}, {
    10.112713429686842`, -7.347314653655914}, {
    6.741809286457895, -4.8982094357706085`}, {
    3.8627134296868433`, -11.88820545368942}}], 
   LineBox[{{6.741809286457895, -4.8982094357706085`}, {8.333334333333331, 
    1.*^-6}, {10.112713429686842`, -7.347314653655914}, {
    6.741809286457895, -4.8982094357706085`}}], 
   LineBox[{{10.112713429686842`, -7.347314653655914}, {12.500001, 1.*^-6}, {
    8.333334333333331, 1.*^-6}, {10.112713429686842`, -7.347314653655914}}], 
   LineBox[{{12.500001, 1.*^-6}, {10.112713429686842`, 7.3473166536559145`}, {
    16.666667666666665`, 1.*^-6}, {12.500001, 1.*^-6}}], 
   LineBox[{{16.666667666666665`, 1.*^-6}, {13.483617572915788`, 
    9.796421871541217}, {10.112713429686842`, 7.3473166536559145`}, {
    16.666667666666665`, 1.*^-6}}], 
   LineBox[{{10.112713429686842`, 7.3473166536559145`}, {3.8627134296868433`, 
    11.888207453689418`}, {13.483617572915788`, 9.796421871541217}, {
    10.112713429686842`, 7.3473166536559145`}}], 
   LineBox[{{13.483617572915788`, 9.796421871541217}, {5.150284239582457, 
    15.850942938252556`}, {3.8627134296868433`, 11.888207453689418`}, {
    13.483617572915788`, 9.796421871541217}}], 
   LineBox[{{3.8627134296868433`, 11.888207453689418`}, {-3.862711429686843, 
    11.888207453689418`}, {5.150284239582457, 15.850942938252556`}, {
    3.8627134296868433`, 11.888207453689418`}}], 
   LineBox[{{5.150284239582457, 15.850942938252556`}, {-5.150282239582457, 
    15.850942938252556`}, {-3.862711429686843, 11.888207453689418`}, {
    5.150284239582457, 15.850942938252556`}}], 
   LineBox[{{-3.862711429686843, 11.888207453689418`}, {-10.112711429686843`, 
    7.3473166536559145`}, {-5.150282239582457, 
    15.850942938252556`}, {-3.862711429686843, 11.888207453689418`}}], 
   LineBox[{{-5.150282239582457, 15.850942938252556`}, {-13.48361557291579, 
    9.796421871541217}, {-10.112711429686843`, 
    7.3473166536559145`}, {-5.150282239582457, 15.850942938252556`}}], 
   LineBox[{{-10.112711429686843`, 7.3473166536559145`}, {-12.499999, 
    1.*^-6}, {-13.48361557291579, 9.796421871541217}, {-10.112711429686843`, 
    7.3473166536559145`}}], 
   LineBox[{{-13.48361557291579, 9.796421871541217}, {-16.666665666666663`, 
    1.*^-6}, {-12.499999, 1.*^-6}, {-13.48361557291579, 9.796421871541217}}], 
   LineBox[{{-12.499999, 
    1.*^-6}, {-10.112711429686843`, -7.347314653655914}, \
{-16.666665666666663`, 1.*^-6}, {-12.499999, 1.*^-6}}], 
   LineBox[{{-16.666665666666663`, 
    1.*^-6}, {-13.48361557291579, -9.796419871541218}, {-10.112711429686843`, \
-7.347314653655914}, {-16.666665666666663`, 1.*^-6}}], 
   LineBox[{{-10.112711429686843`, -7.347314653655914}, {-3.862711429686843, \
-11.88820545368942}, {-13.48361557291579, -9.796419871541218}, \
{-10.112711429686843`, -7.347314653655914}}], 
   LineBox[{{-13.48361557291579, -9.796419871541218}, {-5.150282239582457, \
-15.850940938252558`}, {-3.862711429686843, -11.88820545368942}, \
{-13.48361557291579, -9.796419871541218}}], 
   LineBox[{{-3.862711429686843, -11.88820545368942}, {
    3.8627134296868433`, -11.88820545368942}, {-5.150282239582457, \
-15.850940938252558`}, {-3.862711429686843, -11.88820545368942}}], 
   LineBox[{{-5.150282239582457, -15.850940938252558`}, {
    5.150284239582457, -15.850940938252558`}, {
    3.8627134296868433`, -11.88820545368942}, {-5.150282239582457, \
-15.850940938252558`}}], 
   LineBox[{{3.8627134296868433`, -11.88820545368942}, {
    10.112713429686842`, -7.347314653655914}, {
    5.150284239582457, -15.850940938252558`}, {
    3.8627134296868433`, -11.88820545368942}}], 
   LineBox[{{5.150284239582457, -15.850940938252558`}, {
    13.483617572915788`, -9.796419871541218}, {
    10.112713429686842`, -7.347314653655914}, {
    5.150284239582457, -15.850940938252558`}}], 
   LineBox[{{10.112713429686842`, -7.347314653655914}, {12.500001, 1.*^-6}, {
    13.483617572915788`, -9.796419871541218}, {
    10.112713429686842`, -7.347314653655914}}], 
   LineBox[{{13.483617572915788`, -9.796419871541218}, {16.666667666666665`, 
    1.*^-6}, {12.500001, 1.*^-6}, {13.483617572915788`, -9.796419871541218}}],
    LineBox[{{16.666667666666665`, 1.*^-6}, {13.483617572915788`, 
    9.796421871541217}, {20.833334333333337`, 1.*^-6}, {16.666667666666665`, 
    1.*^-6}}], 
   LineBox[{{20.833334333333337`, 1.*^-6}, {16.854521716144742`, 
    12.245527089426524`}, {13.483617572915788`, 9.796421871541217}, {
    20.833334333333337`, 1.*^-6}}], 
   LineBox[{{13.483617572915788`, 9.796421871541217}, {5.150284239582457, 
    15.850942938252556`}, {16.854521716144742`, 12.245527089426524`}, {
    13.483617572915788`, 9.796421871541217}}], 
   LineBox[{{16.854521716144742`, 12.245527089426524`}, {6.437855049478073, 
    19.813678422815702`}, {5.150284239582457, 15.850942938252556`}, {
    16.854521716144742`, 12.245527089426524`}}], 
   LineBox[{{5.150284239582457, 15.850942938252556`}, {-5.150282239582457, 
    15.850942938252556`}, {6.437855049478073, 19.813678422815702`}, {
    5.150284239582457, 15.850942938252556`}}], 
   LineBox[{{6.437855049478073, 19.813678422815702`}, {-6.437853049478073, 
    19.813678422815702`}, {-5.150282239582457, 15.850942938252556`}, {
    6.437855049478073, 19.813678422815702`}}], 
   LineBox[{{-5.150282239582457, 15.850942938252556`}, {-13.48361557291579, 
    9.796421871541217}, {-6.437853049478073, 
    19.813678422815702`}, {-5.150282239582457, 15.850942938252556`}}], 
   LineBox[{{-6.437853049478073, 19.813678422815702`}, {-16.85451971614474, 
    12.245527089426524`}, {-13.48361557291579, 
    9.796421871541217}, {-6.437853049478073, 19.813678422815702`}}], 
   LineBox[{{-13.48361557291579, 9.796421871541217}, {-16.666665666666663`, 
    1.*^-6}, {-16.85451971614474, 12.245527089426524`}, {-13.48361557291579, 
    9.796421871541217}}], 
   LineBox[{{-16.85451971614474, 12.245527089426524`}, {-20.833332333333335`, 
    1.*^-6}, {-16.666665666666663`, 1.*^-6}, {-16.85451971614474, 
    12.245527089426524`}}], 
   LineBox[{{-16.666665666666663`, 
    1.*^-6}, {-13.48361557291579, -9.796419871541218}, {-20.833332333333335`, 
    1.*^-6}, {-16.666665666666663`, 1.*^-6}}], 
   LineBox[{{-20.833332333333335`, 
    1.*^-6}, {-16.85451971614474, -12.245525089426526`}, {-13.48361557291579, \
-9.796419871541218}, {-20.833332333333335`, 1.*^-6}}], 
   LineBox[{{-13.48361557291579, -9.796419871541218}, {-5.150282239582457, \
-15.850940938252558`}, {-16.85451971614474, -12.245525089426526`}, \
{-13.48361557291579, -9.796419871541218}}], 
   LineBox[{{-16.85451971614474, -12.245525089426526`}, {-6.437853049478073, \
-19.8136764228157}, {-5.150282239582457, -15.850940938252558`}, \
{-16.85451971614474, -12.245525089426526`}}], 
   LineBox[{{-5.150282239582457, -15.850940938252558`}, {
    5.150284239582457, -15.850940938252558`}, {-6.437853049478073, \
-19.8136764228157}, {-5.150282239582457, -15.850940938252558`}}], 
   LineBox[{{-6.437853049478073, -19.8136764228157}, {
    6.437855049478073, -19.8136764228157}, {
    5.150284239582457, -15.850940938252558`}, {-6.437853049478073, \
-19.8136764228157}}], 
   LineBox[{{5.150284239582457, -15.850940938252558`}, {
    13.483617572915788`, -9.796419871541218}, {
    6.437855049478073, -19.8136764228157}, {
    5.150284239582457, -15.850940938252558`}}], 
   LineBox[{{6.437855049478073, -19.8136764228157}, {
    16.854521716144742`, -12.245525089426526`}, {
    13.483617572915788`, -9.796419871541218}, {
    6.437855049478073, -19.8136764228157}}], 
   LineBox[{{13.483617572915788`, -9.796419871541218}, {16.666667666666665`, 
    1.*^-6}, {16.854521716144742`, -12.245525089426526`}, {
    13.483617572915788`, -9.796419871541218}}], 
   LineBox[{{16.854521716144742`, -12.245525089426526`}, {20.833334333333337`,
     1.*^-6}, {16.666667666666665`, 1.*^-6}, {
    16.854521716144742`, -12.245525089426526`}}], 
   LineBox[{{20.833334333333337`, 1.*^-6}, {16.854521716144742`, 
    12.245527089426524`}, {25.000001, 1.*^-6}, {20.833334333333337`, 
    1.*^-6}}], 
   LineBox[{{25.000001, 1.*^-6}, {20.225425859373686`, 14.694632307311828`}, {
    16.854521716144742`, 12.245527089426524`}, {25.000001, 1.*^-6}}], 
   LineBox[{{16.854521716144742`, 12.245527089426524`}, {6.437855049478073, 
    19.813678422815702`}, {20.225425859373686`, 14.694632307311828`}, {
    16.854521716144742`, 12.245527089426524`}}], 
   LineBox[{{20.225425859373686`, 14.694632307311828`}, {7.725425859373686, 
    23.77641390737884}, {6.437855049478073, 19.813678422815702`}, {
    20.225425859373686`, 14.694632307311828`}}], 
   LineBox[{{6.437855049478073, 19.813678422815702`}, {-6.437853049478073, 
    19.813678422815702`}, {7.725425859373686, 23.77641390737884}, {
    6.437855049478073, 19.813678422815702`}}], 
   LineBox[{{7.725425859373686, 23.77641390737884}, {-7.725423859373686, 
    23.77641390737884}, {-6.437853049478073, 19.813678422815702`}, {
    7.725425859373686, 23.77641390737884}}], 
   LineBox[{{-6.437853049478073, 19.813678422815702`}, {-16.85451971614474, 
    12.245527089426524`}, {-7.725423859373686, 
    23.77641390737884}, {-6.437853049478073, 19.813678422815702`}}], 
   LineBox[{{-7.725423859373686, 23.77641390737884}, {-20.225423859373684`, 
    14.694632307311828`}, {-16.85451971614474, 
    12.245527089426524`}, {-7.725423859373686, 23.77641390737884}}], 
   LineBox[{{-16.85451971614474, 12.245527089426524`}, {-20.833332333333335`, 
    1.*^-6}, {-20.225423859373684`, 14.694632307311828`}, {-16.85451971614474,
     12.245527089426524`}}], 
   LineBox[{{-20.225423859373684`, 14.694632307311828`}, {-24.999999, 
    1.*^-6}, {-20.833332333333335`, 1.*^-6}, {-20.225423859373684`, 
    14.694632307311828`}}], 
   LineBox[{{-20.833332333333335`, 
    1.*^-6}, {-16.85451971614474, -12.245525089426526`}, {-24.999999, 
    1.*^-6}, {-20.833332333333335`, 1.*^-6}}], 
   LineBox[{{-24.999999, 
    1.*^-6}, {-20.225423859373684`, -14.69463030731183}, {-16.85451971614474, \
-12.245525089426526`}, {-24.999999, 1.*^-6}}], 
   LineBox[{{-16.85451971614474, -12.245525089426526`}, {-6.437853049478073, \
-19.8136764228157}, {-20.225423859373684`, -14.69463030731183}, \
{-16.85451971614474, -12.245525089426526`}}], 
   LineBox[{{-20.225423859373684`, -14.69463030731183}, {-7.725423859373686, \
-23.776411907378836`}, {-6.437853049478073, -19.8136764228157}, \
{-20.225423859373684`, -14.69463030731183}}], 
   LineBox[{{-6.437853049478073, -19.8136764228157}, {
    6.437855049478073, -19.8136764228157}, {-7.725423859373686, \
-23.776411907378836`}, {-6.437853049478073, -19.8136764228157}}], 
   LineBox[{{-7.725423859373686, -23.776411907378836`}, {
    7.725425859373686, -23.776411907378836`}, {
    6.437855049478073, -19.8136764228157}, {-7.725423859373686, \
-23.776411907378836`}}], 
   LineBox[{{6.437855049478073, -19.8136764228157}, {
    16.854521716144742`, -12.245525089426526`}, {
    7.725425859373686, -23.776411907378836`}, {
    6.437855049478073, -19.8136764228157}}], 
   LineBox[{{7.725425859373686, -23.776411907378836`}, {
    20.225425859373686`, -14.69463030731183}, {
    16.854521716144742`, -12.245525089426526`}, {
    7.725425859373686, -23.776411907378836`}}], 
   LineBox[{{16.854521716144742`, -12.245525089426526`}, {20.833334333333337`,
     1.*^-6}, {20.225425859373686`, -14.69463030731183}, {
    16.854521716144742`, -12.245525089426526`}}], 
   LineBox[{{20.225425859373686`, -14.69463030731183}, {25.000001, 1.*^-6}, {
    20.833334333333337`, 1.*^-6}, {20.225425859373686`, -14.69463030731183}}],
    LineBox[{{25.000001, 1.*^-6}, {20.225425859373686`, 
    14.694632307311828`}, {39.57224775195198, 12.85780339389785}, {25.000001, 
    1.*^-6}}], 
   LineBox[{{20.225425859373686`, 14.694632307311828`}, {7.725425859373686, 
    23.77641390737884}, {24.45699450390395, 33.66216468785433}, {
    20.225425859373686`, 14.694632307311828`}}], 
   LineBox[{{7.725425859373686, 23.77641390737884}, {-7.725423859373686, 
    23.77641390737884}, {1.*^-6, 41.60872358791296}, {7.725425859373686, 
    23.77641390737884}}], 
   LineBox[{{-7.725423859373686, 23.77641390737884}, {-20.225423859373684`, 
    14.694632307311828`}, {-24.456992503903948`, 
    33.66216468785433}, {-7.725423859373686, 23.77641390737884}}], 
   LineBox[{{-20.225423859373684`, 14.694632307311828`}, {-24.999999, 
    1.*^-6}, {-39.57224575195198, 12.85780339389785}, {-20.225423859373684`, 
    14.694632307311828`}}], 
   LineBox[{{-24.999999, 
    1.*^-6}, {-20.225423859373684`, -14.69463030731183}, {-39.57224575195198, \
-12.857801393897851`}, {-24.999999, 1.*^-6}}], 
   LineBox[{{-20.225423859373684`, -14.69463030731183}, {-7.725423859373686, \
-23.776411907378836`}, {-24.456992503903948`, -33.662162687854334`}, \
{-20.225423859373684`, -14.69463030731183}}], 
   LineBox[{{-7.725423859373686, -23.776411907378836`}, {
    7.725425859373686, -23.776411907378836`}, {
    1.*^-6, -41.60872158791297}, {-7.725423859373686, -23.776411907378836`}}],
    LineBox[{{7.725425859373686, -23.776411907378836`}, {
    20.225425859373686`, -14.69463030731183}, {
    24.45699450390395, -33.662162687854334`}, {
    7.725425859373686, -23.776411907378836`}}], 
   LineBox[{{20.225425859373686`, -14.69463030731183}, {25.000001, 1.*^-6}, {
    39.57224775195198, -12.857801393897851`}, {
    20.225425859373686`, -14.69463030731183}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301536650557*^9, 3.614709302784498*^9, 
  3.614729158354793*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[238]:="]
}, Open  ]],

Cell["\<\
Here is a more complex custom mirror example with small-scale surface \
features.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell["\<\
axiconMirrorWithRipples[outDiameter_, inDiameter_, bodyLength_, amplitude_, \
numberOfPeaks_, opts___] :=
\t(* for holes in materials, here is how to interpret the parameters :*)
\t(* outDiameter :  the \"entrance\" hole diameter *)
\t(* inDiameter :   the \"exit\" hole diameter *)
\t(* bodyLength :   the \"depth\" of the hole *)
 \t(* Preconditions : outDiameter > inDiameter *)
Module[{longLength = (bodyLength * outDiameter) / (outDiameter - \
inDiameter)},
\t(* local variable longLength represents the total length that the cone *)
\t(*would be if it was not truncated at its pointy end*)
\tMove[
\t\tResonate[
\t\t\t(* List of components *)
\t\t\tHole[
\t\t\t\tCustomMirror[
\t\t\t\t\t(* Surface function *)
\t\t\t\t\tFunction[{s, t}, Evaluate[2 longLength/ outDiameter * Sqrt[s^2 + \
t^2] + amplitude * 
\t\t\t\t\t\tSin[ numberOfPeaks * \[Pi] * (Sqrt[s^2 + t^2] - inDiameter/2)/ 
\t\t\t\t\t\t\t(1/2 (outDiameter - inDiameter))]] 
\t\t\t\t\t],
\t\t\t\t\toutDiameter, opts
\t\t\t\t],
\t\t\t\t(* hole aperture diameter *)
\t\t\t\tinDiameter
\t\t\t]
\t\t], 
\t\tlongLength, 180]
];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[239]:="],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ 
    axiconMirrorWithRipples[80, 7.5, 200, 20., 4.],
    PlotPoints -> 60
    ];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[240]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGAwBmJmIG7Z+eb+dXZhWwYwcHFggAKPUBAwcli9CgjsnOHi
vm8/7I3+5+AAlq51gov/+Q8E9W4Q/h5HuPgsJzfhjcGeEHN+OcDFg0D6r3o6
hIFoS4T4b5A5/z0g/A92cPElIP1aHhD1ubZw8ai9O9/4rfGAmP/KGs093hB+
hhVcPLyTXfFSQwDEnKcWcPGVIP1ZIRBzkszh4hAQCeE/MEV1/9RYiDmxJghx
65r30/YnQMy5ZQQX/wdyj3ySAyOIE2EIF18x4aLLmytJDmtA6lfpw8VDQOZ+
TYKYv1QHLg4Onv1JDqA4ZFigCRcHa++CmjNLDeHffL3dwquTHCLA7lVGNSc+
GWLOBAW4+JojzQKZB1Ig6kWl4eLBIP7WNIcNIPO5RNHCJxPK5yMoHgo1ZxWa
OWuh9oai2QsGCckQPpI7I6D+CkXz10poOKxCCwcwOJAE4SOFWyg0nEPRwnk5
NF5WocULGChAzUGKx2BovK9Ci/cwaDoJRUsnEICZrtZA0+EqtHQYBU23oWjp
FgwavB3A8ZmOSOfR0HyxCi1fwPJRKFo++gXNd2DqPSLf+ULzaShaPp0Dzder
0PI1rnIAV7mRCS1nVqGVM7jKJVziAAUTQ6A=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGAwBmJmBhjIdIDQfAdgIqEgsDXNYRUIcInCxdceaRbIPJDi
AJYXlYaLg0FCMsScCQpw8Yh8vd3Cq5Mg6qcqw8VXgsztSoKYP0sN1ZwDSRBz
Fmiiuucr1JylOnDx5RMuury5AjVnlT6qOQpQcyIM4eLB1jXvp+1PgKi/ZQQX
DwO7LxZifqwJqjkMkRBzHpjCxdeA9GeFQMxJMoeLR3WyK15qCICY89QC1ZwG
b4f/IJBuBReP3rvzjd8aD4g5r6zh4ktAfC0PiDm5tnDxX2ADPCDmvLeDi/uC
1F31hKi3dICLz3FyE94Y7Akx/xdC/A9If70bxF97HBHmvP2wN/qfA8ScWie4
eCZYwAhijp0zXLxl55v719mFbSE8F4LiHlBzVqOZg8teXO6cBfXXajR/BUHD
IQwtHH5Dww3M+YAIN1g4h6GFcxQ0XlajxQvEPd4QczIQ8RgOjfcwtHhfCU0n
q9HSCQRgpqsgaDoMQ0uHQdB0uxot3f4DuUc+yYERxEFK5yug+WINWr4Igeaj
MLR8BA6e/UkOoLIBOd+tgubTNWj5NByaryPQ8jXYnPhkiDlI5cAaaLkRgVZu
BEPLmQ1o5QwEYJZLuMQBM/ZZXQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1lM8rRFEUxx8WykJqsrJASpHIr/zK9DBpJNKMyyDR83OU/ANEsWE1Gxay
sCBco1hYCDkL/wCRsmFjoxEbG4R37zvmdY7erfdu59u9n3fe+ZVvzYTGUg3D
qLSfNPtZOkk83KX7Gg1nLThbAIJCrQrzT9+X9vK3QMfL2/nAt5nU9bG5Zvj6
sdd8q0k4Z02w3tzqOwq3Uc6HCSF179bVe5RdZ8Kn4vwEKefND1vqXnGQnp9u
hP7zk0RnPEj5zw3oTzvlTNZD73J6/vVCF+U81cKeujfVTTlWDThmH+U8Vjv+
rw5SzmAVhBpmX9cuhinnvgK+lT+5VlJPUe9IOezGrgKJG1ePq/OyDLoV792i
/O0S0OG5cHWVS2OzCPS1FcZZL4TemdJT376rR7TfBQ5naIRyYnkQv1zMisIo
PZ+dA2G1H48n9UPFz8jG+ERpfIxMT10wjkTOAfuuwO9qa3iEcmw/I+y/BP7X
HouDxDhoCyzKseMmWJwFxnmH5UViXrSVxzh2HsMs7xLz3sPqRGCdOOb/uoqz
OpRYh/2sbgXWrWO5da7zOlEPA6wvJPYF7yOBffTB+k6br37oYH0qsE83WF9L
7GuvOeA1N6JszkicM15zyUv/BUDndqA=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGAwBmJmBhjIdIAyGiAUn0MoCGxNg4uvAgEuUYe1R5oFMg+k
wMXB6kSlIfyEZFRzJig4ROTr7RZenYSqfqqyw0qQeV0IcbD5s9Qg/ANJqOYs
0IS45yuaOUt1HJZPuOjy5gqaOav0IXwFNHMiDB2CrWveT9ufgKr+lpFDGNhd
sajmx5pA+ZGo5jwwdVgD0pcVgmpOkrlDVCe74qWGAFRznlpA+A3ecPH/IJBu
5RC9d+cbvzUeqOa8snZYAqK1PFDNybV1+AXW6IFqzns7B1+Q/FVPVPWWDg5z
nNyENwZ7opr/y8HhD0hfvRuqv/Y4Ovi+/bA3+p8Dqjm1Tg6ZYIYRqjl2zg4t
O9/cv84ubItiDoMLTnEPNHNWQ83BZS8ud85C89dqqL+C0MIhDBoOv9HCDUx+
sMMI5zBoOEehxctqaLxA3OONak6GlUM4WryHQeN9JVo6WQ1NJxAuZroKQkuH
YdB0GISWbldD0+0/kHvkk+DijCASmM5XoOWLNdB8EYKWj8Kg+QgcPPsR4qAy
ApTvVqHl0zXQfBqOlq8joPkabE58Mqo5wHJgDVq5EQEtN4LRypkN0HIGwsUs
l3CJAwDjY1ld
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{200., -3.75, 0.}, {
      166.01282525764455`, -6.770833333333333, 0.}, {
      166.01282525764455`, -6.756336459428045, 0.4428336874957603}, {
      200., -3.741970962144763, 0.2452617346130365}, {200., -3.75, 0.}}], 
     Polygon3DBox[{{200., -3.741970962144763, 0.2452617346130365}, {
      166.01282525764455`, -6.756336459428045, 0.4428336874957603}, {
      166.01282525764455`, -6.712907915551841, 0.8837710931565992}, {
      200., -3.717918230151789, 0.4894732208251934}, {
      200., -3.741970962144763, 0.2452617346130365}}], 
     Polygon3DBox[{{200., -3.717918230151789, 0.4894732208251934}, {
      166.01282525764455`, -6.712907915551841, 0.8837710931565992}, {
      166.01282525764455`, -6.640733669396873, 1.3209240553175348`}, {
      200., -3.677944801512114, 0.7315887075604809}, {
      200., -3.717918230151789, 0.4894732208251934}}], 
     Polygon3DBox[{{200., -3.677944801512114, 0.7315887075604809}, {
      166.01282525764455`, -6.640733669396873, 1.3209240553175348`}, {
      166.01282525764455`, -6.540122782165566, 1.7524206178816508`}, {
      199.99999999999997`, -3.6222218485840063`, 0.9705714191344528}, {
      200., -3.677944801512114, 0.7315887075604809}}], 
     Polygon3DBox[{{199.99999999999997`, -3.6222218485840063`, 
      0.9705714191344528}, {166.01282525764455`, -6.540122782165566, 
      1.7524206178816508`}, {166.01282525764455`, -6.411506085123111, 
      2.1764130463234896`}, {200., -3.550987985606646, 1.2053979948868558`}, {
      199.99999999999997`, -3.6222218485840063`, 0.9705714191344528}}], 
     Polygon3DBox[{{200., -3.550987985606646, 1.2053979948868558`}, {
      166.01282525764455`, -6.411506085123111, 2.1764130463234896`}, {
      166.01282525764455`, -6.255434334711838, 2.5910857399719616`}, {
      200., -3.4645482469173254`, 1.4350628713690865`}, {
      200., -3.550987985606646, 1.2053979948868558`}}], 
     Polygon3DBox[{{199.99999999999997`, -3.4645482469173254`, 
      1.4350628713690867`}, {166.01282525764455`, -6.255434334711838, 
      2.591085739971962}, {166.01282525764455`, -6.072575854127578, 
      2.9946630066911544`}, {199.99999999999997`, -3.3632727807475815`, 
      1.6585825883212546`}, {199.99999999999997`, -3.4645482469173254`, 
      1.4350628713690867`}}], 
     Polygon3DBox[{{199.99999999999997`, -3.3632727807475815`, 
      1.6585825883212546`}, {166.01282525764455`, -6.072575854127578, 
      2.9946630066911544`}, {166.01282525764455`, -5.863713671457137, 
      3.385416666666666}, {200., -3.247595264191645, 1.8749999999999998`}, {
      199.99999999999997`, -3.3632727807475815`, 1.6585825883212546`}}], 
     Polygon3DBox[{{200., -3.247595264191645, 1.8749999999999998`}, {
      166.01282525764455`, -5.863713671457137, 3.385416666666666}, {
      166.01282525764455`, -5.629742166631816, 3.76167345273689}, {
      200., -3.1180110461345447`, 2.0833883738235084`}, {
      200., -3.247595264191645, 1.8749999999999998`}}], 
     Polygon3DBox[{{200., -3.1180110461345447`, 2.0833883738235084`}, {
      166.01282525764455`, -5.629742166631816, 3.76167345273689}, {
      166.01282525764455`, -5.371663241555238, 4.121822175579879}, {
      200., -2.975075026092132, 2.2828553587827023`}, {
      200., -3.1180110461345447`, 2.0833883738235084`}}], 
     Polygon3DBox[{{200., -2.9750750260921324`, 2.282855358782702}, {
      166.01282525764455`, -5.371663241555239, 4.1218221755798785`}, {
      166.01282525764455`, -5.090582029805576, 4.464320623073383}, {
      200., -2.8193992780461654`, 2.472546806625258}, {
      200., -2.9750750260921324`, 2.282855358782702}}], 
     Polygon3DBox[{{200., -2.8193992780461654`, 2.472546806625258}, {
      166.01282525764455`, -5.090582029805576, 4.464320623073383}, {
      166.01282525764455`, -4.787702164283916, 4.787702164283915}, {
      200., -2.6516504294495533`, 2.651650429449553}, {
      200., -2.8193992780461654`, 2.472546806625258}}], 
     Polygon3DBox[{{200., -2.6516504294495533`, 2.651650429449553}, {
      166.01282525764455`, -4.787702164283916, 4.787702164283915}, {
      166.01282525764455`, -4.464320623073383, 5.090582029805576}, {
      200., -2.472546806625258, 2.8193992780461654`}, {
      200., -2.6516504294495533`, 2.651650429449553}}], 
     Polygon3DBox[{{200., -2.4725468066252585`, 2.819399278046165}, {
      166.01282525764455`, -4.464320623073384, 5.090582029805575}, {
      166.01282525764455`, -4.121822175579879, 5.371663241555238}, {
      200., -2.2828553587827023`, 2.975075026092132}, {
      200., -2.4725468066252585`, 2.819399278046165}}], 
     Polygon3DBox[{{200., -2.2828553587827023`, 2.975075026092132}, {
      166.01282525764455`, -4.121822175579879, 5.371663241555238}, {
      166.01282525764455`, -3.7616734527368902`, 5.629742166631816}, {
      200., -2.0833883738235084`, 3.1180110461345447`}, {
      200., -2.2828553587827023`, 2.975075026092132}}], 
     Polygon3DBox[{{200., -2.083388373823509, 3.1180110461345443`}, {
      166.01282525764455`, -3.761673452736891, 5.629742166631816}, {
      166.01282525764455`, -3.3854166666666674`, 5.863713671457136}, {
      200., -1.8750000000000004`, 3.2475952641916446`}, {
      200., -2.083388373823509, 3.1180110461345443`}}], 
     Polygon3DBox[{{200., -1.8750000000000004`, 3.2475952641916446`}, {
      166.01282525764455`, -3.3854166666666674`, 5.863713671457136}, {
      166.01282525764455`, -2.9946630066911553`, 6.072575854127576}, {
      199.99999999999997`, -1.6585825883212555`, 3.363272780747581}, {
      200., -1.8750000000000004`, 3.2475952641916446`}}], 
     Polygon3DBox[{{199.99999999999997`, -1.6585825883212555`, 
      3.363272780747581}, {166.01282525764455`, -2.9946630066911553`, 
      6.072575854127576}, {166.01282525764455`, -2.5910857399719633`, 
      6.255434334711836}, {200., -1.4350628713690876`, 3.464548246917325}, {
      199.99999999999997`, -1.6585825883212555`, 3.363272780747581}}], 
     Polygon3DBox[{{199.99999999999997`, -1.435062871369087, 
      3.4645482469173254`}, {166.01282525764455`, -2.5910857399719625`, 
      6.255434334711838}, {166.01282525764455`, -2.1764130463234905`, 
      6.41150608512311}, {200., -1.2053979948868563`, 3.5509879856066457`}, {
      199.99999999999997`, -1.435062871369087, 3.4645482469173254`}}], 
     Polygon3DBox[{{200., -1.2053979948868563`, 3.5509879856066457`}, {
      166.01282525764455`, -2.1764130463234905`, 6.41150608512311}, {
      166.01282525764455`, -1.7524206178816524`, 6.540122782165566}, {
      200., -0.9705714191344537, 3.622221848584006}, {
      200., -1.2053979948868563`, 3.5509879856066457`}}], 
     Polygon3DBox[{{200., -0.9705714191344537, 3.622221848584006}, {
      166.01282525764455`, -1.7524206178816524`, 6.540122782165566}, {
      166.01282525764455`, -1.320924055317537, 6.640733669396873}, {
      200., -0.731588707560482, 3.677944801512114}, {
      200., -0.9705714191344537, 3.622221848584006}}], 
     Polygon3DBox[{{200., -0.7315887075604812, 3.677944801512114}, {
      166.01282525764455`, -1.3209240553175357`, 6.640733669396873}, {
      166.01282525764455`, -0.8837710931566001, 6.712907915551841}, {
      200., -0.4894732208251939, 3.717918230151789}, {
      200., -0.7315887075604812, 3.677944801512114}}], 
     Polygon3DBox[{{200., -0.4894732208251939, 3.717918230151789}, {
      166.01282525764455`, -0.8837710931566001, 6.712907915551841}, {
      166.01282525764455`, -0.4428336874957617, 6.756336459428045}, {
      200., -0.24526173461303727`, 3.741970962144763}, {
      200., -0.4894732208251939, 3.717918230151789}}], 
     Polygon3DBox[{{200., -0.24526173461303727`, 3.741970962144763}, {
      166.01282525764455`, -0.4428336874957617, 6.756336459428045}, {
      166.01282525764455`, -1.9180209809745763`*^-15, 6.770833333333333}, {
      200., -1.0622885433089962`*^-15, 3.75}, {200., -0.24526173461303727`, 
      3.741970962144763}}], 
     Polygon3DBox[{{200., -2.2962127484012875`*^-16, 3.75}, {
      166.01282525764455`, -4.1459396846134354`*^-16, 6.770833333333333}, {
      166.01282525764455`, 0.44283368749575935`, 6.756336459428045}, {200., 
      0.24526173461303596`, 3.741970962144763}, {
      200., -2.2962127484012875`*^-16, 3.75}}], 
     Polygon3DBox[{{200., 0.24526173461303596`, 3.741970962144763}, {
      166.01282525764455`, 0.44283368749575935`, 6.756336459428045}, {
      166.01282525764455`, 0.8837710931565979, 6.712907915551842}, {200., 
      0.4894732208251927, 3.7179182301517892`}, {200., 0.24526173461303596`, 
      3.741970962144763}}], 
     Polygon3DBox[{{200., 0.4894732208251927, 3.7179182301517892`}, {
      166.01282525764455`, 0.8837710931565979, 6.712907915551842}, {
      166.01282525764455`, 1.320924055317533, 6.640733669396873}, {
      199.99999999999997`, 0.7315887075604799, 3.6779448015121146`}, {200., 
      0.4894732208251927, 3.7179182301517892`}}], 
     Polygon3DBox[{{199.99999999999997`, 0.7315887075604799, 
      3.6779448015121146`}, {166.01282525764455`, 1.320924055317533, 
      6.640733669396873}, {166.01282525764455`, 1.7524206178816484`, 
      6.540122782165567}, {199.99999999999997`, 0.9705714191344516, 
      3.6222218485840068`}, {199.99999999999997`, 0.7315887075604799, 
      3.6779448015121146`}}], 
     Polygon3DBox[{{200., 0.9705714191344523, 3.6222218485840063`}, {
      166.01282525764455`, 1.7524206178816502`, 6.540122782165566}, {
      166.01282525764455`, 2.1764130463234883`, 6.411506085123111}, {200., 
      1.2053979948868552`, 3.550987985606646}, {200., 0.9705714191344523, 
      3.6222218485840063`}}], 
     Polygon3DBox[{{200., 1.2053979948868552`, 3.550987985606646}, {
      166.01282525764455`, 2.1764130463234883`, 6.411506085123111}, {
      166.01282525764455`, 2.59108573997196, 6.255434334711838}, {
      199.99999999999997`, 1.4350628713690856`, 3.464548246917326}, {200., 
      1.2053979948868552`, 3.550987985606646}}], 
     Polygon3DBox[{{199.99999999999997`, 1.4350628713690856`, 
      3.464548246917326}, {166.01282525764455`, 2.59108573997196, 
      6.255434334711838}, {166.01282525764455`, 2.9946630066911535`, 
      6.072575854127578}, {200., 1.6585825883212542`, 3.3632727807475815`}, {
      199.99999999999997`, 1.4350628713690856`, 3.464548246917326}}], 
     Polygon3DBox[{{200., 1.6585825883212542`, 3.3632727807475815`}, {
      166.01282525764455`, 2.9946630066911535`, 6.072575854127578}, {
      166.01282525764455`, 3.385416666666665, 5.863713671457137}, {200., 
      1.8749999999999991`, 3.247595264191645}, {200., 1.6585825883212542`, 
      3.3632727807475815`}}], 
     Polygon3DBox[{{200., 1.8749999999999991`, 3.247595264191645}, {
      166.01282525764455`, 3.385416666666665, 5.863713671457137}, {
      166.01282525764455`, 3.761673452736888, 5.629742166631818}, {
      199.99999999999997`, 2.0833883738235075`, 3.1180110461345456`}, {200., 
      1.8749999999999991`, 3.247595264191645}}], 
     Polygon3DBox[{{199.99999999999997`, 2.0833883738235075`, 
      3.1180110461345456`}, {166.01282525764455`, 3.761673452736888, 
      5.629742166631818}, {166.01282525764455`, 4.121822175579878, 
      5.37166324155524}, {200., 2.2828553587827014`, 2.975075026092133}, {
      199.99999999999997`, 2.0833883738235075`, 3.1180110461345456`}}], 
     Polygon3DBox[{{200., 2.2828553587827014`, 2.975075026092133}, {
      166.01282525764455`, 4.121822175579878, 5.37166324155524}, {
      166.01282525764455`, 4.46432062307338, 5.090582029805578}, {200., 
      2.4725468066252567`, 2.8193992780461663`}, {200., 2.2828553587827014`, 
      2.975075026092133}}], 
     Polygon3DBox[{{200., 2.4725468066252567`, 2.8193992780461663`}, {
      166.01282525764455`, 4.46432062307338, 5.090582029805578}, {
      166.01282525764455`, 4.787702164283912, 4.7877021642839175`}, {200., 
      2.6516504294495515`, 2.6516504294495546`}, {200., 2.4725468066252567`, 
      2.8193992780461663`}}], 
     Polygon3DBox[{{200., 2.651650429449553, 2.6516504294495533`}, {
      166.01282525764455`, 4.787702164283915, 4.787702164283916}, {
      166.01282525764455`, 5.090582029805575, 4.464320623073384}, {200., 
      2.819399278046165, 2.4725468066252585`}, {200., 2.651650429449553, 
      2.6516504294495533`}}], 
     Polygon3DBox[{{200., 2.819399278046165, 2.4725468066252585`}, {
      166.01282525764455`, 5.090582029805575, 4.464320623073384}, {
      166.01282525764455`, 5.371663241555237, 4.121822175579881}, {
      199.99999999999997`, 2.9750750260921315`, 2.282855358782703}, {200., 
      2.819399278046165, 2.4725468066252585`}}], 
     Polygon3DBox[{{199.99999999999997`, 2.9750750260921315`, 
      2.282855358782703}, {166.01282525764455`, 5.371663241555237, 
      4.121822175579881}, {166.01282525764455`, 5.629742166631814, 
      3.7616734527368916`}, {200., 3.118011046134544, 2.0833883738235093`}, {
      199.99999999999997`, 2.9750750260921315`, 2.282855358782703}}], 
     Polygon3DBox[{{200., 3.118011046134544, 2.0833883738235093`}, {
      166.01282525764455`, 5.629742166631814, 3.7616734527368916`}, {
      166.01282525764455`, 5.863713671457135, 3.3854166666666687`}, {200., 
      3.247595264191644, 1.8750000000000013`}, {200., 3.118011046134544, 
      2.0833883738235093`}}], 
     Polygon3DBox[{{200., 3.247595264191644, 1.8750000000000013`}, {
      166.01282525764455`, 5.863713671457135, 3.3854166666666687`}, {
      166.01282525764455`, 6.072575854127576, 2.994663006691157}, {
      199.99999999999997`, 3.3632727807475806`, 1.6585825883212564`}, {200., 
      3.247595264191644, 1.8750000000000013`}}], 
     Polygon3DBox[{{199.99999999999997`, 3.3632727807475806`, 
      1.6585825883212564`}, {166.01282525764455`, 6.072575854127576, 
      2.994663006691157}, {166.01282525764455`, 6.255434334711836, 
      2.591085739971965}, {200., 3.4645482469173245`, 1.4350628713690885`}, {
      199.99999999999997`, 3.3632727807475806`, 1.6585825883212564`}}], 
     Polygon3DBox[{{199.99999999999997`, 3.4645482469173254`, 
      1.4350628713690872`}, {166.01282525764455`, 6.255434334711838, 
      2.5910857399719625`}, {166.01282525764455`, 6.41150608512311, 
      2.176413046323491}, {200., 3.5509879856066457`, 1.2053979948868565`}, {
      199.99999999999997`, 3.4645482469173254`, 1.4350628713690872`}}], 
     Polygon3DBox[{{200., 3.5509879856066457`, 1.2053979948868565`}, {
      166.01282525764455`, 6.41150608512311, 2.176413046323491}, {
      166.01282525764455`, 6.540122782165566, 1.7524206178816528`}, {200., 
      3.622221848584006, 0.9705714191344538}, {200., 3.5509879856066457`, 
      1.2053979948868565`}}], 
     Polygon3DBox[{{200., 3.622221848584006, 0.9705714191344538}, {
      166.01282525764455`, 6.540122782165566, 1.7524206178816528`}, {
      166.01282525764455`, 6.640733669396873, 1.3209240553175374`}, {
      199.99999999999997`, 3.677944801512114, 0.7315887075604823}, {200., 
      3.622221848584006, 0.9705714191344538}}], 
     Polygon3DBox[{{199.99999999999997`, 3.677944801512114, 
      0.7315887075604823}, {166.01282525764455`, 6.640733669396873, 
      1.3209240553175374`}, {166.01282525764455`, 6.712907915551841, 
      0.8837710931566021}, {200., 3.717918230151789, 0.48947322082519495`}, {
      199.99999999999997`, 3.677944801512114, 0.7315887075604823}}], 
     Polygon3DBox[{{200., 3.717918230151789, 0.48947322082519495`}, {
      166.01282525764455`, 6.712907915551841, 0.8837710931566021}, {
      166.01282525764455`, 6.756336459428045, 0.4428336874957637}, {200., 
      3.741970962144763, 0.24526173461303835`}, {200., 3.717918230151789, 
      0.48947322082519495`}}], 
     Polygon3DBox[{{200., 3.741970962144763, 0.24526173461303835`}, {
      166.01282525764455`, 6.756336459428045, 0.4428336874957637}, {
      166.01282525764455`, 6.770833333333333, 3.8360419619491526`*^-15}, {
      200., 3.75, 2.1245770866179924`*^-15}, {200., 3.741970962144763, 
      0.24526173461303835`}}], 
     Polygon3DBox[{{200., 3.75, 4.592425496802575*^-16}, {166.01282525764455`,
       6.770833333333333, 8.291879369226871*^-16}, {166.01282525764455`, 
      6.756336459428045, -0.442833687495759}, {200., 
      3.741970962144763, -0.24526173461303574`}, {200., 3.75, 
      4.592425496802575*^-16}}], 
     Polygon3DBox[{{200., 3.741970962144763, -0.24526173461303574`}, {
      166.01282525764455`, 6.756336459428045, -0.442833687495759}, {
      166.01282525764455`, 6.712907915551842, -0.8837710931565974}, {200., 
      3.7179182301517892`, -0.48947322082519246`}, {200., 
      3.741970962144763, -0.24526173461303574`}}], 
     Polygon3DBox[{{200., 3.7179182301517892`, -0.48947322082519246`}, {
      166.01282525764455`, 6.712907915551842, -0.8837710931565974}, {
      166.01282525764455`, 6.640733669396873, -1.3209240553175328`}, {
      199.99999999999997`, 3.6779448015121146`, -0.7315887075604797}, {200., 
      3.7179182301517892`, -0.48947322082519246`}}], 
     Polygon3DBox[{{199.99999999999997`, 
      3.6779448015121146`, -0.7315887075604797}, {166.01282525764455`, 
      6.640733669396873, -1.3209240553175328`}, {166.01282525764455`, 
      6.540122782165567, -1.7524206178816482`}, {199.99999999999997`, 
      3.6222218485840068`, -0.9705714191344513}, {199.99999999999997`, 
      3.6779448015121146`, -0.7315887075604797}}], 
     Polygon3DBox[{{199.99999999999997`, 
      3.6222218485840068`, -0.9705714191344513}, {166.01282525764455`, 
      6.540122782165567, -1.7524206178816482`}, {166.01282525764455`, 
      6.411506085123111, -2.1764130463234865`}, {200., 
      3.5509879856066466`, -1.205397994886854}, {199.99999999999997`, 
      3.6222218485840068`, -0.9705714191344513}}], 
     Polygon3DBox[{{200., 3.5509879856066466`, -1.205397994886854}, {
      166.01282525764455`, 6.411506085123111, -2.1764130463234865`}, {
      166.01282525764455`, 6.255434334711839, -2.591085739971958}, {200., 
      3.4645482469173263`, -1.4350628713690845`}, {200., 
      3.5509879856066466`, -1.205397994886854}}], 
     Polygon3DBox[{{200., 3.4645482469173263`, -1.4350628713690845`}, {
      166.01282525764455`, 6.255434334711839, -2.591085739971958}, {
      166.01282525764455`, 6.072575854127579, -2.994663006691151}, {200., 
      3.3632727807475824`, -1.6585825883212526`}, {200., 
      3.4645482469173263`, -1.4350628713690845`}}], 
     Polygon3DBox[{{200., 3.3632727807475815`, -1.658582588321254}, {
      166.01282525764455`, 6.072575854127578, -2.9946630066911526`}, {
      166.01282525764455`, 5.863713671457138, -3.3854166666666643`}, {200., 
      3.2475952641916455`, -1.874999999999999}, {200., 
      3.3632727807475815`, -1.658582588321254}}], 
     Polygon3DBox[{{200., 3.2475952641916455`, -1.874999999999999}, {
      166.01282525764455`, 5.863713671457138, -3.3854166666666643`}, {
      166.01282525764455`, 5.629742166631818, -3.761673452736888}, {
      199.99999999999997`, 3.1180110461345456`, -2.0833883738235075`}, {200., 
      3.2475952641916455`, -1.874999999999999}}], 
     Polygon3DBox[{{199.99999999999997`, 
      3.1180110461345456`, -2.0833883738235075`}, {166.01282525764455`, 
      5.629742166631818, -3.761673452736888}, {166.01282525764455`, 
      5.37166324155524, -4.121822175579878}, {200., 
      2.975075026092133, -2.2828553587827014`}, {199.99999999999997`, 
      3.1180110461345456`, -2.0833883738235075`}}], 
     Polygon3DBox[{{200., 2.975075026092133, -2.2828553587827014`}, {
      166.01282525764455`, 5.37166324155524, -4.121822175579878}, {
      166.01282525764455`, 5.090582029805578, -4.46432062307338}, {200., 
      2.8193992780461663`, -2.4725468066252567`}, {200., 
      2.975075026092133, -2.2828553587827014`}}], 
     Polygon3DBox[{{200., 2.8193992780461663`, -2.4725468066252567`}, {
      166.01282525764455`, 5.090582029805578, -4.46432062307338}, {
      166.01282525764455`, 4.7877021642839175`, -4.787702164283912}, {200., 
      2.6516504294495546`, -2.6516504294495515`}, {200., 
      2.8193992780461663`, -2.4725468066252567`}}], 
     Polygon3DBox[{{200., 2.6516504294495546`, -2.6516504294495515`}, {
      166.01282525764455`, 4.7877021642839175`, -4.787702164283912}, {
      166.01282525764455`, 4.4643206230733865`, -5.090582029805573}, {200., 
      2.4725468066252603`, -2.8193992780461636`}, {200., 
      2.6516504294495546`, -2.6516504294495515`}}], 
     Polygon3DBox[{{199.99999999999997`, 
      2.472546806625259, -2.819399278046165}, {166.01282525764455`, 
      4.464320623073384, -5.090582029805575}, {166.01282525764455`, 
      4.121822175579881, -5.371663241555236}, {200., 
      2.282855358782703, -2.975075026092131}, {199.99999999999997`, 
      2.472546806625259, -2.819399278046165}}], 
     Polygon3DBox[{{200., 2.282855358782703, -2.975075026092131}, {
      166.01282525764455`, 4.121822175579881, -5.371663241555236}, {
      166.01282525764455`, 3.76167345273689, -5.629742166631816}, {200., 
      2.0833883738235084`, -3.1180110461345447`}, {200., 
      2.282855358782703, -2.975075026092131}}], 
     Polygon3DBox[{{200., 2.083388373823511, -3.118011046134543}, {
      166.01282525764455`, 3.7616734527368947`, -5.6297421666318135`}, {
      166.01282525764455`, 3.3854166666666696`, -5.863713671457135}, {
      199.99999999999997`, 1.8750000000000018`, -3.247595264191644}, {200., 
      2.083388373823511, -3.118011046134543}}], 
     Polygon3DBox[{{199.99999999999997`, 
      1.8750000000000018`, -3.247595264191644}, {166.01282525764455`, 
      3.3854166666666696`, -5.863713671457135}, {166.01282525764455`, 
      2.994663006691155, -6.072575854127576}, {200., 
      1.658582588321255, -3.363272780747581}, {199.99999999999997`, 
      1.8750000000000018`, -3.247595264191644}}], 
     Polygon3DBox[{{200., 1.658582588321255, -3.363272780747581}, {
      166.01282525764455`, 2.994663006691155, -6.072575854127576}, {
      166.01282525764455`, 2.59108573997196, -6.255434334711838}, {
      199.99999999999997`, 1.4350628713690856`, -3.464548246917326}, {200., 
      1.658582588321255, -3.363272780747581}}], 
     Polygon3DBox[{{200., 1.4350628713690887`, -3.4645482469173245`}, {
      166.01282525764455`, 2.5910857399719656`, -6.255434334711836}, {
      166.01282525764455`, 2.1764130463234914`, -6.41150608512311}, {200., 
      1.2053979948868567`, -3.5509879856066457`}, {200., 
      1.4350628713690887`, -3.4645482469173245`}}], 
     Polygon3DBox[{{200., 1.2053979948868567`, -3.5509879856066457`}, {
      166.01282525764455`, 2.1764130463234914`, -6.41150608512311}, {
      166.01282525764455`, 1.7524206178816502`, -6.540122782165566}, {200., 
      0.9705714191344523, -3.6222218485840063`}, {200., 
      1.2053979948868567`, -3.5509879856066457`}}], 
     Polygon3DBox[{{200., 0.9705714191344557, -3.6222218485840054`}, {
      166.01282525764455`, 1.752420617881656, -6.540122782165565}, {
      166.01282525764455`, 1.3209240553175379`, -6.640733669396871}, {200., 
      0.7315887075604824, -3.6779448015121137`}, {200., 
      0.9705714191344557, -3.6222218485840054`}}], 
     Polygon3DBox[{{200., 0.7315887075604824, -3.6779448015121137`}, {
      166.01282525764455`, 1.3209240553175379`, -6.640733669396871}, {
      166.01282525764455`, 0.8837710931565996, -6.712907915551841}, {200., 
      0.4894732208251936, -3.717918230151789}, {200., 
      0.7315887075604824, -3.6779448015121137`}}], 
     Polygon3DBox[{{200., 0.48947322082519684`, -3.7179182301517884`}, {
      166.01282525764455`, 0.8837710931566054, -6.71290791555184}, {
      166.01282525764455`, 0.4428336874957641, -6.756336459428045}, {200., 
      0.24526173461303857`, -3.741970962144763}, {200., 
      0.48947322082519684`, -3.7179182301517884`}}], 
     Polygon3DBox[{{200., 0.24526173461303857`, -3.741970962144763}, {
      166.01282525764455`, 0.4428336874957641, -6.756336459428045}, {
      166.01282525764455`, 1.2437819053840304`*^-15, -6.770833333333333}, {
      200., 6.888638245203861*^-16, -3.75}, {200., 
      0.24526173461303857`, -3.741970962144763}}], 
     Polygon3DBox[{{200., 6.888638245203861*^-16, -3.75}, {
      166.01282525764455`, 1.2437819053840304`*^-15, -6.770833333333333}, {
      166.01282525764455`, -0.4428336874957616, -6.756336459428045}, {
      200., -0.2452617346130372, -3.741970962144763}, {200., 
      6.888638245203861*^-16, -3.75}}], 
     Polygon3DBox[{{
      199.99999999999997`, -0.24526173461303388`, -3.7419709621447637`}, {
      166.01282525764455`, -0.4428336874957556, -6.756336459428045}, {
      166.01282525764455`, -0.8837710931565971, -6.712907915551842}, {
      200., -0.48947322082519223`, -3.7179182301517892`}, {
      199.99999999999997`, -0.24526173461303388`, -3.7419709621447637`}}], 
     Polygon3DBox[{{200., -0.48947322082519223`, -3.7179182301517892`}, {
      166.01282525764455`, -0.8837710931565971, -6.712907915551842}, {
      166.01282525764455`, -1.3209240553175352`, -6.640733669396873}, {
      200., -0.7315887075604811, -3.677944801512114}, {
      200., -0.48947322082519223`, -3.7179182301517892`}}], 
     Polygon3DBox[{{
      199.99999999999997`, -0.7315887075604778, -3.677944801512115}, {
      166.01282525764452`, -1.3209240553175294`, -6.640733669396875}, {
      166.01282525764455`, -1.752420617881648, -6.540122782165567}, {
      199.99999999999997`, -0.9705714191344511, -3.6222218485840068`}, {
      199.99999999999997`, -0.7315887075604778, -3.677944801512115}}], 
     Polygon3DBox[{{
      199.99999999999997`, -0.9705714191344511, -3.6222218485840068`}, {
      166.01282525764455`, -1.752420617881648, -6.540122782165567}, {
      166.01282525764455`, -2.176413046323489, -6.411506085123111}, {
      200., -1.2053979948868556`, -3.550987985606646}, {
      199.99999999999997`, -0.9705714191344511, -3.6222218485840068`}}], 
     Polygon3DBox[{{200., -1.2053979948868556`, -3.550987985606646}, {
      166.01282525764455`, -2.176413046323489, -6.411506085123111}, {
      166.01282525764455`, -2.5910857399719633`, -6.255434334711836}, {
      200., -1.4350628713690876`, -3.464548246917325}, {
      200., -1.2053979948868556`, -3.550987985606646}}], 
     Polygon3DBox[{{200., -1.4350628713690843`, -3.4645482469173263`}, {
      166.01282525764455`, -2.591085739971958, -6.255434334711839}, {
      166.01282525764455`, -2.9946630066911526`, -6.072575854127578}, {
      199.99999999999997`, -1.658582588321254, -3.363272780747582}, {
      200., -1.4350628713690843`, -3.4645482469173263`}}], 
     Polygon3DBox[{{
      199.99999999999997`, -1.658582588321254, -3.363272780747582}, {
      166.01282525764455`, -2.9946630066911526`, -6.072575854127578}, {
      166.01282525764455`, -3.3854166666666674`, -5.863713671457136}, {
      200., -1.8750000000000004`, -3.2475952641916446`}, {
      199.99999999999997`, -1.658582588321254, -3.363272780747582}}], 
     Polygon3DBox[{{200., -1.8749999999999976`, -3.2475952641916463`}, {
      166.01282525764455`, -3.385416666666662, -5.863713671457139}, {
      166.01282525764455`, -3.7616734527368876`, -5.629742166631818}, {
      200., -2.083388373823507, -3.1180110461345456`}, {
      200., -1.8749999999999976`, -3.2475952641916463`}}], 
     Polygon3DBox[{{200., -2.083388373823507, -3.1180110461345456`}, {
      166.01282525764455`, -3.7616734527368876`, -5.629742166631818}, {
      166.01282525764455`, -4.1218221755798785`, -5.371663241555238}, {
      200., -2.282855358782702, -2.975075026092132}, {
      200., -2.083388373823507, -3.1180110461345456`}}], 
     Polygon3DBox[{{200., -2.2828553587826996`, -2.975075026092134}, {
      166.01282525764455`, -4.121822175579874, -5.371663241555241}, {
      166.01282525764455`, -4.46432062307338, -5.090582029805579}, {
      200., -2.4725468066252567`, -2.8193992780461667`}, {
      200., -2.2828553587826996`, -2.975075026092134}}], 
     Polygon3DBox[{{200., -2.4725468066252567`, -2.8193992780461667`}, {
      166.01282525764455`, -4.46432062307338, -5.090582029805579}, {
      166.01282525764455`, -4.787702164283914, -4.787702164283916}, {
      200., -2.6516504294495524`, -2.6516504294495538`}, {
      200., -2.4725468066252567`, -2.8193992780461667`}}], 
     Polygon3DBox[{{200., -2.6516504294495524`, -2.6516504294495538`}, {
      166.01282525764455`, -4.787702164283914, -4.787702164283916}, {
      166.01282525764455`, -5.090582029805576, -4.464320623073382}, {
      200., -2.8193992780461654`, -2.4725468066252576`}, {
      200., -2.6516504294495524`, -2.6516504294495538`}}], 
     Polygon3DBox[{{200., -2.8193992780461636`, -2.4725468066252603`}, {
      166.01282525764455`, -5.090582029805573, -4.4643206230733865`}, {
      166.01282525764455`, -5.371663241555236, -4.121822175579881}, {
      200., -2.975075026092131, -2.282855358782703}, {
      200., -2.8193992780461636`, -2.4725468066252603`}}], 
     Polygon3DBox[{{200., -2.975075026092131, -2.282855358782703}, {
      166.01282525764455`, -5.371663241555236, -4.121822175579881}, {
      166.01282525764455`, -5.629742166631816, -3.76167345273689}, {
      200., -3.1180110461345447`, -2.0833883738235084`}, {
      200., -2.975075026092131, -2.282855358782703}}], 
     Polygon3DBox[{{200., -3.118011046134543, -2.083388373823511}, {
      166.01282525764455`, -5.6297421666318135`, -3.7616734527368947`}, {
      166.01282525764455`, -5.863713671457135, -3.3854166666666696`}, {
      199.99999999999997`, -3.247595264191644, -1.8750000000000018`}, {
      200., -3.118011046134543, -2.083388373823511}}], 
     Polygon3DBox[{{
      199.99999999999997`, -3.247595264191644, -1.8750000000000018`}, {
      166.01282525764455`, -5.863713671457135, -3.3854166666666696`}, {
      166.01282525764455`, -6.072575854127576, -2.9946630066911553`}, {
      200., -3.363272780747581, -1.6585825883212553`}, {
      199.99999999999997`, -3.247595264191644, -1.8750000000000018`}}], 
     Polygon3DBox[{{200., -3.3632727807475793`, -1.6585825883212582`}, {
      166.01282525764455`, -6.072575854127574, -2.9946630066911606`}, {
      166.01282525764455`, -6.255434334711836, -2.591085739971966}, {
      200., -3.4645482469173245`, -1.435062871369089}, {
      200., -3.3632727807475793`, -1.6585825883212582`}}], 
     Polygon3DBox[{{200., -3.4645482469173245`, -1.435062871369089}, {
      166.01282525764455`, -6.255434334711836, -2.591085739971966}, {
      166.01282525764455`, -6.41150608512311, -2.176413046323492}, {
      200., -3.5509879856066457`, -1.205397994886857}, {
      200., -3.4645482469173245`, -1.435062871369089}}], 
     Polygon3DBox[{{200., -3.5509879856066457`, -1.205397994886857}, {
      166.01282525764455`, -6.41150608512311, -2.176413046323492}, {
      166.01282525764455`, -6.540122782165566, -1.7524206178816504`}, {
      199.99999999999997`, -3.6222218485840063`, -0.9705714191344526}, {
      200., -3.5509879856066457`, -1.205397994886857}}], 
     Polygon3DBox[{{200., -3.6222218485840054`, -0.9705714191344559}, {
      166.01282525764455`, -6.540122782165565, -1.7524206178816564`}, {
      166.01282525764455`, -6.640733669396871, -1.3209240553175383`}, {
      200., -3.6779448015121137`, -0.7315887075604827}, {
      200., -3.6222218485840054`, -0.9705714191344559}}], 
     Polygon3DBox[{{200., -3.6779448015121137`, -0.7315887075604827}, {
      166.01282525764455`, -6.640733669396871, -1.3209240553175383`}, {
      166.01282525764455`, -6.712907915551841, -0.8837710931566}, {
      200., -3.717918230151789, -0.48947322082519384`}, {
      200., -3.6779448015121137`, -0.7315887075604827}}], 
     Polygon3DBox[{{200., -3.7179182301517884`, -0.4894732208251972}, {
      166.01282525764455`, -6.71290791555184, -0.883771093156606}, {
      166.01282525764455`, -6.756336459428045, -0.44283368749576446`}, {
      200., -3.741970962144763, -0.24526173461303877`}, {
      200., -3.7179182301517884`, -0.4894732208251972}}], 
     Polygon3DBox[{{200., -3.741970962144763, -0.24526173461303877`}, {
      166.01282525764455`, -6.756336459428045, -0.44283368749576446`}, {
      166.01282525764455`, -6.770833333333333, -1.6583758738453742`*^-15}, {
      200., -3.75, -9.18485099360515*^-16}, {
      200., -3.741970962144763, -0.24526173461303877`}}], 
     Polygon3DBox[{{166.01282525764455`, -6.770833333333333, 0.}, {
      149.3461585909779, -9.791666666666666, 0.}, {
      149.3461585909779, -9.770701956711326, 0.6404056403784841}, {
      166.01282525764455`, -6.756336459428045, 0.4428336874957603}, {
      166.01282525764455`, -6.770833333333333, 0.}}], 
     Polygon3DBox[{{166.01282525764455`, -6.756336459428045, 
      0.4428336874957603}, {149.3461585909779, -9.770701956711326, 
      0.6404056403784841}, {149.3461585909779, -9.707897600951894, 
      1.2780689654880049`}, {166.01282525764455`, -6.712907915551841, 
      0.8837710931565992}, {166.01282525764455`, -6.756336459428045, 
      0.4428336874957603}}], 
     Polygon3DBox[{{166.01282525764455`, -6.712907915551841, 
      0.8837710931565992}, {149.3461585909779, -9.707897600951894, 
      1.2780689654880049`}, {149.3461585909779, -9.60352253728163, 
      1.9102594030745887`}, {166.01282525764455`, -6.640733669396873, 
      1.3209240553175348`}, {166.01282525764455`, -6.712907915551841, 
      0.8837710931565992}}], 
     Polygon3DBox[{{166.01282525764455`, -6.640733669396873, 
      1.3209240553175348`}, {149.3461585909779, -9.60352253728163, 
      1.9102594030745887`}, {149.34615859097786`, -9.458023715747128, 
      2.534269816628849}, {166.01282525764455`, -6.540122782165566, 
      1.7524206178816508`}, {166.01282525764455`, -6.640733669396873, 
      1.3209240553175348`}}], 
     Polygon3DBox[{{166.01282525764455`, -6.540122782165566, 
      1.7524206178816508`}, {149.34615859097786`, -9.458023715747128, 
      2.534269816628849}, {149.3461585909779, -9.272024184639577, 
      3.1474280977601232`}, {166.01282525764455`, -6.411506085123111, 
      2.1764130463234896`}, {166.01282525764455`, -6.540122782165566, 
      1.7524206178816508`}}], 
     Polygon3DBox[{{166.01282525764455`, -6.411506085123111, 
      2.1764130463234896`}, {149.3461585909779, -9.272024184639577, 
      3.1474280977601232`}, {149.3461585909779, -9.04632042250635, 
      3.7471086085748366`}, {166.01282525764455`, -6.255434334711838, 
      2.5910857399719616`}, {166.01282525764455`, -6.411506085123111, 
      2.1764130463234896`}}], 
     Polygon3DBox[{{166.01282525764455`, -6.255434334711838, 
      2.591085739971962}, {149.3461585909779, -9.04632042250635, 
      3.7471086085748375`}, {149.3461585909779, -8.781878927507574, 
      4.330743425061054}, {166.01282525764455`, -6.072575854127578, 
      2.9946630066911544`}, {166.01282525764455`, -6.255434334711838, 
      2.591085739971962}}], 
     Polygon3DBox[{{166.01282525764455`, -6.072575854127578, 
      2.9946630066911544`}, {149.3461585909779, -8.781878927507574, 
      4.330743425061054}, {149.3461585909779, -8.479832078722628, 
      4.895833333333332}, {166.01282525764455`, -5.863713671457137, 
      3.385416666666666}, {166.01282525764455`, -6.072575854127578, 
      2.9946630066911544`}}], 
     Polygon3DBox[{{166.01282525764455`, -5.863713671457137, 
      3.385416666666666}, {149.3461585909779, -8.479832078722628, 
      4.895833333333332}, {149.3461585909779, -8.141473287129088, 
      5.439958531650271}, {166.01282525764455`, -5.629742166631816, 
      3.76167345273689}, {166.01282525764455`, -5.863713671457137, 
      3.385416666666666}}], 
     Polygon3DBox[{{166.01282525764455`, -5.629742166631816, 
      3.76167345273689}, {149.3461585909779, -8.141473287129088, 
      5.439958531650271}, {149.3461585909779, -7.768251457018344, 
      5.960788992377056}, {166.01282525764455`, -5.371663241555238, 
      4.121822175579879}, {166.01282525764455`, -5.629742166631816, 
      3.76167345273689}}], 
     Polygon3DBox[{{166.01282525764455`, -5.371663241555239, 
      4.1218221755798785`}, {149.3461585909779, -7.768251457018345, 
      5.960788992377055}, {149.3461585909779, -7.361764781564987, 
      6.456094439521507}, {166.01282525764455`, -5.090582029805576, 
      4.464320623073383}, {166.01282525764455`, -5.371663241555239, 
      4.1218221755798785`}}], 
     Polygon3DBox[{{166.01282525764455`, -5.090582029805576, 
      4.464320623073383}, {149.3461585909779, -7.361764781564987, 
      6.456094439521507}, {149.3461585909779, -6.923753899118278, 
      6.923753899118276}, {166.01282525764455`, -4.787702164283916, 
      4.787702164283915}, {166.01282525764455`, -5.090582029805576, 
      4.464320623073383}}], 
     Polygon3DBox[{{166.01282525764455`, -4.787702164283916, 
      4.787702164283915}, {149.3461585909779, -6.923753899118278, 
      6.923753899118276}, {149.3461585909779, -6.456094439521507, 
      7.361764781564987}, {166.01282525764455`, -4.464320623073383, 
      5.090582029805576}, {166.01282525764455`, -4.787702164283916, 
      4.787702164283915}}], 
     Polygon3DBox[{{166.01282525764455`, -4.464320623073384, 
      5.090582029805575}, {149.3461585909779, -6.456094439521508, 
      7.361764781564986}, {149.3461585909779, -5.960788992377056, 
      7.768251457018344}, {166.01282525764455`, -4.121822175579879, 
      5.371663241555238}, {166.01282525764455`, -4.464320623073384, 
      5.090582029805575}}], 
     Polygon3DBox[{{166.01282525764455`, -4.121822175579879, 
      5.371663241555238}, {149.3461585909779, -5.960788992377056, 
      7.768251457018344}, {149.3461585909779, -5.439958531650272, 
      8.141473287129088}, {166.01282525764455`, -3.7616734527368902`, 
      5.629742166631816}, {166.01282525764455`, -4.121822175579879, 
      5.371663241555238}}], 
     Polygon3DBox[{{166.01282525764455`, -3.761673452736891, 
      5.629742166631816}, {149.3461585909779, -5.439958531650273, 
      8.141473287129088}, {149.3461585909779, -4.895833333333334, 
      8.479832078722628}, {166.01282525764455`, -3.3854166666666674`, 
      5.863713671457136}, {166.01282525764455`, -3.761673452736891, 
      5.629742166631816}}], 
     Polygon3DBox[{{166.01282525764455`, -3.3854166666666674`, 
      5.863713671457136}, {149.3461585909779, -4.895833333333334, 
      8.479832078722628}, {149.3461585909779, -4.330743425061056, 
      8.781878927507572}, {166.01282525764455`, -2.9946630066911553`, 
      6.072575854127576}, {166.01282525764455`, -3.3854166666666674`, 
      5.863713671457136}}], 
     Polygon3DBox[{{166.01282525764455`, -2.9946630066911553`, 
      6.072575854127576}, {149.3461585909779, -4.330743425061056, 
      8.781878927507572}, {149.3461585909779, -3.7471086085748393`, 
      9.046320422506348}, {166.01282525764455`, -2.5910857399719633`, 
      6.255434334711836}, {166.01282525764455`, -2.9946630066911553`, 
      6.072575854127576}}], 
     Polygon3DBox[{{166.01282525764455`, -2.5910857399719625`, 
      6.255434334711838}, {149.3461585909779, -3.747108608574838, 
      9.04632042250635}, {149.3461585909779, -3.147428097760125, 
      9.272024184639575}, {166.01282525764455`, -2.1764130463234905`, 
      6.41150608512311}, {166.01282525764455`, -2.5910857399719625`, 
      6.255434334711838}}], 
     Polygon3DBox[{{166.01282525764455`, -2.1764130463234905`, 
      6.41150608512311}, {149.3461585909779, -3.147428097760125, 
      9.272024184639575}, {149.3461585909779, -2.534269816628851, 
      9.458023715747126}, {166.01282525764455`, -1.7524206178816524`, 
      6.540122782165566}, {166.01282525764455`, -2.1764130463234905`, 
      6.41150608512311}}], 
     Polygon3DBox[{{166.01282525764455`, -1.7524206178816524`, 
      6.540122782165566}, {149.3461585909779, -2.534269816628851, 
      9.458023715747126}, {149.3461585909779, -1.9102594030745919`, 
      9.60352253728163}, {166.01282525764455`, -1.320924055317537, 
      6.640733669396873}, {166.01282525764455`, -1.7524206178816524`, 
      6.540122782165566}}], 
     Polygon3DBox[{{166.01282525764455`, -1.3209240553175357`, 
      6.640733669396873}, {149.3461585909779, -1.9102594030745899`, 
      9.60352253728163}, {149.3461585909779, -1.2780689654880062`, 
      9.707897600951894}, {166.01282525764455`, -0.8837710931566001, 
      6.712907915551841}, {166.01282525764455`, -1.3209240553175357`, 
      6.640733669396873}}], 
     Polygon3DBox[{{166.01282525764455`, -0.8837710931566001, 
      6.712907915551841}, {149.3461585909779, -1.2780689654880062`, 
      9.707897600951894}, {149.3461585909779, -0.6404056403784861, 
      9.770701956711326}, {166.01282525764455`, -0.4428336874957617, 
      6.756336459428045}, {166.01282525764455`, -0.8837710931566001, 
      6.712907915551841}}], 
     Polygon3DBox[{{166.01282525764455`, -0.4428336874957617, 
      6.756336459428045}, {149.3461585909779, -0.6404056403784861, 
      9.770701956711326}, {149.3461585909779, -2.7737534186401568`*^-15, 
      9.791666666666666}, {166.01282525764455`, -1.9180209809745763`*^-15, 
      6.770833333333333}, {166.01282525764455`, -0.4428336874957617, 
      6.756336459428045}}], 
     Polygon3DBox[{{166.01282525764455`, -4.1459396846134354`*^-16, 
      6.770833333333333}, {149.3461585909779, -5.995666620825583*^-16, 
      9.791666666666666}, {149.3461585909779, 0.6404056403784828, 
      9.770701956711326}, {166.01282525764455`, 0.44283368749575935`, 
      6.756336459428045}, {166.01282525764455`, -4.1459396846134354`*^-16, 
      6.770833333333333}}], 
     Polygon3DBox[{{166.01282525764455`, 0.44283368749575935`, 
      6.756336459428045}, {149.3461585909779, 0.6404056403784828, 
      9.770701956711326}, {149.3461585909779, 1.278068965488003, 
      9.707897600951894}, {166.01282525764455`, 0.8837710931565979, 
      6.712907915551842}, {166.01282525764455`, 0.44283368749575935`, 
      6.756336459428045}}], 
     Polygon3DBox[{{166.01282525764455`, 0.8837710931565979, 
      6.712907915551842}, {149.3461585909779, 1.278068965488003, 
      9.707897600951894}, {149.3461585909779, 1.9102594030745863`, 
      9.60352253728163}, {166.01282525764455`, 1.320924055317533, 
      6.640733669396873}, {166.01282525764455`, 0.8837710931565979, 
      6.712907915551842}}], 
     Polygon3DBox[{{166.01282525764455`, 1.320924055317533, 
      6.640733669396873}, {149.3461585909779, 1.9102594030745863`, 
      9.60352253728163}, {149.3461585909779, 2.5342698166288455`, 
      9.458023715747128}, {166.01282525764455`, 1.7524206178816484`, 
      6.540122782165567}, {166.01282525764455`, 1.320924055317533, 
      6.640733669396873}}], 
     Polygon3DBox[{{166.01282525764455`, 1.7524206178816502`, 
      6.540122782165566}, {149.34615859097786`, 2.5342698166288478`, 
      9.458023715747128}, {149.3461585909779, 3.1474280977601214`, 
      9.272024184639577}, {166.01282525764455`, 2.1764130463234883`, 
      6.411506085123111}, {166.01282525764455`, 1.7524206178816502`, 
      6.540122782165566}}], 
     Polygon3DBox[{{166.01282525764455`, 2.1764130463234883`, 
      6.411506085123111}, {149.3461585909779, 3.1474280977601214`, 
      9.272024184639577}, {149.3461585909779, 3.7471086085748344`, 
      9.04632042250635}, {166.01282525764455`, 2.59108573997196, 
      6.255434334711838}, {166.01282525764455`, 2.1764130463234883`, 
      6.411506085123111}}], 
     Polygon3DBox[{{166.01282525764455`, 2.59108573997196, 
      6.255434334711838}, {149.3461585909779, 3.7471086085748344`, 
      9.04632042250635}, {149.3461585909779, 4.330743425061052, 
      8.781878927507574}, {166.01282525764455`, 2.9946630066911535`, 
      6.072575854127578}, {166.01282525764455`, 2.59108573997196, 
      6.255434334711838}}], 
     Polygon3DBox[{{166.01282525764455`, 2.9946630066911535`, 
      6.072575854127578}, {149.3461585909779, 4.330743425061052, 
      8.781878927507574}, {149.3461585909779, 4.895833333333331, 
      8.479832078722628}, {166.01282525764455`, 3.385416666666665, 
      5.863713671457137}, {166.01282525764455`, 2.9946630066911535`, 
      6.072575854127578}}], 
     Polygon3DBox[{{166.01282525764455`, 3.385416666666665, 
      5.863713671457137}, {149.3461585909779, 4.895833333333331, 
      8.479832078722628}, {149.34615859097786`, 5.439958531650269, 
      8.141473287129092}, {166.01282525764455`, 3.761673452736888, 
      5.629742166631818}, {166.01282525764455`, 3.385416666666665, 
      5.863713671457137}}], 
     Polygon3DBox[{{166.01282525764455`, 3.761673452736888, 
      5.629742166631818}, {149.34615859097786`, 5.439958531650269, 
      8.141473287129092}, {149.3461585909779, 5.960788992377053, 
      7.768251457018346}, {166.01282525764455`, 4.121822175579878, 
      5.37166324155524}, {166.01282525764455`, 3.761673452736888, 
      5.629742166631818}}], 
     Polygon3DBox[{{166.01282525764455`, 4.121822175579878, 
      5.37166324155524}, {149.3461585909779, 5.960788992377053, 
      7.768251457018346}, {149.3461585909779, 6.456094439521504, 
      7.36176478156499}, {166.01282525764455`, 4.46432062307338, 
      5.090582029805578}, {166.01282525764455`, 4.121822175579878, 
      5.37166324155524}}], 
     Polygon3DBox[{{166.01282525764455`, 4.46432062307338, 
      5.090582029805578}, {149.3461585909779, 6.456094439521504, 
      7.36176478156499}, {149.3461585909779, 6.923753899118274, 
      6.923753899118282}, {166.01282525764455`, 4.787702164283912, 
      4.7877021642839175`}, {166.01282525764455`, 4.46432062307338, 
      5.090582029805578}}], 
     Polygon3DBox[{{166.01282525764455`, 4.787702164283915, 
      4.787702164283916}, {149.3461585909779, 6.923753899118276, 
      6.923753899118278}, {149.3461585909779, 7.361764781564986, 
      6.456094439521508}, {166.01282525764455`, 5.090582029805575, 
      4.464320623073384}, {166.01282525764455`, 4.787702164283915, 
      4.787702164283916}}], 
     Polygon3DBox[{{166.01282525764455`, 5.090582029805575, 
      4.464320623073384}, {149.3461585909779, 7.361764781564986, 
      6.456094439521508}, {149.3461585909779, 7.7682514570183425`, 
      5.960788992377058}, {166.01282525764455`, 5.371663241555237, 
      4.121822175579881}, {166.01282525764455`, 5.090582029805575, 
      4.464320623073384}}], 
     Polygon3DBox[{{166.01282525764455`, 5.371663241555237, 
      4.121822175579881}, {149.3461585909779, 7.7682514570183425`, 
      5.960788992377058}, {149.3461585909779, 8.141473287129086, 
      5.439958531650275}, {166.01282525764455`, 5.629742166631814, 
      3.7616734527368916`}, {166.01282525764455`, 5.371663241555237, 
      4.121822175579881}}], 
     Polygon3DBox[{{166.01282525764455`, 5.629742166631814, 
      3.7616734527368916`}, {149.3461585909779, 8.141473287129086, 
      5.439958531650275}, {149.3461585909779, 8.479832078722627, 
      4.895833333333336}, {166.01282525764455`, 5.863713671457135, 
      3.3854166666666687`}, {166.01282525764455`, 5.629742166631814, 
      3.7616734527368916`}}], 
     Polygon3DBox[{{166.01282525764455`, 5.863713671457135, 
      3.3854166666666687`}, {149.3461585909779, 8.479832078722627, 
      4.895833333333336}, {149.34615859097786`, 8.781878927507572, 
      4.330743425061058}, {166.01282525764455`, 6.072575854127576, 
      2.994663006691157}, {166.01282525764455`, 5.863713671457135, 
      3.3854166666666687`}}], 
     Polygon3DBox[{{166.01282525764455`, 6.072575854127576, 
      2.994663006691157}, {149.34615859097786`, 8.781878927507572, 
      4.330743425061058}, {149.3461585909779, 9.046320422506348, 
      3.747108608574842}, {166.01282525764455`, 6.255434334711836, 
      2.591085739971965}, {166.01282525764455`, 6.072575854127576, 
      2.994663006691157}}], 
     Polygon3DBox[{{166.01282525764455`, 6.255434334711838, 
      2.5910857399719625`}, {149.3461585909779, 9.04632042250635, 
      3.7471086085748384`}, {149.3461585909779, 9.272024184639575, 
      3.1474280977601254`}, {166.01282525764455`, 6.41150608512311, 
      2.176413046323491}, {166.01282525764455`, 6.255434334711838, 
      2.5910857399719625`}}], 
     Polygon3DBox[{{166.01282525764455`, 6.41150608512311, 
      2.176413046323491}, {149.3461585909779, 9.272024184639575, 
      3.1474280977601254`}, {149.3461585909779, 9.458023715747126, 
      2.5342698166288518`}, {166.01282525764455`, 6.540122782165566, 
      1.7524206178816528`}, {166.01282525764455`, 6.41150608512311, 
      2.176413046323491}}], 
     Polygon3DBox[{{166.01282525764455`, 6.540122782165566, 
      1.7524206178816528`}, {149.3461585909779, 9.458023715747126, 
      2.5342698166288518`}, {149.3461585909779, 9.60352253728163, 
      1.9102594030745925`}, {166.01282525764455`, 6.640733669396873, 
      1.3209240553175374`}, {166.01282525764455`, 6.540122782165566, 
      1.7524206178816528`}}], 
     Polygon3DBox[{{166.01282525764455`, 6.640733669396873, 
      1.3209240553175374`}, {149.3461585909779, 9.60352253728163, 
      1.9102594030745925`}, {149.3461585909779, 9.707897600951894, 
      1.278068965488009}, {166.01282525764455`, 6.712907915551841, 
      0.8837710931566021}, {166.01282525764455`, 6.640733669396873, 
      1.3209240553175374`}}], 
     Polygon3DBox[{{166.01282525764455`, 6.712907915551841, 
      0.8837710931566021}, {149.3461585909779, 9.707897600951894, 
      1.278068965488009}, {149.3461585909779, 9.770701956711326, 
      0.640405640378489}, {166.01282525764455`, 6.756336459428045, 
      0.4428336874957637}, {166.01282525764455`, 6.712907915551841, 
      0.8837710931566021}}], 
     Polygon3DBox[{{166.01282525764455`, 6.756336459428045, 
      0.4428336874957637}, {149.3461585909779, 9.770701956711326, 
      0.640405640378489}, {149.3461585909779, 9.791666666666666, 
      5.5475068372803135`*^-15}, {166.01282525764455`, 6.770833333333333, 
      3.8360419619491526`*^-15}, {166.01282525764455`, 6.756336459428045, 
      0.4428336874957637}}], 
     Polygon3DBox[{{166.01282525764455`, 6.770833333333333, 
      8.291879369226871*^-16}, {149.3461585909779, 9.791666666666666, 
      1.1991333241651166`*^-15}, {149.3461585909779, 
      9.770701956711326, -0.6404056403784822}, {166.01282525764455`, 
      6.756336459428045, -0.442833687495759}, {166.01282525764455`, 
      6.770833333333333, 8.291879369226871*^-16}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.756336459428045, -0.442833687495759}, {149.3461585909779, 
      9.770701956711326, -0.6404056403784822}, {149.3461585909779, 
      9.707897600951894, -1.2780689654880024`}, {166.01282525764455`, 
      6.712907915551842, -0.8837710931565974}, {166.01282525764455`, 
      6.756336459428045, -0.442833687495759}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.712907915551842, -0.8837710931565974}, {149.3461585909779, 
      9.707897600951894, -1.2780689654880024`}, {149.34615859097786`, 
      9.60352253728163, -1.9102594030745859`}, {166.01282525764455`, 
      6.640733669396873, -1.3209240553175328`}, {166.01282525764455`, 
      6.712907915551842, -0.8837710931565974}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.640733669396873, -1.3209240553175328`}, {149.34615859097786`, 
      9.60352253728163, -1.9102594030745859`}, {149.3461585909779, 
      9.458023715747128, -2.534269816628845}, {166.01282525764455`, 
      6.540122782165567, -1.7524206178816482`}, {166.01282525764455`, 
      6.640733669396873, -1.3209240553175328`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.540122782165567, -1.7524206178816482`}, {149.3461585909779, 
      9.458023715747128, -2.534269816628845}, {149.3461585909779, 
      9.272024184639577, -3.147428097760119}, {166.01282525764455`, 
      6.411506085123111, -2.1764130463234865`}, {166.01282525764455`, 
      6.540122782165567, -1.7524206178816482`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.411506085123111, -2.1764130463234865`}, {149.3461585909779, 
      9.272024184639577, -3.147428097760119}, {149.3461585909779, 
      9.046320422506351, -3.747108608574832}, {166.01282525764455`, 
      6.255434334711839, -2.591085739971958}, {166.01282525764455`, 
      6.411506085123111, -2.1764130463234865`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.255434334711839, -2.591085739971958}, {149.3461585909779, 
      9.046320422506351, -3.747108608574832}, {149.3461585909779, 
      8.781878927507575, -4.330743425061049}, {166.01282525764455`, 
      6.072575854127579, -2.994663006691151}, {166.01282525764455`, 
      6.255434334711839, -2.591085739971958}}], 
     Polygon3DBox[{{166.01282525764455`, 
      6.072575854127578, -2.9946630066911526`}, {149.3461585909779, 
      8.781878927507574, -4.330743425061051}, {149.3461585909779, 
      8.47983207872263, -4.89583333333333}, {166.01282525764455`, 
      5.863713671457138, -3.3854166666666643`}, {166.01282525764455`, 
      6.072575854127578, -2.9946630066911526`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      5.863713671457138, -3.3854166666666643`}, {149.3461585909779, 
      8.47983207872263, -4.89583333333333}, {149.34615859097786`, 
      8.141473287129092, -5.439958531650269}, {166.01282525764455`, 
      5.629742166631818, -3.761673452736888}, {166.01282525764455`, 
      5.863713671457138, -3.3854166666666643`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      5.629742166631818, -3.761673452736888}, {149.34615859097786`, 
      8.141473287129092, -5.439958531650269}, {149.3461585909779, 
      7.768251457018346, -5.960788992377053}, {166.01282525764455`, 
      5.37166324155524, -4.121822175579878}, {166.01282525764455`, 
      5.629742166631818, -3.761673452736888}}], 
     Polygon3DBox[{{166.01282525764455`, 
      5.37166324155524, -4.121822175579878}, {149.3461585909779, 
      7.768251457018346, -5.960788992377053}, {149.3461585909779, 
      7.36176478156499, -6.456094439521504}, {166.01282525764455`, 
      5.090582029805578, -4.46432062307338}, {166.01282525764455`, 
      5.37166324155524, -4.121822175579878}}], 
     Polygon3DBox[{{166.01282525764455`, 
      5.090582029805578, -4.46432062307338}, {149.3461585909779, 
      7.36176478156499, -6.456094439521504}, {149.3461585909779, 
      6.923753899118282, -6.923753899118274}, {166.01282525764455`, 
      4.7877021642839175`, -4.787702164283912}, {166.01282525764455`, 
      5.090582029805578, -4.46432062307338}}], 
     Polygon3DBox[{{166.01282525764455`, 
      4.7877021642839175`, -4.787702164283912}, {149.3461585909779, 
      6.923753899118282, -6.923753899118274}, {149.3461585909779, 
      6.456094439521513, -7.3617647815649825`}, {166.01282525764455`, 
      4.4643206230733865`, -5.090582029805573}, {166.01282525764455`, 
      4.7877021642839175`, -4.787702164283912}}], 
     Polygon3DBox[{{166.01282525764455`, 
      4.464320623073384, -5.090582029805575}, {149.3461585909779, 
      6.456094439521509, -7.361764781564986}, {149.3461585909779, 
      5.960788992377058, -7.7682514570183425`}, {166.01282525764455`, 
      4.121822175579881, -5.371663241555236}, {166.01282525764455`, 
      4.464320623073384, -5.090582029805575}}], 
     Polygon3DBox[{{166.01282525764455`, 
      4.121822175579881, -5.371663241555236}, {149.3461585909779, 
      5.960788992377058, -7.7682514570183425`}, {149.3461585909779, 
      5.439958531650271, -8.141473287129088}, {166.01282525764455`, 
      3.76167345273689, -5.629742166631816}, {166.01282525764455`, 
      4.121822175579881, -5.371663241555236}}], 
     Polygon3DBox[{{166.01282525764455`, 
      3.7616734527368947`, -5.6297421666318135`}, {149.3461585909779, 
      5.439958531650278, -8.141473287129084}, {149.3461585909779, 
      4.8958333333333375`, -8.479832078722627}, {166.01282525764455`, 
      3.3854166666666696`, -5.863713671457135}, {166.01282525764455`, 
      3.7616734527368947`, -5.6297421666318135`}}], 
     Polygon3DBox[{{166.01282525764455`, 
      3.3854166666666696`, -5.863713671457135}, {149.3461585909779, 
      4.8958333333333375`, -8.479832078722627}, {149.3461585909779, 
      4.330743425061055, -8.781878927507572}, {166.01282525764455`, 
      2.994663006691155, -6.072575854127576}, {166.01282525764455`, 
      3.3854166666666696`, -5.863713671457135}}], 
     Polygon3DBox[{{166.01282525764455`, 
      2.994663006691155, -6.072575854127576}, {149.3461585909779, 
      4.330743425061055, -8.781878927507572}, {149.3461585909779, 
      3.7471086085748344`, -9.04632042250635}, {166.01282525764455`, 
      2.59108573997196, -6.255434334711838}, {166.01282525764455`, 
      2.994663006691155, -6.072575854127576}}], 
     Polygon3DBox[{{166.01282525764455`, 
      2.5910857399719656`, -6.255434334711836}, {149.34615859097786`, 
      3.7471086085748424`, -9.046320422506348}, {149.3461585909779, 
      3.147428097760126, -9.272024184639575}, {166.01282525764455`, 
      2.1764130463234914`, -6.41150608512311}, {166.01282525764455`, 
      2.5910857399719656`, -6.255434334711836}}], 
     Polygon3DBox[{{166.01282525764455`, 
      2.1764130463234914`, -6.41150608512311}, {149.3461585909779, 
      3.147428097760126, -9.272024184639575}, {149.34615859097786`, 
      2.5342698166288478`, -9.458023715747128}, {166.01282525764455`, 
      1.7524206178816502`, -6.540122782165566}, {166.01282525764455`, 
      2.1764130463234914`, -6.41150608512311}}], 
     Polygon3DBox[{{166.01282525764455`, 
      1.752420617881656, -6.540122782165565}, {149.3461585909779, 
      2.534269816628856, -9.458023715747125}, {149.3461585909779, 
      1.9102594030745932`, -9.60352253728163}, {166.01282525764455`, 
      1.3209240553175379`, -6.640733669396871}, {166.01282525764455`, 
      1.752420617881656, -6.540122782165565}}], 
     Polygon3DBox[{{166.01282525764455`, 
      1.3209240553175379`, -6.640733669396871}, {149.3461585909779, 
      1.9102594030745932`, -9.60352253728163}, {149.3461585909779, 
      1.2780689654880055`, -9.707897600951894}, {166.01282525764455`, 
      0.8837710931565996, -6.712907915551841}, {166.01282525764455`, 
      1.3209240553175379`, -6.640733669396871}}], 
     Polygon3DBox[{{166.01282525764455`, 
      0.8837710931566054, -6.71290791555184}, {149.3461585909779, 
      1.278068965488014, -9.707897600951892}, {149.3461585909779, 
      0.6404056403784896, -9.770701956711326}, {166.01282525764455`, 
      0.4428336874957641, -6.756336459428045}, {166.01282525764455`, 
      0.8837710931566054, -6.71290791555184}}], 
     Polygon3DBox[{{166.01282525764455`, 
      0.4428336874957641, -6.756336459428045}, {149.3461585909779, 
      0.6404056403784896, -9.770701956711326}, {149.3461585909779, 
      1.798699986247675*^-15, -9.791666666666666}, {166.01282525764455`, 
      1.2437819053840304`*^-15, -6.770833333333333}, {166.01282525764455`, 
      0.4428336874957641, -6.756336459428045}}], 
     Polygon3DBox[{{166.01282525764455`, 
      1.2437819053840304`*^-15, -6.770833333333333}, {149.3461585909779, 
      1.798699986247675*^-15, -9.791666666666666}, {
      149.3461585909779, -0.640405640378486, -9.770701956711326}, {
      166.01282525764455`, -0.4428336874957616, -6.756336459428045}, {
      166.01282525764455`, 1.2437819053840304`*^-15, -6.770833333333333}}], 
     Polygon3DBox[{{
      166.01282525764455`, -0.4428336874957556, -6.756336459428045}, {
      149.3461585909779, -0.6404056403784774, -9.770701956711326}, {
      149.3461585909779, -1.278068965488002, -9.707897600951894}, {
      166.01282525764455`, -0.8837710931565971, -6.712907915551842}, {
      166.01282525764455`, -0.4428336874957556, -6.756336459428045}}], 
     Polygon3DBox[{{
      166.01282525764455`, -0.8837710931565971, -6.712907915551842}, {
      149.3461585909779, -1.278068965488002, -9.707897600951894}, {
      149.3461585909779, -1.9102594030745896`, -9.60352253728163}, {
      166.01282525764455`, -1.3209240553175352`, -6.640733669396873}, {
      166.01282525764455`, -0.8837710931565971, -6.712907915551842}}], 
     Polygon3DBox[{{
      166.01282525764452`, -1.3209240553175294`, -6.640733669396875}, {
      149.34615859097786`, -1.9102594030745808`, -9.603522537281634}, {
      149.3461585909779, -2.5342698166288447`, -9.458023715747128}, {
      166.01282525764455`, -1.752420617881648, -6.540122782165567}, {
      166.01282525764452`, -1.3209240553175294`, -6.640733669396875}}], 
     Polygon3DBox[{{
      166.01282525764455`, -1.752420617881648, -6.540122782165567}, {
      149.3461585909779, -2.5342698166288447`, -9.458023715747128}, {
      149.3461585909779, -3.147428097760123, -9.272024184639577}, {
      166.01282525764455`, -2.176413046323489, -6.411506085123111}, {
      166.01282525764455`, -1.752420617881648, -6.540122782165567}}], 
     Polygon3DBox[{{
      166.01282525764455`, -2.176413046323489, -6.411506085123111}, {
      149.3461585909779, -3.147428097760123, -9.272024184639577}, {
      149.3461585909779, -3.7471086085748393`, -9.046320422506348}, {
      166.01282525764455`, -2.5910857399719633`, -6.255434334711836}, {
      166.01282525764455`, -2.176413046323489, -6.411506085123111}}], 
     Polygon3DBox[{{
      166.01282525764455`, -2.591085739971958, -6.255434334711839}, {
      149.3461585909779, -3.7471086085748313`, -9.046320422506351}, {
      149.3461585909779, -4.330743425061051, -8.781878927507574}, {
      166.01282525764455`, -2.9946630066911526`, -6.072575854127578}, {
      166.01282525764455`, -2.591085739971958, -6.255434334711839}}], 
     Polygon3DBox[{{
      166.01282525764455`, -2.9946630066911526`, -6.072575854127578}, {
      149.3461585909779, -4.330743425061051, -8.781878927507574}, {
      149.3461585909779, -4.895833333333334, -8.479832078722628}, {
      166.01282525764455`, -3.3854166666666674`, -5.863713671457136}, {
      166.01282525764455`, -2.9946630066911526`, -6.072575854127578}}], 
     Polygon3DBox[{{
      166.01282525764455`, -3.385416666666662, -5.863713671457139}, {
      149.3461585909779, -4.895833333333327, -8.479832078722632}, {
      149.3461585909779, -5.439958531650268, -8.141473287129092}, {
      166.01282525764455`, -3.7616734527368876`, -5.629742166631818}, {
      166.01282525764455`, -3.385416666666662, -5.863713671457139}}], 
     Polygon3DBox[{{
      166.01282525764455`, -3.7616734527368876`, -5.629742166631818}, {
      149.3461585909779, -5.439958531650268, -8.141473287129092}, {
      149.3461585909779, -5.960788992377055, -7.768251457018344}, {
      166.01282525764455`, -4.1218221755798785`, -5.371663241555238}, {
      166.01282525764455`, -3.7616734527368876`, -5.629742166631818}}], 
     Polygon3DBox[{{
      166.01282525764455`, -4.121822175579874, -5.371663241555241}, {
      149.3461585909779, -5.960788992377049, -7.76825145701835}, {
      149.3461585909779, -6.456094439521503, -7.361764781564991}, {
      166.01282525764455`, -4.46432062307338, -5.090582029805579}, {
      166.01282525764455`, -4.121822175579874, -5.371663241555241}}], 
     Polygon3DBox[{{
      166.01282525764455`, -4.46432062307338, -5.090582029805579}, {
      149.3461585909779, -6.456094439521503, -7.361764781564991}, {
      149.3461585909779, -6.923753899118275, -6.923753899118278}, {
      166.01282525764455`, -4.787702164283914, -4.787702164283916}, {
      166.01282525764455`, -4.46432062307338, -5.090582029805579}}], 
     Polygon3DBox[{{
      166.01282525764455`, -4.787702164283914, -4.787702164283916}, {
      149.3461585909779, -6.923753899118275, -6.923753899118278}, {
      149.3461585909779, -7.361764781564987, -6.456094439521506}, {
      166.01282525764455`, -5.090582029805576, -4.464320623073382}, {
      166.01282525764455`, -4.787702164283914, -4.787702164283916}}], 
     Polygon3DBox[{{
      166.01282525764455`, -5.090582029805573, -4.4643206230733865`}, {
      149.3461585909779, -7.3617647815649825`, -6.456094439521513}, {
      149.3461585909779, -7.7682514570183425`, -5.960788992377058}, {
      166.01282525764455`, -5.371663241555236, -4.121822175579881}, {
      166.01282525764455`, -5.090582029805573, -4.4643206230733865`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -5.371663241555236, -4.121822175579881}, {
      149.3461585909779, -7.7682514570183425`, -5.960788992377058}, {
      149.3461585909779, -8.141473287129088, -5.439958531650271}, {
      166.01282525764455`, -5.629742166631816, -3.76167345273689}, {
      166.01282525764455`, -5.371663241555236, -4.121822175579881}}], 
     Polygon3DBox[{{
      166.01282525764455`, -5.6297421666318135`, -3.7616734527368947`}, {
      149.3461585909779, -8.141473287129084, -5.439958531650278}, {
      149.3461585909779, -8.479832078722627, -4.8958333333333375`}, {
      166.01282525764455`, -5.863713671457135, -3.3854166666666696`}, {
      166.01282525764455`, -5.6297421666318135`, -3.7616734527368947`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -5.863713671457135, -3.3854166666666696`}, {
      149.3461585909779, -8.479832078722627, -4.8958333333333375`}, {
      149.3461585909779, -8.781878927507572, -4.330743425061055}, {
      166.01282525764455`, -6.072575854127576, -2.9946630066911553`}, {
      166.01282525764455`, -5.863713671457135, -3.3854166666666696`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.072575854127574, -2.9946630066911606`}, {
      149.3461585909779, -8.781878927507568, -4.330743425061063}, {
      149.34615859097786`, -9.046320422506348, -3.7471086085748437`}, {
      166.01282525764455`, -6.255434334711836, -2.591085739971966}, {
      166.01282525764455`, -6.072575854127574, -2.9946630066911606`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.255434334711836, -2.591085739971966}, {
      149.34615859097786`, -9.046320422506348, -3.7471086085748437`}, {
      149.3461585909779, -9.272024184639575, -3.1474280977601263`}, {
      166.01282525764455`, -6.41150608512311, -2.176413046323492}, {
      166.01282525764455`, -6.255434334711836, -2.591085739971966}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.41150608512311, -2.176413046323492}, {
      149.3461585909779, -9.272024184639575, -3.1474280977601263`}, {
      149.34615859097786`, -9.458023715747128, -2.534269816628848}, {
      166.01282525764455`, -6.540122782165566, -1.7524206178816504`}, {
      166.01282525764455`, -6.41150608512311, -2.176413046323492}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.540122782165565, -1.7524206178816564`}, {
      149.3461585909779, -9.458023715747125, -2.534269816628857}, {
      149.3461585909779, -9.60352253728163, -1.9102594030745936`}, {
      166.01282525764455`, -6.640733669396871, -1.3209240553175383`}, {
      166.01282525764455`, -6.540122782165565, -1.7524206178816564`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.640733669396871, -1.3209240553175383`}, {
      149.3461585909779, -9.60352253728163, -1.9102594030745936`}, {
      149.3461585909779, -9.707897600951894, -1.2780689654880062`}, {
      166.01282525764455`, -6.712907915551841, -0.8837710931566}, {
      166.01282525764455`, -6.640733669396871, -1.3209240553175383`}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.71290791555184, -0.883771093156606}, {
      149.3461585909779, -9.707897600951892, -1.2780689654880146`}, {
      149.3461585909779, -9.770701956711326, -0.6404056403784901}, {
      166.01282525764455`, -6.756336459428045, -0.44283368749576446`}, {
      166.01282525764455`, -6.71290791555184, -0.883771093156606}}], 
     Polygon3DBox[{{
      166.01282525764455`, -6.756336459428045, -0.44283368749576446`}, {
      149.3461585909779, -9.770701956711326, -0.6404056403784901}, {
      149.3461585909779, -9.791666666666666, -2.398266648330233*^-15}, {
      166.01282525764455`, -6.770833333333333, -1.6583758738453742`*^-15}, {
      166.01282525764455`, -6.756336459428045, -0.44283368749576446`}}], 
     Polygon3DBox[{{149.3461585909779, -9.791666666666666, 0.}, {
      150., -12.8125, 0.}, {150., -12.785067453994607`, 0.8379775932612079}, {
      149.3461585909779, -9.770701956711326, 0.6404056403784841}, {
      149.3461585909779, -9.791666666666666, 0.}}], 
     Polygon3DBox[{{149.3461585909779, -9.770701956711326, 
      0.6404056403784841}, {150., -12.785067453994607`, 0.8379775932612079}, {
      149.99999999999997`, -12.702887286351945`, 1.672366837819411}, {
      149.3461585909779, -9.707897600951894, 1.2780689654880049`}, {
      149.3461585909779, -9.770701956711326, 0.6404056403784841}}], 
     Polygon3DBox[{{149.3461585909779, -9.707897600951894, 
      1.2780689654880049`}, {149.99999999999997`, -12.702887286351945`, 
      1.672366837819411}, {150., -12.56631140516639, 2.499594750831643}, {
      149.3461585909779, -9.60352253728163, 1.9102594030745887`}, {
      149.3461585909779, -9.707897600951894, 1.2780689654880049`}}], 
     Polygon3DBox[{{149.3461585909779, -9.60352253728163, 
      1.9102594030745887`}, {150., -12.56631140516639, 2.499594750831643}, {
      150., -12.375924649328688`, 3.3161190153760467`}, {
      149.34615859097786`, -9.458023715747128, 2.534269816628849}, {
      149.3461585909779, -9.60352253728163, 1.9102594030745887`}}], 
     Polygon3DBox[{{149.34615859097786`, -9.458023715747128, 
      2.534269816628849}, {150., -12.375924649328688`, 3.3161190153760467`}, {
      149.99999999999997`, -12.132542284156042`, 4.118443149196757}, {
      149.3461585909779, -9.272024184639577, 3.1474280977601232`}, {
      149.34615859097786`, -9.458023715747128, 2.534269816628849}}], 
     Polygon3DBox[{{149.3461585909779, -9.272024184639577, 
      3.1474280977601232`}, {149.99999999999997`, -12.132542284156042`, 
      4.118443149196757}, {149.99999999999997`, -11.837206510300863`, 
      4.903131477177713}, {149.3461585909779, -9.04632042250635, 
      3.7471086085748366`}, {149.3461585909779, -9.272024184639577, 
      3.1474280977601232`}}], 
     Polygon3DBox[{{149.3461585909779, -9.04632042250635, 
      3.7471086085748375`}, {149.99999999999997`, -11.837206510300863`, 
      4.903131477177713}, {150., -11.49118200088757, 5.6668238434309535`}, {
      149.3461585909779, -8.781878927507574, 4.330743425061054}, {
      149.3461585909779, -9.04632042250635, 3.7471086085748375`}}], 
     Polygon3DBox[{{149.3461585909779, -8.781878927507574, 
      4.330743425061054}, {150., -11.49118200088757, 5.6668238434309535`}, {
      150., -11.095950485988121`, 6.406249999999999}, {
      149.3461585909779, -8.479832078722628, 4.895833333333332}, {
      149.3461585909779, -8.781878927507574, 4.330743425061054}}], 
     Polygon3DBox[{{149.3461585909779, -8.479832078722628, 
      4.895833333333332}, {150., -11.095950485988121`, 6.406249999999999}, {
      150., -10.653204407626362`, 7.1182436105636535`}, {
      149.3461585909779, -8.141473287129088, 5.439958531650271}, {
      149.3461585909779, -8.479832078722628, 4.895833333333332}}], 
     Polygon3DBox[{{149.3461585909779, -8.141473287129088, 
      5.439958531650271}, {150., -10.653204407626362`, 7.1182436105636535`}, {
      150., -10.16483967248145, 7.799755809174233}, {
      149.3461585909779, -7.768251457018344, 5.960788992377056}, {
      149.3461585909779, -8.141473287129088, 5.439958531650271}}], 
     Polygon3DBox[{{149.3461585909779, -7.768251457018345, 
      5.960788992377055}, {150., -10.164839672481452`, 7.799755809174232}, {
      150., -9.632947533324398, 8.447868255969633}, {
      149.3461585909779, -7.361764781564987, 6.456094439521507}, {
      149.3461585909779, -7.768251457018345, 5.960788992377055}}], 
     Polygon3DBox[{{149.3461585909779, -7.361764781564987, 
      6.456094439521507}, {150., -9.632947533324398, 8.447868255969633}, {
      149.99999999999997`, -9.05980563395264, 9.059805633952639}, {
      149.3461585909779, -6.923753899118278, 6.923753899118276}, {
      149.3461585909779, -7.361764781564987, 6.456094439521507}}], 
     Polygon3DBox[{{149.3461585909779, -6.923753899118278, 
      6.923753899118276}, {149.99999999999997`, -9.05980563395264, 
      9.059805633952639}, {150., -8.447868255969633, 9.632947533324398}, {
      149.3461585909779, -6.456094439521507, 7.361764781564987}, {
      149.3461585909779, -6.923753899118278, 6.923753899118276}}], 
     Polygon3DBox[{{149.3461585909779, -6.456094439521508, 
      7.361764781564986}, {150., -8.447868255969635, 9.632947533324396}, {
      150., -7.799755809174233, 10.16483967248145}, {
      149.3461585909779, -5.960788992377056, 7.768251457018344}, {
      149.3461585909779, -6.456094439521508, 7.361764781564986}}], 
     Polygon3DBox[{{149.3461585909779, -5.960788992377056, 
      7.768251457018344}, {150., -7.799755809174233, 10.16483967248145}, {
      149.99999999999997`, -7.118243610563654, 10.653204407626362`}, {
      149.3461585909779, -5.439958531650272, 8.141473287129088}, {
      149.3461585909779, -5.960788992377056, 7.768251457018344}}], 
     Polygon3DBox[{{149.3461585909779, -5.439958531650273, 
      8.141473287129088}, {149.99999999999997`, -7.118243610563656, 
      10.65320440762636}, {150., -6.406250000000002, 11.09595048598812}, {
      149.3461585909779, -4.895833333333334, 8.479832078722628}, {
      149.3461585909779, -5.439958531650273, 8.141473287129088}}], 
     Polygon3DBox[{{149.3461585909779, -4.895833333333334, 
      8.479832078722628}, {150., -6.406250000000002, 11.09595048598812}, {
      150., -5.666823843430956, 11.491182000887568`}, {
      149.3461585909779, -4.330743425061056, 8.781878927507572}, {
      149.3461585909779, -4.895833333333334, 8.479832078722628}}], 
     Polygon3DBox[{{149.3461585909779, -4.330743425061056, 
      8.781878927507572}, {150., -5.666823843430956, 11.491182000887568`}, {
      149.99999999999997`, -4.903131477177716, 11.83720651030086}, {
      149.3461585909779, -3.7471086085748393`, 9.046320422506348}, {
      149.3461585909779, -4.330743425061056, 8.781878927507572}}], 
     Polygon3DBox[{{149.3461585909779, -3.747108608574838, 
      9.04632042250635}, {149.99999999999997`, -4.9031314771777135`, 
      11.837206510300863`}, {149.99999999999997`, -4.118443149196759, 
      12.13254228415604}, {149.3461585909779, -3.147428097760125, 
      9.272024184639575}, {149.3461585909779, -3.747108608574838, 
      9.04632042250635}}], 
     Polygon3DBox[{{149.3461585909779, -3.147428097760125, 
      9.272024184639575}, {149.99999999999997`, -4.118443149196759, 
      12.13254228415604}, {150., -3.3161190153760502`, 12.375924649328686`}, {
      149.3461585909779, -2.534269816628851, 9.458023715747126}, {
      149.3461585909779, -3.147428097760125, 9.272024184639575}}], 
     Polygon3DBox[{{149.3461585909779, -2.534269816628851, 
      9.458023715747126}, {150., -3.3161190153760502`, 12.375924649328686`}, {
      149.99999999999997`, -2.4995947508316467`, 12.56631140516639}, {
      149.3461585909779, -1.9102594030745919`, 9.60352253728163}, {
      149.3461585909779, -2.534269816628851, 9.458023715747126}}], 
     Polygon3DBox[{{149.3461585909779, -1.9102594030745899`, 
      9.60352253728163}, {150., -2.499594750831644, 12.56631140516639}, {
      149.99999999999997`, -1.6723668378194125`, 12.702887286351945`}, {
      149.3461585909779, -1.2780689654880062`, 9.707897600951894}, {
      149.3461585909779, -1.9102594030745899`, 9.60352253728163}}], 
     Polygon3DBox[{{149.3461585909779, -1.2780689654880062`, 
      9.707897600951894}, {149.99999999999997`, -1.6723668378194125`, 
      12.702887286351945`}, {150., -0.8379775932612106, 
      12.785067453994607`}, {149.3461585909779, -0.6404056403784861, 
      9.770701956711326}, {149.3461585909779, -1.2780689654880062`, 
      9.707897600951894}}], 
     Polygon3DBox[{{149.3461585909779, -0.6404056403784861, 
      9.770701956711326}, {150., -0.8379775932612106, 12.785067453994607`}, {
      150., -3.6294858563057365`*^-15, 12.8125}, {
      149.3461585909779, -2.7737534186401568`*^-15, 9.791666666666666}, {
      149.3461585909779, -0.6404056403784861, 9.770701956711326}}], 
     Polygon3DBox[{{149.3461585909779, -5.995666620825583*^-16, 
      9.791666666666666}, {150., -7.845393557037732*^-16, 12.8125}, {150., 
      0.8379775932612061, 12.785067453994607`}, {149.3461585909779, 
      0.6404056403784828, 9.770701956711326}, {
      149.3461585909779, -5.995666620825583*^-16, 9.791666666666666}}], 
     Polygon3DBox[{{149.3461585909779, 0.6404056403784828, 
      9.770701956711326}, {150., 0.8379775932612061, 12.785067453994607`}, {
      149.99999999999997`, 1.6723668378194083`, 12.702887286351945`}, {
      149.3461585909779, 1.278068965488003, 9.707897600951894}, {
      149.3461585909779, 0.6404056403784828, 9.770701956711326}}], 
     Polygon3DBox[{{149.3461585909779, 1.278068965488003, 
      9.707897600951894}, {149.99999999999997`, 1.6723668378194083`, 
      12.702887286351945`}, {149.99999999999997`, 2.4995947508316396`, 
      12.566311405166392`}, {149.3461585909779, 1.9102594030745863`, 
      9.60352253728163}, {149.3461585909779, 1.278068965488003, 
      9.707897600951894}}], 
     Polygon3DBox[{{149.3461585909779, 1.9102594030745863`, 
      9.60352253728163}, {149.99999999999997`, 2.4995947508316396`, 
      12.566311405166392`}, {149.99999999999997`, 3.3161190153760427`, 
      12.375924649328688`}, {149.3461585909779, 2.5342698166288455`, 
      9.458023715747128}, {149.3461585909779, 1.9102594030745863`, 
      9.60352253728163}}], 
     Polygon3DBox[{{149.34615859097786`, 2.5342698166288478`, 
      9.458023715747128}, {150., 3.316119015376046, 12.375924649328688`}, {
      150., 4.1184431491967555`, 12.132542284156042`}, {149.3461585909779, 
      3.1474280977601214`, 9.272024184639577}, {149.34615859097786`, 
      2.5342698166288478`, 9.458023715747128}}], 
     Polygon3DBox[{{149.3461585909779, 3.1474280977601214`, 
      9.272024184639577}, {150., 4.1184431491967555`, 12.132542284156042`}, {
      150., 4.903131477177709, 11.837206510300863`}, {149.3461585909779, 
      3.7471086085748344`, 9.04632042250635}, {149.3461585909779, 
      3.1474280977601214`, 9.272024184639577}}], 
     Polygon3DBox[{{149.3461585909779, 3.7471086085748344`, 
      9.04632042250635}, {150., 4.903131477177709, 11.837206510300863`}, {
      149.99999999999997`, 5.666823843430952, 11.49118200088757}, {
      149.3461585909779, 4.330743425061052, 8.781878927507574}, {
      149.3461585909779, 3.7471086085748344`, 9.04632042250635}}], 
     Polygon3DBox[{{149.3461585909779, 4.330743425061052, 
      8.781878927507574}, {149.99999999999997`, 5.666823843430952, 
      11.49118200088757}, {149.99999999999997`, 6.406249999999997, 
      11.095950485988121`}, {149.3461585909779, 4.895833333333331, 
      8.479832078722628}, {149.3461585909779, 4.330743425061052, 
      8.781878927507574}}], 
     Polygon3DBox[{{149.3461585909779, 4.895833333333331, 
      8.479832078722628}, {149.99999999999997`, 6.406249999999997, 
      11.095950485988121`}, {150., 7.11824361056365, 10.653204407626363`}, {
      149.34615859097786`, 5.439958531650269, 8.141473287129092}, {
      149.3461585909779, 4.895833333333331, 8.479832078722628}}], 
     Polygon3DBox[{{149.34615859097786`, 5.439958531650269, 
      8.141473287129092}, {150., 7.11824361056365, 10.653204407626363`}, {
      149.99999999999997`, 7.799755809174229, 10.164839672481454`}, {
      149.3461585909779, 5.960788992377053, 7.768251457018346}, {
      149.34615859097786`, 5.439958531650269, 8.141473287129092}}], 
     Polygon3DBox[{{149.3461585909779, 5.960788992377053, 
      7.768251457018346}, {149.99999999999997`, 7.799755809174229, 
      10.164839672481454`}, {150., 8.447868255969627, 9.632947533324401}, {
      149.3461585909779, 6.456094439521504, 7.36176478156499}, {
      149.3461585909779, 5.960788992377053, 7.768251457018346}}], 
     Polygon3DBox[{{149.3461585909779, 6.456094439521504, 7.36176478156499}, {
      150., 8.447868255969627, 9.632947533324401}, {150., 9.059805633952635, 
      9.059805633952646}, {149.3461585909779, 6.923753899118274, 
      6.923753899118282}, {149.3461585909779, 6.456094439521504, 
      7.36176478156499}}], 
     Polygon3DBox[{{149.3461585909779, 6.923753899118276, 
      6.923753899118278}, {149.99999999999997`, 9.059805633952639, 
      9.05980563395264}, {150., 9.632947533324396, 8.447868255969635}, {
      149.3461585909779, 7.361764781564986, 6.456094439521508}, {
      149.3461585909779, 6.923753899118276, 6.923753899118278}}], 
     Polygon3DBox[{{149.3461585909779, 7.361764781564986, 
      6.456094439521508}, {150., 9.632947533324396, 8.447868255969635}, {150.,
       10.164839672481449`, 7.799755809174236}, {149.3461585909779, 
      7.7682514570183425`, 5.960788992377058}, {149.3461585909779, 
      7.361764781564986, 6.456094439521508}}], 
     Polygon3DBox[{{149.3461585909779, 7.7682514570183425`, 
      5.960788992377058}, {150., 10.164839672481449`, 7.799755809174236}, {
      150., 10.653204407626358`, 7.118243610563657}, {149.3461585909779, 
      8.141473287129086, 5.439958531650275}, {149.3461585909779, 
      7.7682514570183425`, 5.960788992377058}}], 
     Polygon3DBox[{{149.3461585909779, 8.141473287129086, 
      5.439958531650275}, {150., 10.653204407626358`, 7.118243610563657}, {
      150., 11.095950485988118`, 6.4062500000000036`}, {149.3461585909779, 
      8.479832078722627, 4.895833333333336}, {149.3461585909779, 
      8.141473287129086, 5.439958531650275}}], 
     Polygon3DBox[{{149.3461585909779, 8.479832078722627, 
      4.895833333333336}, {150., 11.095950485988118`, 6.4062500000000036`}, {
      149.99999999999997`, 11.491182000887568`, 5.66682384343096}, {
      149.34615859097786`, 8.781878927507572, 4.330743425061058}, {
      149.3461585909779, 8.479832078722627, 4.895833333333336}}], 
     Polygon3DBox[{{149.34615859097786`, 8.781878927507572, 
      4.330743425061058}, {149.99999999999997`, 11.491182000887568`, 
      5.66682384343096}, {150., 11.83720651030086, 4.903131477177719}, {
      149.3461585909779, 9.046320422506348, 3.747108608574842}, {
      149.34615859097786`, 8.781878927507572, 4.330743425061058}}], 
     Polygon3DBox[{{149.3461585909779, 9.04632042250635, 
      3.7471086085748384`}, {149.99999999999997`, 11.837206510300863`, 
      4.903131477177714}, {149.99999999999997`, 12.13254228415604, 
      4.11844314919676}, {149.3461585909779, 9.272024184639575, 
      3.1474280977601254`}, {149.3461585909779, 9.04632042250635, 
      3.7471086085748384`}}], 
     Polygon3DBox[{{149.3461585909779, 9.272024184639575, 
      3.1474280977601254`}, {149.99999999999997`, 12.13254228415604, 
      4.11844314919676}, {150., 12.375924649328686`, 3.3161190153760507`}, {
      149.3461585909779, 9.458023715747126, 2.5342698166288518`}, {
      149.3461585909779, 9.272024184639575, 3.1474280977601254`}}], 
     Polygon3DBox[{{149.3461585909779, 9.458023715747126, 
      2.5342698166288518`}, {150., 12.375924649328686`, 
      3.3161190153760507`}, {149.99999999999997`, 12.56631140516639, 
      2.4995947508316476`}, {149.3461585909779, 9.60352253728163, 
      1.9102594030745925`}, {149.3461585909779, 9.458023715747126, 
      2.5342698166288518`}}], 
     Polygon3DBox[{{149.3461585909779, 9.60352253728163, 
      1.9102594030745925`}, {149.99999999999997`, 12.56631140516639, 
      2.4995947508316476`}, {150., 12.702887286351945`, 
      1.6723668378194163`}, {149.3461585909779, 9.707897600951894, 
      1.278068965488009}, {149.3461585909779, 9.60352253728163, 
      1.9102594030745925`}}], 
     Polygon3DBox[{{149.3461585909779, 9.707897600951894, 
      1.278068965488009}, {150., 12.702887286351945`, 1.6723668378194163`}, {
      150., 12.785067453994607`, 0.8379775932612143}, {149.3461585909779, 
      9.770701956711326, 0.640405640378489}, {149.3461585909779, 
      9.707897600951894, 1.278068965488009}}], 
     Polygon3DBox[{{149.3461585909779, 9.770701956711326, 
      0.640405640378489}, {150., 12.785067453994607`, 0.8379775932612143}, {
      150., 12.8125, 7.258971712611473*^-15}, {149.3461585909779, 
      9.791666666666666, 5.5475068372803135`*^-15}, {149.3461585909779, 
      9.770701956711326, 0.640405640378489}}], 
     Polygon3DBox[{{149.3461585909779, 9.791666666666666, 
      1.1991333241651166`*^-15}, {150., 12.8125, 1.5690787114075465`*^-15}, {
      150., 12.785067453994607`, -0.8379775932612055}, {149.3461585909779, 
      9.770701956711326, -0.6404056403784822}, {149.3461585909779, 
      9.791666666666666, 1.1991333241651166`*^-15}}], 
     Polygon3DBox[{{149.3461585909779, 
      9.770701956711326, -0.6404056403784822}, {150., 
      12.785067453994607`, -0.8379775932612055}, {149.99999999999997`, 
      12.702887286351945`, -1.6723668378194074`}, {149.3461585909779, 
      9.707897600951894, -1.2780689654880024`}, {149.3461585909779, 
      9.770701956711326, -0.6404056403784822}}], 
     Polygon3DBox[{{149.3461585909779, 
      9.707897600951894, -1.2780689654880024`}, {149.99999999999997`, 
      12.702887286351945`, -1.6723668378194074`}, {150., 
      12.566311405166392`, -2.4995947508316387`}, {149.34615859097786`, 
      9.60352253728163, -1.9102594030745859`}, {149.3461585909779, 
      9.707897600951894, -1.2780689654880024`}}], 
     Polygon3DBox[{{149.34615859097786`, 
      9.60352253728163, -1.9102594030745859`}, {150., 
      12.566311405166392`, -2.4995947508316387`}, {149.99999999999997`, 
      12.375924649328688`, -3.316119015376042}, {149.3461585909779, 
      9.458023715747128, -2.534269816628845}, {149.34615859097786`, 
      9.60352253728163, -1.9102594030745859`}}], 
     Polygon3DBox[{{149.3461585909779, 
      9.458023715747128, -2.534269816628845}, {149.99999999999997`, 
      12.375924649328688`, -3.316119015376042}, {149.99999999999997`, 
      12.132542284156042`, -4.118443149196751}, {149.3461585909779, 
      9.272024184639577, -3.147428097760119}, {149.3461585909779, 
      9.458023715747128, -2.534269816628845}}], 
     Polygon3DBox[{{149.3461585909779, 
      9.272024184639577, -3.147428097760119}, {149.99999999999997`, 
      12.132542284156042`, -4.118443149196751}, {149.99999999999997`, 
      11.837206510300865`, -4.9031314771777055`}, {149.3461585909779, 
      9.046320422506351, -3.747108608574832}, {149.3461585909779, 
      9.272024184639577, -3.147428097760119}}], 
     Polygon3DBox[{{149.3461585909779, 
      9.046320422506351, -3.747108608574832}, {149.99999999999997`, 
      11.837206510300865`, -4.9031314771777055`}, {150., 
      11.491182000887573`, -5.666823843430947}, {149.3461585909779, 
      8.781878927507575, -4.330743425061049}, {149.3461585909779, 
      9.046320422506351, -3.747108608574832}}], 
     Polygon3DBox[{{149.3461585909779, 
      8.781878927507574, -4.330743425061051}, {149.99999999999997`, 
      11.49118200088757, -5.666823843430951}, {150., 
      11.095950485988123`, -6.4062499999999964`}, {149.3461585909779, 
      8.47983207872263, -4.89583333333333}, {149.3461585909779, 
      8.781878927507574, -4.330743425061051}}], 
     Polygon3DBox[{{149.3461585909779, 8.47983207872263, -4.89583333333333}, {
      150., 11.095950485988123`, -6.4062499999999964`}, {150., 
      10.653204407626363`, -7.11824361056365}, {149.34615859097786`, 
      8.141473287129092, -5.439958531650269}, {149.3461585909779, 
      8.47983207872263, -4.89583333333333}}], 
     Polygon3DBox[{{149.34615859097786`, 
      8.141473287129092, -5.439958531650269}, {150., 
      10.653204407626363`, -7.11824361056365}, {149.99999999999997`, 
      10.164839672481454`, -7.799755809174229}, {149.3461585909779, 
      7.768251457018346, -5.960788992377053}, {149.34615859097786`, 
      8.141473287129092, -5.439958531650269}}], 
     Polygon3DBox[{{149.3461585909779, 
      7.768251457018346, -5.960788992377053}, {149.99999999999997`, 
      10.164839672481454`, -7.799755809174229}, {150., 
      9.632947533324401, -8.447868255969627}, {149.3461585909779, 
      7.36176478156499, -6.456094439521504}, {149.3461585909779, 
      7.768251457018346, -5.960788992377053}}], 
     Polygon3DBox[{{149.3461585909779, 
      7.36176478156499, -6.456094439521504}, {150., 
      9.632947533324401, -8.447868255969627}, {150., 
      9.059805633952646, -9.059805633952635}, {149.3461585909779, 
      6.923753899118282, -6.923753899118274}, {149.3461585909779, 
      7.36176478156499, -6.456094439521504}}], 
     Polygon3DBox[{{149.3461585909779, 
      6.923753899118282, -6.923753899118274}, {150., 
      9.059805633952646, -9.059805633952635}, {150., 
      8.447868255969638, -9.632947533324392}, {149.3461585909779, 
      6.456094439521513, -7.3617647815649825`}, {149.3461585909779, 
      6.923753899118282, -6.923753899118274}}], 
     Polygon3DBox[{{149.3461585909779, 
      6.456094439521509, -7.361764781564986}, {150., 
      8.447868255969635, -9.632947533324396}, {149.99999999999997`, 
      7.799755809174236, -10.164839672481447`}, {149.3461585909779, 
      5.960788992377058, -7.7682514570183425`}, {149.3461585909779, 
      6.456094439521509, -7.361764781564986}}], 
     Polygon3DBox[{{149.3461585909779, 
      5.960788992377058, -7.7682514570183425`}, {149.99999999999997`, 
      7.799755809174236, -10.164839672481447`}, {150., 
      7.1182436105636535`, -10.653204407626362`}, {149.3461585909779, 
      5.439958531650271, -8.141473287129088}, {149.3461585909779, 
      5.960788992377058, -7.7682514570183425`}}], 
     Polygon3DBox[{{149.3461585909779, 
      5.439958531650278, -8.141473287129084}, {150., 
      7.118243610563662, -10.653204407626355`}, {149.99999999999997`, 
      6.406250000000006, -11.095950485988116`}, {149.3461585909779, 
      4.8958333333333375`, -8.479832078722627}, {149.3461585909779, 
      5.439958531650278, -8.141473287129084}}], 
     Polygon3DBox[{{149.3461585909779, 
      4.8958333333333375`, -8.479832078722627}, {149.99999999999997`, 
      6.406250000000006, -11.095950485988116`}, {149.99999999999997`, 
      5.666823843430954, -11.491182000887568`}, {149.3461585909779, 
      4.330743425061055, -8.781878927507572}, {149.3461585909779, 
      4.8958333333333375`, -8.479832078722627}}], 
     Polygon3DBox[{{149.3461585909779, 
      4.330743425061055, -8.781878927507572}, {149.99999999999997`, 
      5.666823843430954, -11.491182000887568`}, {150., 
      4.903131477177709, -11.837206510300863`}, {149.3461585909779, 
      3.7471086085748344`, -9.04632042250635}, {149.3461585909779, 
      4.330743425061055, -8.781878927507572}}], 
     Polygon3DBox[{{149.34615859097786`, 
      3.7471086085748424`, -9.046320422506348}, {149.99999999999997`, 
      4.90313147717772, -11.83720651030086}, {150., 
      4.118443149196761, -12.13254228415604}, {149.3461585909779, 
      3.147428097760126, -9.272024184639575}, {149.34615859097786`, 
      3.7471086085748424`, -9.046320422506348}}], 
     Polygon3DBox[{{149.3461585909779, 
      3.147428097760126, -9.272024184639575}, {150., 
      4.118443149196761, -12.13254228415604}, {150., 
      3.316119015376046, -12.375924649328688`}, {149.34615859097786`, 
      2.5342698166288478`, -9.458023715747128}, {149.3461585909779, 
      3.147428097760126, -9.272024184639575}}], 
     Polygon3DBox[{{149.3461585909779, 
      2.534269816628856, -9.458023715747125}, {150., 
      3.316119015376057, -12.375924649328685`}, {149.99999999999997`, 
      2.4995947508316485`, -12.566311405166388`}, {149.3461585909779, 
      1.9102594030745932`, -9.60352253728163}, {149.3461585909779, 
      2.534269816628856, -9.458023715747125}}], 
     Polygon3DBox[{{149.3461585909779, 
      1.9102594030745932`, -9.60352253728163}, {149.99999999999997`, 
      2.4995947508316485`, -12.566311405166388`}, {149.99999999999997`, 
      1.6723668378194114`, -12.702887286351945`}, {149.3461585909779, 
      1.2780689654880055`, -9.707897600951894}, {149.3461585909779, 
      1.9102594030745932`, -9.60352253728163}}], 
     Polygon3DBox[{{149.3461585909779, 
      1.278068965488014, -9.707897600951892}, {149.99999999999997`, 
      1.6723668378194225`, -12.702887286351944`}, {150., 
      0.8379775932612151, -12.785067453994607`}, {149.3461585909779, 
      0.6404056403784896, -9.770701956711326}, {149.3461585909779, 
      1.278068965488014, -9.707897600951892}}], 
     Polygon3DBox[{{149.3461585909779, 
      0.6404056403784896, -9.770701956711326}, {150., 
      0.8379775932612151, -12.785067453994607`}, {150., 
      2.3536180671113193`*^-15, -12.8125}, {149.3461585909779, 
      1.798699986247675*^-15, -9.791666666666666}, {149.3461585909779, 
      0.6404056403784896, -9.770701956711326}}], 
     Polygon3DBox[{{149.3461585909779, 
      1.798699986247675*^-15, -9.791666666666666}, {150., 
      2.3536180671113193`*^-15, -12.8125}, {
      150., -0.8379775932612105, -12.785067453994607`}, {
      149.3461585909779, -0.640405640378486, -9.770701956711326}, {
      149.3461585909779, 1.798699986247675*^-15, -9.791666666666666}}], 
     Polygon3DBox[{{
      149.3461585909779, -0.6404056403784774, -9.770701956711326}, {
      150., -0.8379775932611991, -12.785067453994609`}, {
      149.99999999999997`, -1.6723668378194068`, -12.702887286351945`}, {
      149.3461585909779, -1.278068965488002, -9.707897600951894}, {
      149.3461585909779, -0.6404056403784774, -9.770701956711326}}], 
     Polygon3DBox[{{
      149.3461585909779, -1.278068965488002, -9.707897600951894}, {
      149.99999999999997`, -1.6723668378194068`, -12.702887286351945`}, {
      150., -2.499594750831644, -12.56631140516639}, {
      149.3461585909779, -1.9102594030745896`, -9.60352253728163}, {
      149.3461585909779, -1.278068965488002, -9.707897600951894}}], 
     Polygon3DBox[{{
      149.34615859097786`, -1.9102594030745808`, -9.603522537281634}, {
      149.99999999999997`, -2.4995947508316325`, -12.566311405166394`}, {
      149.99999999999997`, -3.3161190153760414`, -12.375924649328688`}, {
      149.3461585909779, -2.5342698166288447`, -9.458023715747128}, {
      149.34615859097786`, -1.9102594030745808`, -9.603522537281634}}], 
     Polygon3DBox[{{
      149.3461585909779, -2.5342698166288447`, -9.458023715747128}, {
      149.99999999999997`, -3.3161190153760414`, -12.375924649328688`}, {
      150., -4.118443149196756, -12.132542284156042`}, {
      149.3461585909779, -3.147428097760123, -9.272024184639577}, {
      149.3461585909779, -2.5342698166288447`, -9.458023715747128}}], 
     Polygon3DBox[{{
      149.3461585909779, -3.147428097760123, -9.272024184639577}, {
      150., -4.118443149196756, -12.132542284156042`}, {
      149.99999999999997`, -4.903131477177716, -11.83720651030086}, {
      149.3461585909779, -3.7471086085748393`, -9.046320422506348}, {
      149.3461585909779, -3.147428097760123, -9.272024184639577}}], 
     Polygon3DBox[{{
      149.3461585909779, -3.7471086085748313`, -9.046320422506351}, {
      149.99999999999997`, -4.9031314771777055`, -11.837206510300865`}, {
      149.99999999999997`, -5.666823843430951, -11.491182000887571`}, {
      149.3461585909779, -4.330743425061051, -8.781878927507574}, {
      149.3461585909779, -3.7471086085748313`, -9.046320422506351}}], 
     Polygon3DBox[{{
      149.3461585909779, -4.330743425061051, -8.781878927507574}, {
      149.99999999999997`, -5.666823843430951, -11.491182000887571`}, {
      150., -6.406250000000002, -11.09595048598812}, {
      149.3461585909779, -4.895833333333334, -8.479832078722628}, {
      149.3461585909779, -4.330743425061051, -8.781878927507574}}], 
     Polygon3DBox[{{
      149.3461585909779, -4.895833333333327, -8.479832078722632}, {
      150., -6.406249999999991, -11.095950485988125`}, {
      150., -7.118243610563649, -10.653204407626363`}, {
      149.3461585909779, -5.439958531650268, -8.141473287129092}, {
      149.3461585909779, -4.895833333333327, -8.479832078722632}}], 
     Polygon3DBox[{{
      149.3461585909779, -5.439958531650268, -8.141473287129092}, {
      150., -7.118243610563649, -10.653204407626363`}, {
      150., -7.799755809174232, -10.16483967248145}, {
      149.3461585909779, -5.960788992377055, -7.768251457018344}, {
      149.3461585909779, -5.439958531650268, -8.141473287129092}}], 
     Polygon3DBox[{{
      149.3461585909779, -5.960788992377049, -7.76825145701835}, {
      150., -7.799755809174224, -10.164839672481458`}, {
      150., -8.447868255969627, -9.632947533324403}, {
      149.3461585909779, -6.456094439521503, -7.361764781564991}, {
      149.3461585909779, -5.960788992377049, -7.76825145701835}}], 
     Polygon3DBox[{{
      149.3461585909779, -6.456094439521503, -7.361764781564991}, {
      150., -8.447868255969627, -9.632947533324403}, {
      150., -9.059805633952639, -9.059805633952642}, {
      149.3461585909779, -6.923753899118275, -6.923753899118278}, {
      149.3461585909779, -6.456094439521503, -7.361764781564991}}], 
     Polygon3DBox[{{
      149.3461585909779, -6.923753899118275, -6.923753899118278}, {
      150., -9.059805633952639, -9.059805633952642}, {
      149.99999999999997`, -9.632947533324398, -8.447868255969631}, {
      149.3461585909779, -7.361764781564987, -6.456094439521506}, {
      149.3461585909779, -6.923753899118275, -6.923753899118278}}], 
     Polygon3DBox[{{
      149.3461585909779, -7.3617647815649825`, -6.456094439521513}, {
      150., -9.632947533324392, -8.447868255969638}, {
      149.99999999999997`, -10.164839672481447`, -7.799755809174236}, {
      149.3461585909779, -7.7682514570183425`, -5.960788992377058}, {
      149.3461585909779, -7.3617647815649825`, -6.456094439521513}}], 
     Polygon3DBox[{{
      149.3461585909779, -7.7682514570183425`, -5.960788992377058}, {
      149.99999999999997`, -10.164839672481447`, -7.799755809174236}, {
      150., -10.653204407626362`, -7.1182436105636535`}, {
      149.3461585909779, -8.141473287129088, -5.439958531650271}, {
      149.3461585909779, -7.7682514570183425`, -5.960788992377058}}], 
     Polygon3DBox[{{
      149.3461585909779, -8.141473287129084, -5.439958531650278}, {
      150., -10.653204407626355`, -7.118243610563662}, {
      149.99999999999997`, -11.095950485988116`, -6.406250000000006}, {
      149.3461585909779, -8.479832078722627, -4.8958333333333375`}, {
      149.3461585909779, -8.141473287129084, -5.439958531650278}}], 
     Polygon3DBox[{{
      149.3461585909779, -8.479832078722627, -4.8958333333333375`}, {
      149.99999999999997`, -11.095950485988116`, -6.406250000000006}, {
      150., -11.491182000887568`, -5.666823843430956}, {
      149.3461585909779, -8.781878927507572, -4.330743425061055}, {
      149.3461585909779, -8.479832078722627, -4.8958333333333375`}}], 
     Polygon3DBox[{{
      149.3461585909779, -8.781878927507568, -4.330743425061063}, {
      150., -11.491182000887562`, -5.666823843430966}, {
      149.99999999999997`, -11.83720651030086, -4.903131477177721}, {
      149.34615859097786`, -9.046320422506348, -3.7471086085748437`}, {
      149.3461585909779, -8.781878927507568, -4.330743425061063}}], 
     Polygon3DBox[{{
      149.34615859097786`, -9.046320422506348, -3.7471086085748437`}, {
      149.99999999999997`, -11.83720651030086, -4.903131477177721}, {
      150., -12.13254228415604, -4.118443149196761}, {
      149.3461585909779, -9.272024184639575, -3.1474280977601263`}, {
      149.34615859097786`, -9.046320422506348, -3.7471086085748437`}}], 
     Polygon3DBox[{{
      149.3461585909779, -9.272024184639575, -3.1474280977601263`}, {
      150., -12.13254228415604, -4.118443149196761}, {
      150., -12.375924649328688`, -3.3161190153760463`}, {
      149.34615859097786`, -9.458023715747128, -2.534269816628848}, {
      149.3461585909779, -9.272024184639575, -3.1474280977601263`}}], 
     Polygon3DBox[{{
      149.3461585909779, -9.458023715747125, -2.534269816628857}, {
      150., -12.375924649328685`, -3.3161190153760574`}, {
      149.99999999999997`, -12.566311405166388`, -2.4995947508316494`}, {
      149.3461585909779, -9.60352253728163, -1.9102594030745936`}, {
      149.3461585909779, -9.458023715747125, -2.534269816628857}}], 
     Polygon3DBox[{{
      149.3461585909779, -9.60352253728163, -1.9102594030745936`}, {
      149.99999999999997`, -12.566311405166388`, -2.4995947508316494`}, {
      149.99999999999997`, -12.702887286351945`, -1.6723668378194123`}, {
      149.3461585909779, -9.707897600951894, -1.2780689654880062`}, {
      149.3461585909779, -9.60352253728163, -1.9102594030745936`}}], 
     Polygon3DBox[{{
      149.3461585909779, -9.707897600951892, -1.2780689654880146`}, {
      150., -12.702887286351944`, -1.6723668378194234`}, {
      150., -12.785067453994607`, -0.8379775932612158}, {
      149.3461585909779, -9.770701956711326, -0.6404056403784901}, {
      149.3461585909779, -9.707897600951892, -1.2780689654880146`}}], 
     Polygon3DBox[{{
      149.3461585909779, -9.770701956711326, -0.6404056403784901}, {
      150., -12.785067453994607`, -0.8379775932612158}, {
      150., -12.8125, -3.138157422815093*^-15}, {
      149.3461585909779, -9.791666666666666, -2.398266648330233*^-15}, {
      149.3461585909779, -9.770701956711326, -0.6404056403784901}}], 
     Polygon3DBox[{{150., -12.8125, 0.}, {
      150.65384140902208`, -15.833333333333332`, 0.}, {
      150.65384140902208`, -15.79943295127789, 1.0355495461439317`}, {
      150., -12.785067453994607`, 0.8379775932612079}, {150., -12.8125, 0.}}],
      Polygon3DBox[{{150., -12.785067453994607`, 0.8379775932612079}, {
      150.65384140902208`, -15.79943295127789, 1.0355495461439317`}, {
      150.65384140902208`, -15.697876971751997`, 2.0666647101508167`}, {
      149.99999999999997`, -12.702887286351945`, 1.672366837819411}, {
      150., -12.785067453994607`, 0.8379775932612079}}], 
     Polygon3DBox[{{149.99999999999997`, -12.702887286351945`, 
      1.672366837819411}, {150.65384140902208`, -15.697876971751997`, 
      2.0666647101508167`}, {150.65384140902208`, -15.529100273051148`, 
      3.0889300985886967`}, {150., -12.56631140516639, 2.499594750831643}, {
      149.99999999999997`, -12.702887286351945`, 1.672366837819411}}], 
     Polygon3DBox[{{150., -12.56631140516639, 2.499594750831643}, {
      150.65384140902208`, -15.529100273051148`, 3.0889300985886967`}, {
      150.65384140902208`, -15.293825582910248`, 4.097968214123245}, {
      150., -12.375924649328688`, 3.3161190153760467`}, {
      150., -12.56631140516639, 2.499594750831643}}], 
     Polygon3DBox[{{150., -12.375924649328688`, 3.3161190153760467`}, {
      150.65384140902208`, -15.293825582910248`, 4.097968214123245}, {
      150.65384140902208`, -14.993060383672507`, 5.08945820063339}, {
      149.99999999999997`, -12.132542284156042`, 4.118443149196757}, {
      150., -12.375924649328688`, 3.3161190153760467`}}], 
     Polygon3DBox[{{149.99999999999997`, -12.132542284156042`, 
      4.118443149196757}, {150.65384140902208`, -14.993060383672507`, 
      5.08945820063339}, {150.65384140902208`, -14.628092598095375`, 
      6.059154345780587}, {149.99999999999997`, -11.837206510300863`, 
      4.903131477177713}, {149.99999999999997`, -12.132542284156042`, 
      4.118443149196757}}], 
     Polygon3DBox[{{149.99999999999997`, -11.837206510300863`, 
      4.903131477177713}, {150.65384140902208`, -14.628092598095375`, 
      6.059154345780588}, {150.65384140902208`, -14.200485074267565`, 
      7.002904261800853}, {150., -11.49118200088757, 5.6668238434309535`}, {
      149.99999999999997`, -11.837206510300863`, 4.903131477177713}}], 
     Polygon3DBox[{{150., -11.49118200088757, 5.6668238434309535`}, {
      150.65384140902208`, -14.200485074267565`, 7.002904261800853}, {
      150.65384140902208`, -13.712068893253612`, 7.916666666666665}, {
      150., -11.095950485988121`, 6.406249999999999}, {
      150., -11.49118200088757, 5.6668238434309535`}}], 
     Polygon3DBox[{{150., -11.095950485988121`, 6.406249999999999}, {
      150.65384140902208`, -13.712068893253612`, 7.916666666666665}, {
      150.65384140902208`, -13.164935528123632`, 8.796528689477036}, {
      150., -10.653204407626362`, 7.1182436105636535`}, {
      150., -11.095950485988121`, 6.406249999999999}}], 
     Polygon3DBox[{{150., -10.653204407626362`, 7.1182436105636535`}, {
      150.65384140902208`, -13.164935528123632`, 8.796528689477036}, {
      150.65384140902208`, -12.561427887944555`, 9.63872262597141}, {
      150., -10.16483967248145, 7.799755809174233}, {
      150., -10.653204407626362`, 7.1182436105636535`}}], 
     Polygon3DBox[{{150., -10.164839672481452`, 7.799755809174232}, {
      150.65384140902208`, -12.561427887944557`, 9.638722625971408}, {
      150.65384140902208`, -11.90413028508381, 10.439642072417756`}, {
      150., -9.632947533324398, 8.447868255969633}, {
      150., -10.164839672481452`, 7.799755809174232}}], 
     Polygon3DBox[{{150., -9.632947533324398, 8.447868255969633}, {
      150.65384140902208`, -11.90413028508381, 10.439642072417756`}, {
      150.65384140902208`, -11.195857368787003`, 11.195857368787001`}, {
      149.99999999999997`, -9.05980563395264, 9.059805633952639}, {
      150., -9.632947533324398, 8.447868255969633}}], 
     Polygon3DBox[{{149.99999999999997`, -9.05980563395264, 
      9.059805633952639}, {150.65384140902208`, -11.195857368787003`, 
      11.195857368787001`}, {150.65384140902208`, -10.439642072417756`, 
      11.90413028508381}, {150., -8.447868255969633, 9.632947533324398}, {
      149.99999999999997`, -9.05980563395264, 9.059805633952639}}], 
     Polygon3DBox[{{150., -8.447868255969635, 9.632947533324396}, {
      150.65384140902208`, -10.439642072417758`, 11.904130285083806`}, {
      150.65384140902208`, -9.63872262597141, 12.561427887944555`}, {
      150., -7.799755809174233, 10.16483967248145}, {150., -8.447868255969635,
       9.632947533324396}}], 
     Polygon3DBox[{{150., -7.799755809174233, 10.16483967248145}, {
      150.65384140902208`, -9.63872262597141, 12.561427887944555`}, {
      150.65384140902208`, -8.796528689477036, 13.164935528123632`}, {
      149.99999999999997`, -7.118243610563654, 10.653204407626362`}, {
      150., -7.799755809174233, 10.16483967248145}}], 
     Polygon3DBox[{{149.99999999999997`, -7.118243610563656, 
      10.65320440762636}, {150.65384140902208`, -8.796528689477038, 
      13.164935528123632`}, {150.65384140902208`, -7.916666666666668, 
      13.712068893253612`}, {150., -6.406250000000002, 11.09595048598812}, {
      149.99999999999997`, -7.118243610563656, 10.65320440762636}}], 
     Polygon3DBox[{{150., -6.406250000000002, 11.09595048598812}, {
      150.65384140902208`, -7.916666666666668, 13.712068893253612`}, {
      150.65384140902208`, -7.002904261800856, 14.200485074267563`}, {
      150., -5.666823843430956, 11.491182000887568`}, {
      150., -6.406250000000002, 11.09595048598812}}], 
     Polygon3DBox[{{150., -5.666823843430956, 11.491182000887568`}, {
      150.65384140902208`, -7.002904261800856, 14.200485074267563`}, {
      150.65384140902208`, -6.059154345780591, 14.628092598095371`}, {
      149.99999999999997`, -4.903131477177716, 11.83720651030086}, {
      150., -5.666823843430956, 11.491182000887568`}}], 
     Polygon3DBox[{{149.99999999999997`, -4.9031314771777135`, 
      11.837206510300863`}, {150.6538414090221, -6.059154345780589, 
      14.628092598095375`}, {150.65384140902208`, -5.089458200633393, 
      14.993060383672503`}, {149.99999999999997`, -4.118443149196759, 
      12.13254228415604}, {149.99999999999997`, -4.9031314771777135`, 
      11.837206510300863`}}], 
     Polygon3DBox[{{149.99999999999997`, -4.118443149196759, 
      12.13254228415604}, {150.65384140902208`, -5.089458200633393, 
      14.993060383672503`}, {150.65384140902208`, -4.097968214123249, 
      15.293825582910246`}, {150., -3.3161190153760502`, 
      12.375924649328686`}, {149.99999999999997`, -4.118443149196759, 
      12.13254228415604}}], 
     Polygon3DBox[{{150., -3.3161190153760502`, 12.375924649328686`}, {
      150.65384140902208`, -4.097968214123249, 15.293825582910246`}, {
      150.65384140902208`, -3.0889300985887016`, 15.529100273051148`}, {
      149.99999999999997`, -2.4995947508316467`, 12.56631140516639}, {
      150., -3.3161190153760502`, 12.375924649328686`}}], 
     Polygon3DBox[{{150., -2.499594750831644, 12.56631140516639}, {
      150.65384140902208`, -3.0889300985886985`, 15.529100273051148`}, {
      150.65384140902208`, -2.0666647101508184`, 15.697876971751997`}, {
      149.99999999999997`, -1.6723668378194125`, 12.702887286351945`}, {
      150., -2.499594750831644, 12.56631140516639}}], 
     Polygon3DBox[{{149.99999999999997`, -1.6723668378194125`, 
      12.702887286351945`}, {150.65384140902208`, -2.0666647101508184`, 
      15.697876971751997`}, {150.65384140902208`, -1.035549546143935, 
      15.79943295127789}, {150., -0.8379775932612106, 12.785067453994607`}, {
      149.99999999999997`, -1.6723668378194125`, 12.702887286351945`}}], 
     Polygon3DBox[{{150., -0.8379775932612106, 12.785067453994607`}, {
      150.65384140902208`, -1.035549546143935, 15.79943295127789}, {
      150.65384140902208`, -4.485218293971317*^-15, 15.833333333333332`}, {
      150., -3.6294858563057365`*^-15, 12.8125}, {150., -0.8379775932612106, 
      12.785067453994607`}}], 
     Polygon3DBox[{{150., -7.845393557037732*^-16, 12.8125}, {
      150.65384140902208`, -9.69512049324988*^-16, 15.833333333333332`}, {
      150.65384140902208`, 1.0355495461439295`, 15.79943295127789}, {150., 
      0.8379775932612061, 12.785067453994607`}, {
      150., -7.845393557037732*^-16, 12.8125}}], 
     Polygon3DBox[{{150., 0.8379775932612061, 12.785067453994607`}, {
      150.65384140902208`, 1.0355495461439295`, 15.79943295127789}, {
      150.65384140902208`, 2.0666647101508135`, 15.697876971751999`}, {
      149.99999999999997`, 1.6723668378194083`, 12.702887286351945`}, {150., 
      0.8379775932612061, 12.785067453994607`}}], 
     Polygon3DBox[{{149.99999999999997`, 1.6723668378194083`, 
      12.702887286351945`}, {150.65384140902208`, 2.0666647101508135`, 
      15.697876971751999`}, {150.65384140902208`, 3.0889300985886927`, 
      15.52910027305115}, {149.99999999999997`, 2.4995947508316396`, 
      12.566311405166392`}, {149.99999999999997`, 1.6723668378194083`, 
      12.702887286351945`}}], 
     Polygon3DBox[{{149.99999999999997`, 2.4995947508316396`, 
      12.566311405166392`}, {150.65384140902208`, 3.0889300985886927`, 
      15.52910027305115}, {150.65384140902208`, 4.097968214123239, 
      15.293825582910248`}, {149.99999999999997`, 3.3161190153760427`, 
      12.375924649328688`}, {149.99999999999997`, 2.4995947508316396`, 
      12.566311405166392`}}], 
     Polygon3DBox[{{150., 3.316119015376046, 12.375924649328688`}, {
      150.65384140902208`, 4.097968214123243, 15.293825582910248`}, {
      150.65384140902208`, 5.089458200633388, 14.993060383672507`}, {150., 
      4.1184431491967555`, 12.132542284156042`}, {150., 3.316119015376046, 
      12.375924649328688`}}], 
     Polygon3DBox[{{150., 4.1184431491967555`, 12.132542284156042`}, {
      150.65384140902208`, 5.089458200633388, 14.993060383672507`}, {
      150.65384140902208`, 6.059154345780583, 14.628092598095375`}, {150., 
      4.903131477177709, 11.837206510300863`}, {150., 4.1184431491967555`, 
      12.132542284156042`}}], 
     Polygon3DBox[{{150., 4.903131477177709, 11.837206510300863`}, {
      150.65384140902208`, 6.059154345780583, 14.628092598095375`}, {
      150.65384140902208`, 7.00290426180085, 14.200485074267565`}, {
      149.99999999999997`, 5.666823843430952, 11.49118200088757}, {150., 
      4.903131477177709, 11.837206510300863`}}], 
     Polygon3DBox[{{149.99999999999997`, 5.666823843430952, 
      11.49118200088757}, {150.65384140902208`, 7.00290426180085, 
      14.200485074267565`}, {150.65384140902208`, 7.916666666666663, 
      13.712068893253612`}, {149.99999999999997`, 6.406249999999997, 
      11.095950485988121`}, {149.99999999999997`, 5.666823843430952, 
      11.49118200088757}}], 
     Polygon3DBox[{{149.99999999999997`, 6.406249999999997, 
      11.095950485988121`}, {150.65384140902208`, 7.916666666666663, 
      13.712068893253612`}, {150.65384140902208`, 8.79652868947703, 
      13.164935528123637`}, {150., 7.11824361056365, 10.653204407626363`}, {
      149.99999999999997`, 6.406249999999997, 11.095950485988121`}}], 
     Polygon3DBox[{{150., 7.11824361056365, 10.653204407626363`}, {
      150.65384140902208`, 8.79652868947703, 13.164935528123637`}, {
      150.65384140902208`, 9.638722625971406, 12.56142788794456}, {
      149.99999999999997`, 7.799755809174229, 10.164839672481454`}, {150., 
      7.11824361056365, 10.653204407626363`}}], 
     Polygon3DBox[{{149.99999999999997`, 7.799755809174229, 
      10.164839672481454`}, {150.65384140902208`, 9.638722625971406, 
      12.56142788794456}, {150.65384140902208`, 10.439642072417751`, 
      11.904130285083813`}, {150., 8.447868255969627, 9.632947533324401}, {
      149.99999999999997`, 7.799755809174229, 10.164839672481454`}}], 
     Polygon3DBox[{{150., 8.447868255969627, 9.632947533324401}, {
      150.65384140902208`, 10.439642072417751`, 11.904130285083813`}, {
      150.65384140902208`, 11.195857368786996`, 11.195857368787008`}, {150., 
      9.059805633952635, 9.059805633952646}, {150., 8.447868255969627, 
      9.632947533324401}}], 
     Polygon3DBox[{{149.99999999999997`, 9.059805633952639, 
      9.05980563395264}, {150.65384140902208`, 11.195857368787001`, 
      11.195857368787003`}, {150.65384140902208`, 11.904130285083806`, 
      10.439642072417758`}, {150., 9.632947533324396, 8.447868255969635}, {
      149.99999999999997`, 9.059805633952639, 9.05980563395264}}], 
     Polygon3DBox[{{150., 9.632947533324396, 8.447868255969635}, {
      150.65384140902208`, 11.904130285083806`, 10.439642072417758`}, {
      150.65384140902208`, 12.561427887944554`, 9.638722625971413}, {150., 
      10.164839672481449`, 7.799755809174236}, {150., 9.632947533324396, 
      8.447868255969635}}], 
     Polygon3DBox[{{150., 10.164839672481449`, 7.799755809174236}, {
      150.65384140902208`, 12.561427887944554`, 9.638722625971413}, {
      150.65384140902208`, 13.164935528123628`, 8.79652868947704}, {150., 
      10.653204407626358`, 7.118243610563657}, {150., 10.164839672481449`, 
      7.799755809174236}}], 
     Polygon3DBox[{{150., 10.653204407626358`, 7.118243610563657}, {
      150.65384140902208`, 13.164935528123628`, 8.79652868947704}, {
      150.65384140902208`, 13.712068893253608`, 7.916666666666671}, {150., 
      11.095950485988118`, 6.4062500000000036`}, {150., 10.653204407626358`, 
      7.118243610563657}}], 
     Polygon3DBox[{{150., 11.095950485988118`, 6.4062500000000036`}, {
      150.65384140902208`, 13.712068893253608`, 7.916666666666671}, {
      150.65384140902208`, 14.200485074267563`, 7.00290426180086}, {
      149.99999999999997`, 11.491182000887568`, 5.66682384343096}, {150., 
      11.095950485988118`, 6.4062500000000036`}}], 
     Polygon3DBox[{{149.99999999999997`, 11.491182000887568`, 
      5.66682384343096}, {150.65384140902208`, 14.200485074267563`, 
      7.00290426180086}, {150.65384140902208`, 14.628092598095371`, 
      6.059154345780596}, {150., 11.83720651030086, 4.903131477177719}, {
      149.99999999999997`, 11.491182000887568`, 5.66682384343096}}], 
     Polygon3DBox[{{149.99999999999997`, 11.837206510300863`, 
      4.903131477177714}, {150.6538414090221, 14.628092598095375`, 
      6.059154345780589}, {150.65384140902208`, 14.993060383672503`, 
      5.089458200633395}, {149.99999999999997`, 12.13254228415604, 
      4.11844314919676}, {149.99999999999997`, 11.837206510300863`, 
      4.903131477177714}}], 
     Polygon3DBox[{{149.99999999999997`, 12.13254228415604, 
      4.11844314919676}, {150.65384140902208`, 14.993060383672503`, 
      5.089458200633395}, {150.65384140902208`, 15.293825582910246`, 
      4.09796821412325}, {150., 12.375924649328686`, 3.3161190153760507`}, {
      149.99999999999997`, 12.13254228415604, 4.11844314919676}}], 
     Polygon3DBox[{{150., 12.375924649328686`, 3.3161190153760507`}, {
      150.65384140902208`, 15.293825582910246`, 4.09796821412325}, {
      150.65384140902208`, 15.529100273051148`, 3.088930098588703}, {
      149.99999999999997`, 12.56631140516639, 2.4995947508316476`}, {150., 
      12.375924649328686`, 3.3161190153760507`}}], 
     Polygon3DBox[{{149.99999999999997`, 12.56631140516639, 
      2.4995947508316476`}, {150.65384140902208`, 15.529100273051148`, 
      3.088930098588703}, {150.65384140902208`, 15.697876971751997`, 
      2.0666647101508233`}, {150., 12.702887286351945`, 
      1.6723668378194163`}, {149.99999999999997`, 12.56631140516639, 
      2.4995947508316476`}}], 
     Polygon3DBox[{{150., 12.702887286351945`, 1.6723668378194163`}, {
      150.65384140902208`, 15.697876971751997`, 2.0666647101508233`}, {
      150.65384140902208`, 15.79943295127789, 1.0355495461439397`}, {150., 
      12.785067453994607`, 0.8379775932612143}, {150., 12.702887286351945`, 
      1.6723668378194163`}}], 
     Polygon3DBox[{{150., 12.785067453994607`, 0.8379775932612143}, {
      150.65384140902208`, 15.79943295127789, 1.0355495461439397`}, {
      150.65384140902208`, 15.833333333333332`, 8.970436587942634*^-15}, {
      150., 12.8125, 7.258971712611473*^-15}, {150., 12.785067453994607`, 
      0.8379775932612143}}], 
     Polygon3DBox[{{150., 12.8125, 1.5690787114075465`*^-15}, {
      150.65384140902208`, 15.833333333333332`, 1.939024098649976*^-15}, {
      150.65384140902208`, 15.79943295127789, -1.0355495461439288`}, {150., 
      12.785067453994607`, -0.8379775932612055}, {150., 12.8125, 
      1.5690787114075465`*^-15}}], 
     Polygon3DBox[{{150., 12.785067453994607`, -0.8379775932612055}, {
      150.65384140902208`, 15.79943295127789, -1.0355495461439288`}, {
      150.65384140902208`, 15.697876971751999`, -2.0666647101508127`}, {
      149.99999999999997`, 12.702887286351945`, -1.6723668378194074`}, {150., 
      12.785067453994607`, -0.8379775932612055}}], 
     Polygon3DBox[{{149.99999999999997`, 
      12.702887286351945`, -1.6723668378194074`}, {150.65384140902208`, 
      15.697876971751999`, -2.0666647101508127`}, {150.65384140902208`, 
      15.52910027305115, -3.0889300985886923`}, {150., 
      12.566311405166392`, -2.4995947508316387`}, {149.99999999999997`, 
      12.702887286351945`, -1.6723668378194074`}}], 
     Polygon3DBox[{{150., 12.566311405166392`, -2.4995947508316387`}, {
      150.65384140902208`, 15.52910027305115, -3.0889300985886923`}, {
      150.65384140902208`, 15.293825582910248`, -4.097968214123239}, {
      149.99999999999997`, 12.375924649328688`, -3.316119015376042}, {150., 
      12.566311405166392`, -2.4995947508316387`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      12.375924649328688`, -3.316119015376042}, {150.65384140902208`, 
      15.293825582910248`, -4.097968214123239}, {150.65384140902208`, 
      14.993060383672507`, -5.089458200633383}, {149.99999999999997`, 
      12.132542284156042`, -4.118443149196751}, {149.99999999999997`, 
      12.375924649328688`, -3.316119015376042}}], 
     Polygon3DBox[{{149.99999999999997`, 
      12.132542284156042`, -4.118443149196751}, {150.65384140902208`, 
      14.993060383672507`, -5.089458200633383}, {150.65384140902208`, 
      14.628092598095376`, -6.05915434578058}, {149.99999999999997`, 
      11.837206510300865`, -4.9031314771777055`}, {149.99999999999997`, 
      12.132542284156042`, -4.118443149196751}}], 
     Polygon3DBox[{{149.99999999999997`, 
      11.837206510300865`, -4.9031314771777055`}, {150.65384140902208`, 
      14.628092598095376`, -6.05915434578058}, {150.65384140902208`, 
      14.200485074267569`, -7.002904261800845}, {150., 
      11.491182000887573`, -5.666823843430947}, {149.99999999999997`, 
      11.837206510300865`, -4.9031314771777055`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      11.49118200088757, -5.666823843430951}, {150.65384140902208`, 
      14.200485074267565`, -7.0029042618008495`}, {150.65384140902208`, 
      13.712068893253614`, -7.916666666666662}, {150., 
      11.095950485988123`, -6.4062499999999964`}, {149.99999999999997`, 
      11.49118200088757, -5.666823843430951}}], 
     Polygon3DBox[{{150., 11.095950485988123`, -6.4062499999999964`}, {
      150.65384140902208`, 13.712068893253614`, -7.916666666666662}, {
      150.65384140902208`, 13.164935528123637`, -8.79652868947703}, {150., 
      10.653204407626363`, -7.11824361056365}, {150., 
      11.095950485988123`, -6.4062499999999964`}}], 
     Polygon3DBox[{{150., 10.653204407626363`, -7.11824361056365}, {
      150.65384140902208`, 13.164935528123637`, -8.79652868947703}, {
      150.65384140902208`, 12.56142788794456, -9.638722625971406}, {
      149.99999999999997`, 10.164839672481454`, -7.799755809174229}, {150., 
      10.653204407626363`, -7.11824361056365}}], 
     Polygon3DBox[{{149.99999999999997`, 
      10.164839672481454`, -7.799755809174229}, {150.65384140902208`, 
      12.56142788794456, -9.638722625971406}, {150.65384140902208`, 
      11.904130285083813`, -10.439642072417751`}, {150., 
      9.632947533324401, -8.447868255969627}, {149.99999999999997`, 
      10.164839672481454`, -7.799755809174229}}], 
     Polygon3DBox[{{150., 9.632947533324401, -8.447868255969627}, {
      150.65384140902208`, 11.904130285083813`, -10.439642072417751`}, {
      150.65384140902208`, 11.195857368787008`, -11.195857368786996`}, {150., 
      9.059805633952646, -9.059805633952635}, {150., 
      9.632947533324401, -8.447868255969627}}], 
     Polygon3DBox[{{150., 9.059805633952646, -9.059805633952635}, {
      150.65384140902208`, 11.195857368787008`, -11.195857368786996`}, {
      150.65384140902208`, 10.439642072417765`, -11.904130285083802`}, {150., 
      8.447868255969638, -9.632947533324392}, {150., 
      9.059805633952646, -9.059805633952635}}], 
     Polygon3DBox[{{150., 8.447868255969635, -9.632947533324396}, {
      150.65384140902208`, 10.43964207241776, -11.904130285083806`}, {
      150.65384140902208`, 9.638722625971413, -12.561427887944554`}, {
      149.99999999999997`, 7.799755809174236, -10.164839672481447`}, {150., 
      8.447868255969635, -9.632947533324396}}], 
     Polygon3DBox[{{149.99999999999997`, 
      7.799755809174236, -10.164839672481447`}, {150.65384140902208`, 
      9.638722625971413, -12.561427887944554`}, {150.65384140902208`, 
      8.796528689477036, -13.164935528123632`}, {150., 
      7.1182436105636535`, -10.653204407626362`}, {149.99999999999997`, 
      7.799755809174236, -10.164839672481447`}}], 
     Polygon3DBox[{{150., 7.118243610563662, -10.653204407626355`}, {
      150.65384140902208`, 8.796528689477046, -13.164935528123625`}, {
      150.65384140902208`, 7.916666666666674, -13.712068893253608`}, {
      149.99999999999997`, 6.406250000000006, -11.095950485988116`}, {150., 
      7.118243610563662, -10.653204407626355`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      6.406250000000006, -11.095950485988116`}, {150.65384140902208`, 
      7.916666666666674, -13.712068893253608`}, {150.65384140902208`, 
      7.002904261800854, -14.200485074267563`}, {149.99999999999997`, 
      5.666823843430954, -11.491182000887568`}, {149.99999999999997`, 
      6.406250000000006, -11.095950485988116`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      5.666823843430954, -11.491182000887568`}, {150.65384140902208`, 
      7.002904261800854, -14.200485074267563`}, {150.65384140902208`, 
      6.059154345780583, -14.628092598095375`}, {150., 
      4.903131477177709, -11.837206510300863`}, {149.99999999999997`, 
      5.666823843430954, -11.491182000887568`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      4.90313147717772, -11.83720651030086}, {150.65384140902208`, 
      6.0591543457805965`, -14.628092598095371`}, {150.65384140902208`, 
      5.089458200633395, -14.993060383672503`}, {150., 
      4.118443149196761, -12.13254228415604}, {149.99999999999997`, 
      4.90313147717772, -11.83720651030086}}], 
     Polygon3DBox[{{150., 4.118443149196761, -12.13254228415604}, {
      150.65384140902208`, 5.089458200633395, -14.993060383672503`}, {
      150.65384140902208`, 4.097968214123243, -15.293825582910248`}, {150., 
      3.316119015376046, -12.375924649328688`}, {150., 
      4.118443149196761, -12.13254228415604}}], 
     Polygon3DBox[{{150., 3.316119015376057, -12.375924649328685`}, {
      150.65384140902208`, 4.097968214123258, -15.293825582910245`}, {
      150.65384140902208`, 3.088930098588704, -15.529100273051146`}, {
      149.99999999999997`, 2.4995947508316485`, -12.566311405166388`}, {150., 
      3.316119015376057, -12.375924649328685`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      2.4995947508316485`, -12.566311405166388`}, {150.65384140902208`, 
      3.088930098588704, -15.529100273051146`}, {150.65384140902208`, 
      2.0666647101508175`, -15.697876971751997`}, {149.99999999999997`, 
      1.6723668378194114`, -12.702887286351945`}, {149.99999999999997`, 
      2.4995947508316485`, -12.566311405166388`}}], 
     Polygon3DBox[{{149.99999999999997`, 
      1.6723668378194225`, -12.702887286351944`}, {150.65384140902208`, 
      2.066664710150831, -15.697876971751995`}, {150.65384140902208`, 
      1.0355495461439406`, -15.79943295127789}, {150., 
      0.8379775932612151, -12.785067453994607`}, {149.99999999999997`, 
      1.6723668378194225`, -12.702887286351944`}}], 
     Polygon3DBox[{{150., 0.8379775932612151, -12.785067453994607`}, {
      150.65384140902208`, 1.0355495461439406`, -15.79943295127789}, {
      150.65384140902208`, 2.9085361479749633`*^-15, -15.833333333333332`}, {
      150., 2.3536180671113193`*^-15, -12.8125}, {150., 
      0.8379775932612151, -12.785067453994607`}}], 
     Polygon3DBox[{{150., 2.3536180671113193`*^-15, -12.8125}, {
      150.65384140902208`, 2.9085361479749633`*^-15, -15.833333333333332`}, {
      150.65384140902208`, -1.0355495461439348`, -15.79943295127789}, {
      150., -0.8379775932612105, -12.785067453994607`}, {150., 
      2.3536180671113193`*^-15, -12.8125}}], 
     Polygon3DBox[{{150., -0.8379775932611991, -12.785067453994609`}, {
      150.65384140902208`, -1.0355495461439208`, -15.79943295127789}, {
      150.65384140902208`, -2.0666647101508118`, -15.697876971751999`}, {
      149.99999999999997`, -1.6723668378194068`, -12.702887286351945`}, {
      150., -0.8379775932611991, -12.785067453994609`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -1.6723668378194068`, -12.702887286351945`}, {
      150.65384140902208`, -2.0666647101508118`, -15.697876971751999`}, {
      150.65384140902208`, -3.088930098588698, -15.529100273051148`}, {
      150., -2.499594750831644, -12.56631140516639}, {
      149.99999999999997`, -1.6723668378194068`, -12.702887286351945`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -2.4995947508316325`, -12.566311405166394`}, {
      150.65384140902208`, -3.088930098588684, -15.529100273051153`}, {
      150.65384140902208`, -4.097968214123238, -15.293825582910248`}, {
      149.99999999999997`, -3.3161190153760414`, -12.375924649328688`}, {
      149.99999999999997`, -2.4995947508316325`, -12.566311405166394`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -3.3161190153760414`, -12.375924649328688`}, {
      150.65384140902208`, -4.097968214123238, -15.293825582910248`}, {
      150.65384140902208`, -5.0894582006333895`, -14.993060383672507`}, {
      150., -4.118443149196756, -12.132542284156042`}, {
      149.99999999999997`, -3.3161190153760414`, -12.375924649328688`}}], 
     Polygon3DBox[{{150., -4.118443149196756, -12.132542284156042`}, {
      150.65384140902208`, -5.0894582006333895`, -14.993060383672507`}, {
      150.65384140902208`, -6.059154345780591, -14.628092598095371`}, {
      149.99999999999997`, -4.903131477177716, -11.83720651030086}, {
      150., -4.118443149196756, -12.132542284156042`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -4.9031314771777055`, -11.837206510300865`}, {
      150.65384140902208`, -6.059154345780579, -14.628092598095376`}, {
      150.65384140902208`, -7.0029042618008495`, -14.200485074267567`}, {
      149.99999999999997`, -5.666823843430951, -11.491182000887571`}, {
      149.99999999999997`, -4.9031314771777055`, -11.837206510300865`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -5.666823843430951, -11.491182000887571`}, {
      150.65384140902208`, -7.0029042618008495`, -14.200485074267567`}, {
      150.65384140902208`, -7.916666666666668, -13.712068893253612`}, {
      150., -6.406250000000002, -11.09595048598812}, {
      149.99999999999997`, -5.666823843430951, -11.491182000887571`}}], 
     Polygon3DBox[{{150., -6.406249999999991, -11.095950485988125`}, {
      150.65384140902208`, -7.916666666666655, -13.712068893253617`}, {
      150.65384140902208`, -8.796528689477029, -13.164935528123637`}, {
      150., -7.118243610563649, -10.653204407626363`}, {
      150., -6.406249999999991, -11.095950485988125`}}], 
     Polygon3DBox[{{150., -7.118243610563649, -10.653204407626363`}, {
      150.65384140902208`, -8.796528689477029, -13.164935528123637`}, {
      150.65384140902208`, -9.638722625971408, -12.561427887944555`}, {
      150., -7.799755809174232, -10.16483967248145}, {
      150., -7.118243610563649, -10.653204407626363`}}], 
     Polygon3DBox[{{150., -7.799755809174224, -10.164839672481458`}, {
      150.65384140902208`, -9.638722625971397, -12.561427887944564`}, {
      150.65384140902208`, -10.43964207241775, -11.904130285083815`}, {
      150., -8.447868255969627, -9.632947533324403}, {
      150., -7.799755809174224, -10.164839672481458`}}], 
     Polygon3DBox[{{150., -8.447868255969627, -9.632947533324403}, {
      150.65384140902208`, -10.43964207241775, -11.904130285083815`}, {
      150.65384140902208`, -11.195857368787, -11.195857368787003`}, {
      150., -9.059805633952639, -9.059805633952642}, {
      150., -8.447868255969627, -9.632947533324403}}], 
     Polygon3DBox[{{150., -9.059805633952639, -9.059805633952642}, {
      150.65384140902208`, -11.195857368787, -11.195857368787003`}, {
      150.65384140902208`, -11.90413028508381, -10.439642072417755`}, {
      149.99999999999997`, -9.632947533324398, -8.447868255969631}, {
      150., -9.059805633952639, -9.059805633952642}}], 
     Polygon3DBox[{{150., -9.632947533324392, -8.447868255969638}, {
      150.65384140902208`, -11.904130285083802`, -10.439642072417765`}, {
      150.65384140902208`, -12.561427887944554`, -9.638722625971413}, {
      149.99999999999997`, -10.164839672481447`, -7.799755809174236}, {
      150., -9.632947533324392, -8.447868255969638}}], 
     Polygon3DBox[{{
      149.99999999999997`, -10.164839672481447`, -7.799755809174236}, {
      150.65384140902208`, -12.561427887944554`, -9.638722625971413}, {
      150.65384140902208`, -13.164935528123632`, -8.796528689477036}, {
      150., -10.653204407626362`, -7.1182436105636535`}, {
      149.99999999999997`, -10.164839672481447`, -7.799755809174236}}], 
     Polygon3DBox[{{150., -10.653204407626355`, -7.118243610563662}, {
      150.65384140902208`, -13.164935528123625`, -8.796528689477046}, {
      150.65384140902208`, -13.712068893253608`, -7.916666666666674}, {
      149.99999999999997`, -11.095950485988116`, -6.406250000000006}, {
      150., -10.653204407626355`, -7.118243610563662}}], 
     Polygon3DBox[{{
      149.99999999999997`, -11.095950485988116`, -6.406250000000006}, {
      150.65384140902208`, -13.712068893253608`, -7.916666666666674}, {
      150.65384140902208`, -14.200485074267563`, -7.002904261800856}, {
      150., -11.491182000887568`, -5.666823843430956}, {
      149.99999999999997`, -11.095950485988116`, -6.406250000000006}}], 
     Polygon3DBox[{{150., -11.491182000887562`, -5.666823843430966}, {
      150.65384140902208`, -14.200485074267556`, -7.002904261800868}, {
      150.6538414090221, -14.628092598095371`, -6.059154345780598}, {
      149.99999999999997`, -11.83720651030086, -4.903131477177721}, {
      150., -11.491182000887562`, -5.666823843430966}}], 
     Polygon3DBox[{{
      149.99999999999997`, -11.83720651030086, -4.903131477177721}, {
      150.6538414090221, -14.628092598095371`, -6.059154345780598}, {
      150.65384140902208`, -14.993060383672503`, -5.089458200633396}, {
      150., -12.13254228415604, -4.118443149196761}, {
      149.99999999999997`, -11.83720651030086, -4.903131477177721}}], 
     Polygon3DBox[{{150., -12.13254228415604, -4.118443149196761}, {
      150.65384140902208`, -14.993060383672503`, -5.089458200633396}, {
      150.65384140902208`, -15.293825582910248`, -4.097968214123243}, {
      150., -12.375924649328688`, -3.3161190153760463`}, {
      150., -12.13254228415604, -4.118443149196761}}], 
     Polygon3DBox[{{150., -12.375924649328685`, -3.3161190153760574`}, {
      150.65384140902208`, -15.293825582910245`, -4.097968214123258}, {
      150.65384140902208`, -15.529100273051146`, -3.0889300985887047`}, {
      149.99999999999997`, -12.566311405166388`, -2.4995947508316494`}, {
      150., -12.375924649328685`, -3.3161190153760574`}}], 
     Polygon3DBox[{{
      149.99999999999997`, -12.566311405166388`, -2.4995947508316494`}, {
      150.65384140902208`, -15.529100273051146`, -3.0889300985887047`}, {
      150.65384140902208`, -15.697876971751997`, -2.0666647101508184`}, {
      149.99999999999997`, -12.702887286351945`, -1.6723668378194123`}, {
      149.99999999999997`, -12.566311405166388`, -2.4995947508316494`}}], 
     Polygon3DBox[{{150., -12.702887286351944`, -1.6723668378194234`}, {
      150.65384140902208`, -15.697876971751995`, -2.066664710150832}, {
      150.65384140902208`, -15.79943295127789, -1.0355495461439415`}, {
      150., -12.785067453994607`, -0.8379775932612158}, {
      150., -12.702887286351944`, -1.6723668378194234`}}], 
     Polygon3DBox[{{150., -12.785067453994607`, -0.8379775932612158}, {
      150.65384140902208`, -15.79943295127789, -1.0355495461439415`}, {
      150.65384140902208`, -15.833333333333332`, -3.878048197299952*^-15}, {
      150., -12.8125, -3.138157422815093*^-15}, {
      150., -12.785067453994607`, -0.8379775932612158}}], 
     Polygon3DBox[{{150.65384140902208`, -15.833333333333332`, 0.}, {
      133.98717474235545`, -18.854166666666664`, 0.}, {
      133.98717474235545`, -18.81379844856117, 1.2331214990266555`}, {
      150.65384140902208`, -15.79943295127789, 1.0355495461439317`}, {
      150.65384140902208`, -15.833333333333332`, 0.}}], 
     Polygon3DBox[{{150.65384140902208`, -15.79943295127789, 
      1.0355495461439317`}, {133.98717474235545`, -18.81379844856117, 
      1.2331214990266555`}, {133.98717474235545`, -18.69286665715205, 
      2.4609625824822223`}, {150.65384140902208`, -15.697876971751997`, 
      2.0666647101508167`}, {150.65384140902208`, -15.79943295127789, 
      1.0355495461439317`}}], 
     Polygon3DBox[{{150.65384140902208`, -15.697876971751997`, 
      2.0666647101508167`}, {133.98717474235545`, -18.69286665715205, 
      2.4609625824822223`}, {133.98717474235542`, -18.491889140935907`, 
      3.6782654463457507`}, {150.65384140902208`, -15.529100273051148`, 
      3.0889300985886967`}, {150.65384140902208`, -15.697876971751997`, 
      2.0666647101508167`}}], 
     Polygon3DBox[{{150.65384140902208`, -15.529100273051148`, 
      3.0889300985886967`}, {133.98717474235542`, -18.491889140935907`, 
      3.6782654463457507`}, {133.98717474235542`, -18.211726516491808`, 
      4.879817412870443}, {150.65384140902208`, -15.293825582910248`, 
      4.097968214123245}, {150.65384140902208`, -15.529100273051148`, 
      3.0889300985886967`}}], 
     Polygon3DBox[{{150.65384140902208`, -15.293825582910248`, 
      4.097968214123245}, {133.98717474235542`, -18.211726516491808`, 
      4.879817412870443}, {133.98717474235548`, -17.85357848318897, 
      6.060473252070024}, {150.65384140902208`, -14.993060383672507`, 
      5.08945820063339}, {150.65384140902208`, -15.293825582910248`, 
      4.097968214123245}}], 
     Polygon3DBox[{{150.65384140902208`, -14.993060383672507`, 
      5.08945820063339}, {133.98717474235548`, -17.85357848318897, 
      6.060473252070024}, {133.98717474235542`, -17.418978685889886`, 
      7.215177214383462}, {150.65384140902208`, -14.628092598095375`, 
      6.059154345780587}, {150.65384140902208`, -14.993060383672507`, 
      5.08945820063339}}], 
     Polygon3DBox[{{150.65384140902208`, -14.628092598095375`, 
      6.059154345780588}, {133.98717474235542`, -17.418978685889886`, 
      7.215177214383463}, {133.98717474235542`, -16.90978814764756, 
      8.338984680170752}, {150.65384140902208`, -14.200485074267565`, 
      7.002904261800853}, {150.65384140902208`, -14.628092598095375`, 
      6.059154345780588}}], 
     Polygon3DBox[{{150.65384140902208`, -14.200485074267565`, 
      7.002904261800853}, {133.98717474235542`, -16.90978814764756, 
      8.338984680170752}, {133.98717474235542`, -16.328187300519104`, 
      9.42708333333333}, {150.65384140902208`, -13.712068893253612`, 
      7.916666666666665}, {150.65384140902208`, -14.200485074267565`, 
      7.002904261800853}}], 
     Polygon3DBox[{{150.65384140902208`, -13.712068893253612`, 
      7.916666666666665}, {133.98717474235542`, -16.328187300519104`, 
      9.42708333333333}, {133.98717474235545`, -15.676666648620904`, 
      10.474813768390415`}, {150.65384140902208`, -13.164935528123632`, 
      8.796528689477036}, {150.65384140902208`, -13.712068893253612`, 
      7.916666666666665}}], 
     Polygon3DBox[{{150.65384140902208`, -13.164935528123632`, 
      8.796528689477036}, {133.98717474235545`, -15.676666648620904`, 
      10.474813768390415`}, {133.98717474235545`, -14.958016103407662`, 
      11.477689442768586`}, {150.65384140902208`, -12.561427887944555`, 
      9.63872262597141}, {150.65384140902208`, -13.164935528123632`, 
      8.796528689477036}}], 
     Polygon3DBox[{{150.65384140902208`, -12.561427887944557`, 
      9.638722625971408}, {133.98717474235542`, -14.958016103407665`, 
      11.477689442768586`}, {133.98717474235545`, -14.175313036843217`, 
      12.431415888865882`}, {150.65384140902208`, -11.90413028508381, 
      10.439642072417756`}, {150.65384140902208`, -12.561427887944557`, 
      9.638722625971408}}], 
     Polygon3DBox[{{150.65384140902208`, -11.90413028508381, 
      10.439642072417756`}, {133.98717474235545`, -14.175313036843217`, 
      12.431415888865882`}, {133.98717474235545`, -13.331909103621363`, 
      13.331909103621363`}, {150.65384140902208`, -11.195857368787003`, 
      11.195857368787001`}, {150.65384140902208`, -11.90413028508381, 
      10.439642072417756`}}], 
     Polygon3DBox[{{150.65384140902208`, -11.195857368787003`, 
      11.195857368787001`}, {133.98717474235545`, -13.331909103621363`, 
      13.331909103621363`}, {133.98717474235545`, -12.431415888865882`, 
      14.175313036843217`}, {150.65384140902208`, -10.439642072417756`, 
      11.90413028508381}, {150.65384140902208`, -11.195857368787003`, 
      11.195857368787001`}}], 
     Polygon3DBox[{{150.65384140902208`, -10.439642072417758`, 
      11.904130285083806`}, {133.98717474235545`, -12.431415888865883`, 
      14.175313036843216`}, {133.98717474235545`, -11.477689442768586`, 
      14.958016103407662`}, {150.65384140902208`, -9.63872262597141, 
      12.561427887944555`}, {150.65384140902208`, -10.439642072417758`, 
      11.904130285083806`}}], 
     Polygon3DBox[{{150.65384140902208`, -9.63872262597141, 
      12.561427887944555`}, {133.98717474235545`, -11.477689442768586`, 
      14.958016103407662`}, {133.98717474235545`, -10.474813768390417`, 
      15.676666648620904`}, {150.65384140902208`, -8.796528689477036, 
      13.164935528123632`}, {150.65384140902208`, -9.63872262597141, 
      12.561427887944555`}}], 
     Polygon3DBox[{{150.65384140902208`, -8.796528689477038, 
      13.164935528123632`}, {133.98717474235545`, -10.474813768390419`, 
      15.676666648620902`}, {133.98717474235545`, -9.427083333333334, 
      16.3281873005191}, {150.65384140902208`, -7.916666666666668, 
      13.712068893253612`}, {150.65384140902208`, -8.796528689477038, 
      13.164935528123632`}}], 
     Polygon3DBox[{{150.65384140902208`, -7.916666666666668, 
      13.712068893253612`}, {133.98717474235545`, -9.427083333333334, 
      16.3281873005191}, {133.98717474235545`, -8.338984680170755, 
      16.909788147647557`}, {150.65384140902208`, -7.002904261800856, 
      14.200485074267563`}, {150.65384140902208`, -7.916666666666668, 
      13.712068893253612`}}], 
     Polygon3DBox[{{150.65384140902208`, -7.002904261800856, 
      14.200485074267563`}, {133.98717474235545`, -8.338984680170755, 
      16.909788147647557`}, {133.98717474235545`, -7.215177214383467, 
      17.418978685889883`}, {150.65384140902208`, -6.059154345780591, 
      14.628092598095371`}, {150.65384140902208`, -7.002904261800856, 
      14.200485074267563`}}], 
     Polygon3DBox[{{150.6538414090221, -6.059154345780589, 
      14.628092598095375`}, {133.98717474235542`, -7.2151772143834645`, 
      17.418978685889886`}, {133.98717474235545`, -6.060473252070027, 
      17.85357848318897}, {150.65384140902208`, -5.089458200633393, 
      14.993060383672503`}, {150.6538414090221, -6.059154345780589, 
      14.628092598095375`}}], 
     Polygon3DBox[{{150.65384140902208`, -5.089458200633393, 
      14.993060383672503`}, {133.98717474235545`, -6.060473252070027, 
      17.85357848318897}, {133.98717474235545`, -4.879817412870447, 
      18.211726516491805`}, {150.65384140902208`, -4.097968214123249, 
      15.293825582910246`}, {150.65384140902208`, -5.089458200633393, 
      14.993060383672503`}}], 
     Polygon3DBox[{{150.65384140902208`, -4.097968214123249, 
      15.293825582910246`}, {133.98717474235545`, -4.879817412870447, 
      18.211726516491805`}, {133.98717474235542`, -3.6782654463457565`, 
      18.491889140935907`}, {150.65384140902208`, -3.0889300985887016`, 
      15.529100273051148`}, {150.65384140902208`, -4.097968214123249, 
      15.293825582910246`}}], 
     Polygon3DBox[{{150.65384140902208`, -3.0889300985886985`, 
      15.529100273051148`}, {133.98717474235542`, -3.678265446345753, 
      18.491889140935907`}, {133.98717474235545`, -2.4609625824822245`, 
      18.69286665715205}, {150.65384140902208`, -2.0666647101508184`, 
      15.697876971751997`}, {150.65384140902208`, -3.0889300985886985`, 
      15.529100273051148`}}], 
     Polygon3DBox[{{150.65384140902208`, -2.0666647101508184`, 
      15.697876971751997`}, {133.98717474235545`, -2.4609625824822245`, 
      18.69286665715205}, {133.98717474235545`, -1.2331214990266595`, 
      18.81379844856117}, {150.65384140902208`, -1.035549546143935, 
      15.79943295127789}, {150.65384140902208`, -2.0666647101508184`, 
      15.697876971751997`}}], 
     Polygon3DBox[{{150.65384140902208`, -1.035549546143935, 
      15.79943295127789}, {133.98717474235545`, -1.2331214990266595`, 
      18.81379844856117}, {133.98717474235545`, -5.3409507316368974`*^-15, 
      18.854166666666664`}, {150.65384140902208`, -4.485218293971317*^-15, 
      15.833333333333332`}, {150.65384140902208`, -1.035549546143935, 
      15.79943295127789}}], 
     Polygon3DBox[{{150.65384140902208`, -9.69512049324988*^-16, 
      15.833333333333332`}, {133.98717474235545`, -1.1544847429462027`*^-15, 
      18.854166666666664`}, {133.98717474235545`, 1.233121499026653, 
      18.81379844856117}, {150.65384140902208`, 1.0355495461439295`, 
      15.79943295127789}, {150.65384140902208`, -9.69512049324988*^-16, 
      15.833333333333332`}}], 
     Polygon3DBox[{{150.65384140902208`, 1.0355495461439295`, 
      15.79943295127789}, {133.98717474235545`, 1.233121499026653, 
      18.81379844856117}, {133.98717474235545`, 2.4609625824822188`, 
      18.69286665715205}, {150.65384140902208`, 2.0666647101508135`, 
      15.697876971751999`}, {150.65384140902208`, 1.0355495461439295`, 
      15.79943295127789}}], 
     Polygon3DBox[{{150.65384140902208`, 2.0666647101508135`, 
      15.697876971751999`}, {133.98717474235545`, 2.4609625824822188`, 
      18.69286665715205}, {133.98717474235545`, 3.678265446345746, 
      18.491889140935907`}, {150.65384140902208`, 3.0889300985886927`, 
      15.52910027305115}, {150.65384140902208`, 2.0666647101508135`, 
      15.697876971751999`}}], 
     Polygon3DBox[{{150.65384140902208`, 3.0889300985886927`, 
      15.52910027305115}, {133.98717474235545`, 3.678265446345746, 
      18.491889140935907`}, {133.98717474235545`, 4.879817412870437, 
      18.211726516491808`}, {150.65384140902208`, 4.097968214123239, 
      15.293825582910248`}, {150.65384140902208`, 3.0889300985886927`, 
      15.52910027305115}}], 
     Polygon3DBox[{{150.65384140902208`, 4.097968214123243, 
      15.293825582910248`}, {133.98717474235545`, 4.879817412870441, 
      18.211726516491808`}, {133.98717474235548`, 6.060473252070021, 
      17.85357848318897}, {150.65384140902208`, 5.089458200633388, 
      14.993060383672507`}, {150.65384140902208`, 4.097968214123243, 
      15.293825582910248`}}], 
     Polygon3DBox[{{150.65384140902208`, 5.089458200633388, 
      14.993060383672507`}, {133.98717474235548`, 6.060473252070021, 
      17.85357848318897}, {133.98717474235545`, 7.215177214383457, 
      17.418978685889886`}, {150.65384140902208`, 6.059154345780583, 
      14.628092598095375`}, {150.65384140902208`, 5.089458200633388, 
      14.993060383672507`}}], 
     Polygon3DBox[{{150.65384140902208`, 6.059154345780583, 
      14.628092598095375`}, {133.98717474235545`, 7.215177214383457, 
      17.418978685889886`}, {133.98717474235545`, 8.33898468017075, 
      16.90978814764756}, {150.65384140902208`, 7.00290426180085, 
      14.200485074267565`}, {150.65384140902208`, 6.059154345780583, 
      14.628092598095375`}}], 
     Polygon3DBox[{{150.65384140902208`, 7.00290426180085, 
      14.200485074267565`}, {133.98717474235545`, 8.33898468017075, 
      16.90978814764756}, {133.98717474235545`, 9.427083333333329, 
      16.328187300519104`}, {150.65384140902208`, 7.916666666666663, 
      13.712068893253612`}, {150.65384140902208`, 7.00290426180085, 
      14.200485074267565`}}], 
     Polygon3DBox[{{150.65384140902208`, 7.916666666666663, 
      13.712068893253612`}, {133.98717474235545`, 9.427083333333329, 
      16.328187300519104`}, {133.98717474235542`, 10.474813768390412`, 
      15.676666648620909`}, {150.65384140902208`, 8.79652868947703, 
      13.164935528123637`}, {150.65384140902208`, 7.916666666666663, 
      13.712068893253612`}}], 
     Polygon3DBox[{{150.65384140902208`, 8.79652868947703, 
      13.164935528123637`}, {133.98717474235542`, 10.474813768390412`, 
      15.676666648620909`}, {133.98717474235542`, 11.47768944276858, 
      14.958016103407667`}, {150.65384140902208`, 9.638722625971406, 
      12.56142788794456}, {150.65384140902208`, 8.79652868947703, 
      13.164935528123637`}}], 
     Polygon3DBox[{{150.65384140902208`, 9.638722625971406, 
      12.56142788794456}, {133.98717474235542`, 11.47768944276858, 
      14.958016103407667`}, {133.98717474235545`, 12.431415888865875`, 
      14.175313036843225`}, {150.65384140902208`, 10.439642072417751`, 
      11.904130285083813`}, {150.65384140902208`, 9.638722625971406, 
      12.56142788794456}}], 
     Polygon3DBox[{{150.65384140902208`, 10.439642072417751`, 
      11.904130285083813`}, {133.98717474235545`, 12.431415888865875`, 
      14.175313036843225`}, {133.98717474235542`, 13.331909103621356`, 
      13.331909103621372`}, {150.65384140902208`, 11.195857368786996`, 
      11.195857368787008`}, {150.65384140902208`, 10.439642072417751`, 
      11.904130285083813`}}], 
     Polygon3DBox[{{150.65384140902208`, 11.195857368787001`, 
      11.195857368787003`}, {133.98717474235545`, 13.331909103621363`, 
      13.331909103621363`}, {133.98717474235545`, 14.175313036843216`, 
      12.431415888865883`}, {150.65384140902208`, 11.904130285083806`, 
      10.439642072417758`}, {150.65384140902208`, 11.195857368787001`, 
      11.195857368787003`}}], 
     Polygon3DBox[{{150.65384140902208`, 11.904130285083806`, 
      10.439642072417758`}, {133.98717474235545`, 14.175313036843216`, 
      12.431415888865883`}, {133.98717474235545`, 14.95801610340766, 
      11.47768944276859}, {150.65384140902208`, 12.561427887944554`, 
      9.638722625971413}, {150.65384140902208`, 11.904130285083806`, 
      10.439642072417758`}}], 
     Polygon3DBox[{{150.65384140902208`, 12.561427887944554`, 
      9.638722625971413}, {133.98717474235545`, 14.95801610340766, 
      11.47768944276859}, {133.98717474235545`, 15.6766666486209, 
      10.474813768390423`}, {150.65384140902208`, 13.164935528123628`, 
      8.79652868947704}, {150.65384140902208`, 12.561427887944554`, 
      9.638722625971413}}], 
     Polygon3DBox[{{150.65384140902208`, 13.164935528123628`, 
      8.79652868947704}, {133.98717474235545`, 15.6766666486209, 
      10.474813768390423`}, {133.98717474235545`, 16.328187300519097`, 
      9.42708333333334}, {150.65384140902208`, 13.712068893253608`, 
      7.916666666666671}, {150.65384140902208`, 13.164935528123628`, 
      8.79652868947704}}], 
     Polygon3DBox[{{150.65384140902208`, 13.712068893253608`, 
      7.916666666666671}, {133.98717474235545`, 16.328187300519097`, 
      9.42708333333334}, {133.98717474235542`, 16.909788147647557`, 
      8.33898468017076}, {150.65384140902208`, 14.200485074267563`, 
      7.00290426180086}, {150.65384140902208`, 13.712068893253608`, 
      7.916666666666671}}], 
     Polygon3DBox[{{150.65384140902208`, 14.200485074267563`, 
      7.00290426180086}, {133.98717474235542`, 16.909788147647557`, 
      8.33898468017076}, {133.98717474235542`, 17.418978685889883`, 
      7.215177214383472}, {150.65384140902208`, 14.628092598095371`, 
      6.059154345780596}, {150.65384140902208`, 14.200485074267563`, 
      7.00290426180086}}], 
     Polygon3DBox[{{150.6538414090221, 14.628092598095375`, 
      6.059154345780589}, {133.98717474235542`, 17.418978685889886`, 
      7.215177214383465}, {133.98717474235545`, 17.85357848318897, 
      6.060473252070029}, {150.65384140902208`, 14.993060383672503`, 
      5.089458200633395}, {150.6538414090221, 14.628092598095375`, 
      6.059154345780589}}], 
     Polygon3DBox[{{150.65384140902208`, 14.993060383672503`, 
      5.089458200633395}, {133.98717474235545`, 17.85357848318897, 
      6.060473252070029}, {133.98717474235545`, 18.211726516491805`, 
      4.879817412870448}, {150.65384140902208`, 15.293825582910246`, 
      4.09796821412325}, {150.65384140902208`, 14.993060383672503`, 
      5.089458200633395}}], 
     Polygon3DBox[{{150.65384140902208`, 15.293825582910246`, 
      4.09796821412325}, {133.98717474235545`, 18.211726516491805`, 
      4.879817412870448}, {133.98717474235542`, 18.491889140935907`, 
      3.6782654463457582`}, {150.65384140902208`, 15.529100273051148`, 
      3.088930098588703}, {150.65384140902208`, 15.293825582910246`, 
      4.09796821412325}}], 
     Polygon3DBox[{{150.65384140902208`, 15.529100273051148`, 
      3.088930098588703}, {133.98717474235542`, 18.491889140935907`, 
      3.6782654463457582`}, {133.98717474235545`, 18.69286665715205, 
      2.4609625824822303`}, {150.65384140902208`, 15.697876971751997`, 
      2.0666647101508233`}, {150.65384140902208`, 15.529100273051148`, 
      3.088930098588703}}], 
     Polygon3DBox[{{150.65384140902208`, 15.697876971751997`, 
      2.0666647101508233`}, {133.98717474235545`, 18.69286665715205, 
      2.4609625824822303`}, {133.98717474235545`, 18.81379844856117, 
      1.233121499026665}, {150.65384140902208`, 15.79943295127789, 
      1.0355495461439397`}, {150.65384140902208`, 15.697876971751997`, 
      2.0666647101508233`}}], 
     Polygon3DBox[{{150.65384140902208`, 15.79943295127789, 
      1.0355495461439397`}, {133.98717474235545`, 18.81379844856117, 
      1.233121499026665}, {133.98717474235545`, 18.854166666666664`, 
      1.0681901463273795`*^-14}, {150.65384140902208`, 15.833333333333332`, 
      8.970436587942634*^-15}, {150.65384140902208`, 15.79943295127789, 
      1.0355495461439397`}}], 
     Polygon3DBox[{{150.65384140902208`, 15.833333333333332`, 
      1.939024098649976*^-15}, {133.98717474235545`, 18.854166666666664`, 
      2.3089694858924054`*^-15}, {133.98717474235545`, 
      18.81379844856117, -1.233121499026652}, {150.65384140902208`, 
      15.79943295127789, -1.0355495461439288`}, {150.65384140902208`, 
      15.833333333333332`, 1.939024098649976*^-15}}], 
     Polygon3DBox[{{150.65384140902208`, 
      15.79943295127789, -1.0355495461439288`}, {133.98717474235545`, 
      18.81379844856117, -1.233121499026652}, {133.98717474235545`, 
      18.69286665715205, -2.4609625824822174`}, {150.65384140902208`, 
      15.697876971751999`, -2.0666647101508127`}, {150.65384140902208`, 
      15.79943295127789, -1.0355495461439288`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      15.697876971751999`, -2.0666647101508127`}, {133.98717474235545`, 
      18.69286665715205, -2.4609625824822174`}, {133.98717474235545`, 
      18.491889140935907`, -3.678265446345745}, {150.65384140902208`, 
      15.52910027305115, -3.0889300985886923`}, {150.65384140902208`, 
      15.697876971751999`, -2.0666647101508127`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      15.52910027305115, -3.0889300985886923`}, {133.98717474235545`, 
      18.491889140935907`, -3.678265446345745}, {133.98717474235545`, 
      18.211726516491808`, -4.879817412870436}, {150.65384140902208`, 
      15.293825582910248`, -4.097968214123239}, {150.65384140902208`, 
      15.52910027305115, -3.0889300985886923`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      15.293825582910248`, -4.097968214123239}, {133.98717474235545`, 
      18.211726516491808`, -4.879817412870436}, {133.98717474235545`, 
      17.853578483188972`, -6.0604732520700155`}, {150.65384140902208`, 
      14.993060383672507`, -5.089458200633383}, {150.65384140902208`, 
      15.293825582910248`, -4.097968214123239}}], 
     Polygon3DBox[{{150.65384140902208`, 
      14.993060383672507`, -5.089458200633383}, {133.98717474235545`, 
      17.853578483188972`, -6.0604732520700155`}, {133.98717474235542`, 
      17.41897868588989, -7.215177214383453}, {150.65384140902208`, 
      14.628092598095376`, -6.05915434578058}, {150.65384140902208`, 
      14.993060383672507`, -5.089458200633383}}], 
     Polygon3DBox[{{150.65384140902208`, 
      14.628092598095376`, -6.05915434578058}, {133.98717474235542`, 
      17.41897868588989, -7.215177214383453}, {133.98717474235542`, 
      16.909788147647568`, -8.338984680170743}, {150.65384140902208`, 
      14.200485074267569`, -7.002904261800845}, {150.65384140902208`, 
      14.628092598095376`, -6.05915434578058}}], 
     Polygon3DBox[{{150.65384140902208`, 
      14.200485074267565`, -7.0029042618008495`}, {133.98717474235545`, 
      16.90978814764756, -8.338984680170748}, {133.98717474235542`, 
      16.328187300519108`, -9.427083333333327}, {150.65384140902208`, 
      13.712068893253614`, -7.916666666666662}, {150.65384140902208`, 
      14.200485074267565`, -7.0029042618008495`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      13.712068893253614`, -7.916666666666662}, {133.98717474235542`, 
      16.328187300519108`, -9.427083333333327}, {133.98717474235542`, 
      15.676666648620909`, -10.474813768390412`}, {150.65384140902208`, 
      13.164935528123637`, -8.79652868947703}, {150.65384140902208`, 
      13.712068893253614`, -7.916666666666662}}], 
     Polygon3DBox[{{150.65384140902208`, 
      13.164935528123637`, -8.79652868947703}, {133.98717474235542`, 
      15.676666648620909`, -10.474813768390412`}, {133.98717474235542`, 
      14.958016103407667`, -11.47768944276858}, {150.65384140902208`, 
      12.56142788794456, -9.638722625971406}, {150.65384140902208`, 
      13.164935528123637`, -8.79652868947703}}], 
     Polygon3DBox[{{150.65384140902208`, 
      12.56142788794456, -9.638722625971406}, {133.98717474235542`, 
      14.958016103407667`, -11.47768944276858}, {133.98717474235545`, 
      14.175313036843225`, -12.431415888865875`}, {150.65384140902208`, 
      11.904130285083813`, -10.439642072417751`}, {150.65384140902208`, 
      12.56142788794456, -9.638722625971406}}], 
     Polygon3DBox[{{150.65384140902208`, 
      11.904130285083813`, -10.439642072417751`}, {133.98717474235545`, 
      14.175313036843225`, -12.431415888865875`}, {133.98717474235542`, 
      13.331909103621372`, -13.331909103621356`}, {150.65384140902208`, 
      11.195857368787008`, -11.195857368786996`}, {150.65384140902208`, 
      11.904130285083813`, -10.439642072417751`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      11.195857368787008`, -11.195857368786996`}, {133.98717474235542`, 
      13.331909103621372`, -13.331909103621356`}, {133.98717474235545`, 
      12.43141588886589, -14.17531303684321}, {150.65384140902208`, 
      10.439642072417765`, -11.904130285083802`}, {150.65384140902208`, 
      11.195857368787008`, -11.195857368786996`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      10.43964207241776, -11.904130285083806`}, {133.98717474235542`, 
      12.431415888865885`, -14.175313036843216`}, {133.98717474235545`, 
      11.47768944276859, -14.958016103407658`}, {150.65384140902208`, 
      9.638722625971413, -12.561427887944554`}, {150.65384140902208`, 
      10.43964207241776, -11.904130285083806`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      9.638722625971413, -12.561427887944554`}, {133.98717474235545`, 
      11.47768944276859, -14.958016103407658`}, {133.98717474235545`, 
      10.474813768390415`, -15.676666648620904`}, {150.65384140902208`, 
      8.796528689477036, -13.164935528123632`}, {150.65384140902208`, 
      9.638722625971413, -12.561427887944554`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      8.796528689477046, -13.164935528123625`}, {133.98717474235545`, 
      10.47481376839043, -15.676666648620895`}, {133.98717474235542`, 
      9.427083333333343, -16.328187300519097`}, {150.65384140902208`, 
      7.916666666666674, -13.712068893253608`}, {150.65384140902208`, 
      8.796528689477046, -13.164935528123625`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      7.916666666666674, -13.712068893253608`}, {133.98717474235542`, 
      9.427083333333343, -16.328187300519097`}, {133.98717474235545`, 
      8.338984680170753, -16.909788147647557`}, {150.65384140902208`, 
      7.002904261800854, -14.200485074267563`}, {150.65384140902208`, 
      7.916666666666674, -13.712068893253608`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      7.002904261800854, -14.200485074267563`}, {133.98717474235545`, 
      8.338984680170753, -16.909788147647557`}, {133.98717474235545`, 
      7.215177214383457, -17.418978685889886`}, {150.65384140902208`, 
      6.059154345780583, -14.628092598095375`}, {150.65384140902208`, 
      7.002904261800854, -14.200485074267563`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      6.0591543457805965`, -14.628092598095371`}, {133.98717474235542`, 
      7.215177214383473, -17.418978685889883`}, {133.98717474235545`, 
      6.06047325207003, -17.85357848318897}, {150.65384140902208`, 
      5.089458200633395, -14.993060383672503`}, {150.65384140902208`, 
      6.0591543457805965`, -14.628092598095371`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      5.089458200633395, -14.993060383672503`}, {133.98717474235545`, 
      6.06047325207003, -17.85357848318897}, {133.98717474235545`, 
      4.879817412870441, -18.211726516491808`}, {150.65384140902208`, 
      4.097968214123243, -15.293825582910248`}, {150.65384140902208`, 
      5.089458200633395, -14.993060383672503`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      4.097968214123258, -15.293825582910245`}, {133.98717474235542`, 
      4.879817412870457, -18.211726516491805`}, {133.98717474235545`, 
      3.6782654463457587`, -18.491889140935903`}, {150.65384140902208`, 
      3.088930098588704, -15.529100273051146`}, {150.65384140902208`, 
      4.097968214123258, -15.293825582910245`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      3.088930098588704, -15.529100273051146`}, {133.98717474235545`, 
      3.6782654463457587`, -18.491889140935903`}, {133.98717474235545`, 
      2.460962582482223, -18.69286665715205}, {150.65384140902208`, 
      2.0666647101508175`, -15.697876971751997`}, {150.65384140902208`, 
      3.088930098588704, -15.529100273051146`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      2.066664710150831, -15.697876971751995`}, {133.98717474235545`, 
      2.4609625824822396`, -18.692866657152045`}, {133.98717474235545`, 
      1.2331214990266661`, -18.81379844856117}, {150.65384140902208`, 
      1.0355495461439406`, -15.79943295127789}, {150.65384140902208`, 
      2.066664710150831, -15.697876971751995`}}], 
     Polygon3DBox[{{150.65384140902208`, 
      1.0355495461439406`, -15.79943295127789}, {133.98717474235545`, 
      1.2331214990266661`, -18.81379844856117}, {133.98717474235545`, 
      3.4634542288386077`*^-15, -18.854166666666664`}, {150.65384140902208`, 
      2.9085361479749633`*^-15, -15.833333333333332`}, {150.65384140902208`, 
      1.0355495461439406`, -15.79943295127789}}], 
     Polygon3DBox[{{150.65384140902208`, 
      2.9085361479749633`*^-15, -15.833333333333332`}, {133.98717474235545`, 
      3.4634542288386077`*^-15, -18.854166666666664`}, {
      133.98717474235545`, -1.2331214990266592`, -18.81379844856117}, {
      150.65384140902208`, -1.0355495461439348`, -15.79943295127789}, {
      150.65384140902208`, 2.9085361479749633`*^-15, -15.833333333333332`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -1.0355495461439208`, -15.79943295127789}, {
      133.98717474235545`, -1.2331214990266426`, -18.81379844856117}, {
      133.98717474235545`, -2.4609625824822166`, -18.69286665715205}, {
      150.65384140902208`, -2.0666647101508118`, -15.697876971751999`}, {
      150.65384140902208`, -1.0355495461439208`, -15.79943295127789}}], 
     Polygon3DBox[{{
      150.65384140902208`, -2.0666647101508118`, -15.697876971751999`}, {
      133.98717474235545`, -2.4609625824822166`, -18.69286665715205}, {
      133.98717474235542`, -3.6782654463457525`, -18.491889140935907`}, {
      150.65384140902208`, -3.088930098588698, -15.529100273051148`}, {
      150.65384140902208`, -2.0666647101508118`, -15.697876971751999`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -3.088930098588684, -15.529100273051153`}, {
      133.98717474235542`, -3.678265446345735, -18.49188914093591}, {
      133.98717474235545`, -4.879817412870434, -18.211726516491808`}, {
      150.65384140902208`, -4.097968214123238, -15.293825582910248`}, {
      150.65384140902208`, -3.088930098588684, -15.529100273051153`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -4.097968214123238, -15.293825582910248`}, {
      133.98717474235545`, -4.879817412870434, -18.211726516491808`}, {
      133.98717474235548`, -6.0604732520700235`, -17.85357848318897}, {
      150.65384140902208`, -5.0894582006333895`, -14.993060383672507`}, {
      150.65384140902208`, -4.097968214123238, -15.293825582910248`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -5.0894582006333895`, -14.993060383672507`}, {
      133.98717474235548`, -6.0604732520700235`, -17.85357848318897}, {
      133.98717474235545`, -7.215177214383467, -17.418978685889883`}, {
      150.65384140902208`, -6.059154345780591, -14.628092598095371`}, {
      150.65384140902208`, -5.0894582006333895`, -14.993060383672507`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -6.059154345780579, -14.628092598095376`}, {
      133.98717474235545`, -7.215177214383452, -17.41897868588989}, {
      133.98717474235545`, -8.338984680170748, -16.90978814764756}, {
      150.65384140902208`, -7.0029042618008495`, -14.200485074267567`}, {
      150.65384140902208`, -6.059154345780579, -14.628092598095376`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -7.0029042618008495`, -14.200485074267567`}, {
      133.98717474235545`, -8.338984680170748, -16.90978814764756}, {
      133.98717474235545`, -9.427083333333334, -16.3281873005191}, {
      150.65384140902208`, -7.916666666666668, -13.712068893253612`}, {
      150.65384140902208`, -7.0029042618008495`, -14.200485074267567`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -7.916666666666655, -13.712068893253617`}, {
      133.98717474235545`, -9.42708333333332, -16.328187300519108`}, {
      133.98717474235545`, -10.474813768390408`, -15.676666648620909`}, {
      150.65384140902208`, -8.796528689477029, -13.164935528123637`}, {
      150.65384140902208`, -7.916666666666655, -13.712068893253617`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -8.796528689477029, -13.164935528123637`}, {
      133.98717474235545`, -10.474813768390408`, -15.676666648620909`}, {
      133.98717474235545`, -11.477689442768586`, -14.958016103407662`}, {
      150.65384140902208`, -9.638722625971408, -12.561427887944555`}, {
      150.65384140902208`, -8.796528689477029, -13.164935528123637`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -9.638722625971397, -12.561427887944564`}, {
      133.98717474235545`, -11.477689442768572`, -14.958016103407672`}, {
      133.98717474235545`, -12.431415888865873`, -14.175313036843226`}, {
      150.65384140902208`, -10.43964207241775, -11.904130285083815`}, {
      150.65384140902208`, -9.638722625971397, -12.561427887944564`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -10.43964207241775, -11.904130285083815`}, {
      133.98717474235545`, -12.431415888865873`, -14.175313036843226`}, {
      133.98717474235545`, -13.33190910362136, -13.331909103621365`}, {
      150.65384140902208`, -11.195857368787, -11.195857368787003`}, {
      150.65384140902208`, -10.43964207241775, -11.904130285083815`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -11.195857368787, -11.195857368787003`}, {
      133.98717474235545`, -13.33190910362136, -13.331909103621365`}, {
      133.98717474235545`, -14.175313036843221`, -12.431415888865878`}, {
      150.65384140902208`, -11.90413028508381, -10.439642072417755`}, {
      150.65384140902208`, -11.195857368787, -11.195857368787003`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -11.904130285083802`, -10.439642072417765`}, {
      133.98717474235545`, -14.17531303684321, -12.43141588886589}, {
      133.98717474235545`, -14.958016103407658`, -11.47768944276859}, {
      150.65384140902208`, -12.561427887944554`, -9.638722625971413}, {
      150.65384140902208`, -11.904130285083802`, -10.439642072417765`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -12.561427887944554`, -9.638722625971413}, {
      133.98717474235545`, -14.958016103407658`, -11.47768944276859}, {
      133.98717474235545`, -15.676666648620904`, -10.474813768390415`}, {
      150.65384140902208`, -13.164935528123632`, -8.796528689477036}, {
      150.65384140902208`, -12.561427887944554`, -9.638722625971413}}], 
     Polygon3DBox[{{
      150.65384140902208`, -13.164935528123625`, -8.796528689477046}, {
      133.98717474235545`, -15.676666648620895`, -10.47481376839043}, {
      133.98717474235542`, -16.328187300519097`, -9.427083333333343}, {
      150.65384140902208`, -13.712068893253608`, -7.916666666666674}, {
      150.65384140902208`, -13.164935528123625`, -8.796528689477046}}], 
     Polygon3DBox[{{
      150.65384140902208`, -13.712068893253608`, -7.916666666666674}, {
      133.98717474235542`, -16.328187300519097`, -9.427083333333343}, {
      133.98717474235545`, -16.909788147647557`, -8.338984680170755}, {
      150.65384140902208`, -14.200485074267563`, -7.002904261800856}, {
      150.65384140902208`, -13.712068893253608`, -7.916666666666674}}], 
     Polygon3DBox[{{
      150.65384140902208`, -14.200485074267556`, -7.002904261800868}, {
      133.98717474235545`, -16.90978814764755, -8.33898468017077}, {
      133.98717474235542`, -17.418978685889883`, -7.215177214383475}, {
      150.6538414090221, -14.628092598095371`, -6.059154345780598}, {
      150.65384140902208`, -14.200485074267556`, -7.002904261800868}}], 
     Polygon3DBox[{{
      150.6538414090221, -14.628092598095371`, -6.059154345780598}, {
      133.98717474235542`, -17.418978685889883`, -7.215177214383475}, {
      133.98717474235545`, -17.85357848318897, -6.060473252070031}, {
      150.65384140902208`, -14.993060383672503`, -5.089458200633396}, {
      150.6538414090221, -14.628092598095371`, -6.059154345780598}}], 
     Polygon3DBox[{{
      150.65384140902208`, -14.993060383672503`, -5.089458200633396}, {
      133.98717474235545`, -17.85357848318897, -6.060473252070031}, {
      133.98717474235545`, -18.211726516491808`, -4.879817412870442}, {
      150.65384140902208`, -15.293825582910248`, -4.097968214123243}, {
      150.65384140902208`, -14.993060383672503`, -5.089458200633396}}], 
     Polygon3DBox[{{
      150.65384140902208`, -15.293825582910245`, -4.097968214123258}, {
      133.98717474235542`, -18.211726516491805`, -4.879817412870459}, {
      133.98717474235545`, -18.491889140935903`, -3.67826544634576}, {
      150.65384140902208`, -15.529100273051146`, -3.0889300985887047`}, {
      150.65384140902208`, -15.293825582910245`, -4.097968214123258}}], 
     Polygon3DBox[{{
      150.65384140902208`, -15.529100273051146`, -3.0889300985887047`}, {
      133.98717474235545`, -18.491889140935903`, -3.67826544634576}, {
      133.98717474235545`, -18.69286665715205, -2.460962582482224}, {
      150.65384140902208`, -15.697876971751997`, -2.0666647101508184`}, {
      150.65384140902208`, -15.529100273051146`, -3.0889300985887047`}}], 
     Polygon3DBox[{{
      150.65384140902208`, -15.697876971751995`, -2.066664710150832}, {
      133.98717474235545`, -18.692866657152045`, -2.460962582482241}, {
      133.98717474235545`, -18.81379844856117, -1.233121499026667}, {
      150.65384140902208`, -15.79943295127789, -1.0355495461439415`}, {
      150.65384140902208`, -15.697876971751995`, -2.066664710150832}}], 
     Polygon3DBox[{{
      150.65384140902208`, -15.79943295127789, -1.0355495461439415`}, {
      133.98717474235545`, -18.81379844856117, -1.233121499026667}, {
      133.98717474235545`, -18.854166666666664`, -4.617938971784811*^-15}, {
      150.65384140902208`, -15.833333333333332`, -3.878048197299952*^-15}, {
      150.65384140902208`, -15.79943295127789, -1.0355495461439415`}}], 
     Polygon3DBox[{{133.98717474235545`, -18.854166666666664`, 0.}, {
      100.00000000000004`, -21.874999999999996`, 0.}, {
      100.00000000000004`, -21.828163945844448`, 1.4306934519093792`}, {
      133.98717474235545`, -18.81379844856117, 1.2331214990266555`}, {
      133.98717474235545`, -18.854166666666664`, 0.}}], 
     Polygon3DBox[{{133.98717474235545`, -18.81379844856117, 
      1.2331214990266555`}, {100.00000000000004`, -21.828163945844448`, 
      1.4306934519093792`}, {100.00000000000004`, -21.6878563425521, 
      2.855260454813628}, {133.98717474235545`, -18.69286665715205, 
      2.4609625824822223`}, {133.98717474235545`, -18.81379844856117, 
      1.2331214990266555`}}], 
     Polygon3DBox[{{133.98717474235545`, -18.69286665715205, 
      2.4609625824822223`}, {100.00000000000004`, -21.6878563425521, 
      2.855260454813628}, {100.00000000000004`, -21.454678008820665`, 
      4.267600794102805}, {133.98717474235542`, -18.491889140935907`, 
      3.6782654463457507`}, {133.98717474235545`, -18.69286665715205, 
      2.4609625824822223`}}], 
     Polygon3DBox[{{133.98717474235542`, -18.491889140935907`, 
      3.6782654463457507`}, {100.00000000000004`, -21.454678008820665`, 
      4.267600794102805}, {100.00000000000004`, -21.129627450073365`, 
      5.66166661161764}, {133.98717474235542`, -18.211726516491808`, 
      4.879817412870443}, {133.98717474235542`, -18.491889140935907`, 
      3.6782654463457507`}}], 
     Polygon3DBox[{{133.98717474235542`, -18.211726516491808`, 
      4.879817412870443}, {100.00000000000004`, -21.129627450073365`, 
      5.66166661161764}, {100.00000000000004`, -20.714096582705434`, 
      7.0314883035066575`}, {133.98717474235548`, -17.85357848318897, 
      6.060473252070024}, {133.98717474235542`, -18.211726516491808`, 
      4.879817412870443}}], 
     Polygon3DBox[{{133.98717474235548`, -17.85357848318897, 
      6.060473252070024}, {100.00000000000004`, -20.714096582705434`, 
      7.0314883035066575`}, {100.00000000000004`, -20.209864773684394`, 
      8.371200082986338}, {133.98717474235542`, -17.418978685889886`, 
      7.215177214383462}, {133.98717474235548`, -17.85357848318897, 
      6.060473252070024}}], 
     Polygon3DBox[{{133.98717474235542`, -17.418978685889886`, 
      7.215177214383463}, {100.00000000000004`, -20.209864773684394`, 
      8.371200082986338}, {100.00000000000004`, -19.619091221027556`, 
      9.67506509854065}, {133.98717474235542`, -16.90978814764756, 
      8.338984680170752}, {133.98717474235542`, -17.418978685889886`, 
      7.215177214383463}}], 
     Polygon3DBox[{{133.98717474235542`, -16.90978814764756, 
      8.338984680170752}, {100.00000000000004`, -19.619091221027556`, 
      9.67506509854065}, {100.00000000000004`, -18.944305707784594`, 
      10.937499999999996`}, {133.98717474235542`, -16.328187300519104`, 
      9.42708333333333}, {133.98717474235542`, -16.90978814764756, 
      8.338984680170752}}], 
     Polygon3DBox[{{133.98717474235542`, -16.328187300519104`, 
      9.42708333333333}, {100.00000000000004`, -18.944305707784594`, 
      10.937499999999996`}, {100.00000000000004`, -18.188397769118176`, 
      12.153098847303797`}, {133.98717474235545`, -15.676666648620904`, 
      10.474813768390415`}, {133.98717474235542`, -16.328187300519104`, 
      9.42708333333333}}], 
     Polygon3DBox[{{133.98717474235545`, -15.676666648620904`, 
      10.474813768390415`}, {100.00000000000004`, -18.188397769118176`, 
      12.153098847303797`}, {100.00000000000004`, -17.354604318870766`, 
      13.316656259565763`}, {133.98717474235545`, -14.958016103407662`, 
      11.477689442768586`}, {133.98717474235545`, -15.676666648620904`, 
      10.474813768390415`}}], 
     Polygon3DBox[{{133.98717474235542`, -14.958016103407665`, 
      11.477689442768586`}, {100., -17.35460431887077, 13.316656259565761`}, {
      100., -16.44649578860263, 14.423189705314005`}, {
      133.98717474235545`, -14.175313036843217`, 12.431415888865882`}, {
      133.98717474235542`, -14.958016103407665`, 11.477689442768586`}}], 
     Polygon3DBox[{{133.98717474235545`, -14.175313036843217`, 
      12.431415888865882`}, {100., -16.44649578860263, 14.423189705314005`}, {
      100.00000000000004`, -15.467960838455726`, 15.467960838455724`}, {
      133.98717474235545`, -13.331909103621363`, 13.331909103621363`}, {
      133.98717474235545`, -14.175313036843217`, 12.431415888865882`}}], 
     Polygon3DBox[{{133.98717474235545`, -13.331909103621363`, 
      13.331909103621363`}, {100.00000000000004`, -15.467960838455726`, 
      15.467960838455724`}, {100., -14.423189705314005`, 16.44649578860263}, {
      133.98717474235545`, -12.431415888865882`, 14.175313036843217`}, {
      133.98717474235545`, -13.331909103621363`, 13.331909103621363`}}], 
     Polygon3DBox[{{133.98717474235545`, -12.431415888865883`, 
      14.175313036843216`}, {100.00000000000004`, -14.423189705314007`, 
      16.446495788602626`}, {100.00000000000004`, -13.316656259565763`, 
      17.354604318870766`}, {133.98717474235545`, -11.477689442768586`, 
      14.958016103407662`}, {133.98717474235545`, -12.431415888865883`, 
      14.175313036843216`}}], 
     Polygon3DBox[{{133.98717474235545`, -11.477689442768586`, 
      14.958016103407662`}, {100.00000000000004`, -13.316656259565763`, 
      17.354604318870766`}, {100., -12.153098847303799`, 
      18.188397769118176`}, {133.98717474235545`, -10.474813768390417`, 
      15.676666648620904`}, {133.98717474235545`, -11.477689442768586`, 
      14.958016103407662`}}], 
     Polygon3DBox[{{133.98717474235545`, -10.474813768390419`, 
      15.676666648620902`}, {100., -12.1530988473038, 18.188397769118176`}, {
      100., -10.9375, 18.944305707784594`}, {
      133.98717474235545`, -9.427083333333334, 16.3281873005191}, {
      133.98717474235545`, -10.474813768390419`, 15.676666648620902`}}], 
     Polygon3DBox[{{133.98717474235545`, -9.427083333333334, 
      16.3281873005191}, {100., -10.9375, 18.944305707784594`}, {
      100.00000000000004`, -9.675065098540655, 19.619091221027553`}, {
      133.98717474235545`, -8.338984680170755, 16.909788147647557`}, {
      133.98717474235545`, -9.427083333333334, 16.3281873005191}}], 
     Polygon3DBox[{{133.98717474235545`, -8.338984680170755, 
      16.909788147647557`}, {100.00000000000004`, -9.675065098540655, 
      19.619091221027553`}, {100.00000000000004`, -8.371200082986343, 
      20.20986477368439}, {133.98717474235545`, -7.215177214383467, 
      17.418978685889883`}, {133.98717474235545`, -8.338984680170755, 
      16.909788147647557`}}], 
     Polygon3DBox[{{133.98717474235542`, -7.2151772143834645`, 
      17.418978685889886`}, {100.00000000000004`, -8.37120008298634, 
      20.209864773684394`}, {100.00000000000004`, -7.031488303506661, 
      20.71409658270543}, {133.98717474235545`, -6.060473252070027, 
      17.85357848318897}, {133.98717474235542`, -7.2151772143834645`, 
      17.418978685889886`}}], 
     Polygon3DBox[{{133.98717474235545`, -6.060473252070027, 
      17.85357848318897}, {100.00000000000004`, -7.031488303506661, 
      20.71409658270543}, {100.00000000000007`, -5.661666611617646, 
      21.12962745007336}, {133.98717474235545`, -4.879817412870447, 
      18.211726516491805`}, {133.98717474235545`, -6.060473252070027, 
      17.85357848318897}}], 
     Polygon3DBox[{{133.98717474235545`, -4.879817412870447, 
      18.211726516491805`}, {100.00000000000007`, -5.661666611617646, 
      21.12962745007336}, {100., -4.267600794102811, 21.454678008820665`}, {
      133.98717474235542`, -3.6782654463457565`, 18.491889140935907`}, {
      133.98717474235545`, -4.879817412870447, 18.211726516491805`}}], 
     Polygon3DBox[{{133.98717474235542`, -3.678265446345753, 
      18.491889140935907`}, {100., -4.2676007941028065`, 
      21.454678008820665`}, {100.00000000000004`, -2.8552604548136307`, 
      21.6878563425521}, {133.98717474235545`, -2.4609625824822245`, 
      18.69286665715205}, {133.98717474235542`, -3.678265446345753, 
      18.491889140935907`}}], 
     Polygon3DBox[{{133.98717474235545`, -2.4609625824822245`, 
      18.69286665715205}, {100.00000000000004`, -2.8552604548136307`, 
      21.6878563425521}, {100.00000000000004`, -1.4306934519093837`, 
      21.828163945844448`}, {133.98717474235545`, -1.2331214990266595`, 
      18.81379844856117}, {133.98717474235545`, -2.4609625824822245`, 
      18.69286665715205}}], 
     Polygon3DBox[{{133.98717474235545`, -1.2331214990266595`, 
      18.81379844856117}, {100.00000000000004`, -1.4306934519093837`, 
      21.828163945844448`}, {100.00000000000004`, -6.196683169302477*^-15, 
      21.874999999999996`}, {133.98717474235545`, -5.3409507316368974`*^-15, 
      18.854166666666664`}, {133.98717474235545`, -1.2331214990266595`, 
      18.81379844856117}}], 
     Polygon3DBox[{{133.98717474235545`, -1.1544847429462027`*^-15, 
      18.854166666666664`}, {100.00000000000004`, -1.3394574365674175`*^-15, 
      21.874999999999996`}, {100.00000000000004`, 1.4306934519093761`, 
      21.828163945844448`}, {133.98717474235545`, 1.233121499026653, 
      18.81379844856117}, {133.98717474235545`, -1.1544847429462027`*^-15, 
      18.854166666666664`}}], 
     Polygon3DBox[{{133.98717474235545`, 1.233121499026653, 
      18.81379844856117}, {100.00000000000004`, 1.4306934519093761`, 
      21.828163945844448`}, {100.00000000000004`, 2.8552604548136236`, 
      21.6878563425521}, {133.98717474235545`, 2.4609625824822188`, 
      18.69286665715205}, {133.98717474235545`, 1.233121499026653, 
      18.81379844856117}}], 
     Polygon3DBox[{{133.98717474235545`, 2.4609625824822188`, 
      18.69286665715205}, {100.00000000000004`, 2.8552604548136236`, 
      21.6878563425521}, {100.00000000000004`, 4.267600794102799, 
      21.454678008820665`}, {133.98717474235545`, 3.678265446345746, 
      18.491889140935907`}, {133.98717474235545`, 2.4609625824822188`, 
      18.69286665715205}}], 
     Polygon3DBox[{{133.98717474235545`, 3.678265446345746, 
      18.491889140935907`}, {100.00000000000004`, 4.267600794102799, 
      21.454678008820665`}, {100.00000000000004`, 5.661666611617632, 
      21.129627450073368`}, {133.98717474235545`, 4.879817412870437, 
      18.211726516491808`}, {133.98717474235545`, 3.678265446345746, 
      18.491889140935907`}}], 
     Polygon3DBox[{{133.98717474235545`, 4.879817412870441, 
      18.211726516491808`}, {100.00000000000004`, 5.661666611617638, 
      21.129627450073365`}, {100.00000000000004`, 7.031488303506654, 
      20.714096582705434`}, {133.98717474235548`, 6.060473252070021, 
      17.85357848318897}, {133.98717474235545`, 4.879817412870441, 
      18.211726516491808`}}], 
     Polygon3DBox[{{133.98717474235548`, 6.060473252070021, 
      17.85357848318897}, {100.00000000000004`, 7.031488303506654, 
      20.714096582705434`}, {100.00000000000007`, 8.37120008298633, 
      20.209864773684394`}, {133.98717474235545`, 7.215177214383457, 
      17.418978685889886`}, {133.98717474235548`, 6.060473252070021, 
      17.85357848318897}}], 
     Polygon3DBox[{{133.98717474235545`, 7.215177214383457, 
      17.418978685889886`}, {100.00000000000007`, 8.37120008298633, 
      20.209864773684394`}, {100.00000000000004`, 9.675065098540648, 
      19.619091221027556`}, {133.98717474235545`, 8.33898468017075, 
      16.90978814764756}, {133.98717474235545`, 7.215177214383457, 
      17.418978685889886`}}], 
     Polygon3DBox[{{133.98717474235545`, 8.33898468017075, 
      16.90978814764756}, {100.00000000000004`, 9.675065098540648, 
      19.619091221027556`}, {100.00000000000004`, 10.937499999999993`, 
      18.944305707784594`}, {133.98717474235545`, 9.427083333333329, 
      16.328187300519104`}, {133.98717474235545`, 8.33898468017075, 
      16.90978814764756}}], 
     Polygon3DBox[{{133.98717474235545`, 9.427083333333329, 
      16.328187300519104`}, {100.00000000000004`, 10.937499999999993`, 
      18.944305707784594`}, {100.00000000000004`, 12.153098847303792`, 
      18.18839776911818}, {133.98717474235542`, 10.474813768390412`, 
      15.676666648620909`}, {133.98717474235545`, 9.427083333333329, 
      16.328187300519104`}}], 
     Polygon3DBox[{{133.98717474235542`, 10.474813768390412`, 
      15.676666648620909`}, {100.00000000000004`, 12.153098847303792`, 
      18.18839776911818}, {100., 13.316656259565756`, 17.354604318870773`}, {
      133.98717474235542`, 11.47768944276858, 14.958016103407667`}, {
      133.98717474235542`, 10.474813768390412`, 15.676666648620909`}}], 
     Polygon3DBox[{{133.98717474235542`, 11.47768944276858, 
      14.958016103407667`}, {100., 13.316656259565756`, 
      17.354604318870773`}, {100.00000000000004`, 14.423189705313996`, 
      16.446495788602636`}, {133.98717474235545`, 12.431415888865875`, 
      14.175313036843225`}, {133.98717474235542`, 11.47768944276858, 
      14.958016103407667`}}], 
     Polygon3DBox[{{133.98717474235545`, 12.431415888865875`, 
      14.175313036843225`}, {100.00000000000004`, 14.423189705313996`, 
      16.446495788602636`}, {100.00000000000004`, 15.467960838455717`, 
      15.467960838455735`}, {133.98717474235542`, 13.331909103621356`, 
      13.331909103621372`}, {133.98717474235545`, 12.431415888865875`, 
      14.175313036843225`}}], 
     Polygon3DBox[{{133.98717474235545`, 13.331909103621363`, 
      13.331909103621363`}, {100.00000000000004`, 15.467960838455724`, 
      15.467960838455726`}, {100.00000000000004`, 16.446495788602626`, 
      14.423189705314007`}, {133.98717474235545`, 14.175313036843216`, 
      12.431415888865883`}, {133.98717474235545`, 13.331909103621363`, 
      13.331909103621363`}}], 
     Polygon3DBox[{{133.98717474235545`, 14.175313036843216`, 
      12.431415888865883`}, {100.00000000000004`, 16.446495788602626`, 
      14.423189705314007`}, {100.00000000000004`, 17.354604318870763`, 
      13.316656259565766`}, {133.98717474235545`, 14.95801610340766, 
      11.47768944276859}, {133.98717474235545`, 14.175313036843216`, 
      12.431415888865883`}}], 
     Polygon3DBox[{{133.98717474235545`, 14.95801610340766, 
      11.47768944276859}, {100.00000000000004`, 17.354604318870763`, 
      13.316656259565766`}, {100.00000000000004`, 18.18839776911817, 
      12.153098847303802`}, {133.98717474235545`, 15.6766666486209, 
      10.474813768390423`}, {133.98717474235545`, 14.95801610340766, 
      11.47768944276859}}], 
     Polygon3DBox[{{133.98717474235545`, 15.6766666486209, 
      10.474813768390423`}, {100.00000000000004`, 18.18839776911817, 
      12.153098847303802`}, {100.00000000000004`, 18.94430570778459, 
      10.937500000000005`}, {133.98717474235545`, 16.328187300519097`, 
      9.42708333333334}, {133.98717474235545`, 15.6766666486209, 
      10.474813768390423`}}], 
     Polygon3DBox[{{133.98717474235545`, 16.328187300519097`, 
      9.42708333333334}, {100.00000000000004`, 18.94430570778459, 
      10.937500000000005`}, {100., 19.619091221027553`, 9.67506509854066}, {
      133.98717474235542`, 16.909788147647557`, 8.33898468017076}, {
      133.98717474235545`, 16.328187300519097`, 9.42708333333334}}], 
     Polygon3DBox[{{133.98717474235542`, 16.909788147647557`, 
      8.33898468017076}, {100., 19.619091221027553`, 9.67506509854066}, {
      100.00000000000004`, 20.20986477368439, 8.371200082986348}, {
      133.98717474235542`, 17.418978685889883`, 7.215177214383472}, {
      133.98717474235542`, 16.909788147647557`, 8.33898468017076}}], 
     Polygon3DBox[{{133.98717474235542`, 17.418978685889886`, 
      7.215177214383465}, {100.00000000000004`, 20.209864773684394`, 
      8.37120008298634}, {100.00000000000004`, 20.71409658270543, 
      7.031488303506663}, {133.98717474235545`, 17.85357848318897, 
      6.060473252070029}, {133.98717474235542`, 17.418978685889886`, 
      7.215177214383465}}], 
     Polygon3DBox[{{133.98717474235545`, 17.85357848318897, 
      6.060473252070029}, {100.00000000000004`, 20.71409658270543, 
      7.031488303506663}, {100.00000000000004`, 21.12962745007336, 
      5.661666611617647}, {133.98717474235545`, 18.211726516491805`, 
      4.879817412870448}, {133.98717474235545`, 17.85357848318897, 
      6.060473252070029}}], 
     Polygon3DBox[{{133.98717474235545`, 18.211726516491805`, 
      4.879817412870448}, {100.00000000000004`, 21.12962745007336, 
      5.661666611617647}, {100., 21.454678008820665`, 4.267600794102813}, {
      133.98717474235542`, 18.491889140935907`, 3.6782654463457582`}, {
      133.98717474235545`, 18.211726516491805`, 4.879817412870448}}], 
     Polygon3DBox[{{133.98717474235542`, 18.491889140935907`, 
      3.6782654463457582`}, {100., 21.454678008820665`, 4.267600794102813}, {
      100.00000000000004`, 21.6878563425521, 2.855260454813637}, {
      133.98717474235545`, 18.69286665715205, 2.4609625824822303`}, {
      133.98717474235542`, 18.491889140935907`, 3.6782654463457582`}}], 
     Polygon3DBox[{{133.98717474235545`, 18.69286665715205, 
      2.4609625824822303`}, {100.00000000000004`, 21.6878563425521, 
      2.855260454813637}, {100.00000000000004`, 21.828163945844448`, 
      1.4306934519093901`}, {133.98717474235545`, 18.81379844856117, 
      1.233121499026665}, {133.98717474235545`, 18.69286665715205, 
      2.4609625824822303`}}], 
     Polygon3DBox[{{133.98717474235545`, 18.81379844856117, 
      1.233121499026665}, {100.00000000000004`, 21.828163945844448`, 
      1.4306934519093901`}, {100.00000000000004`, 21.874999999999996`, 
      1.2393366338604954`*^-14}, {133.98717474235545`, 18.854166666666664`, 
      1.0681901463273795`*^-14}, {133.98717474235545`, 18.81379844856117, 
      1.233121499026665}}], 
     Polygon3DBox[{{133.98717474235545`, 18.854166666666664`, 
      2.3089694858924054`*^-15}, {100.00000000000004`, 21.874999999999996`, 
      2.678914873134835*^-15}, {100.00000000000004`, 
      21.828163945844448`, -1.430693451909375}, {133.98717474235545`, 
      18.81379844856117, -1.233121499026652}, {133.98717474235545`, 
      18.854166666666664`, 2.3089694858924054`*^-15}}], 
     Polygon3DBox[{{133.98717474235545`, 
      18.81379844856117, -1.233121499026652}, {100.00000000000004`, 
      21.828163945844448`, -1.430693451909375}, {100.00000000000004`, 
      21.6878563425521, -2.8552604548136222`}, {133.98717474235545`, 
      18.69286665715205, -2.4609625824822174`}, {133.98717474235545`, 
      18.81379844856117, -1.233121499026652}}], 
     Polygon3DBox[{{133.98717474235545`, 
      18.69286665715205, -2.4609625824822174`}, {100.00000000000004`, 
      21.6878563425521, -2.8552604548136222`}, {100.00000000000004`, 
      21.454678008820665`, -4.267600794102798}, {133.98717474235545`, 
      18.491889140935907`, -3.678265446345745}, {133.98717474235545`, 
      18.69286665715205, -2.4609625824822174`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      18.491889140935907`, -3.678265446345745}, {100.00000000000004`, 
      21.454678008820665`, -4.267600794102798}, {100.00000000000004`, 
      21.129627450073368`, -5.6616666116176315`}, {133.98717474235545`, 
      18.211726516491808`, -4.879817412870436}, {133.98717474235545`, 
      18.491889140935907`, -3.678265446345745}}], 
     Polygon3DBox[{{133.98717474235545`, 
      18.211726516491808`, -4.879817412870436}, {100.00000000000004`, 
      21.129627450073368`, -5.6616666116176315`}, {100.00000000000007`, 
      20.714096582705434`, -7.031488303506648}, {133.98717474235545`, 
      17.853578483188972`, -6.0604732520700155`}, {133.98717474235545`, 
      18.211726516491808`, -4.879817412870436}}], 
     Polygon3DBox[{{133.98717474235545`, 
      17.853578483188972`, -6.0604732520700155`}, {100.00000000000007`, 
      20.714096582705434`, -7.031488303506648}, {100.00000000000004`, 
      20.2098647736844, -8.371200082986325}, {133.98717474235542`, 
      17.41897868588989, -7.215177214383453}, {133.98717474235545`, 
      17.853578483188972`, -6.0604732520700155`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      17.41897868588989, -7.215177214383453}, {100.00000000000004`, 
      20.2098647736844, -8.371200082986325}, {100.00000000000004`, 
      19.61909122102756, -9.675065098540639}, {133.98717474235542`, 
      16.909788147647568`, -8.338984680170743}, {133.98717474235542`, 
      17.41897868588989, -7.215177214383453}}], 
     Polygon3DBox[{{133.98717474235545`, 
      16.90978814764756, -8.338984680170748}, {100.00000000000004`, 
      19.619091221027556`, -9.675065098540646}, {100.00000000000004`, 
      18.944305707784597`, -10.937499999999991`}, {133.98717474235542`, 
      16.328187300519108`, -9.427083333333327}, {133.98717474235545`, 
      16.90978814764756, -8.338984680170748}}], 
     Polygon3DBox[{{133.98717474235542`, 
      16.328187300519108`, -9.427083333333327}, {100.00000000000004`, 
      18.944305707784597`, -10.937499999999991`}, {100.00000000000004`, 
      18.18839776911818, -12.153098847303792`}, {133.98717474235542`, 
      15.676666648620909`, -10.474813768390412`}, {133.98717474235542`, 
      16.328187300519108`, -9.427083333333327}}], 
     Polygon3DBox[{{133.98717474235542`, 
      15.676666648620909`, -10.474813768390412`}, {100.00000000000004`, 
      18.18839776911818, -12.153098847303792`}, {100., 
      17.354604318870773`, -13.316656259565756`}, {133.98717474235542`, 
      14.958016103407667`, -11.47768944276858}, {133.98717474235542`, 
      15.676666648620909`, -10.474813768390412`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      14.958016103407667`, -11.47768944276858}, {100., 
      17.354604318870773`, -13.316656259565756`}, {100.00000000000004`, 
      16.446495788602636`, -14.423189705313996`}, {133.98717474235545`, 
      14.175313036843225`, -12.431415888865875`}, {133.98717474235542`, 
      14.958016103407667`, -11.47768944276858}}], 
     Polygon3DBox[{{133.98717474235545`, 
      14.175313036843225`, -12.431415888865875`}, {100.00000000000004`, 
      16.446495788602636`, -14.423189705313996`}, {100.00000000000004`, 
      15.467960838455735`, -15.467960838455717`}, {133.98717474235542`, 
      13.331909103621372`, -13.331909103621356`}, {133.98717474235545`, 
      14.175313036843225`, -12.431415888865875`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      13.331909103621372`, -13.331909103621356`}, {100.00000000000004`, 
      15.467960838455735`, -15.467960838455717`}, {100.00000000000004`, 
      14.423189705314016`, -16.44649578860262}, {133.98717474235545`, 
      12.43141588886589, -14.17531303684321}, {133.98717474235542`, 
      13.331909103621372`, -13.331909103621356`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      12.431415888865885`, -14.175313036843216`}, {100.00000000000004`, 
      14.423189705314009`, -16.446495788602626`}, {100.00000000000004`, 
      13.316656259565766`, -17.354604318870763`}, {133.98717474235545`, 
      11.47768944276859, -14.958016103407658`}, {133.98717474235542`, 
      12.431415888865885`, -14.175313036843216`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      11.47768944276859, -14.958016103407658`}, {100.00000000000004`, 
      13.316656259565766`, -17.354604318870763`}, {100.00000000000004`, 
      12.153098847303797`, -18.188397769118176`}, {133.98717474235545`, 
      10.474813768390415`, -15.676666648620904`}, {133.98717474235545`, 
      11.47768944276859, -14.958016103407658`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      10.47481376839043, -15.676666648620895`}, {100.00000000000004`, 
      12.153098847303813`, -18.188397769118165`}, {100.00000000000004`, 
      10.937500000000009`, -18.944305707784586`}, {133.98717474235542`, 
      9.427083333333343, -16.328187300519097`}, {133.98717474235545`, 
      10.47481376839043, -15.676666648620895`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      9.427083333333343, -16.328187300519097`}, {100.00000000000004`, 
      10.937500000000009`, -18.944305707784586`}, {100.00000000000004`, 
      9.675065098540653, -19.619091221027553`}, {133.98717474235545`, 
      8.338984680170753, -16.909788147647557`}, {133.98717474235542`, 
      9.427083333333343, -16.328187300519097`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      8.338984680170753, -16.909788147647557`}, {100.00000000000004`, 
      9.675065098540653, -19.619091221027553`}, {100.00000000000007`, 
      8.37120008298633, -20.209864773684394`}, {133.98717474235545`, 
      7.215177214383457, -17.418978685889886`}, {133.98717474235545`, 
      8.338984680170753, -16.909788147647557`}}], 
     Polygon3DBox[{{133.98717474235542`, 
      7.215177214383473, -17.418978685889883`}, {100., 
      8.37120008298635, -20.20986477368439}, {100.00000000000004`, 
      7.031488303506664, -20.71409658270543}, {133.98717474235545`, 
      6.06047325207003, -17.85357848318897}, {133.98717474235542`, 
      7.215177214383473, -17.418978685889883`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      6.06047325207003, -17.85357848318897}, {100.00000000000004`, 
      7.031488303506664, -20.71409658270543}, {100.00000000000004`, 
      5.661666611617638, -21.129627450073365`}, {133.98717474235545`, 
      4.879817412870441, -18.211726516491808`}, {133.98717474235545`, 
      6.06047325207003, -17.85357848318897}}], 
     Polygon3DBox[{{133.98717474235542`, 
      4.879817412870457, -18.211726516491805`}, {100.00000000000004`, 
      5.661666611617657, -21.12962745007336}, {100.00000000000007`, 
      4.267600794102814, -21.454678008820657`}, {133.98717474235545`, 
      3.6782654463457587`, -18.491889140935903`}, {133.98717474235542`, 
      4.879817412870457, -18.211726516491805`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      3.6782654463457587`, -18.491889140935903`}, {100.00000000000007`, 
      4.267600794102814, -21.454678008820657`}, {100.00000000000004`, 
      2.855260454813629, -21.6878563425521}, {133.98717474235545`, 
      2.460962582482223, -18.69286665715205}, {133.98717474235545`, 
      3.6782654463457587`, -18.491889140935903`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      2.4609625824822396`, -18.692866657152045`}, {100.00000000000004`, 
      2.8552604548136475`, -21.687856342552095`}, {100.00000000000004`, 
      1.4306934519093915`, -21.828163945844448`}, {133.98717474235545`, 
      1.2331214990266661`, -18.81379844856117}, {133.98717474235545`, 
      2.4609625824822396`, -18.692866657152045`}}], 
     Polygon3DBox[{{133.98717474235545`, 
      1.2331214990266661`, -18.81379844856117}, {100.00000000000004`, 
      1.4306934519093915`, -21.828163945844448`}, {100.00000000000004`, 
      4.018372309702252*^-15, -21.874999999999996`}, {133.98717474235545`, 
      3.4634542288386077`*^-15, -18.854166666666664`}, {133.98717474235545`, 
      1.2331214990266661`, -18.81379844856117}}], 
     Polygon3DBox[{{133.98717474235545`, 
      3.4634542288386077`*^-15, -18.854166666666664`}, {100.00000000000004`, 
      4.018372309702252*^-15, -21.874999999999996`}, {
      100.00000000000004`, -1.4306934519093835`, -21.828163945844448`}, {
      133.98717474235545`, -1.2331214990266592`, -18.81379844856117}, {
      133.98717474235545`, 3.4634542288386077`*^-15, -18.854166666666664`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -1.2331214990266426`, -18.81379844856117}, {
      100.00000000000004`, -1.4306934519093641`, -21.828163945844448`}, {
      100.00000000000004`, -2.855260454813621, -21.6878563425521}, {
      133.98717474235545`, -2.4609625824822166`, -18.69286665715205}, {
      133.98717474235545`, -1.2331214990266426`, -18.81379844856117}}], 
     Polygon3DBox[{{
      133.98717474235545`, -2.4609625824822166`, -18.69286665715205}, {
      100.00000000000004`, -2.855260454813621, -21.6878563425521}, {
      100., -4.2676007941028065`, -21.454678008820665`}, {
      133.98717474235542`, -3.6782654463457525`, -18.491889140935907`}, {
      133.98717474235545`, -2.4609625824822166`, -18.69286665715205}}], 
     Polygon3DBox[{{
      133.98717474235542`, -3.678265446345735, -18.49188914093591}, {
      100., -4.267600794102787, -21.454678008820668`}, {
      100.00000000000004`, -5.661666611617631, -21.129627450073368`}, {
      133.98717474235545`, -4.879817412870434, -18.211726516491808`}, {
      133.98717474235542`, -3.678265446345735, -18.49188914093591}}], 
     Polygon3DBox[{{
      133.98717474235545`, -4.879817412870434, -18.211726516491808`}, {
      100.00000000000004`, -5.661666611617631, -21.129627450073368`}, {
      100.00000000000004`, -7.031488303506656, -20.714096582705434`}, {
      133.98717474235548`, -6.0604732520700235`, -17.85357848318897}, {
      133.98717474235545`, -4.879817412870434, -18.211726516491808`}}], 
     Polygon3DBox[{{
      133.98717474235548`, -6.0604732520700235`, -17.85357848318897}, {
      100.00000000000004`, -7.031488303506656, -20.714096582705434`}, {
      100.00000000000004`, -8.371200082986343, -20.20986477368439}, {
      133.98717474235545`, -7.215177214383467, -17.418978685889883`}, {
      133.98717474235548`, -6.0604732520700235`, -17.85357848318897}}], 
     Polygon3DBox[{{
      133.98717474235545`, -7.215177214383452, -17.41897868588989}, {
      100.00000000000004`, -8.371200082986325, -20.2098647736844}, {
      100.00000000000004`, -9.675065098540646, -19.619091221027556`}, {
      133.98717474235545`, -8.338984680170748, -16.90978814764756}, {
      133.98717474235545`, -7.215177214383452, -17.41897868588989}}], 
     Polygon3DBox[{{
      133.98717474235545`, -8.338984680170748, -16.90978814764756}, {
      100.00000000000004`, -9.675065098540646, -19.619091221027556`}, {
      100., -10.9375, -18.944305707784594`}, {
      133.98717474235545`, -9.427083333333334, -16.3281873005191}, {
      133.98717474235545`, -8.338984680170748, -16.90978814764756}}], 
     Polygon3DBox[{{
      133.98717474235545`, -9.42708333333332, -16.328187300519108`}, {
      100.00000000000004`, -10.937499999999984`, -18.9443057077846}, {
      100.00000000000004`, -12.153098847303788`, -18.18839776911818}, {
      133.98717474235545`, -10.474813768390408`, -15.676666648620909`}, {
      133.98717474235545`, -9.42708333333332, -16.328187300519108`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -10.474813768390408`, -15.676666648620909`}, {
      100.00000000000004`, -12.153098847303788`, -18.18839776911818}, {
      100.00000000000004`, -13.316656259565761`, -17.354604318870766`}, {
      133.98717474235545`, -11.477689442768586`, -14.958016103407662`}, {
      133.98717474235545`, -10.474813768390408`, -15.676666648620909`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -11.477689442768572`, -14.958016103407672`}, {
      100.00000000000004`, -13.316656259565745`, -17.35460431887078}, {
      100., -14.423189705313995`, -16.44649578860264}, {
      133.98717474235545`, -12.431415888865873`, -14.175313036843226`}, {
      133.98717474235545`, -11.477689442768572`, -14.958016103407672`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -12.431415888865873`, -14.175313036843226`}, {
      100., -14.423189705313995`, -16.44649578860264}, {
      100.00000000000004`, -15.46796083845572, -15.467960838455728`}, {
      133.98717474235545`, -13.33190910362136, -13.331909103621365`}, {
      133.98717474235545`, -12.431415888865873`, -14.175313036843226`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -13.33190910362136, -13.331909103621365`}, {
      100.00000000000004`, -15.46796083845572, -15.467960838455728`}, {
      100.00000000000004`, -16.44649578860263, -14.423189705314002`}, {
      133.98717474235545`, -14.175313036843221`, -12.431415888865878`}, {
      133.98717474235545`, -13.33190910362136, -13.331909103621365`}}], 
     Polygon3DBox[{{
      133.98717474235545`, -14.17531303684321, -12.43141588886589}, {
      100.00000000000004`, -16.44649578860262, -14.423189705314016`}, {
      100.00000000000004`, -17.354604318870763`, -13.316656259565766`}, {
      133.98717474235545`, -14.958016103407658`, -11.47768944276859}, {
      133.98717474235545`, -14.17531303684321, -12.43141588886589}}], 
     Polygon3DBox[{{
      133.98717474235545`, -14.958016103407658`, -11.47768944276859}, {
      100.00000000000004`, -17.354604318870763`, -13.316656259565766`}, {
      100.00000000000004`, -18.188397769118176`, -12.153098847303797`}, {
      133.98717474235545`, -15.676666648620904`, -10.474813768390415`}, {
      133.98717474235545`, -14.958016103407658`, -11.47768944276859}}], 
     Polygon3DBox[{{
      133.98717474235545`, -15.676666648620895`, -10.47481376839043}, {
      100.00000000000004`, -18.188397769118165`, -12.153098847303813`}, {
      100.00000000000004`, -18.944305707784586`, -10.937500000000009`}, {
      133.98717474235542`, -16.328187300519097`, -9.427083333333343}, {
      133.98717474235545`, -15.676666648620895`, -10.47481376839043}}], 
     Polygon3DBox[{{
      133.98717474235542`, -16.328187300519097`, -9.427083333333343}, {
      100.00000000000004`, -18.944305707784586`, -10.937500000000009`}, {
      100.00000000000004`, -19.619091221027553`, -9.675065098540655}, {
      133.98717474235545`, -16.909788147647557`, -8.338984680170755}, {
      133.98717474235542`, -16.328187300519097`, -9.427083333333343}}], 
     Polygon3DBox[{{
      133.98717474235545`, -16.90978814764755, -8.33898468017077}, {
      100.00000000000004`, -19.619091221027542`, -9.67506509854067}, {
      100., -20.20986477368439, -8.371200082986352}, {
      133.98717474235542`, -17.418978685889883`, -7.215177214383475}, {
      133.98717474235545`, -16.90978814764755, -8.33898468017077}}], 
     Polygon3DBox[{{
      133.98717474235542`, -17.418978685889883`, -7.215177214383475}, {
      100., -20.20986477368439, -8.371200082986352}, {
      100.00000000000004`, -20.71409658270543, -7.031488303506665}, {
      133.98717474235545`, -17.85357848318897, -6.060473252070031}, {
      133.98717474235542`, -17.418978685889883`, -7.215177214383475}}], 
     Polygon3DBox[{{
      133.98717474235545`, -17.85357848318897, -6.060473252070031}, {
      100.00000000000004`, -20.71409658270543, -7.031488303506665}, {
      100.00000000000004`, -21.129627450073365`, -5.661666611617639}, {
      133.98717474235545`, -18.211726516491808`, -4.879817412870442}, {
      133.98717474235545`, -17.85357848318897, -6.060473252070031}}], 
     Polygon3DBox[{{
      133.98717474235542`, -18.211726516491805`, -4.879817412870459}, {
      100.00000000000004`, -21.12962745007336, -5.661666611617658}, {
      100.00000000000007`, -21.454678008820657`, -4.267600794102815}, {
      133.98717474235545`, -18.491889140935903`, -3.67826544634576}, {
      133.98717474235542`, -18.211726516491805`, -4.879817412870459}}], 
     Polygon3DBox[{{
      133.98717474235545`, -18.491889140935903`, -3.67826544634576}, {
      100.00000000000007`, -21.454678008820657`, -4.267600794102815}, {
      100.00000000000004`, -21.6878563425521, -2.8552604548136302`}, {
      133.98717474235545`, -18.69286665715205, -2.460962582482224}, {
      133.98717474235545`, -18.491889140935903`, -3.67826544634576}}], 
     Polygon3DBox[{{
      133.98717474235545`, -18.692866657152045`, -2.460962582482241}, {
      100.00000000000004`, -21.687856342552095`, -2.8552604548136493`}, {
      100.00000000000004`, -21.828163945844448`, -1.4306934519093926`}, {
      133.98717474235545`, -18.81379844856117, -1.233121499026667}, {
      133.98717474235545`, -18.692866657152045`, -2.460962582482241}}], 
     Polygon3DBox[{{
      133.98717474235545`, -18.81379844856117, -1.233121499026667}, {
      100.00000000000004`, -21.828163945844448`, -1.4306934519093926`}, {
      100.00000000000004`, -21.874999999999996`, -5.35782974626967*^-15}, {
      133.98717474235545`, -18.854166666666664`, -4.617938971784811*^-15}, {
      133.98717474235545`, -18.81379844856117, -1.233121499026667}}], 
     Polygon3DBox[{{100., -21.875, 0.}, {
      66.01282525764451, -24.895833333333336`, 0.}, {
      66.01282525764451, -24.842529443127734`, 1.6282654047921035`}, {
      100., -21.82816394584445, 1.4306934519093795`}, {100., -21.875, 0.}}], 
     Polygon3DBox[{{100., -21.82816394584445, 1.4306934519093795`}, {
      66.01282525764451, -24.842529443127734`, 1.6282654047921035`}, {
      66.01282525764455, -24.682846027952156`, 3.2495583271450346`}, {
      100., -21.687856342552102`, 2.8552604548136284`}, {
      100., -21.82816394584445, 1.4306934519093795`}}], 
     Polygon3DBox[{{100., -21.687856342552102`, 2.8552604548136284`}, {
      66.01282525764455, -24.682846027952156`, 3.2495583271450346`}, {
      66.01282525764451, -24.41746687670543, 4.856936141859859}, {
      99.99999999999994, -21.454678008820668`, 4.267600794102806}, {
      100., -21.687856342552102`, 2.8552604548136284`}}], 
     Polygon3DBox[{{99.99999999999994, -21.454678008820668`, 
      4.267600794102806}, {66.01282525764451, -24.41746687670543, 
      4.856936141859859}, {66.01282525764451, -24.047528383654935`, 
      6.44351581036484}, {99.99999999999994, -21.12962745007337, 
      5.661666611617641}, {99.99999999999994, -21.454678008820668`, 
      4.267600794102806}}], 
     Polygon3DBox[{{99.99999999999994, -21.12962745007337, 
      5.661666611617641}, {66.01282525764451, -24.047528383654935`, 
      6.44351581036484}, {66.01282525764455, -23.574614682221902`, 
      8.002503354943292}, {100., -20.714096582705437`, 7.031488303506658}, {
      99.99999999999994, -21.12962745007337, 5.661666611617641}}], 
     Polygon3DBox[{{100., -20.714096582705437`, 7.031488303506658}, {
      66.01282525764455, -23.574614682221902`, 8.002503354943292}, {
      66.01282525764451, -23.000750861478913`, 9.527222951589213}, {
      100., -20.209864773684398`, 8.371200082986338}, {
      100., -20.714096582705437`, 7.031488303506658}}], 
     Polygon3DBox[{{100., -20.209864773684398`, 8.37120008298634}, {
      66.01282525764451, -23.000750861478913`, 9.527222951589215}, {
      66.01282525764451, -22.32839429440756, 11.01114551691055}, {
      100., -19.61909122102756, 9.675065098540651}, {
      100., -20.209864773684398`, 8.37120008298634}}], 
     Polygon3DBox[{{100., -19.61909122102756, 9.675065098540651}, {
      66.01282525764451, -22.32839429440756, 11.01114551691055}, {
      66.01282525764451, -21.56042411505009, 12.447916666666666`}, {
      100., -18.944305707784597`, 10.937499999999998`}, {
      100., -19.61909122102756, 9.675065098540651}}], 
     Polygon3DBox[{{100., -18.944305707784597`, 10.937499999999998`}, {
      66.01282525764451, -21.56042411505009, 12.447916666666666`}, {
      66.01282525764455, -20.70012888961545, 13.831383926217182`}, {
      99.99999999999994, -18.18839776911818, 12.153098847303799`}, {
      100., -18.944305707784597`, 10.937499999999998`}}], 
     Polygon3DBox[{{99.99999999999994, -18.18839776911818, 
      12.153098847303799`}, {66.01282525764455, -20.70012888961545, 
      13.831383926217182`}, {66.01282525764455, -19.751192534333875`, 
      15.155623076362943`}, {100., -17.35460431887077, 13.316656259565764`}, {
      99.99999999999994, -18.18839776911818, 12.153098847303799`}}], 
     Polygon3DBox[{{99.99999999999994, -17.354604318870773`, 
      13.316656259565761`}, {66.01282525764455, -19.751192534333878`, 
      15.15562307636294}, {66.01282525764455, -18.71767854036204, 
      16.414963521762132`}, {100., -16.44649578860263, 14.423189705314007`}, {
      99.99999999999994, -17.354604318870773`, 13.316656259565761`}}], 
     Polygon3DBox[{{100., -16.44649578860263, 14.423189705314007`}, {
      66.01282525764455, -18.71767854036204, 16.414963521762132`}, {
      66.01282525764451, -17.604012573290092`, 17.60401257329009}, {
      100., -15.467960838455728`, 15.467960838455726`}, {
      100., -16.44649578860263, 14.423189705314007`}}], 
     Polygon3DBox[{{100., -15.467960838455728`, 15.467960838455726`}, {
      66.01282525764451, -17.604012573290092`, 17.60401257329009}, {
      66.01282525764455, -16.414963521762132`, 18.71767854036204}, {
      100., -14.423189705314007`, 16.44649578860263}, {
      100., -15.467960838455728`, 15.467960838455726`}}], 
     Polygon3DBox[{{100., -14.423189705314009`, 16.44649578860263}, {
      66.01282525764455, -16.414963521762132`, 18.71767854036204}, {
      66.01282525764455, -15.155623076362943`, 19.751192534333875`}, {
      100., -13.316656259565764`, 17.35460431887077}, {
      100., -14.423189705314009`, 16.44649578860263}}], 
     Polygon3DBox[{{100., -13.316656259565764`, 17.35460431887077}, {
      66.01282525764455, -15.155623076362943`, 19.751192534333875`}, {
      66.01282525764451, -13.831383926217184`, 20.70012888961545}, {
      99.99999999999994, -12.1530988473038, 18.18839776911818}, {
      100., -13.316656259565764`, 17.35460431887077}}], 
     Polygon3DBox[{{100., -12.153098847303802`, 18.188397769118176`}, {
      66.01282525764451, -13.831383926217185`, 20.70012888961545}, {
      66.01282525764451, -12.44791666666667, 21.56042411505009}, {
      100., -10.937500000000002`, 18.944305707784594`}, {
      100., -12.153098847303802`, 18.188397769118176`}}], 
     Polygon3DBox[{{100., -10.937500000000002`, 18.944305707784594`}, {
      66.01282525764451, -12.44791666666667, 21.56042411505009}, {
      66.01282525764451, -11.011145516910558`, 22.328394294407552`}, {
      100., -9.675065098540657, 19.619091221027556`}, {
      100., -10.937500000000002`, 18.944305707784594`}}], 
     Polygon3DBox[{{100., -9.675065098540657, 19.619091221027556`}, {
      66.01282525764451, -11.011145516910558`, 22.328394294407552`}, {
      66.01282525764455, -9.52722295158922, 23.000750861478906`}, {
      100., -8.371200082986345, 20.209864773684394`}, {
      100., -9.675065098540657, 19.619091221027556`}}], 
     Polygon3DBox[{{100., -8.37120008298634, 20.209864773684398`}, {
      66.01282525764451, -9.527222951589216, 23.000750861478913`}, {
      66.01282525764455, -8.002503354943297, 23.5746146822219}, {
      100., -7.031488303506662, 20.714096582705434`}, {
      100., -8.37120008298634, 20.209864773684398`}}], 
     Polygon3DBox[{{100., -7.031488303506662, 20.714096582705434`}, {
      66.01282525764455, -8.002503354943297, 23.5746146822219}, {
      66.01282525764455, -6.443515810364846, 24.047528383654925`}, {
      100.00000000000004`, -5.661666611617647, 21.129627450073365`}, {
      100., -7.031488303506662, 20.714096582705434`}}], 
     Polygon3DBox[{{100.00000000000004`, -5.661666611617647, 
      21.129627450073365`}, {66.01282525764455, -6.443515810364846, 
      24.047528383654925`}, {66.0128252576445, -4.856936141859866, 
      24.41746687670543}, {99.99999999999994, -4.267600794102812, 
      21.454678008820668`}, {100.00000000000004`, -5.661666611617647, 
      21.129627450073365`}}], 
     Polygon3DBox[{{99.99999999999994, -4.267600794102807, 
      21.454678008820668`}, {66.01282525764451, -4.856936141859862, 
      24.41746687670543}, {66.01282525764455, -3.2495583271450377`, 
      24.682846027952156`}, {100., -2.855260454813631, 21.687856342552102`}, {
      99.99999999999994, -4.267600794102807, 21.454678008820668`}}], 
     Polygon3DBox[{{100., -2.855260454813631, 21.687856342552102`}, {
      66.01282525764455, -3.2495583271450377`, 24.682846027952156`}, {
      66.01282525764451, -1.6282654047921084`, 24.842529443127734`}, {
      100., -1.430693451909384, 21.82816394584445}, {100., -2.855260454813631,
       21.687856342552102`}}], 
     Polygon3DBox[{{100., -1.430693451909384, 21.82816394584445}, {
      66.01282525764451, -1.6282654047921084`, 24.842529443127734`}, {
      66.01282525764451, -7.0524156069680584`*^-15, 24.895833333333336`}, {
      100., -6.196683169302477*^-15, 21.875}, {100., -1.430693451909384, 
      21.82816394584445}}], 
     Polygon3DBox[{{100., -1.3394574365674177`*^-15, 21.875}, {
      66.01282525764451, -1.5244301301886326`*^-15, 24.895833333333336`}, {
      66.01282525764451, 1.6282654047921, 24.842529443127734`}, {100., 
      1.4306934519093764`, 21.82816394584445}, {
      100., -1.3394574365674177`*^-15, 21.875}}], 
     Polygon3DBox[{{100., 1.4306934519093764`, 21.82816394584445}, {
      66.01282525764451, 1.6282654047921, 24.842529443127734`}, {
      66.01282525764455, 3.2495583271450292`, 24.682846027952156`}, {100., 
      2.855260454813624, 21.687856342552102`}, {100., 1.4306934519093764`, 
      21.82816394584445}}], 
     Polygon3DBox[{{100., 2.855260454813624, 21.687856342552102`}, {
      66.01282525764455, 3.2495583271450292`, 24.682846027952156`}, {
      66.01282525764451, 4.856936141859853, 24.41746687670543}, {100., 
      4.267600794102799, 21.454678008820668`}, {100., 2.855260454813624, 
      21.687856342552102`}}], 
     Polygon3DBox[{{100., 4.267600794102799, 21.454678008820668`}, {
      66.01282525764451, 4.856936141859853, 24.41746687670543}, {
      66.01282525764451, 6.443515810364831, 24.047528383654935`}, {100., 
      5.661666611617633, 21.12962745007337}, {100., 4.267600794102799, 
      21.454678008820668`}}], 
     Polygon3DBox[{{99.99999999999994, 5.661666611617639, 
      21.12962745007337}, {66.01282525764451, 6.443515810364837, 
      24.047528383654935`}, {66.01282525764455, 8.00250335494329, 
      23.574614682221902`}, {100., 7.031488303506655, 20.714096582705437`}, {
      99.99999999999994, 5.661666611617639, 21.12962745007337}}], 
     Polygon3DBox[{{100., 7.031488303506655, 20.714096582705437`}, {
      66.01282525764455, 8.00250335494329, 23.574614682221902`}, {
      66.01282525764451, 9.527222951589208, 23.000750861478913`}, {
      100.00000000000004`, 8.371200082986332, 20.209864773684398`}, {100., 
      7.031488303506655, 20.714096582705437`}}], 
     Polygon3DBox[{{100.00000000000004`, 8.371200082986332, 
      20.209864773684398`}, {66.01282525764451, 9.527222951589208, 
      23.000750861478913`}, {66.01282525764451, 11.011145516910549`, 
      22.32839429440756}, {100., 9.67506509854065, 19.61909122102756}, {
      100.00000000000004`, 8.371200082986332, 20.209864773684398`}}], 
     Polygon3DBox[{{100., 9.67506509854065, 19.61909122102756}, {
      66.01282525764451, 11.011145516910549`, 22.32839429440756}, {
      66.01282525764455, 12.44791666666666, 21.56042411505009}, {100., 
      10.937499999999996`, 18.944305707784597`}, {100., 9.67506509854065, 
      19.61909122102756}}], 
     Polygon3DBox[{{100., 10.937499999999996`, 18.944305707784597`}, {
      66.01282525764455, 12.44791666666666, 21.56042411505009}, {
      66.01282525764451, 13.831383926217175`, 20.700128889615456`}, {100., 
      12.153098847303792`, 18.188397769118183`}, {100., 10.937499999999996`, 
      18.944305707784597`}}], 
     Polygon3DBox[{{100., 12.153098847303792`, 18.188397769118183`}, {
      66.01282525764451, 13.831383926217175`, 20.700128889615456`}, {
      66.01282525764451, 15.155623076362934`, 19.75119253433388}, {100., 
      13.316656259565757`, 17.354604318870773`}, {100., 12.153098847303792`, 
      18.188397769118183`}}], 
     Polygon3DBox[{{100., 13.316656259565757`, 17.354604318870773`}, {
      66.01282525764451, 15.155623076362934`, 19.75119253433388}, {
      66.01282525764451, 16.41496352176212, 18.71767854036205}, {100., 
      14.423189705313998`, 16.44649578860264}, {100., 13.316656259565757`, 
      17.354604318870773`}}], 
     Polygon3DBox[{{100., 14.423189705313998`, 16.44649578860264}, {
      66.01282525764451, 16.41496352176212, 18.71767854036205}, {
      66.01282525764455, 17.60401257329008, 17.6040125732901}, {100., 
      15.467960838455719`, 15.467960838455737`}, {100., 14.423189705313998`, 
      16.44649578860264}}], 
     Polygon3DBox[{{100., 15.467960838455726`, 15.467960838455728`}, {
      66.01282525764451, 17.60401257329009, 17.604012573290092`}, {
      66.01282525764455, 18.71767854036204, 16.414963521762132`}, {100., 
      16.44649578860263, 14.423189705314009`}, {100., 15.467960838455726`, 
      15.467960838455728`}}], 
     Polygon3DBox[{{100., 16.44649578860263, 14.423189705314009`}, {
      66.01282525764455, 18.71767854036204, 16.414963521762132`}, {
      66.01282525764451, 19.751192534333875`, 15.155623076362946`}, {100., 
      17.354604318870766`, 13.316656259565768`}, {100., 16.44649578860263, 
      14.423189705314009`}}], 
     Polygon3DBox[{{100., 17.354604318870766`, 13.316656259565768`}, {
      66.01282525764451, 19.751192534333875`, 15.155623076362946`}, {
      66.01282525764451, 20.700128889615446`, 13.831383926217189`}, {100., 
      18.188397769118172`, 12.153098847303806`}, {100., 17.354604318870766`, 
      13.316656259565768`}}], 
     Polygon3DBox[{{100., 18.188397769118172`, 12.153098847303806`}, {
      66.01282525764451, 20.700128889615446`, 13.831383926217189`}, {
      66.01282525764455, 21.560424115050083`, 12.447916666666675`}, {100., 
      18.94430570778459, 10.937500000000007`}, {100., 18.188397769118172`, 
      12.153098847303806`}}], 
     Polygon3DBox[{{100., 18.94430570778459, 10.937500000000007`}, {
      66.01282525764455, 21.560424115050083`, 12.447916666666675`}, {
      66.01282525764451, 22.328394294407552`, 11.011145516910563`}, {100., 
      19.619091221027553`, 9.675065098540662}, {100., 18.94430570778459, 
      10.937500000000007`}}], 
     Polygon3DBox[{{100., 19.619091221027553`, 9.675065098540662}, {
      66.01282525764451, 22.328394294407552`, 11.011145516910563`}, {
      66.01282525764451, 23.000750861478906`, 9.527222951589227}, {100., 
      20.209864773684394`, 8.37120008298635}, {100., 19.619091221027553`, 
      9.675065098540662}}], 
     Polygon3DBox[{{100., 20.209864773684398`, 8.371200082986341}, {
      66.01282525764451, 23.000750861478913`, 9.527222951589218}, {
      66.01282525764455, 23.5746146822219, 8.002503354943299}, {100., 
      20.714096582705434`, 7.031488303506663}, {100., 20.209864773684398`, 
      8.371200082986341}}], 
     Polygon3DBox[{{100., 20.714096582705434`, 7.031488303506663}, {
      66.01282525764455, 23.5746146822219, 8.002503354943299}, {
      66.01282525764455, 24.047528383654925`, 6.443515810364847}, {
      100.00000000000004`, 21.129627450073365`, 5.6616666116176475`}, {100., 
      20.714096582705434`, 7.031488303506663}}], 
     Polygon3DBox[{{100.00000000000004`, 21.129627450073365`, 
      5.6616666116176475`}, {66.01282525764455, 24.047528383654925`, 
      6.443515810364847}, {66.0128252576445, 24.41746687670543, 
      4.856936141859869}, {99.99999999999994, 21.454678008820668`, 
      4.267600794102814}, {100.00000000000004`, 21.129627450073365`, 
      5.6616666116176475`}}], 
     Polygon3DBox[{{99.99999999999994, 21.454678008820668`, 
      4.267600794102814}, {66.0128252576445, 24.41746687670543, 
      4.856936141859869}, {66.01282525764451, 24.682846027952156`, 
      3.249558327145045}, {100., 21.687856342552102`, 2.8552604548136373`}, {
      99.99999999999994, 21.454678008820668`, 4.267600794102814}}], 
     Polygon3DBox[{{100., 21.687856342552102`, 2.8552604548136373`}, {
      66.01282525764451, 24.682846027952156`, 3.249558327145045}, {
      66.01282525764451, 24.842529443127734`, 1.6282654047921157`}, {100., 
      21.82816394584445, 1.4306934519093903`}, {100., 21.687856342552102`, 
      2.8552604548136373`}}], 
     Polygon3DBox[{{100., 21.82816394584445, 1.4306934519093903`}, {
      66.01282525764451, 24.842529443127734`, 1.6282654047921157`}, {
      66.01282525764451, 24.895833333333336`, 1.4104831213936117`*^-14}, {
      100., 21.875, 1.2393366338604954`*^-14}, {100., 21.82816394584445, 
      1.4306934519093903`}}], 
     Polygon3DBox[{{100., 21.875, 2.6789148731348353`*^-15}, {
      66.01282525764451, 24.895833333333336`, 3.048860260377265*^-15}, {
      66.01282525764451, 24.842529443127734`, -1.6282654047920986`}, {100., 
      21.82816394584445, -1.4306934519093752`}, {100., 21.875, 
      2.6789148731348353`*^-15}}], 
     Polygon3DBox[{{100., 21.82816394584445, -1.4306934519093752`}, {
      66.01282525764451, 24.842529443127734`, -1.6282654047920986`}, {
      66.01282525764455, 24.682846027952156`, -3.249558327145028}, {100., 
      21.687856342552102`, -2.8552604548136227`}, {100., 
      21.82816394584445, -1.4306934519093752`}}], 
     Polygon3DBox[{{100., 21.687856342552102`, -2.8552604548136227`}, {
      66.01282525764455, 24.682846027952156`, -3.249558327145028}, {
      66.01282525764451, 24.41746687670543, -4.856936141859852}, {100., 
      21.454678008820668`, -4.2676007941027985`}, {100., 
      21.687856342552102`, -2.8552604548136227`}}], 
     Polygon3DBox[{{100., 21.454678008820668`, -4.2676007941027985`}, {
      66.01282525764451, 24.41746687670543, -4.856936141859852}, {
      66.01282525764451, 24.047528383654935`, -6.44351581036483}, {100., 
      21.12962745007337, -5.661666611617632}, {100., 
      21.454678008820668`, -4.2676007941027985`}}], 
     Polygon3DBox[{{100., 21.12962745007337, -5.661666611617632}, {
      66.01282525764451, 24.047528383654935`, -6.44351581036483}, {
      66.01282525764455, 23.574614682221902`, -8.002503354943281}, {
      100.00000000000004`, 20.714096582705437`, -7.031488303506649}, {100., 
      21.12962745007337, -5.661666611617632}}], 
     Polygon3DBox[{{100.00000000000004`, 
      20.714096582705437`, -7.031488303506649}, {66.01282525764455, 
      23.574614682221902`, -8.002503354943281}, {66.01282525764451, 
      23.00075086147892, -9.5272229515892}, {100., 
      20.2098647736844, -8.371200082986327}, {100.00000000000004`, 
      20.714096582705437`, -7.031488303506649}}], 
     Polygon3DBox[{{100., 20.2098647736844, -8.371200082986327}, {
      66.01282525764451, 23.00075086147892, -9.5272229515892}, {
      66.01282525764451, 22.328394294407563`, -11.01114551691054}, {100., 
      19.619091221027563`, -9.67506509854064}, {100., 
      20.2098647736844, -8.371200082986327}}], 
     Polygon3DBox[{{100., 19.61909122102756, -9.675065098540648}, {
      66.01282525764451, 22.32839429440756, -11.011145516910547`}, {
      66.01282525764451, 21.560424115050093`, -12.447916666666659`}, {100., 
      18.9443057077846, -10.937499999999993`}, {100., 
      19.61909122102756, -9.675065098540648}}], 
     Polygon3DBox[{{100., 18.9443057077846, -10.937499999999993`}, {
      66.01282525764451, 21.560424115050093`, -12.447916666666659`}, {
      66.01282525764451, 20.700128889615456`, -13.831383926217175`}, {100., 
      18.188397769118183`, -12.153098847303792`}, {100., 
      18.9443057077846, -10.937499999999993`}}], 
     Polygon3DBox[{{100., 18.188397769118183`, -12.153098847303792`}, {
      66.01282525764451, 20.700128889615456`, -13.831383926217175`}, {
      66.01282525764451, 19.75119253433388, -15.155623076362934`}, {100., 
      17.354604318870773`, -13.316656259565757`}, {100., 
      18.188397769118183`, -12.153098847303792`}}], 
     Polygon3DBox[{{100., 17.354604318870773`, -13.316656259565757`}, {
      66.01282525764451, 19.75119253433388, -15.155623076362934`}, {
      66.01282525764451, 18.71767854036205, -16.41496352176212}, {100., 
      16.44649578860264, -14.423189705313998`}, {100., 
      17.354604318870773`, -13.316656259565757`}}], 
     Polygon3DBox[{{100., 16.44649578860264, -14.423189705313998`}, {
      66.01282525764451, 18.71767854036205, -16.41496352176212}, {
      66.01282525764455, 17.6040125732901, -17.60401257329008}, {100., 
      15.467960838455737`, -15.467960838455719`}, {100., 
      16.44649578860264, -14.423189705313998`}}], 
     Polygon3DBox[{{100., 15.467960838455737`, -15.467960838455719`}, {
      66.01282525764455, 17.6040125732901, -17.60401257329008}, {
      66.01282525764451, 16.414963521762147`, -18.71767854036203}, {100., 
      14.423189705314018`, -16.446495788602622`}, {100., 
      15.467960838455737`, -15.467960838455719`}}], 
     Polygon3DBox[{{99.99999999999994, 
      14.42318970531401, -16.44649578860263}, {66.01282525764451, 
      16.414963521762136`, -18.71767854036204}, {66.01282525764455, 
      15.155623076362946`, -19.75119253433387}, {100.00000000000004`, 
      13.316656259565768`, -17.354604318870763`}, {99.99999999999994, 
      14.42318970531401, -16.44649578860263}}], 
     Polygon3DBox[{{100.00000000000004`, 
      13.316656259565768`, -17.354604318870763`}, {66.01282525764455, 
      15.155623076362946`, -19.75119253433387}, {66.01282525764455, 
      13.831383926217182`, -20.70012888961545}, {99.99999999999994, 
      12.153098847303799`, -18.18839776911818}, {100.00000000000004`, 
      13.316656259565768`, -17.354604318870763`}}], 
     Polygon3DBox[{{100., 12.153098847303813`, -18.18839776911817}, {
      66.01282525764451, 13.8313839262172, -20.70012888961544}, {
      66.01282525764451, 12.44791666666668, -21.560424115050083`}, {100., 
      10.93750000000001, -18.94430570778459}, {100., 
      12.153098847303813`, -18.18839776911817}}], 
     Polygon3DBox[{{100., 10.93750000000001, -18.94430570778459}, {
      66.01282525764451, 12.44791666666668, -21.560424115050083`}, {
      66.01282525764451, 11.011145516910556`, -22.328394294407552`}, {100., 
      9.675065098540655, -19.619091221027556`}, {100., 
      10.93750000000001, -18.94430570778459}}], 
     Polygon3DBox[{{100., 9.675065098540655, -19.619091221027556`}, {
      66.01282525764451, 11.011145516910556`, -22.328394294407552`}, {
      66.01282525764451, 9.527222951589208, -23.000750861478913`}, {
      100.00000000000004`, 8.371200082986332, -20.209864773684398`}, {100., 
      9.675065098540655, -19.619091221027556`}}], 
     Polygon3DBox[{{100., 8.37120008298635, -20.209864773684394`}, {
      66.01282525764451, 9.527222951589229, -23.000750861478906`}, {
      66.01282525764455, 8.002503354943299, -23.5746146822219}, {100., 
      7.031488303506665, -20.714096582705434`}, {100., 
      8.37120008298635, -20.209864773684394`}}], 
     Polygon3DBox[{{100., 7.031488303506665, -20.714096582705434`}, {
      66.01282525764455, 8.002503354943299, -23.5746146822219}, {
      66.01282525764451, 6.443515810364837, -24.047528383654935`}, {
      99.99999999999994, 5.661666611617639, -21.12962745007337}, {100., 
      7.031488303506665, -20.714096582705434`}}], 
     Polygon3DBox[{{100., 5.661666611617658, -21.129627450073365`}, {
      66.01282525764451, 6.443515810364859, -24.047528383654925`}, {
      66.01282525764451, 4.85693614185987, -24.417466876705426`}, {100., 
      4.2676007941028145`, -21.454678008820665`}, {100., 
      5.661666611617658, -21.129627450073365`}}], 
     Polygon3DBox[{{100., 4.2676007941028145`, -21.454678008820665`}, {
      66.01282525764451, 4.85693614185987, -24.417466876705426`}, {
      66.01282525764455, 3.2495583271450355`, -24.682846027952156`}, {100., 
      2.8552604548136293`, -21.687856342552102`}, {100., 
      4.2676007941028145`, -21.454678008820665`}}], 
     Polygon3DBox[{{100., 2.8552604548136484`, -21.6878563425521}, {
      66.01282525764451, 3.249558327145057, -24.682846027952152`}, {
      66.01282525764451, 1.6282654047921172`, -24.842529443127734`}, {100., 
      1.4306934519093917`, -21.82816394584445}, {100., 
      2.8552604548136484`, -21.6878563425521}}], 
     Polygon3DBox[{{100., 1.4306934519093917`, -21.82816394584445}, {
      66.01282525764451, 1.6282654047921172`, -24.842529443127734`}, {
      66.01282525764451, 4.573290390565897*^-15, -24.895833333333336`}, {100.,
       4.0183723097022526`*^-15, -21.875}, {100., 
      1.4306934519093917`, -21.82816394584445}}], 
     Polygon3DBox[{{100., 4.0183723097022526`*^-15, -21.875}, {
      66.01282525764451, 4.573290390565897*^-15, -24.895833333333336`}, {
      66.01282525764451, -1.6282654047921081`, -24.842529443127734`}, {
      100., -1.4306934519093837`, -21.82816394584445}, {100., 
      4.0183723097022526`*^-15, -21.875}}], 
     Polygon3DBox[{{100., -1.4306934519093644`, -21.82816394584445}, {
      66.01282525764455, -1.6282654047920861`, -24.842529443127734`}, {
      66.01282525764455, -3.2495583271450266`, -24.682846027952156`}, {
      100.00000000000004`, -2.8552604548136213`, -21.687856342552102`}, {
      100., -1.4306934519093644`, -21.82816394584445}}], 
     Polygon3DBox[{{
      100.00000000000004`, -2.8552604548136213`, -21.687856342552102`}, {
      66.01282525764455, -3.2495583271450266`, -24.682846027952156`}, {
      66.01282525764451, -4.856936141859861, -24.41746687670543}, {
      99.99999999999994, -4.2676007941028065`, -21.454678008820668`}, {
      100.00000000000004`, -2.8552604548136213`, -21.687856342552102`}}], 
     Polygon3DBox[{{
      99.99999999999994, -4.267600794102787, -21.45467800882067}, {
      66.01282525764451, -4.85693614185984, -24.417466876705433`}, {
      66.01282525764451, -6.443515810364828, -24.047528383654935`}, {
      100., -5.6616666116176315`, -21.12962745007337}, {
      99.99999999999994, -4.267600794102787, -21.45467800882067}}], 
     Polygon3DBox[{{100., -5.6616666116176315`, -21.12962745007337}, {
      66.01282525764451, -6.443515810364828, -24.047528383654935`}, {
      66.01282525764455, -8.002503354943292, -23.574614682221902`}, {
      100., -7.0314883035066575`, -20.714096582705437`}, {
      100., -5.6616666116176315`, -21.12962745007337}}], 
     Polygon3DBox[{{100., -7.0314883035066575`, -20.714096582705437`}, {
      66.01282525764455, -8.002503354943292, -23.574614682221902`}, {
      66.01282525764455, -9.52722295158922, -23.000750861478906`}, {
      100., -8.371200082986345, -20.209864773684394`}, {
      100., -7.0314883035066575`, -20.714096582705437`}}], 
     Polygon3DBox[{{
      100.00000000000004`, -8.371200082986325, -20.2098647736844}, {
      66.01282525764451, -9.527222951589199, -23.00075086147892}, {
      66.01282525764451, -11.011145516910547`, -22.32839429440756}, {
      100., -9.675065098540648, -19.61909122102756}, {
      100.00000000000004`, -8.371200082986325, -20.2098647736844}}], 
     Polygon3DBox[{{100., -9.675065098540648, -19.61909122102756}, {
      66.01282525764451, -11.011145516910547`, -22.32839429440756}, {
      66.01282525764451, -12.44791666666667, -21.56042411505009}, {
      100., -10.937500000000002`, -18.944305707784594`}, {
      100., -9.675065098540648, -19.61909122102756}}], 
     Polygon3DBox[{{100., -10.937499999999986`, -18.944305707784604`}, {
      66.01282525764451, -12.447916666666652`, -21.560424115050097`}, {
      66.01282525764451, -13.831383926217171`, -20.700128889615456`}, {
      100., -12.15309884730379, -18.188397769118183`}, {
      100., -10.937499999999986`, -18.944305707784604`}}], 
     Polygon3DBox[{{100., -12.15309884730379, -18.188397769118183`}, {
      66.01282525764451, -13.831383926217171`, -20.700128889615456`}, {
      66.01282525764455, -15.15562307636294, -19.751192534333875`}, {
      100., -13.316656259565761`, -17.35460431887077}, {
      100., -12.15309884730379, -18.188397769118183`}}], 
     Polygon3DBox[{{100., -13.316656259565747`, -17.35460431887078}, {
      66.01282525764451, -15.155623076362922`, -19.751192534333892`}, {
      66.01282525764455, -16.414963521762118`, -18.717678540362055`}, {
      100., -14.423189705313996`, -16.44649578860264}, {
      100., -13.316656259565747`, -17.35460431887078}}], 
     Polygon3DBox[{{100., -14.423189705313996`, -16.44649578860264}, {
      66.01282525764455, -16.414963521762118`, -18.717678540362055`}, {
      66.01282525764455, -17.604012573290085`, -17.604012573290095`}, {
      100., -15.467960838455724`, -15.46796083845573}, {
      100., -14.423189705313996`, -16.44649578860264}}], 
     Polygon3DBox[{{100., -15.467960838455724`, -15.46796083845573}, {
      66.01282525764455, -17.604012573290085`, -17.604012573290095`}, {
      66.01282525764455, -18.717678540362044`, -16.41496352176213}, {
      100., -16.446495788602633`, -14.423189705314002`}, {
      100., -15.467960838455724`, -15.46796083845573}}], 
     Polygon3DBox[{{100., -16.446495788602622`, -14.423189705314018`}, {
      66.01282525764451, -18.71767854036203, -16.414963521762147`}, {
      66.01282525764455, -19.75119253433387, -15.155623076362946`}, {
      100.00000000000004`, -17.354604318870763`, -13.316656259565768`}, {
      100., -16.446495788602622`, -14.423189705314018`}}], 
     Polygon3DBox[{{
      100.00000000000004`, -17.354604318870763`, -13.316656259565768`}, {
      66.01282525764455, -19.75119253433387, -15.155623076362946`}, {
      66.01282525764455, -20.70012888961545, -13.831383926217182`}, {
      99.99999999999994, -18.18839776911818, -12.153098847303799`}, {
      100.00000000000004`, -17.354604318870763`, -13.316656259565768`}}], 
     Polygon3DBox[{{100., -18.18839776911817, -12.153098847303813`}, {
      66.01282525764451, -20.70012888961544, -13.8313839262172}, {
      66.01282525764451, -21.560424115050083`, -12.44791666666668}, {
      100., -18.94430570778459, -10.93750000000001}, {
      100., -18.18839776911817, -12.153098847303813`}}], 
     Polygon3DBox[{{100., -18.94430570778459, -10.93750000000001}, {
      66.01282525764451, -21.560424115050083`, -12.44791666666668}, {
      66.01282525764451, -22.328394294407552`, -11.011145516910558`}, {
      100., -19.619091221027556`, -9.675065098540657}, {
      100., -18.94430570778459, -10.93750000000001}}], 
     Polygon3DBox[{{100., -19.619091221027546`, -9.675065098540673}, {
      66.01282525764455, -22.32839429440754, -11.011145516910576`}, {
      66.01282525764451, -23.000750861478906`, -9.52722295158923}, {
      100., -20.209864773684394`, -8.371200082986352}, {
      100., -19.619091221027546`, -9.675065098540673}}], 
     Polygon3DBox[{{100., -20.209864773684394`, -8.371200082986352}, {
      66.01282525764451, -23.000750861478906`, -9.52722295158923}, {
      66.01282525764455, -23.5746146822219, -8.0025033549433}, {
      100., -20.714096582705434`, -7.0314883035066655`}, {
      100., -20.209864773684394`, -8.371200082986352}}], 
     Polygon3DBox[{{100., -20.714096582705434`, -7.0314883035066655`}, {
      66.01282525764455, -23.5746146822219, -8.0025033549433}, {
      66.01282525764451, -24.047528383654935`, -6.443515810364838}, {
      99.99999999999994, -21.12962745007337, -5.66166661161764}, {
      100., -20.714096582705434`, -7.0314883035066655`}}], 
     Polygon3DBox[{{100., -21.129627450073365`, -5.661666611617659}, {
      66.01282525764451, -24.047528383654925`, -6.44351581036486}, {
      66.01282525764451, -24.417466876705426`, -4.8569361418598715`}, {
      100., -21.454678008820665`, -4.267600794102816}, {
      100., -21.129627450073365`, -5.661666611617659}}], 
     Polygon3DBox[{{100., -21.454678008820665`, -4.267600794102816}, {
      66.01282525764451, -24.417466876705426`, -4.8569361418598715`}, {
      66.01282525764455, -24.682846027952156`, -3.249558327145037}, {
      100., -21.687856342552102`, -2.8552604548136307`}, {
      100., -21.454678008820665`, -4.267600794102816}}], 
     Polygon3DBox[{{100., -21.6878563425521, -2.8552604548136498`}, {
      66.01282525764451, -24.682846027952152`, -3.2495583271450585`}, {
      66.01282525764451, -24.842529443127734`, -1.6282654047921186`}, {
      100., -21.82816394584445, -1.4306934519093928`}, {
      100., -21.6878563425521, -2.8552604548136498`}}], 
     Polygon3DBox[{{100., -21.82816394584445, -1.4306934519093928`}, {
      66.01282525764451, -24.842529443127734`, -1.6282654047921186`}, {
      66.01282525764451, -24.895833333333336`, -6.09772052075453*^-15}, {
      100., -21.875, -5.357829746269671*^-15}, {
      100., -21.82816394584445, -1.4306934519093928`}}], 
     Polygon3DBox[{{66.01282525764455, -24.895833333333332`, 0.}, {
      49.34615859097786, -27.916666666666664`, 0.}, {
      49.34615859097786, -27.856894940411014`, 1.825837357674827}, {
      66.01282525764455, -24.84252944312773, 1.628265404792103}, {
      66.01282525764455, -24.895833333333332`, 0.}}], 
     Polygon3DBox[{{66.01282525764455, -24.84252944312773, 
      1.628265404792103}, {49.34615859097786, -27.856894940411014`, 
      1.825837357674827}, {49.34615859097786, -27.677835713352206`, 
      3.64385619947644}, {66.01282525764455, -24.682846027952152`, 
      3.249558327145034}, {66.01282525764455, -24.84252944312773, 
      1.628265404792103}}], 
     Polygon3DBox[{{66.01282525764455, -24.682846027952152`, 
      3.249558327145034}, {49.34615859097786, -27.677835713352206`, 
      3.64385619947644}, {49.34615859097785, -27.380255744590183`, 
      5.446271489616913}, {66.01282525764455, -24.417466876705426`, 
      4.856936141859858}, {66.01282525764455, -24.682846027952152`, 
      3.249558327145034}}], 
     Polygon3DBox[{{66.01282525764455, -24.417466876705426`, 
      4.856936141859858}, {49.34615859097785, -27.380255744590183`, 
      5.446271489616913}, {49.34615859097785, -26.96542931723649, 
      7.225365009112037}, {66.01282525764455, -24.047528383654928`, 
      6.443515810364839}, {66.01282525764455, -24.417466876705426`, 
      4.856936141859858}}], 
     Polygon3DBox[{{66.01282525764455, -24.047528383654928`, 
      6.443515810364839}, {49.34615859097785, -26.96542931723649, 
      7.225365009112037}, {49.34615859097785, -26.435132781738368`, 
      8.973518406379926}, {66.01282525764455, -23.5746146822219, 
      8.002503354943292}, {66.01282525764455, -24.047528383654928`, 
      6.443515810364839}}], 
     Polygon3DBox[{{66.01282525764455, -23.5746146822219, 
      8.002503354943292}, {49.34615859097785, -26.435132781738368`, 
      8.973518406379926}, {49.34615859097786, -25.79163694927342, 
      10.683245820192088`}, {66.01282525764455, -23.000750861478906`, 
      9.527222951589213}, {66.01282525764455, -23.5746146822219, 
      8.002503354943292}}], 
     Polygon3DBox[{{66.01282525764455, -23.000750861478906`, 
      9.527222951589215}, {49.34615859097786, -25.79163694927342, 
      10.68324582019209}, {49.34615859097785, -25.03769736778755, 
      12.34722593528045}, {66.01282525764455, -22.328394294407552`, 
      11.011145516910549`}, {66.01282525764455, -23.000750861478906`, 
      9.527222951589215}}], 
     Polygon3DBox[{{66.01282525764455, -22.328394294407552`, 
      11.011145516910549`}, {49.34615859097785, -25.03769736778755, 
      12.34722593528045}, {49.34615859097786, -24.17654252231558, 
      13.95833333333333}, {66.01282525764455, -21.560424115050086`, 
      12.447916666666663`}, {66.01282525764455, -22.328394294407552`, 
      11.011145516910549`}}], 
     Polygon3DBox[{{66.01282525764455, -21.560424115050086`, 
      12.447916666666663`}, {49.34615859097786, -24.17654252231558, 
      13.95833333333333}, {49.34615859097786, -23.21186001011272, 
      15.509669005130561`}, {66.0128252576446, -20.700128889615446`, 
      13.831383926217178`}, {66.01282525764455, -21.560424115050086`, 
      12.447916666666663`}}], 
     Polygon3DBox[{{66.0128252576446, -20.700128889615446`, 
      13.831383926217178`}, {49.34615859097786, -23.21186001011272, 
      15.509669005130561`}, {49.34615859097786, -22.14778074979698, 
      16.994589893160118`}, {66.0128252576446, -19.75119253433387, 
      15.15562307636294}, {66.0128252576446, -20.700128889615446`, 
      13.831383926217178`}}], 
     Polygon3DBox[{{66.01282525764455, -19.751192534333875`, 
      15.155623076362936`}, {49.34615859097786, -22.147780749796983`, 
      16.994589893160114`}, {49.34615859097785, -20.988861292121452`, 
      18.406737338210256`}, {66.0128252576446, -18.717678540362037`, 
      16.41496352176213}, {66.01282525764455, -19.751192534333875`, 
      15.155623076362936`}}], 
     Polygon3DBox[{{66.0128252576446, -18.717678540362037`, 
      16.41496352176213}, {49.34615859097785, -20.988861292121452`, 
      18.406737338210256`}, {49.34615859097786, -19.740064308124452`, 
      19.74006430812445}, {66.0128252576446, -17.60401257329009, 
      17.604012573290085`}, {66.0128252576446, -18.717678540362037`, 
      16.41496352176213}}], 
     Polygon3DBox[{{66.0128252576446, -17.60401257329009, 
      17.604012573290085`}, {49.34615859097786, -19.740064308124452`, 
      19.74006430812445}, {49.34615859097785, -18.406737338210256`, 
      20.988861292121452`}, {66.0128252576446, -16.41496352176213, 
      18.717678540362037`}, {66.0128252576446, -17.60401257329009, 
      17.604012573290085`}}], 
     Polygon3DBox[{{66.01282525764455, -16.414963521762132`, 
      18.717678540362037`}, {49.34615859097786, -18.406737338210256`, 
      20.98886129212145}, {49.34615859097786, -16.994589893160118`, 
      22.14778074979698}, {66.0128252576446, -15.15562307636294, 
      19.75119253433387}, {66.01282525764455, -16.414963521762132`, 
      18.717678540362037`}}], 
     Polygon3DBox[{{66.0128252576446, -15.15562307636294, 
      19.75119253433387}, {49.34615859097786, -16.994589893160118`, 
      22.14778074979698}, {49.34615859097786, -15.509669005130563`, 
      23.21186001011272}, {66.01282525764455, -13.83138392621718, 
      20.700128889615446`}, {66.0128252576446, -15.15562307636294, 
      19.75119253433387}}], 
     Polygon3DBox[{{66.01282525764455, -13.831383926217184`, 
      20.700128889615446`}, {49.34615859097785, -15.509669005130567`, 
      23.21186001011272}, {49.34615859097785, -13.958333333333336`, 
      24.17654252231558}, {66.01282525764455, -12.447916666666668`, 
      21.560424115050086`}, {66.01282525764455, -13.831383926217184`, 
      20.700128889615446`}}], 
     Polygon3DBox[{{66.01282525764455, -12.447916666666668`, 
      21.560424115050086`}, {49.34615859097785, -13.958333333333336`, 
      24.17654252231558}, {49.34615859097785, -12.347225935280456`, 
      25.037697367787548`}, {66.01282525764455, -11.011145516910556`, 
      22.32839429440755}, {66.01282525764455, -12.447916666666668`, 
      21.560424115050086`}}], 
     Polygon3DBox[{{66.01282525764455, -11.011145516910556`, 
      22.32839429440755}, {49.34615859097785, -12.347225935280456`, 
      25.037697367787548`}, {49.34615859097786, -10.683245820192095`, 
      25.791636949273418`}, {66.0128252576446, -9.52722295158922, 
      23.000750861478902`}, {66.01282525764455, -11.011145516910556`, 
      22.32839429440755}}], 
     Polygon3DBox[{{66.01282525764455, -9.527222951589215, 
      23.000750861478906`}, {49.34615859097785, -10.683245820192091`, 
      25.79163694927342}, {49.34615859097786, -8.973518406379931, 
      26.43513278173836}, {66.0128252576446, -8.002503354943295, 
      23.574614682221895`}, {66.01282525764455, -9.527222951589215, 
      23.000750861478906`}}], 
     Polygon3DBox[{{66.0128252576446, -8.002503354943295, 
      23.574614682221895`}, {49.34615859097786, -8.973518406379931, 
      26.43513278173836}, {49.34615859097786, -7.225365009112044, 
      26.965429317236485`}, {66.01282525764461, -6.443515810364845, 
      24.04752838365492}, {66.0128252576446, -8.002503354943295, 
      23.574614682221895`}}], 
     Polygon3DBox[{{66.01282525764461, -6.443515810364845, 
      24.04752838365492}, {49.34615859097786, -7.225365009112044, 
      26.965429317236485`}, {49.34615859097785, -5.446271489616921, 
      27.380255744590183`}, {66.01282525764451, -4.856936141859865, 
      24.417466876705426`}, {66.01282525764461, -6.443515810364845, 
      24.04752838365492}}], 
     Polygon3DBox[{{66.01282525764455, -4.856936141859862, 
      24.417466876705426`}, {49.34615859097785, -5.446271489616915, 
      27.380255744590183`}, {49.34615859097786, -3.6438561994764433`, 
      27.677835713352206`}, {66.01282525764455, -3.249558327145037, 
      24.682846027952152`}, {66.01282525764455, -4.856936141859862, 
      24.417466876705426`}}], 
     Polygon3DBox[{{66.01282525764455, -3.249558327145037, 
      24.682846027952152`}, {49.34615859097786, -3.6438561994764433`, 
      27.677835713352206`}, {49.34615859097786, -1.8258373576748328`, 
      27.856894940411014`}, {66.01282525764455, -1.6282654047921081`, 
      24.84252944312773}, {66.01282525764455, -3.249558327145037, 
      24.682846027952152`}}], 
     Polygon3DBox[{{66.01282525764455, -1.6282654047921081`, 
      24.84252944312773}, {49.34615859097786, -1.8258373576748328`, 
      27.856894940411014`}, {49.34615859097786, -7.908148044633638*^-15, 
      27.916666666666664`}, {66.01282525764455, -7.052415606968057*^-15, 
      24.895833333333332`}, {66.01282525764455, -1.6282654047921081`, 
      24.84252944312773}}], 
     Polygon3DBox[{{66.01282525764455, -1.5244301301886324`*^-15, 
      24.895833333333332`}, {49.34615859097786, -1.7094028238098471`*^-15, 
      27.916666666666664`}, {49.34615859097786, 1.825837357674823, 
      27.856894940411014`}, {66.01282525764455, 1.6282654047920997`, 
      24.84252944312773}, {66.01282525764455, -1.5244301301886324`*^-15, 
      24.895833333333332`}}], 
     Polygon3DBox[{{66.01282525764455, 1.6282654047920997`, 
      24.84252944312773}, {49.34615859097786, 1.825837357674823, 
      27.856894940411014`}, {49.34615859097786, 3.6438561994764345`, 
      27.677835713352206`}, {66.01282525764455, 3.249558327145029, 
      24.682846027952152`}, {66.01282525764455, 1.6282654047920997`, 
      24.84252944312773}}], 
     Polygon3DBox[{{66.01282525764455, 3.249558327145029, 
      24.682846027952152`}, {49.34615859097786, 3.6438561994764345`, 
      27.677835713352206`}, {49.34615859097786, 5.4462714896169055`, 
      27.380255744590183`}, {66.01282525764455, 4.856936141859852, 
      24.417466876705426`}, {66.01282525764455, 3.249558327145029, 
      24.682846027952152`}}], 
     Polygon3DBox[{{66.01282525764455, 4.856936141859852, 
      24.417466876705426`}, {49.34615859097786, 5.4462714896169055`, 
      27.380255744590183`}, {49.34615859097786, 7.225365009112027, 
      26.96542931723649}, {66.0128252576446, 6.44351581036483, 
      24.047528383654928`}, {66.01282525764455, 4.856936141859852, 
      24.417466876705426`}}], 
     Polygon3DBox[{{66.01282525764455, 6.443515810364835, 
      24.047528383654928`}, {49.34615859097785, 7.225365009112034, 
      26.96542931723649}, {49.34615859097786, 8.97351840637992, 
      26.435132781738368`}, {66.0128252576446, 8.002503354943286, 
      23.5746146822219}, {66.01282525764455, 6.443515810364835, 
      24.047528383654928`}}], 
     Polygon3DBox[{{66.0128252576446, 8.002503354943286, 23.5746146822219}, {
      49.34615859097786, 8.97351840637992, 26.435132781738368`}, {
      49.34615859097786, 10.68324582019208, 25.79163694927342}, {
      66.01282525764461, 9.527222951589206, 23.000750861478906`}, {
      66.0128252576446, 8.002503354943286, 23.5746146822219}}], 
     Polygon3DBox[{{66.01282525764461, 9.527222951589206, 
      23.000750861478906`}, {49.34615859097786, 10.68324582019208, 
      25.79163694927342}, {49.34615859097785, 12.347225935280447`, 
      25.03769736778755}, {66.01282525764455, 11.011145516910547`, 
      22.328394294407552`}, {66.01282525764461, 9.527222951589206, 
      23.000750861478906`}}], 
     Polygon3DBox[{{66.01282525764455, 11.011145516910547`, 
      22.328394294407552`}, {49.34615859097785, 12.347225935280447`, 
      25.03769736778755}, {49.34615859097786, 13.958333333333329`, 
      24.17654252231558}, {66.01282525764455, 12.44791666666666, 
      21.560424115050086`}, {66.01282525764455, 11.011145516910547`, 
      22.328394294407552`}}], 
     Polygon3DBox[{{66.01282525764455, 12.44791666666666, 
      21.560424115050086`}, {49.34615859097786, 13.958333333333329`, 
      24.17654252231558}, {49.34615859097786, 15.509669005130554`, 
      23.211860010112726`}, {66.01282525764455, 13.831383926217171`, 
      20.700128889615453`}, {66.01282525764455, 12.44791666666666, 
      21.560424115050086`}}], 
     Polygon3DBox[{{66.01282525764455, 13.831383926217171`, 
      20.700128889615453`}, {49.34615859097786, 15.509669005130554`, 
      23.211860010112726`}, {49.34615859097786, 16.99458989316011, 
      22.147780749796986`}, {66.01282525764455, 15.155623076362932`, 
      19.751192534333878`}, {66.01282525764455, 13.831383926217171`, 
      20.700128889615453`}}], 
     Polygon3DBox[{{66.01282525764455, 15.155623076362932`, 
      19.751192534333878`}, {49.34615859097786, 16.99458989316011, 
      22.147780749796986`}, {49.34615859097786, 18.406737338210245`, 
      20.98886129212146}, {66.0128252576446, 16.414963521762118`, 
      18.717678540362048`}, {66.01282525764455, 15.155623076362932`, 
      19.751192534333878`}}], 
     Polygon3DBox[{{66.0128252576446, 16.414963521762118`, 
      18.717678540362048`}, {49.34615859097786, 18.406737338210245`, 
      20.98886129212146}, {49.34615859097786, 19.74006430812444, 
      19.74006430812446}, {66.01282525764455, 17.604012573290078`, 
      17.6040125732901}, {66.0128252576446, 16.414963521762118`, 
      18.717678540362048`}}], 
     Polygon3DBox[{{66.0128252576446, 17.604012573290085`, 
      17.60401257329009}, {49.34615859097786, 19.74006430812445, 
      19.740064308124452`}, {49.34615859097786, 20.98886129212145, 
      18.406737338210256`}, {66.01282525764455, 18.717678540362037`, 
      16.414963521762132`}, {66.0128252576446, 17.604012573290085`, 
      17.60401257329009}}], 
     Polygon3DBox[{{66.01282525764455, 18.717678540362037`, 
      16.414963521762132`}, {49.34615859097786, 20.98886129212145, 
      18.406737338210256`}, {49.34615859097785, 22.147780749796976`, 
      16.994589893160125`}, {66.01282525764455, 19.75119253433387, 
      15.155623076362945`}, {66.01282525764455, 18.717678540362037`, 
      16.414963521762132`}}], 
     Polygon3DBox[{{66.01282525764455, 19.75119253433387, 
      15.155623076362945`}, {49.34615859097785, 22.147780749796976`, 
      16.994589893160125`}, {49.346158590977886`, 23.211860010112712`, 
      15.509669005130569`}, {66.01282525764455, 20.700128889615442`, 
      13.831383926217185`}, {66.01282525764455, 19.75119253433387, 
      15.155623076362945`}}], 
     Polygon3DBox[{{66.01282525764455, 20.700128889615442`, 
      13.831383926217185`}, {49.346158590977886`, 23.211860010112712`, 
      15.509669005130569`}, {49.34615859097786, 24.17654252231557, 
      13.958333333333341`}, {66.0128252576446, 21.56042411505008, 
      12.447916666666673`}, {66.01282525764455, 20.700128889615442`, 
      13.831383926217185`}}], 
     Polygon3DBox[{{66.0128252576446, 21.56042411505008, 
      12.447916666666673`}, {49.34615859097786, 24.17654252231557, 
      13.958333333333341`}, {49.34615859097785, 25.037697367787544`, 
      12.347225935280463`}, {66.01282525764455, 22.328394294407545`, 
      11.011145516910561`}, {66.0128252576446, 21.56042411505008, 
      12.447916666666673`}}], 
     Polygon3DBox[{{66.01282525764455, 22.328394294407545`, 
      11.011145516910561`}, {49.34615859097785, 25.037697367787544`, 
      12.347225935280463`}, {49.34615859097785, 25.791636949273418`, 
      10.683245820192104`}, {66.01282525764455, 23.000750861478902`, 
      9.527222951589225}, {66.01282525764455, 22.328394294407545`, 
      11.011145516910561`}}], 
     Polygon3DBox[{{66.01282525764455, 23.000750861478906`, 
      9.527222951589216}, {49.34615859097785, 25.79163694927342, 
      10.683245820192091`}, {49.34615859097786, 26.43513278173836, 
      8.973518406379933}, {66.0128252576446, 23.574614682221895`, 
      8.002503354943297}, {66.01282525764455, 23.000750861478906`, 
      9.527222951589216}}], 
     Polygon3DBox[{{66.0128252576446, 23.574614682221895`, 
      8.002503354943297}, {49.34615859097786, 26.43513278173836, 
      8.973518406379933}, {49.34615859097786, 26.965429317236485`, 
      7.225365009112045}, {66.01282525764461, 24.04752838365492, 
      6.443515810364846}, {66.0128252576446, 23.574614682221895`, 
      8.002503354943297}}], 
     Polygon3DBox[{{66.01282525764461, 24.04752838365492, 
      6.443515810364846}, {49.34615859097786, 26.965429317236485`, 
      7.225365009112045}, {49.34615859097785, 27.380255744590183`, 
      5.446271489616923}, {66.01282525764451, 24.417466876705426`, 
      4.856936141859868}, {66.01282525764461, 24.04752838365492, 
      6.443515810364846}}], 
     Polygon3DBox[{{66.01282525764451, 24.417466876705426`, 
      4.856936141859868}, {49.34615859097785, 27.380255744590183`, 
      5.446271489616923}, {49.34615859097786, 27.677835713352206`, 
      3.6438561994764513`}, {66.01282525764455, 24.682846027952152`, 
      3.249558327145044}, {66.01282525764451, 24.417466876705426`, 
      4.856936141859868}}], 
     Polygon3DBox[{{66.01282525764455, 24.682846027952152`, 
      3.249558327145044}, {49.34615859097786, 27.677835713352206`, 
      3.6438561994764513`}, {49.34615859097786, 27.856894940411014`, 
      1.825837357674841}, {66.01282525764455, 24.84252944312773, 
      1.6282654047921155`}, {66.01282525764455, 24.682846027952152`, 
      3.249558327145044}}], 
     Polygon3DBox[{{66.01282525764455, 24.84252944312773, 
      1.6282654047921155`}, {49.34615859097786, 27.856894940411014`, 
      1.825837357674841}, {49.34615859097786, 27.916666666666664`, 
      1.5816296089267276`*^-14}, {66.01282525764455, 24.895833333333332`, 
      1.4104831213936114`*^-14}, {66.01282525764455, 24.84252944312773, 
      1.6282654047921155`}}], 
     Polygon3DBox[{{66.01282525764455, 24.895833333333332`, 
      3.0488602603772648`*^-15}, {49.34615859097786, 27.916666666666664`, 
      3.4188056476196943`*^-15}, {49.34615859097786, 
      27.856894940411014`, -1.8258373576748217`}, {66.01282525764455, 
      24.84252944312773, -1.6282654047920984`}, {66.01282525764455, 
      24.895833333333332`, 3.0488602603772648`*^-15}}], 
     Polygon3DBox[{{66.01282525764455, 
      24.84252944312773, -1.6282654047920984`}, {49.34615859097786, 
      27.856894940411014`, -1.8258373576748217`}, {49.34615859097786, 
      27.677835713352206`, -3.6438561994764327`}, {66.01282525764455, 
      24.682846027952152`, -3.2495583271450275`}, {66.01282525764455, 
      24.84252944312773, -1.6282654047920984`}}], 
     Polygon3DBox[{{66.01282525764455, 
      24.682846027952152`, -3.2495583271450275`}, {49.34615859097786, 
      27.677835713352206`, -3.6438561994764327`}, {49.34615859097786, 
      27.380255744590183`, -5.446271489616905}, {66.01282525764455, 
      24.417466876705426`, -4.856936141859851}, {66.01282525764455, 
      24.682846027952152`, -3.2495583271450275`}}], 
     Polygon3DBox[{{66.01282525764455, 
      24.417466876705426`, -4.856936141859851}, {49.34615859097786, 
      27.380255744590183`, -5.446271489616905}, {49.34615859097786, 
      26.96542931723649, -7.225365009112026}, {66.0128252576446, 
      24.047528383654928`, -6.443515810364828}, {66.01282525764455, 
      24.417466876705426`, -4.856936141859851}}], 
     Polygon3DBox[{{66.0128252576446, 
      24.047528383654928`, -6.443515810364828}, {49.34615859097786, 
      26.96542931723649, -7.225365009112026}, {49.34615859097786, 
      26.435132781738368`, -8.973518406379913}, {66.01282525764461, 
      23.5746146822219, -8.00250335494328}, {66.0128252576446, 
      24.047528383654928`, -6.443515810364828}}], 
     Polygon3DBox[{{66.01282525764461, 23.5746146822219, -8.00250335494328}, {
      49.34615859097786, 26.435132781738368`, -8.973518406379913}, {
      49.34615859097786, 25.791636949273425`, -10.683245820192074`}, {
      66.01282525764455, 23.000750861478913`, -9.527222951589199}, {
      66.01282525764461, 23.5746146822219, -8.00250335494328}}], 
     Polygon3DBox[{{66.01282525764455, 
      23.000750861478913`, -9.527222951589199}, {49.34615859097786, 
      25.791636949273425`, -10.683245820192074`}, {49.34615859097786, 
      25.037697367787555`, -12.347225935280436`}, {66.01282525764455, 
      22.32839429440756, -11.011145516910537`}, {66.01282525764455, 
      23.000750861478913`, -9.527222951589199}}], 
     Polygon3DBox[{{66.01282525764455, 
      22.328394294407552`, -11.011145516910545`}, {49.34615859097785, 
      25.03769736778755, -12.347225935280445`}, {49.34615859097786, 
      24.176542522315582`, -13.958333333333323`}, {66.01282525764455, 
      21.56042411505009, -12.447916666666657`}, {66.01282525764455, 
      22.328394294407552`, -11.011145516910545`}}], 
     Polygon3DBox[{{66.01282525764455, 
      21.56042411505009, -12.447916666666657`}, {49.34615859097786, 
      24.176542522315582`, -13.958333333333323`}, {49.34615859097786, 
      23.211860010112726`, -15.509669005130554`}, {66.01282525764455, 
      20.700128889615453`, -13.831383926217171`}, {66.01282525764455, 
      21.56042411505009, -12.447916666666657`}}], 
     Polygon3DBox[{{66.01282525764455, 
      20.700128889615453`, -13.831383926217171`}, {49.34615859097786, 
      23.211860010112726`, -15.509669005130554`}, {49.34615859097786, 
      22.147780749796986`, -16.99458989316011}, {66.01282525764455, 
      19.751192534333878`, -15.155623076362932`}, {66.01282525764455, 
      20.700128889615453`, -13.831383926217171`}}], 
     Polygon3DBox[{{66.01282525764455, 
      19.751192534333878`, -15.155623076362932`}, {49.34615859097786, 
      22.147780749796986`, -16.99458989316011}, {49.34615859097786, 
      20.98886129212146, -18.406737338210245`}, {66.0128252576446, 
      18.717678540362048`, -16.414963521762118`}, {66.01282525764455, 
      19.751192534333878`, -15.155623076362932`}}], 
     Polygon3DBox[{{66.0128252576446, 
      18.717678540362048`, -16.414963521762118`}, {49.34615859097786, 
      20.98886129212146, -18.406737338210245`}, {49.34615859097786, 
      19.74006430812446, -19.74006430812444}, {66.01282525764455, 
      17.6040125732901, -17.604012573290078`}, {66.0128252576446, 
      18.717678540362048`, -16.414963521762118`}}], 
     Polygon3DBox[{{66.01282525764455, 
      17.6040125732901, -17.604012573290078`}, {49.34615859097786, 
      19.74006430812446, -19.74006430812444}, {49.34615859097786, 
      18.40673733821027, -20.988861292121438`}, {66.01282525764455, 
      16.414963521762143`, -18.71767854036203}, {66.01282525764455, 
      17.6040125732901, -17.604012573290078`}}], 
     Polygon3DBox[{{66.01282525764455, 
      16.414963521762136`, -18.717678540362037`}, {49.34615859097785, 
      18.406737338210263`, -20.98886129212145}, {49.34615859097785, 
      16.994589893160125`, -22.147780749796976`}, {66.0128252576446, 
      15.155623076362945`, -19.751192534333867`}, {66.01282525764455, 
      16.414963521762136`, -18.717678540362037`}}], 
     Polygon3DBox[{{66.0128252576446, 
      15.155623076362945`, -19.751192534333867`}, {49.34615859097785, 
      16.994589893160125`, -22.147780749796976`}, {49.34615859097786, 
      15.509669005130561`, -23.21186001011272}, {66.0128252576446, 
      13.831383926217178`, -20.700128889615446`}, {66.0128252576446, 
      15.155623076362945`, -19.751192534333867`}}], 
     Polygon3DBox[{{66.01282525764455, 
      13.831383926217196`, -20.70012888961544}, {49.34615859097786, 
      15.50966900513058, -23.21186001011271}, {49.34615859097785, 
      13.958333333333346`, -24.17654252231557}, {66.01282525764455, 
      12.447916666666677`, -21.56042411505008}, {66.01282525764455, 
      13.831383926217196`, -20.70012888961544}}], 
     Polygon3DBox[{{66.01282525764455, 
      12.447916666666677`, -21.56042411505008}, {49.34615859097785, 
      13.958333333333346`, -24.17654252231557}, {49.34615859097785, 
      12.347225935280454`, -25.037697367787548`}, {66.0128252576446, 
      11.011145516910553`, -22.32839429440755}, {66.01282525764455, 
      12.447916666666677`, -21.56042411505008}}], 
     Polygon3DBox[{{66.0128252576446, 
      11.011145516910553`, -22.32839429440755}, {49.34615859097785, 
      12.347225935280454`, -25.037697367787548`}, {49.34615859097786, 
      10.68324582019208, -25.79163694927342}, {66.01282525764461, 
      9.527222951589206, -23.000750861478906`}, {66.0128252576446, 
      11.011145516910553`, -22.32839429440755}}], 
     Polygon3DBox[{{66.01282525764455, 
      9.527222951589227, -23.000750861478902`}, {49.34615859097785, 
      10.683245820192104`, -25.791636949273418`}, {49.34615859097786, 
      8.973518406379933, -26.43513278173836}, {66.0128252576446, 
      8.002503354943299, -23.574614682221895`}, {66.01282525764455, 
      9.527222951589227, -23.000750861478902`}}], 
     Polygon3DBox[{{66.0128252576446, 
      8.002503354943299, -23.574614682221895`}, {49.34615859097786, 
      8.973518406379933, -26.43513278173836}, {49.34615859097785, 
      7.225365009112034, -26.96542931723649}, {66.01282525764455, 
      6.443515810364835, -24.047528383654928`}, {66.0128252576446, 
      8.002503354943299, -23.574614682221895`}}], 
     Polygon3DBox[{{66.0128252576446, 
      6.4435158103648575`, -24.04752838365492}, {49.34615859097785, 
      7.225365009112059, -26.965429317236485`}, {49.34615859097786, 
      5.446271489616925, -27.38025574459018}, {66.0128252576446, 
      4.856936141859869, -24.41746687670542}, {66.0128252576446, 
      6.4435158103648575`, -24.04752838365492}}], 
     Polygon3DBox[{{66.0128252576446, 
      4.856936141859869, -24.41746687670542}, {49.34615859097786, 
      5.446271489616925, -27.38025574459018}, {49.34615859097786, 
      3.643856199476441, -27.677835713352206`}, {66.01282525764455, 
      3.249558327145035, -24.682846027952152`}, {66.0128252576446, 
      4.856936141859869, -24.41746687670542}}], 
     Polygon3DBox[{{66.01282525764455, 
      3.2495583271450563`, -24.68284602795215}, {49.34615859097786, 
      3.643856199476465, -27.677835713352202`}, {49.34615859097786, 
      1.8258373576748426`, -27.856894940411014`}, {66.01282525764455, 
      1.628265404792117, -24.84252944312773}, {66.01282525764455, 
      3.2495583271450563`, -24.68284602795215}}], 
     Polygon3DBox[{{66.01282525764455, 
      1.628265404792117, -24.84252944312773}, {49.34615859097786, 
      1.8258373576748426`, -27.856894940411014`}, {49.34615859097786, 
      5.128208471429541*^-15, -27.916666666666664`}, {66.01282525764455, 
      4.573290390565896*^-15, -24.895833333333332`}, {66.01282525764455, 
      1.628265404792117, -24.84252944312773}}], 
     Polygon3DBox[{{66.01282525764455, 
      4.573290390565896*^-15, -24.895833333333332`}, {49.34615859097786, 
      5.128208471429541*^-15, -27.916666666666664`}, {
      49.34615859097786, -1.8258373576748324`, -27.856894940411014`}, {
      66.01282525764455, -1.628265404792108, -24.84252944312773}, {
      66.01282525764455, 4.573290390565896*^-15, -24.895833333333332`}}], 
     Polygon3DBox[{{
      66.0128252576446, -1.628265404792086, -24.84252944312773}, {
      49.34615859097786, -1.8258373576748077`, -27.856894940411014`}, {
      49.34615859097786, -3.643856199476431, -27.677835713352206`}, {
      66.01282525764455, -3.2495583271450257`, -24.682846027952152`}, {
      66.0128252576446, -1.628265404792086, -24.84252944312773}}], 
     Polygon3DBox[{{
      66.01282525764455, -3.2495583271450257`, -24.682846027952152`}, {
      49.34615859097786, -3.643856199476431, -27.677835713352206`}, {
      49.34615859097785, -5.446271489616914, -27.380255744590183`}, {
      66.01282525764455, -4.85693614185986, -24.417466876705426`}, {
      66.01282525764455, -3.2495583271450257`, -24.682846027952152`}}], 
     Polygon3DBox[{{
      66.01282525764455, -4.856936141859839, -24.41746687670543}, {
      49.34615859097785, -5.4462714896168904`, -27.38025574459019}, {
      49.34615859097786, -7.225365009112025, -26.96542931723649}, {
      66.0128252576446, -6.443515810364827, -24.047528383654928`}, {
      66.01282525764455, -4.856936141859839, -24.41746687670543}}], 
     Polygon3DBox[{{
      66.0128252576446, -6.443515810364827, -24.047528383654928`}, {
      49.34615859097786, -7.225365009112025, -26.96542931723649}, {
      49.34615859097785, -8.973518406379924, -26.435132781738368`}, {
      66.01282525764455, -8.00250335494329, -23.5746146822219}, {
      66.0128252576446, -6.443515810364827, -24.047528383654928`}}], 
     Polygon3DBox[{{
      66.01282525764455, -8.00250335494329, -23.5746146822219}, {
      49.34615859097785, -8.973518406379924, -26.435132781738368`}, {
      49.34615859097786, -10.683245820192095`, -25.791636949273418`}, {
      66.0128252576446, -9.52722295158922, -23.000750861478902`}, {
      66.01282525764455, -8.00250335494329, -23.5746146822219}}], 
     Polygon3DBox[{{
      66.01282525764455, -9.527222951589199, -23.000750861478913`}, {
      49.34615859097786, -10.683245820192072`, -25.791636949273425`}, {
      49.34615859097785, -12.347225935280445`, -25.03769736778755}, {
      66.01282525764455, -11.011145516910545`, -22.328394294407552`}, {
      66.01282525764455, -9.527222951589199, -23.000750861478913`}}], 
     Polygon3DBox[{{
      66.01282525764455, -11.011145516910545`, -22.328394294407552`}, {
      49.34615859097785, -12.347225935280445`, -25.03769736778755}, {
      49.34615859097785, -13.958333333333336`, -24.17654252231558}, {
      66.01282525764455, -12.447916666666668`, -21.560424115050086`}, {
      66.01282525764455, -11.011145516910545`, -22.328394294407552`}}], 
     Polygon3DBox[{{
      66.0128252576446, -12.447916666666648`, -21.560424115050093`}, {
      49.34615859097786, -13.958333333333314`, -24.176542522315586`}, {
      49.34615859097786, -15.50966900513055, -23.211860010112726`}, {
      66.01282525764455, -13.83138392621717, -20.700128889615453`}, {
      66.0128252576446, -12.447916666666648`, -21.560424115050093`}}], 
     Polygon3DBox[{{
      66.01282525764455, -13.83138392621717, -20.700128889615453`}, {
      49.34615859097786, -15.50966900513055, -23.211860010112726`}, {
      49.34615859097786, -16.994589893160114`, -22.14778074979698}, {
      66.01282525764461, -15.155623076362936`, -19.75119253433387}, {
      66.01282525764455, -13.83138392621717, -20.700128889615453`}}], 
     Polygon3DBox[{{
      66.01282525764455, -15.15562307636292, -19.75119253433389}, {
      49.34615859097786, -16.994589893160096`, -22.147780749796997`}, {
      49.34615859097786, -18.40673733821024, -20.988861292121463`}, {
      66.01282525764455, -16.414963521762118`, -18.71767854036205}, {
      66.01282525764455, -15.15562307636292, -19.75119253433389}}], 
     Polygon3DBox[{{
      66.01282525764455, -16.414963521762118`, -18.71767854036205}, {
      49.34615859097786, -18.40673733821024, -20.988861292121463`}, {
      49.34615859097786, -19.740064308124445`, -19.740064308124452`}, {
      66.01282525764455, -17.604012573290085`, -17.604012573290092`}, {
      66.01282525764455, -16.414963521762118`, -18.71767854036205}}], 
     Polygon3DBox[{{
      66.01282525764455, -17.604012573290085`, -17.604012573290092`}, {
      49.34615859097786, -19.740064308124445`, -19.740064308124452`}, {
      49.346158590977886`, -20.988861292121452`, -18.40673733821025}, {
      66.0128252576446, -18.71767854036204, -16.414963521762125`}, {
      66.01282525764455, -17.604012573290085`, -17.604012573290092`}}], 
     Polygon3DBox[{{
      66.01282525764455, -18.71767854036203, -16.414963521762143`}, {
      49.34615859097786, -20.988861292121438`, -18.40673733821027}, {
      49.34615859097785, -22.147780749796976`, -16.994589893160125`}, {
      66.0128252576446, -19.751192534333867`, -15.155623076362945`}, {
      66.01282525764455, -18.71767854036203, -16.414963521762143`}}], 
     Polygon3DBox[{{
      66.0128252576446, -19.751192534333867`, -15.155623076362945`}, {
      49.34615859097785, -22.147780749796976`, -16.994589893160125`}, {
      49.34615859097786, -23.21186001011272, -15.509669005130561`}, {
      66.0128252576446, -20.700128889615446`, -13.831383926217178`}, {
      66.0128252576446, -19.751192534333867`, -15.155623076362945`}}], 
     Polygon3DBox[{{
      66.01282525764455, -20.70012888961544, -13.831383926217196`}, {
      49.34615859097786, -23.21186001011271, -15.50966900513058}, {
      49.34615859097785, -24.17654252231557, -13.958333333333346`}, {
      66.01282525764455, -21.56042411505008, -12.447916666666677`}, {
      66.01282525764455, -20.70012888961544, -13.831383926217196`}}], 
     Polygon3DBox[{{
      66.01282525764455, -21.56042411505008, -12.447916666666677`}, {
      49.34615859097785, -24.17654252231557, -13.958333333333346`}, {
      49.34615859097785, -25.037697367787548`, -12.347225935280456`}, {
      66.01282525764455, -22.32839429440755, -11.011145516910556`}, {
      66.01282525764455, -21.56042411505008, -12.447916666666677`}}], 
     Polygon3DBox[{{
      66.01282525764455, -22.328394294407538`, -11.011145516910574`}, {
      49.34615859097786, -25.037697367787533`, -12.347225935280477`}, {
      49.34615859097785, -25.791636949273418`, -10.683245820192107`}, {
      66.01282525764455, -23.000750861478902`, -9.527222951589229}, {
      66.01282525764455, -22.328394294407538`, -11.011145516910574`}}], 
     Polygon3DBox[{{
      66.01282525764455, -23.000750861478902`, -9.527222951589229}, {
      49.34615859097785, -25.791636949273418`, -10.683245820192107`}, {
      49.34615859097786, -26.43513278173836, -8.973518406379934}, {
      66.0128252576446, -23.574614682221895`, -8.0025033549433}, {
      66.01282525764455, -23.000750861478902`, -9.527222951589229}}], 
     Polygon3DBox[{{
      66.0128252576446, -23.574614682221895`, -8.0025033549433}, {
      49.34615859097786, -26.43513278173836, -8.973518406379934}, {
      49.34615859097785, -26.96542931723649, -7.225365009112036}, {
      66.01282525764455, -24.047528383654928`, -6.443515810364838}, {
      66.0128252576446, -23.574614682221895`, -8.0025033549433}}], 
     Polygon3DBox[{{
      66.01282525764455, -24.04752838365492, -6.443515810364859}, {
      49.34615859097785, -26.965429317236485`, -7.22536500911206}, {
      49.34615859097786, -27.38025574459018, -5.446271489616927}, {
      66.0128252576446, -24.41746687670542, -4.856936141859871}, {
      66.01282525764455, -24.04752838365492, -6.443515810364859}}], 
     Polygon3DBox[{{
      66.0128252576446, -24.41746687670542, -4.856936141859871}, {
      49.34615859097786, -27.38025574459018, -5.446271489616927}, {
      49.34615859097786, -27.677835713352206`, -3.643856199476443}, {
      66.01282525764455, -24.682846027952152`, -3.2495583271450363`}, {
      66.0128252576446, -24.41746687670542, -4.856936141859871}}], 
     Polygon3DBox[{{
      66.01282525764455, -24.68284602795215, -3.249558327145058}, {
      49.34615859097786, -27.677835713352202`, -3.6438561994764673`}, {
      49.34615859097786, -27.856894940411014`, -1.8258373576748441`}, {
      66.01282525764455, -24.84252944312773, -1.6282654047921183`}, {
      66.01282525764455, -24.68284602795215, -3.249558327145058}}], 
     Polygon3DBox[{{
      66.01282525764455, -24.84252944312773, -1.6282654047921183`}, {
      49.34615859097786, -27.856894940411014`, -1.8258373576748441`}, {
      49.34615859097786, -27.916666666666664`, -6.8376112952393886`*^-15}, {
      66.01282525764455, -24.895833333333332`, -6.0977205207545296`*^-15}, {
      66.01282525764455, -24.84252944312773, -1.6282654047921183`}}], 
     Polygon3DBox[{{49.34615859097786, -27.916666666666664`, 0.}, {
      49.999999999999964`, -30.9375, 0.}, {
      49.999999999999964`, -30.871260437694296`, 2.023409310557551}, {
      49.34615859097786, -27.856894940411014`, 1.825837357674827}, {
      49.34615859097786, -27.916666666666664`, 0.}}], 
     Polygon3DBox[{{49.34615859097786, -27.856894940411014`, 
      1.825837357674827}, {49.999999999999964`, -30.871260437694296`, 
      2.023409310557551}, {49.999999999999964`, -30.67282539875226, 
      4.0381540718078455`}, {49.34615859097786, -27.677835713352206`, 
      3.64385619947644}, {49.34615859097786, -27.856894940411014`, 
      1.825837357674827}}], 
     Polygon3DBox[{{49.34615859097786, -27.677835713352206`, 
      3.64385619947644}, {49.999999999999964`, -30.67282539875226, 
      4.0381540718078455`}, {49.999999999999936`, -30.343044612474944`, 
      6.035606837373967}, {49.34615859097785, -27.380255744590183`, 
      5.446271489616913}, {49.34615859097786, -27.677835713352206`, 
      3.64385619947644}}], 
     Polygon3DBox[{{49.34615859097785, -27.380255744590183`, 
      5.446271489616913}, {49.999999999999936`, -30.343044612474944`, 
      6.035606837373967}, {49.99999999999996, -29.883330250818048`, 
      8.007214207859235}, {49.34615859097785, -26.96542931723649, 
      7.225365009112037}, {49.34615859097785, -27.380255744590183`, 
      5.446271489616913}}], 
     Polygon3DBox[{{49.34615859097785, -26.96542931723649, 
      7.225365009112037}, {49.99999999999996, -29.883330250818048`, 
      8.007214207859235}, {49.999999999999964`, -29.295650881254833`, 
      9.944533457816558}, {49.34615859097785, -26.435132781738368`, 
      8.973518406379926}, {49.34615859097785, -26.96542931723649, 
      7.225365009112037}}], 
     Polygon3DBox[{{49.34615859097785, -26.435132781738368`, 
      8.973518406379926}, {49.999999999999964`, -29.295650881254833`, 
      9.944533457816558}, {49.999999999999936`, -28.582523037067936`, 
      11.839268688794963`}, {49.34615859097786, -25.79163694927342, 
      10.683245820192088`}, {49.34615859097785, -26.435132781738368`, 
      8.973518406379926}}], 
     Polygon3DBox[{{49.34615859097786, -25.79163694927342, 
      10.68324582019209}, {49.999999999999936`, -28.582523037067936`, 
      11.839268688794967`}, {49.999999999999964`, -27.747000441167547`, 
      13.68330635365035}, {49.34615859097785, -25.03769736778755, 
      12.34722593528045}, {49.34615859097786, -25.79163694927342, 
      10.68324582019209}}], 
     Polygon3DBox[{{49.34615859097785, -25.03769736778755, 
      12.34722593528045}, {49.999999999999964`, -27.747000441167547`, 
      13.68330635365035}, {49.999999999999936`, -26.792660929581075`, 
      15.468749999999996`}, {49.34615859097786, -24.17654252231558, 
      13.95833333333333}, {49.34615859097785, -25.03769736778755, 
      12.34722593528045}}], 
     Polygon3DBox[{{49.34615859097786, -24.17654252231558, 
      13.95833333333333}, {49.999999999999936`, -26.792660929581075`, 
      15.468749999999996`}, {49.999999999999964`, -25.723591130609993`, 
      17.187954084043945`}, {49.34615859097786, -23.21186001011272, 
      15.509669005130561`}, {49.34615859097786, -24.17654252231558, 
      13.95833333333333}}], 
     Polygon3DBox[{{49.34615859097786, -23.21186001011272, 
      15.509669005130561`}, {49.999999999999964`, -25.723591130609993`, 
      17.187954084043945`}, {49.999999999999964`, -24.544368965260087`, 
      18.833556709957293`}, {49.34615859097786, -22.14778074979698, 
      16.994589893160118`}, {49.34615859097786, -23.21186001011272, 
      15.509669005130561`}}], 
     Polygon3DBox[{{49.34615859097786, -22.147780749796983`, 
      16.994589893160114`}, {49.999999999999964`, -24.54436896526009, 
      18.83355670995729}, {49.999999999999964`, -23.260044043880864`, 
      20.39851115465838}, {49.34615859097785, -20.988861292121452`, 
      18.406737338210256`}, {49.34615859097786, -22.147780749796983`, 
      16.994589893160114`}}], 
     Polygon3DBox[{{49.34615859097785, -20.988861292121452`, 
      18.406737338210256`}, {49.999999999999964`, -23.260044043880864`, 
      20.39851115465838}, {49.99999999999996, -21.876116042958813`, 
      21.876116042958813`}, {49.34615859097786, -19.740064308124452`, 
      19.74006430812445}, {49.34615859097785, -20.988861292121452`, 
      18.406737338210256`}}], 
     Polygon3DBox[{{49.34615859097786, -19.740064308124452`, 
      19.74006430812445}, {49.99999999999996, -21.876116042958813`, 
      21.876116042958813`}, {49.999999999999964`, -20.39851115465838, 
      23.260044043880864`}, {49.34615859097785, -18.406737338210256`, 
      20.988861292121452`}, {49.34615859097786, -19.740064308124452`, 
      19.74006430812445}}], 
     Polygon3DBox[{{49.34615859097786, -18.406737338210256`, 
      20.98886129212145}, {49.999999999999936`, -20.398511154658387`, 
      23.26004404388086}, {49.999999999999964`, -18.833556709957293`, 
      24.544368965260087`}, {49.34615859097786, -16.994589893160118`, 
      22.14778074979698}, {49.34615859097786, -18.406737338210256`, 
      20.98886129212145}}], 
     Polygon3DBox[{{49.34615859097786, -16.994589893160118`, 
      22.14778074979698}, {49.999999999999964`, -18.833556709957293`, 
      24.544368965260087`}, {49.999999999999964`, -17.187954084043945`, 
      25.723591130609993`}, {49.34615859097786, -15.509669005130563`, 
      23.21186001011272}, {49.34615859097786, -16.994589893160118`, 
      22.14778074979698}}], 
     Polygon3DBox[{{49.34615859097785, -15.509669005130567`, 
      23.21186001011272}, {49.999999999999936`, -17.18795408404395, 
      25.723591130609993`}, {49.999999999999936`, -15.468750000000004`, 
      26.79266092958107}, {49.34615859097785, -13.958333333333336`, 
      24.17654252231558}, {49.34615859097785, -15.509669005130567`, 
      23.21186001011272}}], 
     Polygon3DBox[{{49.34615859097785, -13.958333333333336`, 
      24.17654252231558}, {49.999999999999936`, -15.468750000000004`, 
      26.79266092958107}, {49.999999999999936`, -13.683306353650357`, 
      27.747000441167543`}, {49.34615859097785, -12.347225935280456`, 
      25.037697367787548`}, {49.34615859097785, -13.958333333333336`, 
      24.17654252231558}}], 
     Polygon3DBox[{{49.34615859097785, -12.347225935280456`, 
      25.037697367787548`}, {49.999999999999936`, -13.683306353650357`, 
      27.747000441167543`}, {49.99999999999996, -11.839268688794972`, 
      28.58252303706793}, {49.34615859097786, -10.683245820192095`, 
      25.791636949273418`}, {49.34615859097785, -12.347225935280456`, 
      25.037697367787548`}}], 
     Polygon3DBox[{{49.34615859097785, -10.683245820192091`, 
      25.79163694927342}, {49.999999999999936`, -11.839268688794967`, 
      28.582523037067936`}, {49.999999999999964`, -9.944533457816567, 
      29.29565088125483}, {49.34615859097786, -8.973518406379931, 
      26.43513278173836}, {49.34615859097785, -10.683245820192091`, 
      25.79163694927342}}], 
     Polygon3DBox[{{49.34615859097786, -8.973518406379931, 
      26.43513278173836}, {49.999999999999964`, -9.944533457816567, 
      29.29565088125483}, {49.99999999999996, -8.007214207859242, 
      29.883330250818045`}, {49.34615859097786, -7.225365009112044, 
      26.965429317236485`}, {49.34615859097786, -8.973518406379931, 
      26.43513278173836}}], 
     Polygon3DBox[{{49.34615859097786, -7.225365009112044, 
      26.965429317236485`}, {49.99999999999996, -8.007214207859242, 
      29.883330250818045`}, {49.999999999999936`, -6.035606837373976, 
      30.343044612474944`}, {49.34615859097785, -5.446271489616921, 
      27.380255744590183`}, {49.34615859097786, -7.225365009112044, 
      26.965429317236485`}}], 
     Polygon3DBox[{{49.34615859097785, -5.446271489616915, 
      27.380255744590183`}, {49.999999999999936`, -6.035606837373971, 
      30.343044612474944`}, {49.999999999999964`, -4.03815407180785, 
      30.67282539875226}, {49.34615859097786, -3.6438561994764433`, 
      27.677835713352206`}, {49.34615859097785, -5.446271489616915, 
      27.380255744590183`}}], 
     Polygon3DBox[{{49.34615859097786, -3.6438561994764433`, 
      27.677835713352206`}, {49.999999999999964`, -4.03815407180785, 
      30.67282539875226}, {49.999999999999964`, -2.0234093105575575`, 
      30.871260437694296`}, {49.34615859097786, -1.8258373576748328`, 
      27.856894940411014`}, {49.34615859097786, -3.6438561994764433`, 
      27.677835713352206`}}], 
     Polygon3DBox[{{49.34615859097786, -1.8258373576748328`, 
      27.856894940411014`}, {49.999999999999964`, -2.0234093105575575`, 
      30.871260437694296`}, {49.999999999999964`, -8.763880482299218*^-15, 
      30.9375}, {49.34615859097786, -7.908148044633638*^-15, 
      27.916666666666664`}, {49.34615859097786, -1.8258373576748328`, 
      27.856894940411014`}}], 
     Polygon3DBox[{{49.34615859097786, -1.7094028238098471`*^-15, 
      27.916666666666664`}, {49.999999999999964`, -1.894375517431062*^-15, 
      30.9375}, {49.999999999999964`, 2.023409310557547, 
      30.871260437694296`}, {49.34615859097786, 1.825837357674823, 
      27.856894940411014`}, {49.34615859097786, -1.7094028238098471`*^-15, 
      27.916666666666664`}}], 
     Polygon3DBox[{{49.34615859097786, 1.825837357674823, 
      27.856894940411014`}, {49.999999999999964`, 2.023409310557547, 
      30.871260437694296`}, {49.99999999999996, 4.03815407180784, 
      30.67282539875226}, {49.34615859097786, 3.6438561994764345`, 
      27.677835713352206`}, {49.34615859097786, 1.825837357674823, 
      27.856894940411014`}}], 
     Polygon3DBox[{{49.34615859097786, 3.6438561994764345`, 
      27.677835713352206`}, {49.99999999999996, 4.03815407180784, 
      30.67282539875226}, {49.999999999999936`, 6.035606837373959, 
      30.343044612474944`}, {49.34615859097786, 5.4462714896169055`, 
      27.380255744590183`}, {49.34615859097786, 3.6438561994764345`, 
      27.677835713352206`}}], 
     Polygon3DBox[{{49.34615859097786, 5.4462714896169055`, 
      27.380255744590183`}, {49.999999999999936`, 6.035606837373959, 
      30.343044612474944`}, {49.99999999999996, 8.007214207859224, 
      29.88333025081805}, {49.34615859097786, 7.225365009112027, 
      26.96542931723649}, {49.34615859097786, 5.4462714896169055`, 
      27.380255744590183`}}], 
     Polygon3DBox[{{49.34615859097785, 7.225365009112034, 
      26.96542931723649}, {49.99999999999996, 8.007214207859233, 
      29.883330250818048`}, {49.999999999999964`, 9.944533457816554, 
      29.295650881254833`}, {49.34615859097786, 8.97351840637992, 
      26.435132781738368`}, {49.34615859097785, 7.225365009112034, 
      26.96542931723649}}], 
     Polygon3DBox[{{49.34615859097786, 8.97351840637992, 
      26.435132781738368`}, {49.999999999999964`, 9.944533457816554, 
      29.295650881254833`}, {49.999999999999964`, 11.839268688794956`, 
      28.582523037067936`}, {49.34615859097786, 10.68324582019208, 
      25.79163694927342}, {49.34615859097786, 8.97351840637992, 
      26.435132781738368`}}], 
     Polygon3DBox[{{49.34615859097786, 10.68324582019208, 
      25.79163694927342}, {49.999999999999964`, 11.839268688794956`, 
      28.582523037067936`}, {49.999999999999964`, 13.683306353650346`, 
      27.747000441167547`}, {49.34615859097785, 12.347225935280447`, 
      25.03769736778755}, {49.34615859097786, 10.68324582019208, 
      25.79163694927342}}], 
     Polygon3DBox[{{49.34615859097785, 12.347225935280447`, 
      25.03769736778755}, {49.999999999999964`, 13.683306353650346`, 
      27.747000441167547`}, {49.999999999999964`, 15.468749999999993`, 
      26.792660929581075`}, {49.34615859097786, 13.958333333333329`, 
      24.17654252231558}, {49.34615859097785, 12.347225935280447`, 
      25.03769736778755}}], 
     Polygon3DBox[{{49.34615859097786, 13.958333333333329`, 
      24.17654252231558}, {49.999999999999964`, 15.468749999999993`, 
      26.792660929581075`}, {49.999999999999964`, 17.187954084043934`, 
      25.72359113061}, {49.34615859097786, 15.509669005130554`, 
      23.211860010112726`}, {49.34615859097786, 13.958333333333329`, 
      24.17654252231558}}], 
     Polygon3DBox[{{49.34615859097786, 15.509669005130554`, 
      23.211860010112726`}, {49.999999999999964`, 17.187954084043934`, 
      25.72359113061}, {49.999999999999964`, 18.833556709957286`, 
      24.544368965260094`}, {49.34615859097786, 16.99458989316011, 
      22.147780749796986`}, {49.34615859097786, 15.509669005130554`, 
      23.211860010112726`}}], 
     Polygon3DBox[{{49.34615859097786, 16.99458989316011, 
      22.147780749796986`}, {49.999999999999964`, 18.833556709957286`, 
      24.544368965260094`}, {49.999999999999964`, 20.39851115465837, 
      23.260044043880875`}, {49.34615859097786, 18.406737338210245`, 
      20.98886129212146}, {49.34615859097786, 16.99458989316011, 
      22.147780749796986`}}], 
     Polygon3DBox[{{49.34615859097786, 18.406737338210245`, 
      20.98886129212146}, {49.999999999999964`, 20.39851115465837, 
      23.260044043880875`}, {49.999999999999936`, 21.876116042958806`, 
      21.876116042958827`}, {49.34615859097786, 19.74006430812444, 
      19.74006430812446}, {49.34615859097786, 18.406737338210245`, 
      20.98886129212146}}], 
     Polygon3DBox[{{49.34615859097786, 19.74006430812445, 
      19.740064308124452`}, {49.99999999999996, 21.876116042958813`, 
      21.876116042958813`}, {49.999999999999936`, 23.26004404388086, 
      20.398511154658387`}, {49.34615859097786, 20.98886129212145, 
      18.406737338210256`}, {49.34615859097786, 19.74006430812445, 
      19.740064308124452`}}], 
     Polygon3DBox[{{49.34615859097786, 20.98886129212145, 
      18.406737338210256`}, {49.999999999999936`, 23.26004404388086, 
      20.398511154658387`}, {49.999999999999936`, 24.544368965260084`, 
      18.833556709957303`}, {49.34615859097785, 22.147780749796976`, 
      16.994589893160125`}, {49.34615859097786, 20.98886129212145, 
      18.406737338210256`}}], 
     Polygon3DBox[{{49.34615859097785, 22.147780749796976`, 
      16.994589893160125`}, {49.999999999999936`, 24.544368965260084`, 
      18.833556709957303`}, {49.99999999999996, 25.723591130609986`, 
      17.18795408404395}, {49.346158590977886`, 23.211860010112712`, 
      15.509669005130569`}, {49.34615859097785, 22.147780749796976`, 
      16.994589893160125`}}], 
     Polygon3DBox[{{49.346158590977886`, 23.211860010112712`, 
      15.509669005130569`}, {49.99999999999996, 25.723591130609986`, 
      17.18795408404395}, {49.999999999999964`, 26.792660929581064`, 
      15.468750000000009`}, {49.34615859097786, 24.17654252231557, 
      13.958333333333341`}, {49.346158590977886`, 23.211860010112712`, 
      15.509669005130569`}}], 
     Polygon3DBox[{{49.34615859097786, 24.17654252231557, 
      13.958333333333341`}, {49.999999999999964`, 26.792660929581064`, 
      15.468750000000009`}, {49.99999999999997, 27.747000441167543`, 
      13.683306353650366`}, {49.34615859097785, 25.037697367787544`, 
      12.347225935280463`}, {49.34615859097786, 24.17654252231557, 
      13.958333333333341`}}], 
     Polygon3DBox[{{49.34615859097785, 25.037697367787544`, 
      12.347225935280463`}, {49.99999999999997, 27.747000441167543`, 
      13.683306353650366`}, {49.999999999999936`, 28.58252303706793, 
      11.83926868879498}, {49.34615859097785, 25.791636949273418`, 
      10.683245820192104`}, {49.34615859097785, 25.037697367787544`, 
      12.347225935280463`}}], 
     Polygon3DBox[{{49.34615859097785, 25.79163694927342, 
      10.683245820192091`}, {49.999999999999936`, 28.582523037067936`, 
      11.839268688794968`}, {49.999999999999964`, 29.29565088125483, 
      9.944533457816567}, {49.34615859097786, 26.43513278173836, 
      8.973518406379933}, {49.34615859097785, 25.79163694927342, 
      10.683245820192091`}}], 
     Polygon3DBox[{{49.34615859097786, 26.43513278173836, 
      8.973518406379933}, {49.999999999999964`, 29.29565088125483, 
      9.944533457816567}, {49.99999999999996, 29.883330250818045`, 
      8.007214207859244}, {49.34615859097786, 26.965429317236485`, 
      7.225365009112045}, {49.34615859097786, 26.43513278173836, 
      8.973518406379933}}], 
     Polygon3DBox[{{49.34615859097786, 26.965429317236485`, 
      7.225365009112045}, {49.99999999999996, 29.883330250818045`, 
      8.007214207859244}, {49.99999999999997, 30.343044612474944`, 
      6.035606837373979}, {49.34615859097785, 27.380255744590183`, 
      5.446271489616923}, {49.34615859097786, 26.965429317236485`, 
      7.225365009112045}}], 
     Polygon3DBox[{{49.34615859097785, 27.380255744590183`, 
      5.446271489616923}, {49.99999999999997, 30.343044612474944`, 
      6.035606837373979}, {49.999999999999936`, 30.67282539875226, 
      4.038154071807859}, {49.34615859097786, 27.677835713352206`, 
      3.6438561994764513`}, {49.34615859097785, 27.380255744590183`, 
      5.446271489616923}}], 
     Polygon3DBox[{{49.34615859097786, 27.677835713352206`, 
      3.6438561994764513`}, {49.999999999999936`, 30.67282539875226, 
      4.038154071807859}, {49.999999999999936`, 30.871260437694296`, 
      2.0234093105575663`}, {49.34615859097786, 27.856894940411014`, 
      1.825837357674841}, {49.34615859097786, 27.677835713352206`, 
      3.6438561994764513`}}], 
     Polygon3DBox[{{49.34615859097786, 27.856894940411014`, 
      1.825837357674841}, {49.999999999999936`, 30.871260437694296`, 
      2.0234093105575663`}, {49.999999999999964`, 30.9375, 
      1.7527760964598436`*^-14}, {49.34615859097786, 27.916666666666664`, 
      1.5816296089267276`*^-14}, {49.34615859097786, 27.856894940411014`, 
      1.825837357674841}}], 
     Polygon3DBox[{{49.34615859097786, 27.916666666666664`, 
      3.4188056476196943`*^-15}, {49.999999999999964`, 30.9375, 
      3.788751034862124*^-15}, {49.999999999999964`, 
      30.871260437694296`, -2.023409310557545}, {49.34615859097786, 
      27.856894940411014`, -1.8258373576748217`}, {49.34615859097786, 
      27.916666666666664`, 3.4188056476196943`*^-15}}], 
     Polygon3DBox[{{49.34615859097786, 
      27.856894940411014`, -1.8258373576748217`}, {49.999999999999964`, 
      30.871260437694296`, -2.023409310557545}, {49.99999999999996, 
      30.67282539875226, -4.0381540718078375`}, {49.34615859097786, 
      27.677835713352206`, -3.6438561994764327`}, {49.34615859097786, 
      27.856894940411014`, -1.8258373576748217`}}], 
     Polygon3DBox[{{49.34615859097786, 
      27.677835713352206`, -3.6438561994764327`}, {49.99999999999996, 
      30.67282539875226, -4.0381540718078375`}, {49.999999999999964`, 
      30.343044612474944`, -6.035606837373958}, {49.34615859097786, 
      27.380255744590183`, -5.446271489616905}, {49.34615859097786, 
      27.677835713352206`, -3.6438561994764327`}}], 
     Polygon3DBox[{{49.34615859097786, 
      27.380255744590183`, -5.446271489616905}, {49.999999999999964`, 
      30.343044612474944`, -6.035606837373958}, {49.99999999999996, 
      29.88333025081805, -8.007214207859223}, {49.34615859097786, 
      26.96542931723649, -7.225365009112026}, {49.34615859097786, 
      27.380255744590183`, -5.446271489616905}}], 
     Polygon3DBox[{{49.34615859097786, 
      26.96542931723649, -7.225365009112026}, {49.99999999999996, 
      29.88333025081805, -8.007214207859223}, {49.99999999999996, 
      29.295650881254833`, -9.944533457816545}, {49.34615859097786, 
      26.435132781738368`, -8.973518406379913}, {49.34615859097786, 
      26.96542931723649, -7.225365009112026}}], 
     Polygon3DBox[{{49.34615859097786, 
      26.435132781738368`, -8.973518406379913}, {49.99999999999996, 
      29.295650881254833`, -9.944533457816545}, {49.999999999999936`, 
      28.582523037067944`, -11.839268688794947`}, {49.34615859097786, 
      25.791636949273425`, -10.683245820192074`}, {49.34615859097786, 
      26.435132781738368`, -8.973518406379913}}], 
     Polygon3DBox[{{49.34615859097786, 
      25.791636949273425`, -10.683245820192074`}, {49.999999999999936`, 
      28.582523037067944`, -11.839268688794947`}, {49.999999999999964`, 
      27.747000441167554`, -13.683306353650334`}, {49.34615859097786, 
      25.037697367787555`, -12.347225935280436`}, {49.34615859097786, 
      25.791636949273425`, -10.683245820192074`}}], 
     Polygon3DBox[{{49.34615859097785, 
      25.03769736778755, -12.347225935280445`}, {49.99999999999996, 
      27.747000441167547`, -13.683306353650345`}, {49.999999999999964`, 
      26.792660929581075`, -15.468749999999991`}, {49.34615859097786, 
      24.176542522315582`, -13.958333333333323`}, {49.34615859097785, 
      25.03769736778755, -12.347225935280445`}}], 
     Polygon3DBox[{{49.34615859097786, 
      24.176542522315582`, -13.958333333333323`}, {49.999999999999964`, 
      26.792660929581075`, -15.468749999999991`}, {49.999999999999964`, 
      25.72359113061, -17.187954084043934`}, {49.34615859097786, 
      23.211860010112726`, -15.509669005130554`}, {49.34615859097786, 
      24.176542522315582`, -13.958333333333323`}}], 
     Polygon3DBox[{{49.34615859097786, 
      23.211860010112726`, -15.509669005130554`}, {49.999999999999964`, 
      25.72359113061, -17.187954084043934`}, {49.999999999999964`, 
      24.544368965260094`, -18.833556709957286`}, {49.34615859097786, 
      22.147780749796986`, -16.99458989316011}, {49.34615859097786, 
      23.211860010112726`, -15.509669005130554`}}], 
     Polygon3DBox[{{49.34615859097786, 
      22.147780749796986`, -16.99458989316011}, {49.999999999999964`, 
      24.544368965260094`, -18.833556709957286`}, {49.999999999999964`, 
      23.260044043880875`, -20.39851115465837}, {49.34615859097786, 
      20.98886129212146, -18.406737338210245`}, {49.34615859097786, 
      22.147780749796986`, -16.99458989316011}}], 
     Polygon3DBox[{{49.34615859097786, 
      20.98886129212146, -18.406737338210245`}, {49.999999999999964`, 
      23.260044043880875`, -20.39851115465837}, {49.999999999999936`, 
      21.876116042958827`, -21.876116042958806`}, {49.34615859097786, 
      19.74006430812446, -19.74006430812444}, {49.34615859097786, 
      20.98886129212146, -18.406737338210245`}}], 
     Polygon3DBox[{{49.34615859097786, 
      19.74006430812446, -19.74006430812444}, {49.999999999999936`, 
      21.876116042958827`, -21.876116042958806`}, {49.999999999999964`, 
      20.398511154658397`, -23.26004404388085}, {49.34615859097786, 
      18.40673733821027, -20.988861292121438`}, {49.34615859097786, 
      19.74006430812446, -19.74006430812444}}], 
     Polygon3DBox[{{49.34615859097785, 
      18.406737338210263`, -20.98886129212145}, {49.999999999999936`, 
      20.398511154658387`, -23.26004404388086}, {49.999999999999964`, 
      18.833556709957303`, -24.54436896526008}, {49.34615859097785, 
      16.994589893160125`, -22.147780749796976`}, {49.34615859097785, 
      18.406737338210263`, -20.98886129212145}}], 
     Polygon3DBox[{{49.34615859097785, 
      16.994589893160125`, -22.147780749796976`}, {49.999999999999964`, 
      18.833556709957303`, -24.54436896526008}, {49.999999999999964`, 
      17.187954084043945`, -25.723591130609993`}, {49.34615859097786, 
      15.509669005130561`, -23.21186001011272}, {49.34615859097785, 
      16.994589893160125`, -22.147780749796976`}}], 
     Polygon3DBox[{{49.34615859097786, 
      15.50966900513058, -23.21186001011271}, {49.999999999999964`, 
      17.187954084043966`, -25.72359113060998}, {49.99999999999996, 
      15.468750000000016`, -26.79266092958106}, {49.34615859097785, 
      13.958333333333346`, -24.17654252231557}, {49.34615859097786, 
      15.50966900513058, -23.21186001011271}}], 
     Polygon3DBox[{{49.34615859097785, 
      13.958333333333346`, -24.17654252231557}, {49.99999999999996, 
      15.468750000000016`, -26.79266092958106}, {49.999999999999936`, 
      13.683306353650355`, -27.747000441167543`}, {49.34615859097785, 
      12.347225935280454`, -25.037697367787548`}, {49.34615859097785, 
      13.958333333333346`, -24.17654252231557}}], 
     Polygon3DBox[{{49.34615859097785, 
      12.347225935280454`, -25.037697367787548`}, {49.999999999999936`, 
      13.683306353650355`, -27.747000441167543`}, {49.999999999999964`, 
      11.839268688794956`, -28.582523037067936`}, {49.34615859097786, 
      10.68324582019208, -25.79163694927342}, {49.34615859097785, 
      12.347225935280454`, -25.037697367787548`}}], 
     Polygon3DBox[{{49.34615859097785, 
      10.683245820192104`, -25.791636949273418`}, {49.999999999999936`, 
      11.839268688794983`, -28.58252303706793}, {49.999999999999964`, 
      9.944533457816569, -29.29565088125483}, {49.34615859097786, 
      8.973518406379933, -26.43513278173836}, {49.34615859097785, 
      10.683245820192104`, -25.791636949273418`}}], 
     Polygon3DBox[{{49.34615859097786, 
      8.973518406379933, -26.43513278173836}, {49.999999999999964`, 
      9.944533457816569, -29.29565088125483}, {49.99999999999996, 
      8.007214207859233, -29.883330250818048`}, {49.34615859097785, 
      7.225365009112034, -26.96542931723649}, {49.34615859097786, 
      8.973518406379933, -26.43513278173836}}], 
     Polygon3DBox[{{49.34615859097785, 
      7.225365009112059, -26.965429317236485`}, {49.999999999999964`, 
      8.00721420785926, -29.883330250818045`}, {49.99999999999992, 
      6.03560683737398, -30.343044612474934`}, {49.34615859097786, 
      5.446271489616925, -27.38025574459018}, {49.34615859097785, 
      7.225365009112059, -26.965429317236485`}}], 
     Polygon3DBox[{{49.34615859097786, 
      5.446271489616925, -27.38025574459018}, {49.99999999999992, 
      6.03560683737398, -30.343044612474934`}, {49.999999999999964`, 
      4.038154071807847, -30.67282539875226}, {49.34615859097786, 
      3.643856199476441, -27.677835713352206`}, {49.34615859097786, 
      5.446271489616925, -27.38025574459018}}], 
     Polygon3DBox[{{49.34615859097786, 
      3.643856199476465, -27.677835713352202`}, {49.99999999999996, 
      4.038154071807874, -30.672825398752252`}, {49.999999999999936`, 
      2.023409310557568, -30.871260437694296`}, {49.34615859097786, 
      1.8258373576748426`, -27.856894940411014`}, {49.34615859097786, 
      3.643856199476465, -27.677835713352202`}}], 
     Polygon3DBox[{{49.34615859097786, 
      1.8258373576748426`, -27.856894940411014`}, {49.999999999999936`, 
      2.023409310557568, -30.871260437694296`}, {49.999999999999964`, 
      5.683126552293185*^-15, -30.9375}, {49.34615859097786, 
      5.128208471429541*^-15, -27.916666666666664`}, {49.34615859097786, 
      1.8258373576748426`, -27.856894940411014`}}], 
     Polygon3DBox[{{49.34615859097786, 
      5.128208471429541*^-15, -27.916666666666664`}, {49.999999999999964`, 
      5.683126552293185*^-15, -30.9375}, {
      49.999999999999964`, -2.023409310557557, -30.871260437694296`}, {
      49.34615859097786, -1.8258373576748324`, -27.856894940411014`}, {
      49.34615859097786, 5.128208471429541*^-15, -27.916666666666664`}}], 
     Polygon3DBox[{{
      49.34615859097786, -1.8258373576748077`, -27.856894940411014`}, {
      49.99999999999996, -2.0234093105575295`, -30.871260437694296`}, {
      49.99999999999996, -4.038154071807836, -30.67282539875226}, {
      49.34615859097786, -3.643856199476431, -27.677835713352206`}, {
      49.34615859097786, -1.8258373576748077`, -27.856894940411014`}}], 
     Polygon3DBox[{{
      49.34615859097786, -3.643856199476431, -27.677835713352206`}, {
      49.99999999999996, -4.038154071807836, -30.67282539875226}, {
      49.999999999999936`, -6.03560683737397, -30.343044612474944`}, {
      49.34615859097785, -5.446271489616914, -27.380255744590183`}, {
      49.34615859097786, -3.643856199476431, -27.677835713352206`}}], 
     Polygon3DBox[{{
      49.34615859097785, -5.4462714896168904`, -27.38025574459019}, {
      49.99999999999997, -6.035606837373942, -30.34304461247495}, {
      49.99999999999996, -8.00721420785922, -29.88333025081805}, {
      49.34615859097786, -7.225365009112025, -26.96542931723649}, {
      49.34615859097785, -5.4462714896168904`, -27.38025574459019}}], 
     Polygon3DBox[{{
      49.34615859097786, -7.225365009112025, -26.96542931723649}, {
      49.99999999999996, -8.00721420785922, -29.88333025081805}, {
      49.999999999999964`, -9.944533457816558, -29.295650881254833`}, {
      49.34615859097785, -8.973518406379924, -26.435132781738368`}, {
      49.34615859097786, -7.225365009112025, -26.96542931723649}}], 
     Polygon3DBox[{{
      49.34615859097785, -8.973518406379924, -26.435132781738368`}, {
      49.999999999999964`, -9.944533457816558, -29.295650881254833`}, {
      49.99999999999996, -11.839268688794972`, -28.58252303706793}, {
      49.34615859097786, -10.683245820192095`, -25.791636949273418`}, {
      49.34615859097785, -8.973518406379924, -26.435132781738368`}}], 
     Polygon3DBox[{{
      49.34615859097786, -10.683245820192072`, -25.791636949273425`}, {
      49.999999999999964`, -11.839268688794945`, -28.582523037067944`}, {
      49.99999999999996, -13.683306353650345`, -27.747000441167547`}, {
      49.34615859097785, -12.347225935280445`, -25.03769736778755}, {
      49.34615859097786, -10.683245820192072`, -25.791636949273425`}}], 
     Polygon3DBox[{{
      49.34615859097785, -12.347225935280445`, -25.03769736778755}, {
      49.99999999999996, -13.683306353650345`, -27.747000441167547`}, {
      49.999999999999936`, -15.468750000000004`, -26.79266092958107}, {
      49.34615859097785, -13.958333333333336`, -24.17654252231558}, {
      49.34615859097785, -12.347225935280445`, -25.03769736778755}}], 
     Polygon3DBox[{{
      49.34615859097786, -13.958333333333314`, -24.176542522315586`}, {
      49.999999999999964`, -15.46874999999998, -26.792660929581082`}, {
      49.999999999999964`, -17.18795408404393, -25.72359113061}, {
      49.34615859097786, -15.50966900513055, -23.211860010112726`}, {
      49.34615859097786, -13.958333333333314`, -24.176542522315586`}}], 
     Polygon3DBox[{{
      49.34615859097786, -15.50966900513055, -23.211860010112726`}, {
      49.999999999999964`, -17.18795408404393, -25.72359113061}, {
      49.99999999999996, -18.83355670995729, -24.544368965260087`}, {
      49.34615859097786, -16.994589893160114`, -22.14778074979698}, {
      49.34615859097786, -15.50966900513055, -23.211860010112726`}}], 
     Polygon3DBox[{{
      49.34615859097786, -16.994589893160096`, -22.147780749796997`}, {
      49.999999999999964`, -18.83355670995727, -24.544368965260105`}, {
      49.999999999999964`, -20.398511154658365`, -23.260044043880878`}, {
      49.34615859097786, -18.40673733821024, -20.988861292121463`}, {
      49.34615859097786, -16.994589893160096`, -22.147780749796997`}}], 
     Polygon3DBox[{{
      49.34615859097786, -18.40673733821024, -20.988861292121463`}, {
      49.999999999999964`, -20.398511154658365`, -23.260044043880878`}, {
      49.999999999999964`, -21.87611604295881, -21.876116042958817`}, {
      49.34615859097786, -19.740064308124445`, -19.740064308124452`}, {
      49.34615859097786, -18.40673733821024, -20.988861292121463`}}], 
     Polygon3DBox[{{
      49.34615859097786, -19.740064308124445`, -19.740064308124452`}, {
      49.999999999999964`, -21.87611604295881, -21.876116042958817`}, {
      49.99999999999996, -23.260044043880864`, -20.398511154658376`}, {
      49.346158590977886`, -20.988861292121452`, -18.40673733821025}, {
      49.34615859097786, -19.740064308124445`, -19.740064308124452`}}], 
     Polygon3DBox[{{
      49.34615859097786, -20.988861292121438`, -18.40673733821027}, {
      49.999999999999964`, -23.26004404388085, -20.398511154658397`}, {
      49.999999999999964`, -24.54436896526008, -18.833556709957303`}, {
      49.34615859097785, -22.147780749796976`, -16.994589893160125`}, {
      49.34615859097786, -20.988861292121438`, -18.40673733821027}}], 
     Polygon3DBox[{{
      49.34615859097785, -22.147780749796976`, -16.994589893160125`}, {
      49.999999999999964`, -24.54436896526008, -18.833556709957303`}, {
      49.999999999999964`, -25.723591130609993`, -17.187954084043945`}, {
      49.34615859097786, -23.21186001011272, -15.509669005130561`}, {
      49.34615859097785, -22.147780749796976`, -16.994589893160125`}}], 
     Polygon3DBox[{{
      49.34615859097786, -23.21186001011271, -15.50966900513058}, {
      49.999999999999964`, -25.72359113060998, -17.187954084043966`}, {
      49.99999999999996, -26.79266092958106, -15.468750000000016`}, {
      49.34615859097785, -24.17654252231557, -13.958333333333346`}, {
      49.34615859097786, -23.21186001011271, -15.50966900513058}}], 
     Polygon3DBox[{{
      49.34615859097785, -24.17654252231557, -13.958333333333346`}, {
      49.99999999999996, -26.79266092958106, -15.468750000000016`}, {
      49.999999999999936`, -27.747000441167543`, -13.683306353650357`}, {
      49.34615859097785, -25.037697367787548`, -12.347225935280456`}, {
      49.34615859097785, -24.17654252231557, -13.958333333333346`}}], 
     Polygon3DBox[{{
      49.34615859097786, -25.037697367787533`, -12.347225935280477`}, {
      49.999999999999964`, -27.74700044116753, -13.68330635365038}, {
      49.999999999999936`, -28.58252303706793, -11.839268688794984`}, {
      49.34615859097785, -25.791636949273418`, -10.683245820192107`}, {
      49.34615859097786, -25.037697367787533`, -12.347225935280477`}}], 
     Polygon3DBox[{{
      49.34615859097785, -25.791636949273418`, -10.683245820192107`}, {
      49.999999999999936`, -28.58252303706793, -11.839268688794984`}, {
      49.999999999999964`, -29.29565088125483, -9.94453345781657}, {
      49.34615859097786, -26.43513278173836, -8.973518406379934}, {
      49.34615859097785, -25.791636949273418`, -10.683245820192107`}}], 
     Polygon3DBox[{{
      49.34615859097786, -26.43513278173836, -8.973518406379934}, {
      49.999999999999964`, -29.29565088125483, -9.94453345781657}, {
      49.99999999999996, -29.883330250818048`, -8.007214207859233}, {
      49.34615859097785, -26.96542931723649, -7.225365009112036}, {
      49.34615859097786, -26.43513278173836, -8.973518406379934}}], 
     Polygon3DBox[{{
      49.34615859097785, -26.965429317236485`, -7.22536500911206}, {
      49.999999999999964`, -29.883330250818045`, -8.007214207859262}, {
      49.99999999999992, -30.343044612474934`, -6.035606837373982}, {
      49.34615859097786, -27.38025574459018, -5.446271489616927}, {
      49.34615859097785, -26.965429317236485`, -7.22536500911206}}], 
     Polygon3DBox[{{
      49.34615859097786, -27.38025574459018, -5.446271489616927}, {
      49.99999999999992, -30.343044612474934`, -6.035606837373982}, {
      49.999999999999964`, -30.67282539875226, -4.038154071807849}, {
      49.34615859097786, -27.677835713352206`, -3.643856199476443}, {
      49.34615859097786, -27.38025574459018, -5.446271489616927}}], 
     Polygon3DBox[{{
      49.34615859097786, -27.677835713352202`, -3.6438561994764673`}, {
      49.99999999999996, -30.672825398752252`, -4.0381540718078766`}, {
      49.999999999999936`, -30.871260437694296`, -2.0234093105575695`}, {
      49.34615859097786, -27.856894940411014`, -1.8258373576748441`}, {
      49.34615859097786, -27.677835713352202`, -3.6438561994764673`}}], 
     Polygon3DBox[{{
      49.34615859097786, -27.856894940411014`, -1.8258373576748441`}, {
      49.999999999999936`, -30.871260437694296`, -2.0234093105575695`}, {
      49.999999999999964`, -30.9375, -7.577502069724248*^-15}, {
      49.34615859097786, -27.916666666666664`, -6.8376112952393886`*^-15}, {
      49.34615859097786, -27.856894940411014`, -1.8258373576748441`}}], 
     Polygon3DBox[{{49.999999999999964`, -30.9375, 0.}, {
      50.653841409022064`, -33.958333333333336`, 0.}, {
      50.65384140902205, -33.88562593497758, 2.2209812634402746`}, {
      49.999999999999964`, -30.871260437694296`, 2.023409310557551}, {
      49.999999999999964`, -30.9375, 0.}}], 
     Polygon3DBox[{{49.999999999999964`, -30.871260437694296`, 
      2.023409310557551}, {50.65384140902205, -33.88562593497758, 
      2.2209812634402746`}, {50.653841409022064`, -33.667815084152316`, 
      4.432451944139252}, {49.999999999999964`, -30.67282539875226, 
      4.0381540718078455`}, {49.999999999999964`, -30.871260437694296`, 
      2.023409310557551}}], 
     Polygon3DBox[{{49.999999999999964`, -30.67282539875226, 
      4.0381540718078455`}, {50.653841409022064`, -33.667815084152316`, 
      4.432451944139252}, {50.653841409022064`, -33.3058334803597, 
      6.6249421851310215`}, {49.999999999999936`, -30.343044612474944`, 
      6.035606837373967}, {49.999999999999964`, -30.67282539875226, 
      4.0381540718078455`}}], 
     Polygon3DBox[{{49.999999999999936`, -30.343044612474944`, 
      6.035606837373967}, {50.653841409022064`, -33.3058334803597, 
      6.6249421851310215`}, {50.653841409022064`, -32.80123118439961, 
      8.789063406606433}, {49.99999999999996, -29.883330250818048`, 
      8.007214207859235}, {49.999999999999936`, -30.343044612474944`, 
      6.035606837373967}}], 
     Polygon3DBox[{{49.99999999999996, -29.883330250818048`, 
      8.007214207859235}, {50.653841409022064`, -32.80123118439961, 
      8.789063406606433}, {50.653841409022064`, -32.1561689807713, 
      10.915548509253194`}, {49.999999999999964`, -29.295650881254833`, 
      9.944533457816558}, {49.99999999999996, -29.883330250818048`, 
      8.007214207859235}}], 
     Polygon3DBox[{{49.999999999999964`, -29.295650881254833`, 
      9.944533457816558}, {50.653841409022064`, -32.1561689807713, 
      10.915548509253194`}, {50.653841409022064`, -31.373409124862448`, 
      12.995291557397838`}, {49.999999999999936`, -28.582523037067936`, 
      11.839268688794963`}, {49.999999999999964`, -29.295650881254833`, 
      9.944533457816558}}], 
     Polygon3DBox[{{49.999999999999936`, -28.582523037067936`, 
      11.839268688794967`}, {50.653841409022064`, -31.373409124862448`, 
      12.995291557397842`}, {50.653841409022064`, -30.456303514547546`, 
      15.01938677202025}, {49.999999999999964`, -27.747000441167547`, 
      13.68330635365035}, {49.999999999999936`, -28.582523037067936`, 
      11.839268688794967`}}], 
     Polygon3DBox[{{49.999999999999964`, -27.747000441167547`, 
      13.68330635365035}, {50.653841409022064`, -30.456303514547546`, 
      15.01938677202025}, {50.653841409022064`, -29.408779336846568`, 
      16.979166666666664`}, {49.999999999999936`, -26.792660929581075`, 
      15.468749999999996`}, {49.999999999999964`, -27.747000441167547`, 
      13.68330635365035}}], 
     Polygon3DBox[{{49.999999999999936`, -26.792660929581075`, 
      15.468749999999996`}, {50.653841409022064`, -29.408779336846568`, 
      16.979166666666664`}, {50.653841409022064`, -28.235322251107267`, 
      18.866239162957328`}, {49.999999999999964`, -25.723591130609993`, 
      17.187954084043945`}, {49.999999999999936`, -26.792660929581075`, 
      15.468749999999996`}}], 
     Polygon3DBox[{{49.999999999999964`, -25.723591130609993`, 
      17.187954084043945`}, {50.653841409022064`, -28.235322251107267`, 
      18.866239162957328`}, {50.65384140902208, -26.940957180723192`, 
      20.67252352675447}, {49.999999999999964`, -24.544368965260087`, 
      18.833556709957293`}, {49.999999999999964`, -25.723591130609993`, 
      17.187954084043945`}}], 
     Polygon3DBox[{{49.999999999999964`, -24.54436896526009, 
      18.83355670995729}, {50.653841409022064`, -26.9409571807232, 
      20.672523526754468`}, {50.653841409022064`, -25.531226795640276`, 
      22.390284971106507`}, {49.999999999999964`, -23.260044043880864`, 
      20.39851115465838}, {49.999999999999964`, -24.54436896526009, 
      18.83355670995729}}], 
     Polygon3DBox[{{49.999999999999964`, -23.260044043880864`, 
      20.39851115465838}, {50.653841409022064`, -25.531226795640276`, 
      22.390284971106507`}, {50.653841409022064`, -24.012167777793177`, 
      24.012167777793174`}, {49.99999999999996, -21.876116042958813`, 
      21.876116042958813`}, {49.999999999999964`, -23.260044043880864`, 
      20.39851115465838}}], 
     Polygon3DBox[{{49.99999999999996, -21.876116042958813`, 
      21.876116042958813`}, {50.653841409022064`, -24.012167777793177`, 
      24.012167777793174`}, {50.653841409022064`, -22.390284971106507`, 
      25.531226795640276`}, {49.999999999999964`, -20.39851115465838, 
      23.260044043880864`}, {49.99999999999996, -21.876116042958813`, 
      21.876116042958813`}}], 
     Polygon3DBox[{{49.999999999999936`, -20.398511154658387`, 
      23.26004404388086}, {50.653841409022064`, -22.39028497110651, 
      25.531226795640272`}, {50.65384140902208, -20.67252352675447, 
      26.940957180723192`}, {49.999999999999964`, -18.833556709957293`, 
      24.544368965260087`}, {49.999999999999936`, -20.398511154658387`, 
      23.26004404388086}}], 
     Polygon3DBox[{{49.999999999999964`, -18.833556709957293`, 
      24.544368965260087`}, {50.65384140902208, -20.67252352675447, 
      26.940957180723192`}, {50.653841409022064`, -18.866239162957328`, 
      28.235322251107267`}, {49.999999999999964`, -17.187954084043945`, 
      25.723591130609993`}, {49.999999999999964`, -18.833556709957293`, 
      24.544368965260087`}}], 
     Polygon3DBox[{{49.999999999999936`, -17.18795408404395, 
      25.723591130609993`}, {50.653841409022064`, -18.866239162957335`, 
      28.235322251107263`}, {50.653841409022064`, -16.97916666666667, 
      29.408779336846564`}, {49.999999999999936`, -15.468750000000004`, 
      26.79266092958107}, {49.999999999999936`, -17.18795408404395, 
      25.723591130609993`}}], 
     Polygon3DBox[{{49.999999999999936`, -15.468750000000004`, 
      26.79266092958107}, {50.653841409022064`, -16.97916666666667, 
      29.408779336846564`}, {50.653841409022064`, -15.019386772020258`, 
      30.45630351454754}, {49.999999999999936`, -13.683306353650357`, 
      27.747000441167543`}, {49.999999999999936`, -15.468750000000004`, 
      26.79266092958107}}], 
     Polygon3DBox[{{49.999999999999936`, -13.683306353650357`, 
      27.747000441167543`}, {50.653841409022064`, -15.019386772020258`, 
      30.45630351454754}, {50.65384140902208, -12.995291557397849`, 
      31.37340912486244}, {49.99999999999996, -11.839268688794972`, 
      28.58252303706793}, {49.999999999999936`, -13.683306353650357`, 
      27.747000441167543`}}], 
     Polygon3DBox[{{49.999999999999936`, -11.839268688794967`, 
      28.582523037067936`}, {50.653841409022064`, -12.995291557397843`, 
      31.373409124862448`}, {50.65384140902208, -10.9155485092532, 
      32.15616898077129}, {49.999999999999964`, -9.944533457816567, 
      29.29565088125483}, {49.999999999999936`, -11.839268688794967`, 
      28.582523037067936`}}], 
     Polygon3DBox[{{49.999999999999964`, -9.944533457816567, 
      29.29565088125483}, {50.65384140902208, -10.9155485092532, 
      32.15616898077129}, {50.65384140902208, -8.789063406606441, 
      32.801231184399605`}, {49.99999999999996, -8.007214207859242, 
      29.883330250818045`}, {49.999999999999964`, -9.944533457816567, 
      29.29565088125483}}], 
     Polygon3DBox[{{49.99999999999996, -8.007214207859242, 
      29.883330250818045`}, {50.65384140902208, -8.789063406606441, 
      32.801231184399605`}, {50.653841409022064`, -6.624942185131031, 
      33.3058334803597}, {49.999999999999936`, -6.035606837373976, 
      30.343044612474944`}, {49.99999999999996, -8.007214207859242, 
      29.883330250818045`}}], 
     Polygon3DBox[{{49.999999999999936`, -6.035606837373971, 
      30.343044612474944`}, {50.653841409022064`, -6.624942185131024, 
      33.3058334803597}, {50.653841409022064`, -4.432451944139256, 
      33.667815084152316`}, {49.999999999999964`, -4.03815407180785, 
      30.67282539875226}, {49.999999999999936`, -6.035606837373971, 
      30.343044612474944`}}], 
     Polygon3DBox[{{49.999999999999964`, -4.03815407180785, 
      30.67282539875226}, {50.653841409022064`, -4.432451944139256, 
      33.667815084152316`}, {50.65384140902205, -2.2209812634402817`, 
      33.88562593497758}, {49.999999999999964`, -2.0234093105575575`, 
      30.871260437694296`}, {49.999999999999964`, -4.03815407180785, 
      30.67282539875226}}], 
     Polygon3DBox[{{49.999999999999964`, -2.0234093105575575`, 
      30.871260437694296`}, {50.65384140902205, -2.2209812634402817`, 
      33.88562593497758}, {50.653841409022064`, -9.619612919964799*^-15, 
      33.958333333333336`}, {49.999999999999964`, -8.763880482299218*^-15, 
      30.9375}, {49.999999999999964`, -2.0234093105575575`, 
      30.871260437694296`}}], 
     Polygon3DBox[{{49.999999999999964`, -1.894375517431062*^-15, 30.9375}, {
      50.653841409022064`, -2.079348211052277*^-15, 33.958333333333336`}, {
      50.65384140902205, 2.22098126344027, 33.88562593497758}, {
      49.999999999999964`, 2.023409310557547, 30.871260437694296`}, {
      49.999999999999964`, -1.894375517431062*^-15, 30.9375}}], 
     Polygon3DBox[{{49.999999999999964`, 2.023409310557547, 
      30.871260437694296`}, {50.65384140902205, 2.22098126344027, 
      33.88562593497758}, {50.653841409022064`, 4.432451944139245, 
      33.667815084152316`}, {49.99999999999996, 4.03815407180784, 
      30.67282539875226}, {49.999999999999964`, 2.023409310557547, 
      30.871260437694296`}}], 
     Polygon3DBox[{{49.99999999999996, 4.03815407180784, 30.67282539875226}, {
      50.653841409022064`, 4.432451944139245, 33.667815084152316`}, {
      50.653841409022064`, 6.624942185131013, 33.3058334803597}, {
      49.999999999999936`, 6.035606837373959, 30.343044612474944`}, {
      49.99999999999996, 4.03815407180784, 30.67282539875226}}], 
     Polygon3DBox[{{49.999999999999936`, 6.035606837373959, 
      30.343044612474944`}, {50.653841409022064`, 6.624942185131013, 
      33.3058334803597}, {50.65384140902208, 8.789063406606422, 
      32.80123118439961}, {49.99999999999996, 8.007214207859224, 
      29.88333025081805}, {49.999999999999936`, 6.035606837373959, 
      30.343044612474944`}}], 
     Polygon3DBox[{{49.99999999999996, 8.007214207859233, 
      29.883330250818048`}, {50.653841409022064`, 8.78906340660643, 
      32.80123118439961}, {50.65384140902208, 10.915548509253188`, 
      32.1561689807713}, {49.999999999999964`, 9.944533457816554, 
      29.295650881254833`}, {49.99999999999996, 8.007214207859233, 
      29.883330250818048`}}], 
     Polygon3DBox[{{49.999999999999964`, 9.944533457816554, 
      29.295650881254833`}, {50.65384140902208, 10.915548509253188`, 
      32.1561689807713}, {50.65384140902208, 12.995291557397831`, 
      31.373409124862448`}, {49.999999999999964`, 11.839268688794956`, 
      28.582523037067936`}, {49.999999999999964`, 9.944533457816554, 
      29.295650881254833`}}], 
     Polygon3DBox[{{49.999999999999964`, 11.839268688794956`, 
      28.582523037067936`}, {50.65384140902208, 12.995291557397831`, 
      31.373409124862448`}, {50.653841409022064`, 15.019386772020248`, 
      30.456303514547546`}, {49.999999999999964`, 13.683306353650346`, 
      27.747000441167547`}, {49.999999999999964`, 11.839268688794956`, 
      28.582523037067936`}}], 
     Polygon3DBox[{{49.999999999999964`, 13.683306353650346`, 
      27.747000441167547`}, {50.653841409022064`, 15.019386772020248`, 
      30.456303514547546`}, {50.653841409022064`, 16.97916666666666, 
      29.408779336846568`}, {49.999999999999964`, 15.468749999999993`, 
      26.792660929581075`}, {49.999999999999964`, 13.683306353650346`, 
      27.747000441167547`}}], 
     Polygon3DBox[{{49.999999999999964`, 15.468749999999993`, 
      26.792660929581075`}, {50.653841409022064`, 16.97916666666666, 
      29.408779336846568`}, {50.653841409022064`, 18.866239162957317`, 
      28.235322251107274`}, {49.999999999999964`, 17.187954084043934`, 
      25.72359113061}, {49.999999999999964`, 15.468749999999993`, 
      26.792660929581075`}}], 
     Polygon3DBox[{{49.999999999999964`, 17.187954084043934`, 
      25.72359113061}, {50.653841409022064`, 18.866239162957317`, 
      28.235322251107274`}, {50.653841409022064`, 20.672523526754464`, 
      26.940957180723203`}, {49.999999999999964`, 18.833556709957286`, 
      24.544368965260094`}, {49.999999999999964`, 17.187954084043934`, 
      25.72359113061}}], 
     Polygon3DBox[{{49.999999999999964`, 18.833556709957286`, 
      24.544368965260094`}, {50.653841409022064`, 20.672523526754464`, 
      26.940957180723203`}, {50.653841409022064`, 22.390284971106492`, 
      25.531226795640286`}, {49.999999999999964`, 20.39851115465837, 
      23.260044043880875`}, {49.999999999999964`, 18.833556709957286`, 
      24.544368965260094`}}], 
     Polygon3DBox[{{49.999999999999964`, 20.39851115465837, 
      23.260044043880875`}, {50.653841409022064`, 22.390284971106492`, 
      25.531226795640286`}, {50.653841409022064`, 24.012167777793167`, 
      24.01216777779319}, {49.999999999999936`, 21.876116042958806`, 
      21.876116042958827`}, {49.999999999999964`, 20.39851115465837, 
      23.260044043880875`}}], 
     Polygon3DBox[{{49.99999999999996, 21.876116042958813`, 
      21.876116042958813`}, {50.653841409022064`, 24.012167777793174`, 
      24.012167777793177`}, {50.653841409022064`, 25.531226795640272`, 
      22.39028497110651}, {49.999999999999936`, 23.26004404388086, 
      20.398511154658387`}, {49.99999999999996, 21.876116042958813`, 
      21.876116042958813`}}], 
     Polygon3DBox[{{49.999999999999936`, 23.26004404388086, 
      20.398511154658387`}, {50.653841409022064`, 25.531226795640272`, 
      22.39028497110651}, {50.653841409022064`, 26.940957180723192`, 
      20.672523526754482`}, {49.999999999999936`, 24.544368965260084`, 
      18.833556709957303`}, {49.999999999999936`, 23.26004404388086, 
      20.398511154658387`}}], 
     Polygon3DBox[{{49.999999999999936`, 24.544368965260084`, 
      18.833556709957303`}, {50.653841409022064`, 26.940957180723192`, 
      20.672523526754482`}, {50.653841409022064`, 28.23532225110726, 
      18.86623916295734}, {49.99999999999996, 25.723591130609986`, 
      17.18795408404395}, {49.999999999999936`, 24.544368965260084`, 
      18.833556709957303`}}], 
     Polygon3DBox[{{49.99999999999996, 25.723591130609986`, 
      17.18795408404395}, {50.653841409022064`, 28.23532225110726, 
      18.86623916295734}, {50.653841409022064`, 29.408779336846557`, 
      16.97916666666668}, {49.999999999999964`, 26.792660929581064`, 
      15.468750000000009`}, {49.99999999999996, 25.723591130609986`, 
      17.18795408404395}}], 
     Polygon3DBox[{{49.999999999999964`, 26.792660929581064`, 
      15.468750000000009`}, {50.653841409022064`, 29.408779336846557`, 
      16.97916666666668}, {50.653841409022064`, 30.456303514547535`, 
      15.019386772020267`}, {49.99999999999997, 27.747000441167543`, 
      13.683306353650366`}, {49.999999999999964`, 26.792660929581064`, 
      15.468750000000009`}}], 
     Polygon3DBox[{{49.99999999999997, 27.747000441167543`, 
      13.683306353650366`}, {50.653841409022064`, 30.456303514547535`, 
      15.019386772020267`}, {50.653841409022064`, 31.37340912486244, 
      12.995291557397858`}, {49.999999999999936`, 28.58252303706793, 
      11.83926868879498}, {49.99999999999997, 27.747000441167543`, 
      13.683306353650366`}}], 
     Polygon3DBox[{{49.999999999999936`, 28.582523037067936`, 
      11.839268688794968`}, {50.653841409022064`, 31.373409124862448`, 
      12.995291557397845`}, {50.65384140902208, 32.15616898077129, 
      10.915548509253203`}, {49.999999999999964`, 29.29565088125483, 
      9.944533457816567}, {49.999999999999936`, 28.582523037067936`, 
      11.839268688794968`}}], 
     Polygon3DBox[{{49.999999999999964`, 29.29565088125483, 
      9.944533457816567}, {50.65384140902208, 32.15616898077129, 
      10.915548509253203`}, {50.65384140902208, 32.801231184399605`, 
      8.789063406606443}, {49.99999999999996, 29.883330250818045`, 
      8.007214207859244}, {49.999999999999964`, 29.29565088125483, 
      9.944533457816567}}], 
     Polygon3DBox[{{49.99999999999996, 29.883330250818045`, 
      8.007214207859244}, {50.65384140902208, 32.801231184399605`, 
      8.789063406606443}, {50.653841409022064`, 33.3058334803597, 
      6.624942185131035}, {49.99999999999997, 30.343044612474944`, 
      6.035606837373979}, {49.99999999999996, 29.883330250818045`, 
      8.007214207859244}}], 
     Polygon3DBox[{{49.99999999999997, 30.343044612474944`, 
      6.035606837373979}, {50.653841409022064`, 33.3058334803597, 
      6.624942185131035}, {50.653841409022064`, 33.667815084152316`, 
      4.432451944139266}, {49.999999999999936`, 30.67282539875226, 
      4.038154071807859}, {49.99999999999997, 30.343044612474944`, 
      6.035606837373979}}], 
     Polygon3DBox[{{49.999999999999936`, 30.67282539875226, 
      4.038154071807859}, {50.653841409022064`, 33.667815084152316`, 
      4.432451944139266}, {50.65384140902205, 33.88562593497758, 
      2.220981263440292}, {49.999999999999936`, 30.871260437694296`, 
      2.0234093105575663`}, {49.999999999999936`, 30.67282539875226, 
      4.038154071807859}}], 
     Polygon3DBox[{{49.999999999999936`, 30.871260437694296`, 
      2.0234093105575663`}, {50.65384140902205, 33.88562593497758, 
      2.220981263440292}, {50.653841409022064`, 33.958333333333336`, 
      1.9239225839929598`*^-14}, {49.999999999999964`, 30.9375, 
      1.7527760964598436`*^-14}, {49.999999999999936`, 30.871260437694296`, 
      2.0234093105575663`}}], 
     Polygon3DBox[{{49.999999999999964`, 30.9375, 3.788751034862124*^-15}, {
      50.653841409022064`, 33.958333333333336`, 4.158696422104554*^-15}, {
      50.65384140902205, 33.88562593497758, -2.2209812634402684`}, {
      49.999999999999964`, 30.871260437694296`, -2.023409310557545}, {
      49.999999999999964`, 30.9375, 3.788751034862124*^-15}}], 
     Polygon3DBox[{{49.999999999999964`, 
      30.871260437694296`, -2.023409310557545}, {50.65384140902205, 
      33.88562593497758, -2.2209812634402684`}, {50.653841409022064`, 
      33.667815084152316`, -4.432451944139243}, {49.99999999999996, 
      30.67282539875226, -4.0381540718078375`}, {49.999999999999964`, 
      30.871260437694296`, -2.023409310557545}}], 
     Polygon3DBox[{{49.99999999999996, 
      30.67282539875226, -4.0381540718078375`}, {50.653841409022064`, 
      33.667815084152316`, -4.432451944139243}, {50.653841409022064`, 
      33.3058334803597, -6.624942185131011}, {49.999999999999964`, 
      30.343044612474944`, -6.035606837373958}, {49.99999999999996, 
      30.67282539875226, -4.0381540718078375`}}], 
     Polygon3DBox[{{49.999999999999964`, 
      30.343044612474944`, -6.035606837373958}, {50.653841409022064`, 
      33.3058334803597, -6.624942185131011}, {50.65384140902208, 
      32.80123118439961, -8.78906340660642}, {49.99999999999996, 
      29.88333025081805, -8.007214207859223}, {49.999999999999964`, 
      30.343044612474944`, -6.035606837373958}}], 
     Polygon3DBox[{{49.99999999999996, 
      29.88333025081805, -8.007214207859223}, {50.65384140902208, 
      32.80123118439961, -8.78906340660642}, {50.65384140902208, 
      32.1561689807713, -10.915548509253178`}, {49.99999999999996, 
      29.295650881254833`, -9.944533457816545}, {49.99999999999996, 
      29.88333025081805, -8.007214207859223}}], 
     Polygon3DBox[{{49.99999999999996, 
      29.295650881254833`, -9.944533457816545}, {50.65384140902208, 
      32.1561689807713, -10.915548509253178`}, {50.653841409022064`, 
      31.373409124862455`, -12.995291557397822`}, {49.999999999999936`, 
      28.582523037067944`, -11.839268688794947`}, {49.99999999999996, 
      29.295650881254833`, -9.944533457816545}}], 
     Polygon3DBox[{{49.999999999999936`, 
      28.582523037067944`, -11.839268688794947`}, {50.653841409022064`, 
      31.373409124862455`, -12.995291557397822`}, {50.653841409022064`, 
      30.456303514547553`, -15.019386772020233`}, {49.999999999999964`, 
      27.747000441167554`, -13.683306353650334`}, {49.999999999999936`, 
      28.582523037067944`, -11.839268688794947`}}], 
     Polygon3DBox[{{49.99999999999996, 
      27.747000441167547`, -13.683306353650345`}, {50.653841409022064`, 
      30.456303514547546`, -15.019386772020244`}, {50.653841409022064`, 
      29.408779336846568`, -16.979166666666657`}, {49.999999999999964`, 
      26.792660929581075`, -15.468749999999991`}, {49.99999999999996, 
      27.747000441167547`, -13.683306353650345`}}], 
     Polygon3DBox[{{49.999999999999964`, 
      26.792660929581075`, -15.468749999999991`}, {50.653841409022064`, 
      29.408779336846568`, -16.979166666666657`}, {50.653841409022064`, 
      28.235322251107274`, -18.866239162957317`}, {49.999999999999964`, 
      25.72359113061, -17.187954084043934`}, {49.999999999999964`, 
      26.792660929581075`, -15.468749999999991`}}], 
     Polygon3DBox[{{49.999999999999964`, 
      25.72359113061, -17.187954084043934`}, {50.653841409022064`, 
      28.235322251107274`, -18.866239162957317`}, {50.653841409022064`, 
      26.940957180723203`, -20.672523526754464`}, {49.999999999999964`, 
      24.544368965260094`, -18.833556709957286`}, {49.999999999999964`, 
      25.72359113061, -17.187954084043934`}}], 
     Polygon3DBox[{{49.999999999999964`, 
      24.544368965260094`, -18.833556709957286`}, {50.653841409022064`, 
      26.940957180723203`, -20.672523526754464`}, {50.653841409022064`, 
      25.531226795640286`, -22.390284971106492`}, {49.999999999999964`, 
      23.260044043880875`, -20.39851115465837}, {49.999999999999964`, 
      24.544368965260094`, -18.833556709957286`}}], 
     Polygon3DBox[{{49.999999999999964`, 
      23.260044043880875`, -20.39851115465837}, {50.653841409022064`, 
      25.531226795640286`, -22.390284971106492`}, {50.653841409022064`, 
      24.01216777779319, -24.012167777793167`}, {49.999999999999936`, 
      21.876116042958827`, -21.876116042958806`}, {49.999999999999964`, 
      23.260044043880875`, -20.39851115465837}}], 
     Polygon3DBox[{{49.999999999999936`, 
      21.876116042958827`, -21.876116042958806`}, {50.653841409022064`, 
      24.01216777779319, -24.012167777793167`}, {50.653841409022064`, 
      22.390284971106524`, -25.531226795640258`}, {49.999999999999964`, 
      20.398511154658397`, -23.26004404388085}, {49.999999999999936`, 
      21.876116042958827`, -21.876116042958806`}}], 
     Polygon3DBox[{{49.999999999999936`, 
      20.398511154658387`, -23.26004404388086}, {50.653841409022064`, 
      22.390284971106514`, -25.531226795640272`}, {50.653841409022064`, 
      20.672523526754482`, -26.94095718072319}, {49.999999999999964`, 
      18.833556709957303`, -24.54436896526008}, {49.999999999999936`, 
      20.398511154658387`, -23.26004404388086}}], 
     Polygon3DBox[{{49.999999999999964`, 
      18.833556709957303`, -24.54436896526008}, {50.653841409022064`, 
      20.672523526754482`, -26.94095718072319}, {50.653841409022064`, 
      18.866239162957328`, -28.235322251107267`}, {49.999999999999964`, 
      17.187954084043945`, -25.723591130609993`}, {49.999999999999964`, 
      18.833556709957303`, -24.54436896526008}}], 
     Polygon3DBox[{{49.999999999999964`, 
      17.187954084043966`, -25.72359113060998}, {50.653841409022064`, 
      18.86623916295735, -28.235322251107252`}, {50.653841409022064`, 
      16.979166666666686`, -29.408779336846553`}, {49.99999999999996, 
      15.468750000000016`, -26.79266092958106}, {49.999999999999964`, 
      17.187954084043966`, -25.72359113060998}}], 
     Polygon3DBox[{{49.99999999999996, 
      15.468750000000016`, -26.79266092958106}, {50.653841409022064`, 
      16.979166666666686`, -29.408779336846553`}, {50.653841409022064`, 
      15.019386772020255`, -30.45630351454754}, {49.999999999999936`, 
      13.683306353650355`, -27.747000441167543`}, {49.99999999999996, 
      15.468750000000016`, -26.79266092958106}}], 
     Polygon3DBox[{{49.999999999999936`, 
      13.683306353650355`, -27.747000441167543`}, {50.653841409022064`, 
      15.019386772020255`, -30.45630351454754}, {50.65384140902208, 
      12.995291557397831`, -31.373409124862448`}, {49.999999999999964`, 
      11.839268688794956`, -28.582523037067936`}, {49.999999999999936`, 
      13.683306353650355`, -27.747000441167543`}}], 
     Polygon3DBox[{{49.999999999999936`, 
      11.839268688794983`, -28.58252303706793}, {50.653841409022064`, 
      12.99529155739786, -31.37340912486244}, {50.65384140902208, 
      10.915548509253204`, -32.15616898077129}, {49.999999999999964`, 
      9.944533457816569, -29.29565088125483}, {49.999999999999936`, 
      11.839268688794983`, -28.58252303706793}}], 
     Polygon3DBox[{{49.999999999999964`, 
      9.944533457816569, -29.29565088125483}, {50.65384140902208, 
      10.915548509253204`, -32.15616898077129}, {50.653841409022064`, 
      8.78906340660643, -32.80123118439961}, {49.99999999999996, 
      8.007214207859233, -29.883330250818048`}, {49.999999999999964`, 
      9.944533457816569, -29.29565088125483}}], 
     Polygon3DBox[{{49.999999999999964`, 
      8.00721420785926, -29.883330250818045`}, {50.653841409022064`, 
      8.78906340660646, -32.801231184399605`}, {50.65384140902208, 
      6.624942185131036, -33.305833480359695`}, {49.99999999999992, 
      6.03560683737398, -30.343044612474934`}, {49.999999999999964`, 
      8.00721420785926, -29.883330250818045`}}], 
     Polygon3DBox[{{49.99999999999992, 
      6.03560683737398, -30.343044612474934`}, {50.65384140902208, 
      6.624942185131036, -33.305833480359695`}, {50.653841409022064`, 
      4.432451944139253, -33.667815084152316`}, {49.999999999999964`, 
      4.038154071807847, -30.67282539875226}, {49.99999999999992, 
      6.03560683737398, -30.343044612474934`}}], 
     Polygon3DBox[{{49.99999999999996, 
      4.038154071807874, -30.672825398752252`}, {50.653841409022064`, 
      4.432451944139283, -33.66781508415231}, {50.65384140902205, 
      2.2209812634402937`, -33.88562593497758}, {49.999999999999936`, 
      2.023409310557568, -30.871260437694296`}, {49.99999999999996, 
      4.038154071807874, -30.672825398752252`}}], 
     Polygon3DBox[{{49.999999999999936`, 
      2.023409310557568, -30.871260437694296`}, {50.65384140902205, 
      2.2209812634402937`, -33.88562593497758}, {50.653841409022064`, 
      6.2380446331568295`*^-15, -33.958333333333336`}, {49.999999999999964`, 
      5.683126552293185*^-15, -30.9375}, {49.999999999999936`, 
      2.023409310557568, -30.871260437694296`}}], 
     Polygon3DBox[{{49.999999999999964`, 5.683126552293185*^-15, -30.9375}, {
      50.653841409022064`, 6.2380446331568295`*^-15, -33.958333333333336`}, {
      50.65384140902205, -2.2209812634402812`, -33.88562593497758}, {
      49.999999999999964`, -2.023409310557557, -30.871260437694296`}, {
      49.999999999999964`, 5.683126552293185*^-15, -30.9375}}], 
     Polygon3DBox[{{
      49.99999999999996, -2.0234093105575295`, -30.871260437694296`}, {
      50.653841409022064`, -2.2209812634402515`, -33.88562593497758}, {
      50.653841409022064`, -4.432451944139241, -33.667815084152316`}, {
      49.99999999999996, -4.038154071807836, -30.67282539875226}, {
      49.99999999999996, -2.0234093105575295`, -30.871260437694296`}}], 
     Polygon3DBox[{{
      49.99999999999996, -4.038154071807836, -30.67282539875226}, {
      50.653841409022064`, -4.432451944139241, -33.667815084152316`}, {
      50.653841409022064`, -6.624942185131024, -33.3058334803597}, {
      49.999999999999936`, -6.03560683737397, -30.343044612474944`}, {
      49.99999999999996, -4.038154071807836, -30.67282539875226}}], 
     Polygon3DBox[{{
      49.99999999999997, -6.035606837373942, -30.34304461247495}, {
      50.653841409022064`, -6.624942185130994, -33.30583348035971}, {
      50.65384140902208, -8.789063406606418, -32.80123118439961}, {
      49.99999999999996, -8.00721420785922, -29.88333025081805}, {
      49.99999999999997, -6.035606837373942, -30.34304461247495}}], 
     Polygon3DBox[{{
      49.99999999999996, -8.00721420785922, -29.88333025081805}, {
      50.65384140902208, -8.789063406606418, -32.80123118439961}, {
      50.653841409022064`, -10.915548509253192`, -32.1561689807713}, {
      49.999999999999964`, -9.944533457816558, -29.295650881254833`}, {
      49.99999999999996, -8.00721420785922, -29.88333025081805}}], 
     Polygon3DBox[{{
      49.999999999999964`, -9.944533457816558, -29.295650881254833`}, {
      50.653841409022064`, -10.915548509253192`, -32.1561689807713}, {
      50.65384140902208, -12.995291557397849`, -31.37340912486244}, {
      49.99999999999996, -11.839268688794972`, -28.58252303706793}, {
      49.999999999999964`, -9.944533457816558, -29.295650881254833`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -11.839268688794945`, -28.582523037067944`}, {
      50.653841409022064`, -12.99529155739782, -31.373409124862455`}, {
      50.653841409022064`, -15.019386772020244`, -30.456303514547546`}, {
      49.99999999999996, -13.683306353650345`, -27.747000441167547`}, {
      49.999999999999964`, -11.839268688794945`, -28.582523037067944`}}], 
     Polygon3DBox[{{
      49.99999999999996, -13.683306353650345`, -27.747000441167547`}, {
      50.653841409022064`, -15.019386772020244`, -30.456303514547546`}, {
      50.653841409022064`, -16.97916666666667, -29.408779336846564`}, {
      49.999999999999936`, -15.468750000000004`, -26.79266092958107}, {
      49.99999999999996, -13.683306353650345`, -27.747000441167547`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -15.46874999999998, -26.792660929581082`}, {
      50.653841409022064`, -16.979166666666643`, -29.408779336846575`}, {
      50.653841409022064`, -18.866239162957314`, -28.235322251107274`}, {
      49.999999999999964`, -17.18795408404393, -25.72359113061}, {
      49.999999999999964`, -15.46874999999998, -26.792660929581082`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -17.18795408404393, -25.72359113061}, {
      50.653841409022064`, -18.866239162957314`, -28.235322251107274`}, {
      50.65384140902208, -20.672523526754468`, -26.940957180723192`}, {
      49.99999999999996, -18.83355670995729, -24.544368965260087`}, {
      49.999999999999964`, -17.18795408404393, -25.72359113061}}], 
     Polygon3DBox[{{
      49.999999999999964`, -18.83355670995727, -24.544368965260105`}, {
      50.653841409022064`, -20.672523526754446`, -26.940957180723213`}, {
      50.653841409022064`, -22.39028497110649, -25.53122679564029}, {
      49.999999999999964`, -20.398511154658365`, -23.260044043880878`}, {
      49.999999999999964`, -18.83355670995727, -24.544368965260105`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -20.398511154658365`, -23.260044043880878`}, {
      50.653841409022064`, -22.39028497110649, -25.53122679564029}, {
      50.653841409022064`, -24.012167777793174`, -24.01216777779318}, {
      49.999999999999964`, -21.87611604295881, -21.876116042958817`}, {
      49.999999999999964`, -20.398511154658365`, -23.260044043880878`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -21.87611604295881, -21.876116042958817`}, {
      50.653841409022064`, -24.012167777793174`, -24.01216777779318}, {
      50.653841409022064`, -25.53122679564028, -22.3902849711065}, {
      49.99999999999996, -23.260044043880864`, -20.398511154658376`}, {
      49.999999999999964`, -21.87611604295881, -21.876116042958817`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -23.26004404388085, -20.398511154658397`}, {
      50.653841409022064`, -25.531226795640258`, -22.390284971106524`}, {
      50.653841409022064`, -26.94095718072319, -20.672523526754482`}, {
      49.999999999999964`, -24.54436896526008, -18.833556709957303`}, {
      49.999999999999964`, -23.26004404388085, -20.398511154658397`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -24.54436896526008, -18.833556709957303`}, {
      50.653841409022064`, -26.94095718072319, -20.672523526754482`}, {
      50.653841409022064`, -28.235322251107267`, -18.866239162957328`}, {
      49.999999999999964`, -25.723591130609993`, -17.187954084043945`}, {
      49.999999999999964`, -24.54436896526008, -18.833556709957303`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -25.72359113060998, -17.187954084043966`}, {
      50.653841409022064`, -28.235322251107252`, -18.86623916295735}, {
      50.653841409022064`, -29.408779336846553`, -16.979166666666686`}, {
      49.99999999999996, -26.79266092958106, -15.468750000000016`}, {
      49.999999999999964`, -25.72359113060998, -17.187954084043966`}}], 
     Polygon3DBox[{{
      49.99999999999996, -26.79266092958106, -15.468750000000016`}, {
      50.653841409022064`, -29.408779336846553`, -16.979166666666686`}, {
      50.653841409022064`, -30.45630351454754, -15.019386772020258`}, {
      49.999999999999936`, -27.747000441167543`, -13.683306353650357`}, {
      49.99999999999996, -26.79266092958106, -15.468750000000016`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -27.74700044116753, -13.68330635365038}, {
      50.653841409022064`, -30.456303514547525`, -15.019386772020283`}, {
      50.653841409022064`, -31.37340912486244, -12.995291557397863`}, {
      49.999999999999936`, -28.58252303706793, -11.839268688794984`}, {
      49.999999999999964`, -27.74700044116753, -13.68330635365038}}], 
     Polygon3DBox[{{
      49.999999999999936`, -28.58252303706793, -11.839268688794984`}, {
      50.653841409022064`, -31.37340912486244, -12.995291557397863`}, {
      50.65384140902208, -32.15616898077129, -10.915548509253204`}, {
      49.999999999999964`, -29.29565088125483, -9.94453345781657}, {
      49.999999999999936`, -28.58252303706793, -11.839268688794984`}}], 
     Polygon3DBox[{{
      49.999999999999964`, -29.29565088125483, -9.94453345781657}, {
      50.65384140902208, -32.15616898077129, -10.915548509253204`}, {
      50.653841409022064`, -32.80123118439961, -8.789063406606433}, {
      49.99999999999996, -29.883330250818048`, -8.007214207859233}, {
      49.999999999999964`, -29.29565088125483, -9.94453345781657}}], 
     Polygon3DBox[{{
      49.999999999999964`, -29.883330250818045`, -8.007214207859262}, {
      50.653841409022064`, -32.801231184399605`, -8.789063406606463}, {
      50.65384140902208, -33.305833480359695`, -6.624942185131038}, {
      49.99999999999992, -30.343044612474934`, -6.035606837373982}, {
      49.999999999999964`, -29.883330250818045`, -8.007214207859262}}], 
     Polygon3DBox[{{
      49.99999999999992, -30.343044612474934`, -6.035606837373982}, {
      50.65384140902208, -33.305833480359695`, -6.624942185131038}, {
      50.653841409022064`, -33.667815084152316`, -4.432451944139255}, {
      49.999999999999964`, -30.67282539875226, -4.038154071807849}, {
      49.99999999999992, -30.343044612474934`, -6.035606837373982}}], 
     Polygon3DBox[{{
      49.99999999999996, -30.672825398752252`, -4.0381540718078766`}, {
      50.653841409022064`, -33.66781508415231, -4.432451944139285}, {
      50.65384140902205, -33.88562593497758, -2.2209812634402955`}, {
      49.999999999999936`, -30.871260437694296`, -2.0234093105575695`}, {
      49.99999999999996, -30.672825398752252`, -4.0381540718078766`}}], 
     Polygon3DBox[{{
      49.999999999999936`, -30.871260437694296`, -2.0234093105575695`}, {
      50.65384140902205, -33.88562593497758, -2.2209812634402955`}, {
      50.653841409022064`, -33.958333333333336`, -8.317392844209108*^-15}, {
      49.999999999999964`, -30.9375, -7.577502069724248*^-15}, {
      49.999999999999936`, -30.871260437694296`, -2.0234093105575695`}}], 
     Polygon3DBox[{{50.65384140902208, -33.95833333333333, 0.}, {
      33.98717474235546, -36.979166666666664`, 0.}, {
      33.987174742355506`, -36.899991432260855`, 2.4185532163229984`}, {
      50.65384140902208, -33.885625934977575`, 2.2209812634402746`}, {
      50.65384140902208, -33.95833333333333, 0.}}], 
     Polygon3DBox[{{50.65384140902208, -33.885625934977575`, 
      2.2209812634402746`}, {33.987174742355506`, -36.899991432260855`, 
      2.4185532163229984`}, {33.987174742355506`, -36.66280476955236, 
      4.826749816470657}, {50.65384140902208, -33.66781508415231, 
      4.432451944139252}, {50.65384140902208, -33.885625934977575`, 
      2.2209812634402746`}}], 
     Polygon3DBox[{{50.65384140902208, -33.66781508415231, 
      4.432451944139252}, {33.987174742355506`, -36.66280476955236, 
      4.826749816470657}, {33.98717474235546, -36.268622348244456`, 
      7.214277532888075}, {50.653841409022064`, -33.3058334803597, 
      6.624942185131021}, {50.65384140902208, -33.66781508415231, 
      4.432451944139252}}], 
     Polygon3DBox[{{50.653841409022064`, -33.3058334803597, 
      6.624942185131021}, {33.98717474235546, -36.268622348244456`, 
      7.214277532888075}, {33.98717474235546, -35.71913211798117, 
      9.570912605353632}, {50.653841409022064`, -32.80123118439961, 
      8.789063406606433}, {50.653841409022064`, -33.3058334803597, 
      6.624942185131021}}], 
     Polygon3DBox[{{50.653841409022064`, -32.80123118439961, 
      8.789063406606433}, {33.98717474235546, -35.71913211798117, 
      9.570912605353632}, {33.987174742355364`, -35.01668708028777, 
      11.886563560689826`}, {50.653841409022064`, -32.1561689807713, 
      10.915548509253192`}, {50.653841409022064`, -32.80123118439961, 
      8.789063406606433}}], 
     Polygon3DBox[{{50.653841409022064`, -32.1561689807713, 
      10.915548509253192`}, {33.987174742355364`, -35.01668708028777, 
      11.886563560689826`}, {33.98717474235546, -34.16429521265696, 
      14.151314426000713`}, {50.65384140902208, -31.373409124862444`, 
      12.995291557397838`}, {50.653841409022064`, -32.1561689807713, 
      10.915548509253192`}}], 
     Polygon3DBox[{{50.65384140902208, -31.373409124862444`, 
      12.99529155739784}, {33.98717474235546, -34.16429521265696, 
      14.151314426000717`}, {33.98717474235546, -33.165606587927535`, 
      16.35546719039015}, {50.653841409022064`, -30.456303514547542`, 
      15.019386772020248`}, {50.65384140902208, -31.373409124862444`, 
      12.99529155739784}}], 
     Polygon3DBox[{{50.653841409022064`, -30.456303514547542`, 
      15.019386772020248`}, {33.98717474235546, -33.165606587927535`, 
      16.35546719039015}, {33.98717474235546, -32.02489774411205, 
      18.48958333333333}, {50.65384140902208, -29.408779336846564`, 
      16.97916666666666}, {50.653841409022064`, -30.456303514547542`, 
      15.019386772020248`}}], 
     Polygon3DBox[{{50.65384140902208, -29.408779336846564`, 
      16.97916666666666}, {33.98717474235546, -32.02489774411205, 
      18.48958333333333}, {33.98717474235546, -30.747053371604537`, 
      20.544524241870704`}, {50.65384140902208, -28.235322251107263`, 
      18.86623916295732}, {50.65384140902208, -29.408779336846564`, 
      16.97916666666666}}], 
     Polygon3DBox[{{50.65384140902208, -28.235322251107263`, 
      18.86623916295732}, {33.98717474235546, -30.747053371604537`, 
      20.544524241870704`}, {33.98717474235546, -29.337545396186297`, 
      22.511490343551646`}, {50.65384140902208, -26.940957180723192`, 
      20.672523526754468`}, {50.65384140902208, -28.235322251107263`, 
      18.86623916295732}}], 
     Polygon3DBox[{{50.65384140902208, -26.940957180723196`, 
      20.672523526754468`}, {33.98717474235546, -29.337545396186304`, 
      22.511490343551642`}, {33.98717474235546, -27.802409547399684`, 
      24.382058787554627`}, {50.65384140902208, -25.531226795640272`, 
      22.390284971106503`}, {50.65384140902208, -26.940957180723196`, 
      20.672523526754468`}}], 
     Polygon3DBox[{{50.65384140902208, -25.531226795640272`, 
      22.390284971106503`}, {33.98717474235546, -27.802409547399684`, 
      24.382058787554627`}, {33.98717474235546, -26.148219512627538`, 
      26.148219512627534`}, {50.65384140902208, -24.012167777793174`, 
      24.012167777793174`}, {50.65384140902208, -25.531226795640272`, 
      22.390284971106503`}}], 
     Polygon3DBox[{{50.65384140902208, -24.012167777793174`, 
      24.012167777793174`}, {33.98717474235546, -26.148219512627538`, 
      26.148219512627534`}, {33.98717474235546, -24.382058787554627`, 
      27.802409547399684`}, {50.65384140902208, -22.390284971106503`, 
      25.531226795640272`}, {50.65384140902208, -24.012167777793174`, 
      24.012167777793174`}}], 
     Polygon3DBox[{{50.653841409022064`, -22.39028497110651, 
      25.53122679564027}, {33.98717474235546, -24.382058787554634`, 
      27.80240954739968}, {33.98717474235546, -22.511490343551646`, 
      29.337545396186297`}, {50.65384140902208, -20.672523526754468`, 
      26.940957180723192`}, {50.653841409022064`, -22.39028497110651, 
      25.53122679564027}}], 
     Polygon3DBox[{{50.65384140902208, -20.672523526754468`, 
      26.940957180723192`}, {33.98717474235546, -22.511490343551646`, 
      29.337545396186297`}, {33.98717474235546, -20.54452424187071, 
      30.747053371604537`}, {50.653841409022064`, -18.866239162957328`, 
      28.235322251107263`}, {50.65384140902208, -20.672523526754468`, 
      26.940957180723192`}}], 
     Polygon3DBox[{{50.65384140902208, -18.86623916295733, 
      28.23532225110726}, {33.987174742355364`, -20.544524241870715`, 
      30.747053371604533`}, {33.98717474235546, -18.489583333333336`, 
      32.02489774411205}, {50.653841409022064`, -16.979166666666668`, 
      29.40877933684656}, {50.65384140902208, -18.86623916295733, 
      28.23532225110726}}], 
     Polygon3DBox[{{50.653841409022064`, -16.979166666666668`, 
      29.40877933684656}, {33.98717474235546, -18.489583333333336`, 
      32.02489774411205}, {33.98717474235546, -16.355467190390154`, 
      33.165606587927535`}, {50.65384140902208, -15.019386772020257`, 
      30.456303514547535`}, {50.653841409022064`, -16.979166666666668`, 
      29.40877933684656}}], 
     Polygon3DBox[{{50.65384140902208, -15.019386772020257`, 
      30.456303514547535`}, {33.98717474235546, -16.355467190390154`, 
      33.165606587927535`}, {33.98717474235546, -14.151314426000724`, 
      34.16429521265695}, {50.65384140902208, -12.995291557397847`, 
      31.373409124862437`}, {50.65384140902208, -15.019386772020257`, 
      30.456303514547535`}}], 
     Polygon3DBox[{{50.65384140902208, -12.995291557397842`, 
      31.373409124862444`}, {33.98717474235546, -14.151314426000717`, 
      34.16429521265696}, {33.987174742355506`, -11.886563560689835`, 
      35.01668708028775}, {50.65384140902208, -10.915548509253199`, 
      32.15616898077129}, {50.65384140902208, -12.995291557397842`, 
      31.373409124862444`}}], 
     Polygon3DBox[{{50.65384140902208, -10.915548509253199`, 
      32.15616898077129}, {33.987174742355506`, -11.886563560689835`, 
      35.01668708028775}, {33.987174742355506`, -9.570912605353639, 
      35.71913211798116}, {50.65384140902208, -8.789063406606441, 
      32.801231184399605`}, {50.65384140902208, -10.915548509253199`, 
      32.15616898077129}}], 
     Polygon3DBox[{{50.65384140902208, -8.789063406606441, 
      32.801231184399605`}, {33.987174742355506`, -9.570912605353639, 
      35.71913211798116}, {33.98717474235546, -7.214277532888086, 
      36.268622348244456`}, {50.653841409022064`, -6.62494218513103, 
      33.3058334803597}, {50.65384140902208, -8.789063406606441, 
      32.801231184399605`}}], 
     Polygon3DBox[{{50.653841409022064`, -6.624942185131024, 
      33.3058334803597}, {33.98717474235546, -7.2142775328880795`, 
      36.268622348244456`}, {33.987174742355506`, -4.826749816470662, 
      36.66280476955236}, {50.65384140902208, -4.432451944139255, 
      33.66781508415231}, {50.653841409022064`, -6.624942185131024, 
      33.3058334803597}}], 
     Polygon3DBox[{{50.65384140902208, -4.432451944139255, 
      33.66781508415231}, {33.987174742355506`, -4.826749816470662, 
      36.66280476955236}, {33.98717474235546, -2.418553216323006, 
      36.899991432260855`}, {50.65384140902208, -2.2209812634402817`, 
      33.885625934977575`}, {50.65384140902208, -4.432451944139255, 
      33.66781508415231}}], 
     Polygon3DBox[{{50.65384140902208, -2.2209812634402817`, 
      33.885625934977575`}, {33.98717474235546, -2.418553216323006, 
      36.899991432260855`}, {33.98717474235546, -1.0475345357630377`*^-14, 
      36.979166666666664`}, {50.65384140902208, -9.619612919964797*^-15, 
      33.95833333333333}, {50.65384140902208, -2.2209812634402817`, 
      33.885625934977575`}}], 
     Polygon3DBox[{{50.65384140902208, -2.0793482110522766`*^-15, 
      33.95833333333333}, {33.98717474235546, -2.2643209046734916`*^-15, 
      36.979166666666664`}, {33.987174742355506`, 2.4185532163229935`, 
      36.899991432260855`}, {50.65384140902208, 2.22098126344027, 
      33.885625934977575`}, {50.65384140902208, -2.0793482110522766`*^-15, 
      33.95833333333333}}], 
     Polygon3DBox[{{50.65384140902208, 2.22098126344027, 
      33.885625934977575`}, {33.987174742355506`, 2.4185532163229935`, 
      36.899991432260855`}, {33.987174742355506`, 4.826749816470651, 
      36.66280476955236}, {50.65384140902208, 4.4324519441392445`, 
      33.66781508415231}, {50.65384140902208, 2.22098126344027, 
      33.885625934977575`}}], 
     Polygon3DBox[{{50.65384140902208, 4.4324519441392445`, 
      33.66781508415231}, {33.987174742355506`, 4.826749816470651, 
      36.66280476955236}, {33.987174742355506`, 7.214277532888065, 
      36.268622348244456`}, {50.653841409022064`, 6.624942185131012, 
      33.3058334803597}, {50.65384140902208, 4.4324519441392445`, 
      33.66781508415231}}], 
     Polygon3DBox[{{50.653841409022064`, 6.624942185131012, 
      33.3058334803597}, {33.987174742355506`, 7.214277532888065, 
      36.268622348244456`}, {33.987174742355506`, 9.570912605353618, 
      35.71913211798117}, {50.65384140902208, 8.789063406606422, 
      32.80123118439961}, {50.653841409022064`, 6.624942185131012, 
      33.3058334803597}}], 
     Polygon3DBox[{{50.653841409022064`, 8.789063406606429, 
      32.80123118439961}, {33.987174742355506`, 9.570912605353628, 
      35.71913211798117}, {33.98717474235546, 11.88656356068982, 
      35.01668708028777}, {50.65384140902208, 10.915548509253187`, 
      32.1561689807713}, {50.653841409022064`, 8.789063406606429, 
      32.80123118439961}}], 
     Polygon3DBox[{{50.65384140902208, 10.915548509253187`, 
      32.1561689807713}, {33.98717474235546, 11.88656356068982, 
      35.01668708028777}, {33.98717474235546, 14.151314426000704`, 
      34.16429521265696}, {50.65384140902208, 12.99529155739783, 
      31.373409124862444`}, {50.65384140902208, 10.915548509253187`, 
      32.1561689807713}}], 
     Polygon3DBox[{{50.65384140902208, 12.99529155739783, 
      31.373409124862444`}, {33.98717474235546, 14.151314426000704`, 
      34.16429521265696}, {33.98717474235546, 16.355467190390147`, 
      33.165606587927535`}, {50.653841409022064`, 15.019386772020246`, 
      30.456303514547542`}, {50.65384140902208, 12.99529155739783, 
      31.373409124862444`}}], 
     Polygon3DBox[{{50.653841409022064`, 15.019386772020246`, 
      30.456303514547542`}, {33.98717474235546, 16.355467190390147`, 
      33.165606587927535`}, {33.98717474235546, 18.489583333333325`, 
      32.02489774411205}, {50.65384140902208, 16.979166666666657`, 
      29.408779336846564`}, {50.653841409022064`, 15.019386772020246`, 
      30.456303514547542`}}], 
     Polygon3DBox[{{50.65384140902208, 16.979166666666657`, 
      29.408779336846564`}, {33.98717474235546, 18.489583333333325`, 
      32.02489774411205}, {33.98717474235546, 20.544524241870693`, 
      30.747053371604544`}, {50.65384140902208, 18.866239162957314`, 
      28.23532225110727}, {50.65384140902208, 16.979166666666657`, 
      29.408779336846564`}}], 
     Polygon3DBox[{{50.65384140902208, 18.866239162957314`, 
      28.23532225110727}, {33.98717474235546, 20.544524241870693`, 
      30.747053371604544`}, {33.98717474235546, 22.511490343551635`, 
      29.337545396186307`}, {50.65384140902208, 20.67252352675446, 
      26.9409571807232}, {50.65384140902208, 18.866239162957314`, 
      28.23532225110727}}], 
     Polygon3DBox[{{50.65384140902208, 20.67252352675446, 26.9409571807232}, {
      33.98717474235546, 22.511490343551635`, 29.337545396186307`}, {
      33.987174742355364`, 24.382058787554616`, 27.802409547399698`}, {
      50.65384140902208, 22.390284971106492`, 25.531226795640283`}, {
      50.65384140902208, 20.67252352675446, 26.9409571807232}}], 
     Polygon3DBox[{{50.65384140902208, 22.390284971106492`, 
      25.531226795640283`}, {33.987174742355364`, 24.382058787554616`, 
      27.802409547399698`}, {33.987174742355364`, 26.148219512627527`, 
      26.148219512627552`}, {50.65384140902208, 24.01216777779316, 
      24.012167777793188`}, {50.65384140902208, 22.390284971106492`, 
      25.531226795640283`}}], 
     Polygon3DBox[{{50.65384140902208, 24.012167777793174`, 
      24.012167777793174`}, {33.98717474235546, 26.148219512627534`, 
      26.148219512627538`}, {33.98717474235546, 27.80240954739968, 
      24.382058787554634`}, {50.653841409022064`, 25.53122679564027, 
      22.39028497110651}, {50.65384140902208, 24.012167777793174`, 
      24.012167777793174`}}], 
     Polygon3DBox[{{50.653841409022064`, 25.53122679564027, 
      22.39028497110651}, {33.98717474235546, 27.80240954739968, 
      24.382058787554634`}, {33.98717474235546, 29.337545396186293`, 
      22.511490343551657`}, {50.653841409022064`, 26.94095718072319, 
      20.67252352675448}, {50.653841409022064`, 25.53122679564027, 
      22.39028497110651}}], 
     Polygon3DBox[{{50.653841409022064`, 26.94095718072319, 
      20.67252352675448}, {33.98717474235546, 29.337545396186293`, 
      22.511490343551657`}, {33.98717474235546, 30.747053371604526`, 
      20.544524241870718`}, {50.65384140902208, 28.235322251107256`, 
      18.866239162957335`}, {50.653841409022064`, 26.94095718072319, 
      20.67252352675448}}], 
     Polygon3DBox[{{50.65384140902208, 28.235322251107256`, 
      18.866239162957335`}, {33.98717474235546, 30.747053371604526`, 
      20.544524241870718`}, {33.98717474235546, 32.024897744112046`, 
      18.489583333333343`}, {50.65384140902208, 29.408779336846553`, 
      16.979166666666675`}, {50.65384140902208, 28.235322251107256`, 
      18.866239162957335`}}], 
     Polygon3DBox[{{50.65384140902208, 29.408779336846553`, 
      16.979166666666675`}, {33.98717474235546, 32.024897744112046`, 
      18.489583333333343`}, {33.987174742355364`, 33.165606587927535`, 
      16.35546719039017}, {50.653841409022064`, 30.456303514547535`, 
      15.019386772020265`}, {50.65384140902208, 29.408779336846553`, 
      16.979166666666675`}}], 
     Polygon3DBox[{{50.653841409022064`, 30.456303514547535`, 
      15.019386772020265`}, {33.987174742355364`, 33.165606587927535`, 
      16.35546719039017}, {33.987174742355364`, 34.16429521265695, 
      14.151314426000734`}, {50.65384140902208, 31.373409124862437`, 
      12.995291557397856`}, {50.653841409022064`, 30.456303514547535`, 
      15.019386772020265`}}], 
     Polygon3DBox[{{50.653841409022064`, 31.373409124862444`, 
      12.995291557397843`}, {33.987174742355364`, 34.16429521265696, 
      14.151314426000718`}, {33.987174742355506`, 35.01668708028775, 
      11.886563560689837`}, {50.65384140902208, 32.15616898077129, 
      10.9155485092532}, {50.653841409022064`, 31.373409124862444`, 
      12.995291557397843`}}], 
     Polygon3DBox[{{50.65384140902208, 32.15616898077129, 10.9155485092532}, {
      33.987174742355506`, 35.01668708028775, 11.886563560689837`}, {
      33.987174742355506`, 35.71913211798116, 9.57091260535364}, {
      50.65384140902208, 32.801231184399605`, 8.789063406606441}, {
      50.65384140902208, 32.15616898077129, 10.9155485092532}}], 
     Polygon3DBox[{{50.65384140902208, 32.801231184399605`, 
      8.789063406606441}, {33.987174742355506`, 35.71913211798116, 
      9.57091260535364}, {33.98717474235546, 36.268622348244456`, 
      7.214277532888089}, {50.653841409022064`, 33.3058334803597, 
      6.624942185131034}, {50.65384140902208, 32.801231184399605`, 
      8.789063406606441}}], 
     Polygon3DBox[{{50.653841409022064`, 33.3058334803597, 
      6.624942185131034}, {33.98717474235546, 36.268622348244456`, 
      7.214277532888089}, {33.98717474235546, 36.66280476955236, 
      4.826749816470673}, {50.65384140902208, 33.66781508415231, 
      4.432451944139266}, {50.653841409022064`, 33.3058334803597, 
      6.624942185131034}}], 
     Polygon3DBox[{{50.65384140902208, 33.66781508415231, 
      4.432451944139266}, {33.98717474235546, 36.66280476955236, 
      4.826749816470673}, {33.98717474235546, 36.899991432260855`, 
      2.4185532163230166`}, {50.65384140902208, 33.885625934977575`, 
      2.2209812634402915`}, {50.65384140902208, 33.66781508415231, 
      4.432451944139266}}], 
     Polygon3DBox[{{50.65384140902208, 33.885625934977575`, 
      2.2209812634402915`}, {33.98717474235546, 36.899991432260855`, 
      2.4185532163230166`}, {33.98717474235546, 36.979166666666664`, 
      2.0950690715260754`*^-14}, {50.65384140902208, 33.95833333333333, 
      1.9239225839929595`*^-14}, {50.65384140902208, 33.885625934977575`, 
      2.2209812634402915`}}], 
     Polygon3DBox[{{50.65384140902208, 33.95833333333333, 
      4.158696422104553*^-15}, {33.98717474235546, 36.979166666666664`, 
      4.528641809346983*^-15}, {33.987174742355506`, 
      36.899991432260855`, -2.4185532163229917`}, {50.65384140902208, 
      33.885625934977575`, -2.2209812634402684`}, {50.65384140902208, 
      33.95833333333333, 4.158696422104553*^-15}}], 
     Polygon3DBox[{{50.65384140902208, 
      33.885625934977575`, -2.2209812634402684`}, {33.987174742355506`, 
      36.899991432260855`, -2.4185532163229917`}, {33.987174742355506`, 
      36.66280476955236, -4.826749816470647}, {50.65384140902208, 
      33.66781508415231, -4.432451944139242}, {50.65384140902208, 
      33.885625934977575`, -2.2209812634402684`}}], 
     Polygon3DBox[{{50.65384140902208, 
      33.66781508415231, -4.432451944139242}, {33.987174742355506`, 
      36.66280476955236, -4.826749816470647}, {33.987174742355506`, 
      36.268622348244456`, -7.2142775328880635`}, {50.653841409022064`, 
      33.3058334803597, -6.62494218513101}, {50.65384140902208, 
      33.66781508415231, -4.432451944139242}}], 
     Polygon3DBox[{{50.653841409022064`, 
      33.3058334803597, -6.62494218513101}, {33.987174742355506`, 
      36.268622348244456`, -7.2142775328880635`}, {33.987174742355506`, 
      35.71913211798117, -9.570912605353616}, {50.65384140902208, 
      32.80123118439961, -8.78906340660642}, {50.653841409022064`, 
      33.3058334803597, -6.62494218513101}}], 
     Polygon3DBox[{{50.65384140902208, 
      32.80123118439961, -8.78906340660642}, {33.987174742355506`, 
      35.71913211798117, -9.570912605353616}, {33.98717474235546, 
      35.01668708028777, -11.88656356068981}, {50.65384140902208, 
      32.1561689807713, -10.915548509253176`}, {50.65384140902208, 
      32.80123118439961, -8.78906340660642}}], 
     Polygon3DBox[{{50.65384140902208, 
      32.1561689807713, -10.915548509253176`}, {33.98717474235546, 
      35.01668708028777, -11.88656356068981}, {33.98717474235546, 
      34.16429521265697, -14.151314426000694`}, {50.653841409022064`, 
      31.373409124862455`, -12.99529155739782}, {50.65384140902208, 
      32.1561689807713, -10.915548509253176`}}], 
     Polygon3DBox[{{50.653841409022064`, 
      31.373409124862455`, -12.99529155739782}, {33.98717474235546, 
      34.16429521265697, -14.151314426000694`}, {33.987174742355506`, 
      33.16560658792754, -16.35546719039013}, {50.65384140902208, 
      30.45630351454755, -15.019386772020232`}, {50.653841409022064`, 
      31.373409124862455`, -12.99529155739782}}], 
     Polygon3DBox[{{50.65384140902208, 
      30.456303514547542`, -15.019386772020242`}, {33.987174742355506`, 
      33.165606587927535`, -16.355467190390144`}, {33.98717474235546, 
      32.02489774411206, -18.48958333333332}, {50.653841409022064`, 
      29.408779336846568`, -16.979166666666657`}, {50.65384140902208, 
      30.456303514547542`, -15.019386772020242`}}], 
     Polygon3DBox[{{50.653841409022064`, 
      29.408779336846568`, -16.979166666666657`}, {33.98717474235546, 
      32.02489774411206, -18.48958333333332}, {33.98717474235546, 
      30.747053371604544`, -20.544524241870693`}, {50.65384140902208, 
      28.23532225110727, -18.866239162957314`}, {50.653841409022064`, 
      29.408779336846568`, -16.979166666666657`}}], 
     Polygon3DBox[{{50.65384140902208, 
      28.23532225110727, -18.866239162957314`}, {33.98717474235546, 
      30.747053371604544`, -20.544524241870693`}, {33.98717474235546, 
      29.337545396186307`, -22.511490343551635`}, {50.65384140902208, 
      26.9409571807232, -20.67252352675446}, {50.65384140902208, 
      28.23532225110727, -18.866239162957314`}}], 
     Polygon3DBox[{{50.65384140902208, 
      26.9409571807232, -20.67252352675446}, {33.98717474235546, 
      29.337545396186307`, -22.511490343551635`}, {33.987174742355364`, 
      27.802409547399698`, -24.382058787554616`}, {50.65384140902208, 
      25.531226795640283`, -22.390284971106492`}, {50.65384140902208, 
      26.9409571807232, -20.67252352675446}}], 
     Polygon3DBox[{{50.65384140902208, 
      25.531226795640283`, -22.390284971106492`}, {33.987174742355364`, 
      27.802409547399698`, -24.382058787554616`}, {33.987174742355364`, 
      26.148219512627552`, -26.148219512627527`}, {50.65384140902208, 
      24.012167777793188`, -24.01216777779316}, {50.65384140902208, 
      25.531226795640283`, -22.390284971106492`}}], 
     Polygon3DBox[{{50.65384140902208, 
      24.012167777793188`, -24.01216777779316}, {33.987174742355364`, 
      26.148219512627552`, -26.148219512627527`}, {33.98717474235546, 
      24.382058787554648`, -27.802409547399666`}, {50.65384140902208, 
      22.39028497110652, -25.531226795640258`}, {50.65384140902208, 
      24.012167777793188`, -24.01216777779316}}], 
     Polygon3DBox[{{50.653841409022064`, 
      22.390284971106514`, -25.53122679564027}, {33.987174742355364`, 
      24.382058787554637`, -27.80240954739968}, {33.98717474235546, 
      22.511490343551657`, -29.33754539618629}, {50.65384140902208, 
      20.67252352675448, -26.940957180723185`}, {50.653841409022064`, 
      22.390284971106514`, -25.53122679564027}}], 
     Polygon3DBox[{{50.65384140902208, 
      20.67252352675448, -26.940957180723185`}, {33.98717474235546, 
      22.511490343551657`, -29.33754539618629}, {33.98717474235546, 
      20.544524241870704`, -30.747053371604537`}, {50.65384140902208, 
      18.86623916295732, -28.235322251107263`}, {50.65384140902208, 
      20.67252352675448, -26.940957180723185`}}], 
     Polygon3DBox[{{50.65384140902208, 
      18.866239162957346`, -28.23532225110725}, {33.987174742355364`, 
      20.544524241870732`, -30.747053371604522`}, {33.98717474235546, 
      18.48958333333335, -32.02489774411204}, {50.65384140902208, 
      16.979166666666682`, -29.40877933684655}, {50.65384140902208, 
      18.866239162957346`, -28.23532225110725}}], 
     Polygon3DBox[{{50.65384140902208, 
      16.979166666666682`, -29.40877933684655}, {33.98717474235546, 
      18.48958333333335, -32.02489774411204}, {33.98717474235546, 
      16.35546719039015, -33.165606587927535`}, {50.65384140902208, 
      15.019386772020253`, -30.456303514547535`}, {50.65384140902208, 
      16.979166666666682`, -29.40877933684655}}], 
     Polygon3DBox[{{50.65384140902208, 
      15.019386772020253`, -30.456303514547535`}, {33.98717474235546, 
      16.35546719039015, -33.165606587927535`}, {33.98717474235546, 
      14.151314426000704`, -34.16429521265696}, {50.65384140902208, 
      12.99529155739783, -31.373409124862444`}, {50.65384140902208, 
      15.019386772020253`, -30.456303514547535`}}], 
     Polygon3DBox[{{50.65384140902208, 
      12.995291557397858`, -31.373409124862437`}, {33.987174742355364`, 
      14.151314426000736`, -34.16429521265695}, {33.987174742355506`, 
      11.886563560689837`, -35.01668708028775}, {50.65384140902208, 
      10.915548509253203`, -32.15616898077129}, {50.65384140902208, 
      12.995291557397858`, -31.373409124862437`}}], 
     Polygon3DBox[{{50.65384140902208, 
      10.915548509253203`, -32.15616898077129}, {33.987174742355506`, 
      11.886563560689837`, -35.01668708028775}, {33.987174742355506`, 
      9.570912605353628, -35.71913211798117}, {50.653841409022064`, 
      8.789063406606429, -32.80123118439961}, {50.65384140902208, 
      10.915548509253203`, -32.15616898077129}}], 
     Polygon3DBox[{{50.653841409022064`, 
      8.78906340660646, -32.801231184399605`}, {33.98717474235546, 
      9.570912605353659, -35.71913211798116}, {33.987174742355506`, 
      7.214277532888091, -36.26862234824445}, {50.65384140902208, 
      6.624942185131035, -33.305833480359695`}, {50.653841409022064`, 
      8.78906340660646, -32.801231184399605`}}], 
     Polygon3DBox[{{50.65384140902208, 
      6.624942185131035, -33.305833480359695`}, {33.987174742355506`, 
      7.214277532888091, -36.26862234824445}, {33.987174742355506`, 
      4.8267498164706595`, -36.66280476955236}, {50.65384140902208, 
      4.432451944139253, -33.66781508415231}, {50.65384140902208, 
      6.624942185131035, -33.305833480359695`}}], 
     Polygon3DBox[{{50.65384140902208, 
      4.432451944139282, -33.6678150841523}, {33.98717474235546, 
      4.826749816470691, -36.66280476955236}, {33.98717474235546, 
      2.4185532163230192`, -36.899991432260855`}, {50.65384140902208, 
      2.2209812634402937`, -33.885625934977575`}, {50.65384140902208, 
      4.432451944139282, -33.6678150841523}}], 
     Polygon3DBox[{{50.65384140902208, 
      2.2209812634402937`, -33.885625934977575`}, {33.98717474235546, 
      2.4185532163230192`, -36.899991432260855`}, {33.98717474235546, 
      6.792962714020474*^-15, -36.979166666666664`}, {50.65384140902208, 
      6.2380446331568295`*^-15, -33.95833333333333}, {50.65384140902208, 
      2.2209812634402937`, -33.885625934977575`}}], 
     Polygon3DBox[{{50.65384140902208, 
      6.2380446331568295`*^-15, -33.95833333333333}, {33.98717474235546, 
      6.792962714020474*^-15, -36.979166666666664`}, {
      33.98717474235546, -2.4185532163230055`, -36.899991432260855`}, {
      50.65384140902208, -2.2209812634402812`, -33.885625934977575`}, {
      50.65384140902208, 6.2380446331568295`*^-15, -33.95833333333333}}], 
     Polygon3DBox[{{
      50.65384140902208, -2.220981263440251, -33.885625934977575`}, {
      33.987174742355506`, -2.4185532163229726`, -36.899991432260855`}, {
      33.987174742355506`, -4.826749816470645, -36.66280476955236}, {
      50.65384140902208, -4.432451944139241, -33.66781508415231}, {
      50.65384140902208, -2.220981263440251, -33.885625934977575`}}], 
     Polygon3DBox[{{
      50.65384140902208, -4.432451944139241, -33.66781508415231}, {
      33.987174742355506`, -4.826749816470645, -36.66280476955236}, {
      33.98717474235546, -7.214277532888078, -36.268622348244456`}, {
      50.653841409022064`, -6.624942185131023, -33.3058334803597}, {
      50.65384140902208, -4.432451944139241, -33.66781508415231}}], 
     Polygon3DBox[{{
      50.65384140902208, -6.624942185130993, -33.3058334803597}, {
      33.98717474235546, -7.214277532888045, -36.26862234824446}, {
      33.987174742355506`, -9.570912605353614, -35.71913211798117}, {
      50.65384140902208, -8.789063406606417, -32.80123118439961}, {
      50.65384140902208, -6.624942185130993, -33.3058334803597}}], 
     Polygon3DBox[{{
      50.65384140902208, -8.789063406606417, -32.80123118439961}, {
      33.987174742355506`, -9.570912605353614, -35.71913211798117}, {
      33.987174742355364`, -11.886563560689824`, -35.01668708028777}, {
      50.65384140902208, -10.91554850925319, -32.1561689807713}, {
      50.65384140902208, -8.789063406606417, -32.80123118439961}}], 
     Polygon3DBox[{{
      50.65384140902208, -10.91554850925319, -32.1561689807713}, {
      33.987174742355364`, -11.886563560689824`, -35.01668708028777}, {
      33.98717474235546, -14.151314426000724`, -34.16429521265695}, {
      50.65384140902208, -12.995291557397847`, -31.373409124862437`}, {
      50.65384140902208, -10.91554850925319, -32.1561689807713}}], 
     Polygon3DBox[{{
      50.653841409022064`, -12.995291557397818`, -31.373409124862455`}, {
      33.98717474235546, -14.151314426000694`, -34.16429521265697}, {
      33.987174742355506`, -16.355467190390144`, -33.165606587927535`}, {
      50.65384140902208, -15.019386772020242`, -30.456303514547542`}, {
      50.653841409022064`, -12.995291557397818`, -31.373409124862455`}}], 
     Polygon3DBox[{{
      50.65384140902208, -15.019386772020242`, -30.456303514547542`}, {
      33.987174742355506`, -16.355467190390144`, -33.165606587927535`}, {
      33.98717474235546, -18.489583333333336`, -32.02489774411205}, {
      50.653841409022064`, -16.979166666666668`, -29.40877933684656}, {
      50.65384140902208, -15.019386772020242`, -30.456303514547542`}}], 
     Polygon3DBox[{{
      50.65384140902208, -16.979166666666643`, -29.40877933684657}, {
      33.98717474235546, -18.489583333333307`, -32.02489774411207}, {
      33.98717474235546, -20.544524241870693`, -30.747053371604544`}, {
      50.65384140902208, -18.86623916295731, -28.23532225110727}, {
      50.65384140902208, -16.979166666666643`, -29.40877933684657}}], 
     Polygon3DBox[{{
      50.65384140902208, -18.86623916295731, -28.23532225110727}, {
      33.98717474235546, -20.544524241870693`, -30.747053371604544`}, {
      33.987174742355506`, -22.511490343551642`, -29.337545396186297`}, {
      50.65384140902208, -20.672523526754468`, -26.940957180723192`}, {
      50.65384140902208, -18.86623916295731, -28.23532225110727}}], 
     Polygon3DBox[{{
      50.653841409022064`, -20.672523526754446`, -26.940957180723213`}, {
      33.98717474235546, -22.51149034355162, -29.33754539618632}, {
      33.987174742355364`, -24.382058787554612`, -27.8024095473997}, {
      50.65384140902208, -22.39028497110649, -25.531226795640286`}, {
      50.653841409022064`, -20.672523526754446`, -26.940957180723213`}}], 
     Polygon3DBox[{{
      50.65384140902208, -22.39028497110649, -25.531226795640286`}, {
      33.987174742355364`, -24.382058787554612`, -27.8024095473997}, {
      33.98717474235546, -26.14821951262753, -26.14821951262754}, {
      50.65384140902208, -24.01216777779317, -24.012167777793177`}, {
      50.65384140902208, -22.39028497110649, -25.531226795640286`}}], 
     Polygon3DBox[{{
      50.65384140902208, -24.01216777779317, -24.012167777793177`}, {
      33.98717474235546, -26.14821951262753, -26.14821951262754}, {
      33.98717474235546, -27.802409547399687`, -24.382058787554623`}, {
      50.65384140902208, -25.531226795640276`, -22.390284971106496`}, {
      50.65384140902208, -24.01216777779317, -24.012167777793177`}}], 
     Polygon3DBox[{{
      50.65384140902208, -25.531226795640258`, -22.39028497110652}, {
      33.98717474235546, -27.802409547399666`, -24.382058787554648`}, {
      33.98717474235546, -29.33754539618629, -22.511490343551657`}, {
      50.65384140902208, -26.940957180723185`, -20.67252352675448}, {
      50.65384140902208, -25.531226795640258`, -22.39028497110652}}], 
     Polygon3DBox[{{
      50.65384140902208, -26.940957180723185`, -20.67252352675448}, {
      33.98717474235546, -29.33754539618629, -22.511490343551657`}, {
      33.98717474235546, -30.747053371604537`, -20.544524241870704`}, {
      50.65384140902208, -28.235322251107263`, -18.86623916295732}, {
      50.65384140902208, -26.940957180723185`, -20.67252352675448}}], 
     Polygon3DBox[{{
      50.65384140902208, -28.23532225110725, -18.866239162957346`}, {
      33.987174742355364`, -30.747053371604522`, -20.544524241870732`}, {
      33.98717474235546, -32.02489774411204, -18.48958333333335}, {
      50.65384140902208, -29.40877933684655, -16.979166666666682`}, {
      50.65384140902208, -28.23532225110725, -18.866239162957346`}}], 
     Polygon3DBox[{{
      50.65384140902208, -29.40877933684655, -16.979166666666682`}, {
      33.98717474235546, -32.02489774411204, -18.48958333333335}, {
      33.98717474235546, -33.165606587927535`, -16.355467190390154`}, {
      50.65384140902208, -30.456303514547535`, -15.019386772020257`}, {
      50.65384140902208, -29.40877933684655, -16.979166666666682`}}], 
     Polygon3DBox[{{
      50.65384140902208, -30.45630351454752, -15.019386772020281`}, {
      33.98717474235546, -33.16560658792752, -16.355467190390186`}, {
      33.987174742355364`, -34.16429521265695, -14.151314426000738`}, {
      50.653841409022064`, -31.373409124862437`, -12.995291557397861`}, {
      50.65384140902208, -30.45630351454752, -15.019386772020281`}}], 
     Polygon3DBox[{{
      50.653841409022064`, -31.373409124862437`, -12.995291557397861`}, {
      33.987174742355364`, -34.16429521265695, -14.151314426000738`}, {
      33.987174742355506`, -35.01668708028775, -11.886563560689838`}, {
      50.65384140902208, -32.15616898077129, -10.915548509253204`}, {
      50.653841409022064`, -31.373409124862437`, -12.995291557397861`}}], 
     Polygon3DBox[{{
      50.65384140902208, -32.15616898077129, -10.915548509253204`}, {
      33.987174742355506`, -35.01668708028775, -11.886563560689838`}, {
      33.98717474235546, -35.71913211798117, -9.57091260535363}, {
      50.653841409022064`, -32.80123118439961, -8.78906340660643}, {
      50.65384140902208, -32.15616898077129, -10.915548509253204`}}], 
     Polygon3DBox[{{
      50.653841409022064`, -32.801231184399605`, -8.789063406606461}, {
      33.98717474235546, -35.71913211798116, -9.570912605353662}, {
      33.987174742355506`, -36.26862234824445, -7.214277532888093}, {
      50.65384140902208, -33.305833480359695`, -6.6249421851310375`}, {
      50.653841409022064`, -32.801231184399605`, -8.789063406606461}}], 
     Polygon3DBox[{{
      50.65384140902208, -33.305833480359695`, -6.6249421851310375`}, {
      33.987174742355506`, -36.26862234824445, -7.214277532888093}, {
      33.987174742355506`, -36.66280476955236, -4.826749816470661}, {
      50.65384140902208, -33.66781508415231, -4.432451944139254}, {
      50.65384140902208, -33.305833480359695`, -6.6249421851310375`}}], 
     Polygon3DBox[{{
      50.65384140902208, -33.6678150841523, -4.4324519441392844`}, {
      33.98717474235546, -36.66280476955236, -4.826749816470694}, {
      33.98717474235546, -36.899991432260855`, -2.418553216323021}, {
      50.65384140902208, -33.885625934977575`, -2.220981263440295}, {
      50.65384140902208, -33.6678150841523, -4.4324519441392844`}}], 
     Polygon3DBox[{{
      50.65384140902208, -33.885625934977575`, -2.220981263440295}, {
      33.98717474235546, -36.899991432260855`, -2.418553216323021}, {
      33.98717474235546, -36.979166666666664`, -9.057283618693966*^-15}, {
      50.65384140902208, -33.95833333333333, -8.317392844209107*^-15}, {
      50.65384140902208, -33.885625934977575`, -2.220981263440295}}], 
     Polygon3DBox[{{33.98717474235546, -36.979166666666664`, 0.}, {
      1.6902601750779826`*^-14, -40., 0.}, {
      1.6902601750779826`*^-14, -39.91435692954414, 2.616125169205722}, {
      33.987174742355506`, -36.899991432260855`, 2.4185532163229984`}, {
      33.98717474235546, -36.979166666666664`, 0.}}], 
     Polygon3DBox[{{33.987174742355506`, -36.899991432260855`, 
      2.4185532163229984`}, {1.6902601750779826`*^-14, -39.91435692954414, 
      2.616125169205722}, {1.6902601750779826`*^-14, -39.657794454952416`, 
      5.221047688802063}, {33.987174742355506`, -36.66280476955236, 
      4.826749816470657}, {33.987174742355506`, -36.899991432260855`, 
      2.4185532163229984`}}], 
     Polygon3DBox[{{33.987174742355506`, -36.66280476955236, 
      4.826749816470657}, {1.6902601750779826`*^-14, -39.657794454952416`, 
      5.221047688802063}, {1.6902601750779826`*^-14, -39.23141121612922, 
      7.8036128806451295`}, {33.98717474235546, -36.268622348244456`, 
      7.214277532888075}, {33.987174742355506`, -36.66280476955236, 
      4.826749816470657}}], 
     Polygon3DBox[{{33.98717474235546, -36.268622348244456`, 
      7.214277532888075}, {1.6902601750779826`*^-14, -39.23141121612922, 
      7.8036128806451295`}, {1.6902601750779826`*^-14, -38.63703305156273, 
      10.35276180410083}, {33.98717474235546, -35.71913211798117, 
      9.570912605353632}, {33.98717474235546, -36.268622348244456`, 
      7.214277532888075}}], 
     Polygon3DBox[{{33.98717474235546, -35.71913211798117, 
      9.570912605353632}, {1.6902601750779826`*^-14, -38.63703305156273, 
      10.35276180410083}, {1.6902601750779826`*^-14, -37.87720517980423, 
      12.85757861212646}, {33.987174742355364`, -35.01668708028777, 
      11.886563560689826`}, {33.98717474235546, -35.71913211798117, 
      9.570912605353632}}], 
     Polygon3DBox[{{33.987174742355364`, -35.01668708028777, 
      11.886563560689826`}, {1.6902601750779826`*^-14, -37.87720517980423, 
      12.85757861212646}, {1.6902601750779826`*^-14, -36.95518130045147, 
      15.307337294603588`}, {33.98717474235546, -34.16429521265696, 
      14.151314426000713`}, {33.987174742355364`, -35.01668708028777, 
      11.886563560689826`}}], 
     Polygon3DBox[{{33.98717474235546, -34.16429521265696, 
      14.151314426000717`}, {1.6902601750779826`*^-14, -36.95518130045147, 
      15.307337294603592`}, {1.6902601750779826`*^-14, -35.874909661307534`, 
      17.69154760876005}, {33.98717474235546, -33.165606587927535`, 
      16.35546719039015}, {33.98717474235546, -34.16429521265696, 
      14.151314426000717`}}], 
     Polygon3DBox[{{33.98717474235546, -33.165606587927535`, 
      16.35546719039015}, {1.6902601750779826`*^-14, -35.874909661307534`, 
      17.69154760876005}, {1.6902601750779826`*^-14, -34.64101615137755, 
      19.999999999999996`}, {33.98717474235546, -32.02489774411205, 
      18.48958333333333}, {33.98717474235546, -33.165606587927535`, 
      16.35546719039015}}], 
     Polygon3DBox[{{33.98717474235546, -32.02489774411205, 
      18.48958333333333}, {1.6902601750779826`*^-14, -34.64101615137755, 
      19.999999999999996`}, {1.6902601750779826`*^-14, -33.25878449210181, 
      22.222809320784087`}, {33.98717474235546, -30.747053371604537`, 
      20.544524241870704`}, {33.98717474235546, -32.02489774411205, 
      18.48958333333333}}], 
     Polygon3DBox[{{33.98717474235546, -30.747053371604537`, 
      20.544524241870704`}, {1.6902601750779826`*^-14, -33.25878449210181, 
      22.222809320784087`}, {1.6902601750779826`*^-14, -31.734133611649405`, 
      24.350457160348824`}, {33.98717474235546, -29.337545396186297`, 
      22.511490343551646`}, {33.98717474235546, -30.747053371604537`, 
      20.544524241870704`}}], 
     Polygon3DBox[{{33.98717474235546, -29.337545396186304`, 
      22.511490343551642`}, {1.6902601750779826`*^-14, -31.734133611649412`, 
      24.35045716034882}, {1.6902601750779826`*^-14, -30.073592299159095`, 
      26.373832604002754`}, {33.98717474235546, -27.802409547399684`, 
      24.382058787554627`}, {33.98717474235546, -29.337545396186304`, 
      22.511490343551642`}}], 
     Polygon3DBox[{{33.98717474235546, -27.802409547399684`, 
      24.382058787554627`}, {1.6902601750779826`*^-14, -30.073592299159095`, 
      26.373832604002754`}, {1.6902601750779826`*^-14, -28.284271247461902`, 
      28.2842712474619}, {33.98717474235546, -26.148219512627538`, 
      26.148219512627534`}, {33.98717474235546, -27.802409547399684`, 
      24.382058787554627`}}], 
     Polygon3DBox[{{33.98717474235546, -26.148219512627538`, 
      26.148219512627534`}, {1.6902601750779826`*^-14, -28.284271247461902`, 
      28.2842712474619}, {1.6902601750779826`*^-14, -26.373832604002754`, 
      30.073592299159095`}, {33.98717474235546, -24.382058787554627`, 
      27.802409547399684`}, {33.98717474235546, -26.148219512627538`, 
      26.148219512627534`}}], 
     Polygon3DBox[{{33.98717474235546, -24.382058787554634`, 
      27.80240954739968}, {1.6902601750779826`*^-14, -26.373832604002757`, 
      30.073592299159092`}, {1.6902601750779826`*^-14, -24.350457160348824`, 
      31.734133611649405`}, {33.98717474235546, -22.511490343551646`, 
      29.337545396186297`}, {33.98717474235546, -24.382058787554634`, 
      27.80240954739968}}], 
     Polygon3DBox[{{33.98717474235546, -22.511490343551646`, 
      29.337545396186297`}, {1.6902601750779826`*^-14, -24.350457160348824`, 
      31.734133611649405`}, {-8.25733812556342*^-14, -22.222809320784094`, 
      33.25878449210181}, {33.98717474235546, -20.54452424187071, 
      30.747053371604537`}, {33.98717474235546, -22.511490343551646`, 
      29.337545396186297`}}], 
     Polygon3DBox[{{33.987174742355364`, -20.544524241870715`, 
      30.747053371604533`}, {-8.25733812556342*^-14, -22.222809320784098`, 
      33.25878449210181}, {1.6902601750779826`*^-14, -20.000000000000004`, 
      34.64101615137754}, {33.98717474235546, -18.489583333333336`, 
      32.02489774411205}, {33.987174742355364`, -20.544524241870715`, 
      30.747053371604533`}}], 
     Polygon3DBox[{{33.98717474235546, -18.489583333333336`, 
      32.02489774411205}, {1.6902601750779826`*^-14, -20.000000000000004`, 
      34.64101615137754}, {1.6902601750779826`*^-14, -17.691547608760057`, 
      35.87490966130753}, {33.98717474235546, -16.355467190390154`, 
      33.165606587927535`}, {33.98717474235546, -18.489583333333336`, 
      32.02489774411205}}], 
     Polygon3DBox[{{33.98717474235546, -16.355467190390154`, 
      33.165606587927535`}, {1.6902601750779826`*^-14, -17.691547608760057`, 
      35.87490966130753}, {1.6902601750779826`*^-14, -15.3073372946036, 
      36.955181300451464`}, {33.98717474235546, -14.151314426000724`, 
      34.16429521265695}, {33.98717474235546, -16.355467190390154`, 
      33.165606587927535`}}], 
     Polygon3DBox[{{33.98717474235546, -14.151314426000717`, 
      34.16429521265696}, {1.6902601750779826`*^-14, -15.307337294603593`, 
      36.95518130045147}, {1.6902601750779826`*^-14, -12.857578612126469`, 
      37.87720517980422}, {33.987174742355506`, -11.886563560689835`, 
      35.01668708028775}, {33.98717474235546, -14.151314426000717`, 
      34.16429521265696}}], 
     Polygon3DBox[{{33.987174742355506`, -11.886563560689835`, 
      35.01668708028775}, {1.6902601750779826`*^-14, -12.857578612126469`, 
      37.87720517980422}, {8.085144796918884*^-14, -10.352761804100838`, 
      38.637033051562724`}, {33.987174742355506`, -9.570912605353639, 
      35.71913211798116}, {33.987174742355506`, -11.886563560689835`, 
      35.01668708028775}}], 
     Polygon3DBox[{{33.987174742355506`, -9.570912605353639, 
      35.71913211798116}, {8.085144796918884*^-14, -10.352761804100838`, 
      38.637033051562724`}, {1.6902601750779826`*^-14, -7.803612880645141, 
      39.23141121612922}, {33.98717474235546, -7.214277532888086, 
      36.268622348244456`}, {33.987174742355506`, -9.570912605353639, 
      35.71913211798116}}], 
     Polygon3DBox[{{33.98717474235546, -7.2142775328880795`, 
      36.268622348244456`}, {1.6902601750779826`*^-14, -7.803612880645133, 
      39.23141121612922}, {1.6902601750779826`*^-14, -5.221047688802068, 
      39.657794454952416`}, {33.987174742355506`, -4.826749816470662, 
      36.66280476955236}, {33.98717474235546, -7.2142775328880795`, 
      36.268622348244456`}}], 
     Polygon3DBox[{{33.987174742355506`, -4.826749816470662, 
      36.66280476955236}, {1.6902601750779826`*^-14, -5.221047688802068, 
      39.657794454952416`}, {1.6902601750779826`*^-14, -2.6161251692057306`, 
      39.91435692954414}, {33.98717474235546, -2.418553216323006, 
      36.899991432260855`}, {33.987174742355506`, -4.826749816470662, 
      36.66280476955236}}], 
     Polygon3DBox[{{33.98717474235546, -2.418553216323006, 
      36.899991432260855`}, {1.6902601750779826`*^-14, -2.6161251692057306`, 
      39.91435692954414}, {
      1.6902601750779826`*^-14, -1.1331077795295958`*^-14, 40.}, {
      33.98717474235546, -1.0475345357630377`*^-14, 36.979166666666664`}, {
      33.98717474235546, -2.418553216323006, 36.899991432260855`}}], 
     Polygon3DBox[{{33.98717474235546, -2.2643209046734916`*^-15, 
      36.979166666666664`}, {
      1.6902601750779826`*^-14, -2.4492935982947065`*^-15, 40.}, {
      1.6902601750779826`*^-14, 2.616125169205717, 39.91435692954414}, {
      33.987174742355506`, 2.4185532163229935`, 36.899991432260855`}, {
      33.98717474235546, -2.2643209046734916`*^-15, 36.979166666666664`}}], 
     Polygon3DBox[{{33.987174742355506`, 2.4185532163229935`, 
      36.899991432260855`}, {1.6902601750779826`*^-14, 2.616125169205717, 
      39.91435692954414}, {1.6902601750779826`*^-14, 5.221047688802056, 
      39.657794454952416`}, {33.987174742355506`, 4.826749816470651, 
      36.66280476955236}, {33.987174742355506`, 2.4185532163229935`, 
      36.899991432260855`}}], 
     Polygon3DBox[{{33.987174742355506`, 4.826749816470651, 
      36.66280476955236}, {1.6902601750779826`*^-14, 5.221047688802056, 
      39.657794454952416`}, {1.6902601750779826`*^-14, 7.803612880645119, 
      39.23141121612922}, {33.987174742355506`, 7.214277532888065, 
      36.268622348244456`}, {33.987174742355506`, 4.826749816470651, 
      36.66280476955236}}], 
     Polygon3DBox[{{33.987174742355506`, 7.214277532888065, 
      36.268622348244456`}, {1.6902601750779826`*^-14, 7.803612880645119, 
      39.23141121612922}, {1.6902601750779826`*^-14, 10.352761804100815`, 
      38.63703305156273}, {33.987174742355506`, 9.570912605353618, 
      35.71913211798117}, {33.987174742355506`, 7.214277532888065, 
      36.268622348244456`}}], 
     Polygon3DBox[{{33.987174742355506`, 9.570912605353628, 
      35.71913211798117}, {1.6902601750779826`*^-14, 10.352761804100826`, 
      38.63703305156273}, {1.6902601750779826`*^-14, 12.857578612126455`, 
      37.87720517980423}, {33.98717474235546, 11.88656356068982, 
      35.01668708028777}, {33.987174742355506`, 9.570912605353628, 
      35.71913211798117}}], 
     Polygon3DBox[{{33.98717474235546, 11.88656356068982, 
      35.01668708028777}, {1.6902601750779826`*^-14, 12.857578612126455`, 
      37.87720517980423}, {8.085144796918884*^-14, 15.30733729460358, 
      36.95518130045147}, {33.98717474235546, 14.151314426000704`, 
      34.16429521265696}, {33.98717474235546, 11.88656356068982, 
      35.01668708028777}}], 
     Polygon3DBox[{{33.98717474235546, 14.151314426000704`, 
      34.16429521265696}, {8.085144796918884*^-14, 15.30733729460358, 
      36.95518130045147}, {1.6902601750779826`*^-14, 17.691547608760047`, 
      35.874909661307534`}, {33.98717474235546, 16.355467190390147`, 
      33.165606587927535`}, {33.98717474235546, 14.151314426000704`, 
      34.16429521265696}}], 
     Polygon3DBox[{{33.98717474235546, 16.355467190390147`, 
      33.165606587927535`}, {1.6902601750779826`*^-14, 17.691547608760047`, 
      35.874909661307534`}, {1.6902601750779826`*^-14, 19.999999999999993`, 
      34.64101615137755}, {33.98717474235546, 18.489583333333325`, 
      32.02489774411205}, {33.98717474235546, 16.355467190390147`, 
      33.165606587927535`}}], 
     Polygon3DBox[{{33.98717474235546, 18.489583333333325`, 
      32.02489774411205}, {1.6902601750779826`*^-14, 19.999999999999993`, 
      34.64101615137755}, {1.6902601750779826`*^-14, 22.222809320784076`, 
      33.25878449210182}, {33.98717474235546, 20.544524241870693`, 
      30.747053371604544`}, {33.98717474235546, 18.489583333333325`, 
      32.02489774411205}}], 
     Polygon3DBox[{{33.98717474235546, 20.544524241870693`, 
      30.747053371604544`}, {1.6902601750779826`*^-14, 22.222809320784076`, 
      33.25878449210182}, {1.6902601750779826`*^-14, 24.350457160348814`, 
      31.734133611649415`}, {33.98717474235546, 22.511490343551635`, 
      29.337545396186307`}, {33.98717474235546, 20.544524241870693`, 
      30.747053371604544`}}], 
     Polygon3DBox[{{33.98717474235546, 22.511490343551635`, 
      29.337545396186307`}, {1.6902601750779826`*^-14, 24.350457160348814`, 
      31.734133611649415`}, {1.6902601750779826`*^-14, 26.37383260400274, 
      30.07359229915911}, {33.987174742355364`, 24.382058787554616`, 
      27.802409547399698`}, {33.98717474235546, 22.511490343551635`, 
      29.337545396186307`}}], 
     Polygon3DBox[{{33.987174742355364`, 24.382058787554616`, 
      27.802409547399698`}, {1.6902601750779826`*^-14, 26.37383260400274, 
      30.07359229915911}, {1.6902601750779826`*^-14, 28.284271247461888`, 
      28.284271247461916`}, {33.987174742355364`, 26.148219512627527`, 
      26.148219512627552`}, {33.987174742355364`, 24.382058787554616`, 
      27.802409547399698`}}], 
     Polygon3DBox[{{33.98717474235546, 26.148219512627534`, 
      26.148219512627538`}, {1.6902601750779826`*^-14, 28.2842712474619, 
      28.284271247461902`}, {1.6902601750779826`*^-14, 30.073592299159092`, 
      26.373832604002757`}, {33.98717474235546, 27.80240954739968, 
      24.382058787554634`}, {33.98717474235546, 26.148219512627534`, 
      26.148219512627538`}}], 
     Polygon3DBox[{{33.98717474235546, 27.80240954739968, 
      24.382058787554634`}, {1.6902601750779826`*^-14, 30.073592299159092`, 
      26.373832604002757`}, {1.6902601750779826`*^-14, 31.7341336116494, 
      24.350457160348835`}, {33.98717474235546, 29.337545396186293`, 
      22.511490343551657`}, {33.98717474235546, 27.80240954739968, 
      24.382058787554634`}}], 
     Polygon3DBox[{{33.98717474235546, 29.337545396186293`, 
      22.511490343551657`}, {1.6902601750779826`*^-14, 31.7341336116494, 
      24.350457160348835`}, {8.085144796918884*^-14, 33.258784492101796`, 
      22.2228093207841}, {33.98717474235546, 30.747053371604526`, 
      20.544524241870718`}, {33.98717474235546, 29.337545396186293`, 
      22.511490343551657`}}], 
     Polygon3DBox[{{33.98717474235546, 30.747053371604526`, 
      20.544524241870718`}, {8.085144796918884*^-14, 33.258784492101796`, 
      22.2228093207841}, {1.6902601750779826`*^-14, 34.641016151377535`, 
      20.00000000000001}, {33.98717474235546, 32.024897744112046`, 
      18.489583333333343`}, {33.98717474235546, 30.747053371604526`, 
      20.544524241870718`}}], 
     Polygon3DBox[{{33.98717474235546, 32.024897744112046`, 
      18.489583333333343`}, {1.6902601750779826`*^-14, 34.641016151377535`, 
      20.00000000000001}, {1.6902601750779826`*^-14, 35.87490966130753, 
      17.691547608760068`}, {33.987174742355364`, 33.165606587927535`, 
      16.35546719039017}, {33.98717474235546, 32.024897744112046`, 
      18.489583333333343`}}], 
     Polygon3DBox[{{33.987174742355364`, 33.165606587927535`, 
      16.35546719039017}, {1.6902601750779826`*^-14, 35.87490966130753, 
      17.691547608760068`}, {1.6902601750779826`*^-14, 36.955181300451464`, 
      15.307337294603611`}, {33.987174742355364`, 34.16429521265695, 
      14.151314426000734`}, {33.987174742355364`, 33.165606587927535`, 
      16.35546719039017}}], 
     Polygon3DBox[{{33.987174742355364`, 34.16429521265696, 
      14.151314426000718`}, {1.6902601750779826`*^-14, 36.95518130045147, 
      15.307337294603595`}, {1.6902601750779826`*^-14, 37.87720517980422, 
      12.85757861212647}, {33.987174742355506`, 35.01668708028775, 
      11.886563560689837`}, {33.987174742355364`, 34.16429521265696, 
      14.151314426000718`}}], 
     Polygon3DBox[{{33.987174742355506`, 35.01668708028775, 
      11.886563560689837`}, {1.6902601750779826`*^-14, 37.87720517980422, 
      12.85757861212647}, {8.085144796918884*^-14, 38.637033051562724`, 
      10.35276180410084}, {33.987174742355506`, 35.71913211798116, 
      9.57091260535364}, {33.987174742355506`, 35.01668708028775, 
      11.886563560689837`}}], 
     Polygon3DBox[{{33.987174742355506`, 35.71913211798116, 
      9.57091260535364}, {8.085144796918884*^-14, 38.637033051562724`, 
      10.35276180410084}, {1.6902601750779826`*^-14, 39.23141121612922, 
      7.803612880645145}, {33.98717474235546, 36.268622348244456`, 
      7.214277532888089}, {33.987174742355506`, 35.71913211798116, 
      9.57091260535364}}], 
     Polygon3DBox[{{33.98717474235546, 36.268622348244456`, 
      7.214277532888089}, {1.6902601750779826`*^-14, 39.23141121612922, 
      7.803612880645145}, {1.6902601750779826`*^-14, 39.657794454952416`, 
      5.22104768880208}, {33.98717474235546, 36.66280476955236, 
      4.826749816470673}, {33.98717474235546, 36.268622348244456`, 
      7.214277532888089}}], 
     Polygon3DBox[{{33.98717474235546, 36.66280476955236, 
      4.826749816470673}, {1.6902601750779826`*^-14, 39.657794454952416`, 
      5.22104768880208}, {1.6902601750779826`*^-14, 39.91435692954414, 
      2.616125169205742}, {33.98717474235546, 36.899991432260855`, 
      2.4185532163230166`}, {33.98717474235546, 36.66280476955236, 
      4.826749816470673}}], 
     Polygon3DBox[{{33.98717474235546, 36.899991432260855`, 
      2.4185532163230166`}, {1.6902601750779826`*^-14, 39.91435692954414, 
      2.616125169205742}, {1.6902601750779826`*^-14, 40., 
      2.2662155590591917`*^-14}, {33.98717474235546, 36.979166666666664`, 
      2.0950690715260754`*^-14}, {33.98717474235546, 36.899991432260855`, 
      2.4185532163230166`}}], 
     Polygon3DBox[{{33.98717474235546, 36.979166666666664`, 
      4.528641809346983*^-15}, {1.6902601750779826`*^-14, 40., 
      4.898587196589413*^-15}, {1.6902601750779826`*^-14, 
      39.91435692954414, -2.616125169205715}, {33.987174742355506`, 
      36.899991432260855`, -2.4185532163229917`}, {33.98717474235546, 
      36.979166666666664`, 4.528641809346983*^-15}}], 
     Polygon3DBox[{{33.987174742355506`, 
      36.899991432260855`, -2.4185532163229917`}, {1.6902601750779826`*^-14, 
      39.91435692954414, -2.616125169205715}, {1.6902601750779826`*^-14, 
      39.657794454952416`, -5.221047688802052}, {33.987174742355506`, 
      36.66280476955236, -4.826749816470647}, {33.987174742355506`, 
      36.899991432260855`, -2.4185532163229917`}}], 
     Polygon3DBox[{{33.987174742355506`, 
      36.66280476955236, -4.826749816470647}, {1.6902601750779826`*^-14, 
      39.657794454952416`, -5.221047688802052}, {1.6902601750779826`*^-14, 
      39.23141121612922, -7.803612880645117}, {33.987174742355506`, 
      36.268622348244456`, -7.2142775328880635`}, {33.987174742355506`, 
      36.66280476955236, -4.826749816470647}}], 
     Polygon3DBox[{{33.987174742355506`, 
      36.268622348244456`, -7.2142775328880635`}, {1.6902601750779826`*^-14, 
      39.23141121612922, -7.803612880645117}, {1.6902601750779826`*^-14, 
      38.63703305156273, -10.352761804100814`}, {33.987174742355506`, 
      35.71913211798117, -9.570912605353616}, {33.987174742355506`, 
      36.268622348244456`, -7.2142775328880635`}}], 
     Polygon3DBox[{{33.987174742355506`, 
      35.71913211798117, -9.570912605353616}, {1.6902601750779826`*^-14, 
      38.63703305156273, -10.352761804100814`}, {1.6902601750779826`*^-14, 
      37.87720517980423, -12.857578612126442`}, {33.98717474235546, 
      35.01668708028777, -11.88656356068981}, {33.987174742355506`, 
      35.71913211798117, -9.570912605353616}}], 
     Polygon3DBox[{{33.98717474235546, 
      35.01668708028777, -11.88656356068981}, {1.6902601750779826`*^-14, 
      37.87720517980423, -12.857578612126442`}, {1.6902601750779826`*^-14, 
      36.95518130045148, -15.307337294603569`}, {33.98717474235546, 
      34.16429521265697, -14.151314426000694`}, {33.98717474235546, 
      35.01668708028777, -11.88656356068981}}], 
     Polygon3DBox[{{33.98717474235546, 
      34.16429521265697, -14.151314426000694`}, {1.6902601750779826`*^-14, 
      36.95518130045148, -15.307337294603569`}, {1.6902601750779826`*^-14, 
      35.87490966130754, -17.69154760876003}, {33.987174742355506`, 
      33.16560658792754, -16.35546719039013}, {33.98717474235546, 
      34.16429521265697, -14.151314426000694`}}], 
     Polygon3DBox[{{33.987174742355506`, 
      33.165606587927535`, -16.355467190390144`}, {1.6902601750779826`*^-14, 
      35.874909661307534`, -17.69154760876004}, {1.6902601750779826`*^-14, 
      34.641016151377556`, -19.99999999999999}, {33.98717474235546, 
      32.02489774411206, -18.48958333333332}, {33.987174742355506`, 
      33.165606587927535`, -16.355467190390144`}}], 
     Polygon3DBox[{{33.98717474235546, 
      32.02489774411206, -18.48958333333332}, {1.6902601750779826`*^-14, 
      34.641016151377556`, -19.99999999999999}, {1.6902601750779826`*^-14, 
      33.25878449210182, -22.222809320784076`}, {33.98717474235546, 
      30.747053371604544`, -20.544524241870693`}, {33.98717474235546, 
      32.02489774411206, -18.48958333333332}}], 
     Polygon3DBox[{{33.98717474235546, 
      30.747053371604544`, -20.544524241870693`}, {1.6902601750779826`*^-14, 
      33.25878449210182, -22.222809320784076`}, {1.6902601750779826`*^-14, 
      31.734133611649415`, -24.350457160348814`}, {33.98717474235546, 
      29.337545396186307`, -22.511490343551635`}, {33.98717474235546, 
      30.747053371604544`, -20.544524241870693`}}], 
     Polygon3DBox[{{33.98717474235546, 
      29.337545396186307`, -22.511490343551635`}, {1.6902601750779826`*^-14, 
      31.734133611649415`, -24.350457160348814`}, {1.6902601750779826`*^-14, 
      30.07359229915911, -26.37383260400274}, {33.987174742355364`, 
      27.802409547399698`, -24.382058787554616`}, {33.98717474235546, 
      29.337545396186307`, -22.511490343551635`}}], 
     Polygon3DBox[{{33.987174742355364`, 
      27.802409547399698`, -24.382058787554616`}, {1.6902601750779826`*^-14, 
      30.07359229915911, -26.37383260400274}, {1.6902601750779826`*^-14, 
      28.284271247461916`, -28.284271247461888`}, {33.987174742355364`, 
      26.148219512627552`, -26.148219512627527`}, {33.987174742355364`, 
      27.802409547399698`, -24.382058787554616`}}], 
     Polygon3DBox[{{33.987174742355364`, 
      26.148219512627552`, -26.148219512627527`}, {1.6902601750779826`*^-14, 
      28.284271247461916`, -28.284271247461888`}, {1.6902601750779826`*^-14, 
      26.373832604002775`, -30.073592299159078`}, {33.98717474235546, 
      24.382058787554648`, -27.802409547399666`}, {33.987174742355364`, 
      26.148219512627552`, -26.148219512627527`}}], 
     Polygon3DBox[{{33.987174742355364`, 
      24.382058787554637`, -27.80240954739968}, {-8.25733812556342*^-14, 
      26.373832604002764`, -30.073592299159092`}, {1.6902601750779826`*^-14, 
      24.350457160348835`, -31.734133611649398`}, {33.98717474235546, 
      22.511490343551657`, -29.33754539618629}, {33.987174742355364`, 
      24.382058787554637`, -27.80240954739968}}], 
     Polygon3DBox[{{33.98717474235546, 
      22.511490343551657`, -29.33754539618629}, {1.6902601750779826`*^-14, 
      24.350457160348835`, -31.734133611649398`}, {1.6902601750779826`*^-14, 
      22.222809320784087`, -33.25878449210181}, {33.98717474235546, 
      20.544524241870704`, -30.747053371604537`}, {33.98717474235546, 
      22.511490343551657`, -29.33754539618629}}], 
     Polygon3DBox[{{33.987174742355364`, 
      20.544524241870732`, -30.747053371604522`}, {1.6902601750779826`*^-14, 
      22.222809320784116`, -33.25878449210179}, {1.6902601750779826`*^-14, 
      20.00000000000002, -34.641016151377535`}, {33.98717474235546, 
      18.48958333333335, -32.02489774411204}, {33.987174742355364`, 
      20.544524241870732`, -30.747053371604522`}}], 
     Polygon3DBox[{{33.98717474235546, 
      18.48958333333335, -32.02489774411204}, {1.6902601750779826`*^-14, 
      20.00000000000002, -34.641016151377535`}, {1.6902601750779826`*^-14, 
      17.691547608760054`, -35.87490966130753}, {33.98717474235546, 
      16.35546719039015, -33.165606587927535`}, {33.98717474235546, 
      18.48958333333335, -32.02489774411204}}], 
     Polygon3DBox[{{33.98717474235546, 
      16.35546719039015, -33.165606587927535`}, {1.6902601750779826`*^-14, 
      17.691547608760054`, -35.87490966130753}, {8.085144796918884*^-14, 
      15.30733729460358, -36.95518130045147}, {33.98717474235546, 
      14.151314426000704`, -34.16429521265696}, {33.98717474235546, 
      16.35546719039015, -33.165606587927535`}}], 
     Polygon3DBox[{{33.987174742355364`, 
      14.151314426000736`, -34.16429521265695}, {1.6902601750779826`*^-14, 
      15.307337294603613`, -36.955181300451464`}, {1.6902601750779826`*^-14, 
      12.857578612126472`, -37.87720517980422}, {33.987174742355506`, 
      11.886563560689837`, -35.01668708028775}, {33.987174742355364`, 
      14.151314426000736`, -34.16429521265695}}], 
     Polygon3DBox[{{33.987174742355506`, 
      11.886563560689837`, -35.01668708028775}, {1.6902601750779826`*^-14, 
      12.857578612126472`, -37.87720517980422}, {1.6902601750779826`*^-14, 
      10.352761804100826`, -38.63703305156273}, {33.987174742355506`, 
      9.570912605353628, -35.71913211798117}, {33.987174742355506`, 
      11.886563560689837`, -35.01668708028775}}], 
     Polygon3DBox[{{33.98717474235546, 
      9.570912605353659, -35.71913211798116}, {1.6902601750779826`*^-14, 
      10.352761804100862`, -38.637033051562724`}, {1.6902601750779826`*^-14, 
      7.803612880645146, -39.23141121612921}, {33.987174742355506`, 
      7.214277532888091, -36.26862234824445}, {33.98717474235546, 
      9.570912605353659, -35.71913211798116}}], 
     Polygon3DBox[{{33.987174742355506`, 
      7.214277532888091, -36.26862234824445}, {1.6902601750779826`*^-14, 
      7.803612880645146, -39.23141121612921}, {1.6902601750779826`*^-14, 
      5.221047688802066, -39.657794454952416`}, {33.987174742355506`, 
      4.8267498164706595`, -36.66280476955236}, {33.987174742355506`, 
      7.214277532888091, -36.26862234824445}}], 
     Polygon3DBox[{{33.98717474235546, 
      4.826749816470691, -36.66280476955236}, {1.6902601750779826`*^-14, 
      5.221047688802099, -39.65779445495241}, {1.6902601750779826`*^-14, 
      2.616125169205745, -39.91435692954414}, {33.98717474235546, 
      2.4185532163230192`, -36.899991432260855`}, {33.98717474235546, 
      4.826749816470691, -36.66280476955236}}], 
     Polygon3DBox[{{33.98717474235546, 
      2.4185532163230192`, -36.899991432260855`}, {1.6902601750779826`*^-14, 
      2.616125169205745, -39.91435692954414}, {1.6902601750779826`*^-14, 
      7.347880794884118*^-15, -40.}, {33.98717474235546, 
      6.792962714020474*^-15, -36.979166666666664`}, {33.98717474235546, 
      2.4185532163230192`, -36.899991432260855`}}], 
     Polygon3DBox[{{33.98717474235546, 
      6.792962714020474*^-15, -36.979166666666664`}, {
      1.6902601750779826`*^-14, 7.347880794884118*^-15, -40.}, {
      1.6902601750779826`*^-14, -2.61612516920573, -39.91435692954414}, {
      33.98717474235546, -2.4185532163230055`, -36.899991432260855`}, {
      33.98717474235546, 6.792962714020474*^-15, -36.979166666666664`}}], 
     Polygon3DBox[{{
      33.987174742355506`, -2.4185532163229726`, -36.899991432260855`}, {
      1.6902601750779826`*^-14, -2.6161251692056946`, -39.91435692954414}, {
      1.6902601750779826`*^-14, -5.2210476888020505`, -39.657794454952416`}, {
      33.987174742355506`, -4.826749816470645, -36.66280476955236}, {
      33.987174742355506`, -2.4185532163229726`, -36.899991432260855`}}], 
     Polygon3DBox[{{
      33.987174742355506`, -4.826749816470645, -36.66280476955236}, {
      1.6902601750779826`*^-14, -5.2210476888020505`, -39.657794454952416`}, {
      1.6902601750779826`*^-14, -7.803612880645132, -39.23141121612922}, {
      33.98717474235546, -7.214277532888078, -36.268622348244456`}, {
      33.987174742355506`, -4.826749816470645, -36.66280476955236}}], 
     Polygon3DBox[{{
      33.98717474235546, -7.214277532888045, -36.26862234824446}, {
      1.6902601750779826`*^-14, -7.803612880645097, -39.231411216129224`}, {
      1.6902601750779826`*^-14, -10.352761804100812`, -38.63703305156273}, {
      33.987174742355506`, -9.570912605353614, -35.71913211798117}, {
      33.98717474235546, -7.214277532888045, -36.26862234824446}}], 
     Polygon3DBox[{{
      33.987174742355506`, -9.570912605353614, -35.71913211798117}, {
      1.6902601750779826`*^-14, -10.352761804100812`, -38.63703305156273}, {
      1.6902601750779826`*^-14, -12.857578612126458`, -37.87720517980423}, {
      33.987174742355364`, -11.886563560689824`, -35.01668708028777}, {
      33.987174742355506`, -9.570912605353614, -35.71913211798117}}], 
     Polygon3DBox[{{
      33.987174742355364`, -11.886563560689824`, -35.01668708028777}, {
      1.6902601750779826`*^-14, -12.857578612126458`, -37.87720517980423}, {
      1.6902601750779826`*^-14, -15.3073372946036, -36.955181300451464`}, {
      33.98717474235546, -14.151314426000724`, -34.16429521265695}, {
      33.987174742355364`, -11.886563560689824`, -35.01668708028777}}], 
     Polygon3DBox[{{
      33.98717474235546, -14.151314426000694`, -34.16429521265697}, {
      1.6902601750779826`*^-14, -15.307337294603567`, -36.95518130045148}, {
      1.6902601750779826`*^-14, -17.69154760876004, -35.874909661307534`}, {
      33.987174742355506`, -16.355467190390144`, -33.165606587927535`}, {
      33.98717474235546, -14.151314426000694`, -34.16429521265697}}], 
     Polygon3DBox[{{
      33.987174742355506`, -16.355467190390144`, -33.165606587927535`}, {
      1.6902601750779826`*^-14, -17.69154760876004, -35.874909661307534`}, {
      1.6902601750779826`*^-14, -20.000000000000004`, -34.64101615137754}, {
      33.98717474235546, -18.489583333333336`, -32.02489774411205}, {
      33.987174742355506`, -16.355467190390144`, -33.165606587927535`}}], 
     Polygon3DBox[{{
      33.98717474235546, -18.489583333333307`, -32.02489774411207}, {
      1.6902601750779826`*^-14, -19.99999999999997, -34.64101615137756}, {
      1.6902601750779826`*^-14, -22.222809320784073`, -33.25878449210182}, {
      33.98717474235546, -20.544524241870693`, -30.747053371604544`}, {
      33.98717474235546, -18.489583333333307`, -32.02489774411207}}], 
     Polygon3DBox[{{
      33.98717474235546, -20.544524241870693`, -30.747053371604544`}, {
      1.6902601750779826`*^-14, -22.222809320784073`, -33.25878449210182}, {
      8.085144796918884*^-14, -24.35045716034882, -31.734133611649405`}, {
      33.987174742355506`, -22.511490343551642`, -29.337545396186297`}, {
      33.98717474235546, -20.544524241870693`, -30.747053371604544`}}], 
     Polygon3DBox[{{
      33.98717474235546, -22.51149034355162, -29.33754539618632}, {
      1.6902601750779826`*^-14, -24.350457160348796`, -31.73413361164943}, {
      1.6902601750779826`*^-14, -26.373832604002736`, -30.073592299159113`}, {
      33.987174742355364`, -24.382058787554612`, -27.8024095473997}, {
      33.98717474235546, -22.51149034355162, -29.33754539618632}}], 
     Polygon3DBox[{{
      33.987174742355364`, -24.382058787554612`, -27.8024095473997}, {
      1.6902601750779826`*^-14, -26.373832604002736`, -30.073592299159113`}, {
      1.6902601750779826`*^-14, -28.284271247461895`, -28.284271247461906`}, {
      33.98717474235546, -26.14821951262753, -26.14821951262754}, {
      33.987174742355364`, -24.382058787554612`, -27.8024095473997}}], 
     Polygon3DBox[{{
      33.98717474235546, -26.14821951262753, -26.14821951262754}, {
      1.6902601750779826`*^-14, -28.284271247461895`, -28.284271247461906`}, {
      8.085144796918884*^-14, -30.0735922991591, -26.373832604002747`}, {
      33.98717474235546, -27.802409547399687`, -24.382058787554623`}, {
      33.98717474235546, -26.14821951262753, -26.14821951262754}}], 
     Polygon3DBox[{{
      33.98717474235546, -27.802409547399666`, -24.382058787554648`}, {
      1.6902601750779826`*^-14, -30.073592299159078`, -26.373832604002775`}, {
      1.6902601750779826`*^-14, -31.734133611649398`, -24.350457160348835`}, {
      33.98717474235546, -29.33754539618629, -22.511490343551657`}, {
      33.98717474235546, -27.802409547399666`, -24.382058787554648`}}], 
     Polygon3DBox[{{
      33.98717474235546, -29.33754539618629, -22.511490343551657`}, {
      1.6902601750779826`*^-14, -31.734133611649398`, -24.350457160348835`}, {
      1.6902601750779826`*^-14, -33.25878449210181, -22.222809320784087`}, {
      33.98717474235546, -30.747053371604537`, -20.544524241870704`}, {
      33.98717474235546, -29.33754539618629, -22.511490343551657`}}], 
     Polygon3DBox[{{
      33.987174742355364`, -30.747053371604522`, -20.544524241870732`}, {
      1.6902601750779826`*^-14, -33.25878449210179, -22.222809320784116`}, {
      1.6902601750779826`*^-14, -34.641016151377535`, -20.00000000000002}, {
      33.98717474235546, -32.02489774411204, -18.48958333333335}, {
      33.987174742355364`, -30.747053371604522`, -20.544524241870732`}}], 
     Polygon3DBox[{{
      33.98717474235546, -32.02489774411204, -18.48958333333335}, {
      1.6902601750779826`*^-14, -34.641016151377535`, -20.00000000000002}, {
      1.6902601750779826`*^-14, -35.87490966130753, -17.691547608760057`}, {
      33.98717474235546, -33.165606587927535`, -16.355467190390154`}, {
      33.98717474235546, -32.02489774411204, -18.48958333333335}}], 
     Polygon3DBox[{{
      33.98717474235546, -33.16560658792752, -16.355467190390186`}, {
      1.6902601750779826`*^-14, -35.87490966130751, -17.69154760876009}, \
{-8.25733812556342*^-14, -36.955181300451464`, -15.307337294603617`}, {
      33.987174742355364`, -34.16429521265695, -14.151314426000738`}, {
      33.98717474235546, -33.16560658792752, -16.355467190390186`}}], 
     Polygon3DBox[{{
      33.987174742355364`, -34.16429521265695, -14.151314426000738`}, \
{-8.25733812556342*^-14, -36.955181300451464`, -15.307337294603617`}, {
      1.6902601750779826`*^-14, -37.87720517980422, -12.857578612126474`}, {
      33.987174742355506`, -35.01668708028775, -11.886563560689838`}, {
      33.987174742355364`, -34.16429521265695, -14.151314426000738`}}], 
     Polygon3DBox[{{
      33.987174742355506`, -35.01668708028775, -11.886563560689838`}, {
      1.6902601750779826`*^-14, -37.87720517980422, -12.857578612126474`}, {
      1.6902601750779826`*^-14, -38.63703305156273, -10.352761804100828`}, {
      33.98717474235546, -35.71913211798117, -9.57091260535363}, {
      33.987174742355506`, -35.01668708028775, -11.886563560689838`}}], 
     Polygon3DBox[{{
      33.98717474235546, -35.71913211798116, -9.570912605353662}, {
      1.6902601750779826`*^-14, -38.637033051562724`, -10.352761804100863`}, {
      1.6902601750779826`*^-14, -39.23141121612921, -7.803612880645149}, {
      33.987174742355506`, -36.26862234824445, -7.214277532888093}, {
      33.98717474235546, -35.71913211798116, -9.570912605353662}}], 
     Polygon3DBox[{{
      33.987174742355506`, -36.26862234824445, -7.214277532888093}, {
      1.6902601750779826`*^-14, -39.23141121612921, -7.803612880645149}, {
      1.6902601750779826`*^-14, -39.657794454952416`, -5.221047688802067}, {
      33.987174742355506`, -36.66280476955236, -4.826749816470661}, {
      33.987174742355506`, -36.26862234824445, -7.214277532888093}}], 
     Polygon3DBox[{{
      33.98717474235546, -36.66280476955236, -4.826749816470694}, {
      1.6902601750779826`*^-14, -39.65779445495241, -5.221047688802103}, {
      1.6902601750779826`*^-14, -39.91435692954414, -2.6161251692057466`}, {
      33.98717474235546, -36.899991432260855`, -2.418553216323021}, {
      33.98717474235546, -36.66280476955236, -4.826749816470694}}], 
     Polygon3DBox[{{
      33.98717474235546, -36.899991432260855`, -2.418553216323021}, {
      1.6902601750779826`*^-14, -39.91435692954414, -2.6161251692057466`}, {
      1.6902601750779826`*^-14, -40., -9.797174393178826*^-15}, {
      33.98717474235546, -36.979166666666664`, -9.057283618693966*^-15}, {
      33.98717474235546, -36.899991432260855`, -2.418553216323021}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxdlV1Ik2EUx8csW6lzOsiggjQXBd1EGBjWVoKf4MCgLrrKlLaSCuuiC4Ow
D7U1V5klCJKFF06lMGgF6vuguElUVkjd5ULdiAgpy0D7xOd/TuwM5IUfx+c9
H7/zvNlVpyprzCaT6ci/vyQT/bwu/bQqU8LP62r4GjnXMpemxsYC1warJ5zE
M+4NfSwfTlNFNz7XNx6YYj4b+1F5sjZN9aTcf7LdG3f+Wf55XLk7J+vci6mq
om/+2SfrHMfbDrcdrfWkqlbnCY+7dJ7j66qdmTWhFPViuLB+xcIC89ijosBS
fI3yRT2z/uZFPicaeZNvX1qtdNwv5s2h8+EHXyyqoMF+JRI0uYiXDXTlfHu+
SgVHOnpLC83Mt7TX5mW3JKv1xSOd4UgSc1tJ1oVbu1aqdP1kvkHHKYf+P+a9
+lxVqt/DfI/OQzXpvJibl5+/jSldh4vqDeg6jVldN/OXui8G+sTntOk+Gum6
r8wP6r4bm/UcmPfpORmYG3O3nquBOTP/oD0w4AXz4rXTE6O+h4PwiPkAvJHx
+fAmE+dTXXfhTUzkUwZvckX+1+ENPOJzxuHNGdGfZngDj5j/hDdR0f/d8MYn
5tUDb8rFfNfBm63CB/LGJvwhb+ARv7cE5/YLPxuRx17h83vknaw94n2ZQZ2t
qFvsl2sCfeI80cfb6Ctx8uYQ5kDnkDePMTeKJ2+qxP1AHljCifcJeaM9UgUy
PgjviJM3efCU7wfk0wmviTuQ/z7sAeeJen3YG+Jn0Z9R7Blx8qYJe8l7gf4v
aY/4veQNPFIUT97AI+bkDTxiboc3qbiH6PyN8AYecTx5U4x7jvh+eHMZ9yKd
Y4E38Ijj/fAG9w/zt/DmNO5p4nfgDTxi7oE3OfgOEA/Bmxl8N4hfgjc2fGeI
28IJ9wlzb9dkqPv1OLyxcl3H4M1FEb8D3sAjjvfDmzjyIe6ENw6R/014YxP1
jsAbeMTnkDdx0c/v8GZa9D8f3sAj5t3wpkLMl7zZJnywwpsMPInnIG6T8I28
6Rd+kjfwiOsib+DR/71AnR1iX8ibd2K/yJt2sY/kzXGxv+TNU8yNPcFcr2LO
xMmbrHDifULe6Pvn1eBf2uS+EQ==
       "]], Line3DBox[CompressedData["
1:eJxdlk1IlFEUhr8cU2cUhLKokEajFv2NaDKmqI1OlJVC6ca0HGdCapG2CIoM
rIUrLYoWpckkBi2KSiTTREevFSG2ULM/IwgzlNJpbOEPlpZ433PC88Ew8HC9
3vue55xvYj1nckuCDMNwL35Mi5/KtokvH0JXpxlLz15l4CH+sOHTPfOUU9mG
XGGD/mAHcXf3YF3CW6eqDD+QV/A1ivnP2rnhO16nuhJZeWjUbmVeev5qdtUR
p0rsmYn3Nm9mHn7jRGbWZKZa/yC5Oqp1K/PsmktuZ3mm6sgrOFzotTGv3RRn
mQ9kqOOOOqe5KZ75eFzSQERuhvq79OxiHrLl/pC1waHmgjaEWZLtzJ/5d9gm
2/eokfzya61HdzNPiBn99X5Vuuoryq944kphrixW41VWqurS38z79ToVr/+O
+Te9r2rR/4f5H30OtVKfi/mKpdQT1Q99D+YufU9Vo+/N3KdzUcjJ4bb9npnq
tqdF6xyVRefKPFnnrk7rOvA+13WdFOrGvErXVaHOzB3aAwUvmJvPDnU1Ro52
wCPmsfBGrr8IbzzYv34gOMySnuS7DG8C4jwJ8KZUnH8NvIFHzFvgDeVD/Bi8
qRV5LsCbcZH/LLwJFfUahjdtor6v4Y1d+EDeKOEPedMvfHuKfceEn+TNAs5F
uZE3wdojXk/eeES/UC6dor/Im43Ilfwhb1JE/5I3XtHv5M0tMR/Ig0IxT8gb
7dF0qlwfDe+IkzcX4CnlQN5UwGtaX4bzb0cfEI/AfSPRN8RzkE8j+kzMH0ch
+pL4BPKf1x4xJ2/gEXPyBh4xJ2/gEfOX8KYdc4ju+wbewCNeT940Y84RN5m0
NybMRfYK3nzHHCVeBG/gEfMeeHMQc5q4Fd7AI+b74A08Yl4Pb/x4bxB/BG+K
6T0DXrx8nvzff+1I34tqg99jxAMfl80r5ufgjUfsfxLeBMR5tsGbMnH+dfAm
XNz3MbzJEfkUwJvbIs9ZeOMX+U/Dm1BRr8/wxifq2wtvkoQPnfDmOb6J78S6
d8I38mZM+EnewCPm5A08Yn4T9zwl+oW86RX9Rd7EiH4kb/aL/iVv7op+J2+a
UGf5e6ZEzBPyRs+fEN8/1Oc43A==
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301537438695*^9, 3.6147093037195*^9, 
  3.614729159240803*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[240]:="]
}, Open  ]],

Cell[TextData[{
 "Here is a ",
 StyleBox["SurfacePoints", "Input"],
 " plot of the mirror using the default ",
 StyleBox["SurfacePoints", "Input"],
 " setting."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ 
    axiconMirrorWithRipples[80, 7.5, 200, 20., 4.,GraphicDesign->False],
    PlotPoints -> 60, SurfacePoints -> Mesh
    ];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[241]:="],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{166.95984415435382`, -6.666667666666666, 1.*^-6}],
    Point3DBox[{166.95984078753054`, -3.333334333333333, 5.773503691896257}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.95984078753054`, -3.333334333333333, 5.773503691896257}], 
   Point3DBox[{166.95984998586385`, 3.333332333333333, 5.773503691896257}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.95984998586385`, 3.333332333333333, 5.773503691896257}], 
   Point3DBox[{166.95986255102633`, 6.666665666666666, 1.*^-6}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.95986255102633`, 6.666665666666666, 1.*^-6}], 
   Point3DBox[{166.9598659178526, 3.333332333333333, -5.773501691896256}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.9598659178526, 3.333332333333333, -5.773501691896256}], 
   Point3DBox[{166.95985671951337`, -3.333334333333333, -5.773501691896256}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.95985671951337`, -3.333334333333333, -5.773501691896256}], 
   Point3DBox[{166.95984415435382`, -6.666667666666666, 1.*^-6}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{166.95984415435382`, -6.666667666666666, 1.*^-6}], 
   Point3DBox[{166.95984078753054`, -3.333334333333333, 5.773503691896257}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{150.71787738422992`, -6.666667666666666, 11.547006383792512`}],
    Point3DBox[{166.95984078753054`, -3.333334333333333, 5.773503691896257}], 
   Point3DBox[{166.95984078753054`, -3.333334333333333, 5.773503691896257}], 
   Point3DBox[{166.95984998586385`, 3.333332333333333, 5.773503691896257}], 
   Point3DBox[{150.71787738422992`, -6.666667666666666, 11.547006383792512`}],
    Point3DBox[{150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{166.95984998586385`, 3.333332333333333, 5.773503691896257}], 
   Point3DBox[{166.95984998586385`, 3.333332333333333, 5.773503691896257}], 
   Point3DBox[{166.95986255102633`, 6.666665666666666, 1.*^-6}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{166.95986255102633`, 6.666665666666666, 1.*^-6}], 
   Point3DBox[{166.95986255102633`, 6.666665666666666, 1.*^-6}], 
   Point3DBox[{166.9598659178526, 3.333332333333333, -5.773501691896256}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{150.71787382374248`, 6.666665666666666, -11.547004383792514`}],
    Point3DBox[{166.9598659178526, 3.333332333333333, -5.773501691896256}], 
   Point3DBox[{166.9598659178526, 3.333332333333333, -5.773501691896256}], 
   Point3DBox[{166.95985671951337`, -3.333334333333333, -5.773501691896256}], 
   Point3DBox[{150.71787382374248`, 6.666665666666666, -11.547004383792514`}],
    Point3DBox[{150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{166.95985671951337`, -3.333334333333333, -5.773501691896256}], 
   Point3DBox[{166.95985671951337`, -3.333334333333333, -5.773501691896256}], 
   Point3DBox[{166.95984415435382`, -6.666667666666666, 1.*^-6}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{166.95984415435382`, -6.666667666666666, 1.*^-6}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{150.71787738422992`, -6.666667666666666, 11.547006383792512`}],
    Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{150.71787738422992`, -6.666667666666666, 11.547006383792512`}],
    Point3DBox[{150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{150.71787608100152`, 6.666665666666666, 11.547006383792512`}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{150.7178743007576, 13.333332333333333`, 1.*^-6}], 
   Point3DBox[{150.71787382374248`, 6.666665666666666, -11.547004383792514`}],
    Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{150.71787382374248`, 6.666665666666666, -11.547004383792514`}],
    Point3DBox[{150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{150.71787690721527`, -13.333334333333331`, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{53.64465330663444, -13.333334333333331`, 23.094011767585027`}],
    Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{122.44829681368199`, -10.000001, 17.320509075688772`}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{53.64465330663444, -13.333334333333331`, 23.094011767585027`}],
    Point3DBox[{53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{122.44830785037269`, 9.999999, 17.320509075688772`}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{53.64466667235905, 13.333332333333333`, -23.094009767585025`}],
    Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{122.44832696647963`, 9.999999, -17.32050707568877}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{53.64466667235905, 13.333332333333333`, -23.094009767585025`}],
    Point3DBox[{53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{122.44831592979051`, -10.000001, -17.32050707568877}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{53.64465330663444, -13.333334333333331`, 23.094011767585027`}],
    Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{53.64465330663444, -13.333334333333331`, 23.094011767585027`}],
    Point3DBox[{53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{53.64465819882693, 13.333332333333333`, 23.094011767585027`}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{53.644664881690346`, 26.666665666666663`, 1.*^-6}], 
   Point3DBox[{53.64466667235905, 13.333332333333333`, -23.094009767585025`}],
    Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{53.64466667235905, 13.333332333333333`, -23.094009767585025`}],
    Point3DBox[{53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{53.64465509730084, -26.666667666666665`, 1.*^-6}], 
   Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000017007578179573102`, -20.000001, 34.64101715137754}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{51.547467866583446`, -16.66666766666667, 28.86751445948129}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{-0.000017007578179573102`, -20.000001, 34.64101715137754}], 
   Point3DBox[{-0.000017007578179573102`, -20.000001, 34.64101715137754}], 
   Point3DBox[{-4.557167102348103*^-6, 19.999999, 34.64101715137754}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{51.54746870754087, 16.666665666666667`, 28.86751445948129}], 
   Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{-4.557167102348103*^-6, 19.999999, 34.64101715137754}], 
   Point3DBox[{-4.557167102348103*^-6, 19.999999, 34.64101715137754}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{51.54746985630723, 33.33333233333334, 1.*^-6}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.000017007578179573102`, 19.999999, -34.641015151377545`}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{51.5474701641177, 16.666665666666667`, -28.867512459481286`}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{0.000017007578179573102`, 19.999999, -34.641015151377545`}], 
   Point3DBox[{0.000017007578179573102`, 19.999999, -34.641015151377545`}], 
   Point3DBox[{4.557166590757333*^-6, -20.000001, -34.641015151377545`}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{51.54746932316331, -16.66666766666667, -28.867512459481286`}], 
   Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{4.557166590757333*^-6, -20.000001, -34.641015151377545`}], 
   Point3DBox[{4.557166590757333*^-6, -20.000001, -34.641015151377545`}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{51.54746817439542, -33.33333433333333, 1.*^-6}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000017007578179573102`, -20.000001, 34.64101715137754}], 
   Point3DBox[{-179.97050922358653`, -52.500001, 30.310890132455352`}], 
   Point3DBox[{-0.000017007578179573102`, -20.000001, 34.64101715137754}], 
   Point3DBox[{-4.557167102348103*^-6, 19.999999, 34.64101715137754}], 
   Point3DBox[{-179.9705023169978, -1.*^-6, 60.6217792649107}], 
   Point3DBox[{-4.557167102348103*^-6, 19.999999, 34.64101715137754}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{-179.97047654125703`, 52.499999, 30.310890132455352`}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.000017007578179573102`, 19.999999, -34.641015151377545`}], 
   Point3DBox[{-179.97045767210489`, 52.499999, -30.31088813245535}], 
   Point3DBox[{0.000017007578179573102`, 19.999999, -34.641015151377545`}], 
   Point3DBox[{4.557166590757333*^-6, -20.000001, -34.641015151377545`}], 
   Point3DBox[{-179.97046457869402`, -1.*^-6, -60.621777264910705`}], 
   Point3DBox[{4.557166590757333*^-6, -20.000001, -34.641015151377545`}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-179.9704903544349, -52.500001, -30.31088813245535}], 
   Line3DBox[{{166.95984415435382`, -6.666667666666666, 1.*^-6}, {
    166.95984078753054`, -3.333334333333333, 5.773503691896257}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    166.95984415435382`, -6.666667666666666, 1.*^-6}}], 
   Line3DBox[{{166.95984078753054`, -3.333334333333333, 5.773503691896257}, {
    166.95984998586385`, 3.333332333333333, 5.773503691896257}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    166.95984078753054`, -3.333334333333333, 5.773503691896257}}], 
   Line3DBox[{{166.95984998586385`, 3.333332333333333, 5.773503691896257}, {
    166.95986255102633`, 6.666665666666666, 1.*^-6}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {166.95984998586385`, 
    3.333332333333333, 5.773503691896257}}], 
   Line3DBox[{{166.95986255102633`, 6.666665666666666, 1.*^-6}, {
    166.9598659178526, 3.333332333333333, -5.773501691896256}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {166.95986255102633`, 
    6.666665666666666, 1.*^-6}}], 
   Line3DBox[{{166.9598659178526, 3.333332333333333, -5.773501691896256}, {
    166.95985671951337`, -3.333334333333333, -5.773501691896256}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {166.9598659178526, 
    3.333332333333333, -5.773501691896256}}], 
   Line3DBox[{{166.95985671951337`, -3.333334333333333, -5.773501691896256}, {
    166.95984415435382`, -6.666667666666666, 1.*^-6}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    166.95985671951337`, -3.333334333333333, -5.773501691896256}}], 
   Line3DBox[{{166.95984415435382`, -6.666667666666666, 1.*^-6}, {
    166.95984078753054`, -3.333334333333333, 5.773503691896257}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    166.95984415435382`, -6.666667666666666, 1.*^-6}}], 
   Line3DBox[{{150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    150.71787738422992`, -6.666667666666666, 11.547006383792512`}, {
    166.95984078753054`, -3.333334333333333, 5.773503691896257}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}}], 
   Line3DBox[{{166.95984078753054`, -3.333334333333333, 5.773503691896257}, {
    166.95984998586385`, 3.333332333333333, 5.773503691896257}, {
    150.71787738422992`, -6.666667666666666, 11.547006383792512`}, {
    166.95984078753054`, -3.333334333333333, 5.773503691896257}}], 
   Line3DBox[{{150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}, {150.71787608100152`, 6.666665666666666, 
    11.547006383792512`}, {166.95984998586385`, 3.333332333333333, 
    5.773503691896257}, {150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}}], 
   Line3DBox[{{166.95984998586385`, 3.333332333333333, 5.773503691896257}, {
    166.95986255102633`, 6.666665666666666, 1.*^-6}, {150.71787608100152`, 
    6.666665666666666, 11.547006383792512`}, {166.95984998586385`, 
    3.333332333333333, 5.773503691896257}}], 
   Line3DBox[{{150.71787608100152`, 6.666665666666666, 11.547006383792512`}, {
    150.7178743007576, 13.333332333333333`, 1.*^-6}, {166.95986255102633`, 
    6.666665666666666, 1.*^-6}, {150.71787608100152`, 6.666665666666666, 
    11.547006383792512`}}], 
   Line3DBox[{{166.95986255102633`, 6.666665666666666, 1.*^-6}, {
    166.9598659178526, 3.333332333333333, -5.773501691896256}, {
    150.7178743007576, 13.333332333333333`, 1.*^-6}, {166.95986255102633`, 
    6.666665666666666, 1.*^-6}}], 
   Line3DBox[{{150.7178743007576, 13.333332333333333`, 1.*^-6}, {
    150.71787382374248`, 6.666665666666666, -11.547004383792514`}, {
    166.9598659178526, 3.333332333333333, -5.773501691896256}, {
    150.7178743007576, 13.333332333333333`, 1.*^-6}}], 
   Line3DBox[{{166.9598659178526, 3.333332333333333, -5.773501691896256}, {
    166.95985671951337`, -3.333334333333333, -5.773501691896256}, {
    150.71787382374248`, 6.666665666666666, -11.547004383792514`}, {
    166.9598659178526, 3.333332333333333, -5.773501691896256}}], 
   Line3DBox[{{150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    166.95985671951337`, -3.333334333333333, -5.773501691896256}, {
    150.71787382374248`, 6.666665666666666, -11.547004383792514`}}], 
   Line3DBox[{{166.95985671951337`, -3.333334333333333, -5.773501691896256}, {
    166.95984415435382`, -6.666667666666666, 1.*^-6}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    166.95985671951337`, -3.333334333333333, -5.773501691896256}}], 
   Line3DBox[{{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    166.95984415435382`, -6.666667666666666, 1.*^-6}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}}], 
   Line3DBox[{{150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    150.71787738422992`, -6.666667666666666, 11.547006383792512`}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}}], 
   Line3DBox[{{122.44830085339125`, -20.000001, 1.*^-6}, {
    122.44829681368199`, -10.000001, 17.320509075688772`}, {
    150.71787738422992`, -6.666667666666666, 11.547006383792512`}, {
    122.44830085339125`, -20.000001, 1.*^-6}}], 
   Line3DBox[{{150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}, {150.71787608100152`, 6.666665666666666, 
    11.547006383792512`}, {122.44829681368199`, -10.000001, 
    17.320509075688772`}, {150.71787738422992`, -6.666667666666666, 
    11.547006383792512`}}], 
   Line3DBox[{{122.44829681368199`, -10.000001, 17.320509075688772`}, {
    122.44830785037269`, 9.999999, 17.320509075688772`}, {150.71787608100152`,
     6.666665666666666, 11.547006383792512`}, {
    122.44829681368199`, -10.000001, 17.320509075688772`}}], 
   Line3DBox[{{150.71787608100152`, 6.666665666666666, 11.547006383792512`}, {
    150.7178743007576, 13.333332333333333`, 1.*^-6}, {122.44830785037269`, 
    9.999999, 17.320509075688772`}, {150.71787608100152`, 6.666665666666666, 
    11.547006383792512`}}], 
   Line3DBox[{{122.44830785037269`, 9.999999, 17.320509075688772`}, {
    122.44832292677113`, 19.999999, 1.*^-6}, {150.7178743007576, 
    13.333332333333333`, 1.*^-6}, {122.44830785037269`, 9.999999, 
    17.320509075688772`}}], 
   Line3DBox[{{150.7178743007576, 13.333332333333333`, 1.*^-6}, {
    150.71787382374248`, 6.666665666666666, -11.547004383792514`}, {
    122.44832292677113`, 19.999999, 1.*^-6}, {150.7178743007576, 
    13.333332333333333`, 1.*^-6}}], 
   Line3DBox[{{122.44832292677113`, 19.999999, 1.*^-6}, {122.44832696647963`, 
    9.999999, -17.32050707568877}, {150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}, {122.44832292677113`, 19.999999,
     1.*^-6}}], 
   Line3DBox[{{150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    122.44832696647963`, 9.999999, -17.32050707568877}, {150.71787382374248`, 
    6.666665666666666, -11.547004383792514`}}], 
   Line3DBox[{{122.44832696647963`, 9.999999, -17.32050707568877}, {
    122.44831592979051`, -10.000001, -17.32050707568877}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    122.44832696647963`, 9.999999, -17.32050707568877}}], 
   Line3DBox[{{
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    122.44831592979051`, -10.000001, -17.32050707568877}, {
    150.71787512697182`, -6.666667666666666, -11.547004383792514`}}], 
   Line3DBox[{{122.44831592979051`, -10.000001, -17.32050707568877}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {
    150.71787690721527`, -13.333334333333331`, 1.*^-6}, {
    122.44831592979051`, -10.000001, -17.32050707568877}}], 
   Line3DBox[{{122.44830085339125`, -20.000001, 1.*^-6}, {
    122.44829681368199`, -10.000001, 17.320509075688772`}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    122.44830085339125`, -20.000001, 1.*^-6}}], 
   Line3DBox[{{53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    53.64465330663444, -13.333334333333331`, 23.094011767585027`}, {
    122.44829681368199`, -10.000001, 17.320509075688772`}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{122.44829681368199`, -10.000001, 17.320509075688772`}, {
    122.44830785037269`, 9.999999, 17.320509075688772`}, {
    53.64465330663444, -13.333334333333331`, 23.094011767585027`}, {
    122.44829681368199`, -10.000001, 17.320509075688772`}}], 
   Line3DBox[{{53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}, {53.64465819882693, 13.333332333333333`, 
    23.094011767585027`}, {122.44830785037269`, 9.999999, 
    17.320509075688772`}, {53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}}], 
   Line3DBox[{{122.44830785037269`, 9.999999, 17.320509075688772`}, {
    122.44832292677113`, 19.999999, 1.*^-6}, {53.64465819882693, 
    13.333332333333333`, 23.094011767585027`}, {122.44830785037269`, 9.999999,
     17.320509075688772`}}], 
   Line3DBox[{{53.64465819882693, 13.333332333333333`, 23.094011767585027`}, {
    53.644664881690346`, 26.666665666666663`, 1.*^-6}, {122.44832292677113`, 
    19.999999, 1.*^-6}, {53.64465819882693, 13.333332333333333`, 
    23.094011767585027`}}], 
   Line3DBox[{{122.44832292677113`, 19.999999, 1.*^-6}, {122.44832696647963`, 
    9.999999, -17.32050707568877}, {53.644664881690346`, 26.666665666666663`, 
    1.*^-6}, {122.44832292677113`, 19.999999, 1.*^-6}}], 
   Line3DBox[{{53.644664881690346`, 26.666665666666663`, 1.*^-6}, {
    53.64466667235905, 13.333332333333333`, -23.094009767585025`}, {
    122.44832696647963`, 9.999999, -17.32050707568877}, {53.644664881690346`, 
    26.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{122.44832696647963`, 9.999999, -17.32050707568877}, {
    122.44831592979051`, -10.000001, -17.32050707568877}, {53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}, {122.44832696647963`, 
    9.999999, -17.32050707568877}}], 
   Line3DBox[{{53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    122.44831592979051`, -10.000001, -17.32050707568877}, {53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}}], 
   Line3DBox[{{122.44831592979051`, -10.000001, -17.32050707568877}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    122.44831592979051`, -10.000001, -17.32050707568877}}], 
   Line3DBox[{{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}}], 
   Line3DBox[{{53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    53.64465330663444, -13.333334333333331`, 23.094011767585027`}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}}], 
   Line3DBox[{{51.54746817439542, -33.33333433333333, 1.*^-6}, {
    51.547467866583446`, -16.66666766666667, 28.86751445948129}, {
    53.64465330663444, -13.333334333333331`, 23.094011767585027`}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}}], 
   Line3DBox[{{53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}, {53.64465819882693, 13.333332333333333`, 
    23.094011767585027`}, {51.547467866583446`, -16.66666766666667, 
    28.86751445948129}, {53.64465330663444, -13.333334333333331`, 
    23.094011767585027`}}], 
   Line3DBox[{{51.547467866583446`, -16.66666766666667, 28.86751445948129}, {
    51.54746870754087, 16.666665666666667`, 28.86751445948129}, {
    53.64465819882693, 13.333332333333333`, 23.094011767585027`}, {
    51.547467866583446`, -16.66666766666667, 28.86751445948129}}], 
   Line3DBox[{{53.64465819882693, 13.333332333333333`, 23.094011767585027`}, {
    53.644664881690346`, 26.666665666666663`, 1.*^-6}, {51.54746870754087, 
    16.666665666666667`, 28.86751445948129}, {53.64465819882693, 
    13.333332333333333`, 23.094011767585027`}}], 
   Line3DBox[{{51.54746870754087, 16.666665666666667`, 28.86751445948129}, {
    51.54746985630723, 33.33333233333334, 1.*^-6}, {53.644664881690346`, 
    26.666665666666663`, 1.*^-6}, {51.54746870754087, 16.666665666666667`, 
    28.86751445948129}}], 
   Line3DBox[{{53.644664881690346`, 26.666665666666663`, 1.*^-6}, {
    53.64466667235905, 13.333332333333333`, -23.094009767585025`}, {
    51.54746985630723, 33.33333233333334, 1.*^-6}, {53.644664881690346`, 
    26.666665666666663`, 1.*^-6}}], 
   Line3DBox[{{51.54746985630723, 33.33333233333334, 1.*^-6}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    53.64466667235905, 13.333332333333333`, -23.094009767585025`}, {
    51.54746985630723, 33.33333233333334, 1.*^-6}}], 
   Line3DBox[{{53.64466667235905, 
    13.333332333333333`, -23.094009767585025`}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    53.64466667235905, 13.333332333333333`, -23.094009767585025`}}], 
   Line3DBox[{{51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}}], 
   Line3DBox[{{
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    53.64466178016207, -13.333334333333331`, -23.094009767585025`}}], 
   Line3DBox[{{51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}, {
    53.64465509730084, -26.666667666666665`, 1.*^-6}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}}], 
   Line3DBox[{{51.54746817439542, -33.33333433333333, 1.*^-6}, {
    51.547467866583446`, -16.66666766666667, 
    28.86751445948129}, {-0.000012450411418285512`, -40.000001, 1.*^-6}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}}], 
   Line3DBox[{{-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-0.000017007578179573102`, -20.000001, 34.64101715137754}, {
    51.547467866583446`, -16.66666766666667, 
    28.86751445948129}, {-0.000012450411418285512`, -40.000001, 1.*^-6}}], 
   Line3DBox[{{51.547467866583446`, -16.66666766666667, 28.86751445948129}, {
    51.54746870754087, 16.666665666666667`, 
    28.86751445948129}, {-0.000017007578179573102`, -20.000001, 
    34.64101715137754}, {51.547467866583446`, -16.66666766666667, 
    28.86751445948129}}], 
   Line3DBox[{{-0.000017007578179573102`, -20.000001, 
    34.64101715137754}, {-4.557167102348103*^-6, 19.999999, 
    34.64101715137754}, {51.54746870754087, 16.666665666666667`, 
    28.86751445948129}, {-0.000017007578179573102`, -20.000001, 
    34.64101715137754}}], 
   Line3DBox[{{51.54746870754087, 16.666665666666667`, 28.86751445948129}, {
    51.54746985630723, 33.33333233333334, 1.*^-6}, {-4.557167102348103*^-6, 
    19.999999, 34.64101715137754}, {51.54746870754087, 16.666665666666667`, 
    28.86751445948129}}], 
   Line3DBox[{{-4.557167102348103*^-6, 19.999999, 34.64101715137754}, {
    0.000012450411276176965`, 39.999999, 1.*^-6}, {51.54746985630723, 
    33.33333233333334, 1.*^-6}, {-4.557167102348103*^-6, 19.999999, 
    34.64101715137754}}], 
   Line3DBox[{{51.54746985630723, 33.33333233333334, 1.*^-6}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    0.000012450411276176965`, 39.999999, 1.*^-6}, {51.54746985630723, 
    33.33333233333334, 1.*^-6}}], 
   Line3DBox[{{0.000012450411276176965`, 39.999999, 1.*^-6}, {
    0.000017007578179573102`, 19.999999, -34.641015151377545`}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    0.000012450411276176965`, 39.999999, 1.*^-6}}], 
   Line3DBox[{{51.5474701641177, 16.666665666666667`, -28.867512459481286`}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    0.000017007578179573102`, 19.999999, -34.641015151377545`}, {
    51.5474701641177, 16.666665666666667`, -28.867512459481286`}}], 
   Line3DBox[{{0.000017007578179573102`, 19.999999, -34.641015151377545`}, {
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    0.000017007578179573102`, 19.999999, -34.641015151377545`}}], 
   Line3DBox[{{51.54746932316331, -16.66666766666667, -28.867512459481286`}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}, {
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}, {
    51.54746932316331, -16.66666766666667, -28.867512459481286`}}], 
   Line3DBox[{{
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}, \
{-0.000012450411418285512`, -40.000001, 1.*^-6}, {
    51.54746817439542, -33.33333433333333, 1.*^-6}, {
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}}], 
   Line3DBox[{{-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-0.000017007578179573102`, -20.000001, 
    34.64101715137754}, {-179.97050922358653`, -52.500001, 
    30.310890132455352`}, {-0.000012450411418285512`, -40.000001, 1.*^-6}}], 
   Line3DBox[{{-0.000017007578179573102`, -20.000001, 
    34.64101715137754}, {-4.557167102348103*^-6, 19.999999, 
    34.64101715137754}, {-179.9705023169978, -1.*^-6, 
    60.6217792649107}, {-0.000017007578179573102`, -20.000001, 
    34.64101715137754}}], 
   Line3DBox[{{-4.557167102348103*^-6, 19.999999, 34.64101715137754}, {
    0.000012450411276176965`, 39.999999, 1.*^-6}, {-179.97047654125703`, 
    52.499999, 30.310890132455352`}, {-4.557167102348103*^-6, 19.999999, 
    34.64101715137754}}], 
   Line3DBox[{{0.000012450411276176965`, 39.999999, 1.*^-6}, {
    0.000017007578179573102`, 
    19.999999, -34.641015151377545`}, {-179.97045767210489`, 
    52.499999, -30.31088813245535}, {0.000012450411276176965`, 39.999999, 
    1.*^-6}}], 
   Line3DBox[{{0.000017007578179573102`, 19.999999, -34.641015151377545`}, {
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}, \
{-179.97046457869402`, -1.*^-6, -60.621777264910705`}, {
    0.000017007578179573102`, 19.999999, -34.641015151377545`}}], 
   Line3DBox[{{
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}, \
{-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-179.9704903544349, -52.500001, -30.31088813245535}, {
    4.557166590757333*^-6, -20.000001, -34.641015151377545`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301538078734*^9, 3.614709304281378*^9, 
  3.6147291598446083`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[241]:="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["SurfacePoints", "Input"],
 " plot has a better likeness to the actual surface function when we increase \
its value from 7 to 21."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[ 
    axiconMirrorWithRipples[80, 7.5, 200, 20., 4.,GraphicDesign->False, \
SurfacePoints -> 21],
    PlotPoints -> 60, SurfacePoints -> Mesh
    ];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[242]:="],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{221.05756881381186`, -2.000001, 1.*^-6}], 
   Point3DBox[{221.05756589754, -1.902114032590307, 0.6180349887498949}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05756589754, -1.902114032590307, 0.6180349887498949}], 
   Point3DBox[{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}], Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}],
    Point3DBox[{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}], 
   Point3DBox[{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}], Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}],
    Point3DBox[{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}], 
   Point3DBox[{221.05756589754, -0.6180349887498949, 1.902114032590307}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05756589754, -0.6180349887498949, 1.902114032590307}], 
   Point3DBox[{221.05756881381186`, -1.*^-6, 2.000001}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05756881381186`, -1.*^-6, 2.000001}], 
   Point3DBox[{221.05757282771617`, 0.6180329887498949, 1.902114032590307}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05757282771617`, 0.6180329887498949, 1.902114032590307}], 
   Point3DBox[{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}], 
   Point3DBox[{221.0575825078045, 1.618032988749895, 1.1755715045849462`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575825078045, 1.618032988749895, 1.1755715045849462`}], 
   Point3DBox[{221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}],
    Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}],
    Point3DBox[{221.05759124034108`, 1.999999, 1.*^-6}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05759124034108`, 1.999999, 1.*^-6}], 
   Point3DBox[{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}], 
   Point3DBox[{221.0575956897917, 1.618032988749895, -1.1755695045849464`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575956897917, 1.618032988749895, -1.1755695045849464`}], 
   Point3DBox[{221.0575956897917, 1.1755695045849464`, -1.618032988749895}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575956897917, 1.1755695045849464`, -1.618032988749895}], 
   Point3DBox[{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}], 
   Point3DBox[{221.05759124034108`, -1.*^-6, -1.999999}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05759124034108`, -1.*^-6, -1.999999}], 
   Point3DBox[{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}], 
   Point3DBox[{221.0575825078045, -1.1755715045849462`, -1.618032988749895}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.0575825078045, -1.1755715045849462`, -1.618032988749895}], 
   Point3DBox[{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}], 
   Point3DBox[{221.05757282771617`, -1.902114032590307, -0.6180329887498949}],
    Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05757282771617`, -1.902114032590307, -0.6180329887498949}],
    Point3DBox[{221.05756881381186`, -2.000001, 1.*^-6}], 
   Point3DBox[{239.96064459712753`, -1.*^-6, 1.*^-6}], 
   Point3DBox[{221.05756881381186`, -2.000001, 1.*^-6}], 
   Point3DBox[{221.05756589754, -1.902114032590307, 0.6180349887498949}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}],
    Point3DBox[{221.05756589754, -1.902114032590307, 0.6180349887498949}], 
   Point3DBox[{221.05756589754, -1.902114032590307, 0.6180349887498949}], 
   Point3DBox[{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}], 
   Point3DBox[{196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}],
    Point3DBox[{196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}], 
   Point3DBox[{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}], 
   Point3DBox[{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}], 
   Point3DBox[{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}], 
   Point3DBox[{221.05756589754, -0.6180349887498949, 1.902114032590307}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}],
    Point3DBox[{221.05756589754, -0.6180349887498949, 1.902114032590307}], 
   Point3DBox[{221.05756589754, -0.6180349887498949, 1.902114032590307}], 
   Point3DBox[{221.05756881381186`, -1.*^-6, 2.000001}], 
   Point3DBox[{196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}],
    Point3DBox[{196.8895504095156, -1.2360689774997897`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{221.05756881381186`, -1.*^-6, 2.000001}], 
   Point3DBox[{221.05756881381186`, -1.*^-6, 2.000001}], 
   Point3DBox[{221.05757282771617`, 0.6180329887498949, 1.902114032590307}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], 
   Point3DBox[{221.05757282771617`, 0.6180329887498949, 1.902114032590307}], 
   Point3DBox[{221.05757282771617`, 0.6180329887498949, 1.902114032590307}], 
   Point3DBox[{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}], 
   Point3DBox[{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}], 
   Point3DBox[{221.0575825078045, 1.618032988749895, 1.1755715045849462`}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}], 
   Point3DBox[{221.0575825078045, 1.618032988749895, 1.1755715045849462`}], 
   Point3DBox[{221.0575825078045, 1.618032988749895, 1.1755715045849462`}], 
   Point3DBox[{221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}],
    Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}],
    Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}],
    Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}],
    Point3DBox[{221.05758722643426`, 1.9021120325903071`, 
    0.6180349887498949}], 
   Point3DBox[{221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}],
    Point3DBox[{221.05759124034108`, 1.999999, 1.*^-6}], 
   Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}], 
   Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{221.05759124034108`, 1.999999, 1.*^-6}], 
   Point3DBox[{221.05759124034108`, 1.999999, 1.*^-6}], 
   Point3DBox[{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{196.88958172080754`, 3.804225065180614, -1.2360669774997899`}],
    Point3DBox[{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}],
    Point3DBox[{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}],
    Point3DBox[{221.0575956897917, 1.618032988749895, -1.1755695045849464`}], 
   Point3DBox[{196.88958172080754`, 3.804225065180614, -1.2360669774997899`}],
    Point3DBox[{196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}], 
   Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{221.0575956897917, 1.618032988749895, -1.1755695045849464`}], 
   Point3DBox[{221.0575956897917, 1.618032988749895, -1.1755695045849464`}], 
   Point3DBox[{221.0575956897917, 1.1755695045849464`, -1.618032988749895}], 
   Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{221.0575956897917, 1.1755695045849464`, -1.618032988749895}], 
   Point3DBox[{221.0575956897917, 1.1755695045849464`, -1.618032988749895}], 
   Point3DBox[{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}], 
   Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{196.88958172080754`, 1.2360669774997899`, -3.804225065180614}],
    Point3DBox[{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}],
    Point3DBox[{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}],
    Point3DBox[{221.05759124034108`, -1.*^-6, -1.999999}], 
   Point3DBox[{196.88958172080754`, 1.2360669774997899`, -3.804225065180614}],
    Point3DBox[{196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{221.05759124034108`, -1.*^-6, -1.999999}], 
   Point3DBox[{221.05759124034108`, -1.*^-6, -1.999999}], 
   Point3DBox[{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}], 
   Point3DBox[{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}], 
   Point3DBox[{221.0575825078045, -1.1755715045849462`, -1.618032988749895}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{221.0575825078045, -1.1755715045849462`, -1.618032988749895}], 
   Point3DBox[{221.0575825078045, -1.1755715045849462`, -1.618032988749895}], 
   Point3DBox[{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{196.88956331648936`, -3.23606897749979, -2.3511400091698924`}],
    Point3DBox[{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}], 
   Point3DBox[{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}], 
   Point3DBox[{221.05757282771617`, -1.902114032590307, -0.6180329887498949}],
    Point3DBox[{
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}], 
   Point3DBox[{196.88956331648936`, -3.23606897749979, -2.3511400091698924`}],
    Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{221.05757282771617`, -1.902114032590307, -0.6180329887498949}],
    Point3DBox[{
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}], 
   Point3DBox[{221.05756881381186`, -2.000001, 1.*^-6}], 
   Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{221.05756881381186`, -2.000001, 1.*^-6}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}],
    Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}],
    Point3DBox[{196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}], 
   Point3DBox[{196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}],
    Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}],
    Point3DBox[{196.8895504095156, -1.2360689774997897`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{196.88955364076963`, -1.*^-6, 4.000001}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}],
    Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}], 
   Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}], 
   Point3DBox[{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}], 
   Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}], 
   Point3DBox[{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{196.88957848955158`, 3.999999, 1.*^-6}], 
   Point3DBox[{196.88958172080754`, 3.804225065180614, -1.2360669774997899`}],
    Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{196.88958172080754`, 3.804225065180614, -1.2360669774997899`}],
    Point3DBox[{196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}], 
   Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{173.52089437633285`, 4.854100966249685, -3.5267105137548387`}],
    Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}], 
   Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{173.52089437633285`, 4.854100966249685, -3.5267105137548387`}],
    Point3DBox[{173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}], 
   Point3DBox[{173.52089437633285`, 3.5267105137548387`, -4.854100966249685}],
    Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}], 
   Point3DBox[{196.88958172080754`, 1.2360669774997899`, -3.804225065180614}],
    Point3DBox[{173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}], 
   Point3DBox[{173.52089437633285`, 3.5267105137548387`, -4.854100966249685}],
    Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{196.88958172080754`, 1.2360669774997899`, -3.804225065180614}],
    Point3DBox[{196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{196.88957848955158`, -1.*^-6, -3.999999}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}], 
   Point3DBox[{196.88956331648936`, -3.23606897749979, -2.3511400091698924`}],
    Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}],
    Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}],
    Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{196.88956331648936`, -3.23606897749979, -2.3511400091698924`}],
    Point3DBox[{
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}], 
   Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{196.88955364076963`, -4.000001, 1.*^-6}], 
   Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{156.64669907999547`, -7.608453130361228, 2.4721369549995797`}],
    Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{173.5208666220358, -5.706340097770921, 1.8541029662496846`}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{156.64669907999547`, -7.608453130361228, 2.4721369549995797`}],
    Point3DBox[{156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}], 
   Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{173.5208651937386, -4.854102966249685, 3.526712513754839}], 
   Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{173.5208651937386, -3.526712513754839, 4.854102966249685}], 
   Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{156.64669907999547`, -2.4721369549995797`, 7.608453130361228}],
    Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{173.5208666220358, -1.8541029662496846`, 5.706340097770921}], 
   Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}], 
   Point3DBox[{156.64669907999547`, -2.4721369549995797`, 7.608453130361228}],
    Point3DBox[{156.64669907999547`, -2.4721369549995797`, 
    7.608453130361228}], Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}], 
   Point3DBox[{173.5208693388187, -1.*^-6, 6.000001}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{173.520877473998, 3.5267105137548387`, 4.854102966249685}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{173.52088209606688`, 4.854100966249685, 3.526712513754839}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}], 
   Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{173.52089023124947`, 5.999999, 1.*^-6}], 
   Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{156.64671468509638`, 7.608451130361228, -2.4721349549995795`}],
    Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{173.5208929480344, 5.706338097770921, -1.8541009662496848`}], 
   Point3DBox[{173.52089437633285`, 4.854100966249685, -3.5267105137548387`}],
    Point3DBox[{156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}], 
   Point3DBox[{156.64671468509638`, 7.608451130361228, -2.4721349549995795`}],
    Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{173.52089437633285`, 4.854100966249685, -3.5267105137548387`}],
    Point3DBox[{173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}], 
   Point3DBox[{173.52089437633285`, 3.5267105137548387`, -4.854100966249685}],
    Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{173.52089437633285`, 3.5267105137548387`, -4.854100966249685}],
    Point3DBox[{173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}], 
   Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{156.64671468509638`, 2.4721349549995795`, -7.608451130361228}],
    Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{173.5208929480344, 1.8541009662496848`, -5.706338097770921}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{156.64671468509638`, 2.4721349549995795`, -7.608451130361228}],
    Point3DBox[{156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}], 
   Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{173.52089023124947`, -1.*^-6, -5.999999}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}], 
   Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}], 
   Point3DBox[{173.52088209606688`, -3.526712513754839, -4.854100966249685}], 
   Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{173.520877473998, -4.854102966249685, -3.5267105137548387`}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}], 
   Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{173.5208693388187, -6.000001, 1.*^-6}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{156.64669907999547`, -7.608453130361228, 2.4721369549995797`}],
    Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{148.96345936674507`, -9.510566162951534, 3.0901709437494747`}],
    Point3DBox[{156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}], 
   Point3DBox[{156.64669907999547`, -7.608453130361228, 2.4721369549995797`}],
    Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{148.96345936674507`, -9.510566162951534, 3.0901709437494747`}],
    Point3DBox[{148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{156.64669823335268`, -6.47213695499958, 4.702283018339785}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{156.64669823335268`, -4.702283018339785, 6.47213695499958}], 
   Point3DBox[{156.64669907999547`, -2.4721369549995797`, 7.608453130361228}],
    Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{148.96345936674507`, -3.0901709437494747`, 9.510566162951534}],
    Point3DBox[{156.64669907999547`, -2.4721369549995797`, 
    7.608453130361228}], 
   Point3DBox[{156.64669907999547`, -2.4721369549995797`, 7.608453130361228}],
    Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{148.96345936674507`, -3.0901709437494747`, 9.510566162951534}],
    Point3DBox[{148.96345936674507`, -3.0901709437494747`, 
    9.510566162951534}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{156.6467006904059, -1.*^-6, 8.000001}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{156.64670551264578`, 4.702281018339785, 6.47213695499958}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{156.6467108581421, 7.608451130361228, 2.4721369549995797`}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{156.6467130746841, 7.999999, 1.*^-6}], 
   Point3DBox[{156.64671468509638`, 7.608451130361228, -2.4721349549995795`}],
    Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{148.96346346560304`, 9.510564162951535, -3.0901689437494744`}],
    Point3DBox[{156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}], 
   Point3DBox[{156.64671468509638`, 7.608451130361228, -2.4721349549995795`}],
    Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{148.96346346560304`, 9.510564162951535, -3.0901689437494744`}],
    Point3DBox[{148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{156.6467155317403, 6.4721349549995795`, -4.702281018339785}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{156.6467155317403, 4.702281018339785, -6.4721349549995795`}], 
   Point3DBox[{156.64671468509638`, 2.4721349549995795`, -7.608451130361228}],
    Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{148.96346346560304`, 3.0901689437494744`, -9.510564162951535}],
    Point3DBox[{156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}], 
   Point3DBox[{156.64671468509638`, 2.4721349549995795`, -7.608451130361228}],
    Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{148.96346346560304`, 3.0901689437494744`, -9.510564162951535}],
    Point3DBox[{148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{156.6467130746841, -1.*^-6, -7.999999}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{156.6467108581421, -2.4721369549995797`, -7.608451130361228}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{156.64670551264578`, -6.47213695499958, -4.702281018339785}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{156.6467006904059, -8.000001, 1.*^-6}], 
   Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{148.96345936674507`, -9.510566162951534, 3.0901709437494747`}],
    Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{148.96345936674507`, -9.510566162951534, 3.0901709437494747`}],
    Point3DBox[{148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{148.9634591443649, -8.090170943749474, 5.877853522924732}], 
   Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{148.9634591443649, -5.877853522924732, 8.090170943749474}], 
   Point3DBox[{148.96345936674507`, -3.0901709437494747`, 9.510566162951534}],
    Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{148.96345936674507`, -3.0901709437494747`, 9.510566162951534}],
    Point3DBox[{148.96345936674507`, -3.0901709437494747`, 
    9.510566162951534}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{148.96345978973739`, -1.*^-6, 10.000001}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{148.96346105635314`, 5.877851522924732, 8.090170943749474}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{148.96346177599168`, 8.090168943749475, 5.877853522924732}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{148.963462460409, 9.510564162951535, 3.0901709437494747`}], 
   Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}],
    Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{148.96346304260948`, 9.999999, 1.*^-6}], 
   Point3DBox[{148.96346346560304`, 9.510564162951535, -3.0901689437494744`}],
    Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}], 
   Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{148.96346346560304`, 9.510564162951535, -3.0901689437494744`}],
    Point3DBox[{148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{148.963463687984, 8.090168943749475, -5.877851522924732}], 
   Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}], 
   Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}], 
   Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}], 
   Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{148.963463687984, 5.877851522924732, -8.090168943749475}], 
   Point3DBox[{148.96346346560304`, 3.0901689437494744`, -9.510564162951535}],
    Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}],
    Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}],
    Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{148.96346346560304`, 3.0901689437494744`, -9.510564162951535}],
    Point3DBox[{148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{148.96346304260948`, -1.*^-6, -9.999999}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{148.963462460409, -3.0901709437494747`, -9.510564162951535}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{148.96346177599168`, -5.877853522924732, -8.090168943749475}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{148.96346105635314`, -8.090170943749474, -5.877851522924732}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}], 
   Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{148.96345978973739`, -10.000001, 1.*^-6}], 
   Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{151.4508453226652, -13.314792228132148`, 4.3262389212492645`}],
    Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{151.4508453226652, -13.314792228132148`, 4.3262389212492645`}],
    Point3DBox[{151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}], 
   Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{148.92374723914156`, -9.708204932499369, 7.053424027509678}], 
   Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{148.92374723914156`, -7.053424027509678, 9.708204932499369}], 
   Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{151.4508453226652, -4.3262389212492645`, 13.314792228132148`}],
    Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{151.4508453226652, -4.3262389212492645`, 13.314792228132148`}],
    Point3DBox[{151.4508453226652, -4.3262389212492645`, 
    13.314792228132148`}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{148.92374678570366`, -1.*^-6, 12.000001}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{148.9237458957819, 7.0534220275096775`, 9.708204932499369}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{148.9237453901658, 9.70820293249937, 7.053424027509678}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], 
   Point3DBox[{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}], Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}],
    Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}],
    Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}],
    Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}], 
   Point3DBox[{148.9237445002446, 11.999999, 1.*^-6}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}], 
   Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{151.45084309959006`, 11.326236921249265`, -8.228992532094624}],
    Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}],
    Point3DBox[{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}],
    Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}],
    Point3DBox[{151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}], 
   Point3DBox[{151.45084309959006`, 11.326236921249265`, -8.228992532094624}],
    Point3DBox[{151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}], 
   Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}], 
   Point3DBox[{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}], 
   Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{151.45084309959006`, 8.228992532094624, -11.326236921249265`}],
    Point3DBox[{151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{148.9237445002446, -1.*^-6, -11.999999}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{148.9237453901658, -7.053424027509678, -9.70820293249937}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{148.9237458957819, -9.708204932499369, -7.0534220275096775`}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}], 
   Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{148.92374678570366`, -12.000001, 1.*^-6}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{151.4508453226652, -13.314792228132148`, 4.3262389212492645`}],
    Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{150.28284005321834`, -15.216905260722456`, 4.944272909999159}],
    Point3DBox[{151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}], 
   Point3DBox[{151.4508453226652, -13.314792228132148`, 4.3262389212492645`}],
    Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{150.28284005321834`, -15.216905260722456`, 4.944272909999159}],
    Point3DBox[{150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}], 
   Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}], 
   Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{151.4508454370694, -11.326238921249264`, 8.228994532094623}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}], 
   Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}], 
   Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{151.4508454370694, -8.228994532094623, 11.326238921249264`}], 
   Point3DBox[{151.4508453226652, -4.3262389212492645`, 13.314792228132148`}],
    Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}],
    Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}],
    Point3DBox[{150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}], 
   Point3DBox[{151.4508453226652, -4.3262389212492645`, 13.314792228132148`}],
    Point3DBox[{151.4508453226652, -4.3262389212492645`, 
    13.314792228132148`}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{150.28284005321834`, -4.944272909999159, 15.216905260722456`}],
    Point3DBox[{150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}], 
   Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{151.45084510505546`, -1.*^-6, 14.000001}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{151.45084480554118`, 4.326236921249264, 13.314792228132148`}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{151.45084445344088`, 8.228992532094624, 11.326238921249264`}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{151.45084408322055`, 11.326236921249265`, 8.228994532094623}], 
   Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}], 
   Point3DBox[{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}], 
   Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{151.450843431605, 13.999999, 1.*^-6}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{151.45084321399463`, 13.31479022813215, -4.326236921249264}], 
   Point3DBox[{151.45084309959006`, 11.326236921249265`, -8.228992532094624}],
    Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{151.45084309959006`, 11.326236921249265`, -8.228992532094624}],
    Point3DBox[{151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}], 
   Point3DBox[{151.45084309959006`, 8.228992532094624, -11.326236921249265`}],
    Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{151.45084309959006`, 8.228992532094624, -11.326236921249265`}],
    Point3DBox[{151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{151.45084321399463`, 4.326236921249264, -13.31479022813215}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{151.450843431605, -1.*^-6, -13.999999}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{151.45084510505546`, -14.000001, 1.*^-6}], 
   Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{150.28284005321834`, -15.216905260722456`, 4.944272909999159}],
    Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{140.86399150856653`, -17.119018293312763`, 5.562306898749054}],
    Point3DBox[{150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}], 
   Point3DBox[{150.28284005321834`, -15.216905260722456`, 4.944272909999159}],
    Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}],
    Point3DBox[{140.86399150856653`, -17.119018293312763`, 5.562306898749054}]
    , Point3DBox[{140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}], 
   Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}], 
   Point3DBox[{150.28283972463768`, -12.944272909999158`, 9.40456503667957}], 
   Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}], 
   Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}], 
   Point3DBox[{150.28283972463768`, -9.40456503667957, 12.944272909999158`}], 
   Point3DBox[{150.28284005321834`, -4.944272909999159, 15.216905260722456`}],
    Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399150856653`, -5.562306898749054, 17.119018293312763`}],
    Point3DBox[{150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}], 
   Point3DBox[{150.28284005321834`, -4.944272909999159, 15.216905260722456`}],
    Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{140.86399150856653`, -5.562306898749054, 17.119018293312763`}],
    Point3DBox[{140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{150.28284067821582`, -1.*^-6, 16.000001}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{150.28284153845084`, 4.944270909999159, 15.216905260722456`}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{150.2828425497174, 9.404563036679571, 12.944272909999158`}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{150.28284361302565`, 12.94427090999916, 9.40456503667957}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{150.2828446242915, 15.216903260722457`, 4.944272909999159}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{150.28284548452532`, 15.999999, 1.*^-6}], 
   Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{150.2828461095216, 15.216903260722457`, -4.944270909999159}], 
   Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{150.28284643810156`, 12.94427090999916, -9.404563036679571}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{150.28284643810156`, 9.404563036679571, -12.94427090999916}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{150.2828461095216, 4.944270909999159, -15.216903260722457`}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{150.28284548452532`, -1.*^-6, -15.999999}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{150.2828446242915, -4.944272909999159, -15.216903260722457`}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{150.28284361302565`, -9.40456503667957, -12.94427090999916}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{150.2828425497174, -12.944272909999158`, -9.404563036679571}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}], 
   Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{150.28284067821582`, -16.000001, 1.*^-6}], 
   Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{140.86399150856653`, -17.119018293312763`, 5.562306898749054}],
    Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{140.86399150856653`, -17.119018293312763`, 5.562306898749054}],
    Point3DBox[{140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}], 
   Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{122.44829647400742`, -16.18034088749895, 11.755706045849463`}],
    Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}], 
   Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{122.44829647400742`, -16.18034088749895, 11.755706045849463`}],
    Point3DBox[{122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}], 
   Point3DBox[{122.44829647400742`, -11.755706045849463`, 16.18034088749895}],
    Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399150856653`, -5.562306898749054, 17.119018293312763`}],
    Point3DBox[{122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}], 
   Point3DBox[{122.44829647400742`, -11.755706045849463`, 16.18034088749895}],
    Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{140.86399150856653`, -5.562306898749054, 17.119018293312763`}],
    Point3DBox[{140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{140.8639933501296, -1.*^-6, 18.000001}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{140.86399588482354`, 5.562304898749054, 17.119018293312763`}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{140.86400497729824`, 17.11901629331276, 5.562306898749054}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{140.864007511991, 17.999999, 1.*^-6}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{140.86400935355294`, 17.11901629331276, -5.562304898749054}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{140.86400935355294`, 5.562304898749054, -17.11901629331276}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{140.864007511991, -1.*^-6, -17.999999}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{140.86400497729824`, -5.562306898749054, -17.11901629331276}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}], 
   Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{140.8639933501296, -18.000001, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{122.44829798304029`, -19.02113132590307, 6.180340887498949}], 
   Point3DBox[{122.44829647400742`, -16.18034088749895, 11.755706045849463`}],
    Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{98.44395238658502, -17.798374876248847`, 12.931276550434408`}],
    Point3DBox[{122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}], 
   Point3DBox[{122.44829647400742`, -16.18034088749895, 11.755706045849463`}],
    Point3DBox[{122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}], 
   Point3DBox[{98.44395238658502, -17.798374876248847`, 12.931276550434408`}],
    Point3DBox[{98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}], 
   Point3DBox[{98.44395238658502, -12.931276550434408`, 17.798374876248847`}],
    Point3DBox[{122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}], 
   Point3DBox[{122.44829647400742`, -11.755706045849463`, 16.18034088749895}],
    Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{98.44395238658502, -12.931276550434408`, 17.798374876248847`}],
    Point3DBox[{98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{122.44829798304029`, -6.180340887498949, 19.02113132590307}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{122.44830085339125`, -1.*^-6, 20.000001}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{122.44830480409036`, 6.180338887498949, 19.02113132590307}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{122.44830944841544`, 11.755704045849464`, 16.18034088749895}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{122.4483189760726, 19.02112932590307, 6.180340887498949}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832292677113`, 19.999999, 1.*^-6}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{122.44832579712158`, 19.02112932590307, -6.180338887498949}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{122.44832579712158`, 6.180338887498949, -19.02112932590307}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{122.44832292677113`, -1.*^-6, -19.999999}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{122.4483189760726, -6.180340887498949, -19.02112932590307}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{122.44830480409036`, -19.02113132590307, -6.180338887498949}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{122.44830085339125`, -20.000001, 1.*^-6}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{98.44395408802413, -20.923244358493378`, 6.798374876248844}], 
   Point3DBox[{98.44395238658502, -17.798374876248847`, 12.931276550434408`}],
    Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{98.44395238658502, -17.798374876248847`, 12.931276550434408`}],
    Point3DBox[{98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}], 
   Point3DBox[{98.44395238658502, -12.931276550434408`, 17.798374876248847`}],
    Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{98.44395238658502, -12.931276550434408`, 17.798374876248847`}],
    Point3DBox[{98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{98.44395408802413, -6.798374876248844, 20.923244358493378`}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{98.44395732435352, -1.*^-6, 22.000001}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{98.44396177877888, 6.798372876248844, 20.923244358493378`}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{98.44396701526996, 12.93127455043441, 17.798374876248847`}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{98.44397252124277, 17.798372876248845`, 12.931276550434408`}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{98.44397775773425, 20.923242358493376`, 6.798374876248844}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{98.44398221215992, 21.999999, 1.*^-6}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{98.44398544848977, 20.923242358493376`, -6.798372876248844}], 
   Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{74.83968188323684, 19.416406864998738`, -14.106845055019356`}],
    Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{98.443987149929, 17.798372876248845`, -12.93127455043441}], 
   Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{74.83968188323684, 19.416406864998738`, -14.106845055019356`}],
    Point3DBox[{74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}], 
   Point3DBox[{74.83968188323684, 14.106845055019356`, -19.416406864998738`}],
    Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{98.443987149929, 12.93127455043441, -17.798372876248845`}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{74.83968188323684, 14.106845055019356`, -19.416406864998738`}],
    Point3DBox[{74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}], 
   Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{98.44398544848977, 6.798372876248844, -20.923242358493376`}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{98.44398221215992, -1.*^-6, -21.999999}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{98.44397775773425, -6.798374876248844, -20.923242358493376`}], 
   Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{74.8396693601116, -14.106847055019355`, -19.416406864998738`}],
    Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{74.8396693601116, -14.106847055019355`, -19.416406864998738`}],
    Point3DBox[{
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{98.44396701526996, -17.798374876248847`, -12.93127455043441}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{98.44396177877888, -20.923244358493378`, -6.798372876248844}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{98.44395732435352, -22.000001, 1.*^-6}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{74.83965358005719, -22.825357391083685`, 7.416408864998739}], 
   Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{74.83965212351299, -19.41640886499874, 14.106847055019355`}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{74.83965212351299, -14.106847055019355`, 19.41640886499874}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{74.83965358005719, -7.416408864998739, 22.825357391083685`}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{74.83965635056899, -1.*^-6, 24.000001}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{74.83966016385156, 7.416406864998739, 22.825357391083685`}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{74.83966464663436, 14.106845055019356`, 19.41640886499874}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{74.8396693601116, 19.416406864998738`, 14.106847055019355`}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{74.8396738428952, 22.825355391083683`, 7.416408864998739}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{74.83967765617896, 23.999999, 1.*^-6}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{74.83968042669193, 22.825355391083683`, -7.416406864998739}], 
   Point3DBox[{74.83968188323684, 19.416406864998738`, -14.106845055019356`}],
    Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{57.439391732485376`, 21.03444085374863, -15.282415559604303`}],
    Point3DBox[{74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}], 
   Point3DBox[{74.83968188323684, 19.416406864998738`, -14.106845055019356`}],
    Point3DBox[{74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}], 
   Point3DBox[{57.439391732485376`, 21.03444085374863, -15.282415559604303`}],
    Point3DBox[{57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}], 
   Point3DBox[{57.439391732485376`, 15.282415559604303`, -21.03444085374863}],
    Point3DBox[{74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}], 
   Point3DBox[{74.83968188323684, 14.106845055019356`, -19.416406864998738`}],
    Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{57.439391732485376`, 15.282415559604303`, -21.03444085374863}],
    Point3DBox[{57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{74.83968042669193, 7.416406864998739, -22.825355391083683`}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{74.83967765617896, -1.*^-6, -23.999999}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{74.8396738428952, -7.416408864998739, -22.825355391083683`}], 
   Point3DBox[{74.8396693601116, -14.106847055019355`, -19.416406864998738`}],
    Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{74.8396693601116, -14.106847055019355`, -19.416406864998738`}],
    Point3DBox[{
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{74.83966464663436, -19.41640886499874, -14.106845055019356`}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{74.83966016385156, -22.825357391083685`, -7.416406864998739}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{74.83965635056899, -24.000001, 1.*^-6}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{57.43937448825724, -24.727470423673992`, 8.034442853748633}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{57.4393736008314, -21.034442853748633`, 15.282417559604301`}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{57.4393736008314, -15.282417559604301`, 21.034442853748633`}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{57.43937448825724, -8.034442853748633, 24.727470423673992`}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{57.43937617624164, -1.*^-6, 26.000001}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{57.4393784995531, 8.034440853748634, 24.727470423673992`}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{57.43938123076995, 15.282415559604303`, 21.034442853748633`}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{57.43938410254182, 21.03444085374863, 15.282417559604301`}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{57.43938683375967, 24.72746842367399, 8.034442853748633}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{57.439389157072696`, 25.999999, 1.*^-6}], 
   Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{57.4393908450586, 24.72746842367399, -8.034440853748634}], 
   Point3DBox[{57.439391732485376`, 21.03444085374863, -15.282415559604303`}],
    Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{57.439391732485376`, 21.03444085374863, -15.282415559604303`}],
    Point3DBox[{57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}], 
   Point3DBox[{57.439391732485376`, 15.282415559604303`, -21.03444085374863}],
    Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{57.439391732485376`, 15.282415559604303`, -21.03444085374863}],
    Point3DBox[{57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{57.4393908450586, 8.034440853748634, -24.72746842367399}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{57.439389157072696`, -1.*^-6, -25.999999}], 
   Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{57.43938683375967, -8.034442853748633, -24.72746842367399}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{57.43938410254182, -15.282417559604301`, -21.03444085374863}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{57.4393784995531, -24.727470423673992`, -8.034440853748634}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{57.43937617624164, -26.000001, 1.*^-6}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{49.18245474037829, -26.6295834562643, 8.652476842498528}], 
   Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{48.78638466121615, -24.270510831248426`, 17.633558568774195`}],
    Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{49.18245448351004, -22.65247684249853, 16.457988064189248`}], 
   Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{48.78638466121615, -24.270510831248426`, 17.633558568774195`}],
    Point3DBox[{48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}], 
   Point3DBox[{48.78638466121615, -17.633558568774195`, 24.270510831248426`}],
    Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{49.18245448351004, -16.457988064189248`, 22.65247684249853}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{48.78638466121615, -17.633558568774195`, 24.270510831248426`}],
    Point3DBox[{48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{49.18245474037829, -8.652476842498528, 26.6295834562643}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{49.18245522897084, -1.*^-6, 28.000001}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{49.182455901461054`, 8.65247484249853, 26.6295834562643}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{49.18245669202105, 16.457986064189246`, 22.65247684249853}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{49.18245752326541, 22.652474842498528`, 16.457988064189248`}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{49.1824583138262, 26.629581456264297`, 8.652476842498528}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{49.18245898631761, 27.999999, 1.*^-6}], 
   Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{48.786381863528106`, 28.531694488854605`, -9.270508831248424}],
    Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{49.18245947491141, 26.629581456264297`, -8.65247484249853}], 
   Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{48.786381863528106`, 28.531694488854605`, -9.270508831248424}],
    Point3DBox[{48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}], 
   Point3DBox[{48.78638171955296, 24.270508831248424`, -17.633556568774193`}],
    Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}], 
   Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{48.78638171955296, 24.270508831248424`, -17.633556568774193`}],
    Point3DBox[{48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}], 
   Point3DBox[{48.78638171955296, 17.633556568774193`, -24.270508831248424`}],
    Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}], 
   Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{48.78638171955296, 17.633556568774193`, -24.270508831248424`}],
    Point3DBox[{48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}], 
   Point3DBox[{48.786381863528106`, 9.270508831248424, -28.531694488854605`}],
    Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{49.18245947491141, 8.65247484249853, -26.629581456264297`}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{48.786381863528106`, 9.270508831248424, -28.531694488854605`}],
    Point3DBox[{48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{49.18245898631761, -1.*^-6, -27.999999}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{49.1824583138262, -8.652476842498528, -26.629581456264297`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{49.18245669202105, -22.65247684249853, -16.457986064189246`}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{49.182455901461054`, -26.6295834562643, -8.65247484249853}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{49.18245522897084, -28.000001, 1.*^-6}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{48.78638451724075, -28.531696488854607`, 9.270510831248423}], 
   Point3DBox[{48.78638466121615, -24.270510831248426`, 17.633558568774195`}],
    Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{48.78638466121615, -24.270510831248426`, 17.633558568774195`}],
    Point3DBox[{48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}], 
   Point3DBox[{48.78638466121615, -17.633558568774195`, 24.270510831248426`}],
    Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{48.78638466121615, -17.633558568774195`, 24.270510831248426`}],
    Point3DBox[{48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{48.78638451724075, -9.270510831248423, 28.531696488854607`}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{48.78638424338337, -1.*^-6, 30.000001}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{48.78638386645105, 9.270508831248424, 28.531696488854607`}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{48.78638342334068, 17.633556568774193`, 24.270510831248426`}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{48.78638295742704, 24.270508831248424`, 17.633558568774195`}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{48.78638251431693, 28.531694488854605`, 9.270510831248423}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{48.78638213738503, 29.999999, 1.*^-6}], 
   Point3DBox[{48.786381863528106`, 28.531694488854605`, -9.270508831248424}],
    Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{48.786381863528106`, 28.531694488854605`, -9.270508831248424}],
    Point3DBox[{48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}], 
   Point3DBox[{48.78638171955296, 24.270508831248424`, -17.633556568774193`}],
    Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{48.78638171955296, 24.270508831248424`, -17.633556568774193`}],
    Point3DBox[{48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}], 
   Point3DBox[{48.78638171955296, 17.633556568774193`, -24.270508831248424`}],
    Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{48.78638171955296, 17.633556568774193`, -24.270508831248424`}],
    Point3DBox[{48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}], 
   Point3DBox[{48.786381863528106`, 9.270508831248424, -28.531694488854605`}],
    Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{48.786381863528106`, 9.270508831248424, -28.531694488854605`}],
    Point3DBox[{48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{48.78638213738503, -1.*^-6, -29.999999}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{48.78638251431693, -9.270510831248423, -28.531694488854605`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{48.78638386645105, -28.531696488854607`, -9.270508831248424}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{48.78638424338337, -30.000001, 1.*^-6}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{51.33899135525854, -30.433809521444914`, 9.888544819998318}], 
   Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{50.56658260867397, -27.506578808748213`, 19.984699577944088`}],
    Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{51.33899148527837, -25.88854481999832, 18.80912907335914}], 
   Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{50.56658260867397, -27.506578808748213`, 19.984699577944088`}],
    Point3DBox[{50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}], 
   Point3DBox[{50.56658260867397, -19.984699577944088`, 27.506578808748213`}],
    Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{51.33899148527837, -18.80912907335914, 25.88854481999832}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{50.56658260867397, -19.984699577944088`, 27.506578808748213`}],
    Point3DBox[{50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{51.33899135525854, -9.888544819998318, 30.433809521444914`}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{51.3389911079461, -1.*^-6, 32.000001}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{51.33899076754966, 9.88854281999832, 30.433809521444914`}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{51.338990367389414`, 18.80912707335914, 25.88854481999832}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{51.338989946635934`, 25.888542819998317`, 18.80912907335914}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{51.3389895464754, 30.433807521444912`, 9.888544819998318}], 
   Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{51.338989206078395`, 31.999999, 1.*^-6}], 
   Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{51.33898895876544, 30.433807521444912`, -9.88854281999832}], 
   Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{51.33898882874527, 25.888542819998317`, -18.80912707335914}], 
   Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{51.33898882874527, 18.80912707335914, -25.888542819998317`}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{51.33898895876544, 9.88854281999832, -30.433807521444912`}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{51.338989206078395`, -1.*^-6, -31.999999}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{51.3389895464754, -9.888544819998318, -30.433807521444912`}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{51.338990367389414`, -25.88854481999832, -18.80912707335914}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{51.33899076754966, -30.433809521444914`, -9.88854281999832}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{51.3389911079461, -32.000001, 1.*^-6}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{50.5665829009651, -32.335922554035214`, 10.506578808748213`}], 
   Point3DBox[{50.56658260867397, -27.506578808748213`, 19.984699577944088`}],
    Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{50.56658260867397, -27.506578808748213`, 19.984699577944088`}],
    Point3DBox[{50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}], 
   Point3DBox[{50.56658260867397, -19.984699577944088`, 27.506578808748213`}],
    Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{50.56658260867397, -19.984699577944088`, 27.506578808748213`}],
    Point3DBox[{50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{50.5665829009651, -10.506578808748213`, 32.335922554035214`}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{50.56658345693566, -1.*^-6, 34.000001}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{50.56658422216336, 10.506576808748214`, 32.335922554035214`}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{50.56658512174204, 19.984697577944086`, 27.506578808748213`}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{50.56658606761471, 27.50657680874821, 19.984699577944088`}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{50.56658696719268, 32.33592055403522, 10.506578808748213`}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{50.56658773241915, 33.999999, 1.*^-6}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{50.56658828838857, 32.33592055403522, -10.506576808748214`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{50.56658858067888, 27.50657680874821, -19.984697577944086`}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{50.56658858067888, 19.984697577944086`, -27.50657680874821}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{50.56658828838857, 10.506576808748214`, -32.33592055403522}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{50.56658773241915, -1.*^-6, -33.999999}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{50.56658696719268, -10.506578808748213`, -32.33592055403522}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{50.56658606761471, -19.984699577944088`, -27.50657680874821}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{50.56658345693566, -34.000001, 1.*^-6}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{23.816307054484525`, -36.14014861921583, 11.742646786248002`}],
    Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{41.730756817653, -34.23803558662552, 11.124612797498107`}], 
   Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{23.816307054484525`, -36.14014861921583, 11.742646786248002`}],
    Point3DBox[{23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}], 
   Point3DBox[{23.816305571011128`, -30.742646786248006`, 22.33584058711398}],
    Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{41.73075588969306, -29.12461279749811, 21.160270082529035`}], 
   Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{23.816305571011128`, -30.742646786248006`, 22.33584058711398}],
    Point3DBox[{23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}], 
   Point3DBox[{23.816305571011128`, -22.33584058711398, 30.742646786248006`}],
    Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{41.73075588969306, -21.160270082529035`, 29.12461279749811}], 
   Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{23.816305571011128`, -22.33584058711398, 30.742646786248006`}],
    Point3DBox[{23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}], 
   Point3DBox[{23.816307054484525`, -11.742646786248002`, 36.14014861921583}],
    Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{41.730756817653, -11.124612797498107`, 34.23803558662552}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{23.816307054484525`, -11.742646786248002`, 36.14014861921583}],
    Point3DBox[{23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}], Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{41.730758582737394`, -1.*^-6, 36.000001}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{41.73076101216748, 11.124610797498109`, 34.23803558662552}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{41.73076386813338, 21.160268082529033`, 29.12461279749811}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{41.73076687107326, 29.124610797498107`, 21.160270082529035`}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}], 
   Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}], 
   Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{41.73076972703842, 34.23803358662553, 11.124612797498107`}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}], 
   Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{41.73077215646717, 35.999999, 1.*^-6}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{41.73077392155031, 34.23803358662553, -11.124610797498109`}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{41.7307748495094, 29.124610797498107`, -21.160268082529033`}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{41.7307748495094, 21.160268082529033`, -29.124610797498107`}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{41.73077392155031, 11.124610797498109`, -34.23803358662553}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{41.73077215646717, -1.*^-6, -35.999999}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{41.73076972703842, -11.124612797498107`, -34.23803358662553}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{41.73076386813338, -29.12461279749811, -21.160268082529033`}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{41.73076101216748, -34.23803558662552, -11.124610797498109`}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{41.730758582737394`, -36.000001, 1.*^-6}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{23.816307054484525`, -36.14014861921583, 11.742646786248002`}],
    Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}], 
   Point3DBox[{23.816307054484525`, -36.14014861921583, 11.742646786248002`}],
    Point3DBox[{23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}], 
   Point3DBox[{23.816305571011128`, -30.742646786248006`, 22.33584058711398}],
    Point3DBox[{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}], 
   Point3DBox[{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}], 
   Point3DBox[{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}], 
   Point3DBox[{23.816305571011128`, -30.742646786248006`, 22.33584058711398}],
    Point3DBox[{23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}], 
   Point3DBox[{23.816305571011128`, -22.33584058711398, 30.742646786248006`}],
    Point3DBox[{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}], 
   Point3DBox[{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}], 
   Point3DBox[{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}], 
   Point3DBox[{23.816305571011128`, -22.33584058711398, 30.742646786248006`}],
    Point3DBox[{23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}], 
   Point3DBox[{23.816307054484525`, -11.742646786248002`, 36.14014861921583}],
    Point3DBox[{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}], 
   Point3DBox[{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}], 
   Point3DBox[{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}], 
   Point3DBox[{23.816307054484525`, -11.742646786248002`, 36.14014861921583}],
    Point3DBox[{23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}], Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}], 
   Point3DBox[{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}], 
   Point3DBox[{-0.000012450411418285512`, -1.*^-6, 40.000001}], 
   Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{23.81630987621824, -1.*^-6, 38.000001}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{-0.000012450411418285512`, -1.*^-6, 40.000001}], 
   Point3DBox[{-0.000012450411418285512`, -1.*^-6, 40.000001}], 
   Point3DBox[{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{23.816313760001435`, 11.742644786248004`, 36.14014861921583}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}], 
   Point3DBox[{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}], 
   Point3DBox[{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{23.81631832566208, 22.33583858711398, 30.742646786248006`}], 
   Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}], 
   Point3DBox[{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}], 
   Point3DBox[{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}], 
   Point3DBox[{2.7544259069145482`*^-6, 32.3606787749979, 23.51141109169893}],
    Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}],
    Point3DBox[{23.816323126281645`, 30.742644786248004`, 22.33584058711398}],
    Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}],
    Point3DBox[{2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}], 
   Point3DBox[{2.7544259069145482`*^-6, 32.3606787749979, 23.51141109169893}],
    Point3DBox[{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}], 
   Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}], 
   Point3DBox[{23.81632769194195, 36.140146619215834`, 11.742646786248002`}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}], 
   Point3DBox[{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{23.81633157572432, 37.999999, 1.*^-6}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}], 
   Point3DBox[{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}], 
   Point3DBox[{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{23.81633588093007, 30.742644786248004`, -22.33583858711398}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}], 
   Point3DBox[{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}], 
   Point3DBox[{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{23.81633588093007, 22.33583858711398, -30.742644786248004`}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}], 
   Point3DBox[{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}], 
   Point3DBox[{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}], 
   Point3DBox[{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}], 
   Point3DBox[{0.000012450411276176965`, -1.*^-6, -39.999999}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{23.81633157572432, -1.*^-6, -37.999999}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{0.000012450411276176965`, -1.*^-6, -39.999999}], 
   Point3DBox[{0.000012450411276176965`, -1.*^-6, -39.999999}], 
   Point3DBox[{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}], 
   Point3DBox[{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}], 
   Point3DBox[{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}], 
   Point3DBox[{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}], 
   Point3DBox[{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{23.81631832566208, -30.742646786248006`, -22.33583858711398}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}], 
   Point3DBox[{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}], 
   Point3DBox[{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}], 
   Point3DBox[{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{23.81630987621824, -38.000001, 1.*^-6}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}], 
   Point3DBox[{-39.99345718051421, -45.52465304688692, 7.210397535415441}], 
   Point3DBox[{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}], 
   Point3DBox[{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}], 
   Point3DBox[{-39.993460062385736`, -41.06838291563569, 20.92538675557315}], 
   Point3DBox[{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}], 
   Point3DBox[{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}], 
   Point3DBox[{-39.99346105541093, -32.592053422239815`, 
    32.592053422239815`}], 
   Point3DBox[{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}], 
   Point3DBox[{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}], 
   Point3DBox[{-39.993460062385736`, -20.92538675557315, 41.06838291563569}], 
   Point3DBox[{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}], 
   Point3DBox[{-0.000012450411418285512`, -1.*^-6, 40.000001}], 
   Point3DBox[{-39.99345718051421, -7.210397535415441, 45.52465304688692}], 
   Point3DBox[{-0.000012450411418285512`, -1.*^-6, 40.000001}], 
   Point3DBox[{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}], 
   Point3DBox[{-39.99345269189416, 7.210395535415441, 45.52465304688692}], 
   Point3DBox[{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}], 
   Point3DBox[{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}], 
   Point3DBox[{-39.99344703590293, 20.92538475557315, 41.06838291563569}], 
   Point3DBox[{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}], 
   Point3DBox[{2.7544259069145482`*^-6, 32.3606787749979, 23.51141109169893}],
    Point3DBox[{-39.993440766188314`, 32.59205142223982, 
    32.592053422239815`}], 
   Point3DBox[{2.7544259069145482`*^-6, 32.3606787749979, 23.51141109169893}],
    Point3DBox[{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}], 
   Point3DBox[{-39.99343449647358, 41.06838091563569, 20.92538675557315}], 
   Point3DBox[{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{-39.99342884048207, 45.52465104688692, 7.210397535415441}], 
   Point3DBox[{0.000012450411276176965`, 39.999999, 1.*^-6}], 
   Point3DBox[{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}], 
   Point3DBox[{-39.99342435186185, 45.52465104688692, -7.210395535415441}], 
   Point3DBox[{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}], 
   Point3DBox[{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}], 
   Point3DBox[{-39.993421469990324`, 41.06838091563569, -20.92538475557315}], 
   Point3DBox[{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}], 
   Point3DBox[{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}], 
   Point3DBox[{-39.993420476965014`, 32.59205142223982, -32.59205142223982}], 
   Point3DBox[{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}], 
   Point3DBox[{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}], 
   Point3DBox[{-39.993421469990324`, 20.92538475557315, -41.06838091563569}], 
   Point3DBox[{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}], 
   Point3DBox[{0.000012450411276176965`, -1.*^-6, -39.999999}], 
   Point3DBox[{-39.99342435186185, 7.210395535415441, -45.52465104688692}], 
   Point3DBox[{0.000012450411276176965`, -1.*^-6, -39.999999}], 
   Point3DBox[{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}], 
   Point3DBox[{-39.99342884048207, -7.210397535415441, -45.52465104688692}], 
   Point3DBox[{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}], 
   Point3DBox[{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}], 
   Point3DBox[{-39.99343449647358, -20.92538675557315, -41.06838091563569}], 
   Point3DBox[{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}], 
   Point3DBox[{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}], 
   Point3DBox[{-39.993440766188314`, -32.592053422239815`, \
-32.59205142223982}], 
   Point3DBox[{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}], 
   Point3DBox[{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}], 
   Point3DBox[{-39.99344703590293, -41.06838291563569, -20.92538475557315}], 
   Point3DBox[{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}], 
   Point3DBox[{-0.000012450411418285512`, -40.000001, 1.*^-6}], 
   Point3DBox[{-39.99345269189416, -45.52465304688692, -7.210395535415441}], 
   Line3DBox[{{221.05756881381186`, -2.000001, 1.*^-6}, {
    221.05756589754, -1.902114032590307, 0.6180349887498949}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.05756881381186`, -2.000001, 
    1.*^-6}}], 
   Line3DBox[{{221.05756589754, -1.902114032590307, 0.6180349887498949}, {
    221.05756436436528`, -1.6180349887498948`, 1.1755715045849462`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.05756589754, -1.902114032590307, 0.6180349887498949}}], 
   Line3DBox[{{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}, {221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}, {239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.05756436436528`, -1.6180349887498948`, 1.1755715045849462`}}], 
   Line3DBox[{{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}, {221.05756589754, -0.6180349887498949, 
    1.902114032590307}, {239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.05756436436528`, -1.1755715045849462`, 1.6180349887498948`}}], 
   Line3DBox[{{221.05756589754, -0.6180349887498949, 1.902114032590307}, {
    221.05756881381186`, -1.*^-6, 2.000001}, {239.96064459712753`, -1.*^-6, 
    1.*^-6}, {221.05756589754, -0.6180349887498949, 1.902114032590307}}], 
   Line3DBox[{{221.05756881381186`, -1.*^-6, 2.000001}, {221.05757282771617`, 
    0.6180329887498949, 1.902114032590307}, {239.96064459712753`, -1.*^-6, 
    1.*^-6}, {221.05756881381186`, -1.*^-6, 2.000001}}], 
   Line3DBox[{{221.05757282771617`, 0.6180329887498949, 1.902114032590307}, {
    221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.05757282771617`, 
    0.6180329887498949, 1.902114032590307}}], 
   Line3DBox[{{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}, {
    221.0575825078045, 1.618032988749895, 1.1755715045849462`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.0575775463444, 
    1.1755695045849464`, 1.6180349887498948`}}], 
   Line3DBox[{{221.0575825078045, 1.618032988749895, 1.1755715045849462`}, {
    221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.0575825078045, 
    1.618032988749895, 1.1755715045849462`}}], 
   Line3DBox[{{221.05758722643426`, 1.9021120325903071`, 
    0.6180349887498949}, {221.05759124034108`, 1.999999, 1.*^-6}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.05758722643426`, 
    1.9021120325903071`, 0.6180349887498949}}], 
   Line3DBox[{{221.05759124034108`, 1.999999, 1.*^-6}, {221.0575941566154, 
    1.9021120325903071`, -0.6180329887498949}, {239.96064459712753`, -1.*^-6, 
    1.*^-6}, {221.05759124034108`, 1.999999, 1.*^-6}}], 
   Line3DBox[{{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}, {
    221.0575956897917, 1.618032988749895, -1.1755695045849464`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.0575941566154, 
    1.9021120325903071`, -0.6180329887498949}}], 
   Line3DBox[{{221.0575956897917, 1.618032988749895, -1.1755695045849464`}, {
    221.0575956897917, 1.1755695045849464`, -1.618032988749895}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.0575956897917, 
    1.618032988749895, -1.1755695045849464`}}], 
   Line3DBox[{{221.0575956897917, 1.1755695045849464`, -1.618032988749895}, {
    221.0575941566154, 0.6180329887498949, -1.9021120325903071`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {221.0575956897917, 
    1.1755695045849464`, -1.618032988749895}}], 
   Line3DBox[{{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}, {
    221.05759124034108`, -1.*^-6, -1.999999}, {239.96064459712753`, -1.*^-6, 
    1.*^-6}, {221.0575941566154, 0.6180329887498949, -1.9021120325903071`}}], 
   Line3DBox[{{221.05759124034108`, -1.*^-6, -1.999999}, {
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.05759124034108`, -1.*^-6, -1.999999}}], 
   Line3DBox[{{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}, {
    221.0575825078045, -1.1755715045849462`, -1.618032988749895}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}}], 
   Line3DBox[{{221.0575825078045, -1.1755715045849462`, -1.618032988749895}, {
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.0575825078045, -1.1755715045849462`, -1.618032988749895}}], 
   Line3DBox[{{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}, {
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}, {
    239.96064459712753`, -1.*^-6, 1.*^-6}, {
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}}], 
   Line3DBox[{{
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}, {
    221.05756881381186`, -2.000001, 1.*^-6}, {239.96064459712753`, -1.*^-6, 
    1.*^-6}, {221.05757282771617`, -1.902114032590307, -0.6180329887498949}}],
    Line3DBox[{{221.05756881381186`, -2.000001, 1.*^-6}, {
    221.05756589754, -1.902114032590307, 0.6180349887498949}, {
    196.88955364076963`, -4.000001, 1.*^-6}, {221.05756881381186`, -2.000001, 
    1.*^-6}}], 
   Line3DBox[{{196.88955364076963`, -4.000001, 1.*^-6}, {
    196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}, {
    221.05756589754, -1.902114032590307, 0.6180349887498949}, {
    196.88955364076963`, -4.000001, 1.*^-6}}], 
   Line3DBox[{{221.05756589754, -1.902114032590307, 0.6180349887498949}, {
    221.05756436436528`, -1.6180349887498948`, 1.1755715045849462`}, {
    196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}, {
    221.05756589754, -1.902114032590307, 0.6180349887498949}}], 
   Line3DBox[{{196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}, {196.88954871074495`, -3.23606897749979, 
    2.3511420091698927`}, {221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}, {196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}}], 
   Line3DBox[{{221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}, {221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}, {196.88954871074495`, -3.23606897749979, 
    2.3511420091698927`}, {221.05756436436528`, -1.6180349887498948`, 
    1.1755715045849462`}}], 
   Line3DBox[{{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}, {
    196.88954871074495`, -2.3511420091698927`, 3.23606897749979}, {
    221.05756436436528`, -1.1755715045849462`, 1.6180349887498948`}, {
    196.88954871074495`, -3.23606897749979, 2.3511420091698927`}}], 
   Line3DBox[{{221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}, {221.05756589754, -0.6180349887498949, 
    1.902114032590307}, {196.88954871074495`, -2.3511420091698927`, 
    3.23606897749979}, {221.05756436436528`, -1.1755715045849462`, 
    1.6180349887498948`}}], 
   Line3DBox[{{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}, {
    221.05756589754, -0.6180349887498949, 1.902114032590307}, {
    196.88954871074495`, -2.3511420091698927`, 3.23606897749979}}], 
   Line3DBox[{{221.05756589754, -0.6180349887498949, 1.902114032590307}, {
    221.05756881381186`, -1.*^-6, 2.000001}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}, {
    221.05756589754, -0.6180349887498949, 1.902114032590307}}], 
   Line3DBox[{{196.8895504095156, -1.2360689774997897`, 
    3.8042270651806143`}, {196.88955364076963`, -1.*^-6, 4.000001}, {
    221.05756881381186`, -1.*^-6, 2.000001}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}}], 
   Line3DBox[{{221.05756881381186`, -1.*^-6, 2.000001}, {221.05757282771617`, 
    0.6180329887498949, 1.902114032590307}, {196.88955364076963`, -1.*^-6, 
    4.000001}, {221.05756881381186`, -1.*^-6, 2.000001}}], 
   Line3DBox[{{196.88955364076963`, -1.*^-6, 4.000001}, {196.88955808820958`, 
    1.2360669774997899`, 3.8042270651806143`}, {221.05757282771617`, 
    0.6180329887498949, 1.902114032590307}, {196.88955364076963`, -1.*^-6, 
    4.000001}}], 
   Line3DBox[{{221.05757282771617`, 0.6180329887498949, 1.902114032590307}, {
    221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}, {
    196.88955808820958`, 1.2360669774997899`, 3.8042270651806143`}, {
    221.05757282771617`, 0.6180329887498949, 1.902114032590307}}], 
   Line3DBox[{{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}, {196.88956331648936`, 2.3511400091698924`, 
    3.23606897749979}, {221.0575775463444, 1.1755695045849464`, 
    1.6180349887498948`}, {196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}}], 
   Line3DBox[{{221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}, {
    221.0575825078045, 1.618032988749895, 1.1755715045849462`}, {
    196.88956331648936`, 2.3511400091698924`, 3.23606897749979}, {
    221.0575775463444, 1.1755695045849464`, 1.6180349887498948`}}], 
   Line3DBox[{{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    221.0575825078045, 1.618032988749895, 1.1755715045849462`}, {
    196.88956331648936`, 2.3511400091698924`, 3.23606897749979}}], 
   Line3DBox[{{221.0575825078045, 1.618032988749895, 1.1755715045849462`}, {
    221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    221.0575825078045, 1.618032988749895, 1.1755715045849462`}}], 
   Line3DBox[{{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}}], 
   Line3DBox[{{221.05758722643426`, 1.9021120325903071`, 
    0.6180349887498949}, {221.05759124034108`, 1.999999, 1.*^-6}, {
    196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    221.05758722643426`, 1.9021120325903071`, 0.6180349887498949}}], 
   Line3DBox[{{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    196.88957848955158`, 3.999999, 1.*^-6}, {221.05759124034108`, 1.999999, 
    1.*^-6}, {196.88957404210967`, 3.804225065180614, 1.2360689774997897`}}], 
   Line3DBox[{{221.05759124034108`, 1.999999, 1.*^-6}, {221.0575941566154, 
    1.9021120325903071`, -0.6180329887498949}, {196.88957848955158`, 3.999999,
     1.*^-6}, {221.05759124034108`, 1.999999, 1.*^-6}}], 
   Line3DBox[{{196.88957848955158`, 3.999999, 1.*^-6}, {196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}, {221.0575941566154, 
    1.9021120325903071`, -0.6180329887498949}, {196.88957848955158`, 3.999999,
     1.*^-6}}], 
   Line3DBox[{{221.0575941566154, 1.9021120325903071`, -0.6180329887498949}, {
    221.0575956897917, 1.618032988749895, -1.1755695045849464`}, {
    196.88958172080754`, 3.804225065180614, -1.2360669774997899`}, {
    221.0575941566154, 1.9021120325903071`, -0.6180329887498949}}], 
   Line3DBox[{{196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}, {196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}, {221.0575956897917, 
    1.618032988749895, -1.1755695045849464`}, {196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}}], 
   Line3DBox[{{221.0575956897917, 1.618032988749895, -1.1755695045849464`}, {
    221.0575956897917, 1.1755695045849464`, -1.618032988749895}, {
    196.88958341957942`, 3.2360669774997897`, -2.3511400091698924`}, {
    221.0575956897917, 1.618032988749895, -1.1755695045849464`}}], 
   Line3DBox[{{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}, {196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}, {221.0575956897917, 
    1.1755695045849464`, -1.618032988749895}, {196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}}], 
   Line3DBox[{{221.0575956897917, 1.1755695045849464`, -1.618032988749895}, {
    221.0575941566154, 0.6180329887498949, -1.9021120325903071`}, {
    196.88958341957942`, 2.3511400091698924`, -3.2360669774997897`}, {
    221.0575956897917, 1.1755695045849464`, -1.618032988749895}}], 
   Line3DBox[{{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {221.0575941566154, 
    0.6180329887498949, -1.9021120325903071`}, {196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}}], 
   Line3DBox[{{221.0575941566154, 0.6180329887498949, -1.9021120325903071`}, {
    221.05759124034108`, -1.*^-6, -1.999999}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {221.0575941566154, 
    0.6180329887498949, -1.9021120325903071`}}], 
   Line3DBox[{{196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {
    196.88957848955158`, -1.*^-6, -3.999999}, {
    221.05759124034108`, -1.*^-6, -1.999999}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}}], 
   Line3DBox[{{221.05759124034108`, -1.*^-6, -1.999999}, {
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}, {
    196.88957848955158`, -1.*^-6, -3.999999}, {
    221.05759124034108`, -1.*^-6, -1.999999}}], 
   Line3DBox[{{196.88957848955158`, -1.*^-6, -3.999999}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}, {
    196.88957848955158`, -1.*^-6, -3.999999}}], 
   Line3DBox[{{
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}, {
    221.0575825078045, -1.1755715045849462`, -1.618032988749895}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    221.05758722643426`, -0.6180349887498949, -1.9021120325903071`}}], 
   Line3DBox[{{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    221.0575825078045, -1.1755715045849462`, -1.618032988749895}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}}], 
   Line3DBox[{{221.0575825078045, -1.1755715045849462`, -1.618032988749895}, {
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    221.0575825078045, -1.1755715045849462`, -1.618032988749895}}], 
   Line3DBox[{{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}}], 
   Line3DBox[{{
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}, {
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    221.0575775463444, -1.6180349887498948`, -1.1755695045849464`}}], 
   Line3DBox[{{
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}}], 
   Line3DBox[{{
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}, {
    221.05756881381186`, -2.000001, 1.*^-6}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    221.05757282771617`, -1.902114032590307, -0.6180329887498949}}], 
   Line3DBox[{{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    196.88955364076963`, -4.000001, 1.*^-6}, {221.05756881381186`, -2.000001, 
    1.*^-6}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}}], 
   Line3DBox[{{196.88955364076963`, -4.000001, 1.*^-6}, {
    196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}, {
    173.5208693388187, -6.000001, 1.*^-6}, {196.88955364076963`, -4.000001, 
    1.*^-6}}], 
   Line3DBox[{{173.5208693388187, -6.000001, 1.*^-6}, {
    173.5208666220358, -5.706340097770921, 1.8541029662496846`}, {
    196.8895504095156, -3.8042270651806143`, 1.2360689774997897`}, {
    173.5208693388187, -6.000001, 1.*^-6}}], 
   Line3DBox[{{196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}, {196.88954871074495`, -3.23606897749979, 
    2.3511420091698927`}, {173.5208666220358, -5.706340097770921, 
    1.8541029662496846`}, {196.8895504095156, -3.8042270651806143`, 
    1.2360689774997897`}}], 
   Line3DBox[{{173.5208666220358, -5.706340097770921, 1.8541029662496846`}, {
    173.5208651937386, -4.854102966249685, 3.526712513754839}, {
    196.88954871074495`, -3.23606897749979, 2.3511420091698927`}, {
    173.5208666220358, -5.706340097770921, 1.8541029662496846`}}], 
   Line3DBox[{{196.88954871074495`, -3.23606897749979, 2.3511420091698927`}, {
    196.88954871074495`, -2.3511420091698927`, 3.23606897749979}, {
    173.5208651937386, -4.854102966249685, 3.526712513754839}, {
    196.88954871074495`, -3.23606897749979, 2.3511420091698927`}}], 
   Line3DBox[{{173.5208651937386, -4.854102966249685, 3.526712513754839}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    196.88954871074495`, -2.3511420091698927`, 3.23606897749979}, {
    173.5208651937386, -4.854102966249685, 3.526712513754839}}], 
   Line3DBox[{{196.88954871074495`, -2.3511420091698927`, 3.23606897749979}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    196.88954871074495`, -2.3511420091698927`, 3.23606897749979}}], 
   Line3DBox[{{173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}}], 
   Line3DBox[{{196.8895504095156, -1.2360689774997897`, 
    3.8042270651806143`}, {196.88955364076963`, -1.*^-6, 4.000001}, {
    173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    196.8895504095156, -1.2360689774997897`, 3.8042270651806143`}}], 
   Line3DBox[{{173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    173.5208693388187, -1.*^-6, 6.000001}, {196.88955364076963`, -1.*^-6, 
    4.000001}, {173.5208666220358, -1.8541029662496846`, 5.706340097770921}}],
    Line3DBox[{{196.88955364076963`, -1.*^-6, 4.000001}, {196.88955808820958`,
     1.2360669774997899`, 3.8042270651806143`}, {173.5208693388187, -1.*^-6, 
    6.000001}, {196.88955364076963`, -1.*^-6, 4.000001}}], 
   Line3DBox[{{173.5208693388187, -1.*^-6, 6.000001}, {173.52087307814995`, 
    1.8541009662496848`, 5.706340097770921}, {196.88955808820958`, 
    1.2360669774997899`, 3.8042270651806143`}, {173.5208693388187, -1.*^-6, 
    6.000001}}], 
   Line3DBox[{{196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}, {196.88956331648936`, 2.3511400091698924`, 
    3.23606897749979}, {173.52087307814995`, 1.8541009662496848`, 
    5.706340097770921}, {196.88955808820958`, 1.2360669774997899`, 
    3.8042270651806143`}}], 
   Line3DBox[{{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    196.88956331648936`, 2.3511400091698924`, 3.23606897749979}, {
    173.52087307814995`, 1.8541009662496848`, 5.706340097770921}}], 
   Line3DBox[{{196.88956331648936`, 2.3511400091698924`, 3.23606897749979}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    196.88956331648936`, 2.3511400091698924`, 3.23606897749979}}], 
   Line3DBox[{{173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}}], 
   Line3DBox[{{196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}, {
    196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    196.8895688138287, 3.2360669774997897`, 2.3511420091698927`}}], 
   Line3DBox[{{173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    173.52088649191623`, 5.706338097770921, 1.8541029662496846`}, {
    196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}}], 
   Line3DBox[{{196.88957404210967`, 3.804225065180614, 1.2360689774997897`}, {
    196.88957848955158`, 3.999999, 1.*^-6}, {173.52088649191623`, 
    5.706338097770921, 1.8541029662496846`}, {196.88957404210967`, 
    3.804225065180614, 1.2360689774997897`}}], 
   Line3DBox[{{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}, {
    173.52089023124947`, 5.999999, 1.*^-6}, {196.88957848955158`, 3.999999, 
    1.*^-6}, {173.52088649191623`, 5.706338097770921, 1.8541029662496846`}}], 
   Line3DBox[{{196.88957848955158`, 3.999999, 1.*^-6}, {196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}, {173.52089023124947`, 5.999999, 
    1.*^-6}, {196.88957848955158`, 3.999999, 1.*^-6}}], 
   Line3DBox[{{173.52089023124947`, 5.999999, 1.*^-6}, {173.5208929480344, 
    5.706338097770921, -1.8541009662496848`}, {196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}, {173.52089023124947`, 5.999999, 
    1.*^-6}}], 
   Line3DBox[{{196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}, {196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}, {173.5208929480344, 
    5.706338097770921, -1.8541009662496848`}, {196.88958172080754`, 
    3.804225065180614, -1.2360669774997899`}}], 
   Line3DBox[{{173.5208929480344, 5.706338097770921, -1.8541009662496848`}, {
    173.52089437633285`, 4.854100966249685, -3.5267105137548387`}, {
    196.88958341957942`, 3.2360669774997897`, -2.3511400091698924`}, {
    173.5208929480344, 5.706338097770921, -1.8541009662496848`}}], 
   Line3DBox[{{196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}, {196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}, {173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}, {196.88958341957942`, 
    3.2360669774997897`, -2.3511400091698924`}}], 
   Line3DBox[{{173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}, {173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}, {196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}, {173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}}], 
   Line3DBox[{{196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}, {196.88958341957942`, 
    2.3511400091698924`, -3.2360669774997897`}}], 
   Line3DBox[{{173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}, {173.5208929480344, 
    1.8541009662496848`, -5.706338097770921}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}}], 
   Line3DBox[{{196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}, {
    196.88957848955158`, -1.*^-6, -3.999999}, {173.5208929480344, 
    1.8541009662496848`, -5.706338097770921}, {196.88958172080754`, 
    1.2360669774997899`, -3.804225065180614}}], 
   Line3DBox[{{173.5208929480344, 1.8541009662496848`, -5.706338097770921}, {
    173.52089023124947`, -1.*^-6, -5.999999}, {
    196.88957848955158`, -1.*^-6, -3.999999}, {173.5208929480344, 
    1.8541009662496848`, -5.706338097770921}}], 
   Line3DBox[{{196.88957848955158`, -1.*^-6, -3.999999}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    173.52089023124947`, -1.*^-6, -5.999999}, {
    196.88957848955158`, -1.*^-6, -3.999999}}], 
   Line3DBox[{{173.52089023124947`, -1.*^-6, -5.999999}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    173.52089023124947`, -1.*^-6, -5.999999}}], 
   Line3DBox[{{
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    196.88957404210967`, -1.2360689774997897`, -3.804225065180614}}], 
   Line3DBox[{{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}}], 
   Line3DBox[{{
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    196.8895688138287, -2.3511420091698927`, -3.2360669774997897`}}], 
   Line3DBox[{{173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}}], 
   Line3DBox[{{
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    196.88956331648936`, -3.23606897749979, -2.3511400091698924`}}], 
   Line3DBox[{{173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}}], 
   Line3DBox[{{
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}, {
    196.88955364076963`, -4.000001, 1.*^-6}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    196.88955808820958`, -3.8042270651806143`, -1.2360669774997899`}}], 
   Line3DBox[{{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    173.5208693388187, -6.000001, 1.*^-6}, {196.88955364076963`, -4.000001, 
    1.*^-6}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}}], 
   Line3DBox[{{173.5208693388187, -6.000001, 1.*^-6}, {
    173.5208666220358, -5.706340097770921, 1.8541029662496846`}, {
    156.6467006904059, -8.000001, 1.*^-6}, {173.5208693388187, -6.000001, 
    1.*^-6}}], 
   Line3DBox[{{156.6467006904059, -8.000001, 1.*^-6}, {
    156.64669907999547`, -7.608453130361228, 2.4721369549995797`}, {
    173.5208666220358, -5.706340097770921, 1.8541029662496846`}, {
    156.6467006904059, -8.000001, 1.*^-6}}], 
   Line3DBox[{{173.5208666220358, -5.706340097770921, 1.8541029662496846`}, {
    173.5208651937386, -4.854102966249685, 3.526712513754839}, {
    156.64669907999547`, -7.608453130361228, 2.4721369549995797`}, {
    173.5208666220358, -5.706340097770921, 1.8541029662496846`}}], 
   Line3DBox[{{156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}, {156.64669823335268`, -6.47213695499958, 
    4.702283018339785}, {173.5208651937386, -4.854102966249685, 
    3.526712513754839}, {156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}}], 
   Line3DBox[{{173.5208651937386, -4.854102966249685, 3.526712513754839}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    156.64669823335268`, -6.47213695499958, 4.702283018339785}, {
    173.5208651937386, -4.854102966249685, 3.526712513754839}}], 
   Line3DBox[{{156.64669823335268`, -6.47213695499958, 4.702283018339785}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    156.64669823335268`, -6.47213695499958, 4.702283018339785}}], 
   Line3DBox[{{173.5208651937386, -3.526712513754839, 4.854102966249685}, {
    173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    173.5208651937386, -3.526712513754839, 4.854102966249685}}], 
   Line3DBox[{{156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}, {
    173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}}], 
   Line3DBox[{{173.5208666220358, -1.8541029662496846`, 5.706340097770921}, {
    173.5208693388187, -1.*^-6, 6.000001}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}, {
    173.5208666220358, -1.8541029662496846`, 5.706340097770921}}], 
   Line3DBox[{{156.64669907999547`, -2.4721369549995797`, 
    7.608453130361228}, {156.6467006904059, -1.*^-6, 8.000001}, {
    173.5208693388187, -1.*^-6, 6.000001}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}}], 
   Line3DBox[{{173.5208693388187, -1.*^-6, 6.000001}, {173.52087307814995`, 
    1.8541009662496848`, 5.706340097770921}, {156.6467006904059, -1.*^-6, 
    8.000001}, {173.5208693388187, -1.*^-6, 6.000001}}], 
   Line3DBox[{{156.6467006904059, -1.*^-6, 8.000001}, {156.64670290694602`, 
    2.4721349549995795`, 7.608453130361228}, {173.52087307814995`, 
    1.8541009662496848`, 5.706340097770921}, {156.6467006904059, -1.*^-6, 
    8.000001}}], 
   Line3DBox[{{173.52087307814995`, 1.8541009662496848`, 5.706340097770921}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    156.64670290694602`, 2.4721349549995795`, 7.608453130361228}, {
    173.52087307814995`, 1.8541009662496848`, 5.706340097770921}}], 
   Line3DBox[{{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    156.64670290694602`, 2.4721349549995795`, 7.608453130361228}}], 
   Line3DBox[{{173.520877473998, 3.5267105137548387`, 4.854102966249685}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    173.520877473998, 3.5267105137548387`, 4.854102966249685}}], 
   Line3DBox[{{156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}}], 
   Line3DBox[{{173.52088209606688`, 4.854100966249685, 3.526712513754839}, {
    173.52088649191623`, 5.706338097770921, 1.8541029662496846`}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    173.52088209606688`, 4.854100966249685, 3.526712513754839}}], 
   Line3DBox[{{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    156.6467108581421, 7.608451130361228, 2.4721369549995797`}, {
    173.52088649191623`, 5.706338097770921, 1.8541029662496846`}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}}], 
   Line3DBox[{{173.52088649191623`, 5.706338097770921, 1.8541029662496846`}, {
    173.52089023124947`, 5.999999, 1.*^-6}, {156.6467108581421, 
    7.608451130361228, 2.4721369549995797`}, {173.52088649191623`, 
    5.706338097770921, 1.8541029662496846`}}], 
   Line3DBox[{{156.6467108581421, 7.608451130361228, 2.4721369549995797`}, {
    156.6467130746841, 7.999999, 1.*^-6}, {173.52089023124947`, 5.999999, 
    1.*^-6}, {156.6467108581421, 7.608451130361228, 2.4721369549995797`}}], 
   Line3DBox[{{173.52089023124947`, 5.999999, 1.*^-6}, {173.5208929480344, 
    5.706338097770921, -1.8541009662496848`}, {156.6467130746841, 7.999999, 
    1.*^-6}, {173.52089023124947`, 5.999999, 1.*^-6}}], 
   Line3DBox[{{156.6467130746841, 7.999999, 1.*^-6}, {156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}, {173.5208929480344, 
    5.706338097770921, -1.8541009662496848`}, {156.6467130746841, 7.999999, 
    1.*^-6}}], 
   Line3DBox[{{173.5208929480344, 5.706338097770921, -1.8541009662496848`}, {
    173.52089437633285`, 4.854100966249685, -3.5267105137548387`}, {
    156.64671468509638`, 7.608451130361228, -2.4721349549995795`}, {
    173.5208929480344, 5.706338097770921, -1.8541009662496848`}}], 
   Line3DBox[{{156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}, {156.6467155317403, 
    6.4721349549995795`, -4.702281018339785}, {173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}, {156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}}], 
   Line3DBox[{{173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}, {173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}, {156.6467155317403, 
    6.4721349549995795`, -4.702281018339785}, {173.52089437633285`, 
    4.854100966249685, -3.5267105137548387`}}], 
   Line3DBox[{{156.6467155317403, 6.4721349549995795`, -4.702281018339785}, {
    156.6467155317403, 4.702281018339785, -6.4721349549995795`}, {
    173.52089437633285`, 3.5267105137548387`, -4.854100966249685}, {
    156.6467155317403, 6.4721349549995795`, -4.702281018339785}}], 
   Line3DBox[{{173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}, {173.5208929480344, 
    1.8541009662496848`, -5.706338097770921}, {156.6467155317403, 
    4.702281018339785, -6.4721349549995795`}, {173.52089437633285`, 
    3.5267105137548387`, -4.854100966249685}}], 
   Line3DBox[{{156.6467155317403, 4.702281018339785, -6.4721349549995795`}, {
    156.64671468509638`, 2.4721349549995795`, -7.608451130361228}, {
    173.5208929480344, 1.8541009662496848`, -5.706338097770921}, {
    156.6467155317403, 4.702281018339785, -6.4721349549995795`}}], 
   Line3DBox[{{173.5208929480344, 1.8541009662496848`, -5.706338097770921}, {
    173.52089023124947`, -1.*^-6, -5.999999}, {156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}, {173.5208929480344, 
    1.8541009662496848`, -5.706338097770921}}], 
   Line3DBox[{{156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}, {
    156.6467130746841, -1.*^-6, -7.999999}, {
    173.52089023124947`, -1.*^-6, -5.999999}, {156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}}], 
   Line3DBox[{{173.52089023124947`, -1.*^-6, -5.999999}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    156.6467130746841, -1.*^-6, -7.999999}, {
    173.52089023124947`, -1.*^-6, -5.999999}}], 
   Line3DBox[{{156.6467130746841, -1.*^-6, -7.999999}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    156.6467130746841, -1.*^-6, -7.999999}}], 
   Line3DBox[{{
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    173.52088649191623`, -1.8541029662496846`, -5.706338097770921}}], 
   Line3DBox[{{156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}}], 
   Line3DBox[{{173.52088209606688`, -3.526712513754839, -4.854100966249685}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    173.52088209606688`, -3.526712513754839, -4.854100966249685}}], 
   Line3DBox[{{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}}], 
   Line3DBox[{{173.520877473998, -4.854102966249685, -3.5267105137548387`}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    173.520877473998, -4.854102966249685, -3.5267105137548387`}}], 
   Line3DBox[{{156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}}], 
   Line3DBox[{{
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}, {
    173.5208693388187, -6.000001, 1.*^-6}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    173.52087307814995`, -5.706340097770921, -1.8541009662496848`}}], 
   Line3DBox[{{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    156.6467006904059, -8.000001, 1.*^-6}, {173.5208693388187, -6.000001, 
    1.*^-6}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}}], 
   Line3DBox[{{156.6467006904059, -8.000001, 1.*^-6}, {
    156.64669907999547`, -7.608453130361228, 2.4721369549995797`}, {
    148.96345978973739`, -10.000001, 1.*^-6}, {156.6467006904059, -8.000001, 
    1.*^-6}}], 
   Line3DBox[{{148.96345978973739`, -10.000001, 1.*^-6}, {
    148.96345936674507`, -9.510566162951534, 3.0901709437494747`}, {
    156.64669907999547`, -7.608453130361228, 2.4721369549995797`}, {
    148.96345978973739`, -10.000001, 1.*^-6}}], 
   Line3DBox[{{156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}, {156.64669823335268`, -6.47213695499958, 
    4.702283018339785}, {148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}, {156.64669907999547`, -7.608453130361228, 
    2.4721369549995797`}}], 
   Line3DBox[{{148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}, {148.9634591443649, -8.090170943749474, 
    5.877853522924732}, {156.64669823335268`, -6.47213695499958, 
    4.702283018339785}, {148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}}], 
   Line3DBox[{{156.64669823335268`, -6.47213695499958, 4.702283018339785}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    148.9634591443649, -8.090170943749474, 5.877853522924732}, {
    156.64669823335268`, -6.47213695499958, 4.702283018339785}}], 
   Line3DBox[{{148.9634591443649, -8.090170943749474, 5.877853522924732}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    148.9634591443649, -8.090170943749474, 5.877853522924732}}], 
   Line3DBox[{{156.64669823335268`, -4.702283018339785, 6.47213695499958}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    156.64669823335268`, -4.702283018339785, 6.47213695499958}}], 
   Line3DBox[{{148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}}], 
   Line3DBox[{{156.64669907999547`, -2.4721369549995797`, 
    7.608453130361228}, {156.6467006904059, -1.*^-6, 8.000001}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}, {
    156.64669907999547`, -2.4721369549995797`, 7.608453130361228}}], 
   Line3DBox[{{148.96345936674507`, -3.0901709437494747`, 
    9.510566162951534}, {148.96345978973739`, -1.*^-6, 10.000001}, {
    156.6467006904059, -1.*^-6, 8.000001}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}}], 
   Line3DBox[{{156.6467006904059, -1.*^-6, 8.000001}, {156.64670290694602`, 
    2.4721349549995795`, 7.608453130361228}, {148.96345978973739`, -1.*^-6, 
    10.000001}, {156.6467006904059, -1.*^-6, 8.000001}}], 
   Line3DBox[{{148.96345978973739`, -1.*^-6, 10.000001}, {148.96346037193658`,
     3.0901689437494744`, 9.510566162951534}, {156.64670290694602`, 
    2.4721349549995795`, 7.608453130361228}, {148.96345978973739`, -1.*^-6, 
    10.000001}}], 
   Line3DBox[{{156.64670290694602`, 2.4721349549995795`, 7.608453130361228}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    148.96346037193658`, 3.0901689437494744`, 9.510566162951534}, {
    156.64670290694602`, 2.4721349549995795`, 7.608453130361228}}], 
   Line3DBox[{{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}, {
    148.96346105635314`, 5.877851522924732, 8.090170943749474}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    148.96346037193658`, 3.0901689437494744`, 9.510566162951534}}], 
   Line3DBox[{{156.64670551264578`, 4.702281018339785, 6.47213695499958}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    148.96346105635314`, 5.877851522924732, 8.090170943749474}, {
    156.64670551264578`, 4.702281018339785, 6.47213695499958}}], 
   Line3DBox[{{148.96346105635314`, 5.877851522924732, 8.090170943749474}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    148.96346105635314`, 5.877851522924732, 8.090170943749474}}], 
   Line3DBox[{{156.64670825244121`, 6.4721349549995795`, 4.702283018339785}, {
    156.6467108581421, 7.608451130361228, 2.4721369549995797`}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    156.64670825244121`, 6.4721349549995795`, 4.702283018339785}}], 
   Line3DBox[{{148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    148.963462460409, 9.510564162951535, 3.0901709437494747`}, {
    156.6467108581421, 7.608451130361228, 2.4721369549995797`}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}}], 
   Line3DBox[{{156.6467108581421, 7.608451130361228, 2.4721369549995797`}, {
    156.6467130746841, 7.999999, 1.*^-6}, {148.963462460409, 
    9.510564162951535, 3.0901709437494747`}, {156.6467108581421, 
    7.608451130361228, 2.4721369549995797`}}], 
   Line3DBox[{{148.963462460409, 9.510564162951535, 3.0901709437494747`}, {
    148.96346304260948`, 9.999999, 1.*^-6}, {156.6467130746841, 7.999999, 
    1.*^-6}, {148.963462460409, 9.510564162951535, 3.0901709437494747`}}], 
   Line3DBox[{{156.6467130746841, 7.999999, 1.*^-6}, {156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}, {148.96346304260948`, 9.999999, 
    1.*^-6}, {156.6467130746841, 7.999999, 1.*^-6}}], 
   Line3DBox[{{148.96346304260948`, 9.999999, 1.*^-6}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}, {148.96346304260948`, 9.999999, 
    1.*^-6}}], 
   Line3DBox[{{156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}, {156.6467155317403, 
    6.4721349549995795`, -4.702281018339785}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {156.64671468509638`, 
    7.608451130361228, -2.4721349549995795`}}], 
   Line3DBox[{{148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {148.963463687984, 
    8.090168943749475, -5.877851522924732}, {156.6467155317403, 
    6.4721349549995795`, -4.702281018339785}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}}], 
   Line3DBox[{{156.6467155317403, 6.4721349549995795`, -4.702281018339785}, {
    156.6467155317403, 4.702281018339785, -6.4721349549995795`}, {
    148.963463687984, 8.090168943749475, -5.877851522924732}, {
    156.6467155317403, 6.4721349549995795`, -4.702281018339785}}], 
   Line3DBox[{{148.963463687984, 8.090168943749475, -5.877851522924732}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}, {
    156.6467155317403, 4.702281018339785, -6.4721349549995795`}, {
    148.963463687984, 8.090168943749475, -5.877851522924732}}], 
   Line3DBox[{{156.6467155317403, 4.702281018339785, -6.4721349549995795`}, {
    156.64671468509638`, 2.4721349549995795`, -7.608451130361228}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}, {
    156.6467155317403, 4.702281018339785, -6.4721349549995795`}}], 
   Line3DBox[{{148.963463687984, 5.877851522924732, -8.090168943749475}, {
    148.96346346560304`, 3.0901689437494744`, -9.510564162951535}, {
    156.64671468509638`, 2.4721349549995795`, -7.608451130361228}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}}], 
   Line3DBox[{{156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}, {
    156.6467130746841, -1.*^-6, -7.999999}, {148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}, {156.64671468509638`, 
    2.4721349549995795`, -7.608451130361228}}], 
   Line3DBox[{{148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}, {
    148.96346304260948`, -1.*^-6, -9.999999}, {
    156.6467130746841, -1.*^-6, -7.999999}, {148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}}], 
   Line3DBox[{{156.6467130746841, -1.*^-6, -7.999999}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    148.96346304260948`, -1.*^-6, -9.999999}, {
    156.6467130746841, -1.*^-6, -7.999999}}], 
   Line3DBox[{{148.96346304260948`, -1.*^-6, -9.999999}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    148.96346304260948`, -1.*^-6, -9.999999}}], 
   Line3DBox[{{156.6467108581421, -2.4721369549995797`, -7.608451130361228}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    156.6467108581421, -2.4721369549995797`, -7.608451130361228}}], 
   Line3DBox[{{148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}}], 
   Line3DBox[{{
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    156.64670825244121`, -4.702283018339785, -6.4721349549995795`}}], 
   Line3DBox[{{148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}}], 
   Line3DBox[{{156.64670551264578`, -6.47213695499958, -4.702281018339785}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    156.64670551264578`, -6.47213695499958, -4.702281018339785}}], 
   Line3DBox[{{148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}}], 
   Line3DBox[{{
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}, {
    156.6467006904059, -8.000001, 1.*^-6}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    156.64670290694602`, -7.608453130361228, -2.4721349549995795`}}], 
   Line3DBox[{{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    148.96345978973739`, -10.000001, 1.*^-6}, {156.6467006904059, -8.000001, 
    1.*^-6}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}}], 
   Line3DBox[{{148.96345978973739`, -10.000001, 1.*^-6}, {
    148.96345936674507`, -9.510566162951534, 3.0901709437494747`}, {
    148.92374678570366`, -12.000001, 1.*^-6}, {
    148.96345978973739`, -10.000001, 1.*^-6}}], 
   Line3DBox[{{148.92374678570366`, -12.000001, 1.*^-6}, {
    148.92374708289748`, -11.412679195541841`, 3.7082049324993696`}, {
    148.96345936674507`, -9.510566162951534, 3.0901709437494747`}, {
    148.92374678570366`, -12.000001, 1.*^-6}}], 
   Line3DBox[{{148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}, {148.9634591443649, -8.090170943749474, 
    5.877853522924732}, {148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}, {148.96345936674507`, -9.510566162951534, 
    3.0901709437494747`}}], 
   Line3DBox[{{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}, {148.92374723914156`, -9.708204932499369, 
    7.053424027509678}, {148.9634591443649, -8.090170943749474, 
    5.877853522924732}, {148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}}], 
   Line3DBox[{{148.9634591443649, -8.090170943749474, 5.877853522924732}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    148.92374723914156`, -9.708204932499369, 7.053424027509678}, {
    148.9634591443649, -8.090170943749474, 5.877853522924732}}], 
   Line3DBox[{{148.92374723914156`, -9.708204932499369, 7.053424027509678}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    148.92374723914156`, -9.708204932499369, 7.053424027509678}}], 
   Line3DBox[{{148.9634591443649, -5.877853522924732, 8.090170943749474}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    148.9634591443649, -5.877853522924732, 8.090170943749474}}], 
   Line3DBox[{{148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}}], 
   Line3DBox[{{148.96345936674507`, -3.0901709437494747`, 
    9.510566162951534}, {148.96345978973739`, -1.*^-6, 10.000001}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}, {
    148.96345936674507`, -3.0901709437494747`, 9.510566162951534}}], 
   Line3DBox[{{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}, {148.92374678570366`, -1.*^-6, 12.000001}, {
    148.96345978973739`, -1.*^-6, 10.000001}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}}], 
   Line3DBox[{{148.96345978973739`, -1.*^-6, 10.000001}, {148.96346037193658`,
     3.0901689437494744`, 9.510566162951534}, {148.92374678570366`, -1.*^-6, 
    12.000001}, {148.96345978973739`, -1.*^-6, 10.000001}}], 
   Line3DBox[{{148.92374678570366`, -1.*^-6, 12.000001}, {148.92374637665148`,
     3.7082029324993693`, 11.412679195541841`}, {148.96346037193658`, 
    3.0901689437494744`, 9.510566162951534}, {148.92374678570366`, -1.*^-6, 
    12.000001}}], 
   Line3DBox[{{148.96346037193658`, 3.0901689437494744`, 9.510566162951534}, {
    148.96346105635314`, 5.877851522924732, 8.090170943749474}, {
    148.92374637665148`, 3.7082029324993693`, 11.412679195541841`}, {
    148.96346037193658`, 3.0901689437494744`, 9.510566162951534}}], 
   Line3DBox[{{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}, {148.9237458957819, 7.0534220275096775`, 
    9.708204932499369}, {148.96346105635314`, 5.877851522924732, 
    8.090170943749474}, {148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}}], 
   Line3DBox[{{148.96346105635314`, 5.877851522924732, 8.090170943749474}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    148.9237458957819, 7.0534220275096775`, 9.708204932499369}, {
    148.96346105635314`, 5.877851522924732, 8.090170943749474}}], 
   Line3DBox[{{148.9237458957819, 7.0534220275096775`, 9.708204932499369}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    148.9237458957819, 7.0534220275096775`, 9.708204932499369}}], 
   Line3DBox[{{148.96346177599168`, 8.090168943749475, 5.877853522924732}, {
    148.963462460409, 9.510564162951535, 3.0901709437494747`}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    148.96346177599168`, 8.090168943749475, 5.877853522924732}}], 
   Line3DBox[{{148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    148.92374490929643`, 11.412677195541843`, 3.7082049324993696`}, {
    148.963462460409, 9.510564162951535, 3.0901709437494747`}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}}], 
   Line3DBox[{{148.963462460409, 9.510564162951535, 3.0901709437494747`}, {
    148.96346304260948`, 9.999999, 1.*^-6}, {148.92374490929643`, 
    11.412677195541843`, 3.7082049324993696`}, {148.963462460409, 
    9.510564162951535, 3.0901709437494747`}}], 
   Line3DBox[{{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}, {148.9237445002446, 11.999999, 1.*^-6}, {
    148.96346304260948`, 9.999999, 1.*^-6}, {148.92374490929643`, 
    11.412677195541843`, 3.7082049324993696`}}], 
   Line3DBox[{{148.96346304260948`, 9.999999, 1.*^-6}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {148.9237445002446, 11.999999, 
    1.*^-6}, {148.96346304260948`, 9.999999, 1.*^-6}}], 
   Line3DBox[{{148.9237445002446, 11.999999, 1.*^-6}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {148.9237445002446, 11.999999, 
    1.*^-6}}], 
   Line3DBox[{{148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}, {148.963463687984, 
    8.090168943749475, -5.877851522924732}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {148.96346346560304`, 
    9.510564162951535, -3.0901689437494744`}}], 
   Line3DBox[{{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {148.92374404680726`, 
    9.70820293249937, -7.0534220275096775`}, {148.963463687984, 
    8.090168943749475, -5.877851522924732}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}}], 
   Line3DBox[{{148.963463687984, 8.090168943749475, -5.877851522924732}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}, {
    148.92374404680726`, 9.70820293249937, -7.0534220275096775`}, {
    148.963463687984, 8.090168943749475, -5.877851522924732}}], 
   Line3DBox[{{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}, {
    148.92374404680726`, 7.0534220275096775`, -9.70820293249937}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}, {
    148.92374404680726`, 9.70820293249937, -7.0534220275096775`}}], 
   Line3DBox[{{148.963463687984, 5.877851522924732, -8.090168943749475}, {
    148.96346346560304`, 3.0901689437494744`, -9.510564162951535}, {
    148.92374404680726`, 7.0534220275096775`, -9.70820293249937}, {
    148.963463687984, 5.877851522924732, -8.090168943749475}}], 
   Line3DBox[{{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}, {
    148.92374420305111`, 3.7082029324993693`, -11.412677195541843`}, {
    148.96346346560304`, 3.0901689437494744`, -9.510564162951535}, {
    148.92374404680726`, 7.0534220275096775`, -9.70820293249937}}], 
   Line3DBox[{{148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}, {
    148.96346304260948`, -1.*^-6, -9.999999}, {148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}, {148.96346346560304`, 
    3.0901689437494744`, -9.510564162951535}}], 
   Line3DBox[{{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}, {
    148.9237445002446, -1.*^-6, -11.999999}, {
    148.96346304260948`, -1.*^-6, -9.999999}, {148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}}], 
   Line3DBox[{{148.96346304260948`, -1.*^-6, -9.999999}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    148.9237445002446, -1.*^-6, -11.999999}, {
    148.96346304260948`, -1.*^-6, -9.999999}}], 
   Line3DBox[{{148.9237445002446, -1.*^-6, -11.999999}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    148.9237445002446, -1.*^-6, -11.999999}}], 
   Line3DBox[{{148.963462460409, -3.0901709437494747`, -9.510564162951535}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    148.963462460409, -3.0901709437494747`, -9.510564162951535}}], 
   Line3DBox[{{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}}], 
   Line3DBox[{{148.96346177599168`, -5.877853522924732, -8.090168943749475}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    148.96346177599168`, -5.877853522924732, -8.090168943749475}}], 
   Line3DBox[{{148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}}], 
   Line3DBox[{{148.96346105635314`, -8.090170943749474, -5.877851522924732}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    148.96346105635314`, -8.090170943749474, -5.877851522924732}}], 
   Line3DBox[{{148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}}], 
   Line3DBox[{{
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}, {
    148.96345978973739`, -10.000001, 1.*^-6}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    148.96346037193658`, -9.510566162951534, -3.0901689437494744`}}], 
   Line3DBox[{{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    148.92374678570366`, -12.000001, 1.*^-6}, {
    148.96345978973739`, -10.000001, 1.*^-6}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}}], 
   Line3DBox[{{148.92374678570366`, -12.000001, 1.*^-6}, {
    148.92374708289748`, -11.412679195541841`, 3.7082049324993696`}, {
    151.45084510505546`, -14.000001, 1.*^-6}, {
    148.92374678570366`, -12.000001, 1.*^-6}}], 
   Line3DBox[{{151.45084510505546`, -14.000001, 1.*^-6}, {
    151.4508453226652, -13.314792228132148`, 4.3262389212492645`}, {
    148.92374708289748`, -11.412679195541841`, 3.7082049324993696`}, {
    151.45084510505546`, -14.000001, 1.*^-6}}], 
   Line3DBox[{{148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}, {148.92374723914156`, -9.708204932499369, 
    7.053424027509678}, {151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}, {148.92374708289748`, -11.412679195541841`, 
    3.7082049324993696`}}], 
   Line3DBox[{{151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}, {151.4508454370694, -11.326238921249264`, 
    8.228994532094623}, {148.92374723914156`, -9.708204932499369, 
    7.053424027509678}, {151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}}], 
   Line3DBox[{{148.92374723914156`, -9.708204932499369, 7.053424027509678}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    151.4508454370694, -11.326238921249264`, 8.228994532094623}, {
    148.92374723914156`, -9.708204932499369, 7.053424027509678}}], 
   Line3DBox[{{151.4508454370694, -11.326238921249264`, 8.228994532094623}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    151.4508454370694, -11.326238921249264`, 8.228994532094623}}], 
   Line3DBox[{{148.92374723914156`, -7.053424027509678, 9.708204932499369}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    148.92374723914156`, -7.053424027509678, 9.708204932499369}}], 
   Line3DBox[{{151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}}], 
   Line3DBox[{{148.92374708289748`, -3.7082049324993696`, 
    11.412679195541841`}, {148.92374678570366`, -1.*^-6, 12.000001}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}, {
    148.92374708289748`, -3.7082049324993696`, 11.412679195541841`}}], 
   Line3DBox[{{151.4508453226652, -4.3262389212492645`, 
    13.314792228132148`}, {151.45084510505546`, -1.*^-6, 14.000001}, {
    148.92374678570366`, -1.*^-6, 12.000001}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}}], 
   Line3DBox[{{148.92374678570366`, -1.*^-6, 12.000001}, {148.92374637665148`,
     3.7082029324993693`, 11.412679195541841`}, {151.45084510505546`, -1.*^-6,
     14.000001}, {148.92374678570366`, -1.*^-6, 12.000001}}], 
   Line3DBox[{{151.45084510505546`, -1.*^-6, 14.000001}, {151.45084480554118`,
     4.326236921249264, 13.314792228132148`}, {148.92374637665148`, 
    3.7082029324993693`, 11.412679195541841`}, {151.45084510505546`, -1.*^-6, 
    14.000001}}], 
   Line3DBox[{{148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}, {148.9237458957819, 7.0534220275096775`, 
    9.708204932499369}, {151.45084480554118`, 4.326236921249264, 
    13.314792228132148`}, {148.92374637665148`, 3.7082029324993693`, 
    11.412679195541841`}}], 
   Line3DBox[{{151.45084480554118`, 4.326236921249264, 13.314792228132148`}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    148.9237458957819, 7.0534220275096775`, 9.708204932499369}, {
    151.45084480554118`, 4.326236921249264, 13.314792228132148`}}], 
   Line3DBox[{{148.9237458957819, 7.0534220275096775`, 9.708204932499369}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    148.9237458957819, 7.0534220275096775`, 9.708204932499369}}], 
   Line3DBox[{{151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}}], 
   Line3DBox[{{148.9237453901658, 9.70820293249937, 7.053424027509678}, {
    148.92374490929643`, 11.412677195541843`, 3.7082049324993696`}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    148.9237453901658, 9.70820293249937, 7.053424027509678}}], 
   Line3DBox[{{151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    148.92374490929643`, 11.412677195541843`, 3.7082049324993696`}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}}], 
   Line3DBox[{{148.92374490929643`, 11.412677195541843`, 
    3.7082049324993696`}, {148.9237445002446, 11.999999, 1.*^-6}, {
    151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    148.92374490929643`, 11.412677195541843`, 3.7082049324993696`}}], 
   Line3DBox[{{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    151.450843431605, 13.999999, 1.*^-6}, {148.9237445002446, 11.999999, 
    1.*^-6}, {151.45084373111985`, 13.31479022813215, 4.3262389212492645`}}], 
   Line3DBox[{{148.9237445002446, 11.999999, 1.*^-6}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {151.450843431605, 13.999999, 
    1.*^-6}, {148.9237445002446, 11.999999, 1.*^-6}}], 
   Line3DBox[{{151.450843431605, 13.999999, 1.*^-6}, {151.45084321399463`, 
    13.31479022813215, -4.326236921249264}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {151.450843431605, 13.999999, 
    1.*^-6}}], 
   Line3DBox[{{148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}, {148.92374404680726`, 
    9.70820293249937, -7.0534220275096775`}, {151.45084321399463`, 
    13.31479022813215, -4.326236921249264}, {148.92374420305111`, 
    11.412677195541843`, -3.7082029324993693`}}], 
   Line3DBox[{{151.45084321399463`, 13.31479022813215, -4.326236921249264}, {
    151.45084309959006`, 11.326236921249265`, -8.228992532094624}, {
    148.92374404680726`, 9.70820293249937, -7.0534220275096775`}, {
    151.45084321399463`, 13.31479022813215, -4.326236921249264}}], 
   Line3DBox[{{148.92374404680726`, 9.70820293249937, -7.0534220275096775`}, {
    148.92374404680726`, 7.0534220275096775`, -9.70820293249937}, {
    151.45084309959006`, 11.326236921249265`, -8.228992532094624}, {
    148.92374404680726`, 9.70820293249937, -7.0534220275096775`}}], 
   Line3DBox[{{151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}, {151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}, {148.92374404680726`, 
    7.0534220275096775`, -9.70820293249937}, {151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}}], 
   Line3DBox[{{148.92374404680726`, 7.0534220275096775`, -9.70820293249937}, {
    148.92374420305111`, 3.7082029324993693`, -11.412677195541843`}, {
    151.45084309959006`, 8.228992532094624, -11.326236921249265`}, {
    148.92374404680726`, 7.0534220275096775`, -9.70820293249937}}], 
   Line3DBox[{{151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}, {151.45084321399463`, 
    4.326236921249264, -13.31479022813215}, {148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}, {151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}}], 
   Line3DBox[{{148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}, {
    148.9237445002446, -1.*^-6, -11.999999}, {151.45084321399463`, 
    4.326236921249264, -13.31479022813215}, {148.92374420305111`, 
    3.7082029324993693`, -11.412677195541843`}}], 
   Line3DBox[{{151.45084321399463`, 4.326236921249264, -13.31479022813215}, {
    151.450843431605, -1.*^-6, -13.999999}, {
    148.9237445002446, -1.*^-6, -11.999999}, {151.45084321399463`, 
    4.326236921249264, -13.31479022813215}}], 
   Line3DBox[{{148.9237445002446, -1.*^-6, -11.999999}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    151.450843431605, -1.*^-6, -13.999999}, {
    148.9237445002446, -1.*^-6, -11.999999}}], 
   Line3DBox[{{151.450843431605, -1.*^-6, -13.999999}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    151.450843431605, -1.*^-6, -13.999999}}], 
   Line3DBox[{{
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    148.92374490929643`, -3.7082049324993696`, -11.412677195541843`}}], 
   Line3DBox[{{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}}], 
   Line3DBox[{{148.9237453901658, -7.053424027509678, -9.70820293249937}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    148.9237453901658, -7.053424027509678, -9.70820293249937}}], 
   Line3DBox[{{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}}], 
   Line3DBox[{{148.9237458957819, -9.708204932499369, -7.0534220275096775`}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    148.9237458957819, -9.708204932499369, -7.0534220275096775`}}], 
   Line3DBox[{{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}}], 
   Line3DBox[{{
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}, {
    148.92374678570366`, -12.000001, 1.*^-6}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    148.92374637665148`, -11.412679195541841`, -3.7082029324993693`}}], 
   Line3DBox[{{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    151.45084510505546`, -14.000001, 1.*^-6}, {
    148.92374678570366`, -12.000001, 1.*^-6}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}}], 
   Line3DBox[{{151.45084510505546`, -14.000001, 1.*^-6}, {
    151.4508453226652, -13.314792228132148`, 4.3262389212492645`}, {
    150.28284067821582`, -16.000001, 1.*^-6}, {
    151.45084510505546`, -14.000001, 1.*^-6}}], 
   Line3DBox[{{150.28284067821582`, -16.000001, 1.*^-6}, {
    150.28284005321834`, -15.216905260722456`, 4.944272909999159}, {
    151.4508453226652, -13.314792228132148`, 4.3262389212492645`}, {
    150.28284067821582`, -16.000001, 1.*^-6}}], 
   Line3DBox[{{151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}, {151.4508454370694, -11.326238921249264`, 
    8.228994532094623}, {150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}, {151.4508453226652, -13.314792228132148`, 
    4.3262389212492645`}}], 
   Line3DBox[{{150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}, {150.28283972463768`, -12.944272909999158`, 
    9.40456503667957}, {151.4508454370694, -11.326238921249264`, 
    8.228994532094623}, {150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}}], 
   Line3DBox[{{151.4508454370694, -11.326238921249264`, 8.228994532094623}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    150.28283972463768`, -12.944272909999158`, 9.40456503667957}, {
    151.4508454370694, -11.326238921249264`, 8.228994532094623}}], 
   Line3DBox[{{150.28283972463768`, -12.944272909999158`, 9.40456503667957}, {
    150.28283972463768`, -9.40456503667957, 12.944272909999158`}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    150.28283972463768`, -12.944272909999158`, 9.40456503667957}}], 
   Line3DBox[{{151.4508454370694, -8.228994532094623, 11.326238921249264`}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}, {
    150.28283972463768`, -9.40456503667957, 12.944272909999158`}, {
    151.4508454370694, -8.228994532094623, 11.326238921249264`}}], 
   Line3DBox[{{150.28283972463768`, -9.40456503667957, 12.944272909999158`}, {
    150.28284005321834`, -4.944272909999159, 15.216905260722456`}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}, {
    150.28283972463768`, -9.40456503667957, 12.944272909999158`}}], 
   Line3DBox[{{151.4508453226652, -4.3262389212492645`, 
    13.314792228132148`}, {151.45084510505546`, -1.*^-6, 14.000001}, {
    150.28284005321834`, -4.944272909999159, 15.216905260722456`}, {
    151.4508453226652, -4.3262389212492645`, 13.314792228132148`}}], 
   Line3DBox[{{150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}, {150.28284067821582`, -1.*^-6, 16.000001}, {
    151.45084510505546`, -1.*^-6, 14.000001}, {
    150.28284005321834`, -4.944272909999159, 15.216905260722456`}}], 
   Line3DBox[{{151.45084510505546`, -1.*^-6, 14.000001}, {151.45084480554118`,
     4.326236921249264, 13.314792228132148`}, {150.28284067821582`, -1.*^-6, 
    16.000001}, {151.45084510505546`, -1.*^-6, 14.000001}}], 
   Line3DBox[{{150.28284067821582`, -1.*^-6, 16.000001}, {150.28284153845084`,
     4.944270909999159, 15.216905260722456`}, {151.45084480554118`, 
    4.326236921249264, 13.314792228132148`}, {150.28284067821582`, -1.*^-6, 
    16.000001}}], 
   Line3DBox[{{151.45084480554118`, 4.326236921249264, 13.314792228132148`}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    150.28284153845084`, 4.944270909999159, 15.216905260722456`}, {
    151.45084480554118`, 4.326236921249264, 13.314792228132148`}}], 
   Line3DBox[{{150.28284153845084`, 4.944270909999159, 15.216905260722456`}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    150.28284153845084`, 4.944270909999159, 15.216905260722456`}}], 
   Line3DBox[{{151.45084445344088`, 8.228992532094624, 11.326238921249264`}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    151.45084445344088`, 8.228992532094624, 11.326238921249264`}}], 
   Line3DBox[{{150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    150.28284361302565`, 12.94427090999916, 9.40456503667957}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}}], 
   Line3DBox[{{151.45084408322055`, 11.326236921249265`, 8.228994532094623}, {
    151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    150.28284361302565`, 12.94427090999916, 9.40456503667957}, {
    151.45084408322055`, 11.326236921249265`, 8.228994532094623}}], 
   Line3DBox[{{150.28284361302565`, 12.94427090999916, 9.40456503667957}, {
    150.2828446242915, 15.216903260722457`, 4.944272909999159}, {
    151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    150.28284361302565`, 12.94427090999916, 9.40456503667957}}], 
   Line3DBox[{{151.45084373111985`, 13.31479022813215, 4.3262389212492645`}, {
    151.450843431605, 13.999999, 1.*^-6}, {150.2828446242915, 
    15.216903260722457`, 4.944272909999159}, {151.45084373111985`, 
    13.31479022813215, 4.3262389212492645`}}], 
   Line3DBox[{{150.2828446242915, 15.216903260722457`, 4.944272909999159}, {
    150.28284548452532`, 15.999999, 1.*^-6}, {151.450843431605, 13.999999, 
    1.*^-6}, {150.2828446242915, 15.216903260722457`, 4.944272909999159}}], 
   Line3DBox[{{151.450843431605, 13.999999, 1.*^-6}, {151.45084321399463`, 
    13.31479022813215, -4.326236921249264}, {150.28284548452532`, 15.999999, 
    1.*^-6}, {151.450843431605, 13.999999, 1.*^-6}}], 
   Line3DBox[{{150.28284548452532`, 15.999999, 1.*^-6}, {150.2828461095216, 
    15.216903260722457`, -4.944270909999159}, {151.45084321399463`, 
    13.31479022813215, -4.326236921249264}, {150.28284548452532`, 15.999999, 
    1.*^-6}}], 
   Line3DBox[{{151.45084321399463`, 13.31479022813215, -4.326236921249264}, {
    151.45084309959006`, 11.326236921249265`, -8.228992532094624}, {
    150.2828461095216, 15.216903260722457`, -4.944270909999159}, {
    151.45084321399463`, 13.31479022813215, -4.326236921249264}}], 
   Line3DBox[{{150.2828461095216, 15.216903260722457`, -4.944270909999159}, {
    150.28284643810156`, 12.94427090999916, -9.404563036679571}, {
    151.45084309959006`, 11.326236921249265`, -8.228992532094624}, {
    150.2828461095216, 15.216903260722457`, -4.944270909999159}}], 
   Line3DBox[{{151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}, {151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}, {150.28284643810156`, 
    12.94427090999916, -9.404563036679571}, {151.45084309959006`, 
    11.326236921249265`, -8.228992532094624}}], 
   Line3DBox[{{150.28284643810156`, 12.94427090999916, -9.404563036679571}, {
    150.28284643810156`, 9.404563036679571, -12.94427090999916}, {
    151.45084309959006`, 8.228992532094624, -11.326236921249265`}, {
    150.28284643810156`, 12.94427090999916, -9.404563036679571}}], 
   Line3DBox[{{151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}, {151.45084321399463`, 
    4.326236921249264, -13.31479022813215}, {150.28284643810156`, 
    9.404563036679571, -12.94427090999916}, {151.45084309959006`, 
    8.228992532094624, -11.326236921249265`}}], 
   Line3DBox[{{150.28284643810156`, 9.404563036679571, -12.94427090999916}, {
    150.2828461095216, 4.944270909999159, -15.216903260722457`}, {
    151.45084321399463`, 4.326236921249264, -13.31479022813215}, {
    150.28284643810156`, 9.404563036679571, -12.94427090999916}}], 
   Line3DBox[{{151.45084321399463`, 4.326236921249264, -13.31479022813215}, {
    151.450843431605, -1.*^-6, -13.999999}, {150.2828461095216, 
    4.944270909999159, -15.216903260722457`}, {151.45084321399463`, 
    4.326236921249264, -13.31479022813215}}], 
   Line3DBox[{{150.2828461095216, 4.944270909999159, -15.216903260722457`}, {
    150.28284548452532`, -1.*^-6, -15.999999}, {
    151.450843431605, -1.*^-6, -13.999999}, {150.2828461095216, 
    4.944270909999159, -15.216903260722457`}}], 
   Line3DBox[{{151.450843431605, -1.*^-6, -13.999999}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    150.28284548452532`, -1.*^-6, -15.999999}, {
    151.450843431605, -1.*^-6, -13.999999}}], 
   Line3DBox[{{150.28284548452532`, -1.*^-6, -15.999999}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    150.28284548452532`, -1.*^-6, -15.999999}}], 
   Line3DBox[{{
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    151.45084373111985`, -4.3262389212492645`, -13.31479022813215}}], 
   Line3DBox[{{150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}}], 
   Line3DBox[{{
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    151.45084408322055`, -8.228994532094623, -11.326236921249265`}}], 
   Line3DBox[{{150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}}], 
   Line3DBox[{{
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    151.45084445344088`, -11.326238921249264`, -8.228992532094624}}], 
   Line3DBox[{{150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}}], 
   Line3DBox[{{
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}, {
    151.45084510505546`, -14.000001, 1.*^-6}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    151.45084480554118`, -13.314792228132148`, -4.326236921249264}}], 
   Line3DBox[{{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    150.28284067821582`, -16.000001, 1.*^-6}, {
    151.45084510505546`, -14.000001, 1.*^-6}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}}], 
   Line3DBox[{{150.28284067821582`, -16.000001, 1.*^-6}, {
    150.28284005321834`, -15.216905260722456`, 4.944272909999159}, {
    140.8639933501296, -18.000001, 1.*^-6}, {150.28284067821582`, -16.000001, 
    1.*^-6}}], 
   Line3DBox[{{140.8639933501296, -18.000001, 1.*^-6}, {
    140.86399150856653`, -17.119018293312763`, 5.562306898749054}, {
    150.28284005321834`, -15.216905260722456`, 4.944272909999159}, {
    140.8639933501296, -18.000001, 1.*^-6}}], 
   Line3DBox[{{150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}, {150.28283972463768`, -12.944272909999158`, 
    9.40456503667957}, {140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}, {150.28284005321834`, -15.216905260722456`, 
    4.944272909999159}}], 
   Line3DBox[{{140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}, {140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}, {150.28283972463768`, -12.944272909999158`, 
    9.40456503667957}, {140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}}], 
   Line3DBox[{{150.28283972463768`, -12.944272909999158`, 9.40456503667957}, {
    150.28283972463768`, -9.40456503667957, 12.944272909999158`}, {
    140.86399054039947`, -14.562306898749053`, 10.580135541264516`}, {
    150.28283972463768`, -12.944272909999158`, 9.40456503667957}}], 
   Line3DBox[{{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}, {140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}, {150.28283972463768`, -9.40456503667957, 
    12.944272909999158`}, {140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}}], 
   Line3DBox[{{150.28283972463768`, -9.40456503667957, 12.944272909999158`}, {
    150.28284005321834`, -4.944272909999159, 15.216905260722456`}, {
    140.86399054039947`, -10.580135541264516`, 14.562306898749053`}, {
    150.28283972463768`, -9.40456503667957, 12.944272909999158`}}], 
   Line3DBox[{{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}, {140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}, {150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}, {140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}}], 
   Line3DBox[{{150.28284005321834`, -4.944272909999159, 
    15.216905260722456`}, {150.28284067821582`, -1.*^-6, 16.000001}, {
    140.86399150856653`, -5.562306898749054, 17.119018293312763`}, {
    150.28284005321834`, -4.944272909999159, 15.216905260722456`}}], 
   Line3DBox[{{140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}, {140.8639933501296, -1.*^-6, 18.000001}, {
    150.28284067821582`, -1.*^-6, 16.000001}, {
    140.86399150856653`, -5.562306898749054, 17.119018293312763`}}], 
   Line3DBox[{{150.28284067821582`, -1.*^-6, 16.000001}, {150.28284153845084`,
     4.944270909999159, 15.216905260722456`}, {140.8639933501296, -1.*^-6, 
    18.000001}, {150.28284067821582`, -1.*^-6, 16.000001}}], 
   Line3DBox[{{140.8639933501296, -1.*^-6, 18.000001}, {140.86399588482354`, 
    5.562304898749054, 17.119018293312763`}, {150.28284153845084`, 
    4.944270909999159, 15.216905260722456`}, {140.8639933501296, -1.*^-6, 
    18.000001}}], 
   Line3DBox[{{150.28284153845084`, 4.944270909999159, 15.216905260722456`}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    140.86399588482354`, 5.562304898749054, 17.119018293312763`}, {
    150.28284153845084`, 4.944270909999159, 15.216905260722456`}}], 
   Line3DBox[{{140.86399588482354`, 5.562304898749054, 17.119018293312763`}, {
    140.86399886453455`, 10.580133541264518`, 14.562306898749053`}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    140.86399588482354`, 5.562304898749054, 17.119018293312763`}}], 
   Line3DBox[{{150.2828425497174, 9.404563036679571, 12.944272909999158`}, {
    150.28284361302565`, 12.94427090999916, 9.40456503667957}, {
    140.86399886453455`, 10.580133541264518`, 14.562306898749053`}, {
    150.2828425497174, 9.404563036679571, 12.944272909999158`}}], 
   Line3DBox[{{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}, {140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}, {150.28284361302565`, 12.94427090999916, 
    9.40456503667957}, {140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}}], 
   Line3DBox[{{150.28284361302565`, 12.94427090999916, 9.40456503667957}, {
    150.2828446242915, 15.216903260722457`, 4.944272909999159}, {
    140.86400199758785`, 14.562304898749055`, 10.580135541264516`}, {
    150.28284361302565`, 12.94427090999916, 9.40456503667957}}], 
   Line3DBox[{{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}, {140.86400497729824`, 17.11901629331276, 
    5.562306898749054}, {150.2828446242915, 15.216903260722457`, 
    4.944272909999159}, {140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}}], 
   Line3DBox[{{150.2828446242915, 15.216903260722457`, 4.944272909999159}, {
    150.28284548452532`, 15.999999, 1.*^-6}, {140.86400497729824`, 
    17.11901629331276, 5.562306898749054}, {150.2828446242915, 
    15.216903260722457`, 4.944272909999159}}], 
   Line3DBox[{{140.86400497729824`, 17.11901629331276, 5.562306898749054}, {
    140.864007511991, 17.999999, 1.*^-6}, {150.28284548452532`, 15.999999, 
    1.*^-6}, {140.86400497729824`, 17.11901629331276, 5.562306898749054}}], 
   Line3DBox[{{150.28284548452532`, 15.999999, 1.*^-6}, {150.2828461095216, 
    15.216903260722457`, -4.944270909999159}, {140.864007511991, 17.999999, 
    1.*^-6}, {150.28284548452532`, 15.999999, 1.*^-6}}], 
   Line3DBox[{{140.864007511991, 17.999999, 1.*^-6}, {140.86400935355294`, 
    17.11901629331276, -5.562304898749054}, {150.2828461095216, 
    15.216903260722457`, -4.944270909999159}, {140.864007511991, 17.999999, 
    1.*^-6}}], 
   Line3DBox[{{150.2828461095216, 15.216903260722457`, -4.944270909999159}, {
    150.28284643810156`, 12.94427090999916, -9.404563036679571}, {
    140.86400935355294`, 17.11901629331276, -5.562304898749054}, {
    150.2828461095216, 15.216903260722457`, -4.944270909999159}}], 
   Line3DBox[{{140.86400935355294`, 17.11901629331276, -5.562304898749054}, {
    140.86401032171926`, 14.562304898749055`, -10.580133541264518`}, {
    150.28284643810156`, 12.94427090999916, -9.404563036679571}, {
    140.86400935355294`, 17.11901629331276, -5.562304898749054}}], 
   Line3DBox[{{150.28284643810156`, 12.94427090999916, -9.404563036679571}, {
    150.28284643810156`, 9.404563036679571, -12.94427090999916}, {
    140.86401032171926`, 14.562304898749055`, -10.580133541264518`}, {
    150.28284643810156`, 12.94427090999916, -9.404563036679571}}], 
   Line3DBox[{{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}, {140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}, {150.28284643810156`, 
    9.404563036679571, -12.94427090999916}, {140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}}], 
   Line3DBox[{{150.28284643810156`, 9.404563036679571, -12.94427090999916}, {
    150.2828461095216, 4.944270909999159, -15.216903260722457`}, {
    140.86401032171926`, 10.580133541264518`, -14.562304898749055`}, {
    150.28284643810156`, 9.404563036679571, -12.94427090999916}}], 
   Line3DBox[{{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}, {150.2828461095216, 
    4.944270909999159, -15.216903260722457`}, {140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}}], 
   Line3DBox[{{150.2828461095216, 4.944270909999159, -15.216903260722457`}, {
    150.28284548452532`, -1.*^-6, -15.999999}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}, {150.2828461095216, 
    4.944270909999159, -15.216903260722457`}}], 
   Line3DBox[{{140.86400935355294`, 5.562304898749054, -17.11901629331276}, {
    140.864007511991, -1.*^-6, -17.999999}, {
    150.28284548452532`, -1.*^-6, -15.999999}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}}], 
   Line3DBox[{{150.28284548452532`, -1.*^-6, -15.999999}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    140.864007511991, -1.*^-6, -17.999999}, {
    150.28284548452532`, -1.*^-6, -15.999999}}], 
   Line3DBox[{{140.864007511991, -1.*^-6, -17.999999}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    140.864007511991, -1.*^-6, -17.999999}}], 
   Line3DBox[{{150.2828446242915, -4.944272909999159, -15.216903260722457`}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    150.2828446242915, -4.944272909999159, -15.216903260722457`}}], 
   Line3DBox[{{140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}}], 
   Line3DBox[{{150.28284361302565`, -9.40456503667957, -12.94427090999916}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    150.28284361302565`, -9.40456503667957, -12.94427090999916}}], 
   Line3DBox[{{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}}], 
   Line3DBox[{{150.2828425497174, -12.944272909999158`, -9.404563036679571}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    150.2828425497174, -12.944272909999158`, -9.404563036679571}}], 
   Line3DBox[{{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}}], 
   Line3DBox[{{
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}, {
    150.28284067821582`, -16.000001, 1.*^-6}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    150.28284153845084`, -15.216905260722456`, -4.944270909999159}}], 
   Line3DBox[{{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    140.8639933501296, -18.000001, 1.*^-6}, {150.28284067821582`, -16.000001, 
    1.*^-6}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}}], 
   Line3DBox[{{140.8639933501296, -18.000001, 1.*^-6}, {
    140.86399150856653`, -17.119018293312763`, 5.562306898749054}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {140.8639933501296, -18.000001, 
    1.*^-6}}], 
   Line3DBox[{{122.44830085339125`, -20.000001, 1.*^-6}, {
    122.44829798304029`, -19.02113132590307, 6.180340887498949}, {
    140.86399150856653`, -17.119018293312763`, 5.562306898749054}, {
    122.44830085339125`, -20.000001, 1.*^-6}}], 
   Line3DBox[{{140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}, {140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}, {122.44829798304029`, -19.02113132590307, 
    6.180340887498949}, {140.86399150856653`, -17.119018293312763`, 
    5.562306898749054}}], 
   Line3DBox[{{122.44829798304029`, -19.02113132590307, 6.180340887498949}, {
    122.44829647400742`, -16.18034088749895, 11.755706045849463`}, {
    140.86399054039947`, -14.562306898749053`, 10.580135541264516`}, {
    122.44829798304029`, -19.02113132590307, 6.180340887498949}}], 
   Line3DBox[{{140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}, {140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}, {122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}, {140.86399054039947`, -14.562306898749053`, 
    10.580135541264516`}}], 
   Line3DBox[{{122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}, {122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}}], 
   Line3DBox[{{140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}, {140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {140.86399054039947`, -10.580135541264516`, 
    14.562306898749053`}}], 
   Line3DBox[{{122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {122.44829798304029`, -6.180340887498949, 
    19.02113132590307}, {140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}}], 
   Line3DBox[{{140.86399150856653`, -5.562306898749054, 
    17.119018293312763`}, {140.8639933501296, -1.*^-6, 18.000001}, {
    122.44829798304029`, -6.180340887498949, 19.02113132590307}, {
    140.86399150856653`, -5.562306898749054, 17.119018293312763`}}], 
   Line3DBox[{{122.44829798304029`, -6.180340887498949, 19.02113132590307}, {
    122.44830085339125`, -1.*^-6, 20.000001}, {140.8639933501296, -1.*^-6, 
    18.000001}, {122.44829798304029`, -6.180340887498949, 
    19.02113132590307}}], 
   Line3DBox[{{140.8639933501296, -1.*^-6, 18.000001}, {140.86399588482354`, 
    5.562304898749054, 17.119018293312763`}, {122.44830085339125`, -1.*^-6, 
    20.000001}, {140.8639933501296, -1.*^-6, 18.000001}}], 
   Line3DBox[{{122.44830085339125`, -1.*^-6, 20.000001}, {122.44830480409036`,
     6.180338887498949, 19.02113132590307}, {140.86399588482354`, 
    5.562304898749054, 17.119018293312763`}, {122.44830085339125`, -1.*^-6, 
    20.000001}}], 
   Line3DBox[{{140.86399588482354`, 5.562304898749054, 17.119018293312763`}, {
    140.86399886453455`, 10.580133541264518`, 14.562306898749053`}, {
    122.44830480409036`, 6.180338887498949, 19.02113132590307}, {
    140.86399588482354`, 5.562304898749054, 17.119018293312763`}}], 
   Line3DBox[{{122.44830480409036`, 6.180338887498949, 19.02113132590307}, {
    122.44830944841544`, 11.755704045849464`, 16.18034088749895}, {
    140.86399886453455`, 10.580133541264518`, 14.562306898749053`}, {
    122.44830480409036`, 6.180338887498949, 19.02113132590307}}], 
   Line3DBox[{{140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}, {140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}, {122.44830944841544`, 11.755704045849464`, 
    16.18034088749895}, {140.86399886453455`, 10.580133541264518`, 
    14.562306898749053`}}], 
   Line3DBox[{{122.44830944841544`, 11.755704045849464`, 16.18034088749895}, {
    122.44831433174777`, 16.180338887498948`, 11.755706045849463`}, {
    140.86400199758785`, 14.562304898749055`, 10.580135541264516`}, {
    122.44830944841544`, 11.755704045849464`, 16.18034088749895}}], 
   Line3DBox[{{140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}, {140.86400497729824`, 17.11901629331276, 
    5.562306898749054}, {122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}, {140.86400199758785`, 14.562304898749055`, 
    10.580135541264516`}}], 
   Line3DBox[{{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}, {122.4483189760726, 19.02112932590307, 
    6.180340887498949}, {140.86400497729824`, 17.11901629331276, 
    5.562306898749054}, {122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}}], 
   Line3DBox[{{140.86400497729824`, 17.11901629331276, 5.562306898749054}, {
    140.864007511991, 17.999999, 1.*^-6}, {122.4483189760726, 
    19.02112932590307, 6.180340887498949}, {140.86400497729824`, 
    17.11901629331276, 5.562306898749054}}], 
   Line3DBox[{{122.4483189760726, 19.02112932590307, 6.180340887498949}, {
    122.44832292677113`, 19.999999, 1.*^-6}, {140.864007511991, 17.999999, 
    1.*^-6}, {122.4483189760726, 19.02112932590307, 6.180340887498949}}], 
   Line3DBox[{{140.864007511991, 17.999999, 1.*^-6}, {140.86400935355294`, 
    17.11901629331276, -5.562304898749054}, {122.44832292677113`, 19.999999, 
    1.*^-6}, {140.864007511991, 17.999999, 1.*^-6}}], 
   Line3DBox[{{122.44832292677113`, 19.999999, 1.*^-6}, {122.44832579712158`, 
    19.02112932590307, -6.180338887498949}, {140.86400935355294`, 
    17.11901629331276, -5.562304898749054}, {122.44832292677113`, 19.999999, 
    1.*^-6}}], 
   Line3DBox[{{140.86400935355294`, 17.11901629331276, -5.562304898749054}, {
    140.86401032171926`, 14.562304898749055`, -10.580133541264518`}, {
    122.44832579712158`, 19.02112932590307, -6.180338887498949}, {
    140.86400935355294`, 17.11901629331276, -5.562304898749054}}], 
   Line3DBox[{{122.44832579712158`, 19.02112932590307, -6.180338887498949}, {
    122.44832730615404`, 16.180338887498948`, -11.755704045849464`}, {
    140.86401032171926`, 14.562304898749055`, -10.580133541264518`}, {
    122.44832579712158`, 19.02112932590307, -6.180338887498949}}], 
   Line3DBox[{{140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}, {140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}, {122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}, {140.86401032171926`, 
    14.562304898749055`, -10.580133541264518`}}], 
   Line3DBox[{{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}, {122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}, {140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}, {122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}}], 
   Line3DBox[{{140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}, {122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}, {140.86401032171926`, 
    10.580133541264518`, -14.562304898749055`}}], 
   Line3DBox[{{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}, {122.44832579712158`, 
    6.180338887498949, -19.02112932590307}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}, {122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}}], 
   Line3DBox[{{140.86400935355294`, 5.562304898749054, -17.11901629331276}, {
    140.864007511991, -1.*^-6, -17.999999}, {122.44832579712158`, 
    6.180338887498949, -19.02112932590307}, {140.86400935355294`, 
    5.562304898749054, -17.11901629331276}}], 
   Line3DBox[{{122.44832579712158`, 6.180338887498949, -19.02112932590307}, {
    122.44832292677113`, -1.*^-6, -19.999999}, {
    140.864007511991, -1.*^-6, -17.999999}, {122.44832579712158`, 
    6.180338887498949, -19.02112932590307}}], 
   Line3DBox[{{140.864007511991, -1.*^-6, -17.999999}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    122.44832292677113`, -1.*^-6, -19.999999}, {
    140.864007511991, -1.*^-6, -17.999999}}], 
   Line3DBox[{{122.44832292677113`, -1.*^-6, -19.999999}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    122.44832292677113`, -1.*^-6, -19.999999}}], 
   Line3DBox[{{140.86400497729824`, -5.562306898749054, -17.11901629331276}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    140.86400497729824`, -5.562306898749054, -17.11901629331276}}], 
   Line3DBox[{{122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}}], 
   Line3DBox[{{
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    140.86400199758785`, -10.580135541264516`, -14.562304898749055`}}], 
   Line3DBox[{{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}}], 
   Line3DBox[{{
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    140.86399886453455`, -14.562306898749053`, -10.580133541264518`}}], 
   Line3DBox[{{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}}], 
   Line3DBox[{{
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}, {
    140.8639933501296, -18.000001, 1.*^-6}, {
    122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    140.86399588482354`, -17.119018293312763`, -5.562304898749054}}], 
   Line3DBox[{{122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {140.8639933501296, -18.000001, 
    1.*^-6}, {122.44830480409036`, -19.02113132590307, -6.180338887498949}}], 
   Line3DBox[{{122.44830085339125`, -20.000001, 1.*^-6}, {
    122.44829798304029`, -19.02113132590307, 6.180340887498949}, {
    98.44395732435352, -22.000001, 1.*^-6}, {122.44830085339125`, -20.000001, 
    1.*^-6}}], 
   Line3DBox[{{98.44395732435352, -22.000001, 1.*^-6}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    122.44829798304029`, -19.02113132590307, 6.180340887498949}, {
    98.44395732435352, -22.000001, 1.*^-6}}], 
   Line3DBox[{{122.44829798304029`, -19.02113132590307, 6.180340887498949}, {
    122.44829647400742`, -16.18034088749895, 11.755706045849463`}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    122.44829798304029`, -19.02113132590307, 6.180340887498949}}], 
   Line3DBox[{{98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    98.44395238658502, -17.798374876248847`, 12.931276550434408`}, {
    122.44829647400742`, -16.18034088749895, 11.755706045849463`}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}}], 
   Line3DBox[{{122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}, {122.44829647400742`, -16.18034088749895, 
    11.755706045849463`}}], 
   Line3DBox[{{98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}, {98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}}], 
   Line3DBox[{{122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}, {122.44829798304029`, -6.180340887498949, 
    19.02113132590307}, {98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}, {122.44829647400742`, -11.755706045849463`, 
    16.18034088749895}}], 
   Line3DBox[{{98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}, {98.44395408802413, -6.798374876248844, 
    20.923244358493378`}, {122.44829798304029`, -6.180340887498949, 
    19.02113132590307}, {98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}}], 
   Line3DBox[{{122.44829798304029`, -6.180340887498949, 19.02113132590307}, {
    122.44830085339125`, -1.*^-6, 20.000001}, {
    98.44395408802413, -6.798374876248844, 20.923244358493378`}, {
    122.44829798304029`, -6.180340887498949, 19.02113132590307}}], 
   Line3DBox[{{98.44395408802413, -6.798374876248844, 20.923244358493378`}, {
    98.44395732435352, -1.*^-6, 22.000001}, {122.44830085339125`, -1.*^-6, 
    20.000001}, {98.44395408802413, -6.798374876248844, 
    20.923244358493378`}}], 
   Line3DBox[{{122.44830085339125`, -1.*^-6, 20.000001}, {122.44830480409036`,
     6.180338887498949, 19.02113132590307}, {98.44395732435352, -1.*^-6, 
    22.000001}, {122.44830085339125`, -1.*^-6, 20.000001}}], 
   Line3DBox[{{98.44395732435352, -1.*^-6, 22.000001}, {98.44396177877888, 
    6.798372876248844, 20.923244358493378`}, {122.44830480409036`, 
    6.180338887498949, 19.02113132590307}, {98.44395732435352, -1.*^-6, 
    22.000001}}], 
   Line3DBox[{{122.44830480409036`, 6.180338887498949, 19.02113132590307}, {
    122.44830944841544`, 11.755704045849464`, 16.18034088749895}, {
    98.44396177877888, 6.798372876248844, 20.923244358493378`}, {
    122.44830480409036`, 6.180338887498949, 19.02113132590307}}], 
   Line3DBox[{{98.44396177877888, 6.798372876248844, 20.923244358493378`}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    122.44830944841544`, 11.755704045849464`, 16.18034088749895}, {
    98.44396177877888, 6.798372876248844, 20.923244358493378`}}], 
   Line3DBox[{{122.44830944841544`, 11.755704045849464`, 16.18034088749895}, {
    122.44831433174777`, 16.180338887498948`, 11.755706045849463`}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    122.44830944841544`, 11.755704045849464`, 16.18034088749895}}], 
   Line3DBox[{{98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    98.44397252124277, 17.798372876248845`, 12.931276550434408`}, {
    122.44831433174777`, 16.180338887498948`, 11.755706045849463`}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}}], 
   Line3DBox[{{122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}, {122.4483189760726, 19.02112932590307, 
    6.180340887498949}, {98.44397252124277, 17.798372876248845`, 
    12.931276550434408`}, {122.44831433174777`, 16.180338887498948`, 
    11.755706045849463`}}], 
   Line3DBox[{{98.44397252124277, 17.798372876248845`, 12.931276550434408`}, {
    98.44397775773425, 20.923242358493376`, 6.798374876248844}, {
    122.4483189760726, 19.02112932590307, 6.180340887498949}, {
    98.44397252124277, 17.798372876248845`, 12.931276550434408`}}], 
   Line3DBox[{{122.4483189760726, 19.02112932590307, 6.180340887498949}, {
    122.44832292677113`, 19.999999, 1.*^-6}, {98.44397775773425, 
    20.923242358493376`, 6.798374876248844}, {122.4483189760726, 
    19.02112932590307, 6.180340887498949}}], 
   Line3DBox[{{98.44397775773425, 20.923242358493376`, 6.798374876248844}, {
    98.44398221215992, 21.999999, 1.*^-6}, {122.44832292677113`, 19.999999, 
    1.*^-6}, {98.44397775773425, 20.923242358493376`, 6.798374876248844}}], 
   Line3DBox[{{122.44832292677113`, 19.999999, 1.*^-6}, {122.44832579712158`, 
    19.02112932590307, -6.180338887498949}, {98.44398221215992, 21.999999, 
    1.*^-6}, {122.44832292677113`, 19.999999, 1.*^-6}}], 
   Line3DBox[{{98.44398221215992, 21.999999, 1.*^-6}, {98.44398544848977, 
    20.923242358493376`, -6.798372876248844}, {122.44832579712158`, 
    19.02112932590307, -6.180338887498949}, {98.44398221215992, 21.999999, 
    1.*^-6}}], 
   Line3DBox[{{122.44832579712158`, 19.02112932590307, -6.180338887498949}, {
    122.44832730615404`, 16.180338887498948`, -11.755704045849464`}, {
    98.44398544848977, 20.923242358493376`, -6.798372876248844}, {
    122.44832579712158`, 19.02112932590307, -6.180338887498949}}], 
   Line3DBox[{{98.44398544848977, 20.923242358493376`, -6.798372876248844}, {
    98.443987149929, 17.798372876248845`, -12.93127455043441}, {
    122.44832730615404`, 16.180338887498948`, -11.755704045849464`}, {
    98.44398544848977, 20.923242358493376`, -6.798372876248844}}], 
   Line3DBox[{{122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}, {122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}, {98.443987149929, 
    17.798372876248845`, -12.93127455043441}, {122.44832730615404`, 
    16.180338887498948`, -11.755704045849464`}}], 
   Line3DBox[{{98.443987149929, 17.798372876248845`, -12.93127455043441}, {
    98.443987149929, 12.93127455043441, -17.798372876248845`}, {
    122.44832730615404`, 11.755704045849464`, -16.180338887498948`}, {
    98.443987149929, 17.798372876248845`, -12.93127455043441}}], 
   Line3DBox[{{122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}, {122.44832579712158`, 
    6.180338887498949, -19.02112932590307}, {98.443987149929, 
    12.93127455043441, -17.798372876248845`}, {122.44832730615404`, 
    11.755704045849464`, -16.180338887498948`}}], 
   Line3DBox[{{98.443987149929, 12.93127455043441, -17.798372876248845`}, {
    98.44398544848977, 6.798372876248844, -20.923242358493376`}, {
    122.44832579712158`, 6.180338887498949, -19.02112932590307}, {
    98.443987149929, 12.93127455043441, -17.798372876248845`}}], 
   Line3DBox[{{122.44832579712158`, 6.180338887498949, -19.02112932590307}, {
    122.44832292677113`, -1.*^-6, -19.999999}, {98.44398544848977, 
    6.798372876248844, -20.923242358493376`}, {122.44832579712158`, 
    6.180338887498949, -19.02112932590307}}], 
   Line3DBox[{{98.44398544848977, 6.798372876248844, -20.923242358493376`}, {
    98.44398221215992, -1.*^-6, -21.999999}, {
    122.44832292677113`, -1.*^-6, -19.999999}, {98.44398544848977, 
    6.798372876248844, -20.923242358493376`}}], 
   Line3DBox[{{122.44832292677113`, -1.*^-6, -19.999999}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    98.44398221215992, -1.*^-6, -21.999999}, {
    122.44832292677113`, -1.*^-6, -19.999999}}], 
   Line3DBox[{{98.44398221215992, -1.*^-6, -21.999999}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    98.44398221215992, -1.*^-6, -21.999999}}], 
   Line3DBox[{{122.4483189760726, -6.180340887498949, -19.02112932590307}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    122.4483189760726, -6.180340887498949, -19.02112932590307}}], 
   Line3DBox[{{98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}}], 
   Line3DBox[{{
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    122.44831433174777`, -11.755706045849463`, -16.180338887498948`}}], 
   Line3DBox[{{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}}], 
   Line3DBox[{{
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}, {
    122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    122.44830944841544`, -16.18034088749895, -11.755704045849464`}}], 
   Line3DBox[{{98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}}], 
   Line3DBox[{{122.44830480409036`, -19.02113132590307, -6.180338887498949}, {
    122.44830085339125`, -20.000001, 1.*^-6}, {
    98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    122.44830480409036`, -19.02113132590307, -6.180338887498949}}], 
   Line3DBox[{{98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    98.44395732435352, -22.000001, 1.*^-6}, {122.44830085339125`, -20.000001, 
    1.*^-6}, {98.44396177877888, -20.923244358493378`, -6.798372876248844}}], 
   Line3DBox[{{98.44395732435352, -22.000001, 1.*^-6}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    74.83965635056899, -24.000001, 1.*^-6}, {98.44395732435352, -22.000001, 
    1.*^-6}}], 
   Line3DBox[{{74.83965635056899, -24.000001, 1.*^-6}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    74.83965635056899, -24.000001, 1.*^-6}}], 
   Line3DBox[{{98.44395408802413, -20.923244358493378`, 6.798374876248844}, {
    98.44395238658502, -17.798374876248847`, 12.931276550434408`}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    98.44395408802413, -20.923244358493378`, 6.798374876248844}}], 
   Line3DBox[{{74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    74.83965212351299, -19.41640886499874, 14.106847055019355`}, {
    98.44395238658502, -17.798374876248847`, 12.931276550434408`}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}}], 
   Line3DBox[{{98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}, {98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}, {74.83965212351299, -19.41640886499874, 
    14.106847055019355`}, {98.44395238658502, -17.798374876248847`, 
    12.931276550434408`}}], 
   Line3DBox[{{74.83965212351299, -19.41640886499874, 14.106847055019355`}, {
    74.83965212351299, -14.106847055019355`, 19.41640886499874}, {
    98.44395238658502, -12.931276550434408`, 17.798374876248847`}, {
    74.83965212351299, -19.41640886499874, 14.106847055019355`}}], 
   Line3DBox[{{98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}, {98.44395408802413, -6.798374876248844, 
    20.923244358493378`}, {74.83965212351299, -14.106847055019355`, 
    19.41640886499874}, {98.44395238658502, -12.931276550434408`, 
    17.798374876248847`}}], 
   Line3DBox[{{74.83965212351299, -14.106847055019355`, 19.41640886499874}, {
    74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    98.44395408802413, -6.798374876248844, 20.923244358493378`}, {
    74.83965212351299, -14.106847055019355`, 19.41640886499874}}], 
   Line3DBox[{{98.44395408802413, -6.798374876248844, 20.923244358493378`}, {
    98.44395732435352, -1.*^-6, 22.000001}, {
    74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    98.44395408802413, -6.798374876248844, 20.923244358493378`}}], 
   Line3DBox[{{74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    74.83965635056899, -1.*^-6, 24.000001}, {98.44395732435352, -1.*^-6, 
    22.000001}, {74.83965358005719, -7.416408864998739, 
    22.825357391083685`}}], 
   Line3DBox[{{98.44395732435352, -1.*^-6, 22.000001}, {98.44396177877888, 
    6.798372876248844, 20.923244358493378`}, {74.83965635056899, -1.*^-6, 
    24.000001}, {98.44395732435352, -1.*^-6, 22.000001}}], 
   Line3DBox[{{74.83965635056899, -1.*^-6, 24.000001}, {74.83966016385156, 
    7.416406864998739, 22.825357391083685`}, {98.44396177877888, 
    6.798372876248844, 20.923244358493378`}, {74.83965635056899, -1.*^-6, 
    24.000001}}], 
   Line3DBox[{{98.44396177877888, 6.798372876248844, 20.923244358493378`}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    74.83966016385156, 7.416406864998739, 22.825357391083685`}, {
    98.44396177877888, 6.798372876248844, 20.923244358493378`}}], 
   Line3DBox[{{74.83966016385156, 7.416406864998739, 22.825357391083685`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    74.83966016385156, 7.416406864998739, 22.825357391083685`}}], 
   Line3DBox[{{98.44396701526996, 12.93127455043441, 17.798374876248847`}, {
    98.44397252124277, 17.798372876248845`, 12.931276550434408`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    98.44396701526996, 12.93127455043441, 17.798374876248847`}}], 
   Line3DBox[{{74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    98.44397252124277, 17.798372876248845`, 12.931276550434408`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}}], 
   Line3DBox[{{98.44397252124277, 17.798372876248845`, 12.931276550434408`}, {
    98.44397775773425, 20.923242358493376`, 6.798374876248844}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    98.44397252124277, 17.798372876248845`, 12.931276550434408`}}], 
   Line3DBox[{{74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    74.8396738428952, 22.825355391083683`, 7.416408864998739}, {
    98.44397775773425, 20.923242358493376`, 6.798374876248844}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}}], 
   Line3DBox[{{98.44397775773425, 20.923242358493376`, 6.798374876248844}, {
    98.44398221215992, 21.999999, 1.*^-6}, {74.8396738428952, 
    22.825355391083683`, 7.416408864998739}, {98.44397775773425, 
    20.923242358493376`, 6.798374876248844}}], 
   Line3DBox[{{74.8396738428952, 22.825355391083683`, 7.416408864998739}, {
    74.83967765617896, 23.999999, 1.*^-6}, {98.44398221215992, 21.999999, 
    1.*^-6}, {74.8396738428952, 22.825355391083683`, 7.416408864998739}}], 
   Line3DBox[{{98.44398221215992, 21.999999, 1.*^-6}, {98.44398544848977, 
    20.923242358493376`, -6.798372876248844}, {74.83967765617896, 23.999999, 
    1.*^-6}, {98.44398221215992, 21.999999, 1.*^-6}}], 
   Line3DBox[{{74.83967765617896, 23.999999, 1.*^-6}, {74.83968042669193, 
    22.825355391083683`, -7.416406864998739}, {98.44398544848977, 
    20.923242358493376`, -6.798372876248844}, {74.83967765617896, 23.999999, 
    1.*^-6}}], 
   Line3DBox[{{98.44398544848977, 20.923242358493376`, -6.798372876248844}, {
    98.443987149929, 17.798372876248845`, -12.93127455043441}, {
    74.83968042669193, 22.825355391083683`, -7.416406864998739}, {
    98.44398544848977, 20.923242358493376`, -6.798372876248844}}], 
   Line3DBox[{{74.83968042669193, 22.825355391083683`, -7.416406864998739}, {
    74.83968188323684, 19.416406864998738`, -14.106845055019356`}, {
    98.443987149929, 17.798372876248845`, -12.93127455043441}, {
    74.83968042669193, 22.825355391083683`, -7.416406864998739}}], 
   Line3DBox[{{98.443987149929, 17.798372876248845`, -12.93127455043441}, {
    98.443987149929, 12.93127455043441, -17.798372876248845`}, {
    74.83968188323684, 19.416406864998738`, -14.106845055019356`}, {
    98.443987149929, 17.798372876248845`, -12.93127455043441}}], 
   Line3DBox[{{74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}, {74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}, {98.443987149929, 
    12.93127455043441, -17.798372876248845`}, {74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}}], 
   Line3DBox[{{98.443987149929, 12.93127455043441, -17.798372876248845`}, {
    98.44398544848977, 6.798372876248844, -20.923242358493376`}, {
    74.83968188323684, 14.106845055019356`, -19.416406864998738`}, {
    98.443987149929, 12.93127455043441, -17.798372876248845`}}], 
   Line3DBox[{{74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}, {98.44398544848977, 
    6.798372876248844, -20.923242358493376`}, {74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}}], 
   Line3DBox[{{98.44398544848977, 6.798372876248844, -20.923242358493376`}, {
    98.44398221215992, -1.*^-6, -21.999999}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}, {98.44398544848977, 
    6.798372876248844, -20.923242358493376`}}], 
   Line3DBox[{{74.83968042669193, 7.416406864998739, -22.825355391083683`}, {
    74.83967765617896, -1.*^-6, -23.999999}, {
    98.44398221215992, -1.*^-6, -21.999999}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}}], 
   Line3DBox[{{98.44398221215992, -1.*^-6, -21.999999}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    74.83967765617896, -1.*^-6, -23.999999}, {
    98.44398221215992, -1.*^-6, -21.999999}}], 
   Line3DBox[{{74.83967765617896, -1.*^-6, -23.999999}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    74.83967765617896, -1.*^-6, -23.999999}}], 
   Line3DBox[{{98.44397775773425, -6.798374876248844, -20.923242358493376`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    98.44397775773425, -6.798374876248844, -20.923242358493376`}}], 
   Line3DBox[{{74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}}], 
   Line3DBox[{{
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    98.44397252124277, -12.931276550434408`, -17.798372876248845`}}], 
   Line3DBox[{{
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}}], 
   Line3DBox[{{98.44396701526996, -17.798374876248847`, -12.93127455043441}, {
    98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    98.44396701526996, -17.798374876248847`, -12.93127455043441}}], 
   Line3DBox[{{74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}}], 
   Line3DBox[{{98.44396177877888, -20.923244358493378`, -6.798372876248844}, {
    98.44395732435352, -22.000001, 1.*^-6}, {
    74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    98.44396177877888, -20.923244358493378`, -6.798372876248844}}], 
   Line3DBox[{{74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    74.83965635056899, -24.000001, 1.*^-6}, {98.44395732435352, -22.000001, 
    1.*^-6}, {74.83966016385156, -22.825357391083685`, -7.416406864998739}}], 
   Line3DBox[{{74.83965635056899, -24.000001, 1.*^-6}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    57.43937617624164, -26.000001, 1.*^-6}, {74.83965635056899, -24.000001, 
    1.*^-6}}], 
   Line3DBox[{{57.43937617624164, -26.000001, 1.*^-6}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    57.43937617624164, -26.000001, 1.*^-6}}], 
   Line3DBox[{{74.83965358005719, -22.825357391083685`, 7.416408864998739}, {
    74.83965212351299, -19.41640886499874, 14.106847055019355`}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    74.83965358005719, -22.825357391083685`, 7.416408864998739}}], 
   Line3DBox[{{57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    74.83965212351299, -19.41640886499874, 14.106847055019355`}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}}], 
   Line3DBox[{{74.83965212351299, -19.41640886499874, 14.106847055019355`}, {
    74.83965212351299, -14.106847055019355`, 19.41640886499874}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    74.83965212351299, -19.41640886499874, 14.106847055019355`}}], 
   Line3DBox[{{57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    74.83965212351299, -14.106847055019355`, 19.41640886499874}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}}], 
   Line3DBox[{{74.83965212351299, -14.106847055019355`, 19.41640886499874}, {
    74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    74.83965212351299, -14.106847055019355`, 19.41640886499874}}], 
   Line3DBox[{{57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}}], 
   Line3DBox[{{74.83965358005719, -7.416408864998739, 22.825357391083685`}, {
    74.83965635056899, -1.*^-6, 24.000001}, {
    57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    74.83965358005719, -7.416408864998739, 22.825357391083685`}}], 
   Line3DBox[{{57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    57.43937617624164, -1.*^-6, 26.000001}, {74.83965635056899, -1.*^-6, 
    24.000001}, {57.43937448825724, -8.034442853748633, 
    24.727470423673992`}}], 
   Line3DBox[{{74.83965635056899, -1.*^-6, 24.000001}, {74.83966016385156, 
    7.416406864998739, 22.825357391083685`}, {57.43937617624164, -1.*^-6, 
    26.000001}, {74.83965635056899, -1.*^-6, 24.000001}}], 
   Line3DBox[{{57.43937617624164, -1.*^-6, 26.000001}, {57.4393784995531, 
    8.034440853748634, 24.727470423673992`}, {74.83966016385156, 
    7.416406864998739, 22.825357391083685`}, {57.43937617624164, -1.*^-6, 
    26.000001}}], 
   Line3DBox[{{74.83966016385156, 7.416406864998739, 22.825357391083685`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    57.4393784995531, 8.034440853748634, 24.727470423673992`}, {
    74.83966016385156, 7.416406864998739, 22.825357391083685`}}], 
   Line3DBox[{{57.4393784995531, 8.034440853748634, 24.727470423673992`}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    57.4393784995531, 8.034440853748634, 24.727470423673992`}}], 
   Line3DBox[{{74.83966464663436, 14.106845055019356`, 19.41640886499874}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    74.83966464663436, 14.106845055019356`, 19.41640886499874}}], 
   Line3DBox[{{57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}}], 
   Line3DBox[{{74.8396693601116, 19.416406864998738`, 14.106847055019355`}, {
    74.8396738428952, 22.825355391083683`, 7.416408864998739}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    74.8396693601116, 19.416406864998738`, 14.106847055019355`}}], 
   Line3DBox[{{57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    57.43938683375967, 24.72746842367399, 8.034442853748633}, {
    74.8396738428952, 22.825355391083683`, 7.416408864998739}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}}], 
   Line3DBox[{{74.8396738428952, 22.825355391083683`, 7.416408864998739}, {
    74.83967765617896, 23.999999, 1.*^-6}, {57.43938683375967, 
    24.72746842367399, 8.034442853748633}, {74.8396738428952, 
    22.825355391083683`, 7.416408864998739}}], 
   Line3DBox[{{57.43938683375967, 24.72746842367399, 8.034442853748633}, {
    57.439389157072696`, 25.999999, 1.*^-6}, {74.83967765617896, 23.999999, 
    1.*^-6}, {57.43938683375967, 24.72746842367399, 8.034442853748633}}], 
   Line3DBox[{{74.83967765617896, 23.999999, 1.*^-6}, {74.83968042669193, 
    22.825355391083683`, -7.416406864998739}, {57.439389157072696`, 25.999999,
     1.*^-6}, {74.83967765617896, 23.999999, 1.*^-6}}], 
   Line3DBox[{{57.439389157072696`, 25.999999, 1.*^-6}, {57.4393908450586, 
    24.72746842367399, -8.034440853748634}, {74.83968042669193, 
    22.825355391083683`, -7.416406864998739}, {57.439389157072696`, 25.999999,
     1.*^-6}}], 
   Line3DBox[{{74.83968042669193, 22.825355391083683`, -7.416406864998739}, {
    74.83968188323684, 19.416406864998738`, -14.106845055019356`}, {
    57.4393908450586, 24.72746842367399, -8.034440853748634}, {
    74.83968042669193, 22.825355391083683`, -7.416406864998739}}], 
   Line3DBox[{{57.4393908450586, 24.72746842367399, -8.034440853748634}, {
    57.439391732485376`, 21.03444085374863, -15.282415559604303`}, {
    74.83968188323684, 19.416406864998738`, -14.106845055019356`}, {
    57.4393908450586, 24.72746842367399, -8.034440853748634}}], 
   Line3DBox[{{74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}, {74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}, {57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}, {74.83968188323684, 
    19.416406864998738`, -14.106845055019356`}}], 
   Line3DBox[{{57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}, {57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}}], 
   Line3DBox[{{74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {74.83968188323684, 
    14.106845055019356`, -19.416406864998738`}}], 
   Line3DBox[{{57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}}], 
   Line3DBox[{{74.83968042669193, 7.416406864998739, -22.825355391083683`}, {
    74.83967765617896, -1.*^-6, -23.999999}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}, {74.83968042669193, 
    7.416406864998739, -22.825355391083683`}}], 
   Line3DBox[{{57.4393908450586, 8.034440853748634, -24.72746842367399}, {
    57.439389157072696`, -1.*^-6, -25.999999}, {
    74.83967765617896, -1.*^-6, -23.999999}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}}], 
   Line3DBox[{{74.83967765617896, -1.*^-6, -23.999999}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    57.439389157072696`, -1.*^-6, -25.999999}, {
    74.83967765617896, -1.*^-6, -23.999999}}], 
   Line3DBox[{{57.439389157072696`, -1.*^-6, -25.999999}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    57.439389157072696`, -1.*^-6, -25.999999}}], 
   Line3DBox[{{74.8396738428952, -7.416408864998739, -22.825355391083683`}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    74.8396738428952, -7.416408864998739, -22.825355391083683`}}], 
   Line3DBox[{{57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}}], 
   Line3DBox[{{
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    74.8396693601116, -14.106847055019355`, -19.416406864998738`}}], 
   Line3DBox[{{57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}}], 
   Line3DBox[{{74.83966464663436, -19.41640886499874, -14.106845055019356`}, {
    74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    74.83966464663436, -19.41640886499874, -14.106845055019356`}}], 
   Line3DBox[{{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}}], 
   Line3DBox[{{74.83966016385156, -22.825357391083685`, -7.416406864998739}, {
    74.83965635056899, -24.000001, 1.*^-6}, {
    57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    74.83966016385156, -22.825357391083685`, -7.416406864998739}}], 
   Line3DBox[{{57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    57.43937617624164, -26.000001, 1.*^-6}, {74.83965635056899, -24.000001, 
    1.*^-6}, {57.4393784995531, -24.727470423673992`, -8.034440853748634}}], 
   Line3DBox[{{57.43937617624164, -26.000001, 1.*^-6}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    49.18245522897084, -28.000001, 1.*^-6}, {57.43937617624164, -26.000001, 
    1.*^-6}}], 
   Line3DBox[{{49.18245522897084, -28.000001, 1.*^-6}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    49.18245522897084, -28.000001, 1.*^-6}}], 
   Line3DBox[{{57.43937448825724, -24.727470423673992`, 8.034442853748633}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    57.43937448825724, -24.727470423673992`, 8.034442853748633}}], 
   Line3DBox[{{49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}}], 
   Line3DBox[{{57.4393736008314, -21.034442853748633`, 15.282417559604301`}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    57.4393736008314, -21.034442853748633`, 15.282417559604301`}}], 
   Line3DBox[{{49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    49.18245448351004, -16.457988064189248`, 22.65247684249853}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}}], 
   Line3DBox[{{57.4393736008314, -15.282417559604301`, 21.034442853748633`}, {
    57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    49.18245448351004, -16.457988064189248`, 22.65247684249853}, {
    57.4393736008314, -15.282417559604301`, 21.034442853748633`}}], 
   Line3DBox[{{49.18245448351004, -16.457988064189248`, 22.65247684249853}, {
    49.18245474037829, -8.652476842498528, 26.6295834562643}, {
    57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    49.18245448351004, -16.457988064189248`, 22.65247684249853}}], 
   Line3DBox[{{57.43937448825724, -8.034442853748633, 24.727470423673992`}, {
    57.43937617624164, -1.*^-6, 26.000001}, {
    49.18245474037829, -8.652476842498528, 26.6295834562643}, {
    57.43937448825724, -8.034442853748633, 24.727470423673992`}}], 
   Line3DBox[{{49.18245474037829, -8.652476842498528, 26.6295834562643}, {
    49.18245522897084, -1.*^-6, 28.000001}, {57.43937617624164, -1.*^-6, 
    26.000001}, {49.18245474037829, -8.652476842498528, 26.6295834562643}}], 
   Line3DBox[{{57.43937617624164, -1.*^-6, 26.000001}, {57.4393784995531, 
    8.034440853748634, 24.727470423673992`}, {49.18245522897084, -1.*^-6, 
    28.000001}, {57.43937617624164, -1.*^-6, 26.000001}}], 
   Line3DBox[{{49.18245522897084, -1.*^-6, 28.000001}, {49.182455901461054`, 
    8.65247484249853, 26.6295834562643}, {57.4393784995531, 8.034440853748634,
     24.727470423673992`}, {49.18245522897084, -1.*^-6, 28.000001}}], 
   Line3DBox[{{57.4393784995531, 8.034440853748634, 24.727470423673992`}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    49.182455901461054`, 8.65247484249853, 26.6295834562643}, {
    57.4393784995531, 8.034440853748634, 24.727470423673992`}}], 
   Line3DBox[{{49.182455901461054`, 8.65247484249853, 26.6295834562643}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    49.182455901461054`, 8.65247484249853, 26.6295834562643}}], 
   Line3DBox[{{57.43938123076995, 15.282415559604303`, 21.034442853748633`}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    57.43938123076995, 15.282415559604303`, 21.034442853748633`}}], 
   Line3DBox[{{49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}}], 
   Line3DBox[{{57.43938410254182, 21.03444085374863, 15.282417559604301`}, {
    57.43938683375967, 24.72746842367399, 8.034442853748633}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    57.43938410254182, 21.03444085374863, 15.282417559604301`}}], 
   Line3DBox[{{49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    49.1824583138262, 26.629581456264297`, 8.652476842498528}, {
    57.43938683375967, 24.72746842367399, 8.034442853748633}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}}], 
   Line3DBox[{{57.43938683375967, 24.72746842367399, 8.034442853748633}, {
    57.439389157072696`, 25.999999, 1.*^-6}, {49.1824583138262, 
    26.629581456264297`, 8.652476842498528}, {57.43938683375967, 
    24.72746842367399, 8.034442853748633}}], 
   Line3DBox[{{49.1824583138262, 26.629581456264297`, 8.652476842498528}, {
    49.18245898631761, 27.999999, 1.*^-6}, {57.439389157072696`, 25.999999, 
    1.*^-6}, {49.1824583138262, 26.629581456264297`, 8.652476842498528}}], 
   Line3DBox[{{57.439389157072696`, 25.999999, 1.*^-6}, {57.4393908450586, 
    24.72746842367399, -8.034440853748634}, {49.18245898631761, 27.999999, 
    1.*^-6}, {57.439389157072696`, 25.999999, 1.*^-6}}], 
   Line3DBox[{{49.18245898631761, 27.999999, 1.*^-6}, {49.18245947491141, 
    26.629581456264297`, -8.65247484249853}, {57.4393908450586, 
    24.72746842367399, -8.034440853748634}, {49.18245898631761, 27.999999, 
    1.*^-6}}], 
   Line3DBox[{{57.4393908450586, 24.72746842367399, -8.034440853748634}, {
    57.439391732485376`, 21.03444085374863, -15.282415559604303`}, {
    49.18245947491141, 26.629581456264297`, -8.65247484249853}, {
    57.4393908450586, 24.72746842367399, -8.034440853748634}}], 
   Line3DBox[{{49.18245947491141, 26.629581456264297`, -8.65247484249853}, {
    49.182459731780455`, 22.652474842498528`, -16.457986064189246`}, {
    57.439391732485376`, 21.03444085374863, -15.282415559604303`}, {
    49.18245947491141, 26.629581456264297`, -8.65247484249853}}], 
   Line3DBox[{{57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}, {57.439391732485376`, 
    21.03444085374863, -15.282415559604303`}}], 
   Line3DBox[{{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}}], 
   Line3DBox[{{57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {57.439391732485376`, 
    15.282415559604303`, -21.03444085374863}}], 
   Line3DBox[{{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}}], 
   Line3DBox[{{57.4393908450586, 8.034440853748634, -24.72746842367399}, {
    57.439389157072696`, -1.*^-6, -25.999999}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}, {57.4393908450586, 
    8.034440853748634, -24.72746842367399}}], 
   Line3DBox[{{49.18245947491141, 8.65247484249853, -26.629581456264297`}, {
    49.18245898631761, -1.*^-6, -27.999999}, {
    57.439389157072696`, -1.*^-6, -25.999999}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}}], 
   Line3DBox[{{57.439389157072696`, -1.*^-6, -25.999999}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    49.18245898631761, -1.*^-6, -27.999999}, {
    57.439389157072696`, -1.*^-6, -25.999999}}], 
   Line3DBox[{{49.18245898631761, -1.*^-6, -27.999999}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    49.18245898631761, -1.*^-6, -27.999999}}], 
   Line3DBox[{{57.43938683375967, -8.034442853748633, -24.72746842367399}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    57.43938683375967, -8.034442853748633, -24.72746842367399}}], 
   Line3DBox[{{49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}}], 
   Line3DBox[{{57.43938410254182, -15.282417559604301`, -21.03444085374863}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    57.43938410254182, -15.282417559604301`, -21.03444085374863}}], 
   Line3DBox[{{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}}], 
   Line3DBox[{{
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}, {
    57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    57.43938123076995, -21.034442853748633`, -15.282415559604303`}}], 
   Line3DBox[{{49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}}], 
   Line3DBox[{{57.4393784995531, -24.727470423673992`, -8.034440853748634}, {
    57.43937617624164, -26.000001, 1.*^-6}, {
    49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    57.4393784995531, -24.727470423673992`, -8.034440853748634}}], 
   Line3DBox[{{49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    49.18245522897084, -28.000001, 1.*^-6}, {57.43937617624164, -26.000001, 
    1.*^-6}, {49.182455901461054`, -26.6295834562643, -8.65247484249853}}], 
   Line3DBox[{{49.18245522897084, -28.000001, 1.*^-6}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    48.78638424338337, -30.000001, 1.*^-6}, {49.18245522897084, -28.000001, 
    1.*^-6}}], 
   Line3DBox[{{48.78638424338337, -30.000001, 1.*^-6}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    48.78638424338337, -30.000001, 1.*^-6}}], 
   Line3DBox[{{49.18245474037829, -26.6295834562643, 8.652476842498528}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    49.18245474037829, -26.6295834562643, 8.652476842498528}}], 
   Line3DBox[{{48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    48.78638466121615, -24.270510831248426`, 17.633558568774195`}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}}], 
   Line3DBox[{{49.18245448351004, -22.65247684249853, 16.457988064189248`}, {
    49.18245448351004, -16.457988064189248`, 22.65247684249853}, {
    48.78638466121615, -24.270510831248426`, 17.633558568774195`}, {
    49.18245448351004, -22.65247684249853, 16.457988064189248`}}], 
   Line3DBox[{{48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}, {48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}, {49.18245448351004, -16.457988064189248`, 
    22.65247684249853}, {48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}}], 
   Line3DBox[{{49.18245448351004, -16.457988064189248`, 22.65247684249853}, {
    49.18245474037829, -8.652476842498528, 26.6295834562643}, {
    48.78638466121615, -17.633558568774195`, 24.270510831248426`}, {
    49.18245448351004, -16.457988064189248`, 22.65247684249853}}], 
   Line3DBox[{{48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}, {48.78638451724075, -9.270510831248423, 
    28.531696488854607`}, {49.18245474037829, -8.652476842498528, 
    26.6295834562643}, {48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}}], 
   Line3DBox[{{49.18245474037829, -8.652476842498528, 26.6295834562643}, {
    49.18245522897084, -1.*^-6, 28.000001}, {
    48.78638451724075, -9.270510831248423, 28.531696488854607`}, {
    49.18245474037829, -8.652476842498528, 26.6295834562643}}], 
   Line3DBox[{{48.78638451724075, -9.270510831248423, 28.531696488854607`}, {
    48.78638424338337, -1.*^-6, 30.000001}, {49.18245522897084, -1.*^-6, 
    28.000001}, {48.78638451724075, -9.270510831248423, 
    28.531696488854607`}}], 
   Line3DBox[{{49.18245522897084, -1.*^-6, 28.000001}, {49.182455901461054`, 
    8.65247484249853, 26.6295834562643}, {48.78638424338337, -1.*^-6, 
    30.000001}, {49.18245522897084, -1.*^-6, 28.000001}}], 
   Line3DBox[{{48.78638424338337, -1.*^-6, 30.000001}, {48.78638386645105, 
    9.270508831248424, 28.531696488854607`}, {49.182455901461054`, 
    8.65247484249853, 26.6295834562643}, {48.78638424338337, -1.*^-6, 
    30.000001}}], 
   Line3DBox[{{49.182455901461054`, 8.65247484249853, 26.6295834562643}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    48.78638386645105, 9.270508831248424, 28.531696488854607`}, {
    49.182455901461054`, 8.65247484249853, 26.6295834562643}}], 
   Line3DBox[{{48.78638386645105, 9.270508831248424, 28.531696488854607`}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    48.78638386645105, 9.270508831248424, 28.531696488854607`}}], 
   Line3DBox[{{49.18245669202105, 16.457986064189246`, 22.65247684249853}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    49.18245669202105, 16.457986064189246`, 22.65247684249853}}], 
   Line3DBox[{{48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}}], 
   Line3DBox[{{49.18245752326541, 22.652474842498528`, 16.457988064189248`}, {
    49.1824583138262, 26.629581456264297`, 8.652476842498528}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    49.18245752326541, 22.652474842498528`, 16.457988064189248`}}], 
   Line3DBox[{{48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    48.78638251431693, 28.531694488854605`, 9.270510831248423}, {
    49.1824583138262, 26.629581456264297`, 8.652476842498528}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}}], 
   Line3DBox[{{49.1824583138262, 26.629581456264297`, 8.652476842498528}, {
    49.18245898631761, 27.999999, 1.*^-6}, {48.78638251431693, 
    28.531694488854605`, 9.270510831248423}, {49.1824583138262, 
    26.629581456264297`, 8.652476842498528}}], 
   Line3DBox[{{48.78638251431693, 28.531694488854605`, 9.270510831248423}, {
    48.78638213738503, 29.999999, 1.*^-6}, {49.18245898631761, 27.999999, 
    1.*^-6}, {48.78638251431693, 28.531694488854605`, 9.270510831248423}}], 
   Line3DBox[{{49.18245898631761, 27.999999, 1.*^-6}, {49.18245947491141, 
    26.629581456264297`, -8.65247484249853}, {48.78638213738503, 29.999999, 
    1.*^-6}, {49.18245898631761, 27.999999, 1.*^-6}}], 
   Line3DBox[{{48.78638213738503, 29.999999, 1.*^-6}, {48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}, {49.18245947491141, 
    26.629581456264297`, -8.65247484249853}, {48.78638213738503, 29.999999, 
    1.*^-6}}], 
   Line3DBox[{{49.18245947491141, 26.629581456264297`, -8.65247484249853}, {
    49.182459731780455`, 22.652474842498528`, -16.457986064189246`}, {
    48.786381863528106`, 28.531694488854605`, -9.270508831248424}, {
    49.18245947491141, 26.629581456264297`, -8.65247484249853}}], 
   Line3DBox[{{48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}, {48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}, {49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}, {48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}}], 
   Line3DBox[{{49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}, {49.182459731780455`, 
    22.652474842498528`, -16.457986064189246`}}], 
   Line3DBox[{{48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}, {48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}}], 
   Line3DBox[{{49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}, {48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}, {49.182459731780455`, 
    16.457986064189246`, -22.652474842498528`}}], 
   Line3DBox[{{48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}, {48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}, {48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}}], 
   Line3DBox[{{49.18245947491141, 8.65247484249853, -26.629581456264297`}, {
    49.18245898631761, -1.*^-6, -27.999999}, {48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}, {49.18245947491141, 
    8.65247484249853, -26.629581456264297`}}], 
   Line3DBox[{{48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}, {
    48.78638213738503, -1.*^-6, -29.999999}, {
    49.18245898631761, -1.*^-6, -27.999999}, {48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}}], 
   Line3DBox[{{49.18245898631761, -1.*^-6, -27.999999}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    48.78638213738503, -1.*^-6, -29.999999}, {
    49.18245898631761, -1.*^-6, -27.999999}}], 
   Line3DBox[{{48.78638213738503, -1.*^-6, -29.999999}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    48.78638213738503, -1.*^-6, -29.999999}}], 
   Line3DBox[{{49.1824583138262, -8.652476842498528, -26.629581456264297`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    49.1824583138262, -8.652476842498528, -26.629581456264297`}}], 
   Line3DBox[{{48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}}], 
   Line3DBox[{{
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    49.18245752326541, -16.457988064189248`, -22.652474842498528`}}], 
   Line3DBox[{{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}}], 
   Line3DBox[{{49.18245669202105, -22.65247684249853, -16.457986064189246`}, {
    49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    49.18245669202105, -22.65247684249853, -16.457986064189246`}}], 
   Line3DBox[{{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}}], 
   Line3DBox[{{49.182455901461054`, -26.6295834562643, -8.65247484249853}, {
    49.18245522897084, -28.000001, 1.*^-6}, {
    48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    49.182455901461054`, -26.6295834562643, -8.65247484249853}}], 
   Line3DBox[{{48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    48.78638424338337, -30.000001, 1.*^-6}, {49.18245522897084, -28.000001, 
    1.*^-6}, {48.78638386645105, -28.531696488854607`, -9.270508831248424}}], 
   Line3DBox[{{48.78638424338337, -30.000001, 1.*^-6}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    51.3389911079461, -32.000001, 1.*^-6}, {48.78638424338337, -30.000001, 
    1.*^-6}}], 
   Line3DBox[{{51.3389911079461, -32.000001, 1.*^-6}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    51.3389911079461, -32.000001, 1.*^-6}}], 
   Line3DBox[{{48.78638451724075, -28.531696488854607`, 9.270510831248423}, {
    48.78638466121615, -24.270510831248426`, 17.633558568774195`}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    48.78638451724075, -28.531696488854607`, 9.270510831248423}}], 
   Line3DBox[{{51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    51.33899148527837, -25.88854481999832, 18.80912907335914}, {
    48.78638466121615, -24.270510831248426`, 17.633558568774195`}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}}], 
   Line3DBox[{{48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}, {48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}, {51.33899148527837, -25.88854481999832, 
    18.80912907335914}, {48.78638466121615, -24.270510831248426`, 
    17.633558568774195`}}], 
   Line3DBox[{{51.33899148527837, -25.88854481999832, 18.80912907335914}, {
    51.33899148527837, -18.80912907335914, 25.88854481999832}, {
    48.78638466121615, -17.633558568774195`, 24.270510831248426`}, {
    51.33899148527837, -25.88854481999832, 18.80912907335914}}], 
   Line3DBox[{{48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}, {48.78638451724075, -9.270510831248423, 
    28.531696488854607`}, {51.33899148527837, -18.80912907335914, 
    25.88854481999832}, {48.78638466121615, -17.633558568774195`, 
    24.270510831248426`}}], 
   Line3DBox[{{51.33899148527837, -18.80912907335914, 25.88854481999832}, {
    51.33899135525854, -9.888544819998318, 30.433809521444914`}, {
    48.78638451724075, -9.270510831248423, 28.531696488854607`}, {
    51.33899148527837, -18.80912907335914, 25.88854481999832}}], 
   Line3DBox[{{48.78638451724075, -9.270510831248423, 28.531696488854607`}, {
    48.78638424338337, -1.*^-6, 30.000001}, {
    51.33899135525854, -9.888544819998318, 30.433809521444914`}, {
    48.78638451724075, -9.270510831248423, 28.531696488854607`}}], 
   Line3DBox[{{51.33899135525854, -9.888544819998318, 30.433809521444914`}, {
    51.3389911079461, -1.*^-6, 32.000001}, {48.78638424338337, -1.*^-6, 
    30.000001}, {51.33899135525854, -9.888544819998318, 
    30.433809521444914`}}], 
   Line3DBox[{{48.78638424338337, -1.*^-6, 30.000001}, {48.78638386645105, 
    9.270508831248424, 28.531696488854607`}, {51.3389911079461, -1.*^-6, 
    32.000001}, {48.78638424338337, -1.*^-6, 30.000001}}], 
   Line3DBox[{{51.3389911079461, -1.*^-6, 32.000001}, {51.33899076754966, 
    9.88854281999832, 30.433809521444914`}, {48.78638386645105, 
    9.270508831248424, 28.531696488854607`}, {51.3389911079461, -1.*^-6, 
    32.000001}}], 
   Line3DBox[{{48.78638386645105, 9.270508831248424, 28.531696488854607`}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    51.33899076754966, 9.88854281999832, 30.433809521444914`}, {
    48.78638386645105, 9.270508831248424, 28.531696488854607`}}], 
   Line3DBox[{{51.33899076754966, 9.88854281999832, 30.433809521444914`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    51.33899076754966, 9.88854281999832, 30.433809521444914`}}], 
   Line3DBox[{{48.78638342334068, 17.633556568774193`, 24.270510831248426`}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    48.78638342334068, 17.633556568774193`, 24.270510831248426`}}], 
   Line3DBox[{{51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}}], 
   Line3DBox[{{48.78638295742704, 24.270508831248424`, 17.633558568774195`}, {
    48.78638251431693, 28.531694488854605`, 9.270510831248423}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    48.78638295742704, 24.270508831248424`, 17.633558568774195`}}], 
   Line3DBox[{{51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    51.3389895464754, 30.433807521444912`, 9.888544819998318}, {
    48.78638251431693, 28.531694488854605`, 9.270510831248423}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}}], 
   Line3DBox[{{48.78638251431693, 28.531694488854605`, 9.270510831248423}, {
    48.78638213738503, 29.999999, 1.*^-6}, {51.3389895464754, 
    30.433807521444912`, 9.888544819998318}, {48.78638251431693, 
    28.531694488854605`, 9.270510831248423}}], 
   Line3DBox[{{51.3389895464754, 30.433807521444912`, 9.888544819998318}, {
    51.338989206078395`, 31.999999, 1.*^-6}, {48.78638213738503, 29.999999, 
    1.*^-6}, {51.3389895464754, 30.433807521444912`, 9.888544819998318}}], 
   Line3DBox[{{48.78638213738503, 29.999999, 1.*^-6}, {48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}, {51.338989206078395`, 31.999999,
     1.*^-6}, {48.78638213738503, 29.999999, 1.*^-6}}], 
   Line3DBox[{{51.338989206078395`, 31.999999, 1.*^-6}, {51.33898895876544, 
    30.433807521444912`, -9.88854281999832}, {48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}, {51.338989206078395`, 31.999999,
     1.*^-6}}], 
   Line3DBox[{{48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}, {48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}, {51.33898895876544, 
    30.433807521444912`, -9.88854281999832}, {48.786381863528106`, 
    28.531694488854605`, -9.270508831248424}}], 
   Line3DBox[{{51.33898895876544, 30.433807521444912`, -9.88854281999832}, {
    51.33898882874527, 25.888542819998317`, -18.80912707335914}, {
    48.78638171955296, 24.270508831248424`, -17.633556568774193`}, {
    51.33898895876544, 30.433807521444912`, -9.88854281999832}}], 
   Line3DBox[{{48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}, {48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}, {51.33898882874527, 
    25.888542819998317`, -18.80912707335914}, {48.78638171955296, 
    24.270508831248424`, -17.633556568774193`}}], 
   Line3DBox[{{51.33898882874527, 25.888542819998317`, -18.80912707335914}, {
    51.33898882874527, 18.80912707335914, -25.888542819998317`}, {
    48.78638171955296, 17.633556568774193`, -24.270508831248424`}, {
    51.33898882874527, 25.888542819998317`, -18.80912707335914}}], 
   Line3DBox[{{48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}, {48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}, {51.33898882874527, 
    18.80912707335914, -25.888542819998317`}, {48.78638171955296, 
    17.633556568774193`, -24.270508831248424`}}], 
   Line3DBox[{{51.33898882874527, 18.80912707335914, -25.888542819998317`}, {
    51.33898895876544, 9.88854281999832, -30.433807521444912`}, {
    48.786381863528106`, 9.270508831248424, -28.531694488854605`}, {
    51.33898882874527, 18.80912707335914, -25.888542819998317`}}], 
   Line3DBox[{{48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}, {
    48.78638213738503, -1.*^-6, -29.999999}, {51.33898895876544, 
    9.88854281999832, -30.433807521444912`}, {48.786381863528106`, 
    9.270508831248424, -28.531694488854605`}}], 
   Line3DBox[{{51.33898895876544, 9.88854281999832, -30.433807521444912`}, {
    51.338989206078395`, -1.*^-6, -31.999999}, {
    48.78638213738503, -1.*^-6, -29.999999}, {51.33898895876544, 
    9.88854281999832, -30.433807521444912`}}], 
   Line3DBox[{{48.78638213738503, -1.*^-6, -29.999999}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    51.338989206078395`, -1.*^-6, -31.999999}, {
    48.78638213738503, -1.*^-6, -29.999999}}], 
   Line3DBox[{{51.338989206078395`, -1.*^-6, -31.999999}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    51.338989206078395`, -1.*^-6, -31.999999}}], 
   Line3DBox[{{48.78638251431693, -9.270510831248423, -28.531694488854605`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    48.78638251431693, -9.270510831248423, -28.531694488854605`}}], 
   Line3DBox[{{51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}}], 
   Line3DBox[{{
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    48.78638295742704, -17.633558568774195`, -24.270508831248424`}}], 
   Line3DBox[{{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}}], 
   Line3DBox[{{
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}, {
    48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    48.78638342334068, -24.270510831248426`, -17.633556568774193`}}], 
   Line3DBox[{{51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}}], 
   Line3DBox[{{48.78638386645105, -28.531696488854607`, -9.270508831248424}, {
    48.78638424338337, -30.000001, 1.*^-6}, {
    51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    48.78638386645105, -28.531696488854607`, -9.270508831248424}}], 
   Line3DBox[{{51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    51.3389911079461, -32.000001, 1.*^-6}, {48.78638424338337, -30.000001, 
    1.*^-6}, {51.33899076754966, -30.433809521444914`, -9.88854281999832}}], 
   Line3DBox[{{51.3389911079461, -32.000001, 1.*^-6}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    50.56658345693566, -34.000001, 1.*^-6}, {51.3389911079461, -32.000001, 
    1.*^-6}}], 
   Line3DBox[{{50.56658345693566, -34.000001, 1.*^-6}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    50.56658345693566, -34.000001, 1.*^-6}}], 
   Line3DBox[{{51.33899135525854, -30.433809521444914`, 9.888544819998318}, {
    51.33899148527837, -25.88854481999832, 18.80912907335914}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    51.33899135525854, -30.433809521444914`, 9.888544819998318}}], 
   Line3DBox[{{50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    50.56658260867397, -27.506578808748213`, 19.984699577944088`}, {
    51.33899148527837, -25.88854481999832, 18.80912907335914}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}}], 
   Line3DBox[{{51.33899148527837, -25.88854481999832, 18.80912907335914}, {
    51.33899148527837, -18.80912907335914, 25.88854481999832}, {
    50.56658260867397, -27.506578808748213`, 19.984699577944088`}, {
    51.33899148527837, -25.88854481999832, 18.80912907335914}}], 
   Line3DBox[{{50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}, {50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}, {51.33899148527837, -18.80912907335914, 
    25.88854481999832}, {50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}}], 
   Line3DBox[{{51.33899148527837, -18.80912907335914, 25.88854481999832}, {
    51.33899135525854, -9.888544819998318, 30.433809521444914`}, {
    50.56658260867397, -19.984699577944088`, 27.506578808748213`}, {
    51.33899148527837, -18.80912907335914, 25.88854481999832}}], 
   Line3DBox[{{50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}, {50.5665829009651, -10.506578808748213`, 
    32.335922554035214`}, {51.33899135525854, -9.888544819998318, 
    30.433809521444914`}, {50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}}], 
   Line3DBox[{{51.33899135525854, -9.888544819998318, 30.433809521444914`}, {
    51.3389911079461, -1.*^-6, 32.000001}, {
    50.5665829009651, -10.506578808748213`, 32.335922554035214`}, {
    51.33899135525854, -9.888544819998318, 30.433809521444914`}}], 
   Line3DBox[{{50.5665829009651, -10.506578808748213`, 32.335922554035214`}, {
    50.56658345693566, -1.*^-6, 34.000001}, {51.3389911079461, -1.*^-6, 
    32.000001}, {50.5665829009651, -10.506578808748213`, 
    32.335922554035214`}}], 
   Line3DBox[{{51.3389911079461, -1.*^-6, 32.000001}, {51.33899076754966, 
    9.88854281999832, 30.433809521444914`}, {50.56658345693566, -1.*^-6, 
    34.000001}, {51.3389911079461, -1.*^-6, 32.000001}}], 
   Line3DBox[{{50.56658345693566, -1.*^-6, 34.000001}, {50.56658422216336, 
    10.506576808748214`, 32.335922554035214`}, {51.33899076754966, 
    9.88854281999832, 30.433809521444914`}, {50.56658345693566, -1.*^-6, 
    34.000001}}], 
   Line3DBox[{{51.33899076754966, 9.88854281999832, 30.433809521444914`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    50.56658422216336, 10.506576808748214`, 32.335922554035214`}, {
    51.33899076754966, 9.88854281999832, 30.433809521444914`}}], 
   Line3DBox[{{50.56658422216336, 10.506576808748214`, 32.335922554035214`}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    50.56658422216336, 10.506576808748214`, 32.335922554035214`}}], 
   Line3DBox[{{51.338990367389414`, 18.80912707335914, 25.88854481999832}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    51.338990367389414`, 18.80912707335914, 25.88854481999832}}], 
   Line3DBox[{{50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}}], 
   Line3DBox[{{51.338989946635934`, 25.888542819998317`, 18.80912907335914}, {
    51.3389895464754, 30.433807521444912`, 9.888544819998318}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    51.338989946635934`, 25.888542819998317`, 18.80912907335914}}], 
   Line3DBox[{{50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    50.56658696719268, 32.33592055403522, 10.506578808748213`}, {
    51.3389895464754, 30.433807521444912`, 9.888544819998318}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}}], 
   Line3DBox[{{51.3389895464754, 30.433807521444912`, 9.888544819998318}, {
    51.338989206078395`, 31.999999, 1.*^-6}, {50.56658696719268, 
    32.33592055403522, 10.506578808748213`}, {51.3389895464754, 
    30.433807521444912`, 9.888544819998318}}], 
   Line3DBox[{{50.56658696719268, 32.33592055403522, 10.506578808748213`}, {
    50.56658773241915, 33.999999, 1.*^-6}, {51.338989206078395`, 31.999999, 
    1.*^-6}, {50.56658696719268, 32.33592055403522, 10.506578808748213`}}], 
   Line3DBox[{{51.338989206078395`, 31.999999, 1.*^-6}, {51.33898895876544, 
    30.433807521444912`, -9.88854281999832}, {50.56658773241915, 33.999999, 
    1.*^-6}, {51.338989206078395`, 31.999999, 1.*^-6}}], 
   Line3DBox[{{50.56658773241915, 33.999999, 1.*^-6}, {50.56658828838857, 
    32.33592055403522, -10.506576808748214`}, {51.33898895876544, 
    30.433807521444912`, -9.88854281999832}, {50.56658773241915, 33.999999, 
    1.*^-6}}], 
   Line3DBox[{{51.33898895876544, 30.433807521444912`, -9.88854281999832}, {
    51.33898882874527, 25.888542819998317`, -18.80912707335914}, {
    50.56658828838857, 32.33592055403522, -10.506576808748214`}, {
    51.33898895876544, 30.433807521444912`, -9.88854281999832}}], 
   Line3DBox[{{50.56658828838857, 32.33592055403522, -10.506576808748214`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    51.33898882874527, 25.888542819998317`, -18.80912707335914}, {
    50.56658828838857, 32.33592055403522, -10.506576808748214`}}], 
   Line3DBox[{{51.33898882874527, 25.888542819998317`, -18.80912707335914}, {
    51.33898882874527, 18.80912707335914, -25.888542819998317`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    51.33898882874527, 25.888542819998317`, -18.80912707335914}}], 
   Line3DBox[{{50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    51.33898882874527, 18.80912707335914, -25.888542819998317`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}}], 
   Line3DBox[{{51.33898882874527, 18.80912707335914, -25.888542819998317`}, {
    51.33898895876544, 9.88854281999832, -30.433807521444912`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    51.33898882874527, 18.80912707335914, -25.888542819998317`}}], 
   Line3DBox[{{50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    50.56658828838857, 10.506576808748214`, -32.33592055403522}, {
    51.33898895876544, 9.88854281999832, -30.433807521444912`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}}], 
   Line3DBox[{{51.33898895876544, 9.88854281999832, -30.433807521444912`}, {
    51.338989206078395`, -1.*^-6, -31.999999}, {50.56658828838857, 
    10.506576808748214`, -32.33592055403522}, {51.33898895876544, 
    9.88854281999832, -30.433807521444912`}}], 
   Line3DBox[{{50.56658828838857, 10.506576808748214`, -32.33592055403522}, {
    50.56658773241915, -1.*^-6, -33.999999}, {
    51.338989206078395`, -1.*^-6, -31.999999}, {50.56658828838857, 
    10.506576808748214`, -32.33592055403522}}], 
   Line3DBox[{{51.338989206078395`, -1.*^-6, -31.999999}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    50.56658773241915, -1.*^-6, -33.999999}, {
    51.338989206078395`, -1.*^-6, -31.999999}}], 
   Line3DBox[{{50.56658773241915, -1.*^-6, -33.999999}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    50.56658773241915, -1.*^-6, -33.999999}}], 
   Line3DBox[{{51.3389895464754, -9.888544819998318, -30.433807521444912`}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    51.3389895464754, -9.888544819998318, -30.433807521444912`}}], 
   Line3DBox[{{50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}}], 
   Line3DBox[{{
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    51.338989946635934`, -18.80912907335914, -25.888542819998317`}}], 
   Line3DBox[{{50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}}], 
   Line3DBox[{{51.338990367389414`, -25.88854481999832, -18.80912707335914}, {
    51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    51.338990367389414`, -25.88854481999832, -18.80912707335914}}], 
   Line3DBox[{{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}}], 
   Line3DBox[{{51.33899076754966, -30.433809521444914`, -9.88854281999832}, {
    51.3389911079461, -32.000001, 1.*^-6}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    51.33899076754966, -30.433809521444914`, -9.88854281999832}}], 
   Line3DBox[{{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    50.56658345693566, -34.000001, 1.*^-6}, {51.3389911079461, -32.000001, 
    1.*^-6}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}}], 
   Line3DBox[{{50.56658345693566, -34.000001, 1.*^-6}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    41.730758582737394`, -36.000001, 1.*^-6}, {50.56658345693566, -34.000001, 
    1.*^-6}}], 
   Line3DBox[{{41.730758582737394`, -36.000001, 1.*^-6}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    41.730758582737394`, -36.000001, 1.*^-6}}], 
   Line3DBox[{{50.5665829009651, -32.335922554035214`, 10.506578808748213`}, {
    50.56658260867397, -27.506578808748213`, 19.984699577944088`}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    50.5665829009651, -32.335922554035214`, 10.506578808748213`}}], 
   Line3DBox[{{41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    41.73075588969306, -29.12461279749811, 21.160270082529035`}, {
    50.56658260867397, -27.506578808748213`, 19.984699577944088`}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}}], 
   Line3DBox[{{50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}, {50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}, {41.73075588969306, -29.12461279749811, 
    21.160270082529035`}, {50.56658260867397, -27.506578808748213`, 
    19.984699577944088`}}], 
   Line3DBox[{{41.73075588969306, -29.12461279749811, 21.160270082529035`}, {
    41.73075588969306, -21.160270082529035`, 29.12461279749811}, {
    50.56658260867397, -19.984699577944088`, 27.506578808748213`}, {
    41.73075588969306, -29.12461279749811, 21.160270082529035`}}], 
   Line3DBox[{{50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}, {50.5665829009651, -10.506578808748213`, 
    32.335922554035214`}, {41.73075588969306, -21.160270082529035`, 
    29.12461279749811}, {50.56658260867397, -19.984699577944088`, 
    27.506578808748213`}}], 
   Line3DBox[{{41.73075588969306, -21.160270082529035`, 29.12461279749811}, {
    41.730756817653, -11.124612797498107`, 34.23803558662552}, {
    50.5665829009651, -10.506578808748213`, 32.335922554035214`}, {
    41.73075588969306, -21.160270082529035`, 29.12461279749811}}], 
   Line3DBox[{{50.5665829009651, -10.506578808748213`, 32.335922554035214`}, {
    50.56658345693566, -1.*^-6, 34.000001}, {
    41.730756817653, -11.124612797498107`, 34.23803558662552}, {
    50.5665829009651, -10.506578808748213`, 32.335922554035214`}}], 
   Line3DBox[{{41.730756817653, -11.124612797498107`, 34.23803558662552}, {
    41.730758582737394`, -1.*^-6, 36.000001}, {50.56658345693566, -1.*^-6, 
    34.000001}, {41.730756817653, -11.124612797498107`, 34.23803558662552}}], 
   Line3DBox[{{50.56658345693566, -1.*^-6, 34.000001}, {50.56658422216336, 
    10.506576808748214`, 32.335922554035214`}, {41.730758582737394`, -1.*^-6, 
    36.000001}, {50.56658345693566, -1.*^-6, 34.000001}}], 
   Line3DBox[{{41.730758582737394`, -1.*^-6, 36.000001}, {41.73076101216748, 
    11.124610797498109`, 34.23803558662552}, {50.56658422216336, 
    10.506576808748214`, 32.335922554035214`}, {41.730758582737394`, -1.*^-6, 
    36.000001}}], 
   Line3DBox[{{50.56658422216336, 10.506576808748214`, 32.335922554035214`}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    41.73076101216748, 11.124610797498109`, 34.23803558662552}, {
    50.56658422216336, 10.506576808748214`, 32.335922554035214`}}], 
   Line3DBox[{{41.73076101216748, 11.124610797498109`, 34.23803558662552}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    41.73076101216748, 11.124610797498109`, 34.23803558662552}}], 
   Line3DBox[{{50.56658512174204, 19.984697577944086`, 27.506578808748213`}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    50.56658512174204, 19.984697577944086`, 27.506578808748213`}}], 
   Line3DBox[{{41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}}], 
   Line3DBox[{{50.56658606761471, 27.50657680874821, 19.984699577944088`}, {
    50.56658696719268, 32.33592055403522, 10.506578808748213`}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    50.56658606761471, 27.50657680874821, 19.984699577944088`}}], 
   Line3DBox[{{41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    41.73076972703842, 34.23803358662553, 11.124612797498107`}, {
    50.56658696719268, 32.33592055403522, 10.506578808748213`}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}}], 
   Line3DBox[{{50.56658696719268, 32.33592055403522, 10.506578808748213`}, {
    50.56658773241915, 33.999999, 1.*^-6}, {41.73076972703842, 
    34.23803358662553, 11.124612797498107`}, {50.56658696719268, 
    32.33592055403522, 10.506578808748213`}}], 
   Line3DBox[{{41.73076972703842, 34.23803358662553, 11.124612797498107`}, {
    41.73077215646717, 35.999999, 1.*^-6}, {50.56658773241915, 33.999999, 
    1.*^-6}, {41.73076972703842, 34.23803358662553, 11.124612797498107`}}], 
   Line3DBox[{{50.56658773241915, 33.999999, 1.*^-6}, {50.56658828838857, 
    32.33592055403522, -10.506576808748214`}, {41.73077215646717, 35.999999, 
    1.*^-6}, {50.56658773241915, 33.999999, 1.*^-6}}], 
   Line3DBox[{{41.73077215646717, 35.999999, 1.*^-6}, {41.73077392155031, 
    34.23803358662553, -11.124610797498109`}, {50.56658828838857, 
    32.33592055403522, -10.506576808748214`}, {41.73077215646717, 35.999999, 
    1.*^-6}}], 
   Line3DBox[{{50.56658828838857, 32.33592055403522, -10.506576808748214`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    41.73077392155031, 34.23803358662553, -11.124610797498109`}, {
    50.56658828838857, 32.33592055403522, -10.506576808748214`}}], 
   Line3DBox[{{41.73077392155031, 34.23803358662553, -11.124610797498109`}, {
    41.7307748495094, 29.124610797498107`, -21.160268082529033`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    41.73077392155031, 34.23803358662553, -11.124610797498109`}}], 
   Line3DBox[{{50.56658858067888, 27.50657680874821, -19.984697577944086`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    41.7307748495094, 29.124610797498107`, -21.160268082529033`}, {
    50.56658858067888, 27.50657680874821, -19.984697577944086`}}], 
   Line3DBox[{{41.7307748495094, 29.124610797498107`, -21.160268082529033`}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    41.7307748495094, 29.124610797498107`, -21.160268082529033`}}], 
   Line3DBox[{{50.56658858067888, 19.984697577944086`, -27.50657680874821}, {
    50.56658828838857, 10.506576808748214`, -32.33592055403522}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    50.56658858067888, 19.984697577944086`, -27.50657680874821}}], 
   Line3DBox[{{41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    41.73077392155031, 11.124610797498109`, -34.23803358662553}, {
    50.56658828838857, 10.506576808748214`, -32.33592055403522}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}}], 
   Line3DBox[{{50.56658828838857, 10.506576808748214`, -32.33592055403522}, {
    50.56658773241915, -1.*^-6, -33.999999}, {41.73077392155031, 
    11.124610797498109`, -34.23803358662553}, {50.56658828838857, 
    10.506576808748214`, -32.33592055403522}}], 
   Line3DBox[{{41.73077392155031, 11.124610797498109`, -34.23803358662553}, {
    41.73077215646717, -1.*^-6, -35.999999}, {
    50.56658773241915, -1.*^-6, -33.999999}, {41.73077392155031, 
    11.124610797498109`, -34.23803358662553}}], 
   Line3DBox[{{50.56658773241915, -1.*^-6, -33.999999}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    41.73077215646717, -1.*^-6, -35.999999}, {
    50.56658773241915, -1.*^-6, -33.999999}}], 
   Line3DBox[{{41.73077215646717, -1.*^-6, -35.999999}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    41.73077215646717, -1.*^-6, -35.999999}}], 
   Line3DBox[{{50.56658696719268, -10.506578808748213`, -32.33592055403522}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    50.56658696719268, -10.506578808748213`, -32.33592055403522}}], 
   Line3DBox[{{41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}}], 
   Line3DBox[{{50.56658606761471, -19.984699577944088`, -27.50657680874821}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    50.56658606761471, -19.984699577944088`, -27.50657680874821}}], 
   Line3DBox[{{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}}], 
   Line3DBox[{{
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    50.56658512174204, -27.506578808748213`, -19.984697577944086`}}], 
   Line3DBox[{{41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}}], 
   Line3DBox[{{
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}, {
    50.56658345693566, -34.000001, 1.*^-6}, {
    41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    50.56658422216336, -32.335922554035214`, -10.506576808748214`}}], 
   Line3DBox[{{41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    41.730758582737394`, -36.000001, 1.*^-6}, {50.56658345693566, -34.000001, 
    1.*^-6}, {41.73076101216748, -34.23803558662552, -11.124610797498109`}}], 
   Line3DBox[{{41.730758582737394`, -36.000001, 1.*^-6}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    23.81630987621824, -38.000001, 1.*^-6}, {41.730758582737394`, -36.000001, 
    1.*^-6}}], 
   Line3DBox[{{23.81630987621824, -38.000001, 1.*^-6}, {
    23.816307054484525`, -36.14014861921583, 11.742646786248002`}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    23.81630987621824, -38.000001, 1.*^-6}}], 
   Line3DBox[{{41.730756817653, -34.23803558662552, 11.124612797498107`}, {
    41.73075588969306, -29.12461279749811, 21.160270082529035`}, {
    23.816307054484525`, -36.14014861921583, 11.742646786248002`}, {
    41.730756817653, -34.23803558662552, 11.124612797498107`}}], 
   Line3DBox[{{23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}, {23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}, {41.73075588969306, -29.12461279749811, 
    21.160270082529035`}, {23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}}], 
   Line3DBox[{{41.73075588969306, -29.12461279749811, 21.160270082529035`}, {
    41.73075588969306, -21.160270082529035`, 29.12461279749811}, {
    23.816305571011128`, -30.742646786248006`, 22.33584058711398}, {
    41.73075588969306, -29.12461279749811, 21.160270082529035`}}], 
   Line3DBox[{{23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}, {23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}, {41.73075588969306, -21.160270082529035`, 
    29.12461279749811}, {23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}}], 
   Line3DBox[{{41.73075588969306, -21.160270082529035`, 29.12461279749811}, {
    41.730756817653, -11.124612797498107`, 34.23803558662552}, {
    23.816305571011128`, -22.33584058711398, 30.742646786248006`}, {
    41.73075588969306, -21.160270082529035`, 29.12461279749811}}], 
   Line3DBox[{{23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}, {23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}, {41.730756817653, -11.124612797498107`, 
    34.23803558662552}, {23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}}], 
   Line3DBox[{{41.730756817653, -11.124612797498107`, 34.23803558662552}, {
    41.730758582737394`, -1.*^-6, 36.000001}, {
    23.816307054484525`, -11.742646786248002`, 36.14014861921583}, {
    41.730756817653, -11.124612797498107`, 34.23803558662552}}], 
   Line3DBox[{{23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}, {23.81630987621824, -1.*^-6, 38.000001}, {
    41.730758582737394`, -1.*^-6, 36.000001}, {
    23.816307054484525`, -11.742646786248002`, 36.14014861921583}}], 
   Line3DBox[{{41.730758582737394`, -1.*^-6, 36.000001}, {41.73076101216748, 
    11.124610797498109`, 34.23803558662552}, {23.81630987621824, -1.*^-6, 
    38.000001}, {41.730758582737394`, -1.*^-6, 36.000001}}], 
   Line3DBox[{{23.81630987621824, -1.*^-6, 38.000001}, {23.816313760001435`, 
    11.742644786248004`, 36.14014861921583}, {41.73076101216748, 
    11.124610797498109`, 34.23803558662552}, {23.81630987621824, -1.*^-6, 
    38.000001}}], 
   Line3DBox[{{41.73076101216748, 11.124610797498109`, 34.23803558662552}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    23.816313760001435`, 11.742644786248004`, 36.14014861921583}, {
    41.73076101216748, 11.124610797498109`, 34.23803558662552}}], 
   Line3DBox[{{23.816313760001435`, 11.742644786248004`, 36.14014861921583}, {
    23.81631832566208, 22.33583858711398, 30.742646786248006`}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    23.816313760001435`, 11.742644786248004`, 36.14014861921583}}], 
   Line3DBox[{{41.73076386813338, 21.160268082529033`, 29.12461279749811}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    23.81631832566208, 22.33583858711398, 30.742646786248006`}, {
    41.73076386813338, 21.160268082529033`, 29.12461279749811}}], 
   Line3DBox[{{23.81631832566208, 22.33583858711398, 30.742646786248006`}, {
    23.816323126281645`, 30.742644786248004`, 22.33584058711398}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    23.81631832566208, 22.33583858711398, 30.742646786248006`}}], 
   Line3DBox[{{41.73076687107326, 29.124610797498107`, 21.160270082529035`}, {
    41.73076972703842, 34.23803358662553, 11.124612797498107`}, {
    23.816323126281645`, 30.742644786248004`, 22.33584058711398}, {
    41.73076687107326, 29.124610797498107`, 21.160270082529035`}}], 
   Line3DBox[{{23.816323126281645`, 30.742644786248004`, 22.33584058711398}, {
    23.81632769194195, 36.140146619215834`, 11.742646786248002`}, {
    41.73076972703842, 34.23803358662553, 11.124612797498107`}, {
    23.816323126281645`, 30.742644786248004`, 22.33584058711398}}], 
   Line3DBox[{{41.73076972703842, 34.23803358662553, 11.124612797498107`}, {
    41.73077215646717, 35.999999, 1.*^-6}, {23.81632769194195, 
    36.140146619215834`, 11.742646786248002`}, {41.73076972703842, 
    34.23803358662553, 11.124612797498107`}}], 
   Line3DBox[{{23.81632769194195, 36.140146619215834`, 11.742646786248002`}, {
    23.81633157572432, 37.999999, 1.*^-6}, {41.73077215646717, 35.999999, 
    1.*^-6}, {23.81632769194195, 36.140146619215834`, 11.742646786248002`}}], 
   Line3DBox[{{41.73077215646717, 35.999999, 1.*^-6}, {41.73077392155031, 
    34.23803358662553, -11.124610797498109`}, {23.81633157572432, 37.999999, 
    1.*^-6}, {41.73077215646717, 35.999999, 1.*^-6}}], 
   Line3DBox[{{23.81633157572432, 37.999999, 1.*^-6}, {23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}, {41.73077392155031, 
    34.23803358662553, -11.124610797498109`}, {23.81633157572432, 37.999999, 
    1.*^-6}}], 
   Line3DBox[{{41.73077392155031, 34.23803358662553, -11.124610797498109`}, {
    41.7307748495094, 29.124610797498107`, -21.160268082529033`}, {
    23.816334397457354`, 36.140146619215834`, -11.742644786248004`}, {
    41.73077392155031, 34.23803358662553, -11.124610797498109`}}], 
   Line3DBox[{{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}, {23.81633588093007, 
    30.742644786248004`, -22.33583858711398}, {41.7307748495094, 
    29.124610797498107`, -21.160268082529033`}, {23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}}], 
   Line3DBox[{{41.7307748495094, 29.124610797498107`, -21.160268082529033`}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    23.81633588093007, 30.742644786248004`, -22.33583858711398}, {
    41.7307748495094, 29.124610797498107`, -21.160268082529033`}}], 
   Line3DBox[{{23.81633588093007, 30.742644786248004`, -22.33583858711398}, {
    23.81633588093007, 22.33583858711398, -30.742644786248004`}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    23.81633588093007, 30.742644786248004`, -22.33583858711398}}], 
   Line3DBox[{{41.7307748495094, 21.160268082529033`, -29.124610797498107`}, {
    41.73077392155031, 11.124610797498109`, -34.23803358662553}, {
    23.81633588093007, 22.33583858711398, -30.742644786248004`}, {
    41.7307748495094, 21.160268082529033`, -29.124610797498107`}}], 
   Line3DBox[{{23.81633588093007, 22.33583858711398, -30.742644786248004`}, {
    23.816334397457354`, 11.742644786248004`, -36.140146619215834`}, {
    41.73077392155031, 11.124610797498109`, -34.23803358662553}, {
    23.81633588093007, 22.33583858711398, -30.742644786248004`}}], 
   Line3DBox[{{41.73077392155031, 11.124610797498109`, -34.23803358662553}, {
    41.73077215646717, -1.*^-6, -35.999999}, {23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}, {41.73077392155031, 
    11.124610797498109`, -34.23803358662553}}], 
   Line3DBox[{{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}, {
    23.81633157572432, -1.*^-6, -37.999999}, {
    41.73077215646717, -1.*^-6, -35.999999}, {23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}}], 
   Line3DBox[{{41.73077215646717, -1.*^-6, -35.999999}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    23.81633157572432, -1.*^-6, -37.999999}, {
    41.73077215646717, -1.*^-6, -35.999999}}], 
   Line3DBox[{{23.81633157572432, -1.*^-6, -37.999999}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    23.81633157572432, -1.*^-6, -37.999999}}], 
   Line3DBox[{{41.73076972703842, -11.124612797498107`, -34.23803358662553}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    41.73076972703842, -11.124612797498107`, -34.23803358662553}}], 
   Line3DBox[{{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}}], 
   Line3DBox[{{
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    41.73076687107326, -21.160270082529035`, -29.124610797498107`}}], 
   Line3DBox[{{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}}], 
   Line3DBox[{{41.73076386813338, -29.12461279749811, -21.160268082529033`}, {
    41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    41.73076386813338, -29.12461279749811, -21.160268082529033`}}], 
   Line3DBox[{{23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, {
    41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}}], 
   Line3DBox[{{41.73076101216748, -34.23803558662552, -11.124610797498109`}, {
    41.730758582737394`, -36.000001, 1.*^-6}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, {
    41.73076101216748, -34.23803558662552, -11.124610797498109`}}], 
   Line3DBox[{{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, {
    23.81630987621824, -38.000001, 1.*^-6}, {41.730758582737394`, -36.000001, 
    1.*^-6}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}}], 
   Line3DBox[{{23.81630987621824, -38.000001, 1.*^-6}, {
    23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}, {-0.000012450411418285512`, -40.000001, 1.*^-6}, {
    23.81630987621824, -38.000001, 1.*^-6}}], 
   Line3DBox[{{-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}, {23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}, {-0.000012450411418285512`, -40.000001, 1.*^-6}}], 
   Line3DBox[{{23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}, {23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}, {-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}, {23.816307054484525`, -36.14014861921583, 
    11.742646786248002`}}], 
   Line3DBox[{{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}, {-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}, {23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}, {-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}}], 
   Line3DBox[{{23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}, {23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}, {-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}, {23.816305571011128`, -30.742646786248006`, 
    22.33584058711398}}], 
   Line3DBox[{{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}, {-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}, {23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}, {-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}}], 
   Line3DBox[{{23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}, {23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}, {-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}, {23.816305571011128`, -22.33584058711398, 
    30.742646786248006`}}], 
   Line3DBox[{{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}, {-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}, {23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}, {-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}}], 
   Line3DBox[{{23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}, {23.81630987621824, -1.*^-6, 
    38.000001}, {-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}, {23.816307054484525`, -11.742646786248002`, 
    36.14014861921583}}], 
   Line3DBox[{{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}, {-0.000012450411418285512`, -1.*^-6, 40.000001}, {
    23.81630987621824, -1.*^-6, 
    38.000001}, {-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}}], 
   Line3DBox[{{23.81630987621824, -1.*^-6, 38.000001}, {23.816313760001435`, 
    11.742644786248004`, 
    36.14014861921583}, {-0.000012450411418285512`, -1.*^-6, 40.000001}, {
    23.81630987621824, -1.*^-6, 38.000001}}], 
   Line3DBox[{{-0.000012450411418285512`, -1.*^-6, 
    40.000001}, {-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}, {23.816313760001435`, 11.742644786248004`, 
    36.14014861921583}, {-0.000012450411418285512`, -1.*^-6, 40.000001}}], 
   Line3DBox[{{23.816313760001435`, 11.742644786248004`, 36.14014861921583}, {
    23.81631832566208, 22.33583858711398, 
    30.742646786248006`}, {-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}, {23.816313760001435`, 11.742644786248004`, 
    36.14014861921583}}], 
   Line3DBox[{{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}, {-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}, {23.81631832566208, 22.33583858711398, 
    30.742646786248006`}, {-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}}], 
   Line3DBox[{{23.81631832566208, 22.33583858711398, 30.742646786248006`}, {
    23.816323126281645`, 30.742644786248004`, 
    22.33584058711398}, {-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}, {23.81631832566208, 22.33583858711398, 
    30.742646786248006`}}], 
   Line3DBox[{{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}, {2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}, {23.816323126281645`, 30.742644786248004`, 
    22.33584058711398}, {-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}}], 
   Line3DBox[{{23.816323126281645`, 30.742644786248004`, 22.33584058711398}, {
    23.81632769194195, 36.140146619215834`, 11.742646786248002`}, {
    2.7544259069145482`*^-6, 32.3606787749979, 23.51141109169893}, {
    23.816323126281645`, 30.742644786248004`, 22.33584058711398}}], 
   Line3DBox[{{2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}, {7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}, {23.81632769194195, 36.140146619215834`, 
    11.742646786248002`}, {2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}}], 
   Line3DBox[{{23.81632769194195, 36.140146619215834`, 11.742646786248002`}, {
    23.81633157572432, 37.999999, 1.*^-6}, {7.993655941618272*^-6, 
    38.04225965180614, 12.360680774997897`}, {23.81632769194195, 
    36.140146619215834`, 11.742646786248002`}}], 
   Line3DBox[{{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}, {0.000012450411276176965`, 39.999999, 1.*^-6}, {
    23.81633157572432, 37.999999, 1.*^-6}, {7.993655941618272*^-6, 
    38.04225965180614, 12.360680774997897`}}], 
   Line3DBox[{{23.81633157572432, 37.999999, 1.*^-6}, {23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}, {0.000012450411276176965`, 
    39.999999, 1.*^-6}, {23.81633157572432, 37.999999, 1.*^-6}}], 
   Line3DBox[{{0.000012450411276176965`, 39.999999, 1.*^-6}, {
    0.00001568843347854454, 38.04225965180614, -12.360678774997899`}, {
    23.816334397457354`, 36.140146619215834`, -11.742644786248004`}, {
    0.000012450411276176965`, 39.999999, 1.*^-6}}], 
   Line3DBox[{{23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}, {23.81633588093007, 
    30.742644786248004`, -22.33583858711398}, {0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}, {23.816334397457354`, 
    36.140146619215834`, -11.742644786248004`}}], 
   Line3DBox[{{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}, {0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}, {23.81633588093007, 
    30.742644786248004`, -22.33583858711398}, {0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}}], 
   Line3DBox[{{23.81633588093007, 30.742644786248004`, -22.33583858711398}, {
    23.81633588093007, 22.33583858711398, -30.742644786248004`}, {
    0.00001739076250828475, 32.3606787749979, -23.511409091698926`}, {
    23.81633588093007, 30.742644786248004`, -22.33583858711398}}], 
   Line3DBox[{{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}, {0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}, {23.81633588093007, 
    22.33583858711398, -30.742644786248004`}, {0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}}], 
   Line3DBox[{{23.81633588093007, 22.33583858711398, -30.742644786248004`}, {
    23.816334397457354`, 11.742644786248004`, -36.140146619215834`}, {
    0.00001739076250828475, 23.511409091698926`, -32.3606787749979}, {
    23.81633588093007, 22.33583858711398, -30.742644786248004`}}], 
   Line3DBox[{{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}, {0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}, {23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}, {0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}}], 
   Line3DBox[{{23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}, {
    23.81633157572432, -1.*^-6, -37.999999}, {0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}, {23.816334397457354`, 
    11.742644786248004`, -36.140146619215834`}}], 
   Line3DBox[{{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}, {
    0.000012450411276176965`, -1.*^-6, -39.999999}, {
    23.81633157572432, -1.*^-6, -37.999999}, {0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}}], 
   Line3DBox[{{23.81633157572432, -1.*^-6, -37.999999}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    0.000012450411276176965`, -1.*^-6, -39.999999}, {
    23.81633157572432, -1.*^-6, -37.999999}}], 
   Line3DBox[{{0.000012450411276176965`, -1.*^-6, -39.999999}, {
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    0.000012450411276176965`, -1.*^-6, -39.999999}}], 
   Line3DBox[{{
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}, {
    23.81632769194195, -11.742646786248002`, -36.140146619215834`}}], 
   Line3DBox[{{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}, {
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}}], 
   Line3DBox[{{
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}, {
    23.816323126281645`, -22.33584058711398, -30.742644786248004`}}], 
   Line3DBox[{{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}, \
{-2.754426475348737*^-6, -32.360680774997896`, -23.511409091698926`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}}], 
   Line3DBox[{{23.81631832566208, -30.742646786248006`, -22.33583858711398}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, \
{-2.754426475348737*^-6, -32.360680774997896`, -23.511409091698926`}, {
    23.81631832566208, -30.742646786248006`, -22.33583858711398}}], 
   Line3DBox[{{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}, {-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, \
{-2.754426475348737*^-6, -32.360680774997896`, -23.511409091698926`}}], 
   Line3DBox[{{
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}, {
    23.81630987621824, -38.000001, 
    1.*^-6}, {-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}, {
    23.816313760001435`, -36.14014861921583, -11.742644786248004`}}], 
   Line3DBox[{{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}, {-0.000012450411418285512`, -40.000001, 1.*^-6}, {
    23.81630987621824, -38.000001, 
    1.*^-6}, {-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}}], 
   Line3DBox[{{-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}, {-39.99345718051421, -45.52465304688692, 
    7.210397535415441}, {-0.000012450411418285512`, -40.000001, 1.*^-6}}], 
   Line3DBox[{{-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}, {-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}, {-39.993460062385736`, -41.06838291563569, 
    20.92538675557315}, {-0.000015688433592231377`, -38.042261651806136`, 
    12.360680774997897`}}], 
   Line3DBox[{{-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}, {-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}, {-39.99346105541093, -32.592053422239815`, 
    32.592053422239815`}, {-0.00001739076256512817, -32.360680774997896`, 
    23.51141109169893}}], 
   Line3DBox[{{-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}, {-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}, {-39.993460062385736`, -20.92538675557315, 
    41.06838291563569}, {-0.00001739076256512817, -23.51141109169893, 
    32.360680774997896`}}], 
   Line3DBox[{{-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}, {-0.000012450411418285512`, -1.*^-6, 
    40.000001}, {-39.99345718051421, -7.210397535415441, 
    45.52465304688692}, {-0.000015688433592231377`, -12.360680774997897`, 
    38.042261651806136`}}], 
   Line3DBox[{{-0.000012450411418285512`, -1.*^-6, 
    40.000001}, {-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}, {-39.99345269189416, 7.210395535415441, 
    45.52465304688692}, {-0.000012450411418285512`, -1.*^-6, 40.000001}}], 
   Line3DBox[{{-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}, {-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}, {-39.99344703590293, 20.92538475557315, 
    41.06838291563569}, {-7.993656367943913*^-6, 12.360678774997899`, 
    38.042261651806136`}}], 
   Line3DBox[{{-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}, {2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}, {-39.993440766188314`, 32.59205142223982, 
    32.592053422239815`}, {-2.754426475348737*^-6, 23.511409091698926`, 
    32.360680774997896`}}], 
   Line3DBox[{{2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}, {7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}, {-39.99343449647358, 41.06838091563569, 
    20.92538675557315}, {2.7544259069145482`*^-6, 32.3606787749979, 
    23.51141109169893}}], 
   Line3DBox[{{7.993655941618272*^-6, 38.04225965180614, 
    12.360680774997897`}, {0.000012450411276176965`, 39.999999, 
    1.*^-6}, {-39.99342884048207, 45.52465104688692, 7.210397535415441}, {
    7.993655941618272*^-6, 38.04225965180614, 12.360680774997897`}}], 
   Line3DBox[{{0.000012450411276176965`, 39.999999, 1.*^-6}, {
    0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}, {-39.99342435186185, 
    45.52465104688692, -7.210395535415441}, {0.000012450411276176965`, 
    39.999999, 1.*^-6}}], 
   Line3DBox[{{0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}, {0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}, {-39.993421469990324`, 
    41.06838091563569, -20.92538475557315}, {0.00001568843347854454, 
    38.04225965180614, -12.360678774997899`}}], 
   Line3DBox[{{0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}, {0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}, {-39.993420476965014`, 
    32.59205142223982, -32.59205142223982}, {0.00001739076250828475, 
    32.3606787749979, -23.511409091698926`}}], 
   Line3DBox[{{0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}, {0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}, {-39.993421469990324`, 
    20.92538475557315, -41.06838091563569}, {0.00001739076250828475, 
    23.511409091698926`, -32.3606787749979}}], 
   Line3DBox[{{0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}, {
    0.000012450411276176965`, -1.*^-6, -39.999999}, {-39.99342435186185, 
    7.210395535415441, -45.52465104688692}, {0.00001568843347854454, 
    12.360678774997899`, -38.04225965180614}}], 
   Line3DBox[{{0.000012450411276176965`, -1.*^-6, -39.999999}, {
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}, \
{-39.99342884048207, -7.210397535415441, -45.52465104688692}, {
    0.000012450411276176965`, -1.*^-6, -39.999999}}], 
   Line3DBox[{{
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}, {
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}, \
{-39.99343449647358, -20.92538675557315, -41.06838091563569}, {
    7.993655941618272*^-6, -12.360680774997897`, -38.04225965180614}}], 
   Line3DBox[{{
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}, \
{-2.754426475348737*^-6, -32.360680774997896`, -23.511409091698926`}, \
{-39.993440766188314`, -32.592053422239815`, -32.59205142223982}, {
    2.7544259069145482`*^-6, -23.51141109169893, -32.3606787749979}}], 
   Line3DBox[{{-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}, {-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}, {-39.99344703590293, -41.06838291563569, \
-20.92538475557315}, {-2.754426475348737*^-6, -32.360680774997896`, \
-23.511409091698926`}}], 
   Line3DBox[{{-7.993656367943913*^-6, -38.042261651806136`, \
-12.360678774997899`}, {-0.000012450411418285512`, -40.000001, 
    1.*^-6}, {-39.99345269189416, -45.52465304688692, -7.210395535415441}, \
{-7.993656367943913*^-6, -38.042261651806136`, -12.360678774997899`}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.60130153976305*^9, 3.61470930612342*^9, 
  3.614729161697484*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[242]:="]
}, Open  ]],

Cell[TextData[{
 "Unfortunately, there is a big tradeoff between the ",
 StyleBox["SurfacePoints", "Input"],
 " number and the ray-trace calculation time. Therefore, it is best to use \
the lowest possible ",
 StyleBox["SurfacePoints", "Input"],
 " setting that still gives the correct trace. In general, the ",
 StyleBox["SurfacePoints", "Input"],
 " setting does not usually improve the numeric accuracy of the ray trace. It \
instead permits complex-shaped surfaces to be ray-traced without difficulty. \
In the present ",
 StyleBox["axiconMirrorWithRipples", "Input"],
 " example, the default ",
 StyleBox["SurfacePoints", "Input"],
 " setting appears to enable a good trace to occur. It is consequently \
unnecessary to increase the ",
 StyleBox["SurfacePoints", "Input"],
 " value beyond the default setting."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[ 
\t{
\tMove[SingleRay[], {-10, 0}, 10],
\taxiconMirrorWithRipples[80, 7.5, 200, 20., 4.]
\t},

\tPlotType -> TopView,
\tPlotPoints -> 60
];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"In[243]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301540577829*^9, 3.614709307036249*^9, 
  3.614729162760067*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[243]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301540577829*^9, 3.614709307036249*^9, 
  3.614729162830491*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[243]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxlk8srRVEUxg8TZSB1MzJASpHIK6/cPo90JdK9NheJjudV8g8QxYSRCQMZ
GBC2qxgYCDHwDxApEyYmumJignD2Xp/Jseu0Omf/1tprf+s7Oe5UeCTZcZwy
7zFx4TjxcJcSqHPsakJImVWKPe2tYCPaXt7O+r4B+3mmAV8/3ppthsVP67HW
0Bw4jLQI/wGEDXfbgi4Tq4FPw/+EhH8LYtNwBSHZn6xD79lxoj0ekvznWtZv
FX68Bt2LKTnXcx3CP1Vh13ATncK7lcI5PRIfK+T8lX7h+8sRrp1+XT0fFP6+
FN+mfpaLJMNHS7CzfNWUuHERN/u6GJ0m792V/K1C2PbPXRitnI18WGyJ/Foe
uqeKTgJ7LqL23FzhB4aEX85G/HI+PXYxLPsZmYiYeDSKA5OfmsH+Y4xp/94V
eU1+n/UU61lscEiid16U/Sj2s8t+Nfu13IUr0buP4n0V77tNPTT1sFw2eU+v
CPXU1LOLeivq7Z9HnPPSnFcv56k4T8vNtYpuYzXoox80/fDnF0W/fNBPNrwG
0Ua/KfptnX7U9KPfr34/x+h3Tb/7/wf/+y8+qUOf
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxlk88rRFEUx5/ZKAupaVYWSCkSGYTRTNeQZppGmhlvHhI9P0dp/gEyxYbV
bFjIwoKYeU+xsJiY5iz8A0TKho2NRmxshvy473yzeE697rvvfs6558f31enJ
yKxDUZT230eubAnBayWNSDubE1lpFS46vlyrStCMsL67qsnCpqaZT9eSlmw5
dxo6n2/VU0b6bersv9PAPOnM7zVy/HfwB810mL4aKN6Az7YyXwtea6No7/Lr
dmGKz+/dpFr3TLD/RAfzyijzj51kSm4xxrzeRWMb5XXXqWHmn7qZT4XEt7R5
D43nc8UhM8D8cy/ty7UpwPySl0oWGGD+1Udh+f02yOc9gnb9g87TaJD9S4I+
Jbc6yPlc9FH45S0//iWYX/FTwnpxM+/rp/Vc8eGu3OnlOgb+7QPgDfD2ePb7
dpCPgXwiyFdFvh+ox+LffH/1qqh3DP0w0A+OH2J+wUNx9FNFPzPot4F+2+cR
wbxUzCuCeRqY55eMX6OLMsz7CHowoYcY9KJCL1b6BV04oKcs9GZCb3HoUYMe
LX5ymvlfvZrQswY9R6H3E+jd/j/Y9z+MOVlc
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQ3bLzzf3r7MK2DBDQ4BEKAkYOML7v2w97o/85wPl/
/gNBvRucP8vJTXhjsCecHwTSfhXB/w1S/98Dzl+yCgi0EPyovTvf+K1B8CHm
e8P54Z3sipcaAuD8lSD9WSFwPoSKRLV/aiyCb13zftr+BDj/H8h8+SQ4f8WE
iy5vriD4ISD9XxF8sPP3I/gg61d1Ifjh+Xq7hVejqY9PhvPXHGkWyDyQAucH
g8zfmobm/kyc/FA09WvRzAOTCQj7ItDcsxLNvWDyAIIfiubf5WjhASYVEPxg
tPAMQwtvCIWIjzVo8RWFFp8QEhHf0WjpAT29/EJLT75o6W0OWnpET6/o6TkT
Lb2j5wd0PgCfX9LR
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQGZDlBGQygIbE2D89ceaRbIPJAC54PJhGQ4PyJf
b7fw6iQ4f+UqIOhKQlV/AMEHm/8VwV8+4aLLmyto6hUQ/GDrmvfT9ifA+WEg
/VNjUdUzRML5a0D2Z4XA+VGd7IqXGgJQ1Td4w/nRe3e+8VvjAecvAenXQvB/
/QcBBN8XZP9VTzh/jpOb8MZgBP8PSHm9G0L92w97o/85wPmZ4AAwgvNbdr65
f51d2BYX3wNNPbp56PbNQnNPEJp7f6P5B92/UWjhATEfEV7haOG5Ei28IRQi
PoLQ4isILT7/gcyXT4LzV6ClhxC09AJ2/n4EfxVaegtHS49g9fGI9LoGLT0H
o6V3CJWJkw8Am9LPRA==
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{200., -3.75}, {166.01282525764455`, -6.770833333333333}, {
      166.01282525764455`, -6.756336459428045}, {200., -3.741970962144763}, {
      200., -3.75}}], 
     PolygonBox[{{200., -3.741970962144763}, {
      166.01282525764455`, -6.756336459428045}, {
      166.01282525764455`, -6.712907915551841}, {200., -3.717918230151789}, {
      200., -3.741970962144763}}], 
     PolygonBox[{{200., -3.717918230151789}, {
      166.01282525764455`, -6.712907915551841}, {
      166.01282525764455`, -6.640733669396873}, {200., -3.677944801512114}, {
      200., -3.717918230151789}}], 
     PolygonBox[{{200., -3.677944801512114}, {
      166.01282525764455`, -6.640733669396873}, {
      166.01282525764455`, -6.540122782165566}, {
      199.99999999999997`, -3.6222218485840063`}, {
      200., -3.677944801512114}}], 
     PolygonBox[{{199.99999999999997`, -3.6222218485840063`}, {
      166.01282525764455`, -6.540122782165566}, {
      166.01282525764455`, -6.411506085123111}, {200., -3.550987985606646}, {
      199.99999999999997`, -3.6222218485840063`}}], 
     PolygonBox[{{200., -3.550987985606646}, {
      166.01282525764455`, -6.411506085123111}, {
      166.01282525764455`, -6.255434334711838}, {
      200., -3.4645482469173254`}, {200., -3.550987985606646}}], 
     PolygonBox[{{199.99999999999997`, -3.4645482469173254`}, {
      166.01282525764455`, -6.255434334711838}, {
      166.01282525764455`, -6.072575854127578}, {
      199.99999999999997`, -3.3632727807475815`}, {
      199.99999999999997`, -3.4645482469173254`}}], 
     PolygonBox[{{199.99999999999997`, -3.3632727807475815`}, {
      166.01282525764455`, -6.072575854127578}, {
      166.01282525764455`, -5.863713671457137}, {200., -3.247595264191645}, {
      199.99999999999997`, -3.3632727807475815`}}], 
     PolygonBox[{{200., -3.247595264191645}, {
      166.01282525764455`, -5.863713671457137}, {
      166.01282525764455`, -5.629742166631816}, {
      200., -3.1180110461345447`}, {200., -3.247595264191645}}], 
     PolygonBox[{{200., -3.1180110461345447`}, {
      166.01282525764455`, -5.629742166631816}, {
      166.01282525764455`, -5.371663241555238}, {200., -2.975075026092132}, {
      200., -3.1180110461345447`}}], 
     PolygonBox[{{200., -2.9750750260921324`}, {
      166.01282525764455`, -5.371663241555239}, {
      166.01282525764455`, -5.090582029805576}, {
      200., -2.8193992780461654`}, {200., -2.9750750260921324`}}], 
     PolygonBox[{{200., -2.8193992780461654`}, {
      166.01282525764455`, -5.090582029805576}, {
      166.01282525764455`, -4.787702164283916}, {
      200., -2.6516504294495533`}, {200., -2.8193992780461654`}}], 
     PolygonBox[{{200., -2.6516504294495533`}, {
      166.01282525764455`, -4.787702164283916}, {
      166.01282525764455`, -4.464320623073383}, {200., -2.472546806625258}, {
      200., -2.6516504294495533`}}], 
     PolygonBox[{{200., -2.4725468066252585`}, {
      166.01282525764455`, -4.464320623073384}, {
      166.01282525764455`, -4.121822175579879}, {
      200., -2.2828553587827023`}, {200., -2.4725468066252585`}}], 
     PolygonBox[{{200., -2.2828553587827023`}, {
      166.01282525764455`, -4.121822175579879}, {
      166.01282525764455`, -3.7616734527368902`}, {
      200., -2.0833883738235084`}, {200., -2.2828553587827023`}}], 
     PolygonBox[{{200., -2.083388373823509}, {
      166.01282525764455`, -3.761673452736891}, {
      166.01282525764455`, -3.3854166666666674`}, {
      200., -1.8750000000000004`}, {200., -2.083388373823509}}], 
     PolygonBox[{{200., -1.8750000000000004`}, {
      166.01282525764455`, -3.3854166666666674`}, {
      166.01282525764455`, -2.9946630066911553`}, {
      199.99999999999997`, -1.6585825883212555`}, {
      200., -1.8750000000000004`}}], 
     PolygonBox[{{199.99999999999997`, -1.6585825883212555`}, {
      166.01282525764455`, -2.9946630066911553`}, {
      166.01282525764455`, -2.5910857399719633`}, {
      200., -1.4350628713690876`}, {
      199.99999999999997`, -1.6585825883212555`}}], 
     PolygonBox[{{199.99999999999997`, -1.435062871369087}, {
      166.01282525764455`, -2.5910857399719625`}, {
      166.01282525764455`, -2.1764130463234905`}, {
      200., -1.2053979948868563`}, {
      199.99999999999997`, -1.435062871369087}}], 
     PolygonBox[{{200., -1.2053979948868563`}, {
      166.01282525764455`, -2.1764130463234905`}, {
      166.01282525764455`, -1.7524206178816524`}, {
      200., -0.9705714191344537}, {200., -1.2053979948868563`}}], 
     PolygonBox[{{200., -0.9705714191344537}, {
      166.01282525764455`, -1.7524206178816524`}, {
      166.01282525764455`, -1.320924055317537}, {200., -0.731588707560482}, {
      200., -0.9705714191344537}}], 
     PolygonBox[{{200., -0.7315887075604812}, {
      166.01282525764455`, -1.3209240553175357`}, {
      166.01282525764455`, -0.8837710931566001}, {
      200., -0.4894732208251939}, {200., -0.7315887075604812}}], 
     PolygonBox[{{200., -0.4894732208251939}, {
      166.01282525764455`, -0.8837710931566001}, {
      166.01282525764455`, -0.4428336874957617}, {
      200., -0.24526173461303727`}, {200., -0.4894732208251939}}], 
     PolygonBox[{{200., -0.24526173461303727`}, {
      166.01282525764455`, -0.4428336874957617}, {
      166.01282525764455`, -1.9180209809745763`*^-15}, {
      200., -1.0622885433089962`*^-15}, {200., -0.24526173461303727`}}], 
     PolygonBox[{{200., -2.2962127484012875`*^-16}, {
      166.01282525764455`, -4.1459396846134354`*^-16}, {166.01282525764455`, 
      0.44283368749575935`}, {200., 0.24526173461303596`}, {
      200., -2.2962127484012875`*^-16}}], 
     PolygonBox[{{200., 0.24526173461303596`}, {166.01282525764455`, 
      0.44283368749575935`}, {166.01282525764455`, 0.8837710931565979}, {200.,
       0.4894732208251927}, {200., 0.24526173461303596`}}], 
     PolygonBox[{{200., 0.4894732208251927}, {166.01282525764455`, 
      0.8837710931565979}, {166.01282525764455`, 1.320924055317533}, {
      199.99999999999997`, 0.7315887075604799}, {200., 0.4894732208251927}}], 
     PolygonBox[{{199.99999999999997`, 0.7315887075604799}, {
      166.01282525764455`, 1.320924055317533}, {166.01282525764455`, 
      1.7524206178816484`}, {199.99999999999997`, 0.9705714191344516}, {
      199.99999999999997`, 0.7315887075604799}}], 
     PolygonBox[{{200., 0.9705714191344523}, {166.01282525764455`, 
      1.7524206178816502`}, {166.01282525764455`, 2.1764130463234883`}, {200.,
       1.2053979948868552`}, {200., 0.9705714191344523}}], 
     PolygonBox[{{200., 1.2053979948868552`}, {166.01282525764455`, 
      2.1764130463234883`}, {166.01282525764455`, 2.59108573997196}, {
      199.99999999999997`, 1.4350628713690856`}, {200., 
      1.2053979948868552`}}], 
     PolygonBox[{{199.99999999999997`, 1.4350628713690856`}, {
      166.01282525764455`, 2.59108573997196}, {166.01282525764455`, 
      2.9946630066911535`}, {200., 1.6585825883212542`}, {199.99999999999997`,
       1.4350628713690856`}}], 
     PolygonBox[{{200., 1.6585825883212542`}, {166.01282525764455`, 
      2.9946630066911535`}, {166.01282525764455`, 3.385416666666665}, {200., 
      1.8749999999999991`}, {200., 1.6585825883212542`}}], 
     PolygonBox[{{200., 1.8749999999999991`}, {166.01282525764455`, 
      3.385416666666665}, {166.01282525764455`, 3.761673452736888}, {
      199.99999999999997`, 2.0833883738235075`}, {200., 
      1.8749999999999991`}}], 
     PolygonBox[{{199.99999999999997`, 2.0833883738235075`}, {
      166.01282525764455`, 3.761673452736888}, {166.01282525764455`, 
      4.121822175579878}, {200., 2.2828553587827014`}, {199.99999999999997`, 
      2.0833883738235075`}}], 
     PolygonBox[{{200., 2.2828553587827014`}, {166.01282525764455`, 
      4.121822175579878}, {166.01282525764455`, 4.46432062307338}, {200., 
      2.4725468066252567`}, {200., 2.2828553587827014`}}], 
     PolygonBox[{{200., 2.4725468066252567`}, {166.01282525764455`, 
      4.46432062307338}, {166.01282525764455`, 4.787702164283912}, {200., 
      2.6516504294495515`}, {200., 2.4725468066252567`}}], 
     PolygonBox[{{200., 2.651650429449553}, {166.01282525764455`, 
      4.787702164283915}, {166.01282525764455`, 5.090582029805575}, {200., 
      2.819399278046165}, {200., 2.651650429449553}}], 
     PolygonBox[{{200., 2.819399278046165}, {166.01282525764455`, 
      5.090582029805575}, {166.01282525764455`, 5.371663241555237}, {
      199.99999999999997`, 2.9750750260921315`}, {200., 2.819399278046165}}], 
     PolygonBox[{{199.99999999999997`, 2.9750750260921315`}, {
      166.01282525764455`, 5.371663241555237}, {166.01282525764455`, 
      5.629742166631814}, {200., 3.118011046134544}, {199.99999999999997`, 
      2.9750750260921315`}}], 
     PolygonBox[{{200., 3.118011046134544}, {166.01282525764455`, 
      5.629742166631814}, {166.01282525764455`, 5.863713671457135}, {200., 
      3.247595264191644}, {200., 3.118011046134544}}], 
     PolygonBox[{{200., 3.247595264191644}, {166.01282525764455`, 
      5.863713671457135}, {166.01282525764455`, 6.072575854127576}, {
      199.99999999999997`, 3.3632727807475806`}, {200., 3.247595264191644}}], 
     PolygonBox[{{199.99999999999997`, 3.3632727807475806`}, {
      166.01282525764455`, 6.072575854127576}, {166.01282525764455`, 
      6.255434334711836}, {200., 3.4645482469173245`}, {199.99999999999997`, 
      3.3632727807475806`}}], 
     PolygonBox[{{199.99999999999997`, 3.4645482469173254`}, {
      166.01282525764455`, 6.255434334711838}, {166.01282525764455`, 
      6.41150608512311}, {200., 3.5509879856066457`}, {199.99999999999997`, 
      3.4645482469173254`}}], 
     PolygonBox[{{200., 3.5509879856066457`}, {166.01282525764455`, 
      6.41150608512311}, {166.01282525764455`, 6.540122782165566}, {200., 
      3.622221848584006}, {200., 3.5509879856066457`}}], 
     PolygonBox[{{200., 3.622221848584006}, {166.01282525764455`, 
      6.540122782165566}, {166.01282525764455`, 6.640733669396873}, {
      199.99999999999997`, 3.677944801512114}, {200., 3.622221848584006}}], 
     PolygonBox[{{199.99999999999997`, 3.677944801512114}, {
      166.01282525764455`, 6.640733669396873}, {166.01282525764455`, 
      6.712907915551841}, {200., 3.717918230151789}, {199.99999999999997`, 
      3.677944801512114}}], 
     PolygonBox[{{200., 3.717918230151789}, {166.01282525764455`, 
      6.712907915551841}, {166.01282525764455`, 6.756336459428045}, {200., 
      3.741970962144763}, {200., 3.717918230151789}}], 
     PolygonBox[{{200., 3.741970962144763}, {166.01282525764455`, 
      6.756336459428045}, {166.01282525764455`, 6.770833333333333}, {200., 
      3.75}, {200., 3.741970962144763}}], 
     PolygonBox[{{200., 3.75}, {166.01282525764455`, 6.770833333333333}, {
      166.01282525764455`, 6.756336459428045}, {200., 3.741970962144763}, {
      200., 3.75}}], 
     PolygonBox[{{200., 3.741970962144763}, {166.01282525764455`, 
      6.756336459428045}, {166.01282525764455`, 6.712907915551842}, {200., 
      3.7179182301517892`}, {200., 3.741970962144763}}], 
     PolygonBox[{{200., 3.7179182301517892`}, {166.01282525764455`, 
      6.712907915551842}, {166.01282525764455`, 6.640733669396873}, {
      199.99999999999997`, 3.6779448015121146`}, {200., 
      3.7179182301517892`}}], 
     PolygonBox[{{199.99999999999997`, 3.6779448015121146`}, {
      166.01282525764455`, 6.640733669396873}, {166.01282525764455`, 
      6.540122782165567}, {199.99999999999997`, 3.6222218485840068`}, {
      199.99999999999997`, 3.6779448015121146`}}], 
     PolygonBox[{{199.99999999999997`, 3.6222218485840068`}, {
      166.01282525764455`, 6.540122782165567}, {166.01282525764455`, 
      6.411506085123111}, {200., 3.5509879856066466`}, {199.99999999999997`, 
      3.6222218485840068`}}], 
     PolygonBox[{{200., 3.5509879856066466`}, {166.01282525764455`, 
      6.411506085123111}, {166.01282525764455`, 6.255434334711839}, {200., 
      3.4645482469173263`}, {200., 3.5509879856066466`}}], 
     PolygonBox[{{200., 3.4645482469173263`}, {166.01282525764455`, 
      6.255434334711839}, {166.01282525764455`, 6.072575854127579}, {200., 
      3.3632727807475824`}, {200., 3.4645482469173263`}}], 
     PolygonBox[{{200., 3.3632727807475815`}, {166.01282525764455`, 
      6.072575854127578}, {166.01282525764455`, 5.863713671457138}, {200., 
      3.2475952641916455`}, {200., 3.3632727807475815`}}], 
     PolygonBox[{{200., 3.2475952641916455`}, {166.01282525764455`, 
      5.863713671457138}, {166.01282525764455`, 5.629742166631818}, {
      199.99999999999997`, 3.1180110461345456`}, {200., 
      3.2475952641916455`}}], 
     PolygonBox[{{199.99999999999997`, 3.1180110461345456`}, {
      166.01282525764455`, 5.629742166631818}, {166.01282525764455`, 
      5.37166324155524}, {200., 2.975075026092133}, {199.99999999999997`, 
      3.1180110461345456`}}], 
     PolygonBox[{{200., 2.975075026092133}, {166.01282525764455`, 
      5.37166324155524}, {166.01282525764455`, 5.090582029805578}, {200., 
      2.8193992780461663`}, {200., 2.975075026092133}}], 
     PolygonBox[{{200., 2.8193992780461663`}, {166.01282525764455`, 
      5.090582029805578}, {166.01282525764455`, 4.7877021642839175`}, {200., 
      2.6516504294495546`}, {200., 2.8193992780461663`}}], 
     PolygonBox[{{200., 2.6516504294495546`}, {166.01282525764455`, 
      4.7877021642839175`}, {166.01282525764455`, 4.4643206230733865`}, {200.,
       2.4725468066252603`}, {200., 2.6516504294495546`}}], 
     PolygonBox[{{199.99999999999997`, 2.472546806625259}, {
      166.01282525764455`, 4.464320623073384}, {166.01282525764455`, 
      4.121822175579881}, {200., 2.282855358782703}, {199.99999999999997`, 
      2.472546806625259}}], 
     PolygonBox[{{200., 2.282855358782703}, {166.01282525764455`, 
      4.121822175579881}, {166.01282525764455`, 3.76167345273689}, {200., 
      2.0833883738235084`}, {200., 2.282855358782703}}], 
     PolygonBox[{{200., 2.083388373823511}, {166.01282525764455`, 
      3.7616734527368947`}, {166.01282525764455`, 3.3854166666666696`}, {
      199.99999999999997`, 1.8750000000000018`}, {200., 2.083388373823511}}], 
     PolygonBox[{{199.99999999999997`, 1.8750000000000018`}, {
      166.01282525764455`, 3.3854166666666696`}, {166.01282525764455`, 
      2.994663006691155}, {200., 1.658582588321255}, {199.99999999999997`, 
      1.8750000000000018`}}], 
     PolygonBox[{{200., 1.658582588321255}, {166.01282525764455`, 
      2.994663006691155}, {166.01282525764455`, 2.59108573997196}, {
      199.99999999999997`, 1.4350628713690856`}, {200., 1.658582588321255}}], 
     PolygonBox[{{200., 1.4350628713690887`}, {166.01282525764455`, 
      2.5910857399719656`}, {166.01282525764455`, 2.1764130463234914`}, {200.,
       1.2053979948868567`}, {200., 1.4350628713690887`}}], 
     PolygonBox[{{200., 1.2053979948868567`}, {166.01282525764455`, 
      2.1764130463234914`}, {166.01282525764455`, 1.7524206178816502`}, {200.,
       0.9705714191344523}, {200., 1.2053979948868567`}}], 
     PolygonBox[{{200., 0.9705714191344557}, {166.01282525764455`, 
      1.752420617881656}, {166.01282525764455`, 1.3209240553175379`}, {200., 
      0.7315887075604824}, {200., 0.9705714191344557}}], 
     PolygonBox[{{200., 0.7315887075604824}, {166.01282525764455`, 
      1.3209240553175379`}, {166.01282525764455`, 0.8837710931565996}, {200., 
      0.4894732208251936}, {200., 0.7315887075604824}}], 
     PolygonBox[{{200., 0.48947322082519684`}, {166.01282525764455`, 
      0.8837710931566054}, {166.01282525764455`, 0.4428336874957641}, {200., 
      0.24526173461303857`}, {200., 0.48947322082519684`}}], 
     PolygonBox[{{200., 0.24526173461303857`}, {166.01282525764455`, 
      0.4428336874957641}, {166.01282525764455`, 1.2437819053840304`*^-15}, {
      200., 6.888638245203861*^-16}, {200., 0.24526173461303857`}}], 
     PolygonBox[{{200., 6.888638245203861*^-16}, {166.01282525764455`, 
      1.2437819053840304`*^-15}, {166.01282525764455`, -0.4428336874957616}, {
      200., -0.2452617346130372}, {200., 6.888638245203861*^-16}}], 
     PolygonBox[{{199.99999999999997`, -0.24526173461303388`}, {
      166.01282525764455`, -0.4428336874957556}, {
      166.01282525764455`, -0.8837710931565971}, {
      200., -0.48947322082519223`}, {
      199.99999999999997`, -0.24526173461303388`}}], 
     PolygonBox[{{200., -0.48947322082519223`}, {
      166.01282525764455`, -0.8837710931565971}, {
      166.01282525764455`, -1.3209240553175352`}, {
      200., -0.7315887075604811}, {200., -0.48947322082519223`}}], 
     PolygonBox[{{199.99999999999997`, -0.7315887075604778}, {
      166.01282525764452`, -1.3209240553175294`}, {
      166.01282525764455`, -1.752420617881648}, {
      199.99999999999997`, -0.9705714191344511}, {
      199.99999999999997`, -0.7315887075604778}}], 
     PolygonBox[{{199.99999999999997`, -0.9705714191344511}, {
      166.01282525764455`, -1.752420617881648}, {
      166.01282525764455`, -2.176413046323489}, {
      200., -1.2053979948868556`}, {
      199.99999999999997`, -0.9705714191344511}}], 
     PolygonBox[{{200., -1.2053979948868556`}, {
      166.01282525764455`, -2.176413046323489}, {
      166.01282525764455`, -2.5910857399719633`}, {
      200., -1.4350628713690876`}, {200., -1.2053979948868556`}}], 
     PolygonBox[{{200., -1.4350628713690843`}, {
      166.01282525764455`, -2.591085739971958}, {
      166.01282525764455`, -2.9946630066911526`}, {
      199.99999999999997`, -1.658582588321254}, {
      200., -1.4350628713690843`}}], 
     PolygonBox[{{199.99999999999997`, -1.658582588321254}, {
      166.01282525764455`, -2.9946630066911526`}, {
      166.01282525764455`, -3.3854166666666674`}, {
      200., -1.8750000000000004`}, {
      199.99999999999997`, -1.658582588321254}}], 
     PolygonBox[{{200., -1.8749999999999976`}, {
      166.01282525764455`, -3.385416666666662}, {
      166.01282525764455`, -3.7616734527368876`}, {
      200., -2.083388373823507}, {200., -1.8749999999999976`}}], 
     PolygonBox[{{200., -2.083388373823507}, {
      166.01282525764455`, -3.7616734527368876`}, {
      166.01282525764455`, -4.1218221755798785`}, {
      200., -2.282855358782702}, {200., -2.083388373823507}}], 
     PolygonBox[{{200., -2.2828553587826996`}, {
      166.01282525764455`, -4.121822175579874}, {
      166.01282525764455`, -4.46432062307338}, {200., -2.4725468066252567`}, {
      200., -2.2828553587826996`}}], 
     PolygonBox[{{200., -2.4725468066252567`}, {
      166.01282525764455`, -4.46432062307338}, {
      166.01282525764455`, -4.787702164283914}, {
      200., -2.6516504294495524`}, {200., -2.4725468066252567`}}], 
     PolygonBox[{{200., -2.6516504294495524`}, {
      166.01282525764455`, -4.787702164283914}, {
      166.01282525764455`, -5.090582029805576}, {
      200., -2.8193992780461654`}, {200., -2.6516504294495524`}}], 
     PolygonBox[{{200., -2.8193992780461636`}, {
      166.01282525764455`, -5.090582029805573}, {
      166.01282525764455`, -5.371663241555236}, {200., -2.975075026092131}, {
      200., -2.8193992780461636`}}], 
     PolygonBox[{{200., -2.975075026092131}, {
      166.01282525764455`, -5.371663241555236}, {
      166.01282525764455`, -5.629742166631816}, {
      200., -3.1180110461345447`}, {200., -2.975075026092131}}], 
     PolygonBox[{{200., -3.118011046134543}, {
      166.01282525764455`, -5.6297421666318135`}, {
      166.01282525764455`, -5.863713671457135}, {
      199.99999999999997`, -3.247595264191644}, {200., -3.118011046134543}}], 
     PolygonBox[{{199.99999999999997`, -3.247595264191644}, {
      166.01282525764455`, -5.863713671457135}, {
      166.01282525764455`, -6.072575854127576}, {200., -3.363272780747581}, {
      199.99999999999997`, -3.247595264191644}}], 
     PolygonBox[{{200., -3.3632727807475793`}, {
      166.01282525764455`, -6.072575854127574}, {
      166.01282525764455`, -6.255434334711836}, {
      200., -3.4645482469173245`}, {200., -3.3632727807475793`}}], 
     PolygonBox[{{200., -3.4645482469173245`}, {
      166.01282525764455`, -6.255434334711836}, {
      166.01282525764455`, -6.41150608512311}, {200., -3.5509879856066457`}, {
      200., -3.4645482469173245`}}], 
     PolygonBox[{{200., -3.5509879856066457`}, {
      166.01282525764455`, -6.41150608512311}, {
      166.01282525764455`, -6.540122782165566}, {
      199.99999999999997`, -3.6222218485840063`}, {
      200., -3.5509879856066457`}}], 
     PolygonBox[{{200., -3.6222218485840054`}, {
      166.01282525764455`, -6.540122782165565}, {
      166.01282525764455`, -6.640733669396871}, {
      200., -3.6779448015121137`}, {200., -3.6222218485840054`}}], 
     PolygonBox[{{200., -3.6779448015121137`}, {
      166.01282525764455`, -6.640733669396871}, {
      166.01282525764455`, -6.712907915551841}, {200., -3.717918230151789}, {
      200., -3.6779448015121137`}}], 
     PolygonBox[{{200., -3.7179182301517884`}, {
      166.01282525764455`, -6.71290791555184}, {
      166.01282525764455`, -6.756336459428045}, {200., -3.741970962144763}, {
      200., -3.7179182301517884`}}], 
     PolygonBox[{{200., -3.741970962144763}, {
      166.01282525764455`, -6.756336459428045}, {
      166.01282525764455`, -6.770833333333333}, {200., -3.75}, {
      200., -3.741970962144763}}], 
     PolygonBox[{{166.01282525764455`, -6.770833333333333}, {
      149.3461585909779, -9.791666666666666}, {
      149.3461585909779, -9.770701956711326}, {
      166.01282525764455`, -6.756336459428045}, {
      166.01282525764455`, -6.770833333333333}}], 
     PolygonBox[{{166.01282525764455`, -6.756336459428045}, {
      149.3461585909779, -9.770701956711326}, {
      149.3461585909779, -9.707897600951894}, {
      166.01282525764455`, -6.712907915551841}, {
      166.01282525764455`, -6.756336459428045}}], 
     PolygonBox[{{166.01282525764455`, -6.712907915551841}, {
      149.3461585909779, -9.707897600951894}, {
      149.3461585909779, -9.60352253728163}, {
      166.01282525764455`, -6.640733669396873}, {
      166.01282525764455`, -6.712907915551841}}], 
     PolygonBox[{{166.01282525764455`, -6.640733669396873}, {
      149.3461585909779, -9.60352253728163}, {
      149.34615859097786`, -9.458023715747128}, {
      166.01282525764455`, -6.540122782165566}, {
      166.01282525764455`, -6.640733669396873}}], 
     PolygonBox[{{166.01282525764455`, -6.540122782165566}, {
      149.34615859097786`, -9.458023715747128}, {
      149.3461585909779, -9.272024184639577}, {
      166.01282525764455`, -6.411506085123111}, {
      166.01282525764455`, -6.540122782165566}}], 
     PolygonBox[{{166.01282525764455`, -6.411506085123111}, {
      149.3461585909779, -9.272024184639577}, {
      149.3461585909779, -9.04632042250635}, {
      166.01282525764455`, -6.255434334711838}, {
      166.01282525764455`, -6.411506085123111}}], 
     PolygonBox[{{166.01282525764455`, -6.255434334711838}, {
      149.3461585909779, -9.04632042250635}, {
      149.3461585909779, -8.781878927507574}, {
      166.01282525764455`, -6.072575854127578}, {
      166.01282525764455`, -6.255434334711838}}], 
     PolygonBox[{{166.01282525764455`, -6.072575854127578}, {
      149.3461585909779, -8.781878927507574}, {
      149.3461585909779, -8.479832078722628}, {
      166.01282525764455`, -5.863713671457137}, {
      166.01282525764455`, -6.072575854127578}}], 
     PolygonBox[{{166.01282525764455`, -5.863713671457137}, {
      149.3461585909779, -8.479832078722628}, {
      149.3461585909779, -8.141473287129088}, {
      166.01282525764455`, -5.629742166631816}, {
      166.01282525764455`, -5.863713671457137}}], 
     PolygonBox[{{166.01282525764455`, -5.629742166631816}, {
      149.3461585909779, -8.141473287129088}, {
      149.3461585909779, -7.768251457018344}, {
      166.01282525764455`, -5.371663241555238}, {
      166.01282525764455`, -5.629742166631816}}], 
     PolygonBox[{{166.01282525764455`, -5.371663241555239}, {
      149.3461585909779, -7.768251457018345}, {
      149.3461585909779, -7.361764781564987}, {
      166.01282525764455`, -5.090582029805576}, {
      166.01282525764455`, -5.371663241555239}}], 
     PolygonBox[{{166.01282525764455`, -5.090582029805576}, {
      149.3461585909779, -7.361764781564987}, {
      149.3461585909779, -6.923753899118278}, {
      166.01282525764455`, -4.787702164283916}, {
      166.01282525764455`, -5.090582029805576}}], 
     PolygonBox[{{166.01282525764455`, -4.787702164283916}, {
      149.3461585909779, -6.923753899118278}, {
      149.3461585909779, -6.456094439521507}, {
      166.01282525764455`, -4.464320623073383}, {
      166.01282525764455`, -4.787702164283916}}], 
     PolygonBox[{{166.01282525764455`, -4.464320623073384}, {
      149.3461585909779, -6.456094439521508}, {
      149.3461585909779, -5.960788992377056}, {
      166.01282525764455`, -4.121822175579879}, {
      166.01282525764455`, -4.464320623073384}}], 
     PolygonBox[{{166.01282525764455`, -4.121822175579879}, {
      149.3461585909779, -5.960788992377056}, {
      149.3461585909779, -5.439958531650272}, {
      166.01282525764455`, -3.7616734527368902`}, {
      166.01282525764455`, -4.121822175579879}}], 
     PolygonBox[{{166.01282525764455`, -3.761673452736891}, {
      149.3461585909779, -5.439958531650273}, {
      149.3461585909779, -4.895833333333334}, {
      166.01282525764455`, -3.3854166666666674`}, {
      166.01282525764455`, -3.761673452736891}}], 
     PolygonBox[{{166.01282525764455`, -3.3854166666666674`}, {
      149.3461585909779, -4.895833333333334}, {
      149.3461585909779, -4.330743425061056}, {
      166.01282525764455`, -2.9946630066911553`}, {
      166.01282525764455`, -3.3854166666666674`}}], 
     PolygonBox[{{166.01282525764455`, -2.9946630066911553`}, {
      149.3461585909779, -4.330743425061056}, {
      149.3461585909779, -3.7471086085748393`}, {
      166.01282525764455`, -2.5910857399719633`}, {
      166.01282525764455`, -2.9946630066911553`}}], 
     PolygonBox[{{166.01282525764455`, -2.5910857399719625`}, {
      149.3461585909779, -3.747108608574838}, {
      149.3461585909779, -3.147428097760125}, {
      166.01282525764455`, -2.1764130463234905`}, {
      166.01282525764455`, -2.5910857399719625`}}], 
     PolygonBox[{{166.01282525764455`, -2.1764130463234905`}, {
      149.3461585909779, -3.147428097760125}, {
      149.3461585909779, -2.534269816628851}, {
      166.01282525764455`, -1.7524206178816524`}, {
      166.01282525764455`, -2.1764130463234905`}}], 
     PolygonBox[{{166.01282525764455`, -1.7524206178816524`}, {
      149.3461585909779, -2.534269816628851}, {
      149.3461585909779, -1.9102594030745919`}, {
      166.01282525764455`, -1.320924055317537}, {
      166.01282525764455`, -1.7524206178816524`}}], 
     PolygonBox[{{166.01282525764455`, -1.3209240553175357`}, {
      149.3461585909779, -1.9102594030745899`}, {
      149.3461585909779, -1.2780689654880062`}, {
      166.01282525764455`, -0.8837710931566001}, {
      166.01282525764455`, -1.3209240553175357`}}], 
     PolygonBox[{{166.01282525764455`, -0.8837710931566001}, {
      149.3461585909779, -1.2780689654880062`}, {
      149.3461585909779, -0.6404056403784861}, {
      166.01282525764455`, -0.4428336874957617}, {
      166.01282525764455`, -0.8837710931566001}}], 
     PolygonBox[{{166.01282525764455`, -0.4428336874957617}, {
      149.3461585909779, -0.6404056403784861}, {
      149.3461585909779, -2.7737534186401568`*^-15}, {
      166.01282525764455`, -1.9180209809745763`*^-15}, {
      166.01282525764455`, -0.4428336874957617}}], 
     PolygonBox[{{166.01282525764455`, -4.1459396846134354`*^-16}, {
      149.3461585909779, -5.995666620825583*^-16}, {149.3461585909779, 
      0.6404056403784828}, {166.01282525764455`, 0.44283368749575935`}, {
      166.01282525764455`, -4.1459396846134354`*^-16}}], 
     PolygonBox[{{166.01282525764455`, 0.44283368749575935`}, {
      149.3461585909779, 0.6404056403784828}, {149.3461585909779, 
      1.278068965488003}, {166.01282525764455`, 0.8837710931565979}, {
      166.01282525764455`, 0.44283368749575935`}}], 
     PolygonBox[{{166.01282525764455`, 0.8837710931565979}, {
      149.3461585909779, 1.278068965488003}, {149.3461585909779, 
      1.9102594030745863`}, {166.01282525764455`, 1.320924055317533}, {
      166.01282525764455`, 0.8837710931565979}}], 
     PolygonBox[{{166.01282525764455`, 1.320924055317533}, {149.3461585909779,
       1.9102594030745863`}, {149.3461585909779, 2.5342698166288455`}, {
      166.01282525764455`, 1.7524206178816484`}, {166.01282525764455`, 
      1.320924055317533}}], 
     PolygonBox[{{166.01282525764455`, 1.7524206178816502`}, {
      149.34615859097786`, 2.5342698166288478`}, {149.3461585909779, 
      3.1474280977601214`}, {166.01282525764455`, 2.1764130463234883`}, {
      166.01282525764455`, 1.7524206178816502`}}], 
     PolygonBox[{{166.01282525764455`, 2.1764130463234883`}, {
      149.3461585909779, 3.1474280977601214`}, {149.3461585909779, 
      3.7471086085748344`}, {166.01282525764455`, 2.59108573997196}, {
      166.01282525764455`, 2.1764130463234883`}}], 
     PolygonBox[{{166.01282525764455`, 2.59108573997196}, {149.3461585909779, 
      3.7471086085748344`}, {149.3461585909779, 4.330743425061052}, {
      166.01282525764455`, 2.9946630066911535`}, {166.01282525764455`, 
      2.59108573997196}}], 
     PolygonBox[{{166.01282525764455`, 2.9946630066911535`}, {
      149.3461585909779, 4.330743425061052}, {149.3461585909779, 
      4.895833333333331}, {166.01282525764455`, 3.385416666666665}, {
      166.01282525764455`, 2.9946630066911535`}}], 
     PolygonBox[{{166.01282525764455`, 3.385416666666665}, {149.3461585909779,
       4.895833333333331}, {149.34615859097786`, 5.439958531650269}, {
      166.01282525764455`, 3.761673452736888}, {166.01282525764455`, 
      3.385416666666665}}], 
     PolygonBox[{{166.01282525764455`, 3.761673452736888}, {
      149.34615859097786`, 5.439958531650269}, {149.3461585909779, 
      5.960788992377053}, {166.01282525764455`, 4.121822175579878}, {
      166.01282525764455`, 3.761673452736888}}], 
     PolygonBox[{{166.01282525764455`, 4.121822175579878}, {149.3461585909779,
       5.960788992377053}, {149.3461585909779, 6.456094439521504}, {
      166.01282525764455`, 4.46432062307338}, {166.01282525764455`, 
      4.121822175579878}}], 
     PolygonBox[{{166.01282525764455`, 4.46432062307338}, {149.3461585909779, 
      6.456094439521504}, {149.3461585909779, 6.923753899118274}, {
      166.01282525764455`, 4.787702164283912}, {166.01282525764455`, 
      4.46432062307338}}], 
     PolygonBox[{{166.01282525764455`, 4.787702164283915}, {149.3461585909779,
       6.923753899118276}, {149.3461585909779, 7.361764781564986}, {
      166.01282525764455`, 5.090582029805575}, {166.01282525764455`, 
      4.787702164283915}}], 
     PolygonBox[{{166.01282525764455`, 5.090582029805575}, {149.3461585909779,
       7.361764781564986}, {149.3461585909779, 7.7682514570183425`}, {
      166.01282525764455`, 5.371663241555237}, {166.01282525764455`, 
      5.090582029805575}}], 
     PolygonBox[{{166.01282525764455`, 5.371663241555237}, {149.3461585909779,
       7.7682514570183425`}, {149.3461585909779, 8.141473287129086}, {
      166.01282525764455`, 5.629742166631814}, {166.01282525764455`, 
      5.371663241555237}}], 
     PolygonBox[{{166.01282525764455`, 5.629742166631814}, {149.3461585909779,
       8.141473287129086}, {149.3461585909779, 8.479832078722627}, {
      166.01282525764455`, 5.863713671457135}, {166.01282525764455`, 
      5.629742166631814}}], 
     PolygonBox[{{166.01282525764455`, 5.863713671457135}, {149.3461585909779,
       8.479832078722627}, {149.34615859097786`, 8.781878927507572}, {
      166.01282525764455`, 6.072575854127576}, {166.01282525764455`, 
      5.863713671457135}}], 
     PolygonBox[{{166.01282525764455`, 6.072575854127576}, {
      149.34615859097786`, 8.781878927507572}, {149.3461585909779, 
      9.046320422506348}, {166.01282525764455`, 6.255434334711836}, {
      166.01282525764455`, 6.072575854127576}}], 
     PolygonBox[{{166.01282525764455`, 6.255434334711838}, {149.3461585909779,
       9.04632042250635}, {149.3461585909779, 9.272024184639575}, {
      166.01282525764455`, 6.41150608512311}, {166.01282525764455`, 
      6.255434334711838}}], 
     PolygonBox[{{166.01282525764455`, 6.41150608512311}, {149.3461585909779, 
      9.272024184639575}, {149.3461585909779, 9.458023715747126}, {
      166.01282525764455`, 6.540122782165566}, {166.01282525764455`, 
      6.41150608512311}}], 
     PolygonBox[{{166.01282525764455`, 6.540122782165566}, {149.3461585909779,
       9.458023715747126}, {149.3461585909779, 9.60352253728163}, {
      166.01282525764455`, 6.640733669396873}, {166.01282525764455`, 
      6.540122782165566}}], 
     PolygonBox[{{166.01282525764455`, 6.640733669396873}, {149.3461585909779,
       9.60352253728163}, {149.3461585909779, 9.707897600951894}, {
      166.01282525764455`, 6.712907915551841}, {166.01282525764455`, 
      6.640733669396873}}], 
     PolygonBox[{{166.01282525764455`, 6.712907915551841}, {149.3461585909779,
       9.707897600951894}, {149.3461585909779, 9.770701956711326}, {
      166.01282525764455`, 6.756336459428045}, {166.01282525764455`, 
      6.712907915551841}}], 
     PolygonBox[{{166.01282525764455`, 6.756336459428045}, {149.3461585909779,
       9.770701956711326}, {149.3461585909779, 9.791666666666666}, {
      166.01282525764455`, 6.770833333333333}, {166.01282525764455`, 
      6.756336459428045}}], 
     PolygonBox[{{166.01282525764455`, 6.770833333333333}, {149.3461585909779,
       9.791666666666666}, {149.3461585909779, 9.770701956711326}, {
      166.01282525764455`, 6.756336459428045}, {166.01282525764455`, 
      6.770833333333333}}], 
     PolygonBox[{{166.01282525764455`, 6.756336459428045}, {149.3461585909779,
       9.770701956711326}, {149.3461585909779, 9.707897600951894}, {
      166.01282525764455`, 6.712907915551842}, {166.01282525764455`, 
      6.756336459428045}}], 
     PolygonBox[{{166.01282525764455`, 6.712907915551842}, {149.3461585909779,
       9.707897600951894}, {149.34615859097786`, 9.60352253728163}, {
      166.01282525764455`, 6.640733669396873}, {166.01282525764455`, 
      6.712907915551842}}], 
     PolygonBox[{{166.01282525764455`, 6.640733669396873}, {
      149.34615859097786`, 9.60352253728163}, {149.3461585909779, 
      9.458023715747128}, {166.01282525764455`, 6.540122782165567}, {
      166.01282525764455`, 6.640733669396873}}], 
     PolygonBox[{{166.01282525764455`, 6.540122782165567}, {149.3461585909779,
       9.458023715747128}, {149.3461585909779, 9.272024184639577}, {
      166.01282525764455`, 6.411506085123111}, {166.01282525764455`, 
      6.540122782165567}}], 
     PolygonBox[{{166.01282525764455`, 6.411506085123111}, {149.3461585909779,
       9.272024184639577}, {149.3461585909779, 9.046320422506351}, {
      166.01282525764455`, 6.255434334711839}, {166.01282525764455`, 
      6.411506085123111}}], 
     PolygonBox[{{166.01282525764455`, 6.255434334711839}, {149.3461585909779,
       9.046320422506351}, {149.3461585909779, 8.781878927507575}, {
      166.01282525764455`, 6.072575854127579}, {166.01282525764455`, 
      6.255434334711839}}], 
     PolygonBox[{{166.01282525764455`, 6.072575854127578}, {149.3461585909779,
       8.781878927507574}, {149.3461585909779, 8.47983207872263}, {
      166.01282525764455`, 5.863713671457138}, {166.01282525764455`, 
      6.072575854127578}}], 
     PolygonBox[{{166.01282525764455`, 5.863713671457138}, {149.3461585909779,
       8.47983207872263}, {149.34615859097786`, 8.141473287129092}, {
      166.01282525764455`, 5.629742166631818}, {166.01282525764455`, 
      5.863713671457138}}], 
     PolygonBox[{{166.01282525764455`, 5.629742166631818}, {
      149.34615859097786`, 8.141473287129092}, {149.3461585909779, 
      7.768251457018346}, {166.01282525764455`, 5.37166324155524}, {
      166.01282525764455`, 5.629742166631818}}], 
     PolygonBox[{{166.01282525764455`, 5.37166324155524}, {149.3461585909779, 
      7.768251457018346}, {149.3461585909779, 7.36176478156499}, {
      166.01282525764455`, 5.090582029805578}, {166.01282525764455`, 
      5.37166324155524}}], 
     PolygonBox[{{166.01282525764455`, 5.090582029805578}, {149.3461585909779,
       7.36176478156499}, {149.3461585909779, 6.923753899118282}, {
      166.01282525764455`, 4.7877021642839175`}, {166.01282525764455`, 
      5.090582029805578}}], 
     PolygonBox[{{166.01282525764455`, 4.7877021642839175`}, {
      149.3461585909779, 6.923753899118282}, {149.3461585909779, 
      6.456094439521513}, {166.01282525764455`, 4.4643206230733865`}, {
      166.01282525764455`, 4.7877021642839175`}}], 
     PolygonBox[{{166.01282525764455`, 4.464320623073384}, {149.3461585909779,
       6.456094439521509}, {149.3461585909779, 5.960788992377058}, {
      166.01282525764455`, 4.121822175579881}, {166.01282525764455`, 
      4.464320623073384}}], 
     PolygonBox[{{166.01282525764455`, 4.121822175579881}, {149.3461585909779,
       5.960788992377058}, {149.3461585909779, 5.439958531650271}, {
      166.01282525764455`, 3.76167345273689}, {166.01282525764455`, 
      4.121822175579881}}], 
     PolygonBox[{{166.01282525764455`, 3.7616734527368947`}, {
      149.3461585909779, 5.439958531650278}, {149.3461585909779, 
      4.8958333333333375`}, {166.01282525764455`, 3.3854166666666696`}, {
      166.01282525764455`, 3.7616734527368947`}}], 
     PolygonBox[{{166.01282525764455`, 3.3854166666666696`}, {
      149.3461585909779, 4.8958333333333375`}, {149.3461585909779, 
      4.330743425061055}, {166.01282525764455`, 2.994663006691155}, {
      166.01282525764455`, 3.3854166666666696`}}], 
     PolygonBox[{{166.01282525764455`, 2.994663006691155}, {149.3461585909779,
       4.330743425061055}, {149.3461585909779, 3.7471086085748344`}, {
      166.01282525764455`, 2.59108573997196}, {166.01282525764455`, 
      2.994663006691155}}], 
     PolygonBox[{{166.01282525764455`, 2.5910857399719656`}, {
      149.34615859097786`, 3.7471086085748424`}, {149.3461585909779, 
      3.147428097760126}, {166.01282525764455`, 2.1764130463234914`}, {
      166.01282525764455`, 2.5910857399719656`}}], 
     PolygonBox[{{166.01282525764455`, 2.1764130463234914`}, {
      149.3461585909779, 3.147428097760126}, {149.34615859097786`, 
      2.5342698166288478`}, {166.01282525764455`, 1.7524206178816502`}, {
      166.01282525764455`, 2.1764130463234914`}}], 
     PolygonBox[{{166.01282525764455`, 1.752420617881656}, {149.3461585909779,
       2.534269816628856}, {149.3461585909779, 1.9102594030745932`}, {
      166.01282525764455`, 1.3209240553175379`}, {166.01282525764455`, 
      1.752420617881656}}], 
     PolygonBox[{{166.01282525764455`, 1.3209240553175379`}, {
      149.3461585909779, 1.9102594030745932`}, {149.3461585909779, 
      1.2780689654880055`}, {166.01282525764455`, 0.8837710931565996}, {
      166.01282525764455`, 1.3209240553175379`}}], 
     PolygonBox[{{166.01282525764455`, 0.8837710931566054}, {
      149.3461585909779, 1.278068965488014}, {149.3461585909779, 
      0.6404056403784896}, {166.01282525764455`, 0.4428336874957641}, {
      166.01282525764455`, 0.8837710931566054}}], 
     PolygonBox[{{166.01282525764455`, 0.4428336874957641}, {
      149.3461585909779, 0.6404056403784896}, {149.3461585909779, 
      1.798699986247675*^-15}, {166.01282525764455`, 
      1.2437819053840304`*^-15}, {166.01282525764455`, 0.4428336874957641}}], 
     PolygonBox[{{166.01282525764455`, 1.2437819053840304`*^-15}, {
      149.3461585909779, 1.798699986247675*^-15}, {
      149.3461585909779, -0.640405640378486}, {
      166.01282525764455`, -0.4428336874957616}, {166.01282525764455`, 
      1.2437819053840304`*^-15}}], 
     PolygonBox[{{166.01282525764455`, -0.4428336874957556}, {
      149.3461585909779, -0.6404056403784774}, {
      149.3461585909779, -1.278068965488002}, {
      166.01282525764455`, -0.8837710931565971}, {
      166.01282525764455`, -0.4428336874957556}}], 
     PolygonBox[{{166.01282525764455`, -0.8837710931565971}, {
      149.3461585909779, -1.278068965488002}, {
      149.3461585909779, -1.9102594030745896`}, {
      166.01282525764455`, -1.3209240553175352`}, {
      166.01282525764455`, -0.8837710931565971}}], 
     PolygonBox[{{166.01282525764452`, -1.3209240553175294`}, {
      149.34615859097786`, -1.9102594030745808`}, {
      149.3461585909779, -2.5342698166288447`}, {
      166.01282525764455`, -1.752420617881648}, {
      166.01282525764452`, -1.3209240553175294`}}], 
     PolygonBox[{{166.01282525764455`, -1.752420617881648}, {
      149.3461585909779, -2.5342698166288447`}, {
      149.3461585909779, -3.147428097760123}, {
      166.01282525764455`, -2.176413046323489}, {
      166.01282525764455`, -1.752420617881648}}], 
     PolygonBox[{{166.01282525764455`, -2.176413046323489}, {
      149.3461585909779, -3.147428097760123}, {
      149.3461585909779, -3.7471086085748393`}, {
      166.01282525764455`, -2.5910857399719633`}, {
      166.01282525764455`, -2.176413046323489}}], 
     PolygonBox[{{166.01282525764455`, -2.591085739971958}, {
      149.3461585909779, -3.7471086085748313`}, {
      149.3461585909779, -4.330743425061051}, {
      166.01282525764455`, -2.9946630066911526`}, {
      166.01282525764455`, -2.591085739971958}}], 
     PolygonBox[{{166.01282525764455`, -2.9946630066911526`}, {
      149.3461585909779, -4.330743425061051}, {
      149.3461585909779, -4.895833333333334}, {
      166.01282525764455`, -3.3854166666666674`}, {
      166.01282525764455`, -2.9946630066911526`}}], 
     PolygonBox[{{166.01282525764455`, -3.385416666666662}, {
      149.3461585909779, -4.895833333333327}, {
      149.3461585909779, -5.439958531650268}, {
      166.01282525764455`, -3.7616734527368876`}, {
      166.01282525764455`, -3.385416666666662}}], 
     PolygonBox[{{166.01282525764455`, -3.7616734527368876`}, {
      149.3461585909779, -5.439958531650268}, {
      149.3461585909779, -5.960788992377055}, {
      166.01282525764455`, -4.1218221755798785`}, {
      166.01282525764455`, -3.7616734527368876`}}], 
     PolygonBox[{{166.01282525764455`, -4.121822175579874}, {
      149.3461585909779, -5.960788992377049}, {
      149.3461585909779, -6.456094439521503}, {
      166.01282525764455`, -4.46432062307338}, {
      166.01282525764455`, -4.121822175579874}}], 
     PolygonBox[{{166.01282525764455`, -4.46432062307338}, {
      149.3461585909779, -6.456094439521503}, {
      149.3461585909779, -6.923753899118275}, {
      166.01282525764455`, -4.787702164283914}, {
      166.01282525764455`, -4.46432062307338}}], 
     PolygonBox[{{166.01282525764455`, -4.787702164283914}, {
      149.3461585909779, -6.923753899118275}, {
      149.3461585909779, -7.361764781564987}, {
      166.01282525764455`, -5.090582029805576}, {
      166.01282525764455`, -4.787702164283914}}], 
     PolygonBox[{{166.01282525764455`, -5.090582029805573}, {
      149.3461585909779, -7.3617647815649825`}, {
      149.3461585909779, -7.7682514570183425`}, {
      166.01282525764455`, -5.371663241555236}, {
      166.01282525764455`, -5.090582029805573}}], 
     PolygonBox[{{166.01282525764455`, -5.371663241555236}, {
      149.3461585909779, -7.7682514570183425`}, {
      149.3461585909779, -8.141473287129088}, {
      166.01282525764455`, -5.629742166631816}, {
      166.01282525764455`, -5.371663241555236}}], 
     PolygonBox[{{166.01282525764455`, -5.6297421666318135`}, {
      149.3461585909779, -8.141473287129084}, {
      149.3461585909779, -8.479832078722627}, {
      166.01282525764455`, -5.863713671457135}, {
      166.01282525764455`, -5.6297421666318135`}}], 
     PolygonBox[{{166.01282525764455`, -5.863713671457135}, {
      149.3461585909779, -8.479832078722627}, {
      149.3461585909779, -8.781878927507572}, {
      166.01282525764455`, -6.072575854127576}, {
      166.01282525764455`, -5.863713671457135}}], 
     PolygonBox[{{166.01282525764455`, -6.072575854127574}, {
      149.3461585909779, -8.781878927507568}, {
      149.34615859097786`, -9.046320422506348}, {
      166.01282525764455`, -6.255434334711836}, {
      166.01282525764455`, -6.072575854127574}}], 
     PolygonBox[{{166.01282525764455`, -6.255434334711836}, {
      149.34615859097786`, -9.046320422506348}, {
      149.3461585909779, -9.272024184639575}, {
      166.01282525764455`, -6.41150608512311}, {
      166.01282525764455`, -6.255434334711836}}], 
     PolygonBox[{{166.01282525764455`, -6.41150608512311}, {
      149.3461585909779, -9.272024184639575}, {
      149.34615859097786`, -9.458023715747128}, {
      166.01282525764455`, -6.540122782165566}, {
      166.01282525764455`, -6.41150608512311}}], 
     PolygonBox[{{166.01282525764455`, -6.540122782165565}, {
      149.3461585909779, -9.458023715747125}, {
      149.3461585909779, -9.60352253728163}, {
      166.01282525764455`, -6.640733669396871}, {
      166.01282525764455`, -6.540122782165565}}], 
     PolygonBox[{{166.01282525764455`, -6.640733669396871}, {
      149.3461585909779, -9.60352253728163}, {
      149.3461585909779, -9.707897600951894}, {
      166.01282525764455`, -6.712907915551841}, {
      166.01282525764455`, -6.640733669396871}}], 
     PolygonBox[{{166.01282525764455`, -6.71290791555184}, {
      149.3461585909779, -9.707897600951892}, {
      149.3461585909779, -9.770701956711326}, {
      166.01282525764455`, -6.756336459428045}, {
      166.01282525764455`, -6.71290791555184}}], 
     PolygonBox[{{166.01282525764455`, -6.756336459428045}, {
      149.3461585909779, -9.770701956711326}, {
      149.3461585909779, -9.791666666666666}, {
      166.01282525764455`, -6.770833333333333}, {
      166.01282525764455`, -6.756336459428045}}], 
     PolygonBox[{{149.3461585909779, -9.791666666666666}, {150., -12.8125}, {
      150., -12.785067453994607`}, {149.3461585909779, -9.770701956711326}, {
      149.3461585909779, -9.791666666666666}}], 
     PolygonBox[{{149.3461585909779, -9.770701956711326}, {
      150., -12.785067453994607`}, {
      149.99999999999997`, -12.702887286351945`}, {
      149.3461585909779, -9.707897600951894}, {
      149.3461585909779, -9.770701956711326}}], 
     PolygonBox[{{149.3461585909779, -9.707897600951894}, {
      149.99999999999997`, -12.702887286351945`}, {
      150., -12.56631140516639}, {149.3461585909779, -9.60352253728163}, {
      149.3461585909779, -9.707897600951894}}], 
     PolygonBox[{{149.3461585909779, -9.60352253728163}, {
      150., -12.56631140516639}, {150., -12.375924649328688`}, {
      149.34615859097786`, -9.458023715747128}, {
      149.3461585909779, -9.60352253728163}}], 
     PolygonBox[{{149.34615859097786`, -9.458023715747128}, {
      150., -12.375924649328688`}, {
      149.99999999999997`, -12.132542284156042`}, {
      149.3461585909779, -9.272024184639577}, {
      149.34615859097786`, -9.458023715747128}}], 
     PolygonBox[{{149.3461585909779, -9.272024184639577}, {
      149.99999999999997`, -12.132542284156042`}, {
      149.99999999999997`, -11.837206510300863`}, {
      149.3461585909779, -9.04632042250635}, {
      149.3461585909779, -9.272024184639577}}], 
     PolygonBox[{{149.3461585909779, -9.04632042250635}, {
      149.99999999999997`, -11.837206510300863`}, {
      150., -11.49118200088757}, {149.3461585909779, -8.781878927507574}, {
      149.3461585909779, -9.04632042250635}}], 
     PolygonBox[{{149.3461585909779, -8.781878927507574}, {
      150., -11.49118200088757}, {150., -11.095950485988121`}, {
      149.3461585909779, -8.479832078722628}, {
      149.3461585909779, -8.781878927507574}}], 
     PolygonBox[{{149.3461585909779, -8.479832078722628}, {
      150., -11.095950485988121`}, {150., -10.653204407626362`}, {
      149.3461585909779, -8.141473287129088}, {
      149.3461585909779, -8.479832078722628}}], 
     PolygonBox[{{149.3461585909779, -8.141473287129088}, {
      150., -10.653204407626362`}, {150., -10.16483967248145}, {
      149.3461585909779, -7.768251457018344}, {
      149.3461585909779, -8.141473287129088}}], 
     PolygonBox[{{149.3461585909779, -7.768251457018345}, {
      150., -10.164839672481452`}, {150., -9.632947533324398}, {
      149.3461585909779, -7.361764781564987}, {
      149.3461585909779, -7.768251457018345}}], 
     PolygonBox[{{149.3461585909779, -7.361764781564987}, {
      150., -9.632947533324398}, {149.99999999999997`, -9.05980563395264}, {
      149.3461585909779, -6.923753899118278}, {
      149.3461585909779, -7.361764781564987}}], 
     PolygonBox[{{149.3461585909779, -6.923753899118278}, {
      149.99999999999997`, -9.05980563395264}, {150., -8.447868255969633}, {
      149.3461585909779, -6.456094439521507}, {
      149.3461585909779, -6.923753899118278}}], 
     PolygonBox[{{149.3461585909779, -6.456094439521508}, {
      150., -8.447868255969635}, {150., -7.799755809174233}, {
      149.3461585909779, -5.960788992377056}, {
      149.3461585909779, -6.456094439521508}}], 
     PolygonBox[{{149.3461585909779, -5.960788992377056}, {
      150., -7.799755809174233}, {149.99999999999997`, -7.118243610563654}, {
      149.3461585909779, -5.439958531650272}, {
      149.3461585909779, -5.960788992377056}}], 
     PolygonBox[{{149.3461585909779, -5.439958531650273}, {
      149.99999999999997`, -7.118243610563656}, {150., -6.406250000000002}, {
      149.3461585909779, -4.895833333333334}, {
      149.3461585909779, -5.439958531650273}}], 
     PolygonBox[{{149.3461585909779, -4.895833333333334}, {
      150., -6.406250000000002}, {150., -5.666823843430956}, {
      149.3461585909779, -4.330743425061056}, {
      149.3461585909779, -4.895833333333334}}], 
     PolygonBox[{{149.3461585909779, -4.330743425061056}, {
      150., -5.666823843430956}, {149.99999999999997`, -4.903131477177716}, {
      149.3461585909779, -3.7471086085748393`}, {
      149.3461585909779, -4.330743425061056}}], 
     PolygonBox[{{149.3461585909779, -3.747108608574838}, {
      149.99999999999997`, -4.9031314771777135`}, {
      149.99999999999997`, -4.118443149196759}, {
      149.3461585909779, -3.147428097760125}, {
      149.3461585909779, -3.747108608574838}}], 
     PolygonBox[{{149.3461585909779, -3.147428097760125}, {
      149.99999999999997`, -4.118443149196759}, {150., -3.3161190153760502`},
       {149.3461585909779, -2.534269816628851}, {
      149.3461585909779, -3.147428097760125}}], 
     PolygonBox[{{149.3461585909779, -2.534269816628851}, {
      150., -3.3161190153760502`}, {
      149.99999999999997`, -2.4995947508316467`}, {
      149.3461585909779, -1.9102594030745919`}, {
      149.3461585909779, -2.534269816628851}}], 
     PolygonBox[{{149.3461585909779, -1.9102594030745899`}, {
      150., -2.499594750831644}, {
      149.99999999999997`, -1.6723668378194125`}, {
      149.3461585909779, -1.2780689654880062`}, {
      149.3461585909779, -1.9102594030745899`}}], 
     PolygonBox[{{149.3461585909779, -1.2780689654880062`}, {
      149.99999999999997`, -1.6723668378194125`}, {
      150., -0.8379775932612106}, {149.3461585909779, -0.6404056403784861}, {
      149.3461585909779, -1.2780689654880062`}}], 
     PolygonBox[{{149.3461585909779, -0.6404056403784861}, {
      150., -0.8379775932612106}, {150., -3.6294858563057365`*^-15}, {
      149.3461585909779, -2.7737534186401568`*^-15}, {
      149.3461585909779, -0.6404056403784861}}], 
     PolygonBox[{{149.3461585909779, -5.995666620825583*^-16}, {
      150., -7.845393557037732*^-16}, {150., 0.8379775932612061}, {
      149.3461585909779, 0.6404056403784828}, {
      149.3461585909779, -5.995666620825583*^-16}}], 
     PolygonBox[{{149.3461585909779, 0.6404056403784828}, {150., 
      0.8379775932612061}, {149.99999999999997`, 1.6723668378194083`}, {
      149.3461585909779, 1.278068965488003}, {149.3461585909779, 
      0.6404056403784828}}], 
     PolygonBox[{{149.3461585909779, 1.278068965488003}, {149.99999999999997`,
       1.6723668378194083`}, {149.99999999999997`, 2.4995947508316396`}, {
      149.3461585909779, 1.9102594030745863`}, {149.3461585909779, 
      1.278068965488003}}], 
     PolygonBox[{{149.3461585909779, 1.9102594030745863`}, {
      149.99999999999997`, 2.4995947508316396`}, {149.99999999999997`, 
      3.3161190153760427`}, {149.3461585909779, 2.5342698166288455`}, {
      149.3461585909779, 1.9102594030745863`}}], 
     PolygonBox[{{149.34615859097786`, 2.5342698166288478`}, {150., 
      3.316119015376046}, {150., 4.1184431491967555`}, {149.3461585909779, 
      3.1474280977601214`}, {149.34615859097786`, 2.5342698166288478`}}], 
     PolygonBox[{{149.3461585909779, 3.1474280977601214`}, {150., 
      4.1184431491967555`}, {150., 4.903131477177709}, {149.3461585909779, 
      3.7471086085748344`}, {149.3461585909779, 3.1474280977601214`}}], 
     PolygonBox[{{149.3461585909779, 3.7471086085748344`}, {150., 
      4.903131477177709}, {149.99999999999997`, 5.666823843430952}, {
      149.3461585909779, 4.330743425061052}, {149.3461585909779, 
      3.7471086085748344`}}], 
     PolygonBox[{{149.3461585909779, 4.330743425061052}, {149.99999999999997`,
       5.666823843430952}, {149.99999999999997`, 6.406249999999997}, {
      149.3461585909779, 4.895833333333331}, {149.3461585909779, 
      4.330743425061052}}], 
     PolygonBox[{{149.3461585909779, 4.895833333333331}, {149.99999999999997`,
       6.406249999999997}, {150., 7.11824361056365}, {149.34615859097786`, 
      5.439958531650269}, {149.3461585909779, 4.895833333333331}}], 
     PolygonBox[{{149.34615859097786`, 5.439958531650269}, {150., 
      7.11824361056365}, {149.99999999999997`, 7.799755809174229}, {
      149.3461585909779, 5.960788992377053}, {149.34615859097786`, 
      5.439958531650269}}], 
     PolygonBox[{{149.3461585909779, 5.960788992377053}, {149.99999999999997`,
       7.799755809174229}, {150., 8.447868255969627}, {149.3461585909779, 
      6.456094439521504}, {149.3461585909779, 5.960788992377053}}], 
     PolygonBox[{{149.3461585909779, 6.456094439521504}, {150., 
      8.447868255969627}, {150., 9.059805633952635}, {149.3461585909779, 
      6.923753899118274}, {149.3461585909779, 6.456094439521504}}], 
     PolygonBox[{{149.3461585909779, 6.923753899118276}, {149.99999999999997`,
       9.059805633952639}, {150., 9.632947533324396}, {149.3461585909779, 
      7.361764781564986}, {149.3461585909779, 6.923753899118276}}], 
     PolygonBox[{{149.3461585909779, 7.361764781564986}, {150., 
      9.632947533324396}, {150., 10.164839672481449`}, {149.3461585909779, 
      7.7682514570183425`}, {149.3461585909779, 7.361764781564986}}], 
     PolygonBox[{{149.3461585909779, 7.7682514570183425`}, {150., 
      10.164839672481449`}, {150., 10.653204407626358`}, {149.3461585909779, 
      8.141473287129086}, {149.3461585909779, 7.7682514570183425`}}], 
     PolygonBox[{{149.3461585909779, 8.141473287129086}, {150., 
      10.653204407626358`}, {150., 11.095950485988118`}, {149.3461585909779, 
      8.479832078722627}, {149.3461585909779, 8.141473287129086}}], 
     PolygonBox[{{149.3461585909779, 8.479832078722627}, {150., 
      11.095950485988118`}, {149.99999999999997`, 11.491182000887568`}, {
      149.34615859097786`, 8.781878927507572}, {149.3461585909779, 
      8.479832078722627}}], 
     PolygonBox[{{149.34615859097786`, 8.781878927507572}, {
      149.99999999999997`, 11.491182000887568`}, {150., 11.83720651030086}, {
      149.3461585909779, 9.046320422506348}, {149.34615859097786`, 
      8.781878927507572}}], 
     PolygonBox[{{149.3461585909779, 9.04632042250635}, {149.99999999999997`, 
      11.837206510300863`}, {149.99999999999997`, 12.13254228415604}, {
      149.3461585909779, 9.272024184639575}, {149.3461585909779, 
      9.04632042250635}}], 
     PolygonBox[{{149.3461585909779, 9.272024184639575}, {149.99999999999997`,
       12.13254228415604}, {150., 12.375924649328686`}, {149.3461585909779, 
      9.458023715747126}, {149.3461585909779, 9.272024184639575}}], 
     PolygonBox[{{149.3461585909779, 9.458023715747126}, {150., 
      12.375924649328686`}, {149.99999999999997`, 12.56631140516639}, {
      149.3461585909779, 9.60352253728163}, {149.3461585909779, 
      9.458023715747126}}], 
     PolygonBox[{{149.3461585909779, 9.60352253728163}, {149.99999999999997`, 
      12.56631140516639}, {150., 12.702887286351945`}, {149.3461585909779, 
      9.707897600951894}, {149.3461585909779, 9.60352253728163}}], 
     PolygonBox[{{149.3461585909779, 9.707897600951894}, {150., 
      12.702887286351945`}, {150., 12.785067453994607`}, {149.3461585909779, 
      9.770701956711326}, {149.3461585909779, 9.707897600951894}}], 
     PolygonBox[{{149.3461585909779, 9.770701956711326}, {150., 
      12.785067453994607`}, {150., 12.8125}, {149.3461585909779, 
      9.791666666666666}, {149.3461585909779, 9.770701956711326}}], 
     PolygonBox[{{149.3461585909779, 9.791666666666666}, {150., 12.8125}, {
      150., 12.785067453994607`}, {149.3461585909779, 9.770701956711326}, {
      149.3461585909779, 9.791666666666666}}], 
     PolygonBox[{{149.3461585909779, 9.770701956711326}, {150., 
      12.785067453994607`}, {149.99999999999997`, 12.702887286351945`}, {
      149.3461585909779, 9.707897600951894}, {149.3461585909779, 
      9.770701956711326}}], 
     PolygonBox[{{149.3461585909779, 9.707897600951894}, {149.99999999999997`,
       12.702887286351945`}, {150., 12.566311405166392`}, {
      149.34615859097786`, 9.60352253728163}, {149.3461585909779, 
      9.707897600951894}}], 
     PolygonBox[{{149.34615859097786`, 9.60352253728163}, {150., 
      12.566311405166392`}, {149.99999999999997`, 12.375924649328688`}, {
      149.3461585909779, 9.458023715747128}, {149.34615859097786`, 
      9.60352253728163}}], 
     PolygonBox[{{149.3461585909779, 9.458023715747128}, {149.99999999999997`,
       12.375924649328688`}, {149.99999999999997`, 12.132542284156042`}, {
      149.3461585909779, 9.272024184639577}, {149.3461585909779, 
      9.458023715747128}}], 
     PolygonBox[{{149.3461585909779, 9.272024184639577}, {149.99999999999997`,
       12.132542284156042`}, {149.99999999999997`, 11.837206510300865`}, {
      149.3461585909779, 9.046320422506351}, {149.3461585909779, 
      9.272024184639577}}], 
     PolygonBox[{{149.3461585909779, 9.046320422506351}, {149.99999999999997`,
       11.837206510300865`}, {150., 11.491182000887573`}, {149.3461585909779, 
      8.781878927507575}, {149.3461585909779, 9.046320422506351}}], 
     PolygonBox[{{149.3461585909779, 8.781878927507574}, {149.99999999999997`,
       11.49118200088757}, {150., 11.095950485988123`}, {149.3461585909779, 
      8.47983207872263}, {149.3461585909779, 8.781878927507574}}], 
     PolygonBox[{{149.3461585909779, 8.47983207872263}, {150., 
      11.095950485988123`}, {150., 10.653204407626363`}, {149.34615859097786`,
       8.141473287129092}, {149.3461585909779, 8.47983207872263}}], 
     PolygonBox[{{149.34615859097786`, 8.141473287129092}, {150., 
      10.653204407626363`}, {149.99999999999997`, 10.164839672481454`}, {
      149.3461585909779, 7.768251457018346}, {149.34615859097786`, 
      8.141473287129092}}], 
     PolygonBox[{{149.3461585909779, 7.768251457018346}, {149.99999999999997`,
       10.164839672481454`}, {150., 9.632947533324401}, {149.3461585909779, 
      7.36176478156499}, {149.3461585909779, 7.768251457018346}}], 
     PolygonBox[{{149.3461585909779, 7.36176478156499}, {150., 
      9.632947533324401}, {150., 9.059805633952646}, {149.3461585909779, 
      6.923753899118282}, {149.3461585909779, 7.36176478156499}}], 
     PolygonBox[{{149.3461585909779, 6.923753899118282}, {150., 
      9.059805633952646}, {150., 8.447868255969638}, {149.3461585909779, 
      6.456094439521513}, {149.3461585909779, 6.923753899118282}}], 
     PolygonBox[{{149.3461585909779, 6.456094439521509}, {150., 
      8.447868255969635}, {149.99999999999997`, 7.799755809174236}, {
      149.3461585909779, 5.960788992377058}, {149.3461585909779, 
      6.456094439521509}}], 
     PolygonBox[{{149.3461585909779, 5.960788992377058}, {149.99999999999997`,
       7.799755809174236}, {150., 7.1182436105636535`}, {149.3461585909779, 
      5.439958531650271}, {149.3461585909779, 5.960788992377058}}], 
     PolygonBox[{{149.3461585909779, 5.439958531650278}, {150., 
      7.118243610563662}, {149.99999999999997`, 6.406250000000006}, {
      149.3461585909779, 4.8958333333333375`}, {149.3461585909779, 
      5.439958531650278}}], 
     PolygonBox[{{149.3461585909779, 4.8958333333333375`}, {
      149.99999999999997`, 6.406250000000006}, {149.99999999999997`, 
      5.666823843430954}, {149.3461585909779, 4.330743425061055}, {
      149.3461585909779, 4.8958333333333375`}}], 
     PolygonBox[{{149.3461585909779, 4.330743425061055}, {149.99999999999997`,
       5.666823843430954}, {150., 4.903131477177709}, {149.3461585909779, 
      3.7471086085748344`}, {149.3461585909779, 4.330743425061055}}], 
     PolygonBox[{{149.34615859097786`, 3.7471086085748424`}, {
      149.99999999999997`, 4.90313147717772}, {150., 4.118443149196761}, {
      149.3461585909779, 3.147428097760126}, {149.34615859097786`, 
      3.7471086085748424`}}], 
     PolygonBox[{{149.3461585909779, 3.147428097760126}, {150., 
      4.118443149196761}, {150., 3.316119015376046}, {149.34615859097786`, 
      2.5342698166288478`}, {149.3461585909779, 3.147428097760126}}], 
     PolygonBox[{{149.3461585909779, 2.534269816628856}, {150., 
      3.316119015376057}, {149.99999999999997`, 2.4995947508316485`}, {
      149.3461585909779, 1.9102594030745932`}, {149.3461585909779, 
      2.534269816628856}}], 
     PolygonBox[{{149.3461585909779, 1.9102594030745932`}, {
      149.99999999999997`, 2.4995947508316485`}, {149.99999999999997`, 
      1.6723668378194114`}, {149.3461585909779, 1.2780689654880055`}, {
      149.3461585909779, 1.9102594030745932`}}], 
     PolygonBox[{{149.3461585909779, 1.278068965488014}, {149.99999999999997`,
       1.6723668378194225`}, {150., 0.8379775932612151}, {149.3461585909779, 
      0.6404056403784896}, {149.3461585909779, 1.278068965488014}}], 
     PolygonBox[{{149.3461585909779, 0.6404056403784896}, {150., 
      0.8379775932612151}, {150., 2.3536180671113193`*^-15}, {
      149.3461585909779, 1.798699986247675*^-15}, {149.3461585909779, 
      0.6404056403784896}}], 
     PolygonBox[{{149.3461585909779, 1.798699986247675*^-15}, {150., 
      2.3536180671113193`*^-15}, {150., -0.8379775932612105}, {
      149.3461585909779, -0.640405640378486}, {149.3461585909779, 
      1.798699986247675*^-15}}], 
     PolygonBox[{{149.3461585909779, -0.6404056403784774}, {
      150., -0.8379775932611991}, {
      149.99999999999997`, -1.6723668378194068`}, {
      149.3461585909779, -1.278068965488002}, {
      149.3461585909779, -0.6404056403784774}}], 
     PolygonBox[{{149.3461585909779, -1.278068965488002}, {
      149.99999999999997`, -1.6723668378194068`}, {
      150., -2.499594750831644}, {149.3461585909779, -1.9102594030745896`}, {
      149.3461585909779, -1.278068965488002}}], 
     PolygonBox[{{149.34615859097786`, -1.9102594030745808`}, {
      149.99999999999997`, -2.4995947508316325`}, {
      149.99999999999997`, -3.3161190153760414`}, {
      149.3461585909779, -2.5342698166288447`}, {
      149.34615859097786`, -1.9102594030745808`}}], 
     PolygonBox[{{149.3461585909779, -2.5342698166288447`}, {
      149.99999999999997`, -3.3161190153760414`}, {
      150., -4.118443149196756}, {149.3461585909779, -3.147428097760123}, {
      149.3461585909779, -2.5342698166288447`}}], 
     PolygonBox[{{149.3461585909779, -3.147428097760123}, {
      150., -4.118443149196756}, {149.99999999999997`, -4.903131477177716}, {
      149.3461585909779, -3.7471086085748393`}, {
      149.3461585909779, -3.147428097760123}}], 
     PolygonBox[{{149.3461585909779, -3.7471086085748313`}, {
      149.99999999999997`, -4.9031314771777055`}, {
      149.99999999999997`, -5.666823843430951}, {
      149.3461585909779, -4.330743425061051}, {
      149.3461585909779, -3.7471086085748313`}}], 
     PolygonBox[{{149.3461585909779, -4.330743425061051}, {
      149.99999999999997`, -5.666823843430951}, {150., -6.406250000000002}, {
      149.3461585909779, -4.895833333333334}, {
      149.3461585909779, -4.330743425061051}}], 
     PolygonBox[{{149.3461585909779, -4.895833333333327}, {
      150., -6.406249999999991}, {150., -7.118243610563649}, {
      149.3461585909779, -5.439958531650268}, {
      149.3461585909779, -4.895833333333327}}], 
     PolygonBox[{{149.3461585909779, -5.439958531650268}, {
      150., -7.118243610563649}, {150., -7.799755809174232}, {
      149.3461585909779, -5.960788992377055}, {
      149.3461585909779, -5.439958531650268}}], 
     PolygonBox[{{149.3461585909779, -5.960788992377049}, {
      150., -7.799755809174224}, {150., -8.447868255969627}, {
      149.3461585909779, -6.456094439521503}, {
      149.3461585909779, -5.960788992377049}}], 
     PolygonBox[{{149.3461585909779, -6.456094439521503}, {
      150., -8.447868255969627}, {150., -9.059805633952639}, {
      149.3461585909779, -6.923753899118275}, {
      149.3461585909779, -6.456094439521503}}], 
     PolygonBox[{{149.3461585909779, -6.923753899118275}, {
      150., -9.059805633952639}, {149.99999999999997`, -9.632947533324398}, {
      149.3461585909779, -7.361764781564987}, {
      149.3461585909779, -6.923753899118275}}], 
     PolygonBox[{{149.3461585909779, -7.3617647815649825`}, {
      150., -9.632947533324392}, {
      149.99999999999997`, -10.164839672481447`}, {
      149.3461585909779, -7.7682514570183425`}, {
      149.3461585909779, -7.3617647815649825`}}], 
     PolygonBox[{{149.3461585909779, -7.7682514570183425`}, {
      149.99999999999997`, -10.164839672481447`}, {
      150., -10.653204407626362`}, {149.3461585909779, -8.141473287129088}, {
      149.3461585909779, -7.7682514570183425`}}], 
     PolygonBox[{{149.3461585909779, -8.141473287129084}, {
      150., -10.653204407626355`}, {
      149.99999999999997`, -11.095950485988116`}, {
      149.3461585909779, -8.479832078722627}, {
      149.3461585909779, -8.141473287129084}}], 
     PolygonBox[{{149.3461585909779, -8.479832078722627}, {
      149.99999999999997`, -11.095950485988116`}, {
      150., -11.491182000887568`}, {149.3461585909779, -8.781878927507572}, {
      149.3461585909779, -8.479832078722627}}], 
     PolygonBox[{{149.3461585909779, -8.781878927507568}, {
      150., -11.491182000887562`}, {
      149.99999999999997`, -11.83720651030086}, {
      149.34615859097786`, -9.046320422506348}, {
      149.3461585909779, -8.781878927507568}}], 
     PolygonBox[{{149.34615859097786`, -9.046320422506348}, {
      149.99999999999997`, -11.83720651030086}, {150., -12.13254228415604}, {
      149.3461585909779, -9.272024184639575}, {
      149.34615859097786`, -9.046320422506348}}], 
     PolygonBox[{{149.3461585909779, -9.272024184639575}, {
      150., -12.13254228415604}, {150., -12.375924649328688`}, {
      149.34615859097786`, -9.458023715747128}, {
      149.3461585909779, -9.272024184639575}}], 
     PolygonBox[{{149.3461585909779, -9.458023715747125}, {
      150., -12.375924649328685`}, {
      149.99999999999997`, -12.566311405166388`}, {
      149.3461585909779, -9.60352253728163}, {
      149.3461585909779, -9.458023715747125}}], 
     PolygonBox[{{149.3461585909779, -9.60352253728163}, {
      149.99999999999997`, -12.566311405166388`}, {
      149.99999999999997`, -12.702887286351945`}, {
      149.3461585909779, -9.707897600951894}, {
      149.3461585909779, -9.60352253728163}}], 
     PolygonBox[{{149.3461585909779, -9.707897600951892}, {
      150., -12.702887286351944`}, {150., -12.785067453994607`}, {
      149.3461585909779, -9.770701956711326}, {
      149.3461585909779, -9.707897600951892}}], 
     PolygonBox[{{149.3461585909779, -9.770701956711326}, {
      150., -12.785067453994607`}, {150., -12.8125}, {
      149.3461585909779, -9.791666666666666}, {
      149.3461585909779, -9.770701956711326}}], 
     PolygonBox[{{150., -12.8125}, {
      150.65384140902208`, -15.833333333333332`}, {
      150.65384140902208`, -15.79943295127789}, {
      150., -12.785067453994607`}, {150., -12.8125}}], 
     PolygonBox[{{150., -12.785067453994607`}, {
      150.65384140902208`, -15.79943295127789}, {
      150.65384140902208`, -15.697876971751997`}, {
      149.99999999999997`, -12.702887286351945`}, {
      150., -12.785067453994607`}}], 
     PolygonBox[{{149.99999999999997`, -12.702887286351945`}, {
      150.65384140902208`, -15.697876971751997`}, {
      150.65384140902208`, -15.529100273051148`}, {
      150., -12.56631140516639}, {
      149.99999999999997`, -12.702887286351945`}}], 
     PolygonBox[{{150., -12.56631140516639}, {
      150.65384140902208`, -15.529100273051148`}, {
      150.65384140902208`, -15.293825582910248`}, {
      150., -12.375924649328688`}, {150., -12.56631140516639}}], 
     PolygonBox[{{150., -12.375924649328688`}, {
      150.65384140902208`, -15.293825582910248`}, {
      150.65384140902208`, -14.993060383672507`}, {
      149.99999999999997`, -12.132542284156042`}, {
      150., -12.375924649328688`}}], 
     PolygonBox[{{149.99999999999997`, -12.132542284156042`}, {
      150.65384140902208`, -14.993060383672507`}, {
      150.65384140902208`, -14.628092598095375`}, {
      149.99999999999997`, -11.837206510300863`}, {
      149.99999999999997`, -12.132542284156042`}}], 
     PolygonBox[{{149.99999999999997`, -11.837206510300863`}, {
      150.65384140902208`, -14.628092598095375`}, {
      150.65384140902208`, -14.200485074267565`}, {
      150., -11.49118200088757}, {
      149.99999999999997`, -11.837206510300863`}}], 
     PolygonBox[{{150., -11.49118200088757}, {
      150.65384140902208`, -14.200485074267565`}, {
      150.65384140902208`, -13.712068893253612`}, {
      150., -11.095950485988121`}, {150., -11.49118200088757}}], 
     PolygonBox[{{150., -11.095950485988121`}, {
      150.65384140902208`, -13.712068893253612`}, {
      150.65384140902208`, -13.164935528123632`}, {
      150., -10.653204407626362`}, {150., -11.095950485988121`}}], 
     PolygonBox[{{150., -10.653204407626362`}, {
      150.65384140902208`, -13.164935528123632`}, {
      150.65384140902208`, -12.561427887944555`}, {
      150., -10.16483967248145}, {150., -10.653204407626362`}}], 
     PolygonBox[{{150., -10.164839672481452`}, {
      150.65384140902208`, -12.561427887944557`}, {
      150.65384140902208`, -11.90413028508381}, {150., -9.632947533324398}, {
      150., -10.164839672481452`}}], 
     PolygonBox[{{150., -9.632947533324398}, {
      150.65384140902208`, -11.90413028508381}, {
      150.65384140902208`, -11.195857368787003`}, {
      149.99999999999997`, -9.05980563395264}, {150., -9.632947533324398}}], 
     PolygonBox[{{149.99999999999997`, -9.05980563395264}, {
      150.65384140902208`, -11.195857368787003`}, {
      150.65384140902208`, -10.439642072417756`}, {
      150., -8.447868255969633}, {149.99999999999997`, -9.05980563395264}}], 
     PolygonBox[{{150., -8.447868255969635}, {
      150.65384140902208`, -10.439642072417758`}, {
      150.65384140902208`, -9.63872262597141}, {150., -7.799755809174233}, {
      150., -8.447868255969635}}], 
     PolygonBox[{{150., -7.799755809174233}, {
      150.65384140902208`, -9.63872262597141}, {
      150.65384140902208`, -8.796528689477036}, {
      149.99999999999997`, -7.118243610563654}, {150., -7.799755809174233}}], 
     PolygonBox[{{149.99999999999997`, -7.118243610563656}, {
      150.65384140902208`, -8.796528689477038}, {
      150.65384140902208`, -7.916666666666668}, {150., -6.406250000000002}, {
      149.99999999999997`, -7.118243610563656}}], 
     PolygonBox[{{150., -6.406250000000002}, {
      150.65384140902208`, -7.916666666666668}, {
      150.65384140902208`, -7.002904261800856}, {150., -5.666823843430956}, {
      150., -6.406250000000002}}], 
     PolygonBox[{{150., -5.666823843430956}, {
      150.65384140902208`, -7.002904261800856}, {
      150.65384140902208`, -6.059154345780591}, {
      149.99999999999997`, -4.903131477177716}, {150., -5.666823843430956}}], 
     PolygonBox[{{149.99999999999997`, -4.9031314771777135`}, {
      150.6538414090221, -6.059154345780589}, {
      150.65384140902208`, -5.089458200633393}, {
      149.99999999999997`, -4.118443149196759}, {
      149.99999999999997`, -4.9031314771777135`}}], 
     PolygonBox[{{149.99999999999997`, -4.118443149196759}, {
      150.65384140902208`, -5.089458200633393}, {
      150.65384140902208`, -4.097968214123249}, {
      150., -3.3161190153760502`}, {
      149.99999999999997`, -4.118443149196759}}], 
     PolygonBox[{{150., -3.3161190153760502`}, {
      150.65384140902208`, -4.097968214123249}, {
      150.65384140902208`, -3.0889300985887016`}, {
      149.99999999999997`, -2.4995947508316467`}, {
      150., -3.3161190153760502`}}], 
     PolygonBox[{{150., -2.499594750831644}, {
      150.65384140902208`, -3.0889300985886985`}, {
      150.65384140902208`, -2.0666647101508184`}, {
      149.99999999999997`, -1.6723668378194125`}, {
      150., -2.499594750831644}}], 
     PolygonBox[{{149.99999999999997`, -1.6723668378194125`}, {
      150.65384140902208`, -2.0666647101508184`}, {
      150.65384140902208`, -1.035549546143935}, {150., -0.8379775932612106}, {
      149.99999999999997`, -1.6723668378194125`}}], 
     PolygonBox[{{150., -0.8379775932612106}, {
      150.65384140902208`, -1.035549546143935}, {
      150.65384140902208`, -4.485218293971317*^-15}, {
      150., -3.6294858563057365`*^-15}, {150., -0.8379775932612106}}], 
     PolygonBox[{{150., -7.845393557037732*^-16}, {
      150.65384140902208`, -9.69512049324988*^-16}, {150.65384140902208`, 
      1.0355495461439295`}, {150., 0.8379775932612061}, {
      150., -7.845393557037732*^-16}}], 
     PolygonBox[{{150., 0.8379775932612061}, {150.65384140902208`, 
      1.0355495461439295`}, {150.65384140902208`, 2.0666647101508135`}, {
      149.99999999999997`, 1.6723668378194083`}, {150., 0.8379775932612061}}],
      PolygonBox[{{149.99999999999997`, 1.6723668378194083`}, {
      150.65384140902208`, 2.0666647101508135`}, {150.65384140902208`, 
      3.0889300985886927`}, {149.99999999999997`, 2.4995947508316396`}, {
      149.99999999999997`, 1.6723668378194083`}}], 
     PolygonBox[{{149.99999999999997`, 2.4995947508316396`}, {
      150.65384140902208`, 3.0889300985886927`}, {150.65384140902208`, 
      4.097968214123239}, {149.99999999999997`, 3.3161190153760427`}, {
      149.99999999999997`, 2.4995947508316396`}}], 
     PolygonBox[{{150., 3.316119015376046}, {150.65384140902208`, 
      4.097968214123243}, {150.65384140902208`, 5.089458200633388}, {150., 
      4.1184431491967555`}, {150., 3.316119015376046}}], 
     PolygonBox[{{150., 4.1184431491967555`}, {150.65384140902208`, 
      5.089458200633388}, {150.65384140902208`, 6.059154345780583}, {150., 
      4.903131477177709}, {150., 4.1184431491967555`}}], 
     PolygonBox[{{150., 4.903131477177709}, {150.65384140902208`, 
      6.059154345780583}, {150.65384140902208`, 7.00290426180085}, {
      149.99999999999997`, 5.666823843430952}, {150., 4.903131477177709}}], 
     PolygonBox[{{149.99999999999997`, 5.666823843430952}, {
      150.65384140902208`, 7.00290426180085}, {150.65384140902208`, 
      7.916666666666663}, {149.99999999999997`, 6.406249999999997}, {
      149.99999999999997`, 5.666823843430952}}], 
     PolygonBox[{{149.99999999999997`, 6.406249999999997}, {
      150.65384140902208`, 7.916666666666663}, {150.65384140902208`, 
      8.79652868947703}, {150., 7.11824361056365}, {149.99999999999997`, 
      6.406249999999997}}], 
     PolygonBox[{{150., 7.11824361056365}, {150.65384140902208`, 
      8.79652868947703}, {150.65384140902208`, 9.638722625971406}, {
      149.99999999999997`, 7.799755809174229}, {150., 7.11824361056365}}], 
     PolygonBox[{{149.99999999999997`, 7.799755809174229}, {
      150.65384140902208`, 9.638722625971406}, {150.65384140902208`, 
      10.439642072417751`}, {150., 8.447868255969627}, {149.99999999999997`, 
      7.799755809174229}}], 
     PolygonBox[{{150., 8.447868255969627}, {150.65384140902208`, 
      10.439642072417751`}, {150.65384140902208`, 11.195857368786996`}, {150.,
       9.059805633952635}, {150., 8.447868255969627}}], 
     PolygonBox[{{149.99999999999997`, 9.059805633952639}, {
      150.65384140902208`, 11.195857368787001`}, {150.65384140902208`, 
      11.904130285083806`}, {150., 9.632947533324396}, {149.99999999999997`, 
      9.059805633952639}}], 
     PolygonBox[{{150., 9.632947533324396}, {150.65384140902208`, 
      11.904130285083806`}, {150.65384140902208`, 12.561427887944554`}, {150.,
       10.164839672481449`}, {150., 9.632947533324396}}], 
     PolygonBox[{{150., 10.164839672481449`}, {150.65384140902208`, 
      12.561427887944554`}, {150.65384140902208`, 13.164935528123628`}, {150.,
       10.653204407626358`}, {150., 10.164839672481449`}}], 
     PolygonBox[{{150., 10.653204407626358`}, {150.65384140902208`, 
      13.164935528123628`}, {150.65384140902208`, 13.712068893253608`}, {150.,
       11.095950485988118`}, {150., 10.653204407626358`}}], 
     PolygonBox[{{150., 11.095950485988118`}, {150.65384140902208`, 
      13.712068893253608`}, {150.65384140902208`, 14.200485074267563`}, {
      149.99999999999997`, 11.491182000887568`}, {150., 
      11.095950485988118`}}], 
     PolygonBox[{{149.99999999999997`, 11.491182000887568`}, {
      150.65384140902208`, 14.200485074267563`}, {150.65384140902208`, 
      14.628092598095371`}, {150., 11.83720651030086}, {149.99999999999997`, 
      11.491182000887568`}}], 
     PolygonBox[{{149.99999999999997`, 11.837206510300863`}, {
      150.6538414090221, 14.628092598095375`}, {150.65384140902208`, 
      14.993060383672503`}, {149.99999999999997`, 12.13254228415604}, {
      149.99999999999997`, 11.837206510300863`}}], 
     PolygonBox[{{149.99999999999997`, 12.13254228415604}, {
      150.65384140902208`, 14.993060383672503`}, {150.65384140902208`, 
      15.293825582910246`}, {150., 12.375924649328686`}, {149.99999999999997`,
       12.13254228415604}}], 
     PolygonBox[{{150., 12.375924649328686`}, {150.65384140902208`, 
      15.293825582910246`}, {150.65384140902208`, 15.529100273051148`}, {
      149.99999999999997`, 12.56631140516639}, {150., 12.375924649328686`}}], 
     PolygonBox[{{149.99999999999997`, 12.56631140516639}, {
      150.65384140902208`, 15.529100273051148`}, {150.65384140902208`, 
      15.697876971751997`}, {150., 12.702887286351945`}, {149.99999999999997`,
       12.56631140516639}}], 
     PolygonBox[{{150., 12.702887286351945`}, {150.65384140902208`, 
      15.697876971751997`}, {150.65384140902208`, 15.79943295127789}, {150., 
      12.785067453994607`}, {150., 12.702887286351945`}}], 
     PolygonBox[{{150., 12.785067453994607`}, {150.65384140902208`, 
      15.79943295127789}, {150.65384140902208`, 15.833333333333332`}, {150., 
      12.8125}, {150., 12.785067453994607`}}], 
     PolygonBox[{{150., 12.8125}, {150.65384140902208`, 
      15.833333333333332`}, {150.65384140902208`, 15.79943295127789}, {150., 
      12.785067453994607`}, {150., 12.8125}}], 
     PolygonBox[{{150., 12.785067453994607`}, {150.65384140902208`, 
      15.79943295127789}, {150.65384140902208`, 15.697876971751999`}, {
      149.99999999999997`, 12.702887286351945`}, {150., 
      12.785067453994607`}}], 
     PolygonBox[{{149.99999999999997`, 12.702887286351945`}, {
      150.65384140902208`, 15.697876971751999`}, {150.65384140902208`, 
      15.52910027305115}, {150., 12.566311405166392`}, {149.99999999999997`, 
      12.702887286351945`}}], 
     PolygonBox[{{150., 12.566311405166392`}, {150.65384140902208`, 
      15.52910027305115}, {150.65384140902208`, 15.293825582910248`}, {
      149.99999999999997`, 12.375924649328688`}, {150., 
      12.566311405166392`}}], 
     PolygonBox[{{149.99999999999997`, 12.375924649328688`}, {
      150.65384140902208`, 15.293825582910248`}, {150.65384140902208`, 
      14.993060383672507`}, {149.99999999999997`, 12.132542284156042`}, {
      149.99999999999997`, 12.375924649328688`}}], 
     PolygonBox[{{149.99999999999997`, 12.132542284156042`}, {
      150.65384140902208`, 14.993060383672507`}, {150.65384140902208`, 
      14.628092598095376`}, {149.99999999999997`, 11.837206510300865`}, {
      149.99999999999997`, 12.132542284156042`}}], 
     PolygonBox[{{149.99999999999997`, 11.837206510300865`}, {
      150.65384140902208`, 14.628092598095376`}, {150.65384140902208`, 
      14.200485074267569`}, {150., 11.491182000887573`}, {149.99999999999997`,
       11.837206510300865`}}], 
     PolygonBox[{{149.99999999999997`, 11.49118200088757}, {
      150.65384140902208`, 14.200485074267565`}, {150.65384140902208`, 
      13.712068893253614`}, {150., 11.095950485988123`}, {149.99999999999997`,
       11.49118200088757}}], 
     PolygonBox[{{150., 11.095950485988123`}, {150.65384140902208`, 
      13.712068893253614`}, {150.65384140902208`, 13.164935528123637`}, {150.,
       10.653204407626363`}, {150., 11.095950485988123`}}], 
     PolygonBox[{{150., 10.653204407626363`}, {150.65384140902208`, 
      13.164935528123637`}, {150.65384140902208`, 12.56142788794456}, {
      149.99999999999997`, 10.164839672481454`}, {150., 
      10.653204407626363`}}], 
     PolygonBox[{{149.99999999999997`, 10.164839672481454`}, {
      150.65384140902208`, 12.56142788794456}, {150.65384140902208`, 
      11.904130285083813`}, {150., 9.632947533324401}, {149.99999999999997`, 
      10.164839672481454`}}], 
     PolygonBox[{{150., 9.632947533324401}, {150.65384140902208`, 
      11.904130285083813`}, {150.65384140902208`, 11.195857368787008`}, {150.,
       9.059805633952646}, {150., 9.632947533324401}}], 
     PolygonBox[{{150., 9.059805633952646}, {150.65384140902208`, 
      11.195857368787008`}, {150.65384140902208`, 10.439642072417765`}, {150.,
       8.447868255969638}, {150., 9.059805633952646}}], 
     PolygonBox[{{150., 8.447868255969635}, {150.65384140902208`, 
      10.43964207241776}, {150.65384140902208`, 9.638722625971413}, {
      149.99999999999997`, 7.799755809174236}, {150., 8.447868255969635}}], 
     PolygonBox[{{149.99999999999997`, 7.799755809174236}, {
      150.65384140902208`, 9.638722625971413}, {150.65384140902208`, 
      8.796528689477036}, {150., 7.1182436105636535`}, {149.99999999999997`, 
      7.799755809174236}}], 
     PolygonBox[{{150., 7.118243610563662}, {150.65384140902208`, 
      8.796528689477046}, {150.65384140902208`, 7.916666666666674}, {
      149.99999999999997`, 6.406250000000006}, {150., 7.118243610563662}}], 
     PolygonBox[{{149.99999999999997`, 6.406250000000006}, {
      150.65384140902208`, 7.916666666666674}, {150.65384140902208`, 
      7.002904261800854}, {149.99999999999997`, 5.666823843430954}, {
      149.99999999999997`, 6.406250000000006}}], 
     PolygonBox[{{149.99999999999997`, 5.666823843430954}, {
      150.65384140902208`, 7.002904261800854}, {150.65384140902208`, 
      6.059154345780583}, {150., 4.903131477177709}, {149.99999999999997`, 
      5.666823843430954}}], 
     PolygonBox[{{149.99999999999997`, 4.90313147717772}, {
      150.65384140902208`, 6.0591543457805965`}, {150.65384140902208`, 
      5.089458200633395}, {150., 4.118443149196761}, {149.99999999999997`, 
      4.90313147717772}}], 
     PolygonBox[{{150., 4.118443149196761}, {150.65384140902208`, 
      5.089458200633395}, {150.65384140902208`, 4.097968214123243}, {150., 
      3.316119015376046}, {150., 4.118443149196761}}], 
     PolygonBox[{{150., 3.316119015376057}, {150.65384140902208`, 
      4.097968214123258}, {150.65384140902208`, 3.088930098588704}, {
      149.99999999999997`, 2.4995947508316485`}, {150., 3.316119015376057}}], 
     PolygonBox[{{149.99999999999997`, 2.4995947508316485`}, {
      150.65384140902208`, 3.088930098588704}, {150.65384140902208`, 
      2.0666647101508175`}, {149.99999999999997`, 1.6723668378194114`}, {
      149.99999999999997`, 2.4995947508316485`}}], 
     PolygonBox[{{149.99999999999997`, 1.6723668378194225`}, {
      150.65384140902208`, 2.066664710150831}, {150.65384140902208`, 
      1.0355495461439406`}, {150., 0.8379775932612151}, {149.99999999999997`, 
      1.6723668378194225`}}], 
     PolygonBox[{{150., 0.8379775932612151}, {150.65384140902208`, 
      1.0355495461439406`}, {150.65384140902208`, 2.9085361479749633`*^-15}, {
      150., 2.3536180671113193`*^-15}, {150., 0.8379775932612151}}], 
     PolygonBox[{{150., 2.3536180671113193`*^-15}, {150.65384140902208`, 
      2.9085361479749633`*^-15}, {
      150.65384140902208`, -1.0355495461439348`}, {
      150., -0.8379775932612105}, {150., 2.3536180671113193`*^-15}}], 
     PolygonBox[{{150., -0.8379775932611991}, {
      150.65384140902208`, -1.0355495461439208`}, {
      150.65384140902208`, -2.0666647101508118`}, {
      149.99999999999997`, -1.6723668378194068`}, {
      150., -0.8379775932611991}}], 
     PolygonBox[{{149.99999999999997`, -1.6723668378194068`}, {
      150.65384140902208`, -2.0666647101508118`}, {
      150.65384140902208`, -3.088930098588698}, {150., -2.499594750831644}, {
      149.99999999999997`, -1.6723668378194068`}}], 
     PolygonBox[{{149.99999999999997`, -2.4995947508316325`}, {
      150.65384140902208`, -3.088930098588684}, {
      150.65384140902208`, -4.097968214123238}, {
      149.99999999999997`, -3.3161190153760414`}, {
      149.99999999999997`, -2.4995947508316325`}}], 
     PolygonBox[{{149.99999999999997`, -3.3161190153760414`}, {
      150.65384140902208`, -4.097968214123238}, {
      150.65384140902208`, -5.0894582006333895`}, {
      150., -4.118443149196756}, {
      149.99999999999997`, -3.3161190153760414`}}], 
     PolygonBox[{{150., -4.118443149196756}, {
      150.65384140902208`, -5.0894582006333895`}, {
      150.65384140902208`, -6.059154345780591}, {
      149.99999999999997`, -4.903131477177716}, {150., -4.118443149196756}}], 
     PolygonBox[{{149.99999999999997`, -4.9031314771777055`}, {
      150.65384140902208`, -6.059154345780579}, {
      150.65384140902208`, -7.0029042618008495`}, {
      149.99999999999997`, -5.666823843430951}, {
      149.99999999999997`, -4.9031314771777055`}}], 
     PolygonBox[{{149.99999999999997`, -5.666823843430951}, {
      150.65384140902208`, -7.0029042618008495`}, {
      150.65384140902208`, -7.916666666666668}, {150., -6.406250000000002}, {
      149.99999999999997`, -5.666823843430951}}], 
     PolygonBox[{{150., -6.406249999999991}, {
      150.65384140902208`, -7.916666666666655}, {
      150.65384140902208`, -8.796528689477029}, {150., -7.118243610563649}, {
      150., -6.406249999999991}}], 
     PolygonBox[{{150., -7.118243610563649}, {
      150.65384140902208`, -8.796528689477029}, {
      150.65384140902208`, -9.638722625971408}, {150., -7.799755809174232}, {
      150., -7.118243610563649}}], 
     PolygonBox[{{150., -7.799755809174224}, {
      150.65384140902208`, -9.638722625971397}, {
      150.65384140902208`, -10.43964207241775}, {150., -8.447868255969627}, {
      150., -7.799755809174224}}], 
     PolygonBox[{{150., -8.447868255969627}, {
      150.65384140902208`, -10.43964207241775}, {
      150.65384140902208`, -11.195857368787}, {150., -9.059805633952639}, {
      150., -8.447868255969627}}], 
     PolygonBox[{{150., -9.059805633952639}, {
      150.65384140902208`, -11.195857368787}, {
      150.65384140902208`, -11.90413028508381}, {
      149.99999999999997`, -9.632947533324398}, {150., -9.059805633952639}}], 
     PolygonBox[{{150., -9.632947533324392}, {
      150.65384140902208`, -11.904130285083802`}, {
      150.65384140902208`, -12.561427887944554`}, {
      149.99999999999997`, -10.164839672481447`}, {
      150., -9.632947533324392}}], 
     PolygonBox[{{149.99999999999997`, -10.164839672481447`}, {
      150.65384140902208`, -12.561427887944554`}, {
      150.65384140902208`, -13.164935528123632`}, {
      150., -10.653204407626362`}, {
      149.99999999999997`, -10.164839672481447`}}], 
     PolygonBox[{{150., -10.653204407626355`}, {
      150.65384140902208`, -13.164935528123625`}, {
      150.65384140902208`, -13.712068893253608`}, {
      149.99999999999997`, -11.095950485988116`}, {
      150., -10.653204407626355`}}], 
     PolygonBox[{{149.99999999999997`, -11.095950485988116`}, {
      150.65384140902208`, -13.712068893253608`}, {
      150.65384140902208`, -14.200485074267563`}, {
      150., -11.491182000887568`}, {
      149.99999999999997`, -11.095950485988116`}}], 
     PolygonBox[{{150., -11.491182000887562`}, {
      150.65384140902208`, -14.200485074267556`}, {
      150.6538414090221, -14.628092598095371`}, {
      149.99999999999997`, -11.83720651030086}, {
      150., -11.491182000887562`}}], 
     PolygonBox[{{149.99999999999997`, -11.83720651030086}, {
      150.6538414090221, -14.628092598095371`}, {
      150.65384140902208`, -14.993060383672503`}, {
      150., -12.13254228415604}, {149.99999999999997`, -11.83720651030086}}], 
     PolygonBox[{{150., -12.13254228415604}, {
      150.65384140902208`, -14.993060383672503`}, {
      150.65384140902208`, -15.293825582910248`}, {
      150., -12.375924649328688`}, {150., -12.13254228415604}}], 
     PolygonBox[{{150., -12.375924649328685`}, {
      150.65384140902208`, -15.293825582910245`}, {
      150.65384140902208`, -15.529100273051146`}, {
      149.99999999999997`, -12.566311405166388`}, {
      150., -12.375924649328685`}}], 
     PolygonBox[{{149.99999999999997`, -12.566311405166388`}, {
      150.65384140902208`, -15.529100273051146`}, {
      150.65384140902208`, -15.697876971751997`}, {
      149.99999999999997`, -12.702887286351945`}, {
      149.99999999999997`, -12.566311405166388`}}], 
     PolygonBox[{{150., -12.702887286351944`}, {
      150.65384140902208`, -15.697876971751995`}, {
      150.65384140902208`, -15.79943295127789}, {
      150., -12.785067453994607`}, {150., -12.702887286351944`}}], 
     PolygonBox[{{150., -12.785067453994607`}, {
      150.65384140902208`, -15.79943295127789}, {
      150.65384140902208`, -15.833333333333332`}, {150., -12.8125}, {
      150., -12.785067453994607`}}], 
     PolygonBox[{{150.65384140902208`, -15.833333333333332`}, {
      133.98717474235545`, -18.854166666666664`}, {
      133.98717474235545`, -18.81379844856117}, {
      150.65384140902208`, -15.79943295127789}, {
      150.65384140902208`, -15.833333333333332`}}], 
     PolygonBox[{{150.65384140902208`, -15.79943295127789}, {
      133.98717474235545`, -18.81379844856117}, {
      133.98717474235545`, -18.69286665715205}, {
      150.65384140902208`, -15.697876971751997`}, {
      150.65384140902208`, -15.79943295127789}}], 
     PolygonBox[{{150.65384140902208`, -15.697876971751997`}, {
      133.98717474235545`, -18.69286665715205}, {
      133.98717474235542`, -18.491889140935907`}, {
      150.65384140902208`, -15.529100273051148`}, {
      150.65384140902208`, -15.697876971751997`}}], 
     PolygonBox[{{150.65384140902208`, -15.529100273051148`}, {
      133.98717474235542`, -18.491889140935907`}, {
      133.98717474235542`, -18.211726516491808`}, {
      150.65384140902208`, -15.293825582910248`}, {
      150.65384140902208`, -15.529100273051148`}}], 
     PolygonBox[{{150.65384140902208`, -15.293825582910248`}, {
      133.98717474235542`, -18.211726516491808`}, {
      133.98717474235548`, -17.85357848318897}, {
      150.65384140902208`, -14.993060383672507`}, {
      150.65384140902208`, -15.293825582910248`}}], 
     PolygonBox[{{150.65384140902208`, -14.993060383672507`}, {
      133.98717474235548`, -17.85357848318897}, {
      133.98717474235542`, -17.418978685889886`}, {
      150.65384140902208`, -14.628092598095375`}, {
      150.65384140902208`, -14.993060383672507`}}], 
     PolygonBox[{{150.65384140902208`, -14.628092598095375`}, {
      133.98717474235542`, -17.418978685889886`}, {
      133.98717474235542`, -16.90978814764756}, {
      150.65384140902208`, -14.200485074267565`}, {
      150.65384140902208`, -14.628092598095375`}}], 
     PolygonBox[{{150.65384140902208`, -14.200485074267565`}, {
      133.98717474235542`, -16.90978814764756}, {
      133.98717474235542`, -16.328187300519104`}, {
      150.65384140902208`, -13.712068893253612`}, {
      150.65384140902208`, -14.200485074267565`}}], 
     PolygonBox[{{150.65384140902208`, -13.712068893253612`}, {
      133.98717474235542`, -16.328187300519104`}, {
      133.98717474235545`, -15.676666648620904`}, {
      150.65384140902208`, -13.164935528123632`}, {
      150.65384140902208`, -13.712068893253612`}}], 
     PolygonBox[{{150.65384140902208`, -13.164935528123632`}, {
      133.98717474235545`, -15.676666648620904`}, {
      133.98717474235545`, -14.958016103407662`}, {
      150.65384140902208`, -12.561427887944555`}, {
      150.65384140902208`, -13.164935528123632`}}], 
     PolygonBox[{{150.65384140902208`, -12.561427887944557`}, {
      133.98717474235542`, -14.958016103407665`}, {
      133.98717474235545`, -14.175313036843217`}, {
      150.65384140902208`, -11.90413028508381}, {
      150.65384140902208`, -12.561427887944557`}}], 
     PolygonBox[{{150.65384140902208`, -11.90413028508381}, {
      133.98717474235545`, -14.175313036843217`}, {
      133.98717474235545`, -13.331909103621363`}, {
      150.65384140902208`, -11.195857368787003`}, {
      150.65384140902208`, -11.90413028508381}}], 
     PolygonBox[{{150.65384140902208`, -11.195857368787003`}, {
      133.98717474235545`, -13.331909103621363`}, {
      133.98717474235545`, -12.431415888865882`}, {
      150.65384140902208`, -10.439642072417756`}, {
      150.65384140902208`, -11.195857368787003`}}], 
     PolygonBox[{{150.65384140902208`, -10.439642072417758`}, {
      133.98717474235545`, -12.431415888865883`}, {
      133.98717474235545`, -11.477689442768586`}, {
      150.65384140902208`, -9.63872262597141}, {
      150.65384140902208`, -10.439642072417758`}}], 
     PolygonBox[{{150.65384140902208`, -9.63872262597141}, {
      133.98717474235545`, -11.477689442768586`}, {
      133.98717474235545`, -10.474813768390417`}, {
      150.65384140902208`, -8.796528689477036}, {
      150.65384140902208`, -9.63872262597141}}], 
     PolygonBox[{{150.65384140902208`, -8.796528689477038}, {
      133.98717474235545`, -10.474813768390419`}, {
      133.98717474235545`, -9.427083333333334}, {
      150.65384140902208`, -7.916666666666668}, {
      150.65384140902208`, -8.796528689477038}}], 
     PolygonBox[{{150.65384140902208`, -7.916666666666668}, {
      133.98717474235545`, -9.427083333333334}, {
      133.98717474235545`, -8.338984680170755}, {
      150.65384140902208`, -7.002904261800856}, {
      150.65384140902208`, -7.916666666666668}}], 
     PolygonBox[{{150.65384140902208`, -7.002904261800856}, {
      133.98717474235545`, -8.338984680170755}, {
      133.98717474235545`, -7.215177214383467}, {
      150.65384140902208`, -6.059154345780591}, {
      150.65384140902208`, -7.002904261800856}}], 
     PolygonBox[{{150.6538414090221, -6.059154345780589}, {
      133.98717474235542`, -7.2151772143834645`}, {
      133.98717474235545`, -6.060473252070027}, {
      150.65384140902208`, -5.089458200633393}, {
      150.6538414090221, -6.059154345780589}}], 
     PolygonBox[{{150.65384140902208`, -5.089458200633393}, {
      133.98717474235545`, -6.060473252070027}, {
      133.98717474235545`, -4.879817412870447}, {
      150.65384140902208`, -4.097968214123249}, {
      150.65384140902208`, -5.089458200633393}}], 
     PolygonBox[{{150.65384140902208`, -4.097968214123249}, {
      133.98717474235545`, -4.879817412870447}, {
      133.98717474235542`, -3.6782654463457565`}, {
      150.65384140902208`, -3.0889300985887016`}, {
      150.65384140902208`, -4.097968214123249}}], 
     PolygonBox[{{150.65384140902208`, -3.0889300985886985`}, {
      133.98717474235542`, -3.678265446345753}, {
      133.98717474235545`, -2.4609625824822245`}, {
      150.65384140902208`, -2.0666647101508184`}, {
      150.65384140902208`, -3.0889300985886985`}}], 
     PolygonBox[{{150.65384140902208`, -2.0666647101508184`}, {
      133.98717474235545`, -2.4609625824822245`}, {
      133.98717474235545`, -1.2331214990266595`}, {
      150.65384140902208`, -1.035549546143935}, {
      150.65384140902208`, -2.0666647101508184`}}], 
     PolygonBox[{{150.65384140902208`, -1.035549546143935}, {
      133.98717474235545`, -1.2331214990266595`}, {
      133.98717474235545`, -5.3409507316368974`*^-15}, {
      150.65384140902208`, -4.485218293971317*^-15}, {
      150.65384140902208`, -1.035549546143935}}], 
     PolygonBox[{{150.65384140902208`, -9.69512049324988*^-16}, {
      133.98717474235545`, -1.1544847429462027`*^-15}, {133.98717474235545`, 
      1.233121499026653}, {150.65384140902208`, 1.0355495461439295`}, {
      150.65384140902208`, -9.69512049324988*^-16}}], 
     PolygonBox[{{150.65384140902208`, 1.0355495461439295`}, {
      133.98717474235545`, 1.233121499026653}, {133.98717474235545`, 
      2.4609625824822188`}, {150.65384140902208`, 2.0666647101508135`}, {
      150.65384140902208`, 1.0355495461439295`}}], 
     PolygonBox[{{150.65384140902208`, 2.0666647101508135`}, {
      133.98717474235545`, 2.4609625824822188`}, {133.98717474235545`, 
      3.678265446345746}, {150.65384140902208`, 3.0889300985886927`}, {
      150.65384140902208`, 2.0666647101508135`}}], 
     PolygonBox[{{150.65384140902208`, 3.0889300985886927`}, {
      133.98717474235545`, 3.678265446345746}, {133.98717474235545`, 
      4.879817412870437}, {150.65384140902208`, 4.097968214123239}, {
      150.65384140902208`, 3.0889300985886927`}}], 
     PolygonBox[{{150.65384140902208`, 4.097968214123243}, {
      133.98717474235545`, 4.879817412870441}, {133.98717474235548`, 
      6.060473252070021}, {150.65384140902208`, 5.089458200633388}, {
      150.65384140902208`, 4.097968214123243}}], 
     PolygonBox[{{150.65384140902208`, 5.089458200633388}, {
      133.98717474235548`, 6.060473252070021}, {133.98717474235545`, 
      7.215177214383457}, {150.65384140902208`, 6.059154345780583}, {
      150.65384140902208`, 5.089458200633388}}], 
     PolygonBox[{{150.65384140902208`, 6.059154345780583}, {
      133.98717474235545`, 7.215177214383457}, {133.98717474235545`, 
      8.33898468017075}, {150.65384140902208`, 7.00290426180085}, {
      150.65384140902208`, 6.059154345780583}}], 
     PolygonBox[{{150.65384140902208`, 7.00290426180085}, {
      133.98717474235545`, 8.33898468017075}, {133.98717474235545`, 
      9.427083333333329}, {150.65384140902208`, 7.916666666666663}, {
      150.65384140902208`, 7.00290426180085}}], 
     PolygonBox[{{150.65384140902208`, 7.916666666666663}, {
      133.98717474235545`, 9.427083333333329}, {133.98717474235542`, 
      10.474813768390412`}, {150.65384140902208`, 8.79652868947703}, {
      150.65384140902208`, 7.916666666666663}}], 
     PolygonBox[{{150.65384140902208`, 8.79652868947703}, {
      133.98717474235542`, 10.474813768390412`}, {133.98717474235542`, 
      11.47768944276858}, {150.65384140902208`, 9.638722625971406}, {
      150.65384140902208`, 8.79652868947703}}], 
     PolygonBox[{{150.65384140902208`, 9.638722625971406}, {
      133.98717474235542`, 11.47768944276858}, {133.98717474235545`, 
      12.431415888865875`}, {150.65384140902208`, 10.439642072417751`}, {
      150.65384140902208`, 9.638722625971406}}], 
     PolygonBox[{{150.65384140902208`, 10.439642072417751`}, {
      133.98717474235545`, 12.431415888865875`}, {133.98717474235542`, 
      13.331909103621356`}, {150.65384140902208`, 11.195857368786996`}, {
      150.65384140902208`, 10.439642072417751`}}], 
     PolygonBox[{{150.65384140902208`, 11.195857368787001`}, {
      133.98717474235545`, 13.331909103621363`}, {133.98717474235545`, 
      14.175313036843216`}, {150.65384140902208`, 11.904130285083806`}, {
      150.65384140902208`, 11.195857368787001`}}], 
     PolygonBox[{{150.65384140902208`, 11.904130285083806`}, {
      133.98717474235545`, 14.175313036843216`}, {133.98717474235545`, 
      14.95801610340766}, {150.65384140902208`, 12.561427887944554`}, {
      150.65384140902208`, 11.904130285083806`}}], 
     PolygonBox[{{150.65384140902208`, 12.561427887944554`}, {
      133.98717474235545`, 14.95801610340766}, {133.98717474235545`, 
      15.6766666486209}, {150.65384140902208`, 13.164935528123628`}, {
      150.65384140902208`, 12.561427887944554`}}], 
     PolygonBox[{{150.65384140902208`, 13.164935528123628`}, {
      133.98717474235545`, 15.6766666486209}, {133.98717474235545`, 
      16.328187300519097`}, {150.65384140902208`, 13.712068893253608`}, {
      150.65384140902208`, 13.164935528123628`}}], 
     PolygonBox[{{150.65384140902208`, 13.712068893253608`}, {
      133.98717474235545`, 16.328187300519097`}, {133.98717474235542`, 
      16.909788147647557`}, {150.65384140902208`, 14.200485074267563`}, {
      150.65384140902208`, 13.712068893253608`}}], 
     PolygonBox[{{150.65384140902208`, 14.200485074267563`}, {
      133.98717474235542`, 16.909788147647557`}, {133.98717474235542`, 
      17.418978685889883`}, {150.65384140902208`, 14.628092598095371`}, {
      150.65384140902208`, 14.200485074267563`}}], 
     PolygonBox[{{150.6538414090221, 14.628092598095375`}, {
      133.98717474235542`, 17.418978685889886`}, {133.98717474235545`, 
      17.85357848318897}, {150.65384140902208`, 14.993060383672503`}, {
      150.6538414090221, 14.628092598095375`}}], 
     PolygonBox[{{150.65384140902208`, 14.993060383672503`}, {
      133.98717474235545`, 17.85357848318897}, {133.98717474235545`, 
      18.211726516491805`}, {150.65384140902208`, 15.293825582910246`}, {
      150.65384140902208`, 14.993060383672503`}}], 
     PolygonBox[{{150.65384140902208`, 15.293825582910246`}, {
      133.98717474235545`, 18.211726516491805`}, {133.98717474235542`, 
      18.491889140935907`}, {150.65384140902208`, 15.529100273051148`}, {
      150.65384140902208`, 15.293825582910246`}}], 
     PolygonBox[{{150.65384140902208`, 15.529100273051148`}, {
      133.98717474235542`, 18.491889140935907`}, {133.98717474235545`, 
      18.69286665715205}, {150.65384140902208`, 15.697876971751997`}, {
      150.65384140902208`, 15.529100273051148`}}], 
     PolygonBox[{{150.65384140902208`, 15.697876971751997`}, {
      133.98717474235545`, 18.69286665715205}, {133.98717474235545`, 
      18.81379844856117}, {150.65384140902208`, 15.79943295127789}, {
      150.65384140902208`, 15.697876971751997`}}], 
     PolygonBox[{{150.65384140902208`, 15.79943295127789}, {
      133.98717474235545`, 18.81379844856117}, {133.98717474235545`, 
      18.854166666666664`}, {150.65384140902208`, 15.833333333333332`}, {
      150.65384140902208`, 15.79943295127789}}], 
     PolygonBox[{{150.65384140902208`, 15.833333333333332`}, {
      133.98717474235545`, 18.854166666666664`}, {133.98717474235545`, 
      18.81379844856117}, {150.65384140902208`, 15.79943295127789}, {
      150.65384140902208`, 15.833333333333332`}}], 
     PolygonBox[{{150.65384140902208`, 15.79943295127789}, {
      133.98717474235545`, 18.81379844856117}, {133.98717474235545`, 
      18.69286665715205}, {150.65384140902208`, 15.697876971751999`}, {
      150.65384140902208`, 15.79943295127789}}], 
     PolygonBox[{{150.65384140902208`, 15.697876971751999`}, {
      133.98717474235545`, 18.69286665715205}, {133.98717474235545`, 
      18.491889140935907`}, {150.65384140902208`, 15.52910027305115}, {
      150.65384140902208`, 15.697876971751999`}}], 
     PolygonBox[{{150.65384140902208`, 15.52910027305115}, {
      133.98717474235545`, 18.491889140935907`}, {133.98717474235545`, 
      18.211726516491808`}, {150.65384140902208`, 15.293825582910248`}, {
      150.65384140902208`, 15.52910027305115}}], 
     PolygonBox[{{150.65384140902208`, 15.293825582910248`}, {
      133.98717474235545`, 18.211726516491808`}, {133.98717474235545`, 
      17.853578483188972`}, {150.65384140902208`, 14.993060383672507`}, {
      150.65384140902208`, 15.293825582910248`}}], 
     PolygonBox[{{150.65384140902208`, 14.993060383672507`}, {
      133.98717474235545`, 17.853578483188972`}, {133.98717474235542`, 
      17.41897868588989}, {150.65384140902208`, 14.628092598095376`}, {
      150.65384140902208`, 14.993060383672507`}}], 
     PolygonBox[{{150.65384140902208`, 14.628092598095376`}, {
      133.98717474235542`, 17.41897868588989}, {133.98717474235542`, 
      16.909788147647568`}, {150.65384140902208`, 14.200485074267569`}, {
      150.65384140902208`, 14.628092598095376`}}], 
     PolygonBox[{{150.65384140902208`, 14.200485074267565`}, {
      133.98717474235545`, 16.90978814764756}, {133.98717474235542`, 
      16.328187300519108`}, {150.65384140902208`, 13.712068893253614`}, {
      150.65384140902208`, 14.200485074267565`}}], 
     PolygonBox[{{150.65384140902208`, 13.712068893253614`}, {
      133.98717474235542`, 16.328187300519108`}, {133.98717474235542`, 
      15.676666648620909`}, {150.65384140902208`, 13.164935528123637`}, {
      150.65384140902208`, 13.712068893253614`}}], 
     PolygonBox[{{150.65384140902208`, 13.164935528123637`}, {
      133.98717474235542`, 15.676666648620909`}, {133.98717474235542`, 
      14.958016103407667`}, {150.65384140902208`, 12.56142788794456}, {
      150.65384140902208`, 13.164935528123637`}}], 
     PolygonBox[{{150.65384140902208`, 12.56142788794456}, {
      133.98717474235542`, 14.958016103407667`}, {133.98717474235545`, 
      14.175313036843225`}, {150.65384140902208`, 11.904130285083813`}, {
      150.65384140902208`, 12.56142788794456}}], 
     PolygonBox[{{150.65384140902208`, 11.904130285083813`}, {
      133.98717474235545`, 14.175313036843225`}, {133.98717474235542`, 
      13.331909103621372`}, {150.65384140902208`, 11.195857368787008`}, {
      150.65384140902208`, 11.904130285083813`}}], 
     PolygonBox[{{150.65384140902208`, 11.195857368787008`}, {
      133.98717474235542`, 13.331909103621372`}, {133.98717474235545`, 
      12.43141588886589}, {150.65384140902208`, 10.439642072417765`}, {
      150.65384140902208`, 11.195857368787008`}}], 
     PolygonBox[{{150.65384140902208`, 10.43964207241776}, {
      133.98717474235542`, 12.431415888865885`}, {133.98717474235545`, 
      11.47768944276859}, {150.65384140902208`, 9.638722625971413}, {
      150.65384140902208`, 10.43964207241776}}], 
     PolygonBox[{{150.65384140902208`, 9.638722625971413}, {
      133.98717474235545`, 11.47768944276859}, {133.98717474235545`, 
      10.474813768390415`}, {150.65384140902208`, 8.796528689477036}, {
      150.65384140902208`, 9.638722625971413}}], 
     PolygonBox[{{150.65384140902208`, 8.796528689477046}, {
      133.98717474235545`, 10.47481376839043}, {133.98717474235542`, 
      9.427083333333343}, {150.65384140902208`, 7.916666666666674}, {
      150.65384140902208`, 8.796528689477046}}], 
     PolygonBox[{{150.65384140902208`, 7.916666666666674}, {
      133.98717474235542`, 9.427083333333343}, {133.98717474235545`, 
      8.338984680170753}, {150.65384140902208`, 7.002904261800854}, {
      150.65384140902208`, 7.916666666666674}}], 
     PolygonBox[{{150.65384140902208`, 7.002904261800854}, {
      133.98717474235545`, 8.338984680170753}, {133.98717474235545`, 
      7.215177214383457}, {150.65384140902208`, 6.059154345780583}, {
      150.65384140902208`, 7.002904261800854}}], 
     PolygonBox[{{150.65384140902208`, 6.0591543457805965`}, {
      133.98717474235542`, 7.215177214383473}, {133.98717474235545`, 
      6.06047325207003}, {150.65384140902208`, 5.089458200633395}, {
      150.65384140902208`, 6.0591543457805965`}}], 
     PolygonBox[{{150.65384140902208`, 5.089458200633395}, {
      133.98717474235545`, 6.06047325207003}, {133.98717474235545`, 
      4.879817412870441}, {150.65384140902208`, 4.097968214123243}, {
      150.65384140902208`, 5.089458200633395}}], 
     PolygonBox[{{150.65384140902208`, 4.097968214123258}, {
      133.98717474235542`, 4.879817412870457}, {133.98717474235545`, 
      3.6782654463457587`}, {150.65384140902208`, 3.088930098588704}, {
      150.65384140902208`, 4.097968214123258}}], 
     PolygonBox[{{150.65384140902208`, 3.088930098588704}, {
      133.98717474235545`, 3.6782654463457587`}, {133.98717474235545`, 
      2.460962582482223}, {150.65384140902208`, 2.0666647101508175`}, {
      150.65384140902208`, 3.088930098588704}}], 
     PolygonBox[{{150.65384140902208`, 2.066664710150831}, {
      133.98717474235545`, 2.4609625824822396`}, {133.98717474235545`, 
      1.2331214990266661`}, {150.65384140902208`, 1.0355495461439406`}, {
      150.65384140902208`, 2.066664710150831}}], 
     PolygonBox[{{150.65384140902208`, 1.0355495461439406`}, {
      133.98717474235545`, 1.2331214990266661`}, {133.98717474235545`, 
      3.4634542288386077`*^-15}, {150.65384140902208`, 
      2.9085361479749633`*^-15}, {150.65384140902208`, 1.0355495461439406`}}],
      PolygonBox[{{150.65384140902208`, 2.9085361479749633`*^-15}, {
      133.98717474235545`, 3.4634542288386077`*^-15}, {
      133.98717474235545`, -1.2331214990266592`}, {
      150.65384140902208`, -1.0355495461439348`}, {150.65384140902208`, 
      2.9085361479749633`*^-15}}], 
     PolygonBox[{{150.65384140902208`, -1.0355495461439208`}, {
      133.98717474235545`, -1.2331214990266426`}, {
      133.98717474235545`, -2.4609625824822166`}, {
      150.65384140902208`, -2.0666647101508118`}, {
      150.65384140902208`, -1.0355495461439208`}}], 
     PolygonBox[{{150.65384140902208`, -2.0666647101508118`}, {
      133.98717474235545`, -2.4609625824822166`}, {
      133.98717474235542`, -3.6782654463457525`}, {
      150.65384140902208`, -3.088930098588698}, {
      150.65384140902208`, -2.0666647101508118`}}], 
     PolygonBox[{{150.65384140902208`, -3.088930098588684}, {
      133.98717474235542`, -3.678265446345735}, {
      133.98717474235545`, -4.879817412870434}, {
      150.65384140902208`, -4.097968214123238}, {
      150.65384140902208`, -3.088930098588684}}], 
     PolygonBox[{{150.65384140902208`, -4.097968214123238}, {
      133.98717474235545`, -4.879817412870434}, {
      133.98717474235548`, -6.0604732520700235`}, {
      150.65384140902208`, -5.0894582006333895`}, {
      150.65384140902208`, -4.097968214123238}}], 
     PolygonBox[{{150.65384140902208`, -5.0894582006333895`}, {
      133.98717474235548`, -6.0604732520700235`}, {
      133.98717474235545`, -7.215177214383467}, {
      150.65384140902208`, -6.059154345780591}, {
      150.65384140902208`, -5.0894582006333895`}}], 
     PolygonBox[{{150.65384140902208`, -6.059154345780579}, {
      133.98717474235545`, -7.215177214383452}, {
      133.98717474235545`, -8.338984680170748}, {
      150.65384140902208`, -7.0029042618008495`}, {
      150.65384140902208`, -6.059154345780579}}], 
     PolygonBox[{{150.65384140902208`, -7.0029042618008495`}, {
      133.98717474235545`, -8.338984680170748}, {
      133.98717474235545`, -9.427083333333334}, {
      150.65384140902208`, -7.916666666666668}, {
      150.65384140902208`, -7.0029042618008495`}}], 
     PolygonBox[{{150.65384140902208`, -7.916666666666655}, {
      133.98717474235545`, -9.42708333333332}, {
      133.98717474235545`, -10.474813768390408`}, {
      150.65384140902208`, -8.796528689477029}, {
      150.65384140902208`, -7.916666666666655}}], 
     PolygonBox[{{150.65384140902208`, -8.796528689477029}, {
      133.98717474235545`, -10.474813768390408`}, {
      133.98717474235545`, -11.477689442768586`}, {
      150.65384140902208`, -9.638722625971408}, {
      150.65384140902208`, -8.796528689477029}}], 
     PolygonBox[{{150.65384140902208`, -9.638722625971397}, {
      133.98717474235545`, -11.477689442768572`}, {
      133.98717474235545`, -12.431415888865873`}, {
      150.65384140902208`, -10.43964207241775}, {
      150.65384140902208`, -9.638722625971397}}], 
     PolygonBox[{{150.65384140902208`, -10.43964207241775}, {
      133.98717474235545`, -12.431415888865873`}, {
      133.98717474235545`, -13.33190910362136}, {
      150.65384140902208`, -11.195857368787}, {
      150.65384140902208`, -10.43964207241775}}], 
     PolygonBox[{{150.65384140902208`, -11.195857368787}, {
      133.98717474235545`, -13.33190910362136}, {
      133.98717474235545`, -14.175313036843221`}, {
      150.65384140902208`, -11.90413028508381}, {
      150.65384140902208`, -11.195857368787}}], 
     PolygonBox[{{150.65384140902208`, -11.904130285083802`}, {
      133.98717474235545`, -14.17531303684321}, {
      133.98717474235545`, -14.958016103407658`}, {
      150.65384140902208`, -12.561427887944554`}, {
      150.65384140902208`, -11.904130285083802`}}], 
     PolygonBox[{{150.65384140902208`, -12.561427887944554`}, {
      133.98717474235545`, -14.958016103407658`}, {
      133.98717474235545`, -15.676666648620904`}, {
      150.65384140902208`, -13.164935528123632`}, {
      150.65384140902208`, -12.561427887944554`}}], 
     PolygonBox[{{150.65384140902208`, -13.164935528123625`}, {
      133.98717474235545`, -15.676666648620895`}, {
      133.98717474235542`, -16.328187300519097`}, {
      150.65384140902208`, -13.712068893253608`}, {
      150.65384140902208`, -13.164935528123625`}}], 
     PolygonBox[{{150.65384140902208`, -13.712068893253608`}, {
      133.98717474235542`, -16.328187300519097`}, {
      133.98717474235545`, -16.909788147647557`}, {
      150.65384140902208`, -14.200485074267563`}, {
      150.65384140902208`, -13.712068893253608`}}], 
     PolygonBox[{{150.65384140902208`, -14.200485074267556`}, {
      133.98717474235545`, -16.90978814764755}, {
      133.98717474235542`, -17.418978685889883`}, {
      150.6538414090221, -14.628092598095371`}, {
      150.65384140902208`, -14.200485074267556`}}], 
     PolygonBox[{{150.6538414090221, -14.628092598095371`}, {
      133.98717474235542`, -17.418978685889883`}, {
      133.98717474235545`, -17.85357848318897}, {
      150.65384140902208`, -14.993060383672503`}, {
      150.6538414090221, -14.628092598095371`}}], 
     PolygonBox[{{150.65384140902208`, -14.993060383672503`}, {
      133.98717474235545`, -17.85357848318897}, {
      133.98717474235545`, -18.211726516491808`}, {
      150.65384140902208`, -15.293825582910248`}, {
      150.65384140902208`, -14.993060383672503`}}], 
     PolygonBox[{{150.65384140902208`, -15.293825582910245`}, {
      133.98717474235542`, -18.211726516491805`}, {
      133.98717474235545`, -18.491889140935903`}, {
      150.65384140902208`, -15.529100273051146`}, {
      150.65384140902208`, -15.293825582910245`}}], 
     PolygonBox[{{150.65384140902208`, -15.529100273051146`}, {
      133.98717474235545`, -18.491889140935903`}, {
      133.98717474235545`, -18.69286665715205}, {
      150.65384140902208`, -15.697876971751997`}, {
      150.65384140902208`, -15.529100273051146`}}], 
     PolygonBox[{{150.65384140902208`, -15.697876971751995`}, {
      133.98717474235545`, -18.692866657152045`}, {
      133.98717474235545`, -18.81379844856117}, {
      150.65384140902208`, -15.79943295127789}, {
      150.65384140902208`, -15.697876971751995`}}], 
     PolygonBox[{{150.65384140902208`, -15.79943295127789}, {
      133.98717474235545`, -18.81379844856117}, {
      133.98717474235545`, -18.854166666666664`}, {
      150.65384140902208`, -15.833333333333332`}, {
      150.65384140902208`, -15.79943295127789}}], 
     PolygonBox[{{133.98717474235545`, -18.854166666666664`}, {
      100.00000000000004`, -21.874999999999996`}, {
      100.00000000000004`, -21.828163945844448`}, {
      133.98717474235545`, -18.81379844856117}, {
      133.98717474235545`, -18.854166666666664`}}], 
     PolygonBox[{{133.98717474235545`, -18.81379844856117}, {
      100.00000000000004`, -21.828163945844448`}, {
      100.00000000000004`, -21.6878563425521}, {
      133.98717474235545`, -18.69286665715205}, {
      133.98717474235545`, -18.81379844856117}}], 
     PolygonBox[{{133.98717474235545`, -18.69286665715205}, {
      100.00000000000004`, -21.6878563425521}, {
      100.00000000000004`, -21.454678008820665`}, {
      133.98717474235542`, -18.491889140935907`}, {
      133.98717474235545`, -18.69286665715205}}], 
     PolygonBox[{{133.98717474235542`, -18.491889140935907`}, {
      100.00000000000004`, -21.454678008820665`}, {
      100.00000000000004`, -21.129627450073365`}, {
      133.98717474235542`, -18.211726516491808`}, {
      133.98717474235542`, -18.491889140935907`}}], 
     PolygonBox[{{133.98717474235542`, -18.211726516491808`}, {
      100.00000000000004`, -21.129627450073365`}, {
      100.00000000000004`, -20.714096582705434`}, {
      133.98717474235548`, -17.85357848318897}, {
      133.98717474235542`, -18.211726516491808`}}], 
     PolygonBox[{{133.98717474235548`, -17.85357848318897}, {
      100.00000000000004`, -20.714096582705434`}, {
      100.00000000000004`, -20.209864773684394`}, {
      133.98717474235542`, -17.418978685889886`}, {
      133.98717474235548`, -17.85357848318897}}], 
     PolygonBox[{{133.98717474235542`, -17.418978685889886`}, {
      100.00000000000004`, -20.209864773684394`}, {
      100.00000000000004`, -19.619091221027556`}, {
      133.98717474235542`, -16.90978814764756}, {
      133.98717474235542`, -17.418978685889886`}}], 
     PolygonBox[{{133.98717474235542`, -16.90978814764756}, {
      100.00000000000004`, -19.619091221027556`}, {
      100.00000000000004`, -18.944305707784594`}, {
      133.98717474235542`, -16.328187300519104`}, {
      133.98717474235542`, -16.90978814764756}}], 
     PolygonBox[{{133.98717474235542`, -16.328187300519104`}, {
      100.00000000000004`, -18.944305707784594`}, {
      100.00000000000004`, -18.188397769118176`}, {
      133.98717474235545`, -15.676666648620904`}, {
      133.98717474235542`, -16.328187300519104`}}], 
     PolygonBox[{{133.98717474235545`, -15.676666648620904`}, {
      100.00000000000004`, -18.188397769118176`}, {
      100.00000000000004`, -17.354604318870766`}, {
      133.98717474235545`, -14.958016103407662`}, {
      133.98717474235545`, -15.676666648620904`}}], 
     PolygonBox[{{133.98717474235542`, -14.958016103407665`}, {
      100., -17.35460431887077}, {100., -16.44649578860263}, {
      133.98717474235545`, -14.175313036843217`}, {
      133.98717474235542`, -14.958016103407665`}}], 
     PolygonBox[{{133.98717474235545`, -14.175313036843217`}, {
      100., -16.44649578860263}, {
      100.00000000000004`, -15.467960838455726`}, {
      133.98717474235545`, -13.331909103621363`}, {
      133.98717474235545`, -14.175313036843217`}}], 
     PolygonBox[{{133.98717474235545`, -13.331909103621363`}, {
      100.00000000000004`, -15.467960838455726`}, {
      100., -14.423189705314005`}, {
      133.98717474235545`, -12.431415888865882`}, {
      133.98717474235545`, -13.331909103621363`}}], 
     PolygonBox[{{133.98717474235545`, -12.431415888865883`}, {
      100.00000000000004`, -14.423189705314007`}, {
      100.00000000000004`, -13.316656259565763`}, {
      133.98717474235545`, -11.477689442768586`}, {
      133.98717474235545`, -12.431415888865883`}}], 
     PolygonBox[{{133.98717474235545`, -11.477689442768586`}, {
      100.00000000000004`, -13.316656259565763`}, {
      100., -12.153098847303799`}, {
      133.98717474235545`, -10.474813768390417`}, {
      133.98717474235545`, -11.477689442768586`}}], 
     PolygonBox[{{133.98717474235545`, -10.474813768390419`}, {
      100., -12.1530988473038}, {100., -10.9375}, {
      133.98717474235545`, -9.427083333333334}, {
      133.98717474235545`, -10.474813768390419`}}], 
     PolygonBox[{{133.98717474235545`, -9.427083333333334}, {
      100., -10.9375}, {100.00000000000004`, -9.675065098540655}, {
      133.98717474235545`, -8.338984680170755}, {
      133.98717474235545`, -9.427083333333334}}], 
     PolygonBox[{{133.98717474235545`, -8.338984680170755}, {
      100.00000000000004`, -9.675065098540655}, {
      100.00000000000004`, -8.371200082986343}, {
      133.98717474235545`, -7.215177214383467}, {
      133.98717474235545`, -8.338984680170755}}], 
     PolygonBox[{{133.98717474235542`, -7.2151772143834645`}, {
      100.00000000000004`, -8.37120008298634}, {
      100.00000000000004`, -7.031488303506661}, {
      133.98717474235545`, -6.060473252070027}, {
      133.98717474235542`, -7.2151772143834645`}}], 
     PolygonBox[{{133.98717474235545`, -6.060473252070027}, {
      100.00000000000004`, -7.031488303506661}, {
      100.00000000000007`, -5.661666611617646}, {
      133.98717474235545`, -4.879817412870447}, {
      133.98717474235545`, -6.060473252070027}}], 
     PolygonBox[{{133.98717474235545`, -4.879817412870447}, {
      100.00000000000007`, -5.661666611617646}, {100., -4.267600794102811}, {
      133.98717474235542`, -3.6782654463457565`}, {
      133.98717474235545`, -4.879817412870447}}], 
     PolygonBox[{{133.98717474235542`, -3.678265446345753}, {
      100., -4.2676007941028065`}, {
      100.00000000000004`, -2.8552604548136307`}, {
      133.98717474235545`, -2.4609625824822245`}, {
      133.98717474235542`, -3.678265446345753}}], 
     PolygonBox[{{133.98717474235545`, -2.4609625824822245`}, {
      100.00000000000004`, -2.8552604548136307`}, {
      100.00000000000004`, -1.4306934519093837`}, {
      133.98717474235545`, -1.2331214990266595`}, {
      133.98717474235545`, -2.4609625824822245`}}], 
     PolygonBox[{{133.98717474235545`, -1.2331214990266595`}, {
      100.00000000000004`, -1.4306934519093837`}, {
      100.00000000000004`, -6.196683169302477*^-15}, {
      133.98717474235545`, -5.3409507316368974`*^-15}, {
      133.98717474235545`, -1.2331214990266595`}}], 
     PolygonBox[{{133.98717474235545`, -1.1544847429462027`*^-15}, {
      100.00000000000004`, -1.3394574365674175`*^-15}, {100.00000000000004`, 
      1.4306934519093761`}, {133.98717474235545`, 1.233121499026653}, {
      133.98717474235545`, -1.1544847429462027`*^-15}}], 
     PolygonBox[{{133.98717474235545`, 1.233121499026653}, {
      100.00000000000004`, 1.4306934519093761`}, {100.00000000000004`, 
      2.8552604548136236`}, {133.98717474235545`, 2.4609625824822188`}, {
      133.98717474235545`, 1.233121499026653}}], 
     PolygonBox[{{133.98717474235545`, 2.4609625824822188`}, {
      100.00000000000004`, 2.8552604548136236`}, {100.00000000000004`, 
      4.267600794102799}, {133.98717474235545`, 3.678265446345746}, {
      133.98717474235545`, 2.4609625824822188`}}], 
     PolygonBox[{{133.98717474235545`, 3.678265446345746}, {
      100.00000000000004`, 4.267600794102799}, {100.00000000000004`, 
      5.661666611617632}, {133.98717474235545`, 4.879817412870437}, {
      133.98717474235545`, 3.678265446345746}}], 
     PolygonBox[{{133.98717474235545`, 4.879817412870441}, {
      100.00000000000004`, 5.661666611617638}, {100.00000000000004`, 
      7.031488303506654}, {133.98717474235548`, 6.060473252070021}, {
      133.98717474235545`, 4.879817412870441}}], 
     PolygonBox[{{133.98717474235548`, 6.060473252070021}, {
      100.00000000000004`, 7.031488303506654}, {100.00000000000007`, 
      8.37120008298633}, {133.98717474235545`, 7.215177214383457}, {
      133.98717474235548`, 6.060473252070021}}], 
     PolygonBox[{{133.98717474235545`, 7.215177214383457}, {
      100.00000000000007`, 8.37120008298633}, {100.00000000000004`, 
      9.675065098540648}, {133.98717474235545`, 8.33898468017075}, {
      133.98717474235545`, 7.215177214383457}}], 
     PolygonBox[{{133.98717474235545`, 8.33898468017075}, {
      100.00000000000004`, 9.675065098540648}, {100.00000000000004`, 
      10.937499999999993`}, {133.98717474235545`, 9.427083333333329}, {
      133.98717474235545`, 8.33898468017075}}], 
     PolygonBox[{{133.98717474235545`, 9.427083333333329}, {
      100.00000000000004`, 10.937499999999993`}, {100.00000000000004`, 
      12.153098847303792`}, {133.98717474235542`, 10.474813768390412`}, {
      133.98717474235545`, 9.427083333333329}}], 
     PolygonBox[{{133.98717474235542`, 10.474813768390412`}, {
      100.00000000000004`, 12.153098847303792`}, {100., 
      13.316656259565756`}, {133.98717474235542`, 11.47768944276858}, {
      133.98717474235542`, 10.474813768390412`}}], 
     PolygonBox[{{133.98717474235542`, 11.47768944276858}, {100., 
      13.316656259565756`}, {100.00000000000004`, 14.423189705313996`}, {
      133.98717474235545`, 12.431415888865875`}, {133.98717474235542`, 
      11.47768944276858}}], 
     PolygonBox[{{133.98717474235545`, 12.431415888865875`}, {
      100.00000000000004`, 14.423189705313996`}, {100.00000000000004`, 
      15.467960838455717`}, {133.98717474235542`, 13.331909103621356`}, {
      133.98717474235545`, 12.431415888865875`}}], 
     PolygonBox[{{133.98717474235545`, 13.331909103621363`}, {
      100.00000000000004`, 15.467960838455724`}, {100.00000000000004`, 
      16.446495788602626`}, {133.98717474235545`, 14.175313036843216`}, {
      133.98717474235545`, 13.331909103621363`}}], 
     PolygonBox[{{133.98717474235545`, 14.175313036843216`}, {
      100.00000000000004`, 16.446495788602626`}, {100.00000000000004`, 
      17.354604318870763`}, {133.98717474235545`, 14.95801610340766}, {
      133.98717474235545`, 14.175313036843216`}}], 
     PolygonBox[{{133.98717474235545`, 14.95801610340766}, {
      100.00000000000004`, 17.354604318870763`}, {100.00000000000004`, 
      18.18839776911817}, {133.98717474235545`, 15.6766666486209}, {
      133.98717474235545`, 14.95801610340766}}], 
     PolygonBox[{{133.98717474235545`, 15.6766666486209}, {
      100.00000000000004`, 18.18839776911817}, {100.00000000000004`, 
      18.94430570778459}, {133.98717474235545`, 16.328187300519097`}, {
      133.98717474235545`, 15.6766666486209}}], 
     PolygonBox[{{133.98717474235545`, 16.328187300519097`}, {
      100.00000000000004`, 18.94430570778459}, {100., 19.619091221027553`}, {
      133.98717474235542`, 16.909788147647557`}, {133.98717474235545`, 
      16.328187300519097`}}], 
     PolygonBox[{{133.98717474235542`, 16.909788147647557`}, {100., 
      19.619091221027553`}, {100.00000000000004`, 20.20986477368439}, {
      133.98717474235542`, 17.418978685889883`}, {133.98717474235542`, 
      16.909788147647557`}}], 
     PolygonBox[{{133.98717474235542`, 17.418978685889886`}, {
      100.00000000000004`, 20.209864773684394`}, {100.00000000000004`, 
      20.71409658270543}, {133.98717474235545`, 17.85357848318897}, {
      133.98717474235542`, 17.418978685889886`}}], 
     PolygonBox[{{133.98717474235545`, 17.85357848318897}, {
      100.00000000000004`, 20.71409658270543}, {100.00000000000004`, 
      21.12962745007336}, {133.98717474235545`, 18.211726516491805`}, {
      133.98717474235545`, 17.85357848318897}}], 
     PolygonBox[{{133.98717474235545`, 18.211726516491805`}, {
      100.00000000000004`, 21.12962745007336}, {100., 21.454678008820665`}, {
      133.98717474235542`, 18.491889140935907`}, {133.98717474235545`, 
      18.211726516491805`}}], 
     PolygonBox[{{133.98717474235542`, 18.491889140935907`}, {100., 
      21.454678008820665`}, {100.00000000000004`, 21.6878563425521}, {
      133.98717474235545`, 18.69286665715205}, {133.98717474235542`, 
      18.491889140935907`}}], 
     PolygonBox[{{133.98717474235545`, 18.69286665715205}, {
      100.00000000000004`, 21.6878563425521}, {100.00000000000004`, 
      21.828163945844448`}, {133.98717474235545`, 18.81379844856117}, {
      133.98717474235545`, 18.69286665715205}}], 
     PolygonBox[{{133.98717474235545`, 18.81379844856117}, {
      100.00000000000004`, 21.828163945844448`}, {100.00000000000004`, 
      21.874999999999996`}, {133.98717474235545`, 18.854166666666664`}, {
      133.98717474235545`, 18.81379844856117}}], 
     PolygonBox[{{133.98717474235545`, 18.854166666666664`}, {
      100.00000000000004`, 21.874999999999996`}, {100.00000000000004`, 
      21.828163945844448`}, {133.98717474235545`, 18.81379844856117}, {
      133.98717474235545`, 18.854166666666664`}}], 
     PolygonBox[{{133.98717474235545`, 18.81379844856117}, {
      100.00000000000004`, 21.828163945844448`}, {100.00000000000004`, 
      21.6878563425521}, {133.98717474235545`, 18.69286665715205}, {
      133.98717474235545`, 18.81379844856117}}], 
     PolygonBox[{{133.98717474235545`, 18.69286665715205}, {
      100.00000000000004`, 21.6878563425521}, {100.00000000000004`, 
      21.454678008820665`}, {133.98717474235545`, 18.491889140935907`}, {
      133.98717474235545`, 18.69286665715205}}], 
     PolygonBox[{{133.98717474235545`, 18.491889140935907`}, {
      100.00000000000004`, 21.454678008820665`}, {100.00000000000004`, 
      21.129627450073368`}, {133.98717474235545`, 18.211726516491808`}, {
      133.98717474235545`, 18.491889140935907`}}], 
     PolygonBox[{{133.98717474235545`, 18.211726516491808`}, {
      100.00000000000004`, 21.129627450073368`}, {100.00000000000007`, 
      20.714096582705434`}, {133.98717474235545`, 17.853578483188972`}, {
      133.98717474235545`, 18.211726516491808`}}], 
     PolygonBox[{{133.98717474235545`, 17.853578483188972`}, {
      100.00000000000007`, 20.714096582705434`}, {100.00000000000004`, 
      20.2098647736844}, {133.98717474235542`, 17.41897868588989}, {
      133.98717474235545`, 17.853578483188972`}}], 
     PolygonBox[{{133.98717474235542`, 17.41897868588989}, {
      100.00000000000004`, 20.2098647736844}, {100.00000000000004`, 
      19.61909122102756}, {133.98717474235542`, 16.909788147647568`}, {
      133.98717474235542`, 17.41897868588989}}], 
     PolygonBox[{{133.98717474235545`, 16.90978814764756}, {
      100.00000000000004`, 19.619091221027556`}, {100.00000000000004`, 
      18.944305707784597`}, {133.98717474235542`, 16.328187300519108`}, {
      133.98717474235545`, 16.90978814764756}}], 
     PolygonBox[{{133.98717474235542`, 16.328187300519108`}, {
      100.00000000000004`, 18.944305707784597`}, {100.00000000000004`, 
      18.18839776911818}, {133.98717474235542`, 15.676666648620909`}, {
      133.98717474235542`, 16.328187300519108`}}], 
     PolygonBox[{{133.98717474235542`, 15.676666648620909`}, {
      100.00000000000004`, 18.18839776911818}, {100., 17.354604318870773`}, {
      133.98717474235542`, 14.958016103407667`}, {133.98717474235542`, 
      15.676666648620909`}}], 
     PolygonBox[{{133.98717474235542`, 14.958016103407667`}, {100., 
      17.354604318870773`}, {100.00000000000004`, 16.446495788602636`}, {
      133.98717474235545`, 14.175313036843225`}, {133.98717474235542`, 
      14.958016103407667`}}], 
     PolygonBox[{{133.98717474235545`, 14.175313036843225`}, {
      100.00000000000004`, 16.446495788602636`}, {100.00000000000004`, 
      15.467960838455735`}, {133.98717474235542`, 13.331909103621372`}, {
      133.98717474235545`, 14.175313036843225`}}], 
     PolygonBox[{{133.98717474235542`, 13.331909103621372`}, {
      100.00000000000004`, 15.467960838455735`}, {100.00000000000004`, 
      14.423189705314016`}, {133.98717474235545`, 12.43141588886589}, {
      133.98717474235542`, 13.331909103621372`}}], 
     PolygonBox[{{133.98717474235542`, 12.431415888865885`}, {
      100.00000000000004`, 14.423189705314009`}, {100.00000000000004`, 
      13.316656259565766`}, {133.98717474235545`, 11.47768944276859}, {
      133.98717474235542`, 12.431415888865885`}}], 
     PolygonBox[{{133.98717474235545`, 11.47768944276859}, {
      100.00000000000004`, 13.316656259565766`}, {100.00000000000004`, 
      12.153098847303797`}, {133.98717474235545`, 10.474813768390415`}, {
      133.98717474235545`, 11.47768944276859}}], 
     PolygonBox[{{133.98717474235545`, 10.47481376839043}, {
      100.00000000000004`, 12.153098847303813`}, {100.00000000000004`, 
      10.937500000000009`}, {133.98717474235542`, 9.427083333333343}, {
      133.98717474235545`, 10.47481376839043}}], 
     PolygonBox[{{133.98717474235542`, 9.427083333333343}, {
      100.00000000000004`, 10.937500000000009`}, {100.00000000000004`, 
      9.675065098540653}, {133.98717474235545`, 8.338984680170753}, {
      133.98717474235542`, 9.427083333333343}}], 
     PolygonBox[{{133.98717474235545`, 8.338984680170753}, {
      100.00000000000004`, 9.675065098540653}, {100.00000000000007`, 
      8.37120008298633}, {133.98717474235545`, 7.215177214383457}, {
      133.98717474235545`, 8.338984680170753}}], 
     PolygonBox[{{133.98717474235542`, 7.215177214383473}, {100., 
      8.37120008298635}, {100.00000000000004`, 7.031488303506664}, {
      133.98717474235545`, 6.06047325207003}, {133.98717474235542`, 
      7.215177214383473}}], 
     PolygonBox[{{133.98717474235545`, 6.06047325207003}, {
      100.00000000000004`, 7.031488303506664}, {100.00000000000004`, 
      5.661666611617638}, {133.98717474235545`, 4.879817412870441}, {
      133.98717474235545`, 6.06047325207003}}], 
     PolygonBox[{{133.98717474235542`, 4.879817412870457}, {
      100.00000000000004`, 5.661666611617657}, {100.00000000000007`, 
      4.267600794102814}, {133.98717474235545`, 3.6782654463457587`}, {
      133.98717474235542`, 4.879817412870457}}], 
     PolygonBox[{{133.98717474235545`, 3.6782654463457587`}, {
      100.00000000000007`, 4.267600794102814}, {100.00000000000004`, 
      2.855260454813629}, {133.98717474235545`, 2.460962582482223}, {
      133.98717474235545`, 3.6782654463457587`}}], 
     PolygonBox[{{133.98717474235545`, 2.4609625824822396`}, {
      100.00000000000004`, 2.8552604548136475`}, {100.00000000000004`, 
      1.4306934519093915`}, {133.98717474235545`, 1.2331214990266661`}, {
      133.98717474235545`, 2.4609625824822396`}}], 
     PolygonBox[{{133.98717474235545`, 1.2331214990266661`}, {
      100.00000000000004`, 1.4306934519093915`}, {100.00000000000004`, 
      4.018372309702252*^-15}, {133.98717474235545`, 
      3.4634542288386077`*^-15}, {133.98717474235545`, 1.2331214990266661`}}],
      PolygonBox[{{133.98717474235545`, 3.4634542288386077`*^-15}, {
      100.00000000000004`, 4.018372309702252*^-15}, {
      100.00000000000004`, -1.4306934519093835`}, {
      133.98717474235545`, -1.2331214990266592`}, {133.98717474235545`, 
      3.4634542288386077`*^-15}}], 
     PolygonBox[{{133.98717474235545`, -1.2331214990266426`}, {
      100.00000000000004`, -1.4306934519093641`}, {
      100.00000000000004`, -2.855260454813621}, {
      133.98717474235545`, -2.4609625824822166`}, {
      133.98717474235545`, -1.2331214990266426`}}], 
     PolygonBox[{{133.98717474235545`, -2.4609625824822166`}, {
      100.00000000000004`, -2.855260454813621}, {
      100., -4.2676007941028065`}, {
      133.98717474235542`, -3.6782654463457525`}, {
      133.98717474235545`, -2.4609625824822166`}}], 
     PolygonBox[{{133.98717474235542`, -3.678265446345735}, {
      100., -4.267600794102787}, {100.00000000000004`, -5.661666611617631}, {
      133.98717474235545`, -4.879817412870434}, {
      133.98717474235542`, -3.678265446345735}}], 
     PolygonBox[{{133.98717474235545`, -4.879817412870434}, {
      100.00000000000004`, -5.661666611617631}, {
      100.00000000000004`, -7.031488303506656}, {
      133.98717474235548`, -6.0604732520700235`}, {
      133.98717474235545`, -4.879817412870434}}], 
     PolygonBox[{{133.98717474235548`, -6.0604732520700235`}, {
      100.00000000000004`, -7.031488303506656}, {
      100.00000000000004`, -8.371200082986343}, {
      133.98717474235545`, -7.215177214383467}, {
      133.98717474235548`, -6.0604732520700235`}}], 
     PolygonBox[{{133.98717474235545`, -7.215177214383452}, {
      100.00000000000004`, -8.371200082986325}, {
      100.00000000000004`, -9.675065098540646}, {
      133.98717474235545`, -8.338984680170748}, {
      133.98717474235545`, -7.215177214383452}}], 
     PolygonBox[{{133.98717474235545`, -8.338984680170748}, {
      100.00000000000004`, -9.675065098540646}, {100., -10.9375}, {
      133.98717474235545`, -9.427083333333334}, {
      133.98717474235545`, -8.338984680170748}}], 
     PolygonBox[{{133.98717474235545`, -9.42708333333332}, {
      100.00000000000004`, -10.937499999999984`}, {
      100.00000000000004`, -12.153098847303788`}, {
      133.98717474235545`, -10.474813768390408`}, {
      133.98717474235545`, -9.42708333333332}}], 
     PolygonBox[{{133.98717474235545`, -10.474813768390408`}, {
      100.00000000000004`, -12.153098847303788`}, {
      100.00000000000004`, -13.316656259565761`}, {
      133.98717474235545`, -11.477689442768586`}, {
      133.98717474235545`, -10.474813768390408`}}], 
     PolygonBox[{{133.98717474235545`, -11.477689442768572`}, {
      100.00000000000004`, -13.316656259565745`}, {
      100., -14.423189705313995`}, {
      133.98717474235545`, -12.431415888865873`}, {
      133.98717474235545`, -11.477689442768572`}}], 
     PolygonBox[{{133.98717474235545`, -12.431415888865873`}, {
      100., -14.423189705313995`}, {
      100.00000000000004`, -15.46796083845572}, {
      133.98717474235545`, -13.33190910362136}, {
      133.98717474235545`, -12.431415888865873`}}], 
     PolygonBox[{{133.98717474235545`, -13.33190910362136}, {
      100.00000000000004`, -15.46796083845572}, {
      100.00000000000004`, -16.44649578860263}, {
      133.98717474235545`, -14.175313036843221`}, {
      133.98717474235545`, -13.33190910362136}}], 
     PolygonBox[{{133.98717474235545`, -14.17531303684321}, {
      100.00000000000004`, -16.44649578860262}, {
      100.00000000000004`, -17.354604318870763`}, {
      133.98717474235545`, -14.958016103407658`}, {
      133.98717474235545`, -14.17531303684321}}], 
     PolygonBox[{{133.98717474235545`, -14.958016103407658`}, {
      100.00000000000004`, -17.354604318870763`}, {
      100.00000000000004`, -18.188397769118176`}, {
      133.98717474235545`, -15.676666648620904`}, {
      133.98717474235545`, -14.958016103407658`}}], 
     PolygonBox[{{133.98717474235545`, -15.676666648620895`}, {
      100.00000000000004`, -18.188397769118165`}, {
      100.00000000000004`, -18.944305707784586`}, {
      133.98717474235542`, -16.328187300519097`}, {
      133.98717474235545`, -15.676666648620895`}}], 
     PolygonBox[{{133.98717474235542`, -16.328187300519097`}, {
      100.00000000000004`, -18.944305707784586`}, {
      100.00000000000004`, -19.619091221027553`}, {
      133.98717474235545`, -16.909788147647557`}, {
      133.98717474235542`, -16.328187300519097`}}], 
     PolygonBox[{{133.98717474235545`, -16.90978814764755}, {
      100.00000000000004`, -19.619091221027542`}, {
      100., -20.20986477368439}, {
      133.98717474235542`, -17.418978685889883`}, {
      133.98717474235545`, -16.90978814764755}}], 
     PolygonBox[{{133.98717474235542`, -17.418978685889883`}, {
      100., -20.20986477368439}, {100.00000000000004`, -20.71409658270543}, {
      133.98717474235545`, -17.85357848318897}, {
      133.98717474235542`, -17.418978685889883`}}], 
     PolygonBox[{{133.98717474235545`, -17.85357848318897}, {
      100.00000000000004`, -20.71409658270543}, {
      100.00000000000004`, -21.129627450073365`}, {
      133.98717474235545`, -18.211726516491808`}, {
      133.98717474235545`, -17.85357848318897}}], 
     PolygonBox[{{133.98717474235542`, -18.211726516491805`}, {
      100.00000000000004`, -21.12962745007336}, {
      100.00000000000007`, -21.454678008820657`}, {
      133.98717474235545`, -18.491889140935903`}, {
      133.98717474235542`, -18.211726516491805`}}], 
     PolygonBox[{{133.98717474235545`, -18.491889140935903`}, {
      100.00000000000007`, -21.454678008820657`}, {
      100.00000000000004`, -21.6878563425521}, {
      133.98717474235545`, -18.69286665715205}, {
      133.98717474235545`, -18.491889140935903`}}], 
     PolygonBox[{{133.98717474235545`, -18.692866657152045`}, {
      100.00000000000004`, -21.687856342552095`}, {
      100.00000000000004`, -21.828163945844448`}, {
      133.98717474235545`, -18.81379844856117}, {
      133.98717474235545`, -18.692866657152045`}}], 
     PolygonBox[{{133.98717474235545`, -18.81379844856117}, {
      100.00000000000004`, -21.828163945844448`}, {
      100.00000000000004`, -21.874999999999996`}, {
      133.98717474235545`, -18.854166666666664`}, {
      133.98717474235545`, -18.81379844856117}}], 
     PolygonBox[{{100., -21.875}, {66.01282525764451, -24.895833333333336`}, {
      66.01282525764451, -24.842529443127734`}, {100., -21.82816394584445}, {
      100., -21.875}}], 
     PolygonBox[{{100., -21.82816394584445}, {
      66.01282525764451, -24.842529443127734`}, {
      66.01282525764455, -24.682846027952156`}, {
      100., -21.687856342552102`}, {100., -21.82816394584445}}], 
     PolygonBox[{{100., -21.687856342552102`}, {
      66.01282525764455, -24.682846027952156`}, {
      66.01282525764451, -24.41746687670543}, {
      99.99999999999994, -21.454678008820668`}, {
      100., -21.687856342552102`}}], 
     PolygonBox[{{99.99999999999994, -21.454678008820668`}, {
      66.01282525764451, -24.41746687670543}, {
      66.01282525764451, -24.047528383654935`}, {
      99.99999999999994, -21.12962745007337}, {
      99.99999999999994, -21.454678008820668`}}], 
     PolygonBox[{{99.99999999999994, -21.12962745007337}, {
      66.01282525764451, -24.047528383654935`}, {
      66.01282525764455, -23.574614682221902`}, {
      100., -20.714096582705437`}, {99.99999999999994, -21.12962745007337}}], 
     PolygonBox[{{100., -20.714096582705437`}, {
      66.01282525764455, -23.574614682221902`}, {
      66.01282525764451, -23.000750861478913`}, {
      100., -20.209864773684398`}, {100., -20.714096582705437`}}], 
     PolygonBox[{{100., -20.209864773684398`}, {
      66.01282525764451, -23.000750861478913`}, {
      66.01282525764451, -22.32839429440756}, {100., -19.61909122102756}, {
      100., -20.209864773684398`}}], 
     PolygonBox[{{100., -19.61909122102756}, {
      66.01282525764451, -22.32839429440756}, {
      66.01282525764451, -21.56042411505009}, {100., -18.944305707784597`}, {
      100., -19.61909122102756}}], 
     PolygonBox[{{100., -18.944305707784597`}, {
      66.01282525764451, -21.56042411505009}, {
      66.01282525764455, -20.70012888961545}, {
      99.99999999999994, -18.18839776911818}, {100., -18.944305707784597`}}], 
     PolygonBox[{{99.99999999999994, -18.18839776911818}, {
      66.01282525764455, -20.70012888961545}, {
      66.01282525764455, -19.751192534333875`}, {100., -17.35460431887077}, {
      99.99999999999994, -18.18839776911818}}], 
     PolygonBox[{{99.99999999999994, -17.354604318870773`}, {
      66.01282525764455, -19.751192534333878`}, {
      66.01282525764455, -18.71767854036204}, {100., -16.44649578860263}, {
      99.99999999999994, -17.354604318870773`}}], 
     PolygonBox[{{100., -16.44649578860263}, {
      66.01282525764455, -18.71767854036204}, {
      66.01282525764451, -17.604012573290092`}, {
      100., -15.467960838455728`}, {100., -16.44649578860263}}], 
     PolygonBox[{{100., -15.467960838455728`}, {
      66.01282525764451, -17.604012573290092`}, {
      66.01282525764455, -16.414963521762132`}, {
      100., -14.423189705314007`}, {100., -15.467960838455728`}}], 
     PolygonBox[{{100., -14.423189705314009`}, {
      66.01282525764455, -16.414963521762132`}, {
      66.01282525764455, -15.155623076362943`}, {
      100., -13.316656259565764`}, {100., -14.423189705314009`}}], 
     PolygonBox[{{100., -13.316656259565764`}, {
      66.01282525764455, -15.155623076362943`}, {
      66.01282525764451, -13.831383926217184`}, {
      99.99999999999994, -12.1530988473038}, {100., -13.316656259565764`}}], 
     PolygonBox[{{100., -12.153098847303802`}, {
      66.01282525764451, -13.831383926217185`}, {
      66.01282525764451, -12.44791666666667}, {100., -10.937500000000002`}, {
      100., -12.153098847303802`}}], 
     PolygonBox[{{100., -10.937500000000002`}, {
      66.01282525764451, -12.44791666666667}, {
      66.01282525764451, -11.011145516910558`}, {100., -9.675065098540657}, {
      100., -10.937500000000002`}}], 
     PolygonBox[{{100., -9.675065098540657}, {
      66.01282525764451, -11.011145516910558`}, {
      66.01282525764455, -9.52722295158922}, {100., -8.371200082986345}, {
      100., -9.675065098540657}}], 
     PolygonBox[{{100., -8.37120008298634}, {
      66.01282525764451, -9.527222951589216}, {
      66.01282525764455, -8.002503354943297}, {100., -7.031488303506662}, {
      100., -8.37120008298634}}], 
     PolygonBox[{{100., -7.031488303506662}, {
      66.01282525764455, -8.002503354943297}, {
      66.01282525764455, -6.443515810364846}, {
      100.00000000000004`, -5.661666611617647}, {100., -7.031488303506662}}], 
     PolygonBox[{{100.00000000000004`, -5.661666611617647}, {
      66.01282525764455, -6.443515810364846}, {
      66.0128252576445, -4.856936141859866}, {
      99.99999999999994, -4.267600794102812}, {
      100.00000000000004`, -5.661666611617647}}], 
     PolygonBox[{{99.99999999999994, -4.267600794102807}, {
      66.01282525764451, -4.856936141859862}, {
      66.01282525764455, -3.2495583271450377`}, {100., -2.855260454813631}, {
      99.99999999999994, -4.267600794102807}}], 
     PolygonBox[{{100., -2.855260454813631}, {
      66.01282525764455, -3.2495583271450377`}, {
      66.01282525764451, -1.6282654047921084`}, {100., -1.430693451909384}, {
      100., -2.855260454813631}}], 
     PolygonBox[{{100., -1.430693451909384}, {
      66.01282525764451, -1.6282654047921084`}, {
      66.01282525764451, -7.0524156069680584`*^-15}, {
      100., -6.196683169302477*^-15}, {100., -1.430693451909384}}], 
     PolygonBox[{{100., -1.3394574365674177`*^-15}, {
      66.01282525764451, -1.5244301301886326`*^-15}, {66.01282525764451, 
      1.6282654047921}, {100., 1.4306934519093764`}, {
      100., -1.3394574365674177`*^-15}}], 
     PolygonBox[{{100., 1.4306934519093764`}, {66.01282525764451, 
      1.6282654047921}, {66.01282525764455, 3.2495583271450292`}, {100., 
      2.855260454813624}, {100., 1.4306934519093764`}}], 
     PolygonBox[{{100., 2.855260454813624}, {66.01282525764455, 
      3.2495583271450292`}, {66.01282525764451, 4.856936141859853}, {100., 
      4.267600794102799}, {100., 2.855260454813624}}], 
     PolygonBox[{{100., 4.267600794102799}, {66.01282525764451, 
      4.856936141859853}, {66.01282525764451, 6.443515810364831}, {100., 
      5.661666611617633}, {100., 4.267600794102799}}], 
     PolygonBox[{{99.99999999999994, 5.661666611617639}, {66.01282525764451, 
      6.443515810364837}, {66.01282525764455, 8.00250335494329}, {100., 
      7.031488303506655}, {99.99999999999994, 5.661666611617639}}], 
     PolygonBox[{{100., 7.031488303506655}, {66.01282525764455, 
      8.00250335494329}, {66.01282525764451, 9.527222951589208}, {
      100.00000000000004`, 8.371200082986332}, {100., 7.031488303506655}}], 
     PolygonBox[{{100.00000000000004`, 8.371200082986332}, {66.01282525764451,
       9.527222951589208}, {66.01282525764451, 11.011145516910549`}, {100., 
      9.67506509854065}, {100.00000000000004`, 8.371200082986332}}], 
     PolygonBox[{{100., 9.67506509854065}, {66.01282525764451, 
      11.011145516910549`}, {66.01282525764455, 12.44791666666666}, {100., 
      10.937499999999996`}, {100., 9.67506509854065}}], 
     PolygonBox[{{100., 10.937499999999996`}, {66.01282525764455, 
      12.44791666666666}, {66.01282525764451, 13.831383926217175`}, {100., 
      12.153098847303792`}, {100., 10.937499999999996`}}], 
     PolygonBox[{{100., 12.153098847303792`}, {66.01282525764451, 
      13.831383926217175`}, {66.01282525764451, 15.155623076362934`}, {100., 
      13.316656259565757`}, {100., 12.153098847303792`}}], 
     PolygonBox[{{100., 13.316656259565757`}, {66.01282525764451, 
      15.155623076362934`}, {66.01282525764451, 16.41496352176212}, {100., 
      14.423189705313998`}, {100., 13.316656259565757`}}], 
     PolygonBox[{{100., 14.423189705313998`}, {66.01282525764451, 
      16.41496352176212}, {66.01282525764455, 17.60401257329008}, {100., 
      15.467960838455719`}, {100., 14.423189705313998`}}], 
     PolygonBox[{{100., 15.467960838455726`}, {66.01282525764451, 
      17.60401257329009}, {66.01282525764455, 18.71767854036204}, {100., 
      16.44649578860263}, {100., 15.467960838455726`}}], 
     PolygonBox[{{100., 16.44649578860263}, {66.01282525764455, 
      18.71767854036204}, {66.01282525764451, 19.751192534333875`}, {100., 
      17.354604318870766`}, {100., 16.44649578860263}}], 
     PolygonBox[{{100., 17.354604318870766`}, {66.01282525764451, 
      19.751192534333875`}, {66.01282525764451, 20.700128889615446`}, {100., 
      18.188397769118172`}, {100., 17.354604318870766`}}], 
     PolygonBox[{{100., 18.188397769118172`}, {66.01282525764451, 
      20.700128889615446`}, {66.01282525764455, 21.560424115050083`}, {100., 
      18.94430570778459}, {100., 18.188397769118172`}}], 
     PolygonBox[{{100., 18.94430570778459}, {66.01282525764455, 
      21.560424115050083`}, {66.01282525764451, 22.328394294407552`}, {100., 
      19.619091221027553`}, {100., 18.94430570778459}}], 
     PolygonBox[{{100., 19.619091221027553`}, {66.01282525764451, 
      22.328394294407552`}, {66.01282525764451, 23.000750861478906`}, {100., 
      20.209864773684394`}, {100., 19.619091221027553`}}], 
     PolygonBox[{{100., 20.209864773684398`}, {66.01282525764451, 
      23.000750861478913`}, {66.01282525764455, 23.5746146822219}, {100., 
      20.714096582705434`}, {100., 20.209864773684398`}}], 
     PolygonBox[{{100., 20.714096582705434`}, {66.01282525764455, 
      23.5746146822219}, {66.01282525764455, 24.047528383654925`}, {
      100.00000000000004`, 21.129627450073365`}, {100., 
      20.714096582705434`}}], 
     PolygonBox[{{100.00000000000004`, 21.129627450073365`}, {
      66.01282525764455, 24.047528383654925`}, {66.0128252576445, 
      24.41746687670543}, {99.99999999999994, 21.454678008820668`}, {
      100.00000000000004`, 21.129627450073365`}}], 
     PolygonBox[{{99.99999999999994, 21.454678008820668`}, {66.0128252576445, 
      24.41746687670543}, {66.01282525764451, 24.682846027952156`}, {100., 
      21.687856342552102`}, {99.99999999999994, 21.454678008820668`}}], 
     PolygonBox[{{100., 21.687856342552102`}, {66.01282525764451, 
      24.682846027952156`}, {66.01282525764451, 24.842529443127734`}, {100., 
      21.82816394584445}, {100., 21.687856342552102`}}], 
     PolygonBox[{{100., 21.82816394584445}, {66.01282525764451, 
      24.842529443127734`}, {66.01282525764451, 24.895833333333336`}, {100., 
      21.875}, {100., 21.82816394584445}}], 
     PolygonBox[{{100., 21.875}, {66.01282525764451, 24.895833333333336`}, {
      66.01282525764451, 24.842529443127734`}, {100., 21.82816394584445}, {
      100., 21.875}}], 
     PolygonBox[{{100., 21.82816394584445}, {66.01282525764451, 
      24.842529443127734`}, {66.01282525764455, 24.682846027952156`}, {100., 
      21.687856342552102`}, {100., 21.82816394584445}}], 
     PolygonBox[{{100., 21.687856342552102`}, {66.01282525764455, 
      24.682846027952156`}, {66.01282525764451, 24.41746687670543}, {100., 
      21.454678008820668`}, {100., 21.687856342552102`}}], 
     PolygonBox[{{100., 21.454678008820668`}, {66.01282525764451, 
      24.41746687670543}, {66.01282525764451, 24.047528383654935`}, {100., 
      21.12962745007337}, {100., 21.454678008820668`}}], 
     PolygonBox[{{100., 21.12962745007337}, {66.01282525764451, 
      24.047528383654935`}, {66.01282525764455, 23.574614682221902`}, {
      100.00000000000004`, 20.714096582705437`}, {100., 21.12962745007337}}], 
     PolygonBox[{{100.00000000000004`, 20.714096582705437`}, {
      66.01282525764455, 23.574614682221902`}, {66.01282525764451, 
      23.00075086147892}, {100., 20.2098647736844}, {100.00000000000004`, 
      20.714096582705437`}}], 
     PolygonBox[{{100., 20.2098647736844}, {66.01282525764451, 
      23.00075086147892}, {66.01282525764451, 22.328394294407563`}, {100., 
      19.619091221027563`}, {100., 20.2098647736844}}], 
     PolygonBox[{{100., 19.61909122102756}, {66.01282525764451, 
      22.32839429440756}, {66.01282525764451, 21.560424115050093`}, {100., 
      18.9443057077846}, {100., 19.61909122102756}}], 
     PolygonBox[{{100., 18.9443057077846}, {66.01282525764451, 
      21.560424115050093`}, {66.01282525764451, 20.700128889615456`}, {100., 
      18.188397769118183`}, {100., 18.9443057077846}}], 
     PolygonBox[{{100., 18.188397769118183`}, {66.01282525764451, 
      20.700128889615456`}, {66.01282525764451, 19.75119253433388}, {100., 
      17.354604318870773`}, {100., 18.188397769118183`}}], 
     PolygonBox[{{100., 17.354604318870773`}, {66.01282525764451, 
      19.75119253433388}, {66.01282525764451, 18.71767854036205}, {100., 
      16.44649578860264}, {100., 17.354604318870773`}}], 
     PolygonBox[{{100., 16.44649578860264}, {66.01282525764451, 
      18.71767854036205}, {66.01282525764455, 17.6040125732901}, {100., 
      15.467960838455737`}, {100., 16.44649578860264}}], 
     PolygonBox[{{100., 15.467960838455737`}, {66.01282525764455, 
      17.6040125732901}, {66.01282525764451, 16.414963521762147`}, {100., 
      14.423189705314018`}, {100., 15.467960838455737`}}], 
     PolygonBox[{{99.99999999999994, 14.42318970531401}, {66.01282525764451, 
      16.414963521762136`}, {66.01282525764455, 15.155623076362946`}, {
      100.00000000000004`, 13.316656259565768`}, {99.99999999999994, 
      14.42318970531401}}], 
     PolygonBox[{{100.00000000000004`, 13.316656259565768`}, {
      66.01282525764455, 15.155623076362946`}, {66.01282525764455, 
      13.831383926217182`}, {99.99999999999994, 12.153098847303799`}, {
      100.00000000000004`, 13.316656259565768`}}], 
     PolygonBox[{{100., 12.153098847303813`}, {66.01282525764451, 
      13.8313839262172}, {66.01282525764451, 12.44791666666668}, {100., 
      10.93750000000001}, {100., 12.153098847303813`}}], 
     PolygonBox[{{100., 10.93750000000001}, {66.01282525764451, 
      12.44791666666668}, {66.01282525764451, 11.011145516910556`}, {100., 
      9.675065098540655}, {100., 10.93750000000001}}], 
     PolygonBox[{{100., 9.675065098540655}, {66.01282525764451, 
      11.011145516910556`}, {66.01282525764451, 9.527222951589208}, {
      100.00000000000004`, 8.371200082986332}, {100., 9.675065098540655}}], 
     PolygonBox[{{100., 8.37120008298635}, {66.01282525764451, 
      9.527222951589229}, {66.01282525764455, 8.002503354943299}, {100., 
      7.031488303506665}, {100., 8.37120008298635}}], 
     PolygonBox[{{100., 7.031488303506665}, {66.01282525764455, 
      8.002503354943299}, {66.01282525764451, 6.443515810364837}, {
      99.99999999999994, 5.661666611617639}, {100., 7.031488303506665}}], 
     PolygonBox[{{100., 5.661666611617658}, {66.01282525764451, 
      6.443515810364859}, {66.01282525764451, 4.85693614185987}, {100., 
      4.2676007941028145`}, {100., 5.661666611617658}}], 
     PolygonBox[{{100., 4.2676007941028145`}, {66.01282525764451, 
      4.85693614185987}, {66.01282525764455, 3.2495583271450355`}, {100., 
      2.8552604548136293`}, {100., 4.2676007941028145`}}], 
     PolygonBox[{{100., 2.8552604548136484`}, {66.01282525764451, 
      3.249558327145057}, {66.01282525764451, 1.6282654047921172`}, {100., 
      1.4306934519093917`}, {100., 2.8552604548136484`}}], 
     PolygonBox[{{100., 1.4306934519093917`}, {66.01282525764451, 
      1.6282654047921172`}, {66.01282525764451, 4.573290390565897*^-15}, {
      100., 4.0183723097022526`*^-15}, {100., 1.4306934519093917`}}], 
     PolygonBox[{{100., 4.0183723097022526`*^-15}, {66.01282525764451, 
      4.573290390565897*^-15}, {66.01282525764451, -1.6282654047921081`}, {
      100., -1.4306934519093837`}, {100., 4.0183723097022526`*^-15}}], 
     PolygonBox[{{100., -1.4306934519093644`}, {
      66.01282525764455, -1.6282654047920861`}, {
      66.01282525764455, -3.2495583271450266`}, {
      100.00000000000004`, -2.8552604548136213`}, {
      100., -1.4306934519093644`}}], 
     PolygonBox[{{100.00000000000004`, -2.8552604548136213`}, {
      66.01282525764455, -3.2495583271450266`}, {
      66.01282525764451, -4.856936141859861}, {
      99.99999999999994, -4.2676007941028065`}, {
      100.00000000000004`, -2.8552604548136213`}}], 
     PolygonBox[{{99.99999999999994, -4.267600794102787}, {
      66.01282525764451, -4.85693614185984}, {
      66.01282525764451, -6.443515810364828}, {100., -5.6616666116176315`}, {
      99.99999999999994, -4.267600794102787}}], 
     PolygonBox[{{100., -5.6616666116176315`}, {
      66.01282525764451, -6.443515810364828}, {
      66.01282525764455, -8.002503354943292}, {100., -7.0314883035066575`}, {
      100., -5.6616666116176315`}}], 
     PolygonBox[{{100., -7.0314883035066575`}, {
      66.01282525764455, -8.002503354943292}, {
      66.01282525764455, -9.52722295158922}, {100., -8.371200082986345}, {
      100., -7.0314883035066575`}}], 
     PolygonBox[{{100.00000000000004`, -8.371200082986325}, {
      66.01282525764451, -9.527222951589199}, {
      66.01282525764451, -11.011145516910547`}, {100., -9.675065098540648}, {
      100.00000000000004`, -8.371200082986325}}], 
     PolygonBox[{{100., -9.675065098540648}, {
      66.01282525764451, -11.011145516910547`}, {
      66.01282525764451, -12.44791666666667}, {100., -10.937500000000002`}, {
      100., -9.675065098540648}}], 
     PolygonBox[{{100., -10.937499999999986`}, {
      66.01282525764451, -12.447916666666652`}, {
      66.01282525764451, -13.831383926217171`}, {100., -12.15309884730379}, {
      100., -10.937499999999986`}}], 
     PolygonBox[{{100., -12.15309884730379}, {
      66.01282525764451, -13.831383926217171`}, {
      66.01282525764455, -15.15562307636294}, {100., -13.316656259565761`}, {
      100., -12.15309884730379}}], 
     PolygonBox[{{100., -13.316656259565747`}, {
      66.01282525764451, -15.155623076362922`}, {
      66.01282525764455, -16.414963521762118`}, {
      100., -14.423189705313996`}, {100., -13.316656259565747`}}], 
     PolygonBox[{{100., -14.423189705313996`}, {
      66.01282525764455, -16.414963521762118`}, {
      66.01282525764455, -17.604012573290085`}, {
      100., -15.467960838455724`}, {100., -14.423189705313996`}}], 
     PolygonBox[{{100., -15.467960838455724`}, {
      66.01282525764455, -17.604012573290085`}, {
      66.01282525764455, -18.717678540362044`}, {
      100., -16.446495788602633`}, {100., -15.467960838455724`}}], 
     PolygonBox[{{100., -16.446495788602622`}, {
      66.01282525764451, -18.71767854036203}, {
      66.01282525764455, -19.75119253433387}, {
      100.00000000000004`, -17.354604318870763`}, {
      100., -16.446495788602622`}}], 
     PolygonBox[{{100.00000000000004`, -17.354604318870763`}, {
      66.01282525764455, -19.75119253433387}, {
      66.01282525764455, -20.70012888961545}, {
      99.99999999999994, -18.18839776911818}, {
      100.00000000000004`, -17.354604318870763`}}], 
     PolygonBox[{{100., -18.18839776911817}, {
      66.01282525764451, -20.70012888961544}, {
      66.01282525764451, -21.560424115050083`}, {100., -18.94430570778459}, {
      100., -18.18839776911817}}], 
     PolygonBox[{{100., -18.94430570778459}, {
      66.01282525764451, -21.560424115050083`}, {
      66.01282525764451, -22.328394294407552`}, {
      100., -19.619091221027556`}, {100., -18.94430570778459}}], 
     PolygonBox[{{100., -19.619091221027546`}, {
      66.01282525764455, -22.32839429440754}, {
      66.01282525764451, -23.000750861478906`}, {
      100., -20.209864773684394`}, {100., -19.619091221027546`}}], 
     PolygonBox[{{100., -20.209864773684394`}, {
      66.01282525764451, -23.000750861478906`}, {
      66.01282525764455, -23.5746146822219}, {100., -20.714096582705434`}, {
      100., -20.209864773684394`}}], 
     PolygonBox[{{100., -20.714096582705434`}, {
      66.01282525764455, -23.5746146822219}, {
      66.01282525764451, -24.047528383654935`}, {
      99.99999999999994, -21.12962745007337}, {100., -20.714096582705434`}}], 
     PolygonBox[{{100., -21.129627450073365`}, {
      66.01282525764451, -24.047528383654925`}, {
      66.01282525764451, -24.417466876705426`}, {
      100., -21.454678008820665`}, {100., -21.129627450073365`}}], 
     PolygonBox[{{100., -21.454678008820665`}, {
      66.01282525764451, -24.417466876705426`}, {
      66.01282525764455, -24.682846027952156`}, {
      100., -21.687856342552102`}, {100., -21.454678008820665`}}], 
     PolygonBox[{{100., -21.6878563425521}, {
      66.01282525764451, -24.682846027952152`}, {
      66.01282525764451, -24.842529443127734`}, {100., -21.82816394584445}, {
      100., -21.6878563425521}}], 
     PolygonBox[{{100., -21.82816394584445}, {
      66.01282525764451, -24.842529443127734`}, {
      66.01282525764451, -24.895833333333336`}, {100., -21.875}, {
      100., -21.82816394584445}}], 
     PolygonBox[{{66.01282525764455, -24.895833333333332`}, {
      49.34615859097786, -27.916666666666664`}, {
      49.34615859097786, -27.856894940411014`}, {
      66.01282525764455, -24.84252944312773}, {
      66.01282525764455, -24.895833333333332`}}], 
     PolygonBox[{{66.01282525764455, -24.84252944312773}, {
      49.34615859097786, -27.856894940411014`}, {
      49.34615859097786, -27.677835713352206`}, {
      66.01282525764455, -24.682846027952152`}, {
      66.01282525764455, -24.84252944312773}}], 
     PolygonBox[{{66.01282525764455, -24.682846027952152`}, {
      49.34615859097786, -27.677835713352206`}, {
      49.34615859097785, -27.380255744590183`}, {
      66.01282525764455, -24.417466876705426`}, {
      66.01282525764455, -24.682846027952152`}}], 
     PolygonBox[{{66.01282525764455, -24.417466876705426`}, {
      49.34615859097785, -27.380255744590183`}, {
      49.34615859097785, -26.96542931723649}, {
      66.01282525764455, -24.047528383654928`}, {
      66.01282525764455, -24.417466876705426`}}], 
     PolygonBox[{{66.01282525764455, -24.047528383654928`}, {
      49.34615859097785, -26.96542931723649}, {
      49.34615859097785, -26.435132781738368`}, {
      66.01282525764455, -23.5746146822219}, {
      66.01282525764455, -24.047528383654928`}}], 
     PolygonBox[{{66.01282525764455, -23.5746146822219}, {
      49.34615859097785, -26.435132781738368`}, {
      49.34615859097786, -25.79163694927342}, {
      66.01282525764455, -23.000750861478906`}, {
      66.01282525764455, -23.5746146822219}}], 
     PolygonBox[{{66.01282525764455, -23.000750861478906`}, {
      49.34615859097786, -25.79163694927342}, {
      49.34615859097785, -25.03769736778755}, {
      66.01282525764455, -22.328394294407552`}, {
      66.01282525764455, -23.000750861478906`}}], 
     PolygonBox[{{66.01282525764455, -22.328394294407552`}, {
      49.34615859097785, -25.03769736778755}, {
      49.34615859097786, -24.17654252231558}, {
      66.01282525764455, -21.560424115050086`}, {
      66.01282525764455, -22.328394294407552`}}], 
     PolygonBox[{{66.01282525764455, -21.560424115050086`}, {
      49.34615859097786, -24.17654252231558}, {
      49.34615859097786, -23.21186001011272}, {
      66.0128252576446, -20.700128889615446`}, {
      66.01282525764455, -21.560424115050086`}}], 
     PolygonBox[{{66.0128252576446, -20.700128889615446`}, {
      49.34615859097786, -23.21186001011272}, {
      49.34615859097786, -22.14778074979698}, {
      66.0128252576446, -19.75119253433387}, {
      66.0128252576446, -20.700128889615446`}}], 
     PolygonBox[{{66.01282525764455, -19.751192534333875`}, {
      49.34615859097786, -22.147780749796983`}, {
      49.34615859097785, -20.988861292121452`}, {
      66.0128252576446, -18.717678540362037`}, {
      66.01282525764455, -19.751192534333875`}}], 
     PolygonBox[{{66.0128252576446, -18.717678540362037`}, {
      49.34615859097785, -20.988861292121452`}, {
      49.34615859097786, -19.740064308124452`}, {
      66.0128252576446, -17.60401257329009}, {
      66.0128252576446, -18.717678540362037`}}], 
     PolygonBox[{{66.0128252576446, -17.60401257329009}, {
      49.34615859097786, -19.740064308124452`}, {
      49.34615859097785, -18.406737338210256`}, {
      66.0128252576446, -16.41496352176213}, {
      66.0128252576446, -17.60401257329009}}], 
     PolygonBox[{{66.01282525764455, -16.414963521762132`}, {
      49.34615859097786, -18.406737338210256`}, {
      49.34615859097786, -16.994589893160118`}, {
      66.0128252576446, -15.15562307636294}, {
      66.01282525764455, -16.414963521762132`}}], 
     PolygonBox[{{66.0128252576446, -15.15562307636294}, {
      49.34615859097786, -16.994589893160118`}, {
      49.34615859097786, -15.509669005130563`}, {
      66.01282525764455, -13.83138392621718}, {
      66.0128252576446, -15.15562307636294}}], 
     PolygonBox[{{66.01282525764455, -13.831383926217184`}, {
      49.34615859097785, -15.509669005130567`}, {
      49.34615859097785, -13.958333333333336`}, {
      66.01282525764455, -12.447916666666668`}, {
      66.01282525764455, -13.831383926217184`}}], 
     PolygonBox[{{66.01282525764455, -12.447916666666668`}, {
      49.34615859097785, -13.958333333333336`}, {
      49.34615859097785, -12.347225935280456`}, {
      66.01282525764455, -11.011145516910556`}, {
      66.01282525764455, -12.447916666666668`}}], 
     PolygonBox[{{66.01282525764455, -11.011145516910556`}, {
      49.34615859097785, -12.347225935280456`}, {
      49.34615859097786, -10.683245820192095`}, {
      66.0128252576446, -9.52722295158922}, {
      66.01282525764455, -11.011145516910556`}}], 
     PolygonBox[{{66.01282525764455, -9.527222951589215}, {
      49.34615859097785, -10.683245820192091`}, {
      49.34615859097786, -8.973518406379931}, {
      66.0128252576446, -8.002503354943295}, {
      66.01282525764455, -9.527222951589215}}], 
     PolygonBox[{{66.0128252576446, -8.002503354943295}, {
      49.34615859097786, -8.973518406379931}, {
      49.34615859097786, -7.225365009112044}, {
      66.01282525764461, -6.443515810364845}, {
      66.0128252576446, -8.002503354943295}}], 
     PolygonBox[{{66.01282525764461, -6.443515810364845}, {
      49.34615859097786, -7.225365009112044}, {
      49.34615859097785, -5.446271489616921}, {
      66.01282525764451, -4.856936141859865}, {
      66.01282525764461, -6.443515810364845}}], 
     PolygonBox[{{66.01282525764455, -4.856936141859862}, {
      49.34615859097785, -5.446271489616915}, {
      49.34615859097786, -3.6438561994764433`}, {
      66.01282525764455, -3.249558327145037}, {
      66.01282525764455, -4.856936141859862}}], 
     PolygonBox[{{66.01282525764455, -3.249558327145037}, {
      49.34615859097786, -3.6438561994764433`}, {
      49.34615859097786, -1.8258373576748328`}, {
      66.01282525764455, -1.6282654047921081`}, {
      66.01282525764455, -3.249558327145037}}], 
     PolygonBox[{{66.01282525764455, -1.6282654047921081`}, {
      49.34615859097786, -1.8258373576748328`}, {
      49.34615859097786, -7.908148044633638*^-15}, {
      66.01282525764455, -7.052415606968057*^-15}, {
      66.01282525764455, -1.6282654047921081`}}], 
     PolygonBox[{{66.01282525764455, -1.5244301301886324`*^-15}, {
      49.34615859097786, -1.7094028238098471`*^-15}, {49.34615859097786, 
      1.825837357674823}, {66.01282525764455, 1.6282654047920997`}, {
      66.01282525764455, -1.5244301301886324`*^-15}}], 
     PolygonBox[{{66.01282525764455, 1.6282654047920997`}, {49.34615859097786,
       1.825837357674823}, {49.34615859097786, 3.6438561994764345`}, {
      66.01282525764455, 3.249558327145029}, {66.01282525764455, 
      1.6282654047920997`}}], 
     PolygonBox[{{66.01282525764455, 3.249558327145029}, {49.34615859097786, 
      3.6438561994764345`}, {49.34615859097786, 5.4462714896169055`}, {
      66.01282525764455, 4.856936141859852}, {66.01282525764455, 
      3.249558327145029}}], 
     PolygonBox[{{66.01282525764455, 4.856936141859852}, {49.34615859097786, 
      5.4462714896169055`}, {49.34615859097786, 7.225365009112027}, {
      66.0128252576446, 6.44351581036483}, {66.01282525764455, 
      4.856936141859852}}], 
     PolygonBox[{{66.01282525764455, 6.443515810364835}, {49.34615859097785, 
      7.225365009112034}, {49.34615859097786, 8.97351840637992}, {
      66.0128252576446, 8.002503354943286}, {66.01282525764455, 
      6.443515810364835}}], 
     PolygonBox[{{66.0128252576446, 8.002503354943286}, {49.34615859097786, 
      8.97351840637992}, {49.34615859097786, 10.68324582019208}, {
      66.01282525764461, 9.527222951589206}, {66.0128252576446, 
      8.002503354943286}}], 
     PolygonBox[{{66.01282525764461, 9.527222951589206}, {49.34615859097786, 
      10.68324582019208}, {49.34615859097785, 12.347225935280447`}, {
      66.01282525764455, 11.011145516910547`}, {66.01282525764461, 
      9.527222951589206}}], 
     PolygonBox[{{66.01282525764455, 11.011145516910547`}, {49.34615859097785,
       12.347225935280447`}, {49.34615859097786, 13.958333333333329`}, {
      66.01282525764455, 12.44791666666666}, {66.01282525764455, 
      11.011145516910547`}}], 
     PolygonBox[{{66.01282525764455, 12.44791666666666}, {49.34615859097786, 
      13.958333333333329`}, {49.34615859097786, 15.509669005130554`}, {
      66.01282525764455, 13.831383926217171`}, {66.01282525764455, 
      12.44791666666666}}], 
     PolygonBox[{{66.01282525764455, 13.831383926217171`}, {49.34615859097786,
       15.509669005130554`}, {49.34615859097786, 16.99458989316011}, {
      66.01282525764455, 15.155623076362932`}, {66.01282525764455, 
      13.831383926217171`}}], 
     PolygonBox[{{66.01282525764455, 15.155623076362932`}, {49.34615859097786,
       16.99458989316011}, {49.34615859097786, 18.406737338210245`}, {
      66.0128252576446, 16.414963521762118`}, {66.01282525764455, 
      15.155623076362932`}}], 
     PolygonBox[{{66.0128252576446, 16.414963521762118`}, {49.34615859097786, 
      18.406737338210245`}, {49.34615859097786, 19.74006430812444}, {
      66.01282525764455, 17.604012573290078`}, {66.0128252576446, 
      16.414963521762118`}}], 
     PolygonBox[{{66.0128252576446, 17.604012573290085`}, {49.34615859097786, 
      19.74006430812445}, {49.34615859097786, 20.98886129212145}, {
      66.01282525764455, 18.717678540362037`}, {66.0128252576446, 
      17.604012573290085`}}], 
     PolygonBox[{{66.01282525764455, 18.717678540362037`}, {49.34615859097786,
       20.98886129212145}, {49.34615859097785, 22.147780749796976`}, {
      66.01282525764455, 19.75119253433387}, {66.01282525764455, 
      18.717678540362037`}}], 
     PolygonBox[{{66.01282525764455, 19.75119253433387}, {49.34615859097785, 
      22.147780749796976`}, {49.346158590977886`, 23.211860010112712`}, {
      66.01282525764455, 20.700128889615442`}, {66.01282525764455, 
      19.75119253433387}}], 
     PolygonBox[{{66.01282525764455, 20.700128889615442`}, {
      49.346158590977886`, 23.211860010112712`}, {49.34615859097786, 
      24.17654252231557}, {66.0128252576446, 21.56042411505008}, {
      66.01282525764455, 20.700128889615442`}}], 
     PolygonBox[{{66.0128252576446, 21.56042411505008}, {49.34615859097786, 
      24.17654252231557}, {49.34615859097785, 25.037697367787544`}, {
      66.01282525764455, 22.328394294407545`}, {66.0128252576446, 
      21.56042411505008}}], 
     PolygonBox[{{66.01282525764455, 22.328394294407545`}, {49.34615859097785,
       25.037697367787544`}, {49.34615859097785, 25.791636949273418`}, {
      66.01282525764455, 23.000750861478902`}, {66.01282525764455, 
      22.328394294407545`}}], 
     PolygonBox[{{66.01282525764455, 23.000750861478906`}, {49.34615859097785,
       25.79163694927342}, {49.34615859097786, 26.43513278173836}, {
      66.0128252576446, 23.574614682221895`}, {66.01282525764455, 
      23.000750861478906`}}], 
     PolygonBox[{{66.0128252576446, 23.574614682221895`}, {49.34615859097786, 
      26.43513278173836}, {49.34615859097786, 26.965429317236485`}, {
      66.01282525764461, 24.04752838365492}, {66.0128252576446, 
      23.574614682221895`}}], 
     PolygonBox[{{66.01282525764461, 24.04752838365492}, {49.34615859097786, 
      26.965429317236485`}, {49.34615859097785, 27.380255744590183`}, {
      66.01282525764451, 24.417466876705426`}, {66.01282525764461, 
      24.04752838365492}}], 
     PolygonBox[{{66.01282525764451, 24.417466876705426`}, {49.34615859097785,
       27.380255744590183`}, {49.34615859097786, 27.677835713352206`}, {
      66.01282525764455, 24.682846027952152`}, {66.01282525764451, 
      24.417466876705426`}}], 
     PolygonBox[{{66.01282525764455, 24.682846027952152`}, {49.34615859097786,
       27.677835713352206`}, {49.34615859097786, 27.856894940411014`}, {
      66.01282525764455, 24.84252944312773}, {66.01282525764455, 
      24.682846027952152`}}], 
     PolygonBox[{{66.01282525764455, 24.84252944312773}, {49.34615859097786, 
      27.856894940411014`}, {49.34615859097786, 27.916666666666664`}, {
      66.01282525764455, 24.895833333333332`}, {66.01282525764455, 
      24.84252944312773}}], 
     PolygonBox[{{66.01282525764455, 24.895833333333332`}, {49.34615859097786,
       27.916666666666664`}, {49.34615859097786, 27.856894940411014`}, {
      66.01282525764455, 24.84252944312773}, {66.01282525764455, 
      24.895833333333332`}}], 
     PolygonBox[{{66.01282525764455, 24.84252944312773}, {49.34615859097786, 
      27.856894940411014`}, {49.34615859097786, 27.677835713352206`}, {
      66.01282525764455, 24.682846027952152`}, {66.01282525764455, 
      24.84252944312773}}], 
     PolygonBox[{{66.01282525764455, 24.682846027952152`}, {49.34615859097786,
       27.677835713352206`}, {49.34615859097786, 27.380255744590183`}, {
      66.01282525764455, 24.417466876705426`}, {66.01282525764455, 
      24.682846027952152`}}], 
     PolygonBox[{{66.01282525764455, 24.417466876705426`}, {49.34615859097786,
       27.380255744590183`}, {49.34615859097786, 26.96542931723649}, {
      66.0128252576446, 24.047528383654928`}, {66.01282525764455, 
      24.417466876705426`}}], 
     PolygonBox[{{66.0128252576446, 24.047528383654928`}, {49.34615859097786, 
      26.96542931723649}, {49.34615859097786, 26.435132781738368`}, {
      66.01282525764461, 23.5746146822219}, {66.0128252576446, 
      24.047528383654928`}}], 
     PolygonBox[{{66.01282525764461, 23.5746146822219}, {49.34615859097786, 
      26.435132781738368`}, {49.34615859097786, 25.791636949273425`}, {
      66.01282525764455, 23.000750861478913`}, {66.01282525764461, 
      23.5746146822219}}], 
     PolygonBox[{{66.01282525764455, 23.000750861478913`}, {49.34615859097786,
       25.791636949273425`}, {49.34615859097786, 25.037697367787555`}, {
      66.01282525764455, 22.32839429440756}, {66.01282525764455, 
      23.000750861478913`}}], 
     PolygonBox[{{66.01282525764455, 22.328394294407552`}, {49.34615859097785,
       25.03769736778755}, {49.34615859097786, 24.176542522315582`}, {
      66.01282525764455, 21.56042411505009}, {66.01282525764455, 
      22.328394294407552`}}], 
     PolygonBox[{{66.01282525764455, 21.56042411505009}, {49.34615859097786, 
      24.176542522315582`}, {49.34615859097786, 23.211860010112726`}, {
      66.01282525764455, 20.700128889615453`}, {66.01282525764455, 
      21.56042411505009}}], 
     PolygonBox[{{66.01282525764455, 20.700128889615453`}, {49.34615859097786,
       23.211860010112726`}, {49.34615859097786, 22.147780749796986`}, {
      66.01282525764455, 19.751192534333878`}, {66.01282525764455, 
      20.700128889615453`}}], 
     PolygonBox[{{66.01282525764455, 19.751192534333878`}, {49.34615859097786,
       22.147780749796986`}, {49.34615859097786, 20.98886129212146}, {
      66.0128252576446, 18.717678540362048`}, {66.01282525764455, 
      19.751192534333878`}}], 
     PolygonBox[{{66.0128252576446, 18.717678540362048`}, {49.34615859097786, 
      20.98886129212146}, {49.34615859097786, 19.74006430812446}, {
      66.01282525764455, 17.6040125732901}, {66.0128252576446, 
      18.717678540362048`}}], 
     PolygonBox[{{66.01282525764455, 17.6040125732901}, {49.34615859097786, 
      19.74006430812446}, {49.34615859097786, 18.40673733821027}, {
      66.01282525764455, 16.414963521762143`}, {66.01282525764455, 
      17.6040125732901}}], 
     PolygonBox[{{66.01282525764455, 16.414963521762136`}, {49.34615859097785,
       18.406737338210263`}, {49.34615859097785, 16.994589893160125`}, {
      66.0128252576446, 15.155623076362945`}, {66.01282525764455, 
      16.414963521762136`}}], 
     PolygonBox[{{66.0128252576446, 15.155623076362945`}, {49.34615859097785, 
      16.994589893160125`}, {49.34615859097786, 15.509669005130561`}, {
      66.0128252576446, 13.831383926217178`}, {66.0128252576446, 
      15.155623076362945`}}], 
     PolygonBox[{{66.01282525764455, 13.831383926217196`}, {49.34615859097786,
       15.50966900513058}, {49.34615859097785, 13.958333333333346`}, {
      66.01282525764455, 12.447916666666677`}, {66.01282525764455, 
      13.831383926217196`}}], 
     PolygonBox[{{66.01282525764455, 12.447916666666677`}, {49.34615859097785,
       13.958333333333346`}, {49.34615859097785, 12.347225935280454`}, {
      66.0128252576446, 11.011145516910553`}, {66.01282525764455, 
      12.447916666666677`}}], 
     PolygonBox[{{66.0128252576446, 11.011145516910553`}, {49.34615859097785, 
      12.347225935280454`}, {49.34615859097786, 10.68324582019208}, {
      66.01282525764461, 9.527222951589206}, {66.0128252576446, 
      11.011145516910553`}}], 
     PolygonBox[{{66.01282525764455, 9.527222951589227}, {49.34615859097785, 
      10.683245820192104`}, {49.34615859097786, 8.973518406379933}, {
      66.0128252576446, 8.002503354943299}, {66.01282525764455, 
      9.527222951589227}}], 
     PolygonBox[{{66.0128252576446, 8.002503354943299}, {49.34615859097786, 
      8.973518406379933}, {49.34615859097785, 7.225365009112034}, {
      66.01282525764455, 6.443515810364835}, {66.0128252576446, 
      8.002503354943299}}], 
     PolygonBox[{{66.0128252576446, 6.4435158103648575`}, {49.34615859097785, 
      7.225365009112059}, {49.34615859097786, 5.446271489616925}, {
      66.0128252576446, 4.856936141859869}, {66.0128252576446, 
      6.4435158103648575`}}], 
     PolygonBox[{{66.0128252576446, 4.856936141859869}, {49.34615859097786, 
      5.446271489616925}, {49.34615859097786, 3.643856199476441}, {
      66.01282525764455, 3.249558327145035}, {66.0128252576446, 
      4.856936141859869}}], 
     PolygonBox[{{66.01282525764455, 3.2495583271450563`}, {49.34615859097786,
       3.643856199476465}, {49.34615859097786, 1.8258373576748426`}, {
      66.01282525764455, 1.628265404792117}, {66.01282525764455, 
      3.2495583271450563`}}], 
     PolygonBox[{{66.01282525764455, 1.628265404792117}, {49.34615859097786, 
      1.8258373576748426`}, {49.34615859097786, 5.128208471429541*^-15}, {
      66.01282525764455, 4.573290390565896*^-15}, {66.01282525764455, 
      1.628265404792117}}], 
     PolygonBox[{{66.01282525764455, 4.573290390565896*^-15}, {
      49.34615859097786, 5.128208471429541*^-15}, {
      49.34615859097786, -1.8258373576748324`}, {
      66.01282525764455, -1.628265404792108}, {66.01282525764455, 
      4.573290390565896*^-15}}], 
     PolygonBox[{{66.0128252576446, -1.628265404792086}, {
      49.34615859097786, -1.8258373576748077`}, {
      49.34615859097786, -3.643856199476431}, {
      66.01282525764455, -3.2495583271450257`}, {
      66.0128252576446, -1.628265404792086}}], 
     PolygonBox[{{66.01282525764455, -3.2495583271450257`}, {
      49.34615859097786, -3.643856199476431}, {
      49.34615859097785, -5.446271489616914}, {
      66.01282525764455, -4.85693614185986}, {
      66.01282525764455, -3.2495583271450257`}}], 
     PolygonBox[{{66.01282525764455, -4.856936141859839}, {
      49.34615859097785, -5.4462714896168904`}, {
      49.34615859097786, -7.225365009112025}, {
      66.0128252576446, -6.443515810364827}, {
      66.01282525764455, -4.856936141859839}}], 
     PolygonBox[{{66.0128252576446, -6.443515810364827}, {
      49.34615859097786, -7.225365009112025}, {
      49.34615859097785, -8.973518406379924}, {
      66.01282525764455, -8.00250335494329}, {
      66.0128252576446, -6.443515810364827}}], 
     PolygonBox[{{66.01282525764455, -8.00250335494329}, {
      49.34615859097785, -8.973518406379924}, {
      49.34615859097786, -10.683245820192095`}, {
      66.0128252576446, -9.52722295158922}, {
      66.01282525764455, -8.00250335494329}}], 
     PolygonBox[{{66.01282525764455, -9.527222951589199}, {
      49.34615859097786, -10.683245820192072`}, {
      49.34615859097785, -12.347225935280445`}, {
      66.01282525764455, -11.011145516910545`}, {
      66.01282525764455, -9.527222951589199}}], 
     PolygonBox[{{66.01282525764455, -11.011145516910545`}, {
      49.34615859097785, -12.347225935280445`}, {
      49.34615859097785, -13.958333333333336`}, {
      66.01282525764455, -12.447916666666668`}, {
      66.01282525764455, -11.011145516910545`}}], 
     PolygonBox[{{66.0128252576446, -12.447916666666648`}, {
      49.34615859097786, -13.958333333333314`}, {
      49.34615859097786, -15.50966900513055}, {
      66.01282525764455, -13.83138392621717}, {
      66.0128252576446, -12.447916666666648`}}], 
     PolygonBox[{{66.01282525764455, -13.83138392621717}, {
      49.34615859097786, -15.50966900513055}, {
      49.34615859097786, -16.994589893160114`}, {
      66.01282525764461, -15.155623076362936`}, {
      66.01282525764455, -13.83138392621717}}], 
     PolygonBox[{{66.01282525764455, -15.15562307636292}, {
      49.34615859097786, -16.994589893160096`}, {
      49.34615859097786, -18.40673733821024}, {
      66.01282525764455, -16.414963521762118`}, {
      66.01282525764455, -15.15562307636292}}], 
     PolygonBox[{{66.01282525764455, -16.414963521762118`}, {
      49.34615859097786, -18.40673733821024}, {
      49.34615859097786, -19.740064308124445`}, {
      66.01282525764455, -17.604012573290085`}, {
      66.01282525764455, -16.414963521762118`}}], 
     PolygonBox[{{66.01282525764455, -17.604012573290085`}, {
      49.34615859097786, -19.740064308124445`}, {
      49.346158590977886`, -20.988861292121452`}, {
      66.0128252576446, -18.71767854036204}, {
      66.01282525764455, -17.604012573290085`}}], 
     PolygonBox[{{66.01282525764455, -18.71767854036203}, {
      49.34615859097786, -20.988861292121438`}, {
      49.34615859097785, -22.147780749796976`}, {
      66.0128252576446, -19.751192534333867`}, {
      66.01282525764455, -18.71767854036203}}], 
     PolygonBox[{{66.0128252576446, -19.751192534333867`}, {
      49.34615859097785, -22.147780749796976`}, {
      49.34615859097786, -23.21186001011272}, {
      66.0128252576446, -20.700128889615446`}, {
      66.0128252576446, -19.751192534333867`}}], 
     PolygonBox[{{66.01282525764455, -20.70012888961544}, {
      49.34615859097786, -23.21186001011271}, {
      49.34615859097785, -24.17654252231557}, {
      66.01282525764455, -21.56042411505008}, {
      66.01282525764455, -20.70012888961544}}], 
     PolygonBox[{{66.01282525764455, -21.56042411505008}, {
      49.34615859097785, -24.17654252231557}, {
      49.34615859097785, -25.037697367787548`}, {
      66.01282525764455, -22.32839429440755}, {
      66.01282525764455, -21.56042411505008}}], 
     PolygonBox[{{66.01282525764455, -22.328394294407538`}, {
      49.34615859097786, -25.037697367787533`}, {
      49.34615859097785, -25.791636949273418`}, {
      66.01282525764455, -23.000750861478902`}, {
      66.01282525764455, -22.328394294407538`}}], 
     PolygonBox[{{66.01282525764455, -23.000750861478902`}, {
      49.34615859097785, -25.791636949273418`}, {
      49.34615859097786, -26.43513278173836}, {
      66.0128252576446, -23.574614682221895`}, {
      66.01282525764455, -23.000750861478902`}}], 
     PolygonBox[{{66.0128252576446, -23.574614682221895`}, {
      49.34615859097786, -26.43513278173836}, {
      49.34615859097785, -26.96542931723649}, {
      66.01282525764455, -24.047528383654928`}, {
      66.0128252576446, -23.574614682221895`}}], 
     PolygonBox[{{66.01282525764455, -24.04752838365492}, {
      49.34615859097785, -26.965429317236485`}, {
      49.34615859097786, -27.38025574459018}, {
      66.0128252576446, -24.41746687670542}, {
      66.01282525764455, -24.04752838365492}}], 
     PolygonBox[{{66.0128252576446, -24.41746687670542}, {
      49.34615859097786, -27.38025574459018}, {
      49.34615859097786, -27.677835713352206`}, {
      66.01282525764455, -24.682846027952152`}, {
      66.0128252576446, -24.41746687670542}}], 
     PolygonBox[{{66.01282525764455, -24.68284602795215}, {
      49.34615859097786, -27.677835713352202`}, {
      49.34615859097786, -27.856894940411014`}, {
      66.01282525764455, -24.84252944312773}, {
      66.01282525764455, -24.68284602795215}}], 
     PolygonBox[{{66.01282525764455, -24.84252944312773}, {
      49.34615859097786, -27.856894940411014`}, {
      49.34615859097786, -27.916666666666664`}, {
      66.01282525764455, -24.895833333333332`}, {
      66.01282525764455, -24.84252944312773}}], 
     PolygonBox[{{49.34615859097786, -27.916666666666664`}, {
      49.999999999999964`, -30.9375}, {
      49.999999999999964`, -30.871260437694296`}, {
      49.34615859097786, -27.856894940411014`}, {
      49.34615859097786, -27.916666666666664`}}], 
     PolygonBox[{{49.34615859097786, -27.856894940411014`}, {
      49.999999999999964`, -30.871260437694296`}, {
      49.999999999999964`, -30.67282539875226}, {
      49.34615859097786, -27.677835713352206`}, {
      49.34615859097786, -27.856894940411014`}}], 
     PolygonBox[{{49.34615859097786, -27.677835713352206`}, {
      49.999999999999964`, -30.67282539875226}, {
      49.999999999999936`, -30.343044612474944`}, {
      49.34615859097785, -27.380255744590183`}, {
      49.34615859097786, -27.677835713352206`}}], 
     PolygonBox[{{49.34615859097785, -27.380255744590183`}, {
      49.999999999999936`, -30.343044612474944`}, {
      49.99999999999996, -29.883330250818048`}, {
      49.34615859097785, -26.96542931723649}, {
      49.34615859097785, -27.380255744590183`}}], 
     PolygonBox[{{49.34615859097785, -26.96542931723649}, {
      49.99999999999996, -29.883330250818048`}, {
      49.999999999999964`, -29.295650881254833`}, {
      49.34615859097785, -26.435132781738368`}, {
      49.34615859097785, -26.96542931723649}}], 
     PolygonBox[{{49.34615859097785, -26.435132781738368`}, {
      49.999999999999964`, -29.295650881254833`}, {
      49.999999999999936`, -28.582523037067936`}, {
      49.34615859097786, -25.79163694927342}, {
      49.34615859097785, -26.435132781738368`}}], 
     PolygonBox[{{49.34615859097786, -25.79163694927342}, {
      49.999999999999936`, -28.582523037067936`}, {
      49.999999999999964`, -27.747000441167547`}, {
      49.34615859097785, -25.03769736778755}, {
      49.34615859097786, -25.79163694927342}}], 
     PolygonBox[{{49.34615859097785, -25.03769736778755}, {
      49.999999999999964`, -27.747000441167547`}, {
      49.999999999999936`, -26.792660929581075`}, {
      49.34615859097786, -24.17654252231558}, {
      49.34615859097785, -25.03769736778755}}], 
     PolygonBox[{{49.34615859097786, -24.17654252231558}, {
      49.999999999999936`, -26.792660929581075`}, {
      49.999999999999964`, -25.723591130609993`}, {
      49.34615859097786, -23.21186001011272}, {
      49.34615859097786, -24.17654252231558}}], 
     PolygonBox[{{49.34615859097786, -23.21186001011272}, {
      49.999999999999964`, -25.723591130609993`}, {
      49.999999999999964`, -24.544368965260087`}, {
      49.34615859097786, -22.14778074979698}, {
      49.34615859097786, -23.21186001011272}}], 
     PolygonBox[{{49.34615859097786, -22.147780749796983`}, {
      49.999999999999964`, -24.54436896526009}, {
      49.999999999999964`, -23.260044043880864`}, {
      49.34615859097785, -20.988861292121452`}, {
      49.34615859097786, -22.147780749796983`}}], 
     PolygonBox[{{49.34615859097785, -20.988861292121452`}, {
      49.999999999999964`, -23.260044043880864`}, {
      49.99999999999996, -21.876116042958813`}, {
      49.34615859097786, -19.740064308124452`}, {
      49.34615859097785, -20.988861292121452`}}], 
     PolygonBox[{{49.34615859097786, -19.740064308124452`}, {
      49.99999999999996, -21.876116042958813`}, {
      49.999999999999964`, -20.39851115465838}, {
      49.34615859097785, -18.406737338210256`}, {
      49.34615859097786, -19.740064308124452`}}], 
     PolygonBox[{{49.34615859097786, -18.406737338210256`}, {
      49.999999999999936`, -20.398511154658387`}, {
      49.999999999999964`, -18.833556709957293`}, {
      49.34615859097786, -16.994589893160118`}, {
      49.34615859097786, -18.406737338210256`}}], 
     PolygonBox[{{49.34615859097786, -16.994589893160118`}, {
      49.999999999999964`, -18.833556709957293`}, {
      49.999999999999964`, -17.187954084043945`}, {
      49.34615859097786, -15.509669005130563`}, {
      49.34615859097786, -16.994589893160118`}}], 
     PolygonBox[{{49.34615859097785, -15.509669005130567`}, {
      49.999999999999936`, -17.18795408404395}, {
      49.999999999999936`, -15.468750000000004`}, {
      49.34615859097785, -13.958333333333336`}, {
      49.34615859097785, -15.509669005130567`}}], 
     PolygonBox[{{49.34615859097785, -13.958333333333336`}, {
      49.999999999999936`, -15.468750000000004`}, {
      49.999999999999936`, -13.683306353650357`}, {
      49.34615859097785, -12.347225935280456`}, {
      49.34615859097785, -13.958333333333336`}}], 
     PolygonBox[{{49.34615859097785, -12.347225935280456`}, {
      49.999999999999936`, -13.683306353650357`}, {
      49.99999999999996, -11.839268688794972`}, {
      49.34615859097786, -10.683245820192095`}, {
      49.34615859097785, -12.347225935280456`}}], 
     PolygonBox[{{49.34615859097785, -10.683245820192091`}, {
      49.999999999999936`, -11.839268688794967`}, {
      49.999999999999964`, -9.944533457816567}, {
      49.34615859097786, -8.973518406379931}, {
      49.34615859097785, -10.683245820192091`}}], 
     PolygonBox[{{49.34615859097786, -8.973518406379931}, {
      49.999999999999964`, -9.944533457816567}, {
      49.99999999999996, -8.007214207859242}, {
      49.34615859097786, -7.225365009112044}, {
      49.34615859097786, -8.973518406379931}}], 
     PolygonBox[{{49.34615859097786, -7.225365009112044}, {
      49.99999999999996, -8.007214207859242}, {
      49.999999999999936`, -6.035606837373976}, {
      49.34615859097785, -5.446271489616921}, {
      49.34615859097786, -7.225365009112044}}], 
     PolygonBox[{{49.34615859097785, -5.446271489616915}, {
      49.999999999999936`, -6.035606837373971}, {
      49.999999999999964`, -4.03815407180785}, {
      49.34615859097786, -3.6438561994764433`}, {
      49.34615859097785, -5.446271489616915}}], 
     PolygonBox[{{49.34615859097786, -3.6438561994764433`}, {
      49.999999999999964`, -4.03815407180785}, {
      49.999999999999964`, -2.0234093105575575`}, {
      49.34615859097786, -1.8258373576748328`}, {
      49.34615859097786, -3.6438561994764433`}}], 
     PolygonBox[{{49.34615859097786, -1.8258373576748328`}, {
      49.999999999999964`, -2.0234093105575575`}, {
      49.999999999999964`, -8.763880482299218*^-15}, {
      49.34615859097786, -7.908148044633638*^-15}, {
      49.34615859097786, -1.8258373576748328`}}], 
     PolygonBox[{{49.34615859097786, -1.7094028238098471`*^-15}, {
      49.999999999999964`, -1.894375517431062*^-15}, {49.999999999999964`, 
      2.023409310557547}, {49.34615859097786, 1.825837357674823}, {
      49.34615859097786, -1.7094028238098471`*^-15}}], 
     PolygonBox[{{49.34615859097786, 1.825837357674823}, {49.999999999999964`,
       2.023409310557547}, {49.99999999999996, 4.03815407180784}, {
      49.34615859097786, 3.6438561994764345`}, {49.34615859097786, 
      1.825837357674823}}], 
     PolygonBox[{{49.34615859097786, 3.6438561994764345`}, {49.99999999999996,
       4.03815407180784}, {49.999999999999936`, 6.035606837373959}, {
      49.34615859097786, 5.4462714896169055`}, {49.34615859097786, 
      3.6438561994764345`}}], 
     PolygonBox[{{49.34615859097786, 5.4462714896169055`}, {
      49.999999999999936`, 6.035606837373959}, {49.99999999999996, 
      8.007214207859224}, {49.34615859097786, 7.225365009112027}, {
      49.34615859097786, 5.4462714896169055`}}], 
     PolygonBox[{{49.34615859097785, 7.225365009112034}, {49.99999999999996, 
      8.007214207859233}, {49.999999999999964`, 9.944533457816554}, {
      49.34615859097786, 8.97351840637992}, {49.34615859097785, 
      7.225365009112034}}], 
     PolygonBox[{{49.34615859097786, 8.97351840637992}, {49.999999999999964`, 
      9.944533457816554}, {49.999999999999964`, 11.839268688794956`}, {
      49.34615859097786, 10.68324582019208}, {49.34615859097786, 
      8.97351840637992}}], 
     PolygonBox[{{49.34615859097786, 10.68324582019208}, {49.999999999999964`,
       11.839268688794956`}, {49.999999999999964`, 13.683306353650346`}, {
      49.34615859097785, 12.347225935280447`}, {49.34615859097786, 
      10.68324582019208}}], 
     PolygonBox[{{49.34615859097785, 12.347225935280447`}, {
      49.999999999999964`, 13.683306353650346`}, {49.999999999999964`, 
      15.468749999999993`}, {49.34615859097786, 13.958333333333329`}, {
      49.34615859097785, 12.347225935280447`}}], 
     PolygonBox[{{49.34615859097786, 13.958333333333329`}, {
      49.999999999999964`, 15.468749999999993`}, {49.999999999999964`, 
      17.187954084043934`}, {49.34615859097786, 15.509669005130554`}, {
      49.34615859097786, 13.958333333333329`}}], 
     PolygonBox[{{49.34615859097786, 15.509669005130554`}, {
      49.999999999999964`, 17.187954084043934`}, {49.999999999999964`, 
      18.833556709957286`}, {49.34615859097786, 16.99458989316011}, {
      49.34615859097786, 15.509669005130554`}}], 
     PolygonBox[{{49.34615859097786, 16.99458989316011}, {49.999999999999964`,
       18.833556709957286`}, {49.999999999999964`, 20.39851115465837}, {
      49.34615859097786, 18.406737338210245`}, {49.34615859097786, 
      16.99458989316011}}], 
     PolygonBox[{{49.34615859097786, 18.406737338210245`}, {
      49.999999999999964`, 20.39851115465837}, {49.999999999999936`, 
      21.876116042958806`}, {49.34615859097786, 19.74006430812444}, {
      49.34615859097786, 18.406737338210245`}}], 
     PolygonBox[{{49.34615859097786, 19.74006430812445}, {49.99999999999996, 
      21.876116042958813`}, {49.999999999999936`, 23.26004404388086}, {
      49.34615859097786, 20.98886129212145}, {49.34615859097786, 
      19.74006430812445}}], 
     PolygonBox[{{49.34615859097786, 20.98886129212145}, {49.999999999999936`,
       23.26004404388086}, {49.999999999999936`, 24.544368965260084`}, {
      49.34615859097785, 22.147780749796976`}, {49.34615859097786, 
      20.98886129212145}}], 
     PolygonBox[{{49.34615859097785, 22.147780749796976`}, {
      49.999999999999936`, 24.544368965260084`}, {49.99999999999996, 
      25.723591130609986`}, {49.346158590977886`, 23.211860010112712`}, {
      49.34615859097785, 22.147780749796976`}}], 
     PolygonBox[{{49.346158590977886`, 23.211860010112712`}, {
      49.99999999999996, 25.723591130609986`}, {49.999999999999964`, 
      26.792660929581064`}, {49.34615859097786, 24.17654252231557}, {
      49.346158590977886`, 23.211860010112712`}}], 
     PolygonBox[{{49.34615859097786, 24.17654252231557}, {49.999999999999964`,
       26.792660929581064`}, {49.99999999999997, 27.747000441167543`}, {
      49.34615859097785, 25.037697367787544`}, {49.34615859097786, 
      24.17654252231557}}], 
     PolygonBox[{{49.34615859097785, 25.037697367787544`}, {49.99999999999997,
       27.747000441167543`}, {49.999999999999936`, 28.58252303706793}, {
      49.34615859097785, 25.791636949273418`}, {49.34615859097785, 
      25.037697367787544`}}], 
     PolygonBox[{{49.34615859097785, 25.79163694927342}, {49.999999999999936`,
       28.582523037067936`}, {49.999999999999964`, 29.29565088125483}, {
      49.34615859097786, 26.43513278173836}, {49.34615859097785, 
      25.79163694927342}}], 
     PolygonBox[{{49.34615859097786, 26.43513278173836}, {49.999999999999964`,
       29.29565088125483}, {49.99999999999996, 29.883330250818045`}, {
      49.34615859097786, 26.965429317236485`}, {49.34615859097786, 
      26.43513278173836}}], 
     PolygonBox[{{49.34615859097786, 26.965429317236485`}, {49.99999999999996,
       29.883330250818045`}, {49.99999999999997, 30.343044612474944`}, {
      49.34615859097785, 27.380255744590183`}, {49.34615859097786, 
      26.965429317236485`}}], 
     PolygonBox[{{49.34615859097785, 27.380255744590183`}, {49.99999999999997,
       30.343044612474944`}, {49.999999999999936`, 30.67282539875226}, {
      49.34615859097786, 27.677835713352206`}, {49.34615859097785, 
      27.380255744590183`}}], 
     PolygonBox[{{49.34615859097786, 27.677835713352206`}, {
      49.999999999999936`, 30.67282539875226}, {49.999999999999936`, 
      30.871260437694296`}, {49.34615859097786, 27.856894940411014`}, {
      49.34615859097786, 27.677835713352206`}}], 
     PolygonBox[{{49.34615859097786, 27.856894940411014`}, {
      49.999999999999936`, 30.871260437694296`}, {49.999999999999964`, 
      30.9375}, {49.34615859097786, 27.916666666666664`}, {49.34615859097786, 
      27.856894940411014`}}], 
     PolygonBox[{{49.34615859097786, 27.916666666666664`}, {
      49.999999999999964`, 30.9375}, {49.999999999999964`, 
      30.871260437694296`}, {49.34615859097786, 27.856894940411014`}, {
      49.34615859097786, 27.916666666666664`}}], 
     PolygonBox[{{49.34615859097786, 27.856894940411014`}, {
      49.999999999999964`, 30.871260437694296`}, {49.99999999999996, 
      30.67282539875226}, {49.34615859097786, 27.677835713352206`}, {
      49.34615859097786, 27.856894940411014`}}], 
     PolygonBox[{{49.34615859097786, 27.677835713352206`}, {49.99999999999996,
       30.67282539875226}, {49.999999999999964`, 30.343044612474944`}, {
      49.34615859097786, 27.380255744590183`}, {49.34615859097786, 
      27.677835713352206`}}], 
     PolygonBox[{{49.34615859097786, 27.380255744590183`}, {
      49.999999999999964`, 30.343044612474944`}, {49.99999999999996, 
      29.88333025081805}, {49.34615859097786, 26.96542931723649}, {
      49.34615859097786, 27.380255744590183`}}], 
     PolygonBox[{{49.34615859097786, 26.96542931723649}, {49.99999999999996, 
      29.88333025081805}, {49.99999999999996, 29.295650881254833`}, {
      49.34615859097786, 26.435132781738368`}, {49.34615859097786, 
      26.96542931723649}}], 
     PolygonBox[{{49.34615859097786, 26.435132781738368`}, {49.99999999999996,
       29.295650881254833`}, {49.999999999999936`, 28.582523037067944`}, {
      49.34615859097786, 25.791636949273425`}, {49.34615859097786, 
      26.435132781738368`}}], 
     PolygonBox[{{49.34615859097786, 25.791636949273425`}, {
      49.999999999999936`, 28.582523037067944`}, {49.999999999999964`, 
      27.747000441167554`}, {49.34615859097786, 25.037697367787555`}, {
      49.34615859097786, 25.791636949273425`}}], 
     PolygonBox[{{49.34615859097785, 25.03769736778755}, {49.99999999999996, 
      27.747000441167547`}, {49.999999999999964`, 26.792660929581075`}, {
      49.34615859097786, 24.176542522315582`}, {49.34615859097785, 
      25.03769736778755}}], 
     PolygonBox[{{49.34615859097786, 24.176542522315582`}, {
      49.999999999999964`, 26.792660929581075`}, {49.999999999999964`, 
      25.72359113061}, {49.34615859097786, 23.211860010112726`}, {
      49.34615859097786, 24.176542522315582`}}], 
     PolygonBox[{{49.34615859097786, 23.211860010112726`}, {
      49.999999999999964`, 25.72359113061}, {49.999999999999964`, 
      24.544368965260094`}, {49.34615859097786, 22.147780749796986`}, {
      49.34615859097786, 23.211860010112726`}}], 
     PolygonBox[{{49.34615859097786, 22.147780749796986`}, {
      49.999999999999964`, 24.544368965260094`}, {49.999999999999964`, 
      23.260044043880875`}, {49.34615859097786, 20.98886129212146}, {
      49.34615859097786, 22.147780749796986`}}], 
     PolygonBox[{{49.34615859097786, 20.98886129212146}, {49.999999999999964`,
       23.260044043880875`}, {49.999999999999936`, 21.876116042958827`}, {
      49.34615859097786, 19.74006430812446}, {49.34615859097786, 
      20.98886129212146}}], 
     PolygonBox[{{49.34615859097786, 19.74006430812446}, {49.999999999999936`,
       21.876116042958827`}, {49.999999999999964`, 20.398511154658397`}, {
      49.34615859097786, 18.40673733821027}, {49.34615859097786, 
      19.74006430812446}}], 
     PolygonBox[{{49.34615859097785, 18.406737338210263`}, {
      49.999999999999936`, 20.398511154658387`}, {49.999999999999964`, 
      18.833556709957303`}, {49.34615859097785, 16.994589893160125`}, {
      49.34615859097785, 18.406737338210263`}}], 
     PolygonBox[{{49.34615859097785, 16.994589893160125`}, {
      49.999999999999964`, 18.833556709957303`}, {49.999999999999964`, 
      17.187954084043945`}, {49.34615859097786, 15.509669005130561`}, {
      49.34615859097785, 16.994589893160125`}}], 
     PolygonBox[{{49.34615859097786, 15.50966900513058}, {49.999999999999964`,
       17.187954084043966`}, {49.99999999999996, 15.468750000000016`}, {
      49.34615859097785, 13.958333333333346`}, {49.34615859097786, 
      15.50966900513058}}], 
     PolygonBox[{{49.34615859097785, 13.958333333333346`}, {49.99999999999996,
       15.468750000000016`}, {49.999999999999936`, 13.683306353650355`}, {
      49.34615859097785, 12.347225935280454`}, {49.34615859097785, 
      13.958333333333346`}}], 
     PolygonBox[{{49.34615859097785, 12.347225935280454`}, {
      49.999999999999936`, 13.683306353650355`}, {49.999999999999964`, 
      11.839268688794956`}, {49.34615859097786, 10.68324582019208}, {
      49.34615859097785, 12.347225935280454`}}], 
     PolygonBox[{{49.34615859097785, 10.683245820192104`}, {
      49.999999999999936`, 11.839268688794983`}, {49.999999999999964`, 
      9.944533457816569}, {49.34615859097786, 8.973518406379933}, {
      49.34615859097785, 10.683245820192104`}}], 
     PolygonBox[{{49.34615859097786, 8.973518406379933}, {49.999999999999964`,
       9.944533457816569}, {49.99999999999996, 8.007214207859233}, {
      49.34615859097785, 7.225365009112034}, {49.34615859097786, 
      8.973518406379933}}], 
     PolygonBox[{{49.34615859097785, 7.225365009112059}, {49.999999999999964`,
       8.00721420785926}, {49.99999999999992, 6.03560683737398}, {
      49.34615859097786, 5.446271489616925}, {49.34615859097785, 
      7.225365009112059}}], 
     PolygonBox[{{49.34615859097786, 5.446271489616925}, {49.99999999999992, 
      6.03560683737398}, {49.999999999999964`, 4.038154071807847}, {
      49.34615859097786, 3.643856199476441}, {49.34615859097786, 
      5.446271489616925}}], 
     PolygonBox[{{49.34615859097786, 3.643856199476465}, {49.99999999999996, 
      4.038154071807874}, {49.999999999999936`, 2.023409310557568}, {
      49.34615859097786, 1.8258373576748426`}, {49.34615859097786, 
      3.643856199476465}}], 
     PolygonBox[{{49.34615859097786, 1.8258373576748426`}, {
      49.999999999999936`, 2.023409310557568}, {49.999999999999964`, 
      5.683126552293185*^-15}, {49.34615859097786, 5.128208471429541*^-15}, {
      49.34615859097786, 1.8258373576748426`}}], 
     PolygonBox[{{49.34615859097786, 5.128208471429541*^-15}, {
      49.999999999999964`, 5.683126552293185*^-15}, {
      49.999999999999964`, -2.023409310557557}, {
      49.34615859097786, -1.8258373576748324`}, {49.34615859097786, 
      5.128208471429541*^-15}}], 
     PolygonBox[{{49.34615859097786, -1.8258373576748077`}, {
      49.99999999999996, -2.0234093105575295`}, {
      49.99999999999996, -4.038154071807836}, {
      49.34615859097786, -3.643856199476431}, {
      49.34615859097786, -1.8258373576748077`}}], 
     PolygonBox[{{49.34615859097786, -3.643856199476431}, {
      49.99999999999996, -4.038154071807836}, {
      49.999999999999936`, -6.03560683737397}, {
      49.34615859097785, -5.446271489616914}, {
      49.34615859097786, -3.643856199476431}}], 
     PolygonBox[{{49.34615859097785, -5.4462714896168904`}, {
      49.99999999999997, -6.035606837373942}, {
      49.99999999999996, -8.00721420785922}, {
      49.34615859097786, -7.225365009112025}, {
      49.34615859097785, -5.4462714896168904`}}], 
     PolygonBox[{{49.34615859097786, -7.225365009112025}, {
      49.99999999999996, -8.00721420785922}, {
      49.999999999999964`, -9.944533457816558}, {
      49.34615859097785, -8.973518406379924}, {
      49.34615859097786, -7.225365009112025}}], 
     PolygonBox[{{49.34615859097785, -8.973518406379924}, {
      49.999999999999964`, -9.944533457816558}, {
      49.99999999999996, -11.839268688794972`}, {
      49.34615859097786, -10.683245820192095`}, {
      49.34615859097785, -8.973518406379924}}], 
     PolygonBox[{{49.34615859097786, -10.683245820192072`}, {
      49.999999999999964`, -11.839268688794945`}, {
      49.99999999999996, -13.683306353650345`}, {
      49.34615859097785, -12.347225935280445`}, {
      49.34615859097786, -10.683245820192072`}}], 
     PolygonBox[{{49.34615859097785, -12.347225935280445`}, {
      49.99999999999996, -13.683306353650345`}, {
      49.999999999999936`, -15.468750000000004`}, {
      49.34615859097785, -13.958333333333336`}, {
      49.34615859097785, -12.347225935280445`}}], 
     PolygonBox[{{49.34615859097786, -13.958333333333314`}, {
      49.999999999999964`, -15.46874999999998}, {
      49.999999999999964`, -17.18795408404393}, {
      49.34615859097786, -15.50966900513055}, {
      49.34615859097786, -13.958333333333314`}}], 
     PolygonBox[{{49.34615859097786, -15.50966900513055}, {
      49.999999999999964`, -17.18795408404393}, {
      49.99999999999996, -18.83355670995729}, {
      49.34615859097786, -16.994589893160114`}, {
      49.34615859097786, -15.50966900513055}}], 
     PolygonBox[{{49.34615859097786, -16.994589893160096`}, {
      49.999999999999964`, -18.83355670995727}, {
      49.999999999999964`, -20.398511154658365`}, {
      49.34615859097786, -18.40673733821024}, {
      49.34615859097786, -16.994589893160096`}}], 
     PolygonBox[{{49.34615859097786, -18.40673733821024}, {
      49.999999999999964`, -20.398511154658365`}, {
      49.999999999999964`, -21.87611604295881}, {
      49.34615859097786, -19.740064308124445`}, {
      49.34615859097786, -18.40673733821024}}], 
     PolygonBox[{{49.34615859097786, -19.740064308124445`}, {
      49.999999999999964`, -21.87611604295881}, {
      49.99999999999996, -23.260044043880864`}, {
      49.346158590977886`, -20.988861292121452`}, {
      49.34615859097786, -19.740064308124445`}}], 
     PolygonBox[{{49.34615859097786, -20.988861292121438`}, {
      49.999999999999964`, -23.26004404388085}, {
      49.999999999999964`, -24.54436896526008}, {
      49.34615859097785, -22.147780749796976`}, {
      49.34615859097786, -20.988861292121438`}}], 
     PolygonBox[{{49.34615859097785, -22.147780749796976`}, {
      49.999999999999964`, -24.54436896526008}, {
      49.999999999999964`, -25.723591130609993`}, {
      49.34615859097786, -23.21186001011272}, {
      49.34615859097785, -22.147780749796976`}}], 
     PolygonBox[{{49.34615859097786, -23.21186001011271}, {
      49.999999999999964`, -25.72359113060998}, {
      49.99999999999996, -26.79266092958106}, {
      49.34615859097785, -24.17654252231557}, {
      49.34615859097786, -23.21186001011271}}], 
     PolygonBox[{{49.34615859097785, -24.17654252231557}, {
      49.99999999999996, -26.79266092958106}, {
      49.999999999999936`, -27.747000441167543`}, {
      49.34615859097785, -25.037697367787548`}, {
      49.34615859097785, -24.17654252231557}}], 
     PolygonBox[{{49.34615859097786, -25.037697367787533`}, {
      49.999999999999964`, -27.74700044116753}, {
      49.999999999999936`, -28.58252303706793}, {
      49.34615859097785, -25.791636949273418`}, {
      49.34615859097786, -25.037697367787533`}}], 
     PolygonBox[{{49.34615859097785, -25.791636949273418`}, {
      49.999999999999936`, -28.58252303706793}, {
      49.999999999999964`, -29.29565088125483}, {
      49.34615859097786, -26.43513278173836}, {
      49.34615859097785, -25.791636949273418`}}], 
     PolygonBox[{{49.34615859097786, -26.43513278173836}, {
      49.999999999999964`, -29.29565088125483}, {
      49.99999999999996, -29.883330250818048`}, {
      49.34615859097785, -26.96542931723649}, {
      49.34615859097786, -26.43513278173836}}], 
     PolygonBox[{{49.34615859097785, -26.965429317236485`}, {
      49.999999999999964`, -29.883330250818045`}, {
      49.99999999999992, -30.343044612474934`}, {
      49.34615859097786, -27.38025574459018}, {
      49.34615859097785, -26.965429317236485`}}], 
     PolygonBox[{{49.34615859097786, -27.38025574459018}, {
      49.99999999999992, -30.343044612474934`}, {
      49.999999999999964`, -30.67282539875226}, {
      49.34615859097786, -27.677835713352206`}, {
      49.34615859097786, -27.38025574459018}}], 
     PolygonBox[{{49.34615859097786, -27.677835713352202`}, {
      49.99999999999996, -30.672825398752252`}, {
      49.999999999999936`, -30.871260437694296`}, {
      49.34615859097786, -27.856894940411014`}, {
      49.34615859097786, -27.677835713352202`}}], 
     PolygonBox[{{49.34615859097786, -27.856894940411014`}, {
      49.999999999999936`, -30.871260437694296`}, {
      49.999999999999964`, -30.9375}, {
      49.34615859097786, -27.916666666666664`}, {
      49.34615859097786, -27.856894940411014`}}], 
     PolygonBox[{{49.999999999999964`, -30.9375}, {
      50.653841409022064`, -33.958333333333336`}, {
      50.65384140902205, -33.88562593497758}, {
      49.999999999999964`, -30.871260437694296`}, {
      49.999999999999964`, -30.9375}}], 
     PolygonBox[{{49.999999999999964`, -30.871260437694296`}, {
      50.65384140902205, -33.88562593497758}, {
      50.653841409022064`, -33.667815084152316`}, {
      49.999999999999964`, -30.67282539875226}, {
      49.999999999999964`, -30.871260437694296`}}], 
     PolygonBox[{{49.999999999999964`, -30.67282539875226}, {
      50.653841409022064`, -33.667815084152316`}, {
      50.653841409022064`, -33.3058334803597}, {
      49.999999999999936`, -30.343044612474944`}, {
      49.999999999999964`, -30.67282539875226}}], 
     PolygonBox[{{49.999999999999936`, -30.343044612474944`}, {
      50.653841409022064`, -33.3058334803597}, {
      50.653841409022064`, -32.80123118439961}, {
      49.99999999999996, -29.883330250818048`}, {
      49.999999999999936`, -30.343044612474944`}}], 
     PolygonBox[{{49.99999999999996, -29.883330250818048`}, {
      50.653841409022064`, -32.80123118439961}, {
      50.653841409022064`, -32.1561689807713}, {
      49.999999999999964`, -29.295650881254833`}, {
      49.99999999999996, -29.883330250818048`}}], 
     PolygonBox[{{49.999999999999964`, -29.295650881254833`}, {
      50.653841409022064`, -32.1561689807713}, {
      50.653841409022064`, -31.373409124862448`}, {
      49.999999999999936`, -28.582523037067936`}, {
      49.999999999999964`, -29.295650881254833`}}], 
     PolygonBox[{{49.999999999999936`, -28.582523037067936`}, {
      50.653841409022064`, -31.373409124862448`}, {
      50.653841409022064`, -30.456303514547546`}, {
      49.999999999999964`, -27.747000441167547`}, {
      49.999999999999936`, -28.582523037067936`}}], 
     PolygonBox[{{49.999999999999964`, -27.747000441167547`}, {
      50.653841409022064`, -30.456303514547546`}, {
      50.653841409022064`, -29.408779336846568`}, {
      49.999999999999936`, -26.792660929581075`}, {
      49.999999999999964`, -27.747000441167547`}}], 
     PolygonBox[{{49.999999999999936`, -26.792660929581075`}, {
      50.653841409022064`, -29.408779336846568`}, {
      50.653841409022064`, -28.235322251107267`}, {
      49.999999999999964`, -25.723591130609993`}, {
      49.999999999999936`, -26.792660929581075`}}], 
     PolygonBox[{{49.999999999999964`, -25.723591130609993`}, {
      50.653841409022064`, -28.235322251107267`}, {
      50.65384140902208, -26.940957180723192`}, {
      49.999999999999964`, -24.544368965260087`}, {
      49.999999999999964`, -25.723591130609993`}}], 
     PolygonBox[{{49.999999999999964`, -24.54436896526009}, {
      50.653841409022064`, -26.9409571807232}, {
      50.653841409022064`, -25.531226795640276`}, {
      49.999999999999964`, -23.260044043880864`}, {
      49.999999999999964`, -24.54436896526009}}], 
     PolygonBox[{{49.999999999999964`, -23.260044043880864`}, {
      50.653841409022064`, -25.531226795640276`}, {
      50.653841409022064`, -24.012167777793177`}, {
      49.99999999999996, -21.876116042958813`}, {
      49.999999999999964`, -23.260044043880864`}}], 
     PolygonBox[{{49.99999999999996, -21.876116042958813`}, {
      50.653841409022064`, -24.012167777793177`}, {
      50.653841409022064`, -22.390284971106507`}, {
      49.999999999999964`, -20.39851115465838}, {
      49.99999999999996, -21.876116042958813`}}], 
     PolygonBox[{{49.999999999999936`, -20.398511154658387`}, {
      50.653841409022064`, -22.39028497110651}, {
      50.65384140902208, -20.67252352675447}, {
      49.999999999999964`, -18.833556709957293`}, {
      49.999999999999936`, -20.398511154658387`}}], 
     PolygonBox[{{49.999999999999964`, -18.833556709957293`}, {
      50.65384140902208, -20.67252352675447}, {
      50.653841409022064`, -18.866239162957328`}, {
      49.999999999999964`, -17.187954084043945`}, {
      49.999999999999964`, -18.833556709957293`}}], 
     PolygonBox[{{49.999999999999936`, -17.18795408404395}, {
      50.653841409022064`, -18.866239162957335`}, {
      50.653841409022064`, -16.97916666666667}, {
      49.999999999999936`, -15.468750000000004`}, {
      49.999999999999936`, -17.18795408404395}}], 
     PolygonBox[{{49.999999999999936`, -15.468750000000004`}, {
      50.653841409022064`, -16.97916666666667}, {
      50.653841409022064`, -15.019386772020258`}, {
      49.999999999999936`, -13.683306353650357`}, {
      49.999999999999936`, -15.468750000000004`}}], 
     PolygonBox[{{49.999999999999936`, -13.683306353650357`}, {
      50.653841409022064`, -15.019386772020258`}, {
      50.65384140902208, -12.995291557397849`}, {
      49.99999999999996, -11.839268688794972`}, {
      49.999999999999936`, -13.683306353650357`}}], 
     PolygonBox[{{49.999999999999936`, -11.839268688794967`}, {
      50.653841409022064`, -12.995291557397843`}, {
      50.65384140902208, -10.9155485092532}, {
      49.999999999999964`, -9.944533457816567}, {
      49.999999999999936`, -11.839268688794967`}}], 
     PolygonBox[{{49.999999999999964`, -9.944533457816567}, {
      50.65384140902208, -10.9155485092532}, {
      50.65384140902208, -8.789063406606441}, {
      49.99999999999996, -8.007214207859242}, {
      49.999999999999964`, -9.944533457816567}}], 
     PolygonBox[{{49.99999999999996, -8.007214207859242}, {
      50.65384140902208, -8.789063406606441}, {
      50.653841409022064`, -6.624942185131031}, {
      49.999999999999936`, -6.035606837373976}, {
      49.99999999999996, -8.007214207859242}}], 
     PolygonBox[{{49.999999999999936`, -6.035606837373971}, {
      50.653841409022064`, -6.624942185131024}, {
      50.653841409022064`, -4.432451944139256}, {
      49.999999999999964`, -4.03815407180785}, {
      49.999999999999936`, -6.035606837373971}}], 
     PolygonBox[{{49.999999999999964`, -4.03815407180785}, {
      50.653841409022064`, -4.432451944139256}, {
      50.65384140902205, -2.2209812634402817`}, {
      49.999999999999964`, -2.0234093105575575`}, {
      49.999999999999964`, -4.03815407180785}}], 
     PolygonBox[{{49.999999999999964`, -2.0234093105575575`}, {
      50.65384140902205, -2.2209812634402817`}, {
      50.653841409022064`, -9.619612919964799*^-15}, {
      49.999999999999964`, -8.763880482299218*^-15}, {
      49.999999999999964`, -2.0234093105575575`}}], 
     PolygonBox[{{49.999999999999964`, -1.894375517431062*^-15}, {
      50.653841409022064`, -2.079348211052277*^-15}, {50.65384140902205, 
      2.22098126344027}, {49.999999999999964`, 2.023409310557547}, {
      49.999999999999964`, -1.894375517431062*^-15}}], 
     PolygonBox[{{49.999999999999964`, 2.023409310557547}, {50.65384140902205,
       2.22098126344027}, {50.653841409022064`, 4.432451944139245}, {
      49.99999999999996, 4.03815407180784}, {49.999999999999964`, 
      2.023409310557547}}], 
     PolygonBox[{{49.99999999999996, 4.03815407180784}, {50.653841409022064`, 
      4.432451944139245}, {50.653841409022064`, 6.624942185131013}, {
      49.999999999999936`, 6.035606837373959}, {49.99999999999996, 
      4.03815407180784}}], 
     PolygonBox[{{49.999999999999936`, 6.035606837373959}, {
      50.653841409022064`, 6.624942185131013}, {50.65384140902208, 
      8.789063406606422}, {49.99999999999996, 8.007214207859224}, {
      49.999999999999936`, 6.035606837373959}}], 
     PolygonBox[{{49.99999999999996, 8.007214207859233}, {50.653841409022064`,
       8.78906340660643}, {50.65384140902208, 10.915548509253188`}, {
      49.999999999999964`, 9.944533457816554}, {49.99999999999996, 
      8.007214207859233}}], 
     PolygonBox[{{49.999999999999964`, 9.944533457816554}, {50.65384140902208,
       10.915548509253188`}, {50.65384140902208, 12.995291557397831`}, {
      49.999999999999964`, 11.839268688794956`}, {49.999999999999964`, 
      9.944533457816554}}], 
     PolygonBox[{{49.999999999999964`, 11.839268688794956`}, {
      50.65384140902208, 12.995291557397831`}, {50.653841409022064`, 
      15.019386772020248`}, {49.999999999999964`, 13.683306353650346`}, {
      49.999999999999964`, 11.839268688794956`}}], 
     PolygonBox[{{49.999999999999964`, 13.683306353650346`}, {
      50.653841409022064`, 15.019386772020248`}, {50.653841409022064`, 
      16.97916666666666}, {49.999999999999964`, 15.468749999999993`}, {
      49.999999999999964`, 13.683306353650346`}}], 
     PolygonBox[{{49.999999999999964`, 15.468749999999993`}, {
      50.653841409022064`, 16.97916666666666}, {50.653841409022064`, 
      18.866239162957317`}, {49.999999999999964`, 17.187954084043934`}, {
      49.999999999999964`, 15.468749999999993`}}], 
     PolygonBox[{{49.999999999999964`, 17.187954084043934`}, {
      50.653841409022064`, 18.866239162957317`}, {50.653841409022064`, 
      20.672523526754464`}, {49.999999999999964`, 18.833556709957286`}, {
      49.999999999999964`, 17.187954084043934`}}], 
     PolygonBox[{{49.999999999999964`, 18.833556709957286`}, {
      50.653841409022064`, 20.672523526754464`}, {50.653841409022064`, 
      22.390284971106492`}, {49.999999999999964`, 20.39851115465837}, {
      49.999999999999964`, 18.833556709957286`}}], 
     PolygonBox[{{49.999999999999964`, 20.39851115465837}, {
      50.653841409022064`, 22.390284971106492`}, {50.653841409022064`, 
      24.012167777793167`}, {49.999999999999936`, 21.876116042958806`}, {
      49.999999999999964`, 20.39851115465837}}], 
     PolygonBox[{{49.99999999999996, 21.876116042958813`}, {
      50.653841409022064`, 24.012167777793174`}, {50.653841409022064`, 
      25.531226795640272`}, {49.999999999999936`, 23.26004404388086}, {
      49.99999999999996, 21.876116042958813`}}], 
     PolygonBox[{{49.999999999999936`, 23.26004404388086}, {
      50.653841409022064`, 25.531226795640272`}, {50.653841409022064`, 
      26.940957180723192`}, {49.999999999999936`, 24.544368965260084`}, {
      49.999999999999936`, 23.26004404388086}}], 
     PolygonBox[{{49.999999999999936`, 24.544368965260084`}, {
      50.653841409022064`, 26.940957180723192`}, {50.653841409022064`, 
      28.23532225110726}, {49.99999999999996, 25.723591130609986`}, {
      49.999999999999936`, 24.544368965260084`}}], 
     PolygonBox[{{49.99999999999996, 25.723591130609986`}, {
      50.653841409022064`, 28.23532225110726}, {50.653841409022064`, 
      29.408779336846557`}, {49.999999999999964`, 26.792660929581064`}, {
      49.99999999999996, 25.723591130609986`}}], 
     PolygonBox[{{49.999999999999964`, 26.792660929581064`}, {
      50.653841409022064`, 29.408779336846557`}, {50.653841409022064`, 
      30.456303514547535`}, {49.99999999999997, 27.747000441167543`}, {
      49.999999999999964`, 26.792660929581064`}}], 
     PolygonBox[{{49.99999999999997, 27.747000441167543`}, {
      50.653841409022064`, 30.456303514547535`}, {50.653841409022064`, 
      31.37340912486244}, {49.999999999999936`, 28.58252303706793}, {
      49.99999999999997, 27.747000441167543`}}], 
     PolygonBox[{{49.999999999999936`, 28.582523037067936`}, {
      50.653841409022064`, 31.373409124862448`}, {50.65384140902208, 
      32.15616898077129}, {49.999999999999964`, 29.29565088125483}, {
      49.999999999999936`, 28.582523037067936`}}], 
     PolygonBox[{{49.999999999999964`, 29.29565088125483}, {50.65384140902208,
       32.15616898077129}, {50.65384140902208, 32.801231184399605`}, {
      49.99999999999996, 29.883330250818045`}, {49.999999999999964`, 
      29.29565088125483}}], 
     PolygonBox[{{49.99999999999996, 29.883330250818045`}, {50.65384140902208,
       32.801231184399605`}, {50.653841409022064`, 33.3058334803597}, {
      49.99999999999997, 30.343044612474944`}, {49.99999999999996, 
      29.883330250818045`}}], 
     PolygonBox[{{49.99999999999997, 30.343044612474944`}, {
      50.653841409022064`, 33.3058334803597}, {50.653841409022064`, 
      33.667815084152316`}, {49.999999999999936`, 30.67282539875226}, {
      49.99999999999997, 30.343044612474944`}}], 
     PolygonBox[{{49.999999999999936`, 30.67282539875226}, {
      50.653841409022064`, 33.667815084152316`}, {50.65384140902205, 
      33.88562593497758}, {49.999999999999936`, 30.871260437694296`}, {
      49.999999999999936`, 30.67282539875226}}], 
     PolygonBox[{{49.999999999999936`, 30.871260437694296`}, {
      50.65384140902205, 33.88562593497758}, {50.653841409022064`, 
      33.958333333333336`}, {49.999999999999964`, 30.9375}, {
      49.999999999999936`, 30.871260437694296`}}], 
     PolygonBox[{{49.999999999999964`, 30.9375}, {50.653841409022064`, 
      33.958333333333336`}, {50.65384140902205, 33.88562593497758}, {
      49.999999999999964`, 30.871260437694296`}, {49.999999999999964`, 
      30.9375}}], 
     PolygonBox[{{49.999999999999964`, 30.871260437694296`}, {
      50.65384140902205, 33.88562593497758}, {50.653841409022064`, 
      33.667815084152316`}, {49.99999999999996, 30.67282539875226}, {
      49.999999999999964`, 30.871260437694296`}}], 
     PolygonBox[{{49.99999999999996, 30.67282539875226}, {50.653841409022064`,
       33.667815084152316`}, {50.653841409022064`, 33.3058334803597}, {
      49.999999999999964`, 30.343044612474944`}, {49.99999999999996, 
      30.67282539875226}}], 
     PolygonBox[{{49.999999999999964`, 30.343044612474944`}, {
      50.653841409022064`, 33.3058334803597}, {50.65384140902208, 
      32.80123118439961}, {49.99999999999996, 29.88333025081805}, {
      49.999999999999964`, 30.343044612474944`}}], 
     PolygonBox[{{49.99999999999996, 29.88333025081805}, {50.65384140902208, 
      32.80123118439961}, {50.65384140902208, 32.1561689807713}, {
      49.99999999999996, 29.295650881254833`}, {49.99999999999996, 
      29.88333025081805}}], 
     PolygonBox[{{49.99999999999996, 29.295650881254833`}, {50.65384140902208,
       32.1561689807713}, {50.653841409022064`, 31.373409124862455`}, {
      49.999999999999936`, 28.582523037067944`}, {49.99999999999996, 
      29.295650881254833`}}], 
     PolygonBox[{{49.999999999999936`, 28.582523037067944`}, {
      50.653841409022064`, 31.373409124862455`}, {50.653841409022064`, 
      30.456303514547553`}, {49.999999999999964`, 27.747000441167554`}, {
      49.999999999999936`, 28.582523037067944`}}], 
     PolygonBox[{{49.99999999999996, 27.747000441167547`}, {
      50.653841409022064`, 30.456303514547546`}, {50.653841409022064`, 
      29.408779336846568`}, {49.999999999999964`, 26.792660929581075`}, {
      49.99999999999996, 27.747000441167547`}}], 
     PolygonBox[{{49.999999999999964`, 26.792660929581075`}, {
      50.653841409022064`, 29.408779336846568`}, {50.653841409022064`, 
      28.235322251107274`}, {49.999999999999964`, 25.72359113061}, {
      49.999999999999964`, 26.792660929581075`}}], 
     PolygonBox[{{49.999999999999964`, 25.72359113061}, {50.653841409022064`, 
      28.235322251107274`}, {50.653841409022064`, 26.940957180723203`}, {
      49.999999999999964`, 24.544368965260094`}, {49.999999999999964`, 
      25.72359113061}}], 
     PolygonBox[{{49.999999999999964`, 24.544368965260094`}, {
      50.653841409022064`, 26.940957180723203`}, {50.653841409022064`, 
      25.531226795640286`}, {49.999999999999964`, 23.260044043880875`}, {
      49.999999999999964`, 24.544368965260094`}}], 
     PolygonBox[{{49.999999999999964`, 23.260044043880875`}, {
      50.653841409022064`, 25.531226795640286`}, {50.653841409022064`, 
      24.01216777779319}, {49.999999999999936`, 21.876116042958827`}, {
      49.999999999999964`, 23.260044043880875`}}], 
     PolygonBox[{{49.999999999999936`, 21.876116042958827`}, {
      50.653841409022064`, 24.01216777779319}, {50.653841409022064`, 
      22.390284971106524`}, {49.999999999999964`, 20.398511154658397`}, {
      49.999999999999936`, 21.876116042958827`}}], 
     PolygonBox[{{49.999999999999936`, 20.398511154658387`}, {
      50.653841409022064`, 22.390284971106514`}, {50.653841409022064`, 
      20.672523526754482`}, {49.999999999999964`, 18.833556709957303`}, {
      49.999999999999936`, 20.398511154658387`}}], 
     PolygonBox[{{49.999999999999964`, 18.833556709957303`}, {
      50.653841409022064`, 20.672523526754482`}, {50.653841409022064`, 
      18.866239162957328`}, {49.999999999999964`, 17.187954084043945`}, {
      49.999999999999964`, 18.833556709957303`}}], 
     PolygonBox[{{49.999999999999964`, 17.187954084043966`}, {
      50.653841409022064`, 18.86623916295735}, {50.653841409022064`, 
      16.979166666666686`}, {49.99999999999996, 15.468750000000016`}, {
      49.999999999999964`, 17.187954084043966`}}], 
     PolygonBox[{{49.99999999999996, 15.468750000000016`}, {
      50.653841409022064`, 16.979166666666686`}, {50.653841409022064`, 
      15.019386772020255`}, {49.999999999999936`, 13.683306353650355`}, {
      49.99999999999996, 15.468750000000016`}}], 
     PolygonBox[{{49.999999999999936`, 13.683306353650355`}, {
      50.653841409022064`, 15.019386772020255`}, {50.65384140902208, 
      12.995291557397831`}, {49.999999999999964`, 11.839268688794956`}, {
      49.999999999999936`, 13.683306353650355`}}], 
     PolygonBox[{{49.999999999999936`, 11.839268688794983`}, {
      50.653841409022064`, 12.99529155739786}, {50.65384140902208, 
      10.915548509253204`}, {49.999999999999964`, 9.944533457816569}, {
      49.999999999999936`, 11.839268688794983`}}], 
     PolygonBox[{{49.999999999999964`, 9.944533457816569}, {50.65384140902208,
       10.915548509253204`}, {50.653841409022064`, 8.78906340660643}, {
      49.99999999999996, 8.007214207859233}, {49.999999999999964`, 
      9.944533457816569}}], 
     PolygonBox[{{49.999999999999964`, 8.00721420785926}, {
      50.653841409022064`, 8.78906340660646}, {50.65384140902208, 
      6.624942185131036}, {49.99999999999992, 6.03560683737398}, {
      49.999999999999964`, 8.00721420785926}}], 
     PolygonBox[{{49.99999999999992, 6.03560683737398}, {50.65384140902208, 
      6.624942185131036}, {50.653841409022064`, 4.432451944139253}, {
      49.999999999999964`, 4.038154071807847}, {49.99999999999992, 
      6.03560683737398}}], 
     PolygonBox[{{49.99999999999996, 4.038154071807874}, {50.653841409022064`,
       4.432451944139283}, {50.65384140902205, 2.2209812634402937`}, {
      49.999999999999936`, 2.023409310557568}, {49.99999999999996, 
      4.038154071807874}}], 
     PolygonBox[{{49.999999999999936`, 2.023409310557568}, {50.65384140902205,
       2.2209812634402937`}, {50.653841409022064`, 
      6.2380446331568295`*^-15}, {49.999999999999964`, 
      5.683126552293185*^-15}, {49.999999999999936`, 2.023409310557568}}], 
     PolygonBox[{{49.999999999999964`, 5.683126552293185*^-15}, {
      50.653841409022064`, 6.2380446331568295`*^-15}, {
      50.65384140902205, -2.2209812634402812`}, {
      49.999999999999964`, -2.023409310557557}, {49.999999999999964`, 
      5.683126552293185*^-15}}], 
     PolygonBox[{{49.99999999999996, -2.0234093105575295`}, {
      50.653841409022064`, -2.2209812634402515`}, {
      50.653841409022064`, -4.432451944139241}, {
      49.99999999999996, -4.038154071807836}, {
      49.99999999999996, -2.0234093105575295`}}], 
     PolygonBox[{{49.99999999999996, -4.038154071807836}, {
      50.653841409022064`, -4.432451944139241}, {
      50.653841409022064`, -6.624942185131024}, {
      49.999999999999936`, -6.03560683737397}, {
      49.99999999999996, -4.038154071807836}}], 
     PolygonBox[{{49.99999999999997, -6.035606837373942}, {
      50.653841409022064`, -6.624942185130994}, {
      50.65384140902208, -8.789063406606418}, {
      49.99999999999996, -8.00721420785922}, {
      49.99999999999997, -6.035606837373942}}], 
     PolygonBox[{{49.99999999999996, -8.00721420785922}, {
      50.65384140902208, -8.789063406606418}, {
      50.653841409022064`, -10.915548509253192`}, {
      49.999999999999964`, -9.944533457816558}, {
      49.99999999999996, -8.00721420785922}}], 
     PolygonBox[{{49.999999999999964`, -9.944533457816558}, {
      50.653841409022064`, -10.915548509253192`}, {
      50.65384140902208, -12.995291557397849`}, {
      49.99999999999996, -11.839268688794972`}, {
      49.999999999999964`, -9.944533457816558}}], 
     PolygonBox[{{49.999999999999964`, -11.839268688794945`}, {
      50.653841409022064`, -12.99529155739782}, {
      50.653841409022064`, -15.019386772020244`}, {
      49.99999999999996, -13.683306353650345`}, {
      49.999999999999964`, -11.839268688794945`}}], 
     PolygonBox[{{49.99999999999996, -13.683306353650345`}, {
      50.653841409022064`, -15.019386772020244`}, {
      50.653841409022064`, -16.97916666666667}, {
      49.999999999999936`, -15.468750000000004`}, {
      49.99999999999996, -13.683306353650345`}}], 
     PolygonBox[{{49.999999999999964`, -15.46874999999998}, {
      50.653841409022064`, -16.979166666666643`}, {
      50.653841409022064`, -18.866239162957314`}, {
      49.999999999999964`, -17.18795408404393}, {
      49.999999999999964`, -15.46874999999998}}], 
     PolygonBox[{{49.999999999999964`, -17.18795408404393}, {
      50.653841409022064`, -18.866239162957314`}, {
      50.65384140902208, -20.672523526754468`}, {
      49.99999999999996, -18.83355670995729}, {
      49.999999999999964`, -17.18795408404393}}], 
     PolygonBox[{{49.999999999999964`, -18.83355670995727}, {
      50.653841409022064`, -20.672523526754446`}, {
      50.653841409022064`, -22.39028497110649}, {
      49.999999999999964`, -20.398511154658365`}, {
      49.999999999999964`, -18.83355670995727}}], 
     PolygonBox[{{49.999999999999964`, -20.398511154658365`}, {
      50.653841409022064`, -22.39028497110649}, {
      50.653841409022064`, -24.012167777793174`}, {
      49.999999999999964`, -21.87611604295881}, {
      49.999999999999964`, -20.398511154658365`}}], 
     PolygonBox[{{49.999999999999964`, -21.87611604295881}, {
      50.653841409022064`, -24.012167777793174`}, {
      50.653841409022064`, -25.53122679564028}, {
      49.99999999999996, -23.260044043880864`}, {
      49.999999999999964`, -21.87611604295881}}], 
     PolygonBox[{{49.999999999999964`, -23.26004404388085}, {
      50.653841409022064`, -25.531226795640258`}, {
      50.653841409022064`, -26.94095718072319}, {
      49.999999999999964`, -24.54436896526008}, {
      49.999999999999964`, -23.26004404388085}}], 
     PolygonBox[{{49.999999999999964`, -24.54436896526008}, {
      50.653841409022064`, -26.94095718072319}, {
      50.653841409022064`, -28.235322251107267`}, {
      49.999999999999964`, -25.723591130609993`}, {
      49.999999999999964`, -24.54436896526008}}], 
     PolygonBox[{{49.999999999999964`, -25.72359113060998}, {
      50.653841409022064`, -28.235322251107252`}, {
      50.653841409022064`, -29.408779336846553`}, {
      49.99999999999996, -26.79266092958106}, {
      49.999999999999964`, -25.72359113060998}}], 
     PolygonBox[{{49.99999999999996, -26.79266092958106}, {
      50.653841409022064`, -29.408779336846553`}, {
      50.653841409022064`, -30.45630351454754}, {
      49.999999999999936`, -27.747000441167543`}, {
      49.99999999999996, -26.79266092958106}}], 
     PolygonBox[{{49.999999999999964`, -27.74700044116753}, {
      50.653841409022064`, -30.456303514547525`}, {
      50.653841409022064`, -31.37340912486244}, {
      49.999999999999936`, -28.58252303706793}, {
      49.999999999999964`, -27.74700044116753}}], 
     PolygonBox[{{49.999999999999936`, -28.58252303706793}, {
      50.653841409022064`, -31.37340912486244}, {
      50.65384140902208, -32.15616898077129}, {
      49.999999999999964`, -29.29565088125483}, {
      49.999999999999936`, -28.58252303706793}}], 
     PolygonBox[{{49.999999999999964`, -29.29565088125483}, {
      50.65384140902208, -32.15616898077129}, {
      50.653841409022064`, -32.80123118439961}, {
      49.99999999999996, -29.883330250818048`}, {
      49.999999999999964`, -29.29565088125483}}], 
     PolygonBox[{{49.999999999999964`, -29.883330250818045`}, {
      50.653841409022064`, -32.801231184399605`}, {
      50.65384140902208, -33.305833480359695`}, {
      49.99999999999992, -30.343044612474934`}, {
      49.999999999999964`, -29.883330250818045`}}], 
     PolygonBox[{{49.99999999999992, -30.343044612474934`}, {
      50.65384140902208, -33.305833480359695`}, {
      50.653841409022064`, -33.667815084152316`}, {
      49.999999999999964`, -30.67282539875226}, {
      49.99999999999992, -30.343044612474934`}}], 
     PolygonBox[{{49.99999999999996, -30.672825398752252`}, {
      50.653841409022064`, -33.66781508415231}, {
      50.65384140902205, -33.88562593497758}, {
      49.999999999999936`, -30.871260437694296`}, {
      49.99999999999996, -30.672825398752252`}}], 
     PolygonBox[{{49.999999999999936`, -30.871260437694296`}, {
      50.65384140902205, -33.88562593497758}, {
      50.653841409022064`, -33.958333333333336`}, {
      49.999999999999964`, -30.9375}, {
      49.999999999999936`, -30.871260437694296`}}], 
     PolygonBox[{{50.65384140902208, -33.95833333333333}, {
      33.98717474235546, -36.979166666666664`}, {
      33.987174742355506`, -36.899991432260855`}, {
      50.65384140902208, -33.885625934977575`}, {
      50.65384140902208, -33.95833333333333}}], 
     PolygonBox[{{50.65384140902208, -33.885625934977575`}, {
      33.987174742355506`, -36.899991432260855`}, {
      33.987174742355506`, -36.66280476955236}, {
      50.65384140902208, -33.66781508415231}, {
      50.65384140902208, -33.885625934977575`}}], 
     PolygonBox[{{50.65384140902208, -33.66781508415231}, {
      33.987174742355506`, -36.66280476955236}, {
      33.98717474235546, -36.268622348244456`}, {
      50.653841409022064`, -33.3058334803597}, {
      50.65384140902208, -33.66781508415231}}], 
     PolygonBox[{{50.653841409022064`, -33.3058334803597}, {
      33.98717474235546, -36.268622348244456`}, {
      33.98717474235546, -35.71913211798117}, {
      50.653841409022064`, -32.80123118439961}, {
      50.653841409022064`, -33.3058334803597}}], 
     PolygonBox[{{50.653841409022064`, -32.80123118439961}, {
      33.98717474235546, -35.71913211798117}, {
      33.987174742355364`, -35.01668708028777}, {
      50.653841409022064`, -32.1561689807713}, {
      50.653841409022064`, -32.80123118439961}}], 
     PolygonBox[{{50.653841409022064`, -32.1561689807713}, {
      33.987174742355364`, -35.01668708028777}, {
      33.98717474235546, -34.16429521265696}, {
      50.65384140902208, -31.373409124862444`}, {
      50.653841409022064`, -32.1561689807713}}], 
     PolygonBox[{{50.65384140902208, -31.373409124862444`}, {
      33.98717474235546, -34.16429521265696}, {
      33.98717474235546, -33.165606587927535`}, {
      50.653841409022064`, -30.456303514547542`}, {
      50.65384140902208, -31.373409124862444`}}], 
     PolygonBox[{{50.653841409022064`, -30.456303514547542`}, {
      33.98717474235546, -33.165606587927535`}, {
      33.98717474235546, -32.02489774411205}, {
      50.65384140902208, -29.408779336846564`}, {
      50.653841409022064`, -30.456303514547542`}}], 
     PolygonBox[{{50.65384140902208, -29.408779336846564`}, {
      33.98717474235546, -32.02489774411205}, {
      33.98717474235546, -30.747053371604537`}, {
      50.65384140902208, -28.235322251107263`}, {
      50.65384140902208, -29.408779336846564`}}], 
     PolygonBox[{{50.65384140902208, -28.235322251107263`}, {
      33.98717474235546, -30.747053371604537`}, {
      33.98717474235546, -29.337545396186297`}, {
      50.65384140902208, -26.940957180723192`}, {
      50.65384140902208, -28.235322251107263`}}], 
     PolygonBox[{{50.65384140902208, -26.940957180723196`}, {
      33.98717474235546, -29.337545396186304`}, {
      33.98717474235546, -27.802409547399684`}, {
      50.65384140902208, -25.531226795640272`}, {
      50.65384140902208, -26.940957180723196`}}], 
     PolygonBox[{{50.65384140902208, -25.531226795640272`}, {
      33.98717474235546, -27.802409547399684`}, {
      33.98717474235546, -26.148219512627538`}, {
      50.65384140902208, -24.012167777793174`}, {
      50.65384140902208, -25.531226795640272`}}], 
     PolygonBox[{{50.65384140902208, -24.012167777793174`}, {
      33.98717474235546, -26.148219512627538`}, {
      33.98717474235546, -24.382058787554627`}, {
      50.65384140902208, -22.390284971106503`}, {
      50.65384140902208, -24.012167777793174`}}], 
     PolygonBox[{{50.653841409022064`, -22.39028497110651}, {
      33.98717474235546, -24.382058787554634`}, {
      33.98717474235546, -22.511490343551646`}, {
      50.65384140902208, -20.672523526754468`}, {
      50.653841409022064`, -22.39028497110651}}], 
     PolygonBox[{{50.65384140902208, -20.672523526754468`}, {
      33.98717474235546, -22.511490343551646`}, {
      33.98717474235546, -20.54452424187071}, {
      50.653841409022064`, -18.866239162957328`}, {
      50.65384140902208, -20.672523526754468`}}], 
     PolygonBox[{{50.65384140902208, -18.86623916295733}, {
      33.987174742355364`, -20.544524241870715`}, {
      33.98717474235546, -18.489583333333336`}, {
      50.653841409022064`, -16.979166666666668`}, {
      50.65384140902208, -18.86623916295733}}], 
     PolygonBox[{{50.653841409022064`, -16.979166666666668`}, {
      33.98717474235546, -18.489583333333336`}, {
      33.98717474235546, -16.355467190390154`}, {
      50.65384140902208, -15.019386772020257`}, {
      50.653841409022064`, -16.979166666666668`}}], 
     PolygonBox[{{50.65384140902208, -15.019386772020257`}, {
      33.98717474235546, -16.355467190390154`}, {
      33.98717474235546, -14.151314426000724`}, {
      50.65384140902208, -12.995291557397847`}, {
      50.65384140902208, -15.019386772020257`}}], 
     PolygonBox[{{50.65384140902208, -12.995291557397842`}, {
      33.98717474235546, -14.151314426000717`}, {
      33.987174742355506`, -11.886563560689835`}, {
      50.65384140902208, -10.915548509253199`}, {
      50.65384140902208, -12.995291557397842`}}], 
     PolygonBox[{{50.65384140902208, -10.915548509253199`}, {
      33.987174742355506`, -11.886563560689835`}, {
      33.987174742355506`, -9.570912605353639}, {
      50.65384140902208, -8.789063406606441}, {
      50.65384140902208, -10.915548509253199`}}], 
     PolygonBox[{{50.65384140902208, -8.789063406606441}, {
      33.987174742355506`, -9.570912605353639}, {
      33.98717474235546, -7.214277532888086}, {
      50.653841409022064`, -6.62494218513103}, {
      50.65384140902208, -8.789063406606441}}], 
     PolygonBox[{{50.653841409022064`, -6.624942185131024}, {
      33.98717474235546, -7.2142775328880795`}, {
      33.987174742355506`, -4.826749816470662}, {
      50.65384140902208, -4.432451944139255}, {
      50.653841409022064`, -6.624942185131024}}], 
     PolygonBox[{{50.65384140902208, -4.432451944139255}, {
      33.987174742355506`, -4.826749816470662}, {
      33.98717474235546, -2.418553216323006}, {
      50.65384140902208, -2.2209812634402817`}, {
      50.65384140902208, -4.432451944139255}}], 
     PolygonBox[{{50.65384140902208, -2.2209812634402817`}, {
      33.98717474235546, -2.418553216323006}, {
      33.98717474235546, -1.0475345357630377`*^-14}, {
      50.65384140902208, -9.619612919964797*^-15}, {
      50.65384140902208, -2.2209812634402817`}}], 
     PolygonBox[{{50.65384140902208, -2.0793482110522766`*^-15}, {
      33.98717474235546, -2.2643209046734916`*^-15}, {33.987174742355506`, 
      2.4185532163229935`}, {50.65384140902208, 2.22098126344027}, {
      50.65384140902208, -2.0793482110522766`*^-15}}], 
     PolygonBox[{{50.65384140902208, 2.22098126344027}, {33.987174742355506`, 
      2.4185532163229935`}, {33.987174742355506`, 4.826749816470651}, {
      50.65384140902208, 4.4324519441392445`}, {50.65384140902208, 
      2.22098126344027}}], 
     PolygonBox[{{50.65384140902208, 4.4324519441392445`}, {
      33.987174742355506`, 4.826749816470651}, {33.987174742355506`, 
      7.214277532888065}, {50.653841409022064`, 6.624942185131012}, {
      50.65384140902208, 4.4324519441392445`}}], 
     PolygonBox[{{50.653841409022064`, 6.624942185131012}, {
      33.987174742355506`, 7.214277532888065}, {33.987174742355506`, 
      9.570912605353618}, {50.65384140902208, 8.789063406606422}, {
      50.653841409022064`, 6.624942185131012}}], 
     PolygonBox[{{50.653841409022064`, 8.789063406606429}, {
      33.987174742355506`, 9.570912605353628}, {33.98717474235546, 
      11.88656356068982}, {50.65384140902208, 10.915548509253187`}, {
      50.653841409022064`, 8.789063406606429}}], 
     PolygonBox[{{50.65384140902208, 10.915548509253187`}, {33.98717474235546,
       11.88656356068982}, {33.98717474235546, 14.151314426000704`}, {
      50.65384140902208, 12.99529155739783}, {50.65384140902208, 
      10.915548509253187`}}], 
     PolygonBox[{{50.65384140902208, 12.99529155739783}, {33.98717474235546, 
      14.151314426000704`}, {33.98717474235546, 16.355467190390147`}, {
      50.653841409022064`, 15.019386772020246`}, {50.65384140902208, 
      12.99529155739783}}], 
     PolygonBox[{{50.653841409022064`, 15.019386772020246`}, {
      33.98717474235546, 16.355467190390147`}, {33.98717474235546, 
      18.489583333333325`}, {50.65384140902208, 16.979166666666657`}, {
      50.653841409022064`, 15.019386772020246`}}], 
     PolygonBox[{{50.65384140902208, 16.979166666666657`}, {33.98717474235546,
       18.489583333333325`}, {33.98717474235546, 20.544524241870693`}, {
      50.65384140902208, 18.866239162957314`}, {50.65384140902208, 
      16.979166666666657`}}], 
     PolygonBox[{{50.65384140902208, 18.866239162957314`}, {33.98717474235546,
       20.544524241870693`}, {33.98717474235546, 22.511490343551635`}, {
      50.65384140902208, 20.67252352675446}, {50.65384140902208, 
      18.866239162957314`}}], 
     PolygonBox[{{50.65384140902208, 20.67252352675446}, {33.98717474235546, 
      22.511490343551635`}, {33.987174742355364`, 24.382058787554616`}, {
      50.65384140902208, 22.390284971106492`}, {50.65384140902208, 
      20.67252352675446}}], 
     PolygonBox[{{50.65384140902208, 22.390284971106492`}, {
      33.987174742355364`, 24.382058787554616`}, {33.987174742355364`, 
      26.148219512627527`}, {50.65384140902208, 24.01216777779316}, {
      50.65384140902208, 22.390284971106492`}}], 
     PolygonBox[{{50.65384140902208, 24.012167777793174`}, {33.98717474235546,
       26.148219512627534`}, {33.98717474235546, 27.80240954739968}, {
      50.653841409022064`, 25.53122679564027}, {50.65384140902208, 
      24.012167777793174`}}], 
     PolygonBox[{{50.653841409022064`, 25.53122679564027}, {33.98717474235546,
       27.80240954739968}, {33.98717474235546, 29.337545396186293`}, {
      50.653841409022064`, 26.94095718072319}, {50.653841409022064`, 
      25.53122679564027}}], 
     PolygonBox[{{50.653841409022064`, 26.94095718072319}, {33.98717474235546,
       29.337545396186293`}, {33.98717474235546, 30.747053371604526`}, {
      50.65384140902208, 28.235322251107256`}, {50.653841409022064`, 
      26.94095718072319}}], 
     PolygonBox[{{50.65384140902208, 28.235322251107256`}, {33.98717474235546,
       30.747053371604526`}, {33.98717474235546, 32.024897744112046`}, {
      50.65384140902208, 29.408779336846553`}, {50.65384140902208, 
      28.235322251107256`}}], 
     PolygonBox[{{50.65384140902208, 29.408779336846553`}, {33.98717474235546,
       32.024897744112046`}, {33.987174742355364`, 33.165606587927535`}, {
      50.653841409022064`, 30.456303514547535`}, {50.65384140902208, 
      29.408779336846553`}}], 
     PolygonBox[{{50.653841409022064`, 30.456303514547535`}, {
      33.987174742355364`, 33.165606587927535`}, {33.987174742355364`, 
      34.16429521265695}, {50.65384140902208, 31.373409124862437`}, {
      50.653841409022064`, 30.456303514547535`}}], 
     PolygonBox[{{50.653841409022064`, 31.373409124862444`}, {
      33.987174742355364`, 34.16429521265696}, {33.987174742355506`, 
      35.01668708028775}, {50.65384140902208, 32.15616898077129}, {
      50.653841409022064`, 31.373409124862444`}}], 
     PolygonBox[{{50.65384140902208, 32.15616898077129}, {33.987174742355506`,
       35.01668708028775}, {33.987174742355506`, 35.71913211798116}, {
      50.65384140902208, 32.801231184399605`}, {50.65384140902208, 
      32.15616898077129}}], 
     PolygonBox[{{50.65384140902208, 32.801231184399605`}, {
      33.987174742355506`, 35.71913211798116}, {33.98717474235546, 
      36.268622348244456`}, {50.653841409022064`, 33.3058334803597}, {
      50.65384140902208, 32.801231184399605`}}], 
     PolygonBox[{{50.653841409022064`, 33.3058334803597}, {33.98717474235546, 
      36.268622348244456`}, {33.98717474235546, 36.66280476955236}, {
      50.65384140902208, 33.66781508415231}, {50.653841409022064`, 
      33.3058334803597}}], 
     PolygonBox[{{50.65384140902208, 33.66781508415231}, {33.98717474235546, 
      36.66280476955236}, {33.98717474235546, 36.899991432260855`}, {
      50.65384140902208, 33.885625934977575`}, {50.65384140902208, 
      33.66781508415231}}], 
     PolygonBox[{{50.65384140902208, 33.885625934977575`}, {33.98717474235546,
       36.899991432260855`}, {33.98717474235546, 36.979166666666664`}, {
      50.65384140902208, 33.95833333333333}, {50.65384140902208, 
      33.885625934977575`}}], 
     PolygonBox[{{50.65384140902208, 33.95833333333333}, {33.98717474235546, 
      36.979166666666664`}, {33.987174742355506`, 36.899991432260855`}, {
      50.65384140902208, 33.885625934977575`}, {50.65384140902208, 
      33.95833333333333}}], 
     PolygonBox[{{50.65384140902208, 33.885625934977575`}, {
      33.987174742355506`, 36.899991432260855`}, {33.987174742355506`, 
      36.66280476955236}, {50.65384140902208, 33.66781508415231}, {
      50.65384140902208, 33.885625934977575`}}], 
     PolygonBox[{{50.65384140902208, 33.66781508415231}, {33.987174742355506`,
       36.66280476955236}, {33.987174742355506`, 36.268622348244456`}, {
      50.653841409022064`, 33.3058334803597}, {50.65384140902208, 
      33.66781508415231}}], 
     PolygonBox[{{50.653841409022064`, 33.3058334803597}, {
      33.987174742355506`, 36.268622348244456`}, {33.987174742355506`, 
      35.71913211798117}, {50.65384140902208, 32.80123118439961}, {
      50.653841409022064`, 33.3058334803597}}], 
     PolygonBox[{{50.65384140902208, 32.80123118439961}, {33.987174742355506`,
       35.71913211798117}, {33.98717474235546, 35.01668708028777}, {
      50.65384140902208, 32.1561689807713}, {50.65384140902208, 
      32.80123118439961}}], 
     PolygonBox[{{50.65384140902208, 32.1561689807713}, {33.98717474235546, 
      35.01668708028777}, {33.98717474235546, 34.16429521265697}, {
      50.653841409022064`, 31.373409124862455`}, {50.65384140902208, 
      32.1561689807713}}], 
     PolygonBox[{{50.653841409022064`, 31.373409124862455`}, {
      33.98717474235546, 34.16429521265697}, {33.987174742355506`, 
      33.16560658792754}, {50.65384140902208, 30.45630351454755}, {
      50.653841409022064`, 31.373409124862455`}}], 
     PolygonBox[{{50.65384140902208, 30.456303514547542`}, {
      33.987174742355506`, 33.165606587927535`}, {33.98717474235546, 
      32.02489774411206}, {50.653841409022064`, 29.408779336846568`}, {
      50.65384140902208, 30.456303514547542`}}], 
     PolygonBox[{{50.653841409022064`, 29.408779336846568`}, {
      33.98717474235546, 32.02489774411206}, {33.98717474235546, 
      30.747053371604544`}, {50.65384140902208, 28.23532225110727}, {
      50.653841409022064`, 29.408779336846568`}}], 
     PolygonBox[{{50.65384140902208, 28.23532225110727}, {33.98717474235546, 
      30.747053371604544`}, {33.98717474235546, 29.337545396186307`}, {
      50.65384140902208, 26.9409571807232}, {50.65384140902208, 
      28.23532225110727}}], 
     PolygonBox[{{50.65384140902208, 26.9409571807232}, {33.98717474235546, 
      29.337545396186307`}, {33.987174742355364`, 27.802409547399698`}, {
      50.65384140902208, 25.531226795640283`}, {50.65384140902208, 
      26.9409571807232}}], 
     PolygonBox[{{50.65384140902208, 25.531226795640283`}, {
      33.987174742355364`, 27.802409547399698`}, {33.987174742355364`, 
      26.148219512627552`}, {50.65384140902208, 24.012167777793188`}, {
      50.65384140902208, 25.531226795640283`}}], 
     PolygonBox[{{50.65384140902208, 24.012167777793188`}, {
      33.987174742355364`, 26.148219512627552`}, {33.98717474235546, 
      24.382058787554648`}, {50.65384140902208, 22.39028497110652}, {
      50.65384140902208, 24.012167777793188`}}], 
     PolygonBox[{{50.653841409022064`, 22.390284971106514`}, {
      33.987174742355364`, 24.382058787554637`}, {33.98717474235546, 
      22.511490343551657`}, {50.65384140902208, 20.67252352675448}, {
      50.653841409022064`, 22.390284971106514`}}], 
     PolygonBox[{{50.65384140902208, 20.67252352675448}, {33.98717474235546, 
      22.511490343551657`}, {33.98717474235546, 20.544524241870704`}, {
      50.65384140902208, 18.86623916295732}, {50.65384140902208, 
      20.67252352675448}}], 
     PolygonBox[{{50.65384140902208, 18.866239162957346`}, {
      33.987174742355364`, 20.544524241870732`}, {33.98717474235546, 
      18.48958333333335}, {50.65384140902208, 16.979166666666682`}, {
      50.65384140902208, 18.866239162957346`}}], 
     PolygonBox[{{50.65384140902208, 16.979166666666682`}, {33.98717474235546,
       18.48958333333335}, {33.98717474235546, 16.35546719039015}, {
      50.65384140902208, 15.019386772020253`}, {50.65384140902208, 
      16.979166666666682`}}], 
     PolygonBox[{{50.65384140902208, 15.019386772020253`}, {33.98717474235546,
       16.35546719039015}, {33.98717474235546, 14.151314426000704`}, {
      50.65384140902208, 12.99529155739783}, {50.65384140902208, 
      15.019386772020253`}}], 
     PolygonBox[{{50.65384140902208, 12.995291557397858`}, {
      33.987174742355364`, 14.151314426000736`}, {33.987174742355506`, 
      11.886563560689837`}, {50.65384140902208, 10.915548509253203`}, {
      50.65384140902208, 12.995291557397858`}}], 
     PolygonBox[{{50.65384140902208, 10.915548509253203`}, {
      33.987174742355506`, 11.886563560689837`}, {33.987174742355506`, 
      9.570912605353628}, {50.653841409022064`, 8.789063406606429}, {
      50.65384140902208, 10.915548509253203`}}], 
     PolygonBox[{{50.653841409022064`, 8.78906340660646}, {33.98717474235546, 
      9.570912605353659}, {33.987174742355506`, 7.214277532888091}, {
      50.65384140902208, 6.624942185131035}, {50.653841409022064`, 
      8.78906340660646}}], 
     PolygonBox[{{50.65384140902208, 6.624942185131035}, {33.987174742355506`,
       7.214277532888091}, {33.987174742355506`, 4.8267498164706595`}, {
      50.65384140902208, 4.432451944139253}, {50.65384140902208, 
      6.624942185131035}}], 
     PolygonBox[{{50.65384140902208, 4.432451944139282}, {33.98717474235546, 
      4.826749816470691}, {33.98717474235546, 2.4185532163230192`}, {
      50.65384140902208, 2.2209812634402937`}, {50.65384140902208, 
      4.432451944139282}}], 
     PolygonBox[{{50.65384140902208, 2.2209812634402937`}, {33.98717474235546,
       2.4185532163230192`}, {33.98717474235546, 6.792962714020474*^-15}, {
      50.65384140902208, 6.2380446331568295`*^-15}, {50.65384140902208, 
      2.2209812634402937`}}], 
     PolygonBox[{{50.65384140902208, 6.2380446331568295`*^-15}, {
      33.98717474235546, 6.792962714020474*^-15}, {
      33.98717474235546, -2.4185532163230055`}, {
      50.65384140902208, -2.2209812634402812`}, {50.65384140902208, 
      6.2380446331568295`*^-15}}], 
     PolygonBox[{{50.65384140902208, -2.220981263440251}, {
      33.987174742355506`, -2.4185532163229726`}, {
      33.987174742355506`, -4.826749816470645}, {
      50.65384140902208, -4.432451944139241}, {
      50.65384140902208, -2.220981263440251}}], 
     PolygonBox[{{50.65384140902208, -4.432451944139241}, {
      33.987174742355506`, -4.826749816470645}, {
      33.98717474235546, -7.214277532888078}, {
      50.653841409022064`, -6.624942185131023}, {
      50.65384140902208, -4.432451944139241}}], 
     PolygonBox[{{50.65384140902208, -6.624942185130993}, {
      33.98717474235546, -7.214277532888045}, {
      33.987174742355506`, -9.570912605353614}, {
      50.65384140902208, -8.789063406606417}, {
      50.65384140902208, -6.624942185130993}}], 
     PolygonBox[{{50.65384140902208, -8.789063406606417}, {
      33.987174742355506`, -9.570912605353614}, {
      33.987174742355364`, -11.886563560689824`}, {
      50.65384140902208, -10.91554850925319}, {
      50.65384140902208, -8.789063406606417}}], 
     PolygonBox[{{50.65384140902208, -10.91554850925319}, {
      33.987174742355364`, -11.886563560689824`}, {
      33.98717474235546, -14.151314426000724`}, {
      50.65384140902208, -12.995291557397847`}, {
      50.65384140902208, -10.91554850925319}}], 
     PolygonBox[{{50.653841409022064`, -12.995291557397818`}, {
      33.98717474235546, -14.151314426000694`}, {
      33.987174742355506`, -16.355467190390144`}, {
      50.65384140902208, -15.019386772020242`}, {
      50.653841409022064`, -12.995291557397818`}}], 
     PolygonBox[{{50.65384140902208, -15.019386772020242`}, {
      33.987174742355506`, -16.355467190390144`}, {
      33.98717474235546, -18.489583333333336`}, {
      50.653841409022064`, -16.979166666666668`}, {
      50.65384140902208, -15.019386772020242`}}], 
     PolygonBox[{{50.65384140902208, -16.979166666666643`}, {
      33.98717474235546, -18.489583333333307`}, {
      33.98717474235546, -20.544524241870693`}, {
      50.65384140902208, -18.86623916295731}, {
      50.65384140902208, -16.979166666666643`}}], 
     PolygonBox[{{50.65384140902208, -18.86623916295731}, {
      33.98717474235546, -20.544524241870693`}, {
      33.987174742355506`, -22.511490343551642`}, {
      50.65384140902208, -20.672523526754468`}, {
      50.65384140902208, -18.86623916295731}}], 
     PolygonBox[{{50.653841409022064`, -20.672523526754446`}, {
      33.98717474235546, -22.51149034355162}, {
      33.987174742355364`, -24.382058787554612`}, {
      50.65384140902208, -22.39028497110649}, {
      50.653841409022064`, -20.672523526754446`}}], 
     PolygonBox[{{50.65384140902208, -22.39028497110649}, {
      33.987174742355364`, -24.382058787554612`}, {
      33.98717474235546, -26.14821951262753}, {
      50.65384140902208, -24.01216777779317}, {
      50.65384140902208, -22.39028497110649}}], 
     PolygonBox[{{50.65384140902208, -24.01216777779317}, {
      33.98717474235546, -26.14821951262753}, {
      33.98717474235546, -27.802409547399687`}, {
      50.65384140902208, -25.531226795640276`}, {
      50.65384140902208, -24.01216777779317}}], 
     PolygonBox[{{50.65384140902208, -25.531226795640258`}, {
      33.98717474235546, -27.802409547399666`}, {
      33.98717474235546, -29.33754539618629}, {
      50.65384140902208, -26.940957180723185`}, {
      50.65384140902208, -25.531226795640258`}}], 
     PolygonBox[{{50.65384140902208, -26.940957180723185`}, {
      33.98717474235546, -29.33754539618629}, {
      33.98717474235546, -30.747053371604537`}, {
      50.65384140902208, -28.235322251107263`}, {
      50.65384140902208, -26.940957180723185`}}], 
     PolygonBox[{{50.65384140902208, -28.23532225110725}, {
      33.987174742355364`, -30.747053371604522`}, {
      33.98717474235546, -32.02489774411204}, {
      50.65384140902208, -29.40877933684655}, {
      50.65384140902208, -28.23532225110725}}], 
     PolygonBox[{{50.65384140902208, -29.40877933684655}, {
      33.98717474235546, -32.02489774411204}, {
      33.98717474235546, -33.165606587927535`}, {
      50.65384140902208, -30.456303514547535`}, {
      50.65384140902208, -29.40877933684655}}], 
     PolygonBox[{{50.65384140902208, -30.45630351454752}, {
      33.98717474235546, -33.16560658792752}, {
      33.987174742355364`, -34.16429521265695}, {
      50.653841409022064`, -31.373409124862437`}, {
      50.65384140902208, -30.45630351454752}}], 
     PolygonBox[{{50.653841409022064`, -31.373409124862437`}, {
      33.987174742355364`, -34.16429521265695}, {
      33.987174742355506`, -35.01668708028775}, {
      50.65384140902208, -32.15616898077129}, {
      50.653841409022064`, -31.373409124862437`}}], 
     PolygonBox[{{50.65384140902208, -32.15616898077129}, {
      33.987174742355506`, -35.01668708028775}, {
      33.98717474235546, -35.71913211798117}, {
      50.653841409022064`, -32.80123118439961}, {
      50.65384140902208, -32.15616898077129}}], 
     PolygonBox[{{50.653841409022064`, -32.801231184399605`}, {
      33.98717474235546, -35.71913211798116}, {
      33.987174742355506`, -36.26862234824445}, {
      50.65384140902208, -33.305833480359695`}, {
      50.653841409022064`, -32.801231184399605`}}], 
     PolygonBox[{{50.65384140902208, -33.305833480359695`}, {
      33.987174742355506`, -36.26862234824445}, {
      33.987174742355506`, -36.66280476955236}, {
      50.65384140902208, -33.66781508415231}, {
      50.65384140902208, -33.305833480359695`}}], 
     PolygonBox[{{50.65384140902208, -33.6678150841523}, {
      33.98717474235546, -36.66280476955236}, {
      33.98717474235546, -36.899991432260855`}, {
      50.65384140902208, -33.885625934977575`}, {
      50.65384140902208, -33.6678150841523}}], 
     PolygonBox[{{50.65384140902208, -33.885625934977575`}, {
      33.98717474235546, -36.899991432260855`}, {
      33.98717474235546, -36.979166666666664`}, {
      50.65384140902208, -33.95833333333333}, {
      50.65384140902208, -33.885625934977575`}}], 
     PolygonBox[{{33.98717474235546, -36.979166666666664`}, {
      1.6902601750779826`*^-14, -40.}, {
      1.6902601750779826`*^-14, -39.91435692954414}, {
      33.987174742355506`, -36.899991432260855`}, {
      33.98717474235546, -36.979166666666664`}}], 
     PolygonBox[{{33.987174742355506`, -36.899991432260855`}, {
      1.6902601750779826`*^-14, -39.91435692954414}, {
      1.6902601750779826`*^-14, -39.657794454952416`}, {
      33.987174742355506`, -36.66280476955236}, {
      33.987174742355506`, -36.899991432260855`}}], 
     PolygonBox[{{33.987174742355506`, -36.66280476955236}, {
      1.6902601750779826`*^-14, -39.657794454952416`}, {
      1.6902601750779826`*^-14, -39.23141121612922}, {
      33.98717474235546, -36.268622348244456`}, {
      33.987174742355506`, -36.66280476955236}}], 
     PolygonBox[{{33.98717474235546, -36.268622348244456`}, {
      1.6902601750779826`*^-14, -39.23141121612922}, {
      1.6902601750779826`*^-14, -38.63703305156273}, {
      33.98717474235546, -35.71913211798117}, {
      33.98717474235546, -36.268622348244456`}}], 
     PolygonBox[{{33.98717474235546, -35.71913211798117}, {
      1.6902601750779826`*^-14, -38.63703305156273}, {
      1.6902601750779826`*^-14, -37.87720517980423}, {
      33.987174742355364`, -35.01668708028777}, {
      33.98717474235546, -35.71913211798117}}], 
     PolygonBox[{{33.987174742355364`, -35.01668708028777}, {
      1.6902601750779826`*^-14, -37.87720517980423}, {
      1.6902601750779826`*^-14, -36.95518130045147}, {
      33.98717474235546, -34.16429521265696}, {
      33.987174742355364`, -35.01668708028777}}], 
     PolygonBox[{{33.98717474235546, -34.16429521265696}, {
      1.6902601750779826`*^-14, -36.95518130045147}, {
      1.6902601750779826`*^-14, -35.874909661307534`}, {
      33.98717474235546, -33.165606587927535`}, {
      33.98717474235546, -34.16429521265696}}], 
     PolygonBox[{{33.98717474235546, -33.165606587927535`}, {
      1.6902601750779826`*^-14, -35.874909661307534`}, {
      1.6902601750779826`*^-14, -34.64101615137755}, {
      33.98717474235546, -32.02489774411205}, {
      33.98717474235546, -33.165606587927535`}}], 
     PolygonBox[{{33.98717474235546, -32.02489774411205}, {
      1.6902601750779826`*^-14, -34.64101615137755}, {
      1.6902601750779826`*^-14, -33.25878449210181}, {
      33.98717474235546, -30.747053371604537`}, {
      33.98717474235546, -32.02489774411205}}], 
     PolygonBox[{{33.98717474235546, -30.747053371604537`}, {
      1.6902601750779826`*^-14, -33.25878449210181}, {
      1.6902601750779826`*^-14, -31.734133611649405`}, {
      33.98717474235546, -29.337545396186297`}, {
      33.98717474235546, -30.747053371604537`}}], 
     PolygonBox[{{33.98717474235546, -29.337545396186304`}, {
      1.6902601750779826`*^-14, -31.734133611649412`}, {
      1.6902601750779826`*^-14, -30.073592299159095`}, {
      33.98717474235546, -27.802409547399684`}, {
      33.98717474235546, -29.337545396186304`}}], 
     PolygonBox[{{33.98717474235546, -27.802409547399684`}, {
      1.6902601750779826`*^-14, -30.073592299159095`}, {
      1.6902601750779826`*^-14, -28.284271247461902`}, {
      33.98717474235546, -26.148219512627538`}, {
      33.98717474235546, -27.802409547399684`}}], 
     PolygonBox[{{33.98717474235546, -26.148219512627538`}, {
      1.6902601750779826`*^-14, -28.284271247461902`}, {
      1.6902601750779826`*^-14, -26.373832604002754`}, {
      33.98717474235546, -24.382058787554627`}, {
      33.98717474235546, -26.148219512627538`}}], 
     PolygonBox[{{33.98717474235546, -24.382058787554634`}, {
      1.6902601750779826`*^-14, -26.373832604002757`}, {
      1.6902601750779826`*^-14, -24.350457160348824`}, {
      33.98717474235546, -22.511490343551646`}, {
      33.98717474235546, -24.382058787554634`}}], 
     PolygonBox[{{33.98717474235546, -22.511490343551646`}, {
      1.6902601750779826`*^-14, -24.350457160348824`}, \
{-8.25733812556342*^-14, -22.222809320784094`}, {
      33.98717474235546, -20.54452424187071}, {
      33.98717474235546, -22.511490343551646`}}], 
     PolygonBox[{{
      33.987174742355364`, -20.544524241870715`}, {-8.25733812556342*^-14, \
-22.222809320784098`}, {1.6902601750779826`*^-14, -20.000000000000004`}, {
      33.98717474235546, -18.489583333333336`}, {
      33.987174742355364`, -20.544524241870715`}}], 
     PolygonBox[{{33.98717474235546, -18.489583333333336`}, {
      1.6902601750779826`*^-14, -20.000000000000004`}, {
      1.6902601750779826`*^-14, -17.691547608760057`}, {
      33.98717474235546, -16.355467190390154`}, {
      33.98717474235546, -18.489583333333336`}}], 
     PolygonBox[{{33.98717474235546, -16.355467190390154`}, {
      1.6902601750779826`*^-14, -17.691547608760057`}, {
      1.6902601750779826`*^-14, -15.3073372946036}, {
      33.98717474235546, -14.151314426000724`}, {
      33.98717474235546, -16.355467190390154`}}], 
     PolygonBox[{{33.98717474235546, -14.151314426000717`}, {
      1.6902601750779826`*^-14, -15.307337294603593`}, {
      1.6902601750779826`*^-14, -12.857578612126469`}, {
      33.987174742355506`, -11.886563560689835`}, {
      33.98717474235546, -14.151314426000717`}}], 
     PolygonBox[{{33.987174742355506`, -11.886563560689835`}, {
      1.6902601750779826`*^-14, -12.857578612126469`}, {
      8.085144796918884*^-14, -10.352761804100838`}, {
      33.987174742355506`, -9.570912605353639}, {
      33.987174742355506`, -11.886563560689835`}}], 
     PolygonBox[{{33.987174742355506`, -9.570912605353639}, {
      8.085144796918884*^-14, -10.352761804100838`}, {
      1.6902601750779826`*^-14, -7.803612880645141}, {
      33.98717474235546, -7.214277532888086}, {
      33.987174742355506`, -9.570912605353639}}], 
     PolygonBox[{{33.98717474235546, -7.2142775328880795`}, {
      1.6902601750779826`*^-14, -7.803612880645133}, {
      1.6902601750779826`*^-14, -5.221047688802068}, {
      33.987174742355506`, -4.826749816470662}, {
      33.98717474235546, -7.2142775328880795`}}], 
     PolygonBox[{{33.987174742355506`, -4.826749816470662}, {
      1.6902601750779826`*^-14, -5.221047688802068}, {
      1.6902601750779826`*^-14, -2.6161251692057306`}, {
      33.98717474235546, -2.418553216323006}, {
      33.987174742355506`, -4.826749816470662}}], 
     PolygonBox[{{33.98717474235546, -2.418553216323006}, {
      1.6902601750779826`*^-14, -2.6161251692057306`}, {
      1.6902601750779826`*^-14, -1.1331077795295958`*^-14}, {
      33.98717474235546, -1.0475345357630377`*^-14}, {
      33.98717474235546, -2.418553216323006}}], 
     PolygonBox[{{33.98717474235546, -2.2643209046734916`*^-15}, {
      1.6902601750779826`*^-14, -2.4492935982947065`*^-15}, {
      1.6902601750779826`*^-14, 2.616125169205717}, {33.987174742355506`, 
      2.4185532163229935`}, {33.98717474235546, -2.2643209046734916`*^-15}}], 
     PolygonBox[{{33.987174742355506`, 2.4185532163229935`}, {
      1.6902601750779826`*^-14, 2.616125169205717}, {1.6902601750779826`*^-14,
       5.221047688802056}, {33.987174742355506`, 4.826749816470651}, {
      33.987174742355506`, 2.4185532163229935`}}], 
     PolygonBox[{{33.987174742355506`, 4.826749816470651}, {
      1.6902601750779826`*^-14, 5.221047688802056}, {1.6902601750779826`*^-14,
       7.803612880645119}, {33.987174742355506`, 7.214277532888065}, {
      33.987174742355506`, 4.826749816470651}}], 
     PolygonBox[{{33.987174742355506`, 7.214277532888065}, {
      1.6902601750779826`*^-14, 7.803612880645119}, {1.6902601750779826`*^-14,
       10.352761804100815`}, {33.987174742355506`, 9.570912605353618}, {
      33.987174742355506`, 7.214277532888065}}], 
     PolygonBox[{{33.987174742355506`, 9.570912605353628}, {
      1.6902601750779826`*^-14, 10.352761804100826`}, {
      1.6902601750779826`*^-14, 12.857578612126455`}, {33.98717474235546, 
      11.88656356068982}, {33.987174742355506`, 9.570912605353628}}], 
     PolygonBox[{{33.98717474235546, 11.88656356068982}, {
      1.6902601750779826`*^-14, 12.857578612126455`}, {8.085144796918884*^-14,
       15.30733729460358}, {33.98717474235546, 14.151314426000704`}, {
      33.98717474235546, 11.88656356068982}}], 
     PolygonBox[{{33.98717474235546, 14.151314426000704`}, {
      8.085144796918884*^-14, 15.30733729460358}, {1.6902601750779826`*^-14, 
      17.691547608760047`}, {33.98717474235546, 16.355467190390147`}, {
      33.98717474235546, 14.151314426000704`}}], 
     PolygonBox[{{33.98717474235546, 16.355467190390147`}, {
      1.6902601750779826`*^-14, 17.691547608760047`}, {
      1.6902601750779826`*^-14, 19.999999999999993`}, {33.98717474235546, 
      18.489583333333325`}, {33.98717474235546, 16.355467190390147`}}], 
     PolygonBox[{{33.98717474235546, 18.489583333333325`}, {
      1.6902601750779826`*^-14, 19.999999999999993`}, {
      1.6902601750779826`*^-14, 22.222809320784076`}, {33.98717474235546, 
      20.544524241870693`}, {33.98717474235546, 18.489583333333325`}}], 
     PolygonBox[{{33.98717474235546, 20.544524241870693`}, {
      1.6902601750779826`*^-14, 22.222809320784076`}, {
      1.6902601750779826`*^-14, 24.350457160348814`}, {33.98717474235546, 
      22.511490343551635`}, {33.98717474235546, 20.544524241870693`}}], 
     PolygonBox[{{33.98717474235546, 22.511490343551635`}, {
      1.6902601750779826`*^-14, 24.350457160348814`}, {
      1.6902601750779826`*^-14, 26.37383260400274}, {33.987174742355364`, 
      24.382058787554616`}, {33.98717474235546, 22.511490343551635`}}], 
     PolygonBox[{{33.987174742355364`, 24.382058787554616`}, {
      1.6902601750779826`*^-14, 26.37383260400274}, {1.6902601750779826`*^-14,
       28.284271247461888`}, {33.987174742355364`, 26.148219512627527`}, {
      33.987174742355364`, 24.382058787554616`}}], 
     PolygonBox[{{33.98717474235546, 26.148219512627534`}, {
      1.6902601750779826`*^-14, 28.2842712474619}, {1.6902601750779826`*^-14, 
      30.073592299159092`}, {33.98717474235546, 27.80240954739968}, {
      33.98717474235546, 26.148219512627534`}}], 
     PolygonBox[{{33.98717474235546, 27.80240954739968}, {
      1.6902601750779826`*^-14, 30.073592299159092`}, {
      1.6902601750779826`*^-14, 31.7341336116494}, {33.98717474235546, 
      29.337545396186293`}, {33.98717474235546, 27.80240954739968}}], 
     PolygonBox[{{33.98717474235546, 29.337545396186293`}, {
      1.6902601750779826`*^-14, 31.7341336116494}, {8.085144796918884*^-14, 
      33.258784492101796`}, {33.98717474235546, 30.747053371604526`}, {
      33.98717474235546, 29.337545396186293`}}], 
     PolygonBox[{{33.98717474235546, 30.747053371604526`}, {
      8.085144796918884*^-14, 33.258784492101796`}, {1.6902601750779826`*^-14,
       34.641016151377535`}, {33.98717474235546, 32.024897744112046`}, {
      33.98717474235546, 30.747053371604526`}}], 
     PolygonBox[{{33.98717474235546, 32.024897744112046`}, {
      1.6902601750779826`*^-14, 34.641016151377535`}, {
      1.6902601750779826`*^-14, 35.87490966130753}, {33.987174742355364`, 
      33.165606587927535`}, {33.98717474235546, 32.024897744112046`}}], 
     PolygonBox[{{33.987174742355364`, 33.165606587927535`}, {
      1.6902601750779826`*^-14, 35.87490966130753}, {1.6902601750779826`*^-14,
       36.955181300451464`}, {33.987174742355364`, 34.16429521265695}, {
      33.987174742355364`, 33.165606587927535`}}], 
     PolygonBox[{{33.987174742355364`, 34.16429521265696}, {
      1.6902601750779826`*^-14, 36.95518130045147}, {1.6902601750779826`*^-14,
       37.87720517980422}, {33.987174742355506`, 35.01668708028775}, {
      33.987174742355364`, 34.16429521265696}}], 
     PolygonBox[{{33.987174742355506`, 35.01668708028775}, {
      1.6902601750779826`*^-14, 37.87720517980422}, {8.085144796918884*^-14, 
      38.637033051562724`}, {33.987174742355506`, 35.71913211798116}, {
      33.987174742355506`, 35.01668708028775}}], 
     PolygonBox[{{33.987174742355506`, 35.71913211798116}, {
      8.085144796918884*^-14, 38.637033051562724`}, {1.6902601750779826`*^-14,
       39.23141121612922}, {33.98717474235546, 36.268622348244456`}, {
      33.987174742355506`, 35.71913211798116}}], 
     PolygonBox[{{33.98717474235546, 36.268622348244456`}, {
      1.6902601750779826`*^-14, 39.23141121612922}, {1.6902601750779826`*^-14,
       39.657794454952416`}, {33.98717474235546, 36.66280476955236}, {
      33.98717474235546, 36.268622348244456`}}], 
     PolygonBox[{{33.98717474235546, 36.66280476955236}, {
      1.6902601750779826`*^-14, 39.657794454952416`}, {
      1.6902601750779826`*^-14, 39.91435692954414}, {33.98717474235546, 
      36.899991432260855`}, {33.98717474235546, 36.66280476955236}}], 
     PolygonBox[{{33.98717474235546, 36.899991432260855`}, {
      1.6902601750779826`*^-14, 39.91435692954414}, {1.6902601750779826`*^-14,
       40.}, {33.98717474235546, 36.979166666666664`}, {33.98717474235546, 
      36.899991432260855`}}], 
     PolygonBox[{{33.98717474235546, 36.979166666666664`}, {
      1.6902601750779826`*^-14, 40.}, {1.6902601750779826`*^-14, 
      39.91435692954414}, {33.987174742355506`, 36.899991432260855`}, {
      33.98717474235546, 36.979166666666664`}}], 
     PolygonBox[{{33.987174742355506`, 36.899991432260855`}, {
      1.6902601750779826`*^-14, 39.91435692954414}, {1.6902601750779826`*^-14,
       39.657794454952416`}, {33.987174742355506`, 36.66280476955236}, {
      33.987174742355506`, 36.899991432260855`}}], 
     PolygonBox[{{33.987174742355506`, 36.66280476955236}, {
      1.6902601750779826`*^-14, 39.657794454952416`}, {
      1.6902601750779826`*^-14, 39.23141121612922}, {33.987174742355506`, 
      36.268622348244456`}, {33.987174742355506`, 36.66280476955236}}], 
     PolygonBox[{{33.987174742355506`, 36.268622348244456`}, {
      1.6902601750779826`*^-14, 39.23141121612922}, {1.6902601750779826`*^-14,
       38.63703305156273}, {33.987174742355506`, 35.71913211798117}, {
      33.987174742355506`, 36.268622348244456`}}], 
     PolygonBox[{{33.987174742355506`, 35.71913211798117}, {
      1.6902601750779826`*^-14, 38.63703305156273}, {1.6902601750779826`*^-14,
       37.87720517980423}, {33.98717474235546, 35.01668708028777}, {
      33.987174742355506`, 35.71913211798117}}], 
     PolygonBox[{{33.98717474235546, 35.01668708028777}, {
      1.6902601750779826`*^-14, 37.87720517980423}, {1.6902601750779826`*^-14,
       36.95518130045148}, {33.98717474235546, 34.16429521265697}, {
      33.98717474235546, 35.01668708028777}}], 
     PolygonBox[{{33.98717474235546, 34.16429521265697}, {
      1.6902601750779826`*^-14, 36.95518130045148}, {1.6902601750779826`*^-14,
       35.87490966130754}, {33.987174742355506`, 33.16560658792754}, {
      33.98717474235546, 34.16429521265697}}], 
     PolygonBox[{{33.987174742355506`, 33.165606587927535`}, {
      1.6902601750779826`*^-14, 35.874909661307534`}, {
      1.6902601750779826`*^-14, 34.641016151377556`}, {33.98717474235546, 
      32.02489774411206}, {33.987174742355506`, 33.165606587927535`}}], 
     PolygonBox[{{33.98717474235546, 32.02489774411206}, {
      1.6902601750779826`*^-14, 34.641016151377556`}, {
      1.6902601750779826`*^-14, 33.25878449210182}, {33.98717474235546, 
      30.747053371604544`}, {33.98717474235546, 32.02489774411206}}], 
     PolygonBox[{{33.98717474235546, 30.747053371604544`}, {
      1.6902601750779826`*^-14, 33.25878449210182}, {1.6902601750779826`*^-14,
       31.734133611649415`}, {33.98717474235546, 29.337545396186307`}, {
      33.98717474235546, 30.747053371604544`}}], 
     PolygonBox[{{33.98717474235546, 29.337545396186307`}, {
      1.6902601750779826`*^-14, 31.734133611649415`}, {
      1.6902601750779826`*^-14, 30.07359229915911}, {33.987174742355364`, 
      27.802409547399698`}, {33.98717474235546, 29.337545396186307`}}], 
     PolygonBox[{{33.987174742355364`, 27.802409547399698`}, {
      1.6902601750779826`*^-14, 30.07359229915911}, {1.6902601750779826`*^-14,
       28.284271247461916`}, {33.987174742355364`, 26.148219512627552`}, {
      33.987174742355364`, 27.802409547399698`}}], 
     PolygonBox[{{33.987174742355364`, 26.148219512627552`}, {
      1.6902601750779826`*^-14, 28.284271247461916`}, {
      1.6902601750779826`*^-14, 26.373832604002775`}, {33.98717474235546, 
      24.382058787554648`}, {33.987174742355364`, 26.148219512627552`}}], 
     PolygonBox[{{33.987174742355364`, 
      24.382058787554637`}, {-8.25733812556342*^-14, 26.373832604002764`}, {
      1.6902601750779826`*^-14, 24.350457160348835`}, {33.98717474235546, 
      22.511490343551657`}, {33.987174742355364`, 24.382058787554637`}}], 
     PolygonBox[{{33.98717474235546, 22.511490343551657`}, {
      1.6902601750779826`*^-14, 24.350457160348835`}, {
      1.6902601750779826`*^-14, 22.222809320784087`}, {33.98717474235546, 
      20.544524241870704`}, {33.98717474235546, 22.511490343551657`}}], 
     PolygonBox[{{33.987174742355364`, 20.544524241870732`}, {
      1.6902601750779826`*^-14, 22.222809320784116`}, {
      1.6902601750779826`*^-14, 20.00000000000002}, {33.98717474235546, 
      18.48958333333335}, {33.987174742355364`, 20.544524241870732`}}], 
     PolygonBox[{{33.98717474235546, 18.48958333333335}, {
      1.6902601750779826`*^-14, 20.00000000000002}, {1.6902601750779826`*^-14,
       17.691547608760054`}, {33.98717474235546, 16.35546719039015}, {
      33.98717474235546, 18.48958333333335}}], 
     PolygonBox[{{33.98717474235546, 16.35546719039015}, {
      1.6902601750779826`*^-14, 17.691547608760054`}, {8.085144796918884*^-14,
       15.30733729460358}, {33.98717474235546, 14.151314426000704`}, {
      33.98717474235546, 16.35546719039015}}], 
     PolygonBox[{{33.987174742355364`, 14.151314426000736`}, {
      1.6902601750779826`*^-14, 15.307337294603613`}, {
      1.6902601750779826`*^-14, 12.857578612126472`}, {33.987174742355506`, 
      11.886563560689837`}, {33.987174742355364`, 14.151314426000736`}}], 
     PolygonBox[{{33.987174742355506`, 11.886563560689837`}, {
      1.6902601750779826`*^-14, 12.857578612126472`}, {
      1.6902601750779826`*^-14, 10.352761804100826`}, {33.987174742355506`, 
      9.570912605353628}, {33.987174742355506`, 11.886563560689837`}}], 
     PolygonBox[{{33.98717474235546, 9.570912605353659}, {
      1.6902601750779826`*^-14, 10.352761804100862`}, {
      1.6902601750779826`*^-14, 7.803612880645146}, {33.987174742355506`, 
      7.214277532888091}, {33.98717474235546, 9.570912605353659}}], 
     PolygonBox[{{33.987174742355506`, 7.214277532888091}, {
      1.6902601750779826`*^-14, 7.803612880645146}, {1.6902601750779826`*^-14,
       5.221047688802066}, {33.987174742355506`, 4.8267498164706595`}, {
      33.987174742355506`, 7.214277532888091}}], 
     PolygonBox[{{33.98717474235546, 4.826749816470691}, {
      1.6902601750779826`*^-14, 5.221047688802099}, {1.6902601750779826`*^-14,
       2.616125169205745}, {33.98717474235546, 2.4185532163230192`}, {
      33.98717474235546, 4.826749816470691}}], 
     PolygonBox[{{33.98717474235546, 2.4185532163230192`}, {
      1.6902601750779826`*^-14, 2.616125169205745}, {1.6902601750779826`*^-14,
       7.347880794884118*^-15}, {33.98717474235546, 6.792962714020474*^-15}, {
      33.98717474235546, 2.4185532163230192`}}], 
     PolygonBox[{{33.98717474235546, 6.792962714020474*^-15}, {
      1.6902601750779826`*^-14, 7.347880794884118*^-15}, {
      1.6902601750779826`*^-14, -2.61612516920573}, {
      33.98717474235546, -2.4185532163230055`}, {33.98717474235546, 
      6.792962714020474*^-15}}], 
     PolygonBox[{{33.987174742355506`, -2.4185532163229726`}, {
      1.6902601750779826`*^-14, -2.6161251692056946`}, {
      1.6902601750779826`*^-14, -5.2210476888020505`}, {
      33.987174742355506`, -4.826749816470645}, {
      33.987174742355506`, -2.4185532163229726`}}], 
     PolygonBox[{{33.987174742355506`, -4.826749816470645}, {
      1.6902601750779826`*^-14, -5.2210476888020505`}, {
      1.6902601750779826`*^-14, -7.803612880645132}, {
      33.98717474235546, -7.214277532888078}, {
      33.987174742355506`, -4.826749816470645}}], 
     PolygonBox[{{33.98717474235546, -7.214277532888045}, {
      1.6902601750779826`*^-14, -7.803612880645097}, {
      1.6902601750779826`*^-14, -10.352761804100812`}, {
      33.987174742355506`, -9.570912605353614}, {
      33.98717474235546, -7.214277532888045}}], 
     PolygonBox[{{33.987174742355506`, -9.570912605353614}, {
      1.6902601750779826`*^-14, -10.352761804100812`}, {
      1.6902601750779826`*^-14, -12.857578612126458`}, {
      33.987174742355364`, -11.886563560689824`}, {
      33.987174742355506`, -9.570912605353614}}], 
     PolygonBox[{{33.987174742355364`, -11.886563560689824`}, {
      1.6902601750779826`*^-14, -12.857578612126458`}, {
      1.6902601750779826`*^-14, -15.3073372946036}, {
      33.98717474235546, -14.151314426000724`}, {
      33.987174742355364`, -11.886563560689824`}}], 
     PolygonBox[{{33.98717474235546, -14.151314426000694`}, {
      1.6902601750779826`*^-14, -15.307337294603567`}, {
      1.6902601750779826`*^-14, -17.69154760876004}, {
      33.987174742355506`, -16.355467190390144`}, {
      33.98717474235546, -14.151314426000694`}}], 
     PolygonBox[{{33.987174742355506`, -16.355467190390144`}, {
      1.6902601750779826`*^-14, -17.69154760876004}, {
      1.6902601750779826`*^-14, -20.000000000000004`}, {
      33.98717474235546, -18.489583333333336`}, {
      33.987174742355506`, -16.355467190390144`}}], 
     PolygonBox[{{33.98717474235546, -18.489583333333307`}, {
      1.6902601750779826`*^-14, -19.99999999999997}, {
      1.6902601750779826`*^-14, -22.222809320784073`}, {
      33.98717474235546, -20.544524241870693`}, {
      33.98717474235546, -18.489583333333307`}}], 
     PolygonBox[{{33.98717474235546, -20.544524241870693`}, {
      1.6902601750779826`*^-14, -22.222809320784073`}, {
      8.085144796918884*^-14, -24.35045716034882}, {
      33.987174742355506`, -22.511490343551642`}, {
      33.98717474235546, -20.544524241870693`}}], 
     PolygonBox[{{33.98717474235546, -22.51149034355162}, {
      1.6902601750779826`*^-14, -24.350457160348796`}, {
      1.6902601750779826`*^-14, -26.373832604002736`}, {
      33.987174742355364`, -24.382058787554612`}, {
      33.98717474235546, -22.51149034355162}}], 
     PolygonBox[{{33.987174742355364`, -24.382058787554612`}, {
      1.6902601750779826`*^-14, -26.373832604002736`}, {
      1.6902601750779826`*^-14, -28.284271247461895`}, {
      33.98717474235546, -26.14821951262753}, {
      33.987174742355364`, -24.382058787554612`}}], 
     PolygonBox[{{33.98717474235546, -26.14821951262753}, {
      1.6902601750779826`*^-14, -28.284271247461895`}, {
      8.085144796918884*^-14, -30.0735922991591}, {
      33.98717474235546, -27.802409547399687`}, {
      33.98717474235546, -26.14821951262753}}], 
     PolygonBox[{{33.98717474235546, -27.802409547399666`}, {
      1.6902601750779826`*^-14, -30.073592299159078`}, {
      1.6902601750779826`*^-14, -31.734133611649398`}, {
      33.98717474235546, -29.33754539618629}, {
      33.98717474235546, -27.802409547399666`}}], 
     PolygonBox[{{33.98717474235546, -29.33754539618629}, {
      1.6902601750779826`*^-14, -31.734133611649398`}, {
      1.6902601750779826`*^-14, -33.25878449210181}, {
      33.98717474235546, -30.747053371604537`}, {
      33.98717474235546, -29.33754539618629}}], 
     PolygonBox[{{33.987174742355364`, -30.747053371604522`}, {
      1.6902601750779826`*^-14, -33.25878449210179}, {
      1.6902601750779826`*^-14, -34.641016151377535`}, {
      33.98717474235546, -32.02489774411204}, {
      33.987174742355364`, -30.747053371604522`}}], 
     PolygonBox[{{33.98717474235546, -32.02489774411204}, {
      1.6902601750779826`*^-14, -34.641016151377535`}, {
      1.6902601750779826`*^-14, -35.87490966130753}, {
      33.98717474235546, -33.165606587927535`}, {
      33.98717474235546, -32.02489774411204}}], 
     PolygonBox[{{33.98717474235546, -33.16560658792752}, {
      1.6902601750779826`*^-14, -35.87490966130751}, {-8.25733812556342*^-14, \
-36.955181300451464`}, {33.987174742355364`, -34.16429521265695}, {
      33.98717474235546, -33.16560658792752}}], 
     PolygonBox[{{
      33.987174742355364`, -34.16429521265695}, {-8.25733812556342*^-14, \
-36.955181300451464`}, {1.6902601750779826`*^-14, -37.87720517980422}, {
      33.987174742355506`, -35.01668708028775}, {
      33.987174742355364`, -34.16429521265695}}], 
     PolygonBox[{{33.987174742355506`, -35.01668708028775}, {
      1.6902601750779826`*^-14, -37.87720517980422}, {
      1.6902601750779826`*^-14, -38.63703305156273}, {
      33.98717474235546, -35.71913211798117}, {
      33.987174742355506`, -35.01668708028775}}], 
     PolygonBox[{{33.98717474235546, -35.71913211798116}, {
      1.6902601750779826`*^-14, -38.637033051562724`}, {
      1.6902601750779826`*^-14, -39.23141121612921}, {
      33.987174742355506`, -36.26862234824445}, {
      33.98717474235546, -35.71913211798116}}], 
     PolygonBox[{{33.987174742355506`, -36.26862234824445}, {
      1.6902601750779826`*^-14, -39.23141121612921}, {
      1.6902601750779826`*^-14, -39.657794454952416`}, {
      33.987174742355506`, -36.66280476955236}, {
      33.987174742355506`, -36.26862234824445}}], 
     PolygonBox[{{33.98717474235546, -36.66280476955236}, {
      1.6902601750779826`*^-14, -39.65779445495241}, {
      1.6902601750779826`*^-14, -39.91435692954414}, {
      33.98717474235546, -36.899991432260855`}, {
      33.98717474235546, -36.66280476955236}}], 
     PolygonBox[{{33.98717474235546, -36.899991432260855`}, {
      1.6902601750779826`*^-14, -39.91435692954414}, {
      1.6902601750779826`*^-14, -40.}, {
      33.98717474235546, -36.979166666666664`}, {
      33.98717474235546, -36.899991432260855`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1lE9IVFEUxget1NSXOqAucqFmtGgjUTBivEGh8c9iwMCNq0rpDQ0p0qKF
QUhpg41jkRQEkYoL0yh0MS5Mh4lmJCIppKU5+I+QkLQMtEydc843dMAHw+U3
59x3zzv3O1/h5ea6piSbzXZp77e/0uNx0mqEhNvXoze71zLB2f1vvtVOJnhp
+XfddW9m6F/8sZwnzsy2urcyEM9q6L3itTIQb200c5qC6eDlsQuB7ZWjyJ+P
fnbYt9PAvuCtyKsfqeCa0b6inx9SwCefeM8Wdh9JnFeVd/vRucPg467ws0g0
GTwcfjpcXZkEPt9u74i+sIGpFztTUl9g3lry+7bAHycr2w5tbk5Jfq95zXJX
b4DrRzberxpr4JH0gfHTnhWw+8H3ts6LX8Gxd4H7E40zYFfuwszbrtcTwqMU
N4UdtN+Uep7T+xGvofPBPVQf8qepfsR99H3gP/G8v8gvo/44JT5E/QPnU3/B
x6j/4BK6H6e8r4ruD/FOul/wHN0/8hdJH2DWT+I80he4mPSHfNYn4qxfMOsb
TKtxYDyH90O//H7hEj4f56n6bqj6Wf/gmPr+LtWfWtW/U9xfYTv3X/YXqPt5
qe6vgu9X8lPj/+9AD36ljy9KP49ZX8KW0l9Q6fMO61c4K/K/vj19s8HBT9Pl
Us9VNR+lPD8S9/N8CZtq/h6q+Qzz/Er+PZ5vif8i/YMdyh8GlX/kK38xlP8U
KX9yKf+6y/4m9cwp/4spf2xh/xRm/SfOU/67yP6Mfiv/1v5OqxHaBTfeQmo=

       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBIBGIQ3bLzzf3r7MK2DGDgcgDGX7Pw1lLOr85wfuLBy7ON
riD472b+ejhvLoKfW97r0xWI4HNPSnby+OAE5/vMqE90rkLwZyrpc/197wjn
v9Y3v8gThOCzqa68Kb/QAc7f8VZH78NuezjfSOHZx2tCdnD+AS55hmMeNnD+
hbiIus3xVnD+k4iq/u2RFnD+HyYpDi5LMzifEex/Ezg/3mG2M+dGQzh/b3BU
QPRcvQOJer+/fz1oZiuzyrJbZLsmnG954rvh3C0qcPUT+Fu8n5nJw/ld3J7B
UY9E4HyHm/Ecl9+ywPmcxTf3r+d/tgfGV4TIO8D41RD9DvMvsnBw2ZnvbYCY
D5c3gtgP54tC3Afnb4O4H86PgfgPzv/3HwSM4fwfkPCB8x9Cwg/OPw0JXzh/
PyT84XxDSPzA+Vsh8Qfns0LiF+6fV5D4h8vPgKQPB7T0A+dzQdKXAyz8cyDp
Dy4PTZ9wPjT9wvnQ9A3nQ9M/TvkkqH6Ye9+jmZ+HZj8P1H0wvi+a+2ei+e8N
mv/ZoeED4+9ECz8ztPA9Ag1/mPsuocXPc7T4Y2ZGjV9WSPqH8+PQ0scJtPQj
j5a+3NDS33y09LkWmn5h/AS09O0m9vj84W4GWxj//Q3U/FGGln/S0fKXFlr+
k4DmTxh/HTT/wvhRaPn7ByT9w/nf0MqHO2jlxym08mUfWvmji1Y+bUErv5jR
yreXaOXfNLTy0Qut/ORCK19z0Mrft2jlcwJa+Y1evsPKfwDPOugi
       "]]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-10., 0.}, {109.63885536993459`, 21.095558142797284`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{109.63885536993459`, 21.095558142797284`}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.6013015410443373`*^9, 3.6147093074953957`*^9, 
  3.6147291631689*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"},
 CellLabel->"During evaluation of In[243]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3.6 ",
 StyleBox["SurfaceApproximation -> {TriangleNet -> ", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 StyleBox["}", "Input"]
}], "Subsection",
 CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[TextData[{
 "For some surface shapes, the ",
 StyleBox["SurfaceApproximation -> TriangleNet", "Input"],
 " setting has difficulty working correctly regardless of the number of ",
 StyleBox["SurfacePoints", "Input"],
 " chosen. This is particularly the case for enclosed surfaces that are \
steeply curved and where the ray must undergo multiple bounces within such a \
surface. The reason for this difficulty is that the triangular facets for \
this type of surface function can miss some rays entirely. Here is an example \
of such a surface that is in the shape of an elongated tube. Here the default \
setting of ",
 StyleBox["SurfaceApproximation", "Input"],
 " produces triangular facets that inscribe the surface boundary."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[CellGroupData[{

Cell["\<\
tubemirror = CustomMirror[Function[{#1,Cos[#2],Sin[#2]}],{10,2.0001*Pi}];

ShowSystem[tubemirror, PlotPoints->100, SurfacePoints->Mesh];

ShowSystem[tubemirror, PlotPoints->100, SurfacePoints->Mesh, \
PlotType->FrontView];\
\>", "Input",
 CellChangeTimes->{{3.5634579658495703`*^9, 3.563457967338673*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"In[244]:="],

Cell[BoxData[
 Graphics3DBox[{
   Point3DBox[{-4.999999, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{-4.999999, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-4.999999, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-4.999999, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-4.999999, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, 0.499955520381858, -0.8660510825809905}],
    Point3DBox[{-4.999999, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-4.999999, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-4.999999, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-3.3333323333333333`, 0.499955520381858, -0.8660510825809905}],
    Point3DBox[{-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-3.3333323333333333`, 0.9999999999995, 9.999999999998333*^-7}],
    Point3DBox[{-4.999999, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-4.999999, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-4.999999, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{-3.3333323333333333`, 0.9999999999995, 9.999999999998333*^-7}],
    Point3DBox[{-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}], 
   Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-4.999999, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{-4.999999, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{-4.999999, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-3.3333323333333333`, -0.500091553199278, 0.8659725390673388}],
    Point3DBox[{-4.999999, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-4.999999, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-4.999999, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{-3.3333323333333333`, -0.500091553199278, 0.8659725390673388}],
    Point3DBox[{-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{-4.999999, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}], 
   Point3DBox[{-3.3333323333333333`, 0.499955520381858, -0.8660510825809905}],
    Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-3.3333323333333333`, 0.499955520381858, -0.8660510825809905}],
    Point3DBox[{-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-3.3333323333333333`, 0.9999999999995, 9.999999999998333*^-7}],
    Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-3.3333323333333333`, 0.9999999999995, 9.999999999998333*^-7}],
    Point3DBox[{-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}], 
   Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-1.666665666666667, 0.49995378827869347`, 0.8660520824902989}],
    Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-3.3333323333333333`, -0.500091553199278, 0.8659725390673388}],
    Point3DBox[{-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-1.666665666666667, 0.49995378827869347`, 0.8660520824902989}],
    Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-3.3333323333333333`, -0.500091553199278, 0.8659725390673388}],
    Point3DBox[{-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-1.666665666666667, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{1.*^-6, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-1.666665666666667, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-1.666665666666667, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-1.666665666666667, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{-1.666665666666667, 0.49995378827869347`, 0.8660520824902989}],
    Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{-1.666665666666667, 0.49995378827869347`, 0.8660520824902989}],
    Point3DBox[{-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-1.666665666666667, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{-1.666665666666667, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{-1.666665666666667, -0.9999999875054149, \
-0.00015807963202138384`}], 
   Point3DBox[{1.*^-6, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.666667666666666, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{1.666667666666666, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.*^-6, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.*^-6, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{1.*^-6, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{1.666667666666666, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{3.3333343333333323`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{3.3333343333333323`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{3.3333343333333323`, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.666667666666666, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{1.666667666666666, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{3.3333343333333323`, -0.9999999878195741, 
    0.00015607963204577864`}], 
   Point3DBox[{3.3333343333333323`, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{5.000001, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{5.000001, -0.9999999878195741, 0.00015607963204577864`}], 
   Point3DBox[{5.000001, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{3.3333343333333323`, -0.5000898212532002, -0.865973539248713}],
    Point3DBox[{
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{5.000001, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{5.000001, -0.5000898212532002, -0.865973539248713}], 
   Point3DBox[{5.000001, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{5.000001, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{5.000001, 0.499955520381858, -0.8660510825809905}], 
   Point3DBox[{5.000001, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{5.000001, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{5.000001, 0.9999999999995, 9.999999999998333*^-7}], 
   Point3DBox[{5.000001, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{5.000001, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{5.000001, 0.49995378827869347`, 0.8660520824902989}], 
   Point3DBox[{5.000001, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{5.000001, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{5.000001, -0.500091553199278, 0.8659725390673388}], 
   Point3DBox[{5.000001, -0.9999999875054149, -0.00015807963202138384`}], 
   Point3DBox[{
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}], 
   Line3DBox[{{-4.999999, -0.9999999878195741, 
    0.00015607963204577864`}, {-4.999999, -0.5000898212532002, \
-0.865973539248713}, {-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}, {-4.999999, -0.9999999878195741, 
    0.00015607963204577864`}}], 
   Line3DBox[{{-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}, {-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}, {-4.999999, -0.5000898212532002, -0.865973539248713}, \
{-3.3333323333333333`, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{-4.999999, -0.5000898212532002, -0.865973539248713}, \
{-4.999999, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, \
-0.5000898212532002, -0.865973539248713}, {-4.999999, -0.5000898212532002, \
-0.865973539248713}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-4.999999, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, \
-0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{-4.999999, 0.499955520381858, -0.8660510825809905}, {-4.999999,
     0.9999999999995, 9.999999999998333*^-7}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-4.999999, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, 
    0.9999999999995, 9.999999999998333*^-7}, {-4.999999, 0.9999999999995, 
    9.999999999998333*^-7}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{-4.999999, 0.9999999999995, 9.999999999998333*^-7}, {-4.999999,
     0.49995378827869347`, 0.8660520824902989}, {-3.3333323333333333`, 
    0.9999999999995, 9.999999999998333*^-7}, {-4.999999, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-4.999999, 0.49995378827869347`, 
    0.8660520824902989}, {-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{-4.999999, 0.49995378827869347`, 
    0.8660520824902989}, {-4.999999, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-4.999999, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-4.999999, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{-4.999999, -0.500091553199278, 
    0.8659725390673388}, {-4.999999, -0.9999999875054149, \
-0.00015807963202138384`}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-4.999999, -0.500091553199278, 
    0.8659725390673388}}], 
   Line3DBox[{{-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}, {-4.999999, -0.9999999875054149, \
-0.00015807963202138384`}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}}], 
   Line3DBox[{{-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}, {-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}, {-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}, {-3.3333323333333333`, -0.9999999878195741, 
    0.00015607963204577864`}}], 
   Line3DBox[{{-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}, {-1.666665666666667, -0.5000898212532002, \
-0.865973539248713}, {-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}, {-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5000898212532002, \
-0.865973539248713}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, \
-0.5000898212532002, -0.865973539248713}, {-3.3333323333333333`, \
-0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{-1.666665666666667, -0.5000898212532002, -0.865973539248713}, \
{-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, \
-0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, 
    0.9999999999995, 9.999999999998333*^-7}, {-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}, {-3.3333323333333333`, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, 
    0.9999999999995, 9.999999999998333*^-7}, {-3.3333323333333333`, 
    0.9999999999995, 9.999999999998333*^-7}, {-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-1.666665666666667, 0.9999999999995, 
    9.999999999998333*^-7}, {-3.3333323333333333`, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{-1.666665666666667, 0.9999999999995, 
    9.999999999998333*^-7}, {-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-1.666665666666667, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}, {-3.3333323333333333`, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {-3.3333323333333333`, -0.500091553199278, 
    0.8659725390673388}}], 
   Line3DBox[{{-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, -0.9999999875054149, \
-0.00015807963202138384`}, {-3.3333323333333333`, -0.9999999875054149, \
-0.00015807963202138384`}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}}], 
   Line3DBox[{{-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}, {-1.666665666666667, -0.5000898212532002, \
-0.865973539248713}, {1.*^-6, -0.9999999878195741, 
    0.00015607963204577864`}, {-1.666665666666667, -0.9999999878195741, 
    0.00015607963204577864`}}], 
   Line3DBox[{{1.*^-6, -0.9999999878195741, 0.00015607963204577864`}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}, {-1.666665666666667, \
-0.5000898212532002, -0.865973539248713}, {1.*^-6, -0.9999999878195741, 
    0.00015607963204577864`}}], 
   Line3DBox[{{-1.666665666666667, -0.5000898212532002, -0.865973539248713}, \
{-1.666665666666667, 0.499955520381858, -0.8660510825809905}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}, {-1.666665666666667, \
-0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{1.*^-6, -0.5000898212532002, -0.865973539248713}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, 
    0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}, {-1.666665666666667, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{1.*^-6, 0.499955520381858, -0.8660510825809905}, {1.*^-6, 
    0.9999999999995, 9.999999999998333*^-7}, {-1.666665666666667, 
    0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{-1.666665666666667, 0.9999999999995, 
    9.999999999998333*^-7}, {-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}, {1.*^-6, 0.9999999999995, 
    9.999999999998333*^-7}, {-1.666665666666667, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 
    0.49995378827869347`, 0.8660520824902989}, {-1.666665666666667, 
    0.49995378827869347`, 0.8660520824902989}, {1.*^-6, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {1.*^-6, 0.49995378827869347`, 
    0.8660520824902989}, {-1.666665666666667, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{1.*^-6, 0.49995378827869347`, 0.8660520824902989}, {
    1.*^-6, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {1.*^-6, 0.49995378827869347`, 0.8660520824902989}}],
    Line3DBox[{{-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, -0.9999999875054149, \
-0.00015807963202138384`}, {1.*^-6, -0.500091553199278, 
    0.8659725390673388}, {-1.666665666666667, -0.500091553199278, 
    0.8659725390673388}}], 
   Line3DBox[{{1.*^-6, -0.500091553199278, 0.8659725390673388}, {
    1.*^-6, -0.9999999875054149, -0.00015807963202138384`}, \
{-1.666665666666667, -0.9999999875054149, -0.00015807963202138384`}, {
    1.*^-6, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{1.*^-6, -0.9999999878195741, 0.00015607963204577864`}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, -0.9999999878195741, 0.00015607963204577864`}, {
    1.*^-6, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{1.666667666666666, -0.9999999878195741, 
    0.00015607963204577864`}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{1.*^-6, -0.5000898212532002, -0.865973539248713}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    1.*^-6, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, 0.499955520381858, -0.8660510825809905}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{1.*^-6, 0.499955520381858, -0.8660510825809905}, {1.*^-6, 
    0.9999999999995, 9.999999999998333*^-7}, {1.666667666666666, 
    0.499955520381858, -0.8660510825809905}, {1.*^-6, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{1.666667666666666, 0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 
    0.9999999999995, 9.999999999998333*^-7}, {1.666667666666666, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{1.*^-6, 0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 
    0.49995378827869347`, 0.8660520824902989}, {1.666667666666666, 
    0.9999999999995, 9.999999999998333*^-7}, {1.*^-6, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}, {
    1.666667666666666, 0.49995378827869347`, 0.8660520824902989}, {1.*^-6, 
    0.49995378827869347`, 0.8660520824902989}, {1.666667666666666, 
    0.9999999999995, 9.999999999998333*^-7}}], 
   Line3DBox[{{1.*^-6, 0.49995378827869347`, 0.8660520824902989}, {
    1.*^-6, -0.500091553199278, 0.8659725390673388}, {1.666667666666666, 
    0.49995378827869347`, 0.8660520824902989}, {1.*^-6, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}, {
    1.666667666666666, -0.500091553199278, 0.8659725390673388}, {
    1.*^-6, -0.500091553199278, 0.8659725390673388}, {1.666667666666666, 
    0.49995378827869347`, 0.8660520824902989}}], 
   Line3DBox[{{1.*^-6, -0.500091553199278, 0.8659725390673388}, {
    1.*^-6, -0.9999999875054149, -0.00015807963202138384`}, {
    1.666667666666666, -0.500091553199278, 0.8659725390673388}, {
    1.*^-6, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{1.666667666666666, -0.500091553199278, 0.8659725390673388}, {
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}, {
    1.*^-6, -0.9999999875054149, -0.00015807963202138384`}, {
    1.666667666666666, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{1.666667666666666, -0.9999999878195741, 
    0.00015607963204577864`}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, -0.9999999878195741, 0.00015607963204577864`}, {
    1.666667666666666, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{3.3333343333333323`, -0.9999999878195741, 
    0.00015607963204577864`}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{1.666667666666666, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, 0.499955520381858, -0.8660510825809905}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    1.666667666666666, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, 0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, 0.499955520381858, -0.8660510825809905}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{1.666667666666666, 0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}, {
    3.3333343333333323`, 0.499955520381858, -0.8660510825809905}, {
    1.666667666666666, 0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}, {
    3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}, {
    1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}, {
    3.3333343333333323`, 0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}, {
    1.666667666666666, 0.49995378827869347`, 0.8660520824902989}, {
    3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}, {
    1.666667666666666, 0.9999999999995, 9.999999999998333*^-7}}], 
   Line3DBox[{{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}, {
    3.3333343333333323`, 0.49995378827869347`, 0.8660520824902989}, {
    1.666667666666666, 0.49995378827869347`, 0.8660520824902989}, {
    3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}}], 
   Line3DBox[{{1.666667666666666, 0.49995378827869347`, 0.8660520824902989}, {
    1.666667666666666, -0.500091553199278, 0.8659725390673388}, {
    3.3333343333333323`, 0.49995378827869347`, 0.8660520824902989}, {
    1.666667666666666, 0.49995378827869347`, 0.8660520824902989}}], 
   Line3DBox[{{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}, {3.3333343333333323`, -0.500091553199278, 
    0.8659725390673388}, {1.666667666666666, -0.500091553199278, 
    0.8659725390673388}, {3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{1.666667666666666, -0.500091553199278, 0.8659725390673388}, {
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}, {
    3.3333343333333323`, -0.500091553199278, 0.8659725390673388}, {
    1.666667666666666, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}, {
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}, {
    1.666667666666666, -0.9999999875054149, -0.00015807963202138384`}, {
    3.3333343333333323`, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{3.3333343333333323`, -0.9999999878195741, 
    0.00015607963204577864`}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    5.000001, -0.9999999878195741, 0.00015607963204577864`}, {
    3.3333343333333323`, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{5.000001, -0.9999999878195741, 0.00015607963204577864`}, {
    5.000001, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    5.000001, -0.9999999878195741, 0.00015607963204577864`}}], 
   Line3DBox[{{
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, 0.499955520381858, -0.8660510825809905}, {
    5.000001, -0.5000898212532002, -0.865973539248713}, {
    3.3333343333333323`, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{5.000001, -0.5000898212532002, -0.865973539248713}, {5.000001, 
    0.499955520381858, -0.8660510825809905}, {3.3333343333333323`, 
    0.499955520381858, -0.8660510825809905}, {
    5.000001, -0.5000898212532002, -0.865973539248713}}], 
   Line3DBox[{{3.3333343333333323`, 0.499955520381858, -0.8660510825809905}, {
    3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}, {5.000001, 
    0.499955520381858, -0.8660510825809905}, {3.3333343333333323`, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{5.000001, 0.499955520381858, -0.8660510825809905}, {5.000001, 
    0.9999999999995, 9.999999999998333*^-7}, {3.3333343333333323`, 
    0.9999999999995, 9.999999999998333*^-7}, {5.000001, 
    0.499955520381858, -0.8660510825809905}}], 
   Line3DBox[{{3.3333343333333323`, 0.9999999999995, 9.999999999998333*^-7}, {
    3.3333343333333323`, 0.49995378827869347`, 0.8660520824902989}, {5.000001,
     0.9999999999995, 9.999999999998333*^-7}, {3.3333343333333323`, 
    0.9999999999995, 9.999999999998333*^-7}}], 
   Line3DBox[{{5.000001, 0.9999999999995, 9.999999999998333*^-7}, {5.000001, 
    0.49995378827869347`, 0.8660520824902989}, {3.3333343333333323`, 
    0.49995378827869347`, 0.8660520824902989}, {5.000001, 0.9999999999995, 
    9.999999999998333*^-7}}], 
   Line3DBox[{{3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}, {3.3333343333333323`, -0.500091553199278, 
    0.8659725390673388}, {5.000001, 0.49995378827869347`, 
    0.8660520824902989}, {3.3333343333333323`, 0.49995378827869347`, 
    0.8660520824902989}}], 
   Line3DBox[{{5.000001, 0.49995378827869347`, 0.8660520824902989}, {
    5.000001, -0.500091553199278, 0.8659725390673388}, {
    3.3333343333333323`, -0.500091553199278, 0.8659725390673388}, {5.000001, 
    0.49995378827869347`, 0.8660520824902989}}], 
   Line3DBox[{{3.3333343333333323`, -0.500091553199278, 0.8659725390673388}, {
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}, {
    5.000001, -0.500091553199278, 0.8659725390673388}, {
    3.3333343333333323`, -0.500091553199278, 0.8659725390673388}}], 
   Line3DBox[{{5.000001, -0.500091553199278, 0.8659725390673388}, {
    5.000001, -0.9999999875054149, -0.00015807963202138384`}, {
    3.3333343333333323`, -0.9999999875054149, -0.00015807963202138384`}, {
    5.000001, -0.500091553199278, 0.8659725390673388}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyV1UsKglAABdDHSyREwt8GWomtoXYQNG6JtYSW0LChAwcOHBREQuYZJIhw
EF+9z73b43l/iiGEw+tehc/VXN/Prg1fVw2v4CW8gG/gOTyDr+EpPIFHeICP
l2Uf4D28gz/gd/gNPo0zf7/F9+EPeAfv4QN8hIfdskd4Ak/ha3gGz+EbeAEv
4RW8hjd/ur6jcfU79b80D5o3zbPWReuodY9w7SvtQ+1b7XOdC50jnTud0/k4
0/t/5oZyRrmkHFPuKSeVq8ph5XYKVy+oR9Q76in1mnpQvameVS//+hMtS6j/

       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFlV1IU1EcwK+uwlpZiBQIPhQ9SUbRdNmII328LBeVfeyhQqVPLW9SUdnD
wJEQZEWFUFauDygphoNCSuoYm2SxtsV9SIIRXnOwWJuJRAvSVufsf7x/OOzA
Xn47nPv/+p2ztEHdcTBfUZTazM+kiFXRWJeenk7R0ncRf1/ncpLlRStnuXd1
Zbi3J8+aF6BZfm3fvKdH1SQt1R9t6g9owDe0Rqzd7gR1nlxcbpsfBT6UtriK
vsapyXP+gyOkA3/wo2GJ416MXvHt7k11x4BfPHTuajSs05bKUOG4Hgf+qv7W
yycLo7TFbR573ZYAXrGivezwkEZ//yz+E2lOArc9d635VBCgL7Y0rivI5JHl
5gsjgb7OYtpR4pz6l3eWP9xvom9MAeK40eS3zdifttZenxzUyITF8r5SFedv
dN18VrcgSqbWtp3a6RbxqKuOL9JCOqm+PeDzjYr4m7/tLTvgiZHTXvP9YY/I
N7zn7si20ThZfebYdmdY1Ofj5WrvXHeCaMMlVe2Fop49/dYxk5okwd6JL+Vv
Rf1r7nQoy7pSxB+0t9bMEf1ia5woaGX3a2w//P+Yn6+x84GHeTyfWTzAgzx+
C4sfeBPP9yzLF/gRXp/NrD7ALbye+VX/6wn8O6//JKs/8Eu8X1tZv4CbZ+sz
+wvcbpwH4Ov5/Pxi8wN8kM/bCTZv4rt8PlU2n8DRPANH8w8c+QIc+SXzETjy
l+bisnNk35XFKctLVgfkNXDktcjL6DVwm6SPyGvgyGvgyGvgyGvgyGvgyGvh
i9Fr4Mhr4Mhr4Mhr5HFOr6HvyGtx/xi9Bo68Bo68Bo68Bo68Bo68Bo68Fve2
0Wvgdsk9j7wGjrwW3zV6nfOdkr1rsndQ9m7K3lnZu4z5X3H4xtM=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5., -0.9999999876629945, 
      0.00015707963203365978`}, {-4.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.75, -0.987711673632875, \
-0.15628707486335794`}, {-5., -0.987711673632875, -0.15628707486335794`}, \
{-5., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-5., -0.987711673632875, -0.15628707486335794`}, {-4.75, \
-0.987711673632875, -0.15628707486335794`}, {-4.75, -0.951100193039496, \
-0.3088825388399828}, {-5., -0.951100193039496, -0.3088825388399828}, {-5., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-5., -0.951100193039496, -0.3088825388399828}, {-4.75, \
-0.951100193039496, -0.3088825388399828}, {-4.75, -0.8910671320080115, \
-0.4538715305623575}, {-5., -0.8910671320080115, -0.4538715305623575}, {-5., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-5., -0.8910671320080115, -0.4538715305623575}, {-4.75, \
-0.8910671320080115, -0.4538715305623575}, {-4.75, -0.8090908512602306, \
-0.5876835835779278}, {-5., -0.8090908512602306, -0.5876835835779278}, {-5., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-5., -0.8090908512602306, -0.5876835835779278}, {-4.75, \
-0.8090908512602306, -0.5876835835779278}, {-4.75, -0.7071900803344316, \
-0.7070234722246357}, {-5., -0.7071900803344316, -0.7070234722246357}, {-5., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-5., -0.7071900803344316, -0.7070234722246357}, {-4.75, \
-0.7071900803344316, -0.7070234722246357}, {-4.75, -0.5878742048036698, \
-0.8089523591203952}, {-5., -0.5878742048036698, -0.8089523591203952}, {-5., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-5., -0.5878742048036698, -0.8089523591203952}, {-4.75, \
-0.5878742048036698, -0.8089523591203952}, {-4.75, -0.45408147070841337`, \
-0.890960166314569}, {-5., -0.45408147070841337`, -0.890960166314569}, {-5., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-5., -0.45408147070841337`, -0.890960166314569}, {-4.75, \
-0.45408147070841337`, -0.890960166314569}, {-4.75, -0.3091066279673134, \
-0.9510273879056674}, {-5., -0.3091066279673134, -0.9510273879056674}, {-5., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-5., -0.3091066279673132, -0.9510273879056675}, {-4.75, \
-0.3091066279673132, -0.9510273879056675}, {-4.75, -0.15651979460327867`, \
-0.987674821941588}, {-5., -0.15651979460327867`, -0.987674821941588}, {-5., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-5., -0.15651979460327867`, -0.987674821941588}, {-4.75, \
-0.15651979460327867`, -0.987674821941588}, {-4.75, -0.00007853981625928847, \
-0.9999999969157486}, {-5., -0.00007853981625928847, -0.9999999969157486}, \
{-5., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-5., -0.00007853981625928847, -0.9999999969157486}, \
{-4.75, -0.00007853981625928847, -0.9999999969157486}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-5., 
      0.15636464907469316`, -0.9876993958283806}, {-5., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-5., 0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.30895723712171647`, -0.9510759305282178}, {-5., 
      0.30895723712171647`, -0.9510759305282178}, {-5., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-5., 0.3089572371217167, -0.9510759305282178}, {-4.75, 
      0.3089572371217167, -0.9510759305282178}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-5., 
      0.453941513411326, -0.8910314822731209}, {-5., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-5., 0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-5., 
      0.5877471276121589, -0.8090446922041185}, {-5., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-5., 0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-5., 
      0.7070790126229672, -0.7071345486596803}, {-5., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-5., 0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-5., 
      0.8089985281574115, -0.5878106680208703}, {-5., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-5., 0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-5., 
      0.8909958270419, -0.45401149346015546`}, {-5., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-5., 0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-5., 
      0.951051662150225, -0.3090319334976474}, {-5., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-5., 0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.9876871119312596, -0.15644222232149346`}, {-5., 
      0.9876871119312596, -0.15644222232149346`}, {-5., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-5., 0.9876871119312596, -0.1564422223214935}, {-4.75, 
      0.9876871119312596, -0.1564422223214935}, {-4.75, 
      1., -4.163336342344337*^-16}, {-5., 1., -4.163336342344337*^-16}, {-5., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-5., 1., -4.440892098500626*^-16}, {-4.75, 
      1., -4.440892098500626*^-16}, {-4.75, 0.9876871119312597, 
      0.15644222232149263`}, {-5., 0.9876871119312597, 
      0.15644222232149263`}, {-5., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-5., 0.9876871119312597, 0.1564422223214926}, {-4.75, 
      0.9876871119312597, 0.1564422223214926}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}, {-5., 0.9510516621502252, 
      0.30903193349764657`}, {-5., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-5., 0.9510516621502252, 0.30903193349764657`}, {-4.75, 
      0.9510516621502252, 0.30903193349764657`}, {-4.75, 0.8909958270419003, 
      0.4540114934601547}, {-5., 0.8909958270419003, 
      0.4540114934601547}, {-5., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-5., 0.8909958270419003, 0.4540114934601547}, {-4.75, 
      0.8909958270419003, 0.4540114934601547}, {-4.75, 0.808998528157412, 
      0.5878106680208697}, {-5., 0.808998528157412, 0.5878106680208697}, {-5.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-5., 0.8089985281574118, 0.58781066802087}, {-4.75, 
      0.8089985281574118, 0.58781066802087}, {-4.75, 0.7070790126229676, 
      0.70713454865968}, {-5., 0.7070790126229676, 0.70713454865968}, {-5., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-5., 0.7070790126229676, 0.70713454865968}, {-4.75, 
      0.7070790126229676, 0.70713454865968}, {-4.75, 0.5877471276121592, 
      0.8090446922041181}, {-5., 0.5877471276121592, 
      0.8090446922041181}, {-5., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-5., 0.5877471276121592, 0.8090446922041181}, {-4.75, 
      0.5877471276121592, 0.8090446922041181}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}, {-5., 0.45394151341132644`, 
      0.8910314822731207}, {-5., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-5., 0.45394151341132644`, 0.8910314822731207}, {-4.75, 
      0.45394151341132644`, 0.8910314822731207}, {-4.75, 0.3089572371217171, 
      0.9510759305282176}, {-5., 0.3089572371217171, 
      0.9510759305282176}, {-5., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-5., 0.3089572371217171, 0.9510759305282176}, {-4.75, 
      0.3089572371217171, 0.9510759305282176}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}, {-5., 0.15636464907469383`, 
      0.9876993958283805}, {-5., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-5., 0.15636464907469383`, 0.9876993958283805}, {-4.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-5., -0.00007853981625862234, 
      0.9999999969157486}, {-5., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-5., -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-5., -0.156519794603278, 
      0.9876748219415881}, {-5., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-5., -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-5., -0.3091066279673126, 
      0.9510273879056678}, {-5., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-5., -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-5., -0.45408147070841254`, 
      0.8909601663145693}, {-5., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-5., -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-5., -0.5878742048036691, 
      0.8089523591203958}, {-5., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-5., -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-5., -0.707190080334431, 
      0.7070234722246362}, {-5., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-5., -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-5., -0.8090908512602302, 
      0.5876835835779286}, {-5., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-5., -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-5., -0.8910671320080111, 
      0.4538715305623583}, {-5., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-5., -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-5., -0.9511001930394957, 
      0.3088825388399836}, {-5., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-5., -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-5., -0.9877116736328749, 
      0.15628707486335883`}, {-5., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-5., -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9999999876629945, \
-0.0001570796320327716}, {-5., -0.9999999876629945, -0.0001570796320327716}, \
{-5., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-4.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.5, -0.987711673632875, \
-0.15628707486335794`}, {-4.75, -0.987711673632875, -0.15628707486335794`}, \
{-4.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.75, -0.987711673632875, -0.15628707486335794`}, {-4.5, \
-0.987711673632875, -0.15628707486335794`}, {-4.5, -0.951100193039496, \
-0.3088825388399828}, {-4.75, -0.951100193039496, -0.3088825388399828}, \
{-4.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.75, -0.951100193039496, -0.3088825388399828}, {-4.5, \
-0.951100193039496, -0.3088825388399828}, {-4.5, -0.8910671320080115, \
-0.4538715305623575}, {-4.75, -0.8910671320080115, -0.4538715305623575}, \
{-4.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.75, -0.8910671320080115, -0.4538715305623575}, {-4.5, \
-0.8910671320080115, -0.4538715305623575}, {-4.5, -0.8090908512602306, \
-0.5876835835779278}, {-4.75, -0.8090908512602306, -0.5876835835779278}, \
{-4.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.75, -0.8090908512602306, -0.5876835835779278}, {-4.5, \
-0.8090908512602306, -0.5876835835779278}, {-4.5, -0.7071900803344316, \
-0.7070234722246357}, {-4.75, -0.7071900803344316, -0.7070234722246357}, \
{-4.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.75, -0.7071900803344316, -0.7070234722246357}, {-4.5, \
-0.7071900803344316, -0.7070234722246357}, {-4.5, -0.5878742048036698, \
-0.8089523591203952}, {-4.75, -0.5878742048036698, -0.8089523591203952}, \
{-4.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.75, -0.5878742048036698, -0.8089523591203952}, {-4.5, \
-0.5878742048036698, -0.8089523591203952}, {-4.5, -0.45408147070841337`, \
-0.890960166314569}, {-4.75, -0.45408147070841337`, -0.890960166314569}, \
{-4.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.75, -0.45408147070841337`, -0.890960166314569}, {-4.5, \
-0.45408147070841337`, -0.890960166314569}, {-4.5, -0.3091066279673134, \
-0.9510273879056674}, {-4.75, -0.3091066279673134, -0.9510273879056674}, \
{-4.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.75, -0.3091066279673132, -0.9510273879056675}, {-4.5, \
-0.3091066279673132, -0.9510273879056675}, {-4.5, -0.15651979460327867`, \
-0.987674821941588}, {-4.75, -0.15651979460327867`, -0.987674821941588}, \
{-4.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.75, -0.15651979460327867`, -0.987674821941588}, {-4.5, \
-0.15651979460327867`, -0.987674821941588}, {-4.5, -0.00007853981625928847, \
-0.9999999969157486}, {-4.75, -0.00007853981625928847, -0.9999999969157486}, \
{-4.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.75, -0.00007853981625928847, -0.9999999969157486}, \
{-4.5, -0.00007853981625928847, -0.9999999969157486}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.75, 0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.30895723712171647`, -0.9510759305282178}, {-4.75, 
      0.30895723712171647`, -0.9510759305282178}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.75, 0.3089572371217167, -0.9510759305282178}, {-4.5, 
      0.3089572371217167, -0.9510759305282178}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.75, 0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.75, 0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.75, 0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.75, 0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.75, 0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.75, 0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.9876871119312596, -0.15644222232149346`}, {-4.75, 
      0.9876871119312596, -0.15644222232149346`}, {-4.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.75, 0.9876871119312596, -0.1564422223214935}, {-4.5, 
      0.9876871119312596, -0.1564422223214935}, {-4.5, 
      1., -4.163336342344337*^-16}, {-4.75, 
      1., -4.163336342344337*^-16}, {-4.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.75, 1., -4.440892098500626*^-16}, {-4.5, 
      1., -4.440892098500626*^-16}, {-4.5, 0.9876871119312597, 
      0.15644222232149263`}, {-4.75, 0.9876871119312597, 
      0.15644222232149263`}, {-4.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.75, 0.9876871119312597, 0.1564422223214926}, {-4.5, 
      0.9876871119312597, 0.1564422223214926}, {-4.5, 0.9510516621502252, 
      0.30903193349764657`}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}, {-4.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-4.75, 0.9510516621502252, 0.30903193349764657`}, {-4.5, 
      0.9510516621502252, 0.30903193349764657`}, {-4.5, 0.8909958270419003, 
      0.4540114934601547}, {-4.75, 0.8909958270419003, 
      0.4540114934601547}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-4.75, 0.8909958270419003, 0.4540114934601547}, {-4.5, 
      0.8909958270419003, 0.4540114934601547}, {-4.5, 0.808998528157412, 
      0.5878106680208697}, {-4.75, 0.808998528157412, 
      0.5878106680208697}, {-4.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.75, 0.8089985281574118, 0.58781066802087}, {-4.5, 
      0.8089985281574118, 0.58781066802087}, {-4.5, 0.7070790126229676, 
      0.70713454865968}, {-4.75, 0.7070790126229676, 
      0.70713454865968}, {-4.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.75, 0.7070790126229676, 0.70713454865968}, {-4.5, 
      0.7070790126229676, 0.70713454865968}, {-4.5, 0.5877471276121592, 
      0.8090446922041181}, {-4.75, 0.5877471276121592, 
      0.8090446922041181}, {-4.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.75, 0.5877471276121592, 0.8090446922041181}, {-4.5, 
      0.5877471276121592, 0.8090446922041181}, {-4.5, 0.45394151341132644`, 
      0.8910314822731207}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}, {-4.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.75, 0.45394151341132644`, 0.8910314822731207}, {-4.5, 
      0.45394151341132644`, 0.8910314822731207}, {-4.5, 0.3089572371217171, 
      0.9510759305282176}, {-4.75, 0.3089572371217171, 
      0.9510759305282176}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-4.75, 0.3089572371217171, 0.9510759305282176}, {-4.5, 
      0.3089572371217171, 0.9510759305282176}, {-4.5, 0.15636464907469383`, 
      0.9876993958283805}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}, {-4.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.75, 0.15636464907469383`, 0.9876993958283805}, {-4.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9999999876629945, \
-0.0001570796320327716}, {-4.75, -0.9999999876629945, \
-0.0001570796320327716}, {-4.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-4.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.25, -0.987711673632875, \
-0.15628707486335794`}, {-4.5, -0.987711673632875, -0.15628707486335794`}, \
{-4.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.5, -0.987711673632875, -0.15628707486335794`}, {-4.25, \
-0.987711673632875, -0.15628707486335794`}, {-4.25, -0.951100193039496, \
-0.3088825388399828}, {-4.5, -0.951100193039496, -0.3088825388399828}, {-4.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.5, -0.951100193039496, -0.3088825388399828}, {-4.25, \
-0.951100193039496, -0.3088825388399828}, {-4.25, -0.8910671320080115, \
-0.4538715305623575}, {-4.5, -0.8910671320080115, -0.4538715305623575}, \
{-4.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.5, -0.8910671320080115, -0.4538715305623575}, {-4.25, \
-0.8910671320080115, -0.4538715305623575}, {-4.25, -0.8090908512602306, \
-0.5876835835779278}, {-4.5, -0.8090908512602306, -0.5876835835779278}, \
{-4.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.5, -0.8090908512602306, -0.5876835835779278}, {-4.25, \
-0.8090908512602306, -0.5876835835779278}, {-4.25, -0.7071900803344316, \
-0.7070234722246357}, {-4.5, -0.7071900803344316, -0.7070234722246357}, \
{-4.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.5, -0.7071900803344316, -0.7070234722246357}, {-4.25, \
-0.7071900803344316, -0.7070234722246357}, {-4.25, -0.5878742048036698, \
-0.8089523591203952}, {-4.5, -0.5878742048036698, -0.8089523591203952}, \
{-4.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.5, -0.5878742048036698, -0.8089523591203952}, {-4.25, \
-0.5878742048036698, -0.8089523591203952}, {-4.25, -0.45408147070841337`, \
-0.890960166314569}, {-4.5, -0.45408147070841337`, -0.890960166314569}, \
{-4.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.5, -0.45408147070841337`, -0.890960166314569}, {-4.25, \
-0.45408147070841337`, -0.890960166314569}, {-4.25, -0.3091066279673134, \
-0.9510273879056674}, {-4.5, -0.3091066279673134, -0.9510273879056674}, \
{-4.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.5, -0.3091066279673132, -0.9510273879056675}, {-4.25, \
-0.3091066279673132, -0.9510273879056675}, {-4.25, -0.15651979460327867`, \
-0.987674821941588}, {-4.5, -0.15651979460327867`, -0.987674821941588}, \
{-4.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.5, -0.15651979460327867`, -0.987674821941588}, {-4.25, \
-0.15651979460327867`, -0.987674821941588}, {-4.25, -0.00007853981625928847, \
-0.9999999969157486}, {-4.5, -0.00007853981625928847, -0.9999999969157486}, \
{-4.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.5, -0.00007853981625928847, -0.9999999969157486}, \
{-4.25, -0.00007853981625928847, -0.9999999969157486}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.5, 0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.30895723712171647`, -0.9510759305282178}, {-4.5, 
      0.30895723712171647`, -0.9510759305282178}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.5, 0.3089572371217167, -0.9510759305282178}, {-4.25, 
      0.3089572371217167, -0.9510759305282178}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.5, 0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.5, 0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.5, 0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.5, 0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.5, 0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.5, 0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.9876871119312596, -0.15644222232149346`}, {-4.5, 
      0.9876871119312596, -0.15644222232149346`}, {-4.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.5, 0.9876871119312596, -0.1564422223214935}, {-4.25, 
      0.9876871119312596, -0.1564422223214935}, {-4.25, 
      1., -4.163336342344337*^-16}, {-4.5, 
      1., -4.163336342344337*^-16}, {-4.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.5, 1., -4.440892098500626*^-16}, {-4.25, 
      1., -4.440892098500626*^-16}, {-4.25, 0.9876871119312597, 
      0.15644222232149263`}, {-4.5, 0.9876871119312597, 
      0.15644222232149263`}, {-4.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.5, 0.9876871119312597, 0.1564422223214926}, {-4.25, 
      0.9876871119312597, 0.1564422223214926}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}, {-4.5, 0.9510516621502252, 
      0.30903193349764657`}, {-4.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-4.5, 0.9510516621502252, 0.30903193349764657`}, {-4.25, 
      0.9510516621502252, 0.30903193349764657`}, {-4.25, 0.8909958270419003, 
      0.4540114934601547}, {-4.5, 0.8909958270419003, 
      0.4540114934601547}, {-4.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-4.5, 0.8909958270419003, 0.4540114934601547}, {-4.25, 
      0.8909958270419003, 0.4540114934601547}, {-4.25, 0.808998528157412, 
      0.5878106680208697}, {-4.5, 0.808998528157412, 
      0.5878106680208697}, {-4.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.5, 0.8089985281574118, 0.58781066802087}, {-4.25, 
      0.8089985281574118, 0.58781066802087}, {-4.25, 0.7070790126229676, 
      0.70713454865968}, {-4.5, 0.7070790126229676, 0.70713454865968}, {-4.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.5, 0.7070790126229676, 0.70713454865968}, {-4.25, 
      0.7070790126229676, 0.70713454865968}, {-4.25, 0.5877471276121592, 
      0.8090446922041181}, {-4.5, 0.5877471276121592, 
      0.8090446922041181}, {-4.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.5, 0.5877471276121592, 0.8090446922041181}, {-4.25, 
      0.5877471276121592, 0.8090446922041181}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}, {-4.5, 0.45394151341132644`, 
      0.8910314822731207}, {-4.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.5, 0.45394151341132644`, 0.8910314822731207}, {-4.25, 
      0.45394151341132644`, 0.8910314822731207}, {-4.25, 0.3089572371217171, 
      0.9510759305282176}, {-4.5, 0.3089572371217171, 
      0.9510759305282176}, {-4.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-4.5, 0.3089572371217171, 0.9510759305282176}, {-4.25, 
      0.3089572371217171, 0.9510759305282176}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}, {-4.5, 0.15636464907469383`, 
      0.9876993958283805}, {-4.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.5, 0.15636464907469383`, 0.9876993958283805}, {-4.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9999999876629945, \
-0.0001570796320327716}, {-4.5, -0.9999999876629945, -0.0001570796320327716}, \
{-4.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-4.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-4., -0.9999999876629945, 
      0.00015707963203365978`}, {-4., -0.987711673632875, \
-0.15628707486335794`}, {-4.25, -0.987711673632875, -0.15628707486335794`}, \
{-4.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.25, -0.987711673632875, -0.15628707486335794`}, {-4., \
-0.987711673632875, -0.15628707486335794`}, {-4., -0.951100193039496, \
-0.3088825388399828}, {-4.25, -0.951100193039496, -0.3088825388399828}, \
{-4.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.25, -0.951100193039496, -0.3088825388399828}, {-4., \
-0.951100193039496, -0.3088825388399828}, {-4., -0.8910671320080115, \
-0.4538715305623575}, {-4.25, -0.8910671320080115, -0.4538715305623575}, \
{-4.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.25, -0.8910671320080115, -0.4538715305623575}, {-4., \
-0.8910671320080115, -0.4538715305623575}, {-4., -0.8090908512602306, \
-0.5876835835779278}, {-4.25, -0.8090908512602306, -0.5876835835779278}, \
{-4.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.25, -0.8090908512602306, -0.5876835835779278}, {-4., \
-0.8090908512602306, -0.5876835835779278}, {-4., -0.7071900803344316, \
-0.7070234722246357}, {-4.25, -0.7071900803344316, -0.7070234722246357}, \
{-4.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.25, -0.7071900803344316, -0.7070234722246357}, {-4., \
-0.7071900803344316, -0.7070234722246357}, {-4., -0.5878742048036698, \
-0.8089523591203952}, {-4.25, -0.5878742048036698, -0.8089523591203952}, \
{-4.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.25, -0.5878742048036698, -0.8089523591203952}, {-4., \
-0.5878742048036698, -0.8089523591203952}, {-4., -0.45408147070841337`, \
-0.890960166314569}, {-4.25, -0.45408147070841337`, -0.890960166314569}, \
{-4.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.25, -0.45408147070841337`, -0.890960166314569}, {-4., \
-0.45408147070841337`, -0.890960166314569}, {-4., -0.3091066279673134, \
-0.9510273879056674}, {-4.25, -0.3091066279673134, -0.9510273879056674}, \
{-4.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.25, -0.3091066279673132, -0.9510273879056675}, {-4., \
-0.3091066279673132, -0.9510273879056675}, {-4., -0.15651979460327867`, \
-0.987674821941588}, {-4.25, -0.15651979460327867`, -0.987674821941588}, \
{-4.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.25, -0.15651979460327867`, -0.987674821941588}, {-4., \
-0.15651979460327867`, -0.987674821941588}, {-4., -0.00007853981625928847, \
-0.9999999969157486}, {-4.25, -0.00007853981625928847, -0.9999999969157486}, \
{-4.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.25, -0.00007853981625928847, -0.9999999969157486}, \
{-4., -0.00007853981625928847, -0.9999999969157486}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.25, 0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.30895723712171647`, -0.9510759305282178}, {-4.25, 
      0.30895723712171647`, -0.9510759305282178}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.25, 0.3089572371217167, -0.9510759305282178}, {-4., 
      0.3089572371217167, -0.9510759305282178}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.25, 0.453941513411326, -0.8910314822731209}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.25, 0.5877471276121589, -0.8090446922041185}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.25, 0.7070790126229672, -0.7071345486596803}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.25, 0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.25, 0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.25, 0.951051662150225, -0.3090319334976474}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.9876871119312596, -0.15644222232149346`}, {-4.25, 
      0.9876871119312596, -0.15644222232149346`}, {-4.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.25, 0.9876871119312596, -0.1564422223214935}, {-4., 
      0.9876871119312596, -0.1564422223214935}, {-4., 
      1., -4.163336342344337*^-16}, {-4.25, 
      1., -4.163336342344337*^-16}, {-4.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.25, 1., -4.440892098500626*^-16}, {-4., 
      1., -4.440892098500626*^-16}, {-4., 0.9876871119312597, 
      0.15644222232149263`}, {-4.25, 0.9876871119312597, 
      0.15644222232149263`}, {-4.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.25, 0.9876871119312597, 0.1564422223214926}, {-4., 
      0.9876871119312597, 0.1564422223214926}, {-4., 0.9510516621502252, 
      0.30903193349764657`}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}, {-4.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-4.25, 0.9510516621502252, 0.30903193349764657`}, {-4., 
      0.9510516621502252, 0.30903193349764657`}, {-4., 0.8909958270419003, 
      0.4540114934601547}, {-4.25, 0.8909958270419003, 
      0.4540114934601547}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-4.25, 0.8909958270419003, 0.4540114934601547}, {-4., 
      0.8909958270419003, 0.4540114934601547}, {-4., 0.808998528157412, 
      0.5878106680208697}, {-4.25, 0.808998528157412, 
      0.5878106680208697}, {-4.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.25, 0.8089985281574118, 0.58781066802087}, {-4., 
      0.8089985281574118, 0.58781066802087}, {-4., 0.7070790126229676, 
      0.70713454865968}, {-4.25, 0.7070790126229676, 
      0.70713454865968}, {-4.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.25, 0.7070790126229676, 0.70713454865968}, {-4., 
      0.7070790126229676, 0.70713454865968}, {-4., 0.5877471276121592, 
      0.8090446922041181}, {-4.25, 0.5877471276121592, 
      0.8090446922041181}, {-4.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.25, 0.5877471276121592, 0.8090446922041181}, {-4., 
      0.5877471276121592, 0.8090446922041181}, {-4., 0.45394151341132644`, 
      0.8910314822731207}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}, {-4.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.25, 0.45394151341132644`, 0.8910314822731207}, {-4., 
      0.45394151341132644`, 0.8910314822731207}, {-4., 0.3089572371217171, 
      0.9510759305282176}, {-4.25, 0.3089572371217171, 
      0.9510759305282176}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-4.25, 0.3089572371217171, 0.9510759305282176}, {-4., 
      0.3089572371217171, 0.9510759305282176}, {-4., 0.15636464907469383`, 
      0.9876993958283805}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}, {-4.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.25, 0.15636464907469383`, 0.9876993958283805}, {-4., 
      0.15636464907469383`, 
      0.9876993958283805}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9999999876629945, \
-0.0001570796320327716}, {-4.25, -0.9999999876629945, \
-0.0001570796320327716}, {-4.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-4., -0.9999999876629945, 
      0.00015707963203365978`}, {-3.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.75, -0.987711673632875, \
-0.15628707486335794`}, {-4., -0.987711673632875, -0.15628707486335794`}, \
{-4., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4., -0.987711673632875, -0.15628707486335794`}, {-3.75, \
-0.987711673632875, -0.15628707486335794`}, {-3.75, -0.951100193039496, \
-0.3088825388399828}, {-4., -0.951100193039496, -0.3088825388399828}, {-4., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4., -0.951100193039496, -0.3088825388399828}, {-3.75, \
-0.951100193039496, -0.3088825388399828}, {-3.75, -0.8910671320080115, \
-0.4538715305623575}, {-4., -0.8910671320080115, -0.4538715305623575}, {-4., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4., -0.8910671320080115, -0.4538715305623575}, {-3.75, \
-0.8910671320080115, -0.4538715305623575}, {-3.75, -0.8090908512602306, \
-0.5876835835779278}, {-4., -0.8090908512602306, -0.5876835835779278}, {-4., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4., -0.8090908512602306, -0.5876835835779278}, {-3.75, \
-0.8090908512602306, -0.5876835835779278}, {-3.75, -0.7071900803344316, \
-0.7070234722246357}, {-4., -0.7071900803344316, -0.7070234722246357}, {-4., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4., -0.7071900803344316, -0.7070234722246357}, {-3.75, \
-0.7071900803344316, -0.7070234722246357}, {-3.75, -0.5878742048036698, \
-0.8089523591203952}, {-4., -0.5878742048036698, -0.8089523591203952}, {-4., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4., -0.5878742048036698, -0.8089523591203952}, {-3.75, \
-0.5878742048036698, -0.8089523591203952}, {-3.75, -0.45408147070841337`, \
-0.890960166314569}, {-4., -0.45408147070841337`, -0.890960166314569}, {-4., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4., -0.45408147070841337`, -0.890960166314569}, {-3.75, \
-0.45408147070841337`, -0.890960166314569}, {-3.75, -0.3091066279673134, \
-0.9510273879056674}, {-4., -0.3091066279673134, -0.9510273879056674}, {-4., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4., -0.3091066279673132, -0.9510273879056675}, {-3.75, \
-0.3091066279673132, -0.9510273879056675}, {-3.75, -0.15651979460327867`, \
-0.987674821941588}, {-4., -0.15651979460327867`, -0.987674821941588}, {-4., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4., -0.15651979460327867`, -0.987674821941588}, {-3.75, \
-0.15651979460327867`, -0.987674821941588}, {-3.75, -0.00007853981625928847, \
-0.9999999969157486}, {-4., -0.00007853981625928847, -0.9999999969157486}, \
{-4., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4., -0.00007853981625928847, -0.9999999969157486}, \
{-3.75, -0.00007853981625928847, -0.9999999969157486}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4., 0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.30895723712171647`, -0.9510759305282178}, {-4., 
      0.30895723712171647`, -0.9510759305282178}, {-4., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4., 0.3089572371217167, -0.9510759305282178}, {-3.75, 
      0.3089572371217167, -0.9510759305282178}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4., 0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4., 0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4., 0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4., 0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4., 0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4., 0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.9876871119312596, -0.15644222232149346`}, {-4., 
      0.9876871119312596, -0.15644222232149346`}, {-4., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4., 0.9876871119312596, -0.1564422223214935}, {-3.75, 
      0.9876871119312596, -0.1564422223214935}, {-3.75, 
      1., -4.163336342344337*^-16}, {-4., 1., -4.163336342344337*^-16}, {-4., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4., 1., -4.440892098500626*^-16}, {-3.75, 
      1., -4.440892098500626*^-16}, {-3.75, 0.9876871119312597, 
      0.15644222232149263`}, {-4., 0.9876871119312597, 
      0.15644222232149263`}, {-4., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4., 0.9876871119312597, 0.1564422223214926}, {-3.75, 
      0.9876871119312597, 0.1564422223214926}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}, {-4., 0.9510516621502252, 
      0.30903193349764657`}, {-4., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-4., 0.9510516621502252, 0.30903193349764657`}, {-3.75, 
      0.9510516621502252, 0.30903193349764657`}, {-3.75, 0.8909958270419003, 
      0.4540114934601547}, {-4., 0.8909958270419003, 
      0.4540114934601547}, {-4., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-4., 0.8909958270419003, 0.4540114934601547}, {-3.75, 
      0.8909958270419003, 0.4540114934601547}, {-3.75, 0.808998528157412, 
      0.5878106680208697}, {-4., 0.808998528157412, 0.5878106680208697}, {-4.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4., 0.8089985281574118, 0.58781066802087}, {-3.75, 
      0.8089985281574118, 0.58781066802087}, {-3.75, 0.7070790126229676, 
      0.70713454865968}, {-4., 0.7070790126229676, 0.70713454865968}, {-4., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4., 0.7070790126229676, 0.70713454865968}, {-3.75, 
      0.7070790126229676, 0.70713454865968}, {-3.75, 0.5877471276121592, 
      0.8090446922041181}, {-4., 0.5877471276121592, 
      0.8090446922041181}, {-4., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4., 0.5877471276121592, 0.8090446922041181}, {-3.75, 
      0.5877471276121592, 0.8090446922041181}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}, {-4., 0.45394151341132644`, 
      0.8910314822731207}, {-4., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4., 0.45394151341132644`, 0.8910314822731207}, {-3.75, 
      0.45394151341132644`, 0.8910314822731207}, {-3.75, 0.3089572371217171, 
      0.9510759305282176}, {-4., 0.3089572371217171, 
      0.9510759305282176}, {-4., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-4., 0.3089572371217171, 0.9510759305282176}, {-3.75, 
      0.3089572371217171, 0.9510759305282176}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}, {-4., 0.15636464907469383`, 
      0.9876993958283805}, {-4., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4., 0.15636464907469383`, 0.9876993958283805}, {-3.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-4., -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4., -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4., -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-4., -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-4., -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-4., -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4., -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-4., -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-4., -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-4., -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9999999876629945, \
-0.0001570796320327716}, {-4., -0.9999999876629945, -0.0001570796320327716}, \
{-4., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-3.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.5, -0.987711673632875, \
-0.15628707486335794`}, {-3.75, -0.987711673632875, -0.15628707486335794`}, \
{-3.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.75, -0.987711673632875, -0.15628707486335794`}, {-3.5, \
-0.987711673632875, -0.15628707486335794`}, {-3.5, -0.951100193039496, \
-0.3088825388399828}, {-3.75, -0.951100193039496, -0.3088825388399828}, \
{-3.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.75, -0.951100193039496, -0.3088825388399828}, {-3.5, \
-0.951100193039496, -0.3088825388399828}, {-3.5, -0.8910671320080115, \
-0.4538715305623575}, {-3.75, -0.8910671320080115, -0.4538715305623575}, \
{-3.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.75, -0.8910671320080115, -0.4538715305623575}, {-3.5, \
-0.8910671320080115, -0.4538715305623575}, {-3.5, -0.8090908512602306, \
-0.5876835835779278}, {-3.75, -0.8090908512602306, -0.5876835835779278}, \
{-3.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.75, -0.8090908512602306, -0.5876835835779278}, {-3.5, \
-0.8090908512602306, -0.5876835835779278}, {-3.5, -0.7071900803344316, \
-0.7070234722246357}, {-3.75, -0.7071900803344316, -0.7070234722246357}, \
{-3.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.75, -0.7071900803344316, -0.7070234722246357}, {-3.5, \
-0.7071900803344316, -0.7070234722246357}, {-3.5, -0.5878742048036698, \
-0.8089523591203952}, {-3.75, -0.5878742048036698, -0.8089523591203952}, \
{-3.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.75, -0.5878742048036698, -0.8089523591203952}, {-3.5, \
-0.5878742048036698, -0.8089523591203952}, {-3.5, -0.45408147070841337`, \
-0.890960166314569}, {-3.75, -0.45408147070841337`, -0.890960166314569}, \
{-3.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.75, -0.45408147070841337`, -0.890960166314569}, {-3.5, \
-0.45408147070841337`, -0.890960166314569}, {-3.5, -0.3091066279673134, \
-0.9510273879056674}, {-3.75, -0.3091066279673134, -0.9510273879056674}, \
{-3.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.75, -0.3091066279673132, -0.9510273879056675}, {-3.5, \
-0.3091066279673132, -0.9510273879056675}, {-3.5, -0.15651979460327867`, \
-0.987674821941588}, {-3.75, -0.15651979460327867`, -0.987674821941588}, \
{-3.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.75, -0.15651979460327867`, -0.987674821941588}, {-3.5, \
-0.15651979460327867`, -0.987674821941588}, {-3.5, -0.00007853981625928847, \
-0.9999999969157486}, {-3.75, -0.00007853981625928847, -0.9999999969157486}, \
{-3.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.75, -0.00007853981625928847, -0.9999999969157486}, \
{-3.5, -0.00007853981625928847, -0.9999999969157486}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.75, 0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.30895723712171647`, -0.9510759305282178}, {-3.75, 
      0.30895723712171647`, -0.9510759305282178}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.75, 0.3089572371217167, -0.9510759305282178}, {-3.5, 
      0.3089572371217167, -0.9510759305282178}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.75, 0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.75, 0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.75, 0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.75, 0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.75, 0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.75, 0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.9876871119312596, -0.15644222232149346`}, {-3.75, 
      0.9876871119312596, -0.15644222232149346`}, {-3.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.75, 0.9876871119312596, -0.1564422223214935}, {-3.5, 
      0.9876871119312596, -0.1564422223214935}, {-3.5, 
      1., -4.163336342344337*^-16}, {-3.75, 
      1., -4.163336342344337*^-16}, {-3.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.75, 1., -4.440892098500626*^-16}, {-3.5, 
      1., -4.440892098500626*^-16}, {-3.5, 0.9876871119312597, 
      0.15644222232149263`}, {-3.75, 0.9876871119312597, 
      0.15644222232149263`}, {-3.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.75, 0.9876871119312597, 0.1564422223214926}, {-3.5, 
      0.9876871119312597, 0.1564422223214926}, {-3.5, 0.9510516621502252, 
      0.30903193349764657`}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}, {-3.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-3.75, 0.9510516621502252, 0.30903193349764657`}, {-3.5, 
      0.9510516621502252, 0.30903193349764657`}, {-3.5, 0.8909958270419003, 
      0.4540114934601547}, {-3.75, 0.8909958270419003, 
      0.4540114934601547}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-3.75, 0.8909958270419003, 0.4540114934601547}, {-3.5, 
      0.8909958270419003, 0.4540114934601547}, {-3.5, 0.808998528157412, 
      0.5878106680208697}, {-3.75, 0.808998528157412, 
      0.5878106680208697}, {-3.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.75, 0.8089985281574118, 0.58781066802087}, {-3.5, 
      0.8089985281574118, 0.58781066802087}, {-3.5, 0.7070790126229676, 
      0.70713454865968}, {-3.75, 0.7070790126229676, 
      0.70713454865968}, {-3.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.75, 0.7070790126229676, 0.70713454865968}, {-3.5, 
      0.7070790126229676, 0.70713454865968}, {-3.5, 0.5877471276121592, 
      0.8090446922041181}, {-3.75, 0.5877471276121592, 
      0.8090446922041181}, {-3.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.75, 0.5877471276121592, 0.8090446922041181}, {-3.5, 
      0.5877471276121592, 0.8090446922041181}, {-3.5, 0.45394151341132644`, 
      0.8910314822731207}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}, {-3.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.75, 0.45394151341132644`, 0.8910314822731207}, {-3.5, 
      0.45394151341132644`, 0.8910314822731207}, {-3.5, 0.3089572371217171, 
      0.9510759305282176}, {-3.75, 0.3089572371217171, 
      0.9510759305282176}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-3.75, 0.3089572371217171, 0.9510759305282176}, {-3.5, 
      0.3089572371217171, 0.9510759305282176}, {-3.5, 0.15636464907469383`, 
      0.9876993958283805}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}, {-3.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.75, 0.15636464907469383`, 0.9876993958283805}, {-3.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9999999876629945, \
-0.0001570796320327716}, {-3.75, -0.9999999876629945, \
-0.0001570796320327716}, {-3.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-3.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.25, -0.987711673632875, \
-0.15628707486335794`}, {-3.5, -0.987711673632875, -0.15628707486335794`}, \
{-3.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.5, -0.987711673632875, -0.15628707486335794`}, {-3.25, \
-0.987711673632875, -0.15628707486335794`}, {-3.25, -0.951100193039496, \
-0.3088825388399828}, {-3.5, -0.951100193039496, -0.3088825388399828}, {-3.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.5, -0.951100193039496, -0.3088825388399828}, {-3.25, \
-0.951100193039496, -0.3088825388399828}, {-3.25, -0.8910671320080115, \
-0.4538715305623575}, {-3.5, -0.8910671320080115, -0.4538715305623575}, \
{-3.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.5, -0.8910671320080115, -0.4538715305623575}, {-3.25, \
-0.8910671320080115, -0.4538715305623575}, {-3.25, -0.8090908512602306, \
-0.5876835835779278}, {-3.5, -0.8090908512602306, -0.5876835835779278}, \
{-3.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.5, -0.8090908512602306, -0.5876835835779278}, {-3.25, \
-0.8090908512602306, -0.5876835835779278}, {-3.25, -0.7071900803344316, \
-0.7070234722246357}, {-3.5, -0.7071900803344316, -0.7070234722246357}, \
{-3.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.5, -0.7071900803344316, -0.7070234722246357}, {-3.25, \
-0.7071900803344316, -0.7070234722246357}, {-3.25, -0.5878742048036698, \
-0.8089523591203952}, {-3.5, -0.5878742048036698, -0.8089523591203952}, \
{-3.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.5, -0.5878742048036698, -0.8089523591203952}, {-3.25, \
-0.5878742048036698, -0.8089523591203952}, {-3.25, -0.45408147070841337`, \
-0.890960166314569}, {-3.5, -0.45408147070841337`, -0.890960166314569}, \
{-3.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.5, -0.45408147070841337`, -0.890960166314569}, {-3.25, \
-0.45408147070841337`, -0.890960166314569}, {-3.25, -0.3091066279673134, \
-0.9510273879056674}, {-3.5, -0.3091066279673134, -0.9510273879056674}, \
{-3.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.5, -0.3091066279673132, -0.9510273879056675}, {-3.25, \
-0.3091066279673132, -0.9510273879056675}, {-3.25, -0.15651979460327867`, \
-0.987674821941588}, {-3.5, -0.15651979460327867`, -0.987674821941588}, \
{-3.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.5, -0.15651979460327867`, -0.987674821941588}, {-3.25, \
-0.15651979460327867`, -0.987674821941588}, {-3.25, -0.00007853981625928847, \
-0.9999999969157486}, {-3.5, -0.00007853981625928847, -0.9999999969157486}, \
{-3.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.5, -0.00007853981625928847, -0.9999999969157486}, \
{-3.25, -0.00007853981625928847, -0.9999999969157486}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.5, 0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.30895723712171647`, -0.9510759305282178}, {-3.5, 
      0.30895723712171647`, -0.9510759305282178}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.5, 0.3089572371217167, -0.9510759305282178}, {-3.25, 
      0.3089572371217167, -0.9510759305282178}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.5, 0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.5, 0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.5, 0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.5, 0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.5, 0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.5, 0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.9876871119312596, -0.15644222232149346`}, {-3.5, 
      0.9876871119312596, -0.15644222232149346`}, {-3.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.5, 0.9876871119312596, -0.1564422223214935}, {-3.25, 
      0.9876871119312596, -0.1564422223214935}, {-3.25, 
      1., -4.163336342344337*^-16}, {-3.5, 
      1., -4.163336342344337*^-16}, {-3.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.5, 1., -4.440892098500626*^-16}, {-3.25, 
      1., -4.440892098500626*^-16}, {-3.25, 0.9876871119312597, 
      0.15644222232149263`}, {-3.5, 0.9876871119312597, 
      0.15644222232149263`}, {-3.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.5, 0.9876871119312597, 0.1564422223214926}, {-3.25, 
      0.9876871119312597, 0.1564422223214926}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}, {-3.5, 0.9510516621502252, 
      0.30903193349764657`}, {-3.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-3.5, 0.9510516621502252, 0.30903193349764657`}, {-3.25, 
      0.9510516621502252, 0.30903193349764657`}, {-3.25, 0.8909958270419003, 
      0.4540114934601547}, {-3.5, 0.8909958270419003, 
      0.4540114934601547}, {-3.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-3.5, 0.8909958270419003, 0.4540114934601547}, {-3.25, 
      0.8909958270419003, 0.4540114934601547}, {-3.25, 0.808998528157412, 
      0.5878106680208697}, {-3.5, 0.808998528157412, 
      0.5878106680208697}, {-3.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.5, 0.8089985281574118, 0.58781066802087}, {-3.25, 
      0.8089985281574118, 0.58781066802087}, {-3.25, 0.7070790126229676, 
      0.70713454865968}, {-3.5, 0.7070790126229676, 0.70713454865968}, {-3.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.5, 0.7070790126229676, 0.70713454865968}, {-3.25, 
      0.7070790126229676, 0.70713454865968}, {-3.25, 0.5877471276121592, 
      0.8090446922041181}, {-3.5, 0.5877471276121592, 
      0.8090446922041181}, {-3.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.5, 0.5877471276121592, 0.8090446922041181}, {-3.25, 
      0.5877471276121592, 0.8090446922041181}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}, {-3.5, 0.45394151341132644`, 
      0.8910314822731207}, {-3.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.5, 0.45394151341132644`, 0.8910314822731207}, {-3.25, 
      0.45394151341132644`, 0.8910314822731207}, {-3.25, 0.3089572371217171, 
      0.9510759305282176}, {-3.5, 0.3089572371217171, 
      0.9510759305282176}, {-3.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-3.5, 0.3089572371217171, 0.9510759305282176}, {-3.25, 
      0.3089572371217171, 0.9510759305282176}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}, {-3.5, 0.15636464907469383`, 
      0.9876993958283805}, {-3.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.5, 0.15636464907469383`, 0.9876993958283805}, {-3.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9999999876629945, \
-0.0001570796320327716}, {-3.5, -0.9999999876629945, -0.0001570796320327716}, \
{-3.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-3.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-3., -0.9999999876629945, 
      0.00015707963203365978`}, {-3., -0.987711673632875, \
-0.15628707486335794`}, {-3.25, -0.987711673632875, -0.15628707486335794`}, \
{-3.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.25, -0.987711673632875, -0.15628707486335794`}, {-3., \
-0.987711673632875, -0.15628707486335794`}, {-3., -0.951100193039496, \
-0.3088825388399828}, {-3.25, -0.951100193039496, -0.3088825388399828}, \
{-3.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.25, -0.951100193039496, -0.3088825388399828}, {-3., \
-0.951100193039496, -0.3088825388399828}, {-3., -0.8910671320080115, \
-0.4538715305623575}, {-3.25, -0.8910671320080115, -0.4538715305623575}, \
{-3.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.25, -0.8910671320080115, -0.4538715305623575}, {-3., \
-0.8910671320080115, -0.4538715305623575}, {-3., -0.8090908512602306, \
-0.5876835835779278}, {-3.25, -0.8090908512602306, -0.5876835835779278}, \
{-3.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.25, -0.8090908512602306, -0.5876835835779278}, {-3., \
-0.8090908512602306, -0.5876835835779278}, {-3., -0.7071900803344316, \
-0.7070234722246357}, {-3.25, -0.7071900803344316, -0.7070234722246357}, \
{-3.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.25, -0.7071900803344316, -0.7070234722246357}, {-3., \
-0.7071900803344316, -0.7070234722246357}, {-3., -0.5878742048036698, \
-0.8089523591203952}, {-3.25, -0.5878742048036698, -0.8089523591203952}, \
{-3.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.25, -0.5878742048036698, -0.8089523591203952}, {-3., \
-0.5878742048036698, -0.8089523591203952}, {-3., -0.45408147070841337`, \
-0.890960166314569}, {-3.25, -0.45408147070841337`, -0.890960166314569}, \
{-3.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.25, -0.45408147070841337`, -0.890960166314569}, {-3., \
-0.45408147070841337`, -0.890960166314569}, {-3., -0.3091066279673134, \
-0.9510273879056674}, {-3.25, -0.3091066279673134, -0.9510273879056674}, \
{-3.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.25, -0.3091066279673132, -0.9510273879056675}, {-3., \
-0.3091066279673132, -0.9510273879056675}, {-3., -0.15651979460327867`, \
-0.987674821941588}, {-3.25, -0.15651979460327867`, -0.987674821941588}, \
{-3.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.25, -0.15651979460327867`, -0.987674821941588}, {-3., \
-0.15651979460327867`, -0.987674821941588}, {-3., -0.00007853981625928847, \
-0.9999999969157486}, {-3.25, -0.00007853981625928847, -0.9999999969157486}, \
{-3.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.25, -0.00007853981625928847, -0.9999999969157486}, \
{-3., -0.00007853981625928847, -0.9999999969157486}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.25, 0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.30895723712171647`, -0.9510759305282178}, {-3.25, 
      0.30895723712171647`, -0.9510759305282178}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.25, 0.3089572371217167, -0.9510759305282178}, {-3., 
      0.3089572371217167, -0.9510759305282178}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.25, 0.453941513411326, -0.8910314822731209}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.25, 0.5877471276121589, -0.8090446922041185}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.25, 0.7070790126229672, -0.7071345486596803}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.25, 0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.25, 0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.25, 0.951051662150225, -0.3090319334976474}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.9876871119312596, -0.15644222232149346`}, {-3.25, 
      0.9876871119312596, -0.15644222232149346`}, {-3.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.25, 0.9876871119312596, -0.1564422223214935}, {-3., 
      0.9876871119312596, -0.1564422223214935}, {-3., 
      1., -4.163336342344337*^-16}, {-3.25, 
      1., -4.163336342344337*^-16}, {-3.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.25, 1., -4.440892098500626*^-16}, {-3., 
      1., -4.440892098500626*^-16}, {-3., 0.9876871119312597, 
      0.15644222232149263`}, {-3.25, 0.9876871119312597, 
      0.15644222232149263`}, {-3.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.25, 0.9876871119312597, 0.1564422223214926}, {-3., 
      0.9876871119312597, 0.1564422223214926}, {-3., 0.9510516621502252, 
      0.30903193349764657`}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}, {-3.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-3.25, 0.9510516621502252, 0.30903193349764657`}, {-3., 
      0.9510516621502252, 0.30903193349764657`}, {-3., 0.8909958270419003, 
      0.4540114934601547}, {-3.25, 0.8909958270419003, 
      0.4540114934601547}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-3.25, 0.8909958270419003, 0.4540114934601547}, {-3., 
      0.8909958270419003, 0.4540114934601547}, {-3., 0.808998528157412, 
      0.5878106680208697}, {-3.25, 0.808998528157412, 
      0.5878106680208697}, {-3.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.25, 0.8089985281574118, 0.58781066802087}, {-3., 
      0.8089985281574118, 0.58781066802087}, {-3., 0.7070790126229676, 
      0.70713454865968}, {-3.25, 0.7070790126229676, 
      0.70713454865968}, {-3.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.25, 0.7070790126229676, 0.70713454865968}, {-3., 
      0.7070790126229676, 0.70713454865968}, {-3., 0.5877471276121592, 
      0.8090446922041181}, {-3.25, 0.5877471276121592, 
      0.8090446922041181}, {-3.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.25, 0.5877471276121592, 0.8090446922041181}, {-3., 
      0.5877471276121592, 0.8090446922041181}, {-3., 0.45394151341132644`, 
      0.8910314822731207}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}, {-3.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.25, 0.45394151341132644`, 0.8910314822731207}, {-3., 
      0.45394151341132644`, 0.8910314822731207}, {-3., 0.3089572371217171, 
      0.9510759305282176}, {-3.25, 0.3089572371217171, 
      0.9510759305282176}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-3.25, 0.3089572371217171, 0.9510759305282176}, {-3., 
      0.3089572371217171, 0.9510759305282176}, {-3., 0.15636464907469383`, 
      0.9876993958283805}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}, {-3.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.25, 0.15636464907469383`, 0.9876993958283805}, {-3., 
      0.15636464907469383`, 
      0.9876993958283805}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9999999876629945, \
-0.0001570796320327716}, {-3.25, -0.9999999876629945, \
-0.0001570796320327716}, {-3.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-3., -0.9999999876629945, 
      0.00015707963203365978`}, {-2.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.75, -0.987711673632875, \
-0.15628707486335794`}, {-3., -0.987711673632875, -0.15628707486335794`}, \
{-3., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3., -0.987711673632875, -0.15628707486335794`}, {-2.75, \
-0.987711673632875, -0.15628707486335794`}, {-2.75, -0.951100193039496, \
-0.3088825388399828}, {-3., -0.951100193039496, -0.3088825388399828}, {-3., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3., -0.951100193039496, -0.3088825388399828}, {-2.75, \
-0.951100193039496, -0.3088825388399828}, {-2.75, -0.8910671320080115, \
-0.4538715305623575}, {-3., -0.8910671320080115, -0.4538715305623575}, {-3., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3., -0.8910671320080115, -0.4538715305623575}, {-2.75, \
-0.8910671320080115, -0.4538715305623575}, {-2.75, -0.8090908512602306, \
-0.5876835835779278}, {-3., -0.8090908512602306, -0.5876835835779278}, {-3., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3., -0.8090908512602306, -0.5876835835779278}, {-2.75, \
-0.8090908512602306, -0.5876835835779278}, {-2.75, -0.7071900803344316, \
-0.7070234722246357}, {-3., -0.7071900803344316, -0.7070234722246357}, {-3., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3., -0.7071900803344316, -0.7070234722246357}, {-2.75, \
-0.7071900803344316, -0.7070234722246357}, {-2.75, -0.5878742048036698, \
-0.8089523591203952}, {-3., -0.5878742048036698, -0.8089523591203952}, {-3., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3., -0.5878742048036698, -0.8089523591203952}, {-2.75, \
-0.5878742048036698, -0.8089523591203952}, {-2.75, -0.45408147070841337`, \
-0.890960166314569}, {-3., -0.45408147070841337`, -0.890960166314569}, {-3., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3., -0.45408147070841337`, -0.890960166314569}, {-2.75, \
-0.45408147070841337`, -0.890960166314569}, {-2.75, -0.3091066279673134, \
-0.9510273879056674}, {-3., -0.3091066279673134, -0.9510273879056674}, {-3., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3., -0.3091066279673132, -0.9510273879056675}, {-2.75, \
-0.3091066279673132, -0.9510273879056675}, {-2.75, -0.15651979460327867`, \
-0.987674821941588}, {-3., -0.15651979460327867`, -0.987674821941588}, {-3., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3., -0.15651979460327867`, -0.987674821941588}, {-2.75, \
-0.15651979460327867`, -0.987674821941588}, {-2.75, -0.00007853981625928847, \
-0.9999999969157486}, {-3., -0.00007853981625928847, -0.9999999969157486}, \
{-3., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3., -0.00007853981625928847, -0.9999999969157486}, \
{-2.75, -0.00007853981625928847, -0.9999999969157486}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3., 0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.30895723712171647`, -0.9510759305282178}, {-3., 
      0.30895723712171647`, -0.9510759305282178}, {-3., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3., 0.3089572371217167, -0.9510759305282178}, {-2.75, 
      0.3089572371217167, -0.9510759305282178}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3., 0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3., 0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3., 0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3., 0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3., 0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3., 0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.9876871119312596, -0.15644222232149346`}, {-3., 
      0.9876871119312596, -0.15644222232149346`}, {-3., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3., 0.9876871119312596, -0.1564422223214935}, {-2.75, 
      0.9876871119312596, -0.1564422223214935}, {-2.75, 
      1., -4.163336342344337*^-16}, {-3., 1., -4.163336342344337*^-16}, {-3., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3., 1., -4.440892098500626*^-16}, {-2.75, 
      1., -4.440892098500626*^-16}, {-2.75, 0.9876871119312597, 
      0.15644222232149263`}, {-3., 0.9876871119312597, 
      0.15644222232149263`}, {-3., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3., 0.9876871119312597, 0.1564422223214926}, {-2.75, 
      0.9876871119312597, 0.1564422223214926}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}, {-3., 0.9510516621502252, 
      0.30903193349764657`}, {-3., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-3., 0.9510516621502252, 0.30903193349764657`}, {-2.75, 
      0.9510516621502252, 0.30903193349764657`}, {-2.75, 0.8909958270419003, 
      0.4540114934601547}, {-3., 0.8909958270419003, 
      0.4540114934601547}, {-3., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-3., 0.8909958270419003, 0.4540114934601547}, {-2.75, 
      0.8909958270419003, 0.4540114934601547}, {-2.75, 0.808998528157412, 
      0.5878106680208697}, {-3., 0.808998528157412, 0.5878106680208697}, {-3.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3., 0.8089985281574118, 0.58781066802087}, {-2.75, 
      0.8089985281574118, 0.58781066802087}, {-2.75, 0.7070790126229676, 
      0.70713454865968}, {-3., 0.7070790126229676, 0.70713454865968}, {-3., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3., 0.7070790126229676, 0.70713454865968}, {-2.75, 
      0.7070790126229676, 0.70713454865968}, {-2.75, 0.5877471276121592, 
      0.8090446922041181}, {-3., 0.5877471276121592, 
      0.8090446922041181}, {-3., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3., 0.5877471276121592, 0.8090446922041181}, {-2.75, 
      0.5877471276121592, 0.8090446922041181}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}, {-3., 0.45394151341132644`, 
      0.8910314822731207}, {-3., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3., 0.45394151341132644`, 0.8910314822731207}, {-2.75, 
      0.45394151341132644`, 0.8910314822731207}, {-2.75, 0.3089572371217171, 
      0.9510759305282176}, {-3., 0.3089572371217171, 
      0.9510759305282176}, {-3., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-3., 0.3089572371217171, 0.9510759305282176}, {-2.75, 
      0.3089572371217171, 0.9510759305282176}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}, {-3., 0.15636464907469383`, 
      0.9876993958283805}, {-3., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3., 0.15636464907469383`, 0.9876993958283805}, {-2.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-3., -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3., -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3., -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-3., -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-3., -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-3., -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3., -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-3., -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-3., -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-3., -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9999999876629945, \
-0.0001570796320327716}, {-3., -0.9999999876629945, -0.0001570796320327716}, \
{-3., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-2.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.5, -0.987711673632875, \
-0.15628707486335794`}, {-2.75, -0.987711673632875, -0.15628707486335794`}, \
{-2.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.75, -0.987711673632875, -0.15628707486335794`}, {-2.5, \
-0.987711673632875, -0.15628707486335794`}, {-2.5, -0.951100193039496, \
-0.3088825388399828}, {-2.75, -0.951100193039496, -0.3088825388399828}, \
{-2.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.75, -0.951100193039496, -0.3088825388399828}, {-2.5, \
-0.951100193039496, -0.3088825388399828}, {-2.5, -0.8910671320080115, \
-0.4538715305623575}, {-2.75, -0.8910671320080115, -0.4538715305623575}, \
{-2.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.75, -0.8910671320080115, -0.4538715305623575}, {-2.5, \
-0.8910671320080115, -0.4538715305623575}, {-2.5, -0.8090908512602306, \
-0.5876835835779278}, {-2.75, -0.8090908512602306, -0.5876835835779278}, \
{-2.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.75, -0.8090908512602306, -0.5876835835779278}, {-2.5, \
-0.8090908512602306, -0.5876835835779278}, {-2.5, -0.7071900803344316, \
-0.7070234722246357}, {-2.75, -0.7071900803344316, -0.7070234722246357}, \
{-2.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.75, -0.7071900803344316, -0.7070234722246357}, {-2.5, \
-0.7071900803344316, -0.7070234722246357}, {-2.5, -0.5878742048036698, \
-0.8089523591203952}, {-2.75, -0.5878742048036698, -0.8089523591203952}, \
{-2.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.75, -0.5878742048036698, -0.8089523591203952}, {-2.5, \
-0.5878742048036698, -0.8089523591203952}, {-2.5, -0.45408147070841337`, \
-0.890960166314569}, {-2.75, -0.45408147070841337`, -0.890960166314569}, \
{-2.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.75, -0.45408147070841337`, -0.890960166314569}, {-2.5, \
-0.45408147070841337`, -0.890960166314569}, {-2.5, -0.3091066279673134, \
-0.9510273879056674}, {-2.75, -0.3091066279673134, -0.9510273879056674}, \
{-2.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.75, -0.3091066279673132, -0.9510273879056675}, {-2.5, \
-0.3091066279673132, -0.9510273879056675}, {-2.5, -0.15651979460327867`, \
-0.987674821941588}, {-2.75, -0.15651979460327867`, -0.987674821941588}, \
{-2.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.75, -0.15651979460327867`, -0.987674821941588}, {-2.5, \
-0.15651979460327867`, -0.987674821941588}, {-2.5, -0.00007853981625928847, \
-0.9999999969157486}, {-2.75, -0.00007853981625928847, -0.9999999969157486}, \
{-2.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.75, -0.00007853981625928847, -0.9999999969157486}, \
{-2.5, -0.00007853981625928847, -0.9999999969157486}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.75, 0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.30895723712171647`, -0.9510759305282178}, {-2.75, 
      0.30895723712171647`, -0.9510759305282178}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.75, 0.3089572371217167, -0.9510759305282178}, {-2.5, 
      0.3089572371217167, -0.9510759305282178}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.75, 0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.75, 0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.75, 0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.75, 0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.75, 0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.75, 0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.9876871119312596, -0.15644222232149346`}, {-2.75, 
      0.9876871119312596, -0.15644222232149346`}, {-2.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.75, 0.9876871119312596, -0.1564422223214935}, {-2.5, 
      0.9876871119312596, -0.1564422223214935}, {-2.5, 
      1., -4.163336342344337*^-16}, {-2.75, 
      1., -4.163336342344337*^-16}, {-2.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.75, 1., -4.440892098500626*^-16}, {-2.5, 
      1., -4.440892098500626*^-16}, {-2.5, 0.9876871119312597, 
      0.15644222232149263`}, {-2.75, 0.9876871119312597, 
      0.15644222232149263`}, {-2.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.75, 0.9876871119312597, 0.1564422223214926}, {-2.5, 
      0.9876871119312597, 0.1564422223214926}, {-2.5, 0.9510516621502252, 
      0.30903193349764657`}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}, {-2.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-2.75, 0.9510516621502252, 0.30903193349764657`}, {-2.5, 
      0.9510516621502252, 0.30903193349764657`}, {-2.5, 0.8909958270419003, 
      0.4540114934601547}, {-2.75, 0.8909958270419003, 
      0.4540114934601547}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-2.75, 0.8909958270419003, 0.4540114934601547}, {-2.5, 
      0.8909958270419003, 0.4540114934601547}, {-2.5, 0.808998528157412, 
      0.5878106680208697}, {-2.75, 0.808998528157412, 
      0.5878106680208697}, {-2.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.75, 0.8089985281574118, 0.58781066802087}, {-2.5, 
      0.8089985281574118, 0.58781066802087}, {-2.5, 0.7070790126229676, 
      0.70713454865968}, {-2.75, 0.7070790126229676, 
      0.70713454865968}, {-2.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.75, 0.7070790126229676, 0.70713454865968}, {-2.5, 
      0.7070790126229676, 0.70713454865968}, {-2.5, 0.5877471276121592, 
      0.8090446922041181}, {-2.75, 0.5877471276121592, 
      0.8090446922041181}, {-2.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.75, 0.5877471276121592, 0.8090446922041181}, {-2.5, 
      0.5877471276121592, 0.8090446922041181}, {-2.5, 0.45394151341132644`, 
      0.8910314822731207}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}, {-2.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.75, 0.45394151341132644`, 0.8910314822731207}, {-2.5, 
      0.45394151341132644`, 0.8910314822731207}, {-2.5, 0.3089572371217171, 
      0.9510759305282176}, {-2.75, 0.3089572371217171, 
      0.9510759305282176}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-2.75, 0.3089572371217171, 0.9510759305282176}, {-2.5, 
      0.3089572371217171, 0.9510759305282176}, {-2.5, 0.15636464907469383`, 
      0.9876993958283805}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}, {-2.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.75, 0.15636464907469383`, 0.9876993958283805}, {-2.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9999999876629945, \
-0.0001570796320327716}, {-2.75, -0.9999999876629945, \
-0.0001570796320327716}, {-2.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-2.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.25, -0.987711673632875, \
-0.15628707486335794`}, {-2.5, -0.987711673632875, -0.15628707486335794`}, \
{-2.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.5, -0.987711673632875, -0.15628707486335794`}, {-2.25, \
-0.987711673632875, -0.15628707486335794`}, {-2.25, -0.951100193039496, \
-0.3088825388399828}, {-2.5, -0.951100193039496, -0.3088825388399828}, {-2.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.5, -0.951100193039496, -0.3088825388399828}, {-2.25, \
-0.951100193039496, -0.3088825388399828}, {-2.25, -0.8910671320080115, \
-0.4538715305623575}, {-2.5, -0.8910671320080115, -0.4538715305623575}, \
{-2.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.5, -0.8910671320080115, -0.4538715305623575}, {-2.25, \
-0.8910671320080115, -0.4538715305623575}, {-2.25, -0.8090908512602306, \
-0.5876835835779278}, {-2.5, -0.8090908512602306, -0.5876835835779278}, \
{-2.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.5, -0.8090908512602306, -0.5876835835779278}, {-2.25, \
-0.8090908512602306, -0.5876835835779278}, {-2.25, -0.7071900803344316, \
-0.7070234722246357}, {-2.5, -0.7071900803344316, -0.7070234722246357}, \
{-2.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.5, -0.7071900803344316, -0.7070234722246357}, {-2.25, \
-0.7071900803344316, -0.7070234722246357}, {-2.25, -0.5878742048036698, \
-0.8089523591203952}, {-2.5, -0.5878742048036698, -0.8089523591203952}, \
{-2.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.5, -0.5878742048036698, -0.8089523591203952}, {-2.25, \
-0.5878742048036698, -0.8089523591203952}, {-2.25, -0.45408147070841337`, \
-0.890960166314569}, {-2.5, -0.45408147070841337`, -0.890960166314569}, \
{-2.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.5, -0.45408147070841337`, -0.890960166314569}, {-2.25, \
-0.45408147070841337`, -0.890960166314569}, {-2.25, -0.3091066279673134, \
-0.9510273879056674}, {-2.5, -0.3091066279673134, -0.9510273879056674}, \
{-2.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.5, -0.3091066279673132, -0.9510273879056675}, {-2.25, \
-0.3091066279673132, -0.9510273879056675}, {-2.25, -0.15651979460327867`, \
-0.987674821941588}, {-2.5, -0.15651979460327867`, -0.987674821941588}, \
{-2.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.5, -0.15651979460327867`, -0.987674821941588}, {-2.25, \
-0.15651979460327867`, -0.987674821941588}, {-2.25, -0.00007853981625928847, \
-0.9999999969157486}, {-2.5, -0.00007853981625928847, -0.9999999969157486}, \
{-2.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.5, -0.00007853981625928847, -0.9999999969157486}, \
{-2.25, -0.00007853981625928847, -0.9999999969157486}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.5, 0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.30895723712171647`, -0.9510759305282178}, {-2.5, 
      0.30895723712171647`, -0.9510759305282178}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.5, 0.3089572371217167, -0.9510759305282178}, {-2.25, 
      0.3089572371217167, -0.9510759305282178}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.5, 0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.5, 0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.5, 0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.5, 0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.5, 0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.5, 0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.9876871119312596, -0.15644222232149346`}, {-2.5, 
      0.9876871119312596, -0.15644222232149346`}, {-2.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.5, 0.9876871119312596, -0.1564422223214935}, {-2.25, 
      0.9876871119312596, -0.1564422223214935}, {-2.25, 
      1., -4.163336342344337*^-16}, {-2.5, 
      1., -4.163336342344337*^-16}, {-2.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.5, 1., -4.440892098500626*^-16}, {-2.25, 
      1., -4.440892098500626*^-16}, {-2.25, 0.9876871119312597, 
      0.15644222232149263`}, {-2.5, 0.9876871119312597, 
      0.15644222232149263`}, {-2.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.5, 0.9876871119312597, 0.1564422223214926}, {-2.25, 
      0.9876871119312597, 0.1564422223214926}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}, {-2.5, 0.9510516621502252, 
      0.30903193349764657`}, {-2.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-2.5, 0.9510516621502252, 0.30903193349764657`}, {-2.25, 
      0.9510516621502252, 0.30903193349764657`}, {-2.25, 0.8909958270419003, 
      0.4540114934601547}, {-2.5, 0.8909958270419003, 
      0.4540114934601547}, {-2.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-2.5, 0.8909958270419003, 0.4540114934601547}, {-2.25, 
      0.8909958270419003, 0.4540114934601547}, {-2.25, 0.808998528157412, 
      0.5878106680208697}, {-2.5, 0.808998528157412, 
      0.5878106680208697}, {-2.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.5, 0.8089985281574118, 0.58781066802087}, {-2.25, 
      0.8089985281574118, 0.58781066802087}, {-2.25, 0.7070790126229676, 
      0.70713454865968}, {-2.5, 0.7070790126229676, 0.70713454865968}, {-2.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.5, 0.7070790126229676, 0.70713454865968}, {-2.25, 
      0.7070790126229676, 0.70713454865968}, {-2.25, 0.5877471276121592, 
      0.8090446922041181}, {-2.5, 0.5877471276121592, 
      0.8090446922041181}, {-2.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.5, 0.5877471276121592, 0.8090446922041181}, {-2.25, 
      0.5877471276121592, 0.8090446922041181}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}, {-2.5, 0.45394151341132644`, 
      0.8910314822731207}, {-2.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.5, 0.45394151341132644`, 0.8910314822731207}, {-2.25, 
      0.45394151341132644`, 0.8910314822731207}, {-2.25, 0.3089572371217171, 
      0.9510759305282176}, {-2.5, 0.3089572371217171, 
      0.9510759305282176}, {-2.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-2.5, 0.3089572371217171, 0.9510759305282176}, {-2.25, 
      0.3089572371217171, 0.9510759305282176}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}, {-2.5, 0.15636464907469383`, 
      0.9876993958283805}, {-2.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.5, 0.15636464907469383`, 0.9876993958283805}, {-2.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9999999876629945, \
-0.0001570796320327716}, {-2.5, -0.9999999876629945, -0.0001570796320327716}, \
{-2.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-2.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-2., -0.9999999876629945, 
      0.00015707963203365978`}, {-2., -0.987711673632875, \
-0.15628707486335794`}, {-2.25, -0.987711673632875, -0.15628707486335794`}, \
{-2.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.25, -0.987711673632875, -0.15628707486335794`}, {-2., \
-0.987711673632875, -0.15628707486335794`}, {-2., -0.951100193039496, \
-0.3088825388399828}, {-2.25, -0.951100193039496, -0.3088825388399828}, \
{-2.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.25, -0.951100193039496, -0.3088825388399828}, {-2., \
-0.951100193039496, -0.3088825388399828}, {-2., -0.8910671320080115, \
-0.4538715305623575}, {-2.25, -0.8910671320080115, -0.4538715305623575}, \
{-2.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.25, -0.8910671320080115, -0.4538715305623575}, {-2., \
-0.8910671320080115, -0.4538715305623575}, {-2., -0.8090908512602306, \
-0.5876835835779278}, {-2.25, -0.8090908512602306, -0.5876835835779278}, \
{-2.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.25, -0.8090908512602306, -0.5876835835779278}, {-2., \
-0.8090908512602306, -0.5876835835779278}, {-2., -0.7071900803344316, \
-0.7070234722246357}, {-2.25, -0.7071900803344316, -0.7070234722246357}, \
{-2.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.25, -0.7071900803344316, -0.7070234722246357}, {-2., \
-0.7071900803344316, -0.7070234722246357}, {-2., -0.5878742048036698, \
-0.8089523591203952}, {-2.25, -0.5878742048036698, -0.8089523591203952}, \
{-2.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.25, -0.5878742048036698, -0.8089523591203952}, {-2., \
-0.5878742048036698, -0.8089523591203952}, {-2., -0.45408147070841337`, \
-0.890960166314569}, {-2.25, -0.45408147070841337`, -0.890960166314569}, \
{-2.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.25, -0.45408147070841337`, -0.890960166314569}, {-2., \
-0.45408147070841337`, -0.890960166314569}, {-2., -0.3091066279673134, \
-0.9510273879056674}, {-2.25, -0.3091066279673134, -0.9510273879056674}, \
{-2.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.25, -0.3091066279673132, -0.9510273879056675}, {-2., \
-0.3091066279673132, -0.9510273879056675}, {-2., -0.15651979460327867`, \
-0.987674821941588}, {-2.25, -0.15651979460327867`, -0.987674821941588}, \
{-2.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.25, -0.15651979460327867`, -0.987674821941588}, {-2., \
-0.15651979460327867`, -0.987674821941588}, {-2., -0.00007853981625928847, \
-0.9999999969157486}, {-2.25, -0.00007853981625928847, -0.9999999969157486}, \
{-2.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.25, -0.00007853981625928847, -0.9999999969157486}, \
{-2., -0.00007853981625928847, -0.9999999969157486}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.25, 0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.30895723712171647`, -0.9510759305282178}, {-2.25, 
      0.30895723712171647`, -0.9510759305282178}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.25, 0.3089572371217167, -0.9510759305282178}, {-2., 
      0.3089572371217167, -0.9510759305282178}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.25, 0.453941513411326, -0.8910314822731209}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.25, 0.5877471276121589, -0.8090446922041185}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.25, 0.7070790126229672, -0.7071345486596803}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.25, 0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.25, 0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.25, 0.951051662150225, -0.3090319334976474}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.9876871119312596, -0.15644222232149346`}, {-2.25, 
      0.9876871119312596, -0.15644222232149346`}, {-2.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.25, 0.9876871119312596, -0.1564422223214935}, {-2., 
      0.9876871119312596, -0.1564422223214935}, {-2., 
      1., -4.163336342344337*^-16}, {-2.25, 
      1., -4.163336342344337*^-16}, {-2.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.25, 1., -4.440892098500626*^-16}, {-2., 
      1., -4.440892098500626*^-16}, {-2., 0.9876871119312597, 
      0.15644222232149263`}, {-2.25, 0.9876871119312597, 
      0.15644222232149263`}, {-2.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.25, 0.9876871119312597, 0.1564422223214926}, {-2., 
      0.9876871119312597, 0.1564422223214926}, {-2., 0.9510516621502252, 
      0.30903193349764657`}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}, {-2.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-2.25, 0.9510516621502252, 0.30903193349764657`}, {-2., 
      0.9510516621502252, 0.30903193349764657`}, {-2., 0.8909958270419003, 
      0.4540114934601547}, {-2.25, 0.8909958270419003, 
      0.4540114934601547}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-2.25, 0.8909958270419003, 0.4540114934601547}, {-2., 
      0.8909958270419003, 0.4540114934601547}, {-2., 0.808998528157412, 
      0.5878106680208697}, {-2.25, 0.808998528157412, 
      0.5878106680208697}, {-2.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.25, 0.8089985281574118, 0.58781066802087}, {-2., 
      0.8089985281574118, 0.58781066802087}, {-2., 0.7070790126229676, 
      0.70713454865968}, {-2.25, 0.7070790126229676, 
      0.70713454865968}, {-2.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.25, 0.7070790126229676, 0.70713454865968}, {-2., 
      0.7070790126229676, 0.70713454865968}, {-2., 0.5877471276121592, 
      0.8090446922041181}, {-2.25, 0.5877471276121592, 
      0.8090446922041181}, {-2.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.25, 0.5877471276121592, 0.8090446922041181}, {-2., 
      0.5877471276121592, 0.8090446922041181}, {-2., 0.45394151341132644`, 
      0.8910314822731207}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}, {-2.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.25, 0.45394151341132644`, 0.8910314822731207}, {-2., 
      0.45394151341132644`, 0.8910314822731207}, {-2., 0.3089572371217171, 
      0.9510759305282176}, {-2.25, 0.3089572371217171, 
      0.9510759305282176}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-2.25, 0.3089572371217171, 0.9510759305282176}, {-2., 
      0.3089572371217171, 0.9510759305282176}, {-2., 0.15636464907469383`, 
      0.9876993958283805}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}, {-2.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.25, 0.15636464907469383`, 0.9876993958283805}, {-2., 
      0.15636464907469383`, 
      0.9876993958283805}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9999999876629945, \
-0.0001570796320327716}, {-2.25, -0.9999999876629945, \
-0.0001570796320327716}, {-2.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-2., -0.9999999876629945, 
      0.00015707963203365978`}, {-1.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.75, -0.987711673632875, \
-0.15628707486335794`}, {-2., -0.987711673632875, -0.15628707486335794`}, \
{-2., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2., -0.987711673632875, -0.15628707486335794`}, {-1.75, \
-0.987711673632875, -0.15628707486335794`}, {-1.75, -0.951100193039496, \
-0.3088825388399828}, {-2., -0.951100193039496, -0.3088825388399828}, {-2., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2., -0.951100193039496, -0.3088825388399828}, {-1.75, \
-0.951100193039496, -0.3088825388399828}, {-1.75, -0.8910671320080115, \
-0.4538715305623575}, {-2., -0.8910671320080115, -0.4538715305623575}, {-2., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2., -0.8910671320080115, -0.4538715305623575}, {-1.75, \
-0.8910671320080115, -0.4538715305623575}, {-1.75, -0.8090908512602306, \
-0.5876835835779278}, {-2., -0.8090908512602306, -0.5876835835779278}, {-2., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2., -0.8090908512602306, -0.5876835835779278}, {-1.75, \
-0.8090908512602306, -0.5876835835779278}, {-1.75, -0.7071900803344316, \
-0.7070234722246357}, {-2., -0.7071900803344316, -0.7070234722246357}, {-2., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2., -0.7071900803344316, -0.7070234722246357}, {-1.75, \
-0.7071900803344316, -0.7070234722246357}, {-1.75, -0.5878742048036698, \
-0.8089523591203952}, {-2., -0.5878742048036698, -0.8089523591203952}, {-2., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2., -0.5878742048036698, -0.8089523591203952}, {-1.75, \
-0.5878742048036698, -0.8089523591203952}, {-1.75, -0.45408147070841337`, \
-0.890960166314569}, {-2., -0.45408147070841337`, -0.890960166314569}, {-2., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2., -0.45408147070841337`, -0.890960166314569}, {-1.75, \
-0.45408147070841337`, -0.890960166314569}, {-1.75, -0.3091066279673134, \
-0.9510273879056674}, {-2., -0.3091066279673134, -0.9510273879056674}, {-2., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2., -0.3091066279673132, -0.9510273879056675}, {-1.75, \
-0.3091066279673132, -0.9510273879056675}, {-1.75, -0.15651979460327867`, \
-0.987674821941588}, {-2., -0.15651979460327867`, -0.987674821941588}, {-2., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2., -0.15651979460327867`, -0.987674821941588}, {-1.75, \
-0.15651979460327867`, -0.987674821941588}, {-1.75, -0.00007853981625928847, \
-0.9999999969157486}, {-2., -0.00007853981625928847, -0.9999999969157486}, \
{-2., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2., -0.00007853981625928847, -0.9999999969157486}, \
{-1.75, -0.00007853981625928847, -0.9999999969157486}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2., 0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.30895723712171647`, -0.9510759305282178}, {-2., 
      0.30895723712171647`, -0.9510759305282178}, {-2., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2., 0.3089572371217167, -0.9510759305282178}, {-1.75, 
      0.3089572371217167, -0.9510759305282178}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2., 0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2., 0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2., 0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2., 0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2., 0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2., 0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.9876871119312596, -0.15644222232149346`}, {-2., 
      0.9876871119312596, -0.15644222232149346`}, {-2., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2., 0.9876871119312596, -0.1564422223214935}, {-1.75, 
      0.9876871119312596, -0.1564422223214935}, {-1.75, 
      1., -4.163336342344337*^-16}, {-2., 1., -4.163336342344337*^-16}, {-2., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2., 1., -4.440892098500626*^-16}, {-1.75, 
      1., -4.440892098500626*^-16}, {-1.75, 0.9876871119312597, 
      0.15644222232149263`}, {-2., 0.9876871119312597, 
      0.15644222232149263`}, {-2., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2., 0.9876871119312597, 0.1564422223214926}, {-1.75, 
      0.9876871119312597, 0.1564422223214926}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}, {-2., 0.9510516621502252, 
      0.30903193349764657`}, {-2., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-2., 0.9510516621502252, 0.30903193349764657`}, {-1.75, 
      0.9510516621502252, 0.30903193349764657`}, {-1.75, 0.8909958270419003, 
      0.4540114934601547}, {-2., 0.8909958270419003, 
      0.4540114934601547}, {-2., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-2., 0.8909958270419003, 0.4540114934601547}, {-1.75, 
      0.8909958270419003, 0.4540114934601547}, {-1.75, 0.808998528157412, 
      0.5878106680208697}, {-2., 0.808998528157412, 0.5878106680208697}, {-2.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2., 0.8089985281574118, 0.58781066802087}, {-1.75, 
      0.8089985281574118, 0.58781066802087}, {-1.75, 0.7070790126229676, 
      0.70713454865968}, {-2., 0.7070790126229676, 0.70713454865968}, {-2., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2., 0.7070790126229676, 0.70713454865968}, {-1.75, 
      0.7070790126229676, 0.70713454865968}, {-1.75, 0.5877471276121592, 
      0.8090446922041181}, {-2., 0.5877471276121592, 
      0.8090446922041181}, {-2., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2., 0.5877471276121592, 0.8090446922041181}, {-1.75, 
      0.5877471276121592, 0.8090446922041181}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}, {-2., 0.45394151341132644`, 
      0.8910314822731207}, {-2., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2., 0.45394151341132644`, 0.8910314822731207}, {-1.75, 
      0.45394151341132644`, 0.8910314822731207}, {-1.75, 0.3089572371217171, 
      0.9510759305282176}, {-2., 0.3089572371217171, 
      0.9510759305282176}, {-2., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-2., 0.3089572371217171, 0.9510759305282176}, {-1.75, 
      0.3089572371217171, 0.9510759305282176}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}, {-2., 0.15636464907469383`, 
      0.9876993958283805}, {-2., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2., 0.15636464907469383`, 0.9876993958283805}, {-1.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-2., -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2., -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2., -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-2., -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-2., -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-2., -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2., -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-2., -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-2., -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-2., -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9999999876629945, \
-0.0001570796320327716}, {-2., -0.9999999876629945, -0.0001570796320327716}, \
{-2., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-1.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.5, -0.987711673632875, \
-0.15628707486335794`}, {-1.75, -0.987711673632875, -0.15628707486335794`}, \
{-1.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.75, -0.987711673632875, -0.15628707486335794`}, {-1.5, \
-0.987711673632875, -0.15628707486335794`}, {-1.5, -0.951100193039496, \
-0.3088825388399828}, {-1.75, -0.951100193039496, -0.3088825388399828}, \
{-1.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.75, -0.951100193039496, -0.3088825388399828}, {-1.5, \
-0.951100193039496, -0.3088825388399828}, {-1.5, -0.8910671320080115, \
-0.4538715305623575}, {-1.75, -0.8910671320080115, -0.4538715305623575}, \
{-1.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.75, -0.8910671320080115, -0.4538715305623575}, {-1.5, \
-0.8910671320080115, -0.4538715305623575}, {-1.5, -0.8090908512602306, \
-0.5876835835779278}, {-1.75, -0.8090908512602306, -0.5876835835779278}, \
{-1.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.75, -0.8090908512602306, -0.5876835835779278}, {-1.5, \
-0.8090908512602306, -0.5876835835779278}, {-1.5, -0.7071900803344316, \
-0.7070234722246357}, {-1.75, -0.7071900803344316, -0.7070234722246357}, \
{-1.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.75, -0.7071900803344316, -0.7070234722246357}, {-1.5, \
-0.7071900803344316, -0.7070234722246357}, {-1.5, -0.5878742048036698, \
-0.8089523591203952}, {-1.75, -0.5878742048036698, -0.8089523591203952}, \
{-1.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.75, -0.5878742048036698, -0.8089523591203952}, {-1.5, \
-0.5878742048036698, -0.8089523591203952}, {-1.5, -0.45408147070841337`, \
-0.890960166314569}, {-1.75, -0.45408147070841337`, -0.890960166314569}, \
{-1.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.75, -0.45408147070841337`, -0.890960166314569}, {-1.5, \
-0.45408147070841337`, -0.890960166314569}, {-1.5, -0.3091066279673134, \
-0.9510273879056674}, {-1.75, -0.3091066279673134, -0.9510273879056674}, \
{-1.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.75, -0.3091066279673132, -0.9510273879056675}, {-1.5, \
-0.3091066279673132, -0.9510273879056675}, {-1.5, -0.15651979460327867`, \
-0.987674821941588}, {-1.75, -0.15651979460327867`, -0.987674821941588}, \
{-1.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.75, -0.15651979460327867`, -0.987674821941588}, {-1.5, \
-0.15651979460327867`, -0.987674821941588}, {-1.5, -0.00007853981625928847, \
-0.9999999969157486}, {-1.75, -0.00007853981625928847, -0.9999999969157486}, \
{-1.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.75, -0.00007853981625928847, -0.9999999969157486}, \
{-1.5, -0.00007853981625928847, -0.9999999969157486}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.75, 0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.30895723712171647`, -0.9510759305282178}, {-1.75, 
      0.30895723712171647`, -0.9510759305282178}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.75, 0.3089572371217167, -0.9510759305282178}, {-1.5, 
      0.3089572371217167, -0.9510759305282178}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.75, 0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.75, 0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.75, 0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.75, 0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.75, 0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.75, 0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.9876871119312596, -0.15644222232149346`}, {-1.75, 
      0.9876871119312596, -0.15644222232149346`}, {-1.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.75, 0.9876871119312596, -0.1564422223214935}, {-1.5, 
      0.9876871119312596, -0.1564422223214935}, {-1.5, 
      1., -4.163336342344337*^-16}, {-1.75, 
      1., -4.163336342344337*^-16}, {-1.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.75, 1., -4.440892098500626*^-16}, {-1.5, 
      1., -4.440892098500626*^-16}, {-1.5, 0.9876871119312597, 
      0.15644222232149263`}, {-1.75, 0.9876871119312597, 
      0.15644222232149263`}, {-1.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.75, 0.9876871119312597, 0.1564422223214926}, {-1.5, 
      0.9876871119312597, 0.1564422223214926}, {-1.5, 0.9510516621502252, 
      0.30903193349764657`}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}, {-1.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-1.75, 0.9510516621502252, 0.30903193349764657`}, {-1.5, 
      0.9510516621502252, 0.30903193349764657`}, {-1.5, 0.8909958270419003, 
      0.4540114934601547}, {-1.75, 0.8909958270419003, 
      0.4540114934601547}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-1.75, 0.8909958270419003, 0.4540114934601547}, {-1.5, 
      0.8909958270419003, 0.4540114934601547}, {-1.5, 0.808998528157412, 
      0.5878106680208697}, {-1.75, 0.808998528157412, 
      0.5878106680208697}, {-1.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.75, 0.8089985281574118, 0.58781066802087}, {-1.5, 
      0.8089985281574118, 0.58781066802087}, {-1.5, 0.7070790126229676, 
      0.70713454865968}, {-1.75, 0.7070790126229676, 
      0.70713454865968}, {-1.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.75, 0.7070790126229676, 0.70713454865968}, {-1.5, 
      0.7070790126229676, 0.70713454865968}, {-1.5, 0.5877471276121592, 
      0.8090446922041181}, {-1.75, 0.5877471276121592, 
      0.8090446922041181}, {-1.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.75, 0.5877471276121592, 0.8090446922041181}, {-1.5, 
      0.5877471276121592, 0.8090446922041181}, {-1.5, 0.45394151341132644`, 
      0.8910314822731207}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}, {-1.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.75, 0.45394151341132644`, 0.8910314822731207}, {-1.5, 
      0.45394151341132644`, 0.8910314822731207}, {-1.5, 0.3089572371217171, 
      0.9510759305282176}, {-1.75, 0.3089572371217171, 
      0.9510759305282176}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-1.75, 0.3089572371217171, 0.9510759305282176}, {-1.5, 
      0.3089572371217171, 0.9510759305282176}, {-1.5, 0.15636464907469383`, 
      0.9876993958283805}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}, {-1.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.75, 0.15636464907469383`, 0.9876993958283805}, {-1.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9999999876629945, \
-0.0001570796320327716}, {-1.75, -0.9999999876629945, \
-0.0001570796320327716}, {-1.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-1.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.25, -0.987711673632875, \
-0.15628707486335794`}, {-1.5, -0.987711673632875, -0.15628707486335794`}, \
{-1.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.5, -0.987711673632875, -0.15628707486335794`}, {-1.25, \
-0.987711673632875, -0.15628707486335794`}, {-1.25, -0.951100193039496, \
-0.3088825388399828}, {-1.5, -0.951100193039496, -0.3088825388399828}, {-1.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.5, -0.951100193039496, -0.3088825388399828}, {-1.25, \
-0.951100193039496, -0.3088825388399828}, {-1.25, -0.8910671320080115, \
-0.4538715305623575}, {-1.5, -0.8910671320080115, -0.4538715305623575}, \
{-1.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.5, -0.8910671320080115, -0.4538715305623575}, {-1.25, \
-0.8910671320080115, -0.4538715305623575}, {-1.25, -0.8090908512602306, \
-0.5876835835779278}, {-1.5, -0.8090908512602306, -0.5876835835779278}, \
{-1.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.5, -0.8090908512602306, -0.5876835835779278}, {-1.25, \
-0.8090908512602306, -0.5876835835779278}, {-1.25, -0.7071900803344316, \
-0.7070234722246357}, {-1.5, -0.7071900803344316, -0.7070234722246357}, \
{-1.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.5, -0.7071900803344316, -0.7070234722246357}, {-1.25, \
-0.7071900803344316, -0.7070234722246357}, {-1.25, -0.5878742048036698, \
-0.8089523591203952}, {-1.5, -0.5878742048036698, -0.8089523591203952}, \
{-1.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.5, -0.5878742048036698, -0.8089523591203952}, {-1.25, \
-0.5878742048036698, -0.8089523591203952}, {-1.25, -0.45408147070841337`, \
-0.890960166314569}, {-1.5, -0.45408147070841337`, -0.890960166314569}, \
{-1.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.5, -0.45408147070841337`, -0.890960166314569}, {-1.25, \
-0.45408147070841337`, -0.890960166314569}, {-1.25, -0.3091066279673134, \
-0.9510273879056674}, {-1.5, -0.3091066279673134, -0.9510273879056674}, \
{-1.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.5, -0.3091066279673132, -0.9510273879056675}, {-1.25, \
-0.3091066279673132, -0.9510273879056675}, {-1.25, -0.15651979460327867`, \
-0.987674821941588}, {-1.5, -0.15651979460327867`, -0.987674821941588}, \
{-1.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.5, -0.15651979460327867`, -0.987674821941588}, {-1.25, \
-0.15651979460327867`, -0.987674821941588}, {-1.25, -0.00007853981625928847, \
-0.9999999969157486}, {-1.5, -0.00007853981625928847, -0.9999999969157486}, \
{-1.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.5, -0.00007853981625928847, -0.9999999969157486}, \
{-1.25, -0.00007853981625928847, -0.9999999969157486}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.5, 0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.30895723712171647`, -0.9510759305282178}, {-1.5, 
      0.30895723712171647`, -0.9510759305282178}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.5, 0.3089572371217167, -0.9510759305282178}, {-1.25, 
      0.3089572371217167, -0.9510759305282178}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.5, 0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.5, 0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.5, 0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.5, 0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.5, 0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.5, 0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.9876871119312596, -0.15644222232149346`}, {-1.5, 
      0.9876871119312596, -0.15644222232149346`}, {-1.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.5, 0.9876871119312596, -0.1564422223214935}, {-1.25, 
      0.9876871119312596, -0.1564422223214935}, {-1.25, 
      1., -4.163336342344337*^-16}, {-1.5, 
      1., -4.163336342344337*^-16}, {-1.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.5, 1., -4.440892098500626*^-16}, {-1.25, 
      1., -4.440892098500626*^-16}, {-1.25, 0.9876871119312597, 
      0.15644222232149263`}, {-1.5, 0.9876871119312597, 
      0.15644222232149263`}, {-1.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.5, 0.9876871119312597, 0.1564422223214926}, {-1.25, 
      0.9876871119312597, 0.1564422223214926}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}, {-1.5, 0.9510516621502252, 
      0.30903193349764657`}, {-1.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-1.5, 0.9510516621502252, 0.30903193349764657`}, {-1.25, 
      0.9510516621502252, 0.30903193349764657`}, {-1.25, 0.8909958270419003, 
      0.4540114934601547}, {-1.5, 0.8909958270419003, 
      0.4540114934601547}, {-1.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-1.5, 0.8909958270419003, 0.4540114934601547}, {-1.25, 
      0.8909958270419003, 0.4540114934601547}, {-1.25, 0.808998528157412, 
      0.5878106680208697}, {-1.5, 0.808998528157412, 
      0.5878106680208697}, {-1.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.5, 0.8089985281574118, 0.58781066802087}, {-1.25, 
      0.8089985281574118, 0.58781066802087}, {-1.25, 0.7070790126229676, 
      0.70713454865968}, {-1.5, 0.7070790126229676, 0.70713454865968}, {-1.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.5, 0.7070790126229676, 0.70713454865968}, {-1.25, 
      0.7070790126229676, 0.70713454865968}, {-1.25, 0.5877471276121592, 
      0.8090446922041181}, {-1.5, 0.5877471276121592, 
      0.8090446922041181}, {-1.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.5, 0.5877471276121592, 0.8090446922041181}, {-1.25, 
      0.5877471276121592, 0.8090446922041181}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}, {-1.5, 0.45394151341132644`, 
      0.8910314822731207}, {-1.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.5, 0.45394151341132644`, 0.8910314822731207}, {-1.25, 
      0.45394151341132644`, 0.8910314822731207}, {-1.25, 0.3089572371217171, 
      0.9510759305282176}, {-1.5, 0.3089572371217171, 
      0.9510759305282176}, {-1.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-1.5, 0.3089572371217171, 0.9510759305282176}, {-1.25, 
      0.3089572371217171, 0.9510759305282176}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}, {-1.5, 0.15636464907469383`, 
      0.9876993958283805}, {-1.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.5, 0.15636464907469383`, 0.9876993958283805}, {-1.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9999999876629945, \
-0.0001570796320327716}, {-1.5, -0.9999999876629945, -0.0001570796320327716}, \
{-1.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-1.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-1., -0.9999999876629945, 
      0.00015707963203365978`}, {-1., -0.987711673632875, \
-0.15628707486335794`}, {-1.25, -0.987711673632875, -0.15628707486335794`}, \
{-1.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.25, -0.987711673632875, -0.15628707486335794`}, {-1., \
-0.987711673632875, -0.15628707486335794`}, {-1., -0.951100193039496, \
-0.3088825388399828}, {-1.25, -0.951100193039496, -0.3088825388399828}, \
{-1.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.25, -0.951100193039496, -0.3088825388399828}, {-1., \
-0.951100193039496, -0.3088825388399828}, {-1., -0.8910671320080115, \
-0.4538715305623575}, {-1.25, -0.8910671320080115, -0.4538715305623575}, \
{-1.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.25, -0.8910671320080115, -0.4538715305623575}, {-1., \
-0.8910671320080115, -0.4538715305623575}, {-1., -0.8090908512602306, \
-0.5876835835779278}, {-1.25, -0.8090908512602306, -0.5876835835779278}, \
{-1.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.25, -0.8090908512602306, -0.5876835835779278}, {-1., \
-0.8090908512602306, -0.5876835835779278}, {-1., -0.7071900803344316, \
-0.7070234722246357}, {-1.25, -0.7071900803344316, -0.7070234722246357}, \
{-1.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.25, -0.7071900803344316, -0.7070234722246357}, {-1., \
-0.7071900803344316, -0.7070234722246357}, {-1., -0.5878742048036698, \
-0.8089523591203952}, {-1.25, -0.5878742048036698, -0.8089523591203952}, \
{-1.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.25, -0.5878742048036698, -0.8089523591203952}, {-1., \
-0.5878742048036698, -0.8089523591203952}, {-1., -0.45408147070841337`, \
-0.890960166314569}, {-1.25, -0.45408147070841337`, -0.890960166314569}, \
{-1.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.25, -0.45408147070841337`, -0.890960166314569}, {-1., \
-0.45408147070841337`, -0.890960166314569}, {-1., -0.3091066279673134, \
-0.9510273879056674}, {-1.25, -0.3091066279673134, -0.9510273879056674}, \
{-1.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.25, -0.3091066279673132, -0.9510273879056675}, {-1., \
-0.3091066279673132, -0.9510273879056675}, {-1., -0.15651979460327867`, \
-0.987674821941588}, {-1.25, -0.15651979460327867`, -0.987674821941588}, \
{-1.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.25, -0.15651979460327867`, -0.987674821941588}, {-1., \
-0.15651979460327867`, -0.987674821941588}, {-1., -0.00007853981625928847, \
-0.9999999969157486}, {-1.25, -0.00007853981625928847, -0.9999999969157486}, \
{-1.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.25, -0.00007853981625928847, -0.9999999969157486}, \
{-1., -0.00007853981625928847, -0.9999999969157486}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.25, 0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.30895723712171647`, -0.9510759305282178}, {-1.25, 
      0.30895723712171647`, -0.9510759305282178}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.25, 0.3089572371217167, -0.9510759305282178}, {-1., 
      0.3089572371217167, -0.9510759305282178}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.25, 0.453941513411326, -0.8910314822731209}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.25, 0.5877471276121589, -0.8090446922041185}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.25, 0.7070790126229672, -0.7071345486596803}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.25, 0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.25, 0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.25, 0.951051662150225, -0.3090319334976474}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.9876871119312596, -0.15644222232149346`}, {-1.25, 
      0.9876871119312596, -0.15644222232149346`}, {-1.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.25, 0.9876871119312596, -0.1564422223214935}, {-1., 
      0.9876871119312596, -0.1564422223214935}, {-1., 
      1., -4.163336342344337*^-16}, {-1.25, 
      1., -4.163336342344337*^-16}, {-1.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.25, 1., -4.440892098500626*^-16}, {-1., 
      1., -4.440892098500626*^-16}, {-1., 0.9876871119312597, 
      0.15644222232149263`}, {-1.25, 0.9876871119312597, 
      0.15644222232149263`}, {-1.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.25, 0.9876871119312597, 0.1564422223214926}, {-1., 
      0.9876871119312597, 0.1564422223214926}, {-1., 0.9510516621502252, 
      0.30903193349764657`}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}, {-1.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-1.25, 0.9510516621502252, 0.30903193349764657`}, {-1., 
      0.9510516621502252, 0.30903193349764657`}, {-1., 0.8909958270419003, 
      0.4540114934601547}, {-1.25, 0.8909958270419003, 
      0.4540114934601547}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-1.25, 0.8909958270419003, 0.4540114934601547}, {-1., 
      0.8909958270419003, 0.4540114934601547}, {-1., 0.808998528157412, 
      0.5878106680208697}, {-1.25, 0.808998528157412, 
      0.5878106680208697}, {-1.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.25, 0.8089985281574118, 0.58781066802087}, {-1., 
      0.8089985281574118, 0.58781066802087}, {-1., 0.7070790126229676, 
      0.70713454865968}, {-1.25, 0.7070790126229676, 
      0.70713454865968}, {-1.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.25, 0.7070790126229676, 0.70713454865968}, {-1., 
      0.7070790126229676, 0.70713454865968}, {-1., 0.5877471276121592, 
      0.8090446922041181}, {-1.25, 0.5877471276121592, 
      0.8090446922041181}, {-1.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.25, 0.5877471276121592, 0.8090446922041181}, {-1., 
      0.5877471276121592, 0.8090446922041181}, {-1., 0.45394151341132644`, 
      0.8910314822731207}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}, {-1.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.25, 0.45394151341132644`, 0.8910314822731207}, {-1., 
      0.45394151341132644`, 0.8910314822731207}, {-1., 0.3089572371217171, 
      0.9510759305282176}, {-1.25, 0.3089572371217171, 
      0.9510759305282176}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-1.25, 0.3089572371217171, 0.9510759305282176}, {-1., 
      0.3089572371217171, 0.9510759305282176}, {-1., 0.15636464907469383`, 
      0.9876993958283805}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}, {-1.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.25, 0.15636464907469383`, 0.9876993958283805}, {-1., 
      0.15636464907469383`, 
      0.9876993958283805}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9999999876629945, \
-0.0001570796320327716}, {-1.25, -0.9999999876629945, \
-0.0001570796320327716}, {-1.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-1., -0.9999999876629945, 
      0.00015707963203365978`}, {-0.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.75, -0.987711673632875, \
-0.15628707486335794`}, {-1., -0.987711673632875, -0.15628707486335794`}, \
{-1., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1., -0.987711673632875, -0.15628707486335794`}, {-0.75, \
-0.987711673632875, -0.15628707486335794`}, {-0.75, -0.951100193039496, \
-0.3088825388399828}, {-1., -0.951100193039496, -0.3088825388399828}, {-1., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1., -0.951100193039496, -0.3088825388399828}, {-0.75, \
-0.951100193039496, -0.3088825388399828}, {-0.75, -0.8910671320080115, \
-0.4538715305623575}, {-1., -0.8910671320080115, -0.4538715305623575}, {-1., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1., -0.8910671320080115, -0.4538715305623575}, {-0.75, \
-0.8910671320080115, -0.4538715305623575}, {-0.75, -0.8090908512602306, \
-0.5876835835779278}, {-1., -0.8090908512602306, -0.5876835835779278}, {-1., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1., -0.8090908512602306, -0.5876835835779278}, {-0.75, \
-0.8090908512602306, -0.5876835835779278}, {-0.75, -0.7071900803344316, \
-0.7070234722246357}, {-1., -0.7071900803344316, -0.7070234722246357}, {-1., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1., -0.7071900803344316, -0.7070234722246357}, {-0.75, \
-0.7071900803344316, -0.7070234722246357}, {-0.75, -0.5878742048036698, \
-0.8089523591203952}, {-1., -0.5878742048036698, -0.8089523591203952}, {-1., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1., -0.5878742048036698, -0.8089523591203952}, {-0.75, \
-0.5878742048036698, -0.8089523591203952}, {-0.75, -0.45408147070841337`, \
-0.890960166314569}, {-1., -0.45408147070841337`, -0.890960166314569}, {-1., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1., -0.45408147070841337`, -0.890960166314569}, {-0.75, \
-0.45408147070841337`, -0.890960166314569}, {-0.75, -0.3091066279673134, \
-0.9510273879056674}, {-1., -0.3091066279673134, -0.9510273879056674}, {-1., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1., -0.3091066279673132, -0.9510273879056675}, {-0.75, \
-0.3091066279673132, -0.9510273879056675}, {-0.75, -0.15651979460327867`, \
-0.987674821941588}, {-1., -0.15651979460327867`, -0.987674821941588}, {-1., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1., -0.15651979460327867`, -0.987674821941588}, {-0.75, \
-0.15651979460327867`, -0.987674821941588}, {-0.75, -0.00007853981625928847, \
-0.9999999969157486}, {-1., -0.00007853981625928847, -0.9999999969157486}, \
{-1., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1., -0.00007853981625928847, -0.9999999969157486}, \
{-0.75, -0.00007853981625928847, -0.9999999969157486}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1., 0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.30895723712171647`, -0.9510759305282178}, {-1., 
      0.30895723712171647`, -0.9510759305282178}, {-1., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1., 0.3089572371217167, -0.9510759305282178}, {-0.75, 
      0.3089572371217167, -0.9510759305282178}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1., 0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1., 0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1., 0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1., 0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1., 0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1., 0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.9876871119312596, -0.15644222232149346`}, {-1., 
      0.9876871119312596, -0.15644222232149346`}, {-1., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1., 0.9876871119312596, -0.1564422223214935}, {-0.75, 
      0.9876871119312596, -0.1564422223214935}, {-0.75, 
      1., -4.163336342344337*^-16}, {-1., 1., -4.163336342344337*^-16}, {-1., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1., 1., -4.440892098500626*^-16}, {-0.75, 
      1., -4.440892098500626*^-16}, {-0.75, 0.9876871119312597, 
      0.15644222232149263`}, {-1., 0.9876871119312597, 
      0.15644222232149263`}, {-1., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1., 0.9876871119312597, 0.1564422223214926}, {-0.75, 
      0.9876871119312597, 0.1564422223214926}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}, {-1., 0.9510516621502252, 
      0.30903193349764657`}, {-1., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-1., 0.9510516621502252, 0.30903193349764657`}, {-0.75, 
      0.9510516621502252, 0.30903193349764657`}, {-0.75, 0.8909958270419003, 
      0.4540114934601547}, {-1., 0.8909958270419003, 
      0.4540114934601547}, {-1., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-1., 0.8909958270419003, 0.4540114934601547}, {-0.75, 
      0.8909958270419003, 0.4540114934601547}, {-0.75, 0.808998528157412, 
      0.5878106680208697}, {-1., 0.808998528157412, 0.5878106680208697}, {-1.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1., 0.8089985281574118, 0.58781066802087}, {-0.75, 
      0.8089985281574118, 0.58781066802087}, {-0.75, 0.7070790126229676, 
      0.70713454865968}, {-1., 0.7070790126229676, 0.70713454865968}, {-1., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1., 0.7070790126229676, 0.70713454865968}, {-0.75, 
      0.7070790126229676, 0.70713454865968}, {-0.75, 0.5877471276121592, 
      0.8090446922041181}, {-1., 0.5877471276121592, 
      0.8090446922041181}, {-1., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1., 0.5877471276121592, 0.8090446922041181}, {-0.75, 
      0.5877471276121592, 0.8090446922041181}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}, {-1., 0.45394151341132644`, 
      0.8910314822731207}, {-1., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1., 0.45394151341132644`, 0.8910314822731207}, {-0.75, 
      0.45394151341132644`, 0.8910314822731207}, {-0.75, 0.3089572371217171, 
      0.9510759305282176}, {-1., 0.3089572371217171, 
      0.9510759305282176}, {-1., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-1., 0.3089572371217171, 0.9510759305282176}, {-0.75, 
      0.3089572371217171, 0.9510759305282176}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}, {-1., 0.15636464907469383`, 
      0.9876993958283805}, {-1., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1., 0.15636464907469383`, 0.9876993958283805}, {-0.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-1., -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1., -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1., -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-1., -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-1., -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-1., -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1., -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-1., -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-1., -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-1., -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9999999876629945, \
-0.0001570796320327716}, {-1., -0.9999999876629945, -0.0001570796320327716}, \
{-1., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-0.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.5, -0.987711673632875, \
-0.15628707486335794`}, {-0.75, -0.987711673632875, -0.15628707486335794`}, \
{-0.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.75, -0.987711673632875, -0.15628707486335794`}, {-0.5, \
-0.987711673632875, -0.15628707486335794`}, {-0.5, -0.951100193039496, \
-0.3088825388399828}, {-0.75, -0.951100193039496, -0.3088825388399828}, \
{-0.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-0.75, -0.951100193039496, -0.3088825388399828}, {-0.5, \
-0.951100193039496, -0.3088825388399828}, {-0.5, -0.8910671320080115, \
-0.4538715305623575}, {-0.75, -0.8910671320080115, -0.4538715305623575}, \
{-0.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-0.75, -0.8910671320080115, -0.4538715305623575}, {-0.5, \
-0.8910671320080115, -0.4538715305623575}, {-0.5, -0.8090908512602306, \
-0.5876835835779278}, {-0.75, -0.8090908512602306, -0.5876835835779278}, \
{-0.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-0.75, -0.8090908512602306, -0.5876835835779278}, {-0.5, \
-0.8090908512602306, -0.5876835835779278}, {-0.5, -0.7071900803344316, \
-0.7070234722246357}, {-0.75, -0.7071900803344316, -0.7070234722246357}, \
{-0.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-0.75, -0.7071900803344316, -0.7070234722246357}, {-0.5, \
-0.7071900803344316, -0.7070234722246357}, {-0.5, -0.5878742048036698, \
-0.8089523591203952}, {-0.75, -0.5878742048036698, -0.8089523591203952}, \
{-0.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-0.75, -0.5878742048036698, -0.8089523591203952}, {-0.5, \
-0.5878742048036698, -0.8089523591203952}, {-0.5, -0.45408147070841337`, \
-0.890960166314569}, {-0.75, -0.45408147070841337`, -0.890960166314569}, \
{-0.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-0.75, -0.45408147070841337`, -0.890960166314569}, {-0.5, \
-0.45408147070841337`, -0.890960166314569}, {-0.5, -0.3091066279673134, \
-0.9510273879056674}, {-0.75, -0.3091066279673134, -0.9510273879056674}, \
{-0.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-0.75, -0.3091066279673132, -0.9510273879056675}, {-0.5, \
-0.3091066279673132, -0.9510273879056675}, {-0.5, -0.15651979460327867`, \
-0.987674821941588}, {-0.75, -0.15651979460327867`, -0.987674821941588}, \
{-0.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-0.75, -0.15651979460327867`, -0.987674821941588}, {-0.5, \
-0.15651979460327867`, -0.987674821941588}, {-0.5, -0.00007853981625928847, \
-0.9999999969157486}, {-0.75, -0.00007853981625928847, -0.9999999969157486}, \
{-0.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-0.75, -0.00007853981625928847, -0.9999999969157486}, \
{-0.5, -0.00007853981625928847, -0.9999999969157486}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.75, 0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.30895723712171647`, -0.9510759305282178}, {-0.75, 
      0.30895723712171647`, -0.9510759305282178}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.75, 0.3089572371217167, -0.9510759305282178}, {-0.5, 
      0.3089572371217167, -0.9510759305282178}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.75, 0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.75, 0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.75, 0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.75, 0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.75, 0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.75, 0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.9876871119312596, -0.15644222232149346`}, {-0.75, 
      0.9876871119312596, -0.15644222232149346`}, {-0.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.75, 0.9876871119312596, -0.1564422223214935}, {-0.5, 
      0.9876871119312596, -0.1564422223214935}, {-0.5, 
      1., -4.163336342344337*^-16}, {-0.75, 
      1., -4.163336342344337*^-16}, {-0.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.75, 1., -4.440892098500626*^-16}, {-0.5, 
      1., -4.440892098500626*^-16}, {-0.5, 0.9876871119312597, 
      0.15644222232149263`}, {-0.75, 0.9876871119312597, 
      0.15644222232149263`}, {-0.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.75, 0.9876871119312597, 0.1564422223214926}, {-0.5, 
      0.9876871119312597, 0.1564422223214926}, {-0.5, 0.9510516621502252, 
      0.30903193349764657`}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}, {-0.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-0.75, 0.9510516621502252, 0.30903193349764657`}, {-0.5, 
      0.9510516621502252, 0.30903193349764657`}, {-0.5, 0.8909958270419003, 
      0.4540114934601547}, {-0.75, 0.8909958270419003, 
      0.4540114934601547}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-0.75, 0.8909958270419003, 0.4540114934601547}, {-0.5, 
      0.8909958270419003, 0.4540114934601547}, {-0.5, 0.808998528157412, 
      0.5878106680208697}, {-0.75, 0.808998528157412, 
      0.5878106680208697}, {-0.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.75, 0.8089985281574118, 0.58781066802087}, {-0.5, 
      0.8089985281574118, 0.58781066802087}, {-0.5, 0.7070790126229676, 
      0.70713454865968}, {-0.75, 0.7070790126229676, 
      0.70713454865968}, {-0.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.75, 0.7070790126229676, 0.70713454865968}, {-0.5, 
      0.7070790126229676, 0.70713454865968}, {-0.5, 0.5877471276121592, 
      0.8090446922041181}, {-0.75, 0.5877471276121592, 
      0.8090446922041181}, {-0.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.75, 0.5877471276121592, 0.8090446922041181}, {-0.5, 
      0.5877471276121592, 0.8090446922041181}, {-0.5, 0.45394151341132644`, 
      0.8910314822731207}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}, {-0.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.75, 0.45394151341132644`, 0.8910314822731207}, {-0.5, 
      0.45394151341132644`, 0.8910314822731207}, {-0.5, 0.3089572371217171, 
      0.9510759305282176}, {-0.75, 0.3089572371217171, 
      0.9510759305282176}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-0.75, 0.3089572371217171, 0.9510759305282176}, {-0.5, 
      0.3089572371217171, 0.9510759305282176}, {-0.5, 0.15636464907469383`, 
      0.9876993958283805}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}, {-0.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.75, 0.15636464907469383`, 0.9876993958283805}, {-0.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9999999876629945, \
-0.0001570796320327716}, {-0.75, -0.9999999876629945, \
-0.0001570796320327716}, {-0.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-0.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.25, -0.987711673632875, \
-0.15628707486335794`}, {-0.5, -0.987711673632875, -0.15628707486335794`}, \
{-0.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.5, -0.987711673632875, -0.15628707486335794`}, {-0.25, \
-0.987711673632875, -0.15628707486335794`}, {-0.25, -0.951100193039496, \
-0.3088825388399828}, {-0.5, -0.951100193039496, -0.3088825388399828}, {-0.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-0.5, -0.951100193039496, -0.3088825388399828}, {-0.25, \
-0.951100193039496, -0.3088825388399828}, {-0.25, -0.8910671320080115, \
-0.4538715305623575}, {-0.5, -0.8910671320080115, -0.4538715305623575}, \
{-0.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-0.5, -0.8910671320080115, -0.4538715305623575}, {-0.25, \
-0.8910671320080115, -0.4538715305623575}, {-0.25, -0.8090908512602306, \
-0.5876835835779278}, {-0.5, -0.8090908512602306, -0.5876835835779278}, \
{-0.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-0.5, -0.8090908512602306, -0.5876835835779278}, {-0.25, \
-0.8090908512602306, -0.5876835835779278}, {-0.25, -0.7071900803344316, \
-0.7070234722246357}, {-0.5, -0.7071900803344316, -0.7070234722246357}, \
{-0.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-0.5, -0.7071900803344316, -0.7070234722246357}, {-0.25, \
-0.7071900803344316, -0.7070234722246357}, {-0.25, -0.5878742048036698, \
-0.8089523591203952}, {-0.5, -0.5878742048036698, -0.8089523591203952}, \
{-0.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-0.5, -0.5878742048036698, -0.8089523591203952}, {-0.25, \
-0.5878742048036698, -0.8089523591203952}, {-0.25, -0.45408147070841337`, \
-0.890960166314569}, {-0.5, -0.45408147070841337`, -0.890960166314569}, \
{-0.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-0.5, -0.45408147070841337`, -0.890960166314569}, {-0.25, \
-0.45408147070841337`, -0.890960166314569}, {-0.25, -0.3091066279673134, \
-0.9510273879056674}, {-0.5, -0.3091066279673134, -0.9510273879056674}, \
{-0.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-0.5, -0.3091066279673132, -0.9510273879056675}, {-0.25, \
-0.3091066279673132, -0.9510273879056675}, {-0.25, -0.15651979460327867`, \
-0.987674821941588}, {-0.5, -0.15651979460327867`, -0.987674821941588}, \
{-0.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-0.5, -0.15651979460327867`, -0.987674821941588}, {-0.25, \
-0.15651979460327867`, -0.987674821941588}, {-0.25, -0.00007853981625928847, \
-0.9999999969157486}, {-0.5, -0.00007853981625928847, -0.9999999969157486}, \
{-0.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-0.5, -0.00007853981625928847, -0.9999999969157486}, \
{-0.25, -0.00007853981625928847, -0.9999999969157486}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.5, 0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.30895723712171647`, -0.9510759305282178}, {-0.5, 
      0.30895723712171647`, -0.9510759305282178}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.5, 0.3089572371217167, -0.9510759305282178}, {-0.25, 
      0.3089572371217167, -0.9510759305282178}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.5, 0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.5, 0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.5, 0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.5, 0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.5, 0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.5, 0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.9876871119312596, -0.15644222232149346`}, {-0.5, 
      0.9876871119312596, -0.15644222232149346`}, {-0.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.5, 0.9876871119312596, -0.1564422223214935}, {-0.25, 
      0.9876871119312596, -0.1564422223214935}, {-0.25, 
      1., -4.163336342344337*^-16}, {-0.5, 
      1., -4.163336342344337*^-16}, {-0.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.5, 1., -4.440892098500626*^-16}, {-0.25, 
      1., -4.440892098500626*^-16}, {-0.25, 0.9876871119312597, 
      0.15644222232149263`}, {-0.5, 0.9876871119312597, 
      0.15644222232149263`}, {-0.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.5, 0.9876871119312597, 0.1564422223214926}, {-0.25, 
      0.9876871119312597, 0.1564422223214926}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}, {-0.5, 0.9510516621502252, 
      0.30903193349764657`}, {-0.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-0.5, 0.9510516621502252, 0.30903193349764657`}, {-0.25, 
      0.9510516621502252, 0.30903193349764657`}, {-0.25, 0.8909958270419003, 
      0.4540114934601547}, {-0.5, 0.8909958270419003, 
      0.4540114934601547}, {-0.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-0.5, 0.8909958270419003, 0.4540114934601547}, {-0.25, 
      0.8909958270419003, 0.4540114934601547}, {-0.25, 0.808998528157412, 
      0.5878106680208697}, {-0.5, 0.808998528157412, 
      0.5878106680208697}, {-0.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.5, 0.8089985281574118, 0.58781066802087}, {-0.25, 
      0.8089985281574118, 0.58781066802087}, {-0.25, 0.7070790126229676, 
      0.70713454865968}, {-0.5, 0.7070790126229676, 0.70713454865968}, {-0.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.5, 0.7070790126229676, 0.70713454865968}, {-0.25, 
      0.7070790126229676, 0.70713454865968}, {-0.25, 0.5877471276121592, 
      0.8090446922041181}, {-0.5, 0.5877471276121592, 
      0.8090446922041181}, {-0.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.5, 0.5877471276121592, 0.8090446922041181}, {-0.25, 
      0.5877471276121592, 0.8090446922041181}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}, {-0.5, 0.45394151341132644`, 
      0.8910314822731207}, {-0.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.5, 0.45394151341132644`, 0.8910314822731207}, {-0.25, 
      0.45394151341132644`, 0.8910314822731207}, {-0.25, 0.3089572371217171, 
      0.9510759305282176}, {-0.5, 0.3089572371217171, 
      0.9510759305282176}, {-0.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-0.5, 0.3089572371217171, 0.9510759305282176}, {-0.25, 
      0.3089572371217171, 0.9510759305282176}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}, {-0.5, 0.15636464907469383`, 
      0.9876993958283805}, {-0.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.5, 0.15636464907469383`, 0.9876993958283805}, {-0.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.25, -0.156519794603278, 
      0.9876748219415881}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9999999876629945, \
-0.0001570796320327716}, {-0.5, -0.9999999876629945, -0.0001570796320327716}, \
{-0.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0., -0.9999999876629945, 0.00015707963203365978`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {-0.25, \
-0.987711673632875, -0.15628707486335794`}, {-0.25, -0.9999999876629945, 
      0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.25, -0.987711673632875, -0.15628707486335794`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {
      0., -0.951100193039496, -0.3088825388399828}, {-0.25, \
-0.951100193039496, -0.3088825388399828}, {-0.25, -0.987711673632875, \
-0.15628707486335794`}}], 
     Polygon3DBox[{{-0.25, -0.951100193039496, -0.3088825388399828}, {
      0., -0.951100193039496, -0.3088825388399828}, {
      0., -0.8910671320080115, -0.4538715305623575}, {-0.25, \
-0.8910671320080115, -0.4538715305623575}, {-0.25, -0.951100193039496, \
-0.3088825388399828}}], 
     Polygon3DBox[{{-0.25, -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8090908512602306, -0.5876835835779278}, {-0.25, \
-0.8090908512602306, -0.5876835835779278}, {-0.25, -0.8910671320080115, \
-0.4538715305623575}}], 
     Polygon3DBox[{{-0.25, -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8090908512602306, -0.5876835835779278}, {
      0., -0.7071900803344316, -0.7070234722246357}, {-0.25, \
-0.7071900803344316, -0.7070234722246357}, {-0.25, -0.8090908512602306, \
-0.5876835835779278}}], 
     Polygon3DBox[{{-0.25, -0.7071900803344316, -0.7070234722246357}, {
      0., -0.7071900803344316, -0.7070234722246357}, {
      0., -0.5878742048036698, -0.8089523591203952}, {-0.25, \
-0.5878742048036698, -0.8089523591203952}, {-0.25, -0.7071900803344316, \
-0.7070234722246357}}], 
     Polygon3DBox[{{-0.25, -0.5878742048036698, -0.8089523591203952}, {
      0., -0.5878742048036698, -0.8089523591203952}, {
      0., -0.45408147070841337`, -0.890960166314569}, {-0.25, \
-0.45408147070841337`, -0.890960166314569}, {-0.25, -0.5878742048036698, \
-0.8089523591203952}}], 
     Polygon3DBox[{{-0.25, -0.45408147070841337`, -0.890960166314569}, {
      0., -0.45408147070841337`, -0.890960166314569}, {
      0., -0.3091066279673134, -0.9510273879056674}, {-0.25, \
-0.3091066279673134, -0.9510273879056674}, {-0.25, -0.45408147070841337`, \
-0.890960166314569}}], 
     Polygon3DBox[{{-0.25, -0.3091066279673132, -0.9510273879056675}, {
      0., -0.3091066279673132, -0.9510273879056675}, {
      0., -0.15651979460327867`, -0.987674821941588}, {-0.25, \
-0.15651979460327867`, -0.987674821941588}, {-0.25, -0.3091066279673132, \
-0.9510273879056675}}], 
     Polygon3DBox[{{-0.25, -0.15651979460327867`, -0.987674821941588}, {
      0., -0.15651979460327867`, -0.987674821941588}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {-0.25, \
-0.00007853981625928847, -0.9999999969157486}, {-0.25, -0.15651979460327867`, \
-0.987674821941588}}], 
     Polygon3DBox[{{-0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.25, 0.15636464907469316`, -0.9876993958283806}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {0., 
      0.30895723712171647`, -0.9510759305282178}, {-0.25, 
      0.30895723712171647`, -0.9510759305282178}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.25, 0.3089572371217167, -0.9510759305282178}, {0., 
      0.3089572371217167, -0.9510759305282178}, {0., 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.25, 0.453941513411326, -0.8910314822731209}, {0., 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.25, 0.5877471276121589, -0.8090446922041185}, {0., 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.25, 0.7070790126229672, -0.7071345486596803}, {0., 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.25, 0.8089985281574115, -0.5878106680208703}, {0., 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.25, 0.8909958270419, -0.45401149346015546`}, {0., 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.25, 0.951051662150225, -0.3090319334976474}, {0., 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.9876871119312596, -0.15644222232149346`}, {-0.25, 
      0.9876871119312596, -0.15644222232149346`}, {-0.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.25, 0.9876871119312596, -0.1564422223214935}, {0., 
      0.9876871119312596, -0.1564422223214935}, {0., 
      1., -4.163336342344337*^-16}, {-0.25, 
      1., -4.163336342344337*^-16}, {-0.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.25, 1., -4.440892098500626*^-16}, {0., 
      1., -4.440892098500626*^-16}, {0., 0.9876871119312597, 
      0.15644222232149263`}, {-0.25, 0.9876871119312597, 
      0.15644222232149263`}, {-0.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.25, 0.9876871119312597, 0.1564422223214926}, {0., 
      0.9876871119312597, 0.1564422223214926}, {0., 0.9510516621502252, 
      0.30903193349764657`}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}, {-0.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-0.25, 0.9510516621502252, 0.30903193349764657`}, {0., 
      0.9510516621502252, 0.30903193349764657`}, {0., 0.8909958270419003, 
      0.4540114934601547}, {-0.25, 0.8909958270419003, 
      0.4540114934601547}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-0.25, 0.8909958270419003, 0.4540114934601547}, {0., 
      0.8909958270419003, 0.4540114934601547}, {0., 0.808998528157412, 
      0.5878106680208697}, {-0.25, 0.808998528157412, 
      0.5878106680208697}, {-0.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.25, 0.8089985281574118, 0.58781066802087}, {0., 
      0.8089985281574118, 0.58781066802087}, {0., 0.7070790126229676, 
      0.70713454865968}, {-0.25, 0.7070790126229676, 
      0.70713454865968}, {-0.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.25, 0.7070790126229676, 0.70713454865968}, {0., 
      0.7070790126229676, 0.70713454865968}, {0., 0.5877471276121592, 
      0.8090446922041181}, {-0.25, 0.5877471276121592, 
      0.8090446922041181}, {-0.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.25, 0.5877471276121592, 0.8090446922041181}, {0., 
      0.5877471276121592, 0.8090446922041181}, {0., 0.45394151341132644`, 
      0.8910314822731207}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}, {-0.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.25, 0.45394151341132644`, 0.8910314822731207}, {0., 
      0.45394151341132644`, 0.8910314822731207}, {0., 0.3089572371217171, 
      0.9510759305282176}, {-0.25, 0.3089572371217171, 
      0.9510759305282176}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-0.25, 0.3089572371217171, 0.9510759305282176}, {0., 
      0.3089572371217171, 0.9510759305282176}, {0., 0.15636464907469383`, 
      0.9876993958283805}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}, {-0.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.25, 0.15636464907469383`, 0.9876993958283805}, {0., 
      0.15636464907469383`, 0.9876993958283805}, {0., -0.00007853981625862234,
       0.9999999969157486}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.156519794603278, 0.9876748219415881}, {-0.25, -0.156519794603278,
       0.9876748219415881}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.25, -0.156519794603278, 0.9876748219415881}, {
      0., -0.156519794603278, 0.9876748219415881}, {0., -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.25, -0.3091066279673126, 0.9510273879056678}, {
      0., -0.3091066279673126, 0.9510273879056678}, {
      0., -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.25, -0.5878742048036691, 0.8089523591203958}, {
      0., -0.5878742048036691, 0.8089523591203958}, {0., -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-0.25, -0.707190080334431, 0.7070234722246362}, {
      0., -0.707190080334431, 0.7070234722246362}, {0., -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.25, -0.8090908512602302, 0.5876835835779286}, {
      0., -0.8090908512602302, 0.5876835835779286}, {0., -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-0.25, -0.8910671320080111, 0.4538715305623583}, {
      0., -0.8910671320080111, 0.4538715305623583}, {0., -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-0.25, -0.9511001930394957, 0.3088825388399836}, {
      0., -0.9511001930394957, 0.3088825388399836}, {0., -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9999999876629945, -0.0001570796320327716}, {-0.25, \
-0.9999999876629945, -0.0001570796320327716}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}}], 
     Polygon3DBox[{{0., -0.9999999876629945, 0.00015707963203365978`}, {
      0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {
      0., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0., -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0., -0.951100193039496, -0.3088825388399828}, {
      0., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0., -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8910671320080115, -0.4538715305623575}, {
      0., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0., -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0., -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0., -0.7071900803344316, -0.7070234722246357}, {
      0., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0., -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0., -0.5878742048036698, -0.8089523591203952}, {
      0., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0., -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0., -0.45408147070841337`, -0.890960166314569}, {
      0., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0., -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.3091066279673134, -0.9510273879056674}, {
      0., -0.3091066279673134, -0.9510273879056674}, {
      0., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0., -0.3091066279673132, -0.9510273879056675}, {
      0.25, -0.3091066279673132, -0.9510273879056675}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0., -0.15651979460327867`, -0.987674821941588}, {
      0., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0., -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0., -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {
      0., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0., 0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.30895723712171647`, -0.9510759305282178}, {0., 
      0.30895723712171647`, -0.9510759305282178}, {0., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0., 0.3089572371217167, -0.9510759305282178}, {0.25, 
      0.3089572371217167, -0.9510759305282178}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0., 0.453941513411326, -0.8910314822731209}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0., 0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0., 0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0., 0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0., 0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0., 0.951051662150225, -0.3090319334976474}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.9876871119312596, -0.15644222232149346`}, {0., 
      0.9876871119312596, -0.15644222232149346`}, {0., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0., 0.9876871119312596, -0.1564422223214935}, {0.25, 
      0.9876871119312596, -0.1564422223214935}, {0.25, 
      1., -4.163336342344337*^-16}, {0., 1., -4.163336342344337*^-16}, {0., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0., 1., -4.440892098500626*^-16}, {0.25, 
      1., -4.440892098500626*^-16}, {0.25, 0.9876871119312597, 
      0.15644222232149263`}, {0., 0.9876871119312597, 0.15644222232149263`}, {
      0., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0., 0.9876871119312597, 0.1564422223214926}, {0.25, 
      0.9876871119312597, 0.1564422223214926}, {0.25, 0.9510516621502252, 
      0.30903193349764657`}, {0., 0.9510516621502252, 0.30903193349764657`}, {
      0., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{0., 0.9510516621502252, 0.30903193349764657`}, {0.25, 
      0.9510516621502252, 0.30903193349764657`}, {0.25, 0.8909958270419003, 
      0.4540114934601547}, {0., 0.8909958270419003, 0.4540114934601547}, {0., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0., 0.8909958270419003, 0.4540114934601547}, {0.25, 
      0.8909958270419003, 0.4540114934601547}, {0.25, 0.808998528157412, 
      0.5878106680208697}, {0., 0.808998528157412, 0.5878106680208697}, {0., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0., 0.8089985281574118, 0.58781066802087}, {0.25, 
      0.8089985281574118, 0.58781066802087}, {0.25, 0.7070790126229676, 
      0.70713454865968}, {0., 0.7070790126229676, 0.70713454865968}, {0., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0., 0.7070790126229676, 0.70713454865968}, {0.25, 
      0.7070790126229676, 0.70713454865968}, {0.25, 0.5877471276121592, 
      0.8090446922041181}, {0., 0.5877471276121592, 0.8090446922041181}, {0., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0., 0.5877471276121592, 0.8090446922041181}, {0.25, 
      0.5877471276121592, 0.8090446922041181}, {0.25, 0.45394151341132644`, 
      0.8910314822731207}, {0., 0.45394151341132644`, 0.8910314822731207}, {
      0., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0., 0.45394151341132644`, 0.8910314822731207}, {0.25, 
      0.45394151341132644`, 0.8910314822731207}, {0.25, 0.3089572371217171, 
      0.9510759305282176}, {0., 0.3089572371217171, 0.9510759305282176}, {0., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0., 0.3089572371217171, 0.9510759305282176}, {0.25, 
      0.3089572371217171, 0.9510759305282176}, {0.25, 0.15636464907469383`, 
      0.9876993958283805}, {0., 0.15636464907469383`, 0.9876993958283805}, {
      0., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0., 0.15636464907469383`, 0.9876993958283805}, {0.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.00007853981625862234, 0.9999999969157486}, {0., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0., -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.156519794603278, 0.9876748219415881}, {0., -0.156519794603278, 
      0.9876748219415881}, {0., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0., -0.156519794603278, 0.9876748219415881}, {
      0.25, -0.156519794603278, 0.9876748219415881}, {
      0.25, -0.3091066279673126, 0.9510273879056678}, {
      0., -0.3091066279673126, 0.9510273879056678}, {0., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{0., -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0., -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0., -0.5878742048036691, 0.8089523591203958}, {
      0., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0., -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.707190080334431, 0.7070234722246362}, {0., -0.707190080334431, 
      0.7070234722246362}, {0., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0., -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.8090908512602302, 0.5876835835779286}, {
      0., -0.8090908512602302, 0.5876835835779286}, {0., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{0., -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0., -0.8910671320080111, 0.4538715305623583}, {0., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{0., -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0., -0.9511001930394957, 0.3088825388399836}, {0., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{0., -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0., -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9999999876629945, -0.0001570796320327716}, {
      0., -0.9999999876629945, -0.0001570796320327716}, {
      0., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0.5, -0.9999999876629945, 0.00015707963203365978`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.25, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.3091066279673134, -0.9510273879056674}, {
      0.25, -0.3091066279673134, -0.9510273879056674}, {
      0.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.25, -0.3091066279673132, -0.9510273879056675}, {
      0.5, -0.3091066279673132, -0.9510273879056675}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.25, 0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.30895723712171647`, -0.9510759305282178}, {0.25, 
      0.30895723712171647`, -0.9510759305282178}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.25, 0.3089572371217167, -0.9510759305282178}, {0.5, 
      0.3089572371217167, -0.9510759305282178}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.25, 0.453941513411326, -0.8910314822731209}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.25, 0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.25, 0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.25, 0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.25, 0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.25, 0.951051662150225, -0.3090319334976474}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.9876871119312596, -0.15644222232149346`}, {0.25, 
      0.9876871119312596, -0.15644222232149346`}, {0.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.25, 0.9876871119312596, -0.1564422223214935}, {0.5, 
      0.9876871119312596, -0.1564422223214935}, {0.5, 
      1., -4.163336342344337*^-16}, {0.25, 1., -4.163336342344337*^-16}, {
      0.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.25, 1., -4.440892098500626*^-16}, {0.5, 
      1., -4.440892098500626*^-16}, {0.5, 0.9876871119312597, 
      0.15644222232149263`}, {0.25, 0.9876871119312597, 
      0.15644222232149263`}, {0.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.25, 0.9876871119312597, 0.1564422223214926}, {0.5, 
      0.9876871119312597, 0.1564422223214926}, {0.5, 0.9510516621502252, 
      0.30903193349764657`}, {0.25, 0.9510516621502252, 
      0.30903193349764657`}, {0.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{0.25, 0.9510516621502252, 0.30903193349764657`}, {0.5, 
      0.9510516621502252, 0.30903193349764657`}, {0.5, 0.8909958270419003, 
      0.4540114934601547}, {0.25, 0.8909958270419003, 0.4540114934601547}, {
      0.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.25, 0.8909958270419003, 0.4540114934601547}, {0.5, 
      0.8909958270419003, 0.4540114934601547}, {0.5, 0.808998528157412, 
      0.5878106680208697}, {0.25, 0.808998528157412, 0.5878106680208697}, {
      0.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.25, 0.8089985281574118, 0.58781066802087}, {0.5, 
      0.8089985281574118, 0.58781066802087}, {0.5, 0.7070790126229676, 
      0.70713454865968}, {0.25, 0.7070790126229676, 0.70713454865968}, {0.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.25, 0.7070790126229676, 0.70713454865968}, {0.5, 
      0.7070790126229676, 0.70713454865968}, {0.5, 0.5877471276121592, 
      0.8090446922041181}, {0.25, 0.5877471276121592, 0.8090446922041181}, {
      0.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.25, 0.5877471276121592, 0.8090446922041181}, {0.5, 
      0.5877471276121592, 0.8090446922041181}, {0.5, 0.45394151341132644`, 
      0.8910314822731207}, {0.25, 0.45394151341132644`, 0.8910314822731207}, {
      0.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.25, 0.45394151341132644`, 0.8910314822731207}, {0.5, 
      0.45394151341132644`, 0.8910314822731207}, {0.5, 0.3089572371217171, 
      0.9510759305282176}, {0.25, 0.3089572371217171, 0.9510759305282176}, {
      0.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.25, 0.3089572371217171, 0.9510759305282176}, {0.5, 
      0.3089572371217171, 0.9510759305282176}, {0.5, 0.15636464907469383`, 
      0.9876993958283805}, {0.25, 0.15636464907469383`, 0.9876993958283805}, {
      0.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.25, 0.15636464907469383`, 0.9876993958283805}, {0.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {0.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.156519794603278, 0.9876748219415881}, {0.25, -0.156519794603278,
       0.9876748219415881}, {0.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.25, -0.156519794603278, 0.9876748219415881}, {
      0.5, -0.156519794603278, 0.9876748219415881}, {0.5, -0.3091066279673126,
       0.9510273879056678}, {0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {0.5, -0.707190080334431,
       0.7070234722246362}, {0.25, -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.25, -0.707190080334431, 0.7070234722246362}, {
      0.5, -0.707190080334431, 0.7070234722246362}, {0.5, -0.8090908512602302,
       0.5876835835779286}, {0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9999999876629945, -0.0001570796320327716}, {
      0.25, -0.9999999876629945, -0.0001570796320327716}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.5, -0.9999999876629945, 0.00015707963203365978`}, {
      0.75, -0.9999999876629945, 0.00015707963203365978`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.5, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.3091066279673134, -0.9510273879056674}, {
      0.5, -0.3091066279673134, -0.9510273879056674}, {
      0.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.5, -0.3091066279673132, -0.9510273879056675}, {
      0.75, -0.3091066279673132, -0.9510273879056675}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.5, 0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.30895723712171647`, -0.9510759305282178}, {0.5, 
      0.30895723712171647`, -0.9510759305282178}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.5, 0.3089572371217167, -0.9510759305282178}, {0.75, 
      0.3089572371217167, -0.9510759305282178}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.5, 0.453941513411326, -0.8910314822731209}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.5, 0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.5, 0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.5, 0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.5, 0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.5, 0.951051662150225, -0.3090319334976474}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.9876871119312596, -0.15644222232149346`}, {0.5, 
      0.9876871119312596, -0.15644222232149346`}, {0.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.5, 0.9876871119312596, -0.1564422223214935}, {0.75, 
      0.9876871119312596, -0.1564422223214935}, {0.75, 
      1., -4.163336342344337*^-16}, {0.5, 1., -4.163336342344337*^-16}, {0.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.5, 1., -4.440892098500626*^-16}, {0.75, 
      1., -4.440892098500626*^-16}, {0.75, 0.9876871119312597, 
      0.15644222232149263`}, {0.5, 0.9876871119312597, 
      0.15644222232149263`}, {0.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.5, 0.9876871119312597, 0.1564422223214926}, {0.75, 
      0.9876871119312597, 0.1564422223214926}, {0.75, 0.9510516621502252, 
      0.30903193349764657`}, {0.5, 0.9510516621502252, 
      0.30903193349764657`}, {0.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{0.5, 0.9510516621502252, 0.30903193349764657`}, {0.75, 
      0.9510516621502252, 0.30903193349764657`}, {0.75, 0.8909958270419003, 
      0.4540114934601547}, {0.5, 0.8909958270419003, 0.4540114934601547}, {
      0.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.5, 0.8909958270419003, 0.4540114934601547}, {0.75, 
      0.8909958270419003, 0.4540114934601547}, {0.75, 0.808998528157412, 
      0.5878106680208697}, {0.5, 0.808998528157412, 0.5878106680208697}, {0.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.5, 0.8089985281574118, 0.58781066802087}, {0.75, 
      0.8089985281574118, 0.58781066802087}, {0.75, 0.7070790126229676, 
      0.70713454865968}, {0.5, 0.7070790126229676, 0.70713454865968}, {0.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.5, 0.7070790126229676, 0.70713454865968}, {0.75, 
      0.7070790126229676, 0.70713454865968}, {0.75, 0.5877471276121592, 
      0.8090446922041181}, {0.5, 0.5877471276121592, 0.8090446922041181}, {
      0.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.5, 0.5877471276121592, 0.8090446922041181}, {0.75, 
      0.5877471276121592, 0.8090446922041181}, {0.75, 0.45394151341132644`, 
      0.8910314822731207}, {0.5, 0.45394151341132644`, 0.8910314822731207}, {
      0.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.5, 0.45394151341132644`, 0.8910314822731207}, {0.75, 
      0.45394151341132644`, 0.8910314822731207}, {0.75, 0.3089572371217171, 
      0.9510759305282176}, {0.5, 0.3089572371217171, 0.9510759305282176}, {
      0.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.5, 0.3089572371217171, 0.9510759305282176}, {0.75, 
      0.3089572371217171, 0.9510759305282176}, {0.75, 0.15636464907469383`, 
      0.9876993958283805}, {0.5, 0.15636464907469383`, 0.9876993958283805}, {
      0.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.5, 0.15636464907469383`, 0.9876993958283805}, {0.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.75, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {0.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.75, -0.00007853981625862234, 0.9999999969157486}, {
      0.75, -0.156519794603278, 0.9876748219415881}, {0.5, -0.156519794603278,
       0.9876748219415881}, {0.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.5, -0.156519794603278, 0.9876748219415881}, {
      0.75, -0.156519794603278, 0.9876748219415881}, {
      0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.3091066279673126, 0.9510273879056678}, {0.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{0.5, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.707190080334431, 0.7070234722246362}, {0.5, -0.707190080334431,
       0.7070234722246362}, {0.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.5, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8090908512602302, 0.5876835835779286}, {0.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{0.5, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}, {
      0.75, -0.9999999876629945, -0.0001570796320327716}, {
      0.5, -0.9999999876629945, -0.0001570796320327716}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.75, -0.9999999876629945, 0.00015707963203365978`}, {
      1., -0.9999999876629945, 0.00015707963203365978`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.75, -0.987711673632875, -0.15628707486335794`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.75, -0.951100193039496, -0.3088825388399828}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.75, -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.75, -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.75, -0.7071900803344316, -0.7070234722246357}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.75, -0.5878742048036698, -0.8089523591203952}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.75, -0.45408147070841337`, -0.890960166314569}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      1., -0.3091066279673134, -0.9510273879056674}, {
      0.75, -0.3091066279673134, -0.9510273879056674}, {
      0.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.75, -0.3091066279673132, -0.9510273879056675}, {
      1., -0.3091066279673132, -0.9510273879056675}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.75, -0.15651979460327867`, -0.987674821941588}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.75, -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.75, 0.15636464907469316`, -0.9876993958283806}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {1., 
      0.30895723712171647`, -0.9510759305282178}, {0.75, 
      0.30895723712171647`, -0.9510759305282178}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.75, 0.3089572371217167, -0.9510759305282178}, {1., 
      0.3089572371217167, -0.9510759305282178}, {1., 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.75, 0.453941513411326, -0.8910314822731209}, {1., 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.75, 0.5877471276121589, -0.8090446922041185}, {1., 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.75, 0.7070790126229672, -0.7071345486596803}, {1., 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.75, 0.8089985281574115, -0.5878106680208703}, {1., 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.75, 0.8909958270419, -0.45401149346015546`}, {1., 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.75, 0.951051662150225, -0.3090319334976474}, {1., 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.9876871119312596, -0.15644222232149346`}, {0.75, 
      0.9876871119312596, -0.15644222232149346`}, {0.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.75, 0.9876871119312596, -0.1564422223214935}, {1., 
      0.9876871119312596, -0.1564422223214935}, {1., 
      1., -4.163336342344337*^-16}, {0.75, 1., -4.163336342344337*^-16}, {
      0.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.75, 1., -4.440892098500626*^-16}, {1., 
      1., -4.440892098500626*^-16}, {1., 0.9876871119312597, 
      0.15644222232149263`}, {0.75, 0.9876871119312597, 
      0.15644222232149263`}, {0.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.75, 0.9876871119312597, 0.1564422223214926}, {1., 
      0.9876871119312597, 0.1564422223214926}, {1., 0.9510516621502252, 
      0.30903193349764657`}, {0.75, 0.9510516621502252, 
      0.30903193349764657`}, {0.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{0.75, 0.9510516621502252, 0.30903193349764657`}, {1., 
      0.9510516621502252, 0.30903193349764657`}, {1., 0.8909958270419003, 
      0.4540114934601547}, {0.75, 0.8909958270419003, 0.4540114934601547}, {
      0.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.75, 0.8909958270419003, 0.4540114934601547}, {1., 
      0.8909958270419003, 0.4540114934601547}, {1., 0.808998528157412, 
      0.5878106680208697}, {0.75, 0.808998528157412, 0.5878106680208697}, {
      0.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.75, 0.8089985281574118, 0.58781066802087}, {1., 
      0.8089985281574118, 0.58781066802087}, {1., 0.7070790126229676, 
      0.70713454865968}, {0.75, 0.7070790126229676, 0.70713454865968}, {0.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.75, 0.7070790126229676, 0.70713454865968}, {1., 
      0.7070790126229676, 0.70713454865968}, {1., 0.5877471276121592, 
      0.8090446922041181}, {0.75, 0.5877471276121592, 0.8090446922041181}, {
      0.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.75, 0.5877471276121592, 0.8090446922041181}, {1., 
      0.5877471276121592, 0.8090446922041181}, {1., 0.45394151341132644`, 
      0.8910314822731207}, {0.75, 0.45394151341132644`, 0.8910314822731207}, {
      0.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.75, 0.45394151341132644`, 0.8910314822731207}, {1., 
      0.45394151341132644`, 0.8910314822731207}, {1., 0.3089572371217171, 
      0.9510759305282176}, {0.75, 0.3089572371217171, 0.9510759305282176}, {
      0.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.75, 0.3089572371217171, 0.9510759305282176}, {1., 
      0.3089572371217171, 0.9510759305282176}, {1., 0.15636464907469383`, 
      0.9876993958283805}, {0.75, 0.15636464907469383`, 0.9876993958283805}, {
      0.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.75, 0.15636464907469383`, 0.9876993958283805}, {1., 
      0.15636464907469383`, 0.9876993958283805}, {1., -0.00007853981625862234,
       0.9999999969157486}, {0.75, -0.00007853981625862234, 
      0.9999999969157486}, {0.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{0.75, -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.156519794603278, 0.9876748219415881}, {0.75, -0.156519794603278, 
      0.9876748219415881}, {0.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.75, -0.156519794603278, 0.9876748219415881}, {
      1., -0.156519794603278, 0.9876748219415881}, {1., -0.3091066279673126, 
      0.9510273879056678}, {0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{0.75, -0.3091066279673126, 0.9510273879056678}, {
      1., -0.3091066279673126, 0.9510273879056678}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.75, -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.75, -0.5878742048036691, 0.8089523591203958}, {
      1., -0.5878742048036691, 0.8089523591203958}, {1., -0.707190080334431, 
      0.7070234722246362}, {0.75, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.75, -0.707190080334431, 0.7070234722246362}, {
      1., -0.707190080334431, 0.7070234722246362}, {1., -0.8090908512602302, 
      0.5876835835779286}, {0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{0.75, -0.8090908512602302, 0.5876835835779286}, {
      1., -0.8090908512602302, 0.5876835835779286}, {1., -0.8910671320080111, 
      0.4538715305623583}, {0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.75, -0.8910671320080111, 0.4538715305623583}, {
      1., -0.8910671320080111, 0.4538715305623583}, {1., -0.9511001930394957, 
      0.3088825388399836}, {0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.75, -0.9511001930394957, 0.3088825388399836}, {
      1., -0.9511001930394957, 0.3088825388399836}, {1., -0.9877116736328749, 
      0.15628707486335883`}, {0.75, -0.9877116736328749, 
      0.15628707486335883`}, {0.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{0.75, -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9999999876629945, -0.0001570796320327716}, {
      0.75, -0.9999999876629945, -0.0001570796320327716}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1., -0.9999999876629945, 0.00015707963203365978`}, {
      1.25, -0.9999999876629945, 0.00015707963203365978`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      1., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1., -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      1., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1., -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      1., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1., -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1., -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      1., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1., -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      1., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1., -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      1., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1., -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.3091066279673134, -0.9510273879056674}, {
      1., -0.3091066279673134, -0.9510273879056674}, {
      1., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1., -0.3091066279673132, -0.9510273879056675}, {
      1.25, -0.3091066279673132, -0.9510273879056675}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      1., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1., -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1., -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {
      1., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1., 0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.30895723712171647`, -0.9510759305282178}, {1., 
      0.30895723712171647`, -0.9510759305282178}, {1., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1., 0.3089572371217167, -0.9510759305282178}, {1.25, 
      0.3089572371217167, -0.9510759305282178}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1., 0.453941513411326, -0.8910314822731209}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1., 0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1., 0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1., 0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1., 0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1., 0.951051662150225, -0.3090319334976474}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.9876871119312596, -0.15644222232149346`}, {1., 
      0.9876871119312596, -0.15644222232149346`}, {1., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1., 0.9876871119312596, -0.1564422223214935}, {1.25, 
      0.9876871119312596, -0.1564422223214935}, {1.25, 
      1., -4.163336342344337*^-16}, {1., 1., -4.163336342344337*^-16}, {1., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1., 1., -4.440892098500626*^-16}, {1.25, 
      1., -4.440892098500626*^-16}, {1.25, 0.9876871119312597, 
      0.15644222232149263`}, {1., 0.9876871119312597, 0.15644222232149263`}, {
      1., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1., 0.9876871119312597, 0.1564422223214926}, {1.25, 
      0.9876871119312597, 0.1564422223214926}, {1.25, 0.9510516621502252, 
      0.30903193349764657`}, {1., 0.9510516621502252, 0.30903193349764657`}, {
      1., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{1., 0.9510516621502252, 0.30903193349764657`}, {1.25, 
      0.9510516621502252, 0.30903193349764657`}, {1.25, 0.8909958270419003, 
      0.4540114934601547}, {1., 0.8909958270419003, 0.4540114934601547}, {1., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1., 0.8909958270419003, 0.4540114934601547}, {1.25, 
      0.8909958270419003, 0.4540114934601547}, {1.25, 0.808998528157412, 
      0.5878106680208697}, {1., 0.808998528157412, 0.5878106680208697}, {1., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1., 0.8089985281574118, 0.58781066802087}, {1.25, 
      0.8089985281574118, 0.58781066802087}, {1.25, 0.7070790126229676, 
      0.70713454865968}, {1., 0.7070790126229676, 0.70713454865968}, {1., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1., 0.7070790126229676, 0.70713454865968}, {1.25, 
      0.7070790126229676, 0.70713454865968}, {1.25, 0.5877471276121592, 
      0.8090446922041181}, {1., 0.5877471276121592, 0.8090446922041181}, {1., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1., 0.5877471276121592, 0.8090446922041181}, {1.25, 
      0.5877471276121592, 0.8090446922041181}, {1.25, 0.45394151341132644`, 
      0.8910314822731207}, {1., 0.45394151341132644`, 0.8910314822731207}, {
      1., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1., 0.45394151341132644`, 0.8910314822731207}, {1.25, 
      0.45394151341132644`, 0.8910314822731207}, {1.25, 0.3089572371217171, 
      0.9510759305282176}, {1., 0.3089572371217171, 0.9510759305282176}, {1., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1., 0.3089572371217171, 0.9510759305282176}, {1.25, 
      0.3089572371217171, 0.9510759305282176}, {1.25, 0.15636464907469383`, 
      0.9876993958283805}, {1., 0.15636464907469383`, 0.9876993958283805}, {
      1., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1., 0.15636464907469383`, 0.9876993958283805}, {1.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.00007853981625862234, 0.9999999969157486}, {1., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1., -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.156519794603278, 0.9876748219415881}, {1., -0.156519794603278, 
      0.9876748219415881}, {1., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1., -0.156519794603278, 0.9876748219415881}, {
      1.25, -0.156519794603278, 0.9876748219415881}, {
      1.25, -0.3091066279673126, 0.9510273879056678}, {
      1., -0.3091066279673126, 0.9510273879056678}, {1., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{1., -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1., -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1., -0.5878742048036691, 0.8089523591203958}, {
      1., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1., -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.707190080334431, 0.7070234722246362}, {1., -0.707190080334431, 
      0.7070234722246362}, {1., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1., -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.8090908512602302, 0.5876835835779286}, {
      1., -0.8090908512602302, 0.5876835835779286}, {1., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{1., -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1., -0.8910671320080111, 0.4538715305623583}, {1., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{1., -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1., -0.9511001930394957, 0.3088825388399836}, {1., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{1., -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1., -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9999999876629945, -0.0001570796320327716}, {
      1., -0.9999999876629945, -0.0001570796320327716}, {
      1., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.25, -0.9999999876629945, 0.00015707963203365978`}, {
      1.5, -0.9999999876629945, 0.00015707963203365978`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.25, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.3091066279673134, -0.9510273879056674}, {
      1.25, -0.3091066279673134, -0.9510273879056674}, {
      1.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.25, -0.3091066279673132, -0.9510273879056675}, {
      1.5, -0.3091066279673132, -0.9510273879056675}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.25, 0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.30895723712171647`, -0.9510759305282178}, {1.25, 
      0.30895723712171647`, -0.9510759305282178}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.25, 0.3089572371217167, -0.9510759305282178}, {1.5, 
      0.3089572371217167, -0.9510759305282178}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.25, 0.453941513411326, -0.8910314822731209}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.25, 0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.25, 0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.25, 0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.25, 0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.25, 0.951051662150225, -0.3090319334976474}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.9876871119312596, -0.15644222232149346`}, {1.25, 
      0.9876871119312596, -0.15644222232149346`}, {1.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.25, 0.9876871119312596, -0.1564422223214935}, {1.5, 
      0.9876871119312596, -0.1564422223214935}, {1.5, 
      1., -4.163336342344337*^-16}, {1.25, 1., -4.163336342344337*^-16}, {
      1.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.25, 1., -4.440892098500626*^-16}, {1.5, 
      1., -4.440892098500626*^-16}, {1.5, 0.9876871119312597, 
      0.15644222232149263`}, {1.25, 0.9876871119312597, 
      0.15644222232149263`}, {1.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.25, 0.9876871119312597, 0.1564422223214926}, {1.5, 
      0.9876871119312597, 0.1564422223214926}, {1.5, 0.9510516621502252, 
      0.30903193349764657`}, {1.25, 0.9510516621502252, 
      0.30903193349764657`}, {1.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{1.25, 0.9510516621502252, 0.30903193349764657`}, {1.5, 
      0.9510516621502252, 0.30903193349764657`}, {1.5, 0.8909958270419003, 
      0.4540114934601547}, {1.25, 0.8909958270419003, 0.4540114934601547}, {
      1.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.25, 0.8909958270419003, 0.4540114934601547}, {1.5, 
      0.8909958270419003, 0.4540114934601547}, {1.5, 0.808998528157412, 
      0.5878106680208697}, {1.25, 0.808998528157412, 0.5878106680208697}, {
      1.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.25, 0.8089985281574118, 0.58781066802087}, {1.5, 
      0.8089985281574118, 0.58781066802087}, {1.5, 0.7070790126229676, 
      0.70713454865968}, {1.25, 0.7070790126229676, 0.70713454865968}, {1.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.25, 0.7070790126229676, 0.70713454865968}, {1.5, 
      0.7070790126229676, 0.70713454865968}, {1.5, 0.5877471276121592, 
      0.8090446922041181}, {1.25, 0.5877471276121592, 0.8090446922041181}, {
      1.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.25, 0.5877471276121592, 0.8090446922041181}, {1.5, 
      0.5877471276121592, 0.8090446922041181}, {1.5, 0.45394151341132644`, 
      0.8910314822731207}, {1.25, 0.45394151341132644`, 0.8910314822731207}, {
      1.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.25, 0.45394151341132644`, 0.8910314822731207}, {1.5, 
      0.45394151341132644`, 0.8910314822731207}, {1.5, 0.3089572371217171, 
      0.9510759305282176}, {1.25, 0.3089572371217171, 0.9510759305282176}, {
      1.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.25, 0.3089572371217171, 0.9510759305282176}, {1.5, 
      0.3089572371217171, 0.9510759305282176}, {1.5, 0.15636464907469383`, 
      0.9876993958283805}, {1.25, 0.15636464907469383`, 0.9876993958283805}, {
      1.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.25, 0.15636464907469383`, 0.9876993958283805}, {1.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {1.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.156519794603278, 0.9876748219415881}, {1.25, -0.156519794603278,
       0.9876748219415881}, {1.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.25, -0.156519794603278, 0.9876748219415881}, {
      1.5, -0.156519794603278, 0.9876748219415881}, {1.5, -0.3091066279673126,
       0.9510273879056678}, {1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {1.5, -0.707190080334431,
       0.7070234722246362}, {1.25, -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.25, -0.707190080334431, 0.7070234722246362}, {
      1.5, -0.707190080334431, 0.7070234722246362}, {1.5, -0.8090908512602302,
       0.5876835835779286}, {1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9999999876629945, -0.0001570796320327716}, {
      1.25, -0.9999999876629945, -0.0001570796320327716}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.5, -0.9999999876629945, 0.00015707963203365978`}, {
      1.75, -0.9999999876629945, 0.00015707963203365978`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.5, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.3091066279673134, -0.9510273879056674}, {
      1.5, -0.3091066279673134, -0.9510273879056674}, {
      1.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.5, -0.3091066279673132, -0.9510273879056675}, {
      1.75, -0.3091066279673132, -0.9510273879056675}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.5, 0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.30895723712171647`, -0.9510759305282178}, {1.5, 
      0.30895723712171647`, -0.9510759305282178}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.5, 0.3089572371217167, -0.9510759305282178}, {1.75, 
      0.3089572371217167, -0.9510759305282178}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.5, 0.453941513411326, -0.8910314822731209}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.5, 0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.5, 0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.5, 0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.5, 0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.5, 0.951051662150225, -0.3090319334976474}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.9876871119312596, -0.15644222232149346`}, {1.5, 
      0.9876871119312596, -0.15644222232149346`}, {1.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.5, 0.9876871119312596, -0.1564422223214935}, {1.75, 
      0.9876871119312596, -0.1564422223214935}, {1.75, 
      1., -4.163336342344337*^-16}, {1.5, 1., -4.163336342344337*^-16}, {1.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.5, 1., -4.440892098500626*^-16}, {1.75, 
      1., -4.440892098500626*^-16}, {1.75, 0.9876871119312597, 
      0.15644222232149263`}, {1.5, 0.9876871119312597, 
      0.15644222232149263`}, {1.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.5, 0.9876871119312597, 0.1564422223214926}, {1.75, 
      0.9876871119312597, 0.1564422223214926}, {1.75, 0.9510516621502252, 
      0.30903193349764657`}, {1.5, 0.9510516621502252, 
      0.30903193349764657`}, {1.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{1.5, 0.9510516621502252, 0.30903193349764657`}, {1.75, 
      0.9510516621502252, 0.30903193349764657`}, {1.75, 0.8909958270419003, 
      0.4540114934601547}, {1.5, 0.8909958270419003, 0.4540114934601547}, {
      1.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.5, 0.8909958270419003, 0.4540114934601547}, {1.75, 
      0.8909958270419003, 0.4540114934601547}, {1.75, 0.808998528157412, 
      0.5878106680208697}, {1.5, 0.808998528157412, 0.5878106680208697}, {1.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.5, 0.8089985281574118, 0.58781066802087}, {1.75, 
      0.8089985281574118, 0.58781066802087}, {1.75, 0.7070790126229676, 
      0.70713454865968}, {1.5, 0.7070790126229676, 0.70713454865968}, {1.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.5, 0.7070790126229676, 0.70713454865968}, {1.75, 
      0.7070790126229676, 0.70713454865968}, {1.75, 0.5877471276121592, 
      0.8090446922041181}, {1.5, 0.5877471276121592, 0.8090446922041181}, {
      1.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.5, 0.5877471276121592, 0.8090446922041181}, {1.75, 
      0.5877471276121592, 0.8090446922041181}, {1.75, 0.45394151341132644`, 
      0.8910314822731207}, {1.5, 0.45394151341132644`, 0.8910314822731207}, {
      1.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.5, 0.45394151341132644`, 0.8910314822731207}, {1.75, 
      0.45394151341132644`, 0.8910314822731207}, {1.75, 0.3089572371217171, 
      0.9510759305282176}, {1.5, 0.3089572371217171, 0.9510759305282176}, {
      1.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.5, 0.3089572371217171, 0.9510759305282176}, {1.75, 
      0.3089572371217171, 0.9510759305282176}, {1.75, 0.15636464907469383`, 
      0.9876993958283805}, {1.5, 0.15636464907469383`, 0.9876993958283805}, {
      1.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.5, 0.15636464907469383`, 0.9876993958283805}, {1.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.75, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {1.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.75, -0.00007853981625862234, 0.9999999969157486}, {
      1.75, -0.156519794603278, 0.9876748219415881}, {1.5, -0.156519794603278,
       0.9876748219415881}, {1.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.5, -0.156519794603278, 0.9876748219415881}, {
      1.75, -0.156519794603278, 0.9876748219415881}, {
      1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.3091066279673126, 0.9510273879056678}, {1.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{1.5, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.707190080334431, 0.7070234722246362}, {1.5, -0.707190080334431,
       0.7070234722246362}, {1.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.5, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8090908512602302, 0.5876835835779286}, {1.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{1.5, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}, {
      1.75, -0.9999999876629945, -0.0001570796320327716}, {
      1.5, -0.9999999876629945, -0.0001570796320327716}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.75, -0.9999999876629945, 0.00015707963203365978`}, {
      2., -0.9999999876629945, 0.00015707963203365978`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.75, -0.987711673632875, -0.15628707486335794`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.75, -0.951100193039496, -0.3088825388399828}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.75, -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.75, -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.75, -0.7071900803344316, -0.7070234722246357}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.75, -0.5878742048036698, -0.8089523591203952}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.75, -0.45408147070841337`, -0.890960166314569}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      2., -0.3091066279673134, -0.9510273879056674}, {
      1.75, -0.3091066279673134, -0.9510273879056674}, {
      1.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.75, -0.3091066279673132, -0.9510273879056675}, {
      2., -0.3091066279673132, -0.9510273879056675}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.75, -0.15651979460327867`, -0.987674821941588}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.75, -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.75, 0.15636464907469316`, -0.9876993958283806}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {2., 
      0.30895723712171647`, -0.9510759305282178}, {1.75, 
      0.30895723712171647`, -0.9510759305282178}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.75, 0.3089572371217167, -0.9510759305282178}, {2., 
      0.3089572371217167, -0.9510759305282178}, {2., 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.75, 0.453941513411326, -0.8910314822731209}, {2., 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.75, 0.5877471276121589, -0.8090446922041185}, {2., 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.75, 0.7070790126229672, -0.7071345486596803}, {2., 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.75, 0.8089985281574115, -0.5878106680208703}, {2., 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.75, 0.8909958270419, -0.45401149346015546`}, {2., 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.75, 0.951051662150225, -0.3090319334976474}, {2., 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.9876871119312596, -0.15644222232149346`}, {1.75, 
      0.9876871119312596, -0.15644222232149346`}, {1.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.75, 0.9876871119312596, -0.1564422223214935}, {2., 
      0.9876871119312596, -0.1564422223214935}, {2., 
      1., -4.163336342344337*^-16}, {1.75, 1., -4.163336342344337*^-16}, {
      1.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.75, 1., -4.440892098500626*^-16}, {2., 
      1., -4.440892098500626*^-16}, {2., 0.9876871119312597, 
      0.15644222232149263`}, {1.75, 0.9876871119312597, 
      0.15644222232149263`}, {1.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.75, 0.9876871119312597, 0.1564422223214926}, {2., 
      0.9876871119312597, 0.1564422223214926}, {2., 0.9510516621502252, 
      0.30903193349764657`}, {1.75, 0.9510516621502252, 
      0.30903193349764657`}, {1.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{1.75, 0.9510516621502252, 0.30903193349764657`}, {2., 
      0.9510516621502252, 0.30903193349764657`}, {2., 0.8909958270419003, 
      0.4540114934601547}, {1.75, 0.8909958270419003, 0.4540114934601547}, {
      1.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.75, 0.8909958270419003, 0.4540114934601547}, {2., 
      0.8909958270419003, 0.4540114934601547}, {2., 0.808998528157412, 
      0.5878106680208697}, {1.75, 0.808998528157412, 0.5878106680208697}, {
      1.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.75, 0.8089985281574118, 0.58781066802087}, {2., 
      0.8089985281574118, 0.58781066802087}, {2., 0.7070790126229676, 
      0.70713454865968}, {1.75, 0.7070790126229676, 0.70713454865968}, {1.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.75, 0.7070790126229676, 0.70713454865968}, {2., 
      0.7070790126229676, 0.70713454865968}, {2., 0.5877471276121592, 
      0.8090446922041181}, {1.75, 0.5877471276121592, 0.8090446922041181}, {
      1.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.75, 0.5877471276121592, 0.8090446922041181}, {2., 
      0.5877471276121592, 0.8090446922041181}, {2., 0.45394151341132644`, 
      0.8910314822731207}, {1.75, 0.45394151341132644`, 0.8910314822731207}, {
      1.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.75, 0.45394151341132644`, 0.8910314822731207}, {2., 
      0.45394151341132644`, 0.8910314822731207}, {2., 0.3089572371217171, 
      0.9510759305282176}, {1.75, 0.3089572371217171, 0.9510759305282176}, {
      1.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.75, 0.3089572371217171, 0.9510759305282176}, {2., 
      0.3089572371217171, 0.9510759305282176}, {2., 0.15636464907469383`, 
      0.9876993958283805}, {1.75, 0.15636464907469383`, 0.9876993958283805}, {
      1.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.75, 0.15636464907469383`, 0.9876993958283805}, {2., 
      0.15636464907469383`, 0.9876993958283805}, {2., -0.00007853981625862234,
       0.9999999969157486}, {1.75, -0.00007853981625862234, 
      0.9999999969157486}, {1.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{1.75, -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.156519794603278, 0.9876748219415881}, {1.75, -0.156519794603278, 
      0.9876748219415881}, {1.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.75, -0.156519794603278, 0.9876748219415881}, {
      2., -0.156519794603278, 0.9876748219415881}, {2., -0.3091066279673126, 
      0.9510273879056678}, {1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{1.75, -0.3091066279673126, 0.9510273879056678}, {
      2., -0.3091066279673126, 0.9510273879056678}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.75, -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.75, -0.5878742048036691, 0.8089523591203958}, {
      2., -0.5878742048036691, 0.8089523591203958}, {2., -0.707190080334431, 
      0.7070234722246362}, {1.75, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.75, -0.707190080334431, 0.7070234722246362}, {
      2., -0.707190080334431, 0.7070234722246362}, {2., -0.8090908512602302, 
      0.5876835835779286}, {1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{1.75, -0.8090908512602302, 0.5876835835779286}, {
      2., -0.8090908512602302, 0.5876835835779286}, {2., -0.8910671320080111, 
      0.4538715305623583}, {1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.75, -0.8910671320080111, 0.4538715305623583}, {
      2., -0.8910671320080111, 0.4538715305623583}, {2., -0.9511001930394957, 
      0.3088825388399836}, {1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.75, -0.9511001930394957, 0.3088825388399836}, {
      2., -0.9511001930394957, 0.3088825388399836}, {2., -0.9877116736328749, 
      0.15628707486335883`}, {1.75, -0.9877116736328749, 
      0.15628707486335883`}, {1.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{1.75, -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9999999876629945, -0.0001570796320327716}, {
      1.75, -0.9999999876629945, -0.0001570796320327716}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2., -0.9999999876629945, 0.00015707963203365978`}, {
      2.25, -0.9999999876629945, 0.00015707963203365978`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      2., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2., -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      2., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2., -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      2., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2., -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2., -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      2., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2., -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      2., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2., -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      2., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2., -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.3091066279673134, -0.9510273879056674}, {
      2., -0.3091066279673134, -0.9510273879056674}, {
      2., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2., -0.3091066279673132, -0.9510273879056675}, {
      2.25, -0.3091066279673132, -0.9510273879056675}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      2., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2., -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2., -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {
      2., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2., 0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.30895723712171647`, -0.9510759305282178}, {2., 
      0.30895723712171647`, -0.9510759305282178}, {2., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2., 0.3089572371217167, -0.9510759305282178}, {2.25, 
      0.3089572371217167, -0.9510759305282178}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2., 0.453941513411326, -0.8910314822731209}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2., 0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2., 0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2., 0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2., 0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2., 0.951051662150225, -0.3090319334976474}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.9876871119312596, -0.15644222232149346`}, {2., 
      0.9876871119312596, -0.15644222232149346`}, {2., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2., 0.9876871119312596, -0.1564422223214935}, {2.25, 
      0.9876871119312596, -0.1564422223214935}, {2.25, 
      1., -4.163336342344337*^-16}, {2., 1., -4.163336342344337*^-16}, {2., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2., 1., -4.440892098500626*^-16}, {2.25, 
      1., -4.440892098500626*^-16}, {2.25, 0.9876871119312597, 
      0.15644222232149263`}, {2., 0.9876871119312597, 0.15644222232149263`}, {
      2., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2., 0.9876871119312597, 0.1564422223214926}, {2.25, 
      0.9876871119312597, 0.1564422223214926}, {2.25, 0.9510516621502252, 
      0.30903193349764657`}, {2., 0.9510516621502252, 0.30903193349764657`}, {
      2., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{2., 0.9510516621502252, 0.30903193349764657`}, {2.25, 
      0.9510516621502252, 0.30903193349764657`}, {2.25, 0.8909958270419003, 
      0.4540114934601547}, {2., 0.8909958270419003, 0.4540114934601547}, {2., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2., 0.8909958270419003, 0.4540114934601547}, {2.25, 
      0.8909958270419003, 0.4540114934601547}, {2.25, 0.808998528157412, 
      0.5878106680208697}, {2., 0.808998528157412, 0.5878106680208697}, {2., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2., 0.8089985281574118, 0.58781066802087}, {2.25, 
      0.8089985281574118, 0.58781066802087}, {2.25, 0.7070790126229676, 
      0.70713454865968}, {2., 0.7070790126229676, 0.70713454865968}, {2., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2., 0.7070790126229676, 0.70713454865968}, {2.25, 
      0.7070790126229676, 0.70713454865968}, {2.25, 0.5877471276121592, 
      0.8090446922041181}, {2., 0.5877471276121592, 0.8090446922041181}, {2., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2., 0.5877471276121592, 0.8090446922041181}, {2.25, 
      0.5877471276121592, 0.8090446922041181}, {2.25, 0.45394151341132644`, 
      0.8910314822731207}, {2., 0.45394151341132644`, 0.8910314822731207}, {
      2., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2., 0.45394151341132644`, 0.8910314822731207}, {2.25, 
      0.45394151341132644`, 0.8910314822731207}, {2.25, 0.3089572371217171, 
      0.9510759305282176}, {2., 0.3089572371217171, 0.9510759305282176}, {2., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2., 0.3089572371217171, 0.9510759305282176}, {2.25, 
      0.3089572371217171, 0.9510759305282176}, {2.25, 0.15636464907469383`, 
      0.9876993958283805}, {2., 0.15636464907469383`, 0.9876993958283805}, {
      2., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2., 0.15636464907469383`, 0.9876993958283805}, {2.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.00007853981625862234, 0.9999999969157486}, {2., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2., -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.156519794603278, 0.9876748219415881}, {2., -0.156519794603278, 
      0.9876748219415881}, {2., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2., -0.156519794603278, 0.9876748219415881}, {
      2.25, -0.156519794603278, 0.9876748219415881}, {
      2.25, -0.3091066279673126, 0.9510273879056678}, {
      2., -0.3091066279673126, 0.9510273879056678}, {2., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{2., -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2., -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2., -0.5878742048036691, 0.8089523591203958}, {
      2., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2., -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.707190080334431, 0.7070234722246362}, {2., -0.707190080334431, 
      0.7070234722246362}, {2., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2., -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.8090908512602302, 0.5876835835779286}, {
      2., -0.8090908512602302, 0.5876835835779286}, {2., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{2., -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2., -0.8910671320080111, 0.4538715305623583}, {2., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{2., -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2., -0.9511001930394957, 0.3088825388399836}, {2., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{2., -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2., -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9999999876629945, -0.0001570796320327716}, {
      2., -0.9999999876629945, -0.0001570796320327716}, {
      2., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.25, -0.9999999876629945, 0.00015707963203365978`}, {
      2.5, -0.9999999876629945, 0.00015707963203365978`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.25, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.3091066279673134, -0.9510273879056674}, {
      2.25, -0.3091066279673134, -0.9510273879056674}, {
      2.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.25, -0.3091066279673132, -0.9510273879056675}, {
      2.5, -0.3091066279673132, -0.9510273879056675}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.25, 0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.30895723712171647`, -0.9510759305282178}, {2.25, 
      0.30895723712171647`, -0.9510759305282178}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.25, 0.3089572371217167, -0.9510759305282178}, {2.5, 
      0.3089572371217167, -0.9510759305282178}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.25, 0.453941513411326, -0.8910314822731209}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.25, 0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.25, 0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.25, 0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.25, 0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.25, 0.951051662150225, -0.3090319334976474}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.9876871119312596, -0.15644222232149346`}, {2.25, 
      0.9876871119312596, -0.15644222232149346`}, {2.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.25, 0.9876871119312596, -0.1564422223214935}, {2.5, 
      0.9876871119312596, -0.1564422223214935}, {2.5, 
      1., -4.163336342344337*^-16}, {2.25, 1., -4.163336342344337*^-16}, {
      2.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.25, 1., -4.440892098500626*^-16}, {2.5, 
      1., -4.440892098500626*^-16}, {2.5, 0.9876871119312597, 
      0.15644222232149263`}, {2.25, 0.9876871119312597, 
      0.15644222232149263`}, {2.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.25, 0.9876871119312597, 0.1564422223214926}, {2.5, 
      0.9876871119312597, 0.1564422223214926}, {2.5, 0.9510516621502252, 
      0.30903193349764657`}, {2.25, 0.9510516621502252, 
      0.30903193349764657`}, {2.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{2.25, 0.9510516621502252, 0.30903193349764657`}, {2.5, 
      0.9510516621502252, 0.30903193349764657`}, {2.5, 0.8909958270419003, 
      0.4540114934601547}, {2.25, 0.8909958270419003, 0.4540114934601547}, {
      2.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.25, 0.8909958270419003, 0.4540114934601547}, {2.5, 
      0.8909958270419003, 0.4540114934601547}, {2.5, 0.808998528157412, 
      0.5878106680208697}, {2.25, 0.808998528157412, 0.5878106680208697}, {
      2.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.25, 0.8089985281574118, 0.58781066802087}, {2.5, 
      0.8089985281574118, 0.58781066802087}, {2.5, 0.7070790126229676, 
      0.70713454865968}, {2.25, 0.7070790126229676, 0.70713454865968}, {2.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.25, 0.7070790126229676, 0.70713454865968}, {2.5, 
      0.7070790126229676, 0.70713454865968}, {2.5, 0.5877471276121592, 
      0.8090446922041181}, {2.25, 0.5877471276121592, 0.8090446922041181}, {
      2.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.25, 0.5877471276121592, 0.8090446922041181}, {2.5, 
      0.5877471276121592, 0.8090446922041181}, {2.5, 0.45394151341132644`, 
      0.8910314822731207}, {2.25, 0.45394151341132644`, 0.8910314822731207}, {
      2.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.25, 0.45394151341132644`, 0.8910314822731207}, {2.5, 
      0.45394151341132644`, 0.8910314822731207}, {2.5, 0.3089572371217171, 
      0.9510759305282176}, {2.25, 0.3089572371217171, 0.9510759305282176}, {
      2.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.25, 0.3089572371217171, 0.9510759305282176}, {2.5, 
      0.3089572371217171, 0.9510759305282176}, {2.5, 0.15636464907469383`, 
      0.9876993958283805}, {2.25, 0.15636464907469383`, 0.9876993958283805}, {
      2.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.25, 0.15636464907469383`, 0.9876993958283805}, {2.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {2.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.156519794603278, 0.9876748219415881}, {2.25, -0.156519794603278,
       0.9876748219415881}, {2.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.25, -0.156519794603278, 0.9876748219415881}, {
      2.5, -0.156519794603278, 0.9876748219415881}, {2.5, -0.3091066279673126,
       0.9510273879056678}, {2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {2.5, -0.707190080334431,
       0.7070234722246362}, {2.25, -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.25, -0.707190080334431, 0.7070234722246362}, {
      2.5, -0.707190080334431, 0.7070234722246362}, {2.5, -0.8090908512602302,
       0.5876835835779286}, {2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9999999876629945, -0.0001570796320327716}, {
      2.25, -0.9999999876629945, -0.0001570796320327716}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.5, -0.9999999876629945, 0.00015707963203365978`}, {
      2.75, -0.9999999876629945, 0.00015707963203365978`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.5, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.3091066279673134, -0.9510273879056674}, {
      2.5, -0.3091066279673134, -0.9510273879056674}, {
      2.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.5, -0.3091066279673132, -0.9510273879056675}, {
      2.75, -0.3091066279673132, -0.9510273879056675}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.5, 0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.30895723712171647`, -0.9510759305282178}, {2.5, 
      0.30895723712171647`, -0.9510759305282178}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.5, 0.3089572371217167, -0.9510759305282178}, {2.75, 
      0.3089572371217167, -0.9510759305282178}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.5, 0.453941513411326, -0.8910314822731209}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.5, 0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.5, 0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.5, 0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.5, 0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.5, 0.951051662150225, -0.3090319334976474}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.9876871119312596, -0.15644222232149346`}, {2.5, 
      0.9876871119312596, -0.15644222232149346`}, {2.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.5, 0.9876871119312596, -0.1564422223214935}, {2.75, 
      0.9876871119312596, -0.1564422223214935}, {2.75, 
      1., -4.163336342344337*^-16}, {2.5, 1., -4.163336342344337*^-16}, {2.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.5, 1., -4.440892098500626*^-16}, {2.75, 
      1., -4.440892098500626*^-16}, {2.75, 0.9876871119312597, 
      0.15644222232149263`}, {2.5, 0.9876871119312597, 
      0.15644222232149263`}, {2.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.5, 0.9876871119312597, 0.1564422223214926}, {2.75, 
      0.9876871119312597, 0.1564422223214926}, {2.75, 0.9510516621502252, 
      0.30903193349764657`}, {2.5, 0.9510516621502252, 
      0.30903193349764657`}, {2.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{2.5, 0.9510516621502252, 0.30903193349764657`}, {2.75, 
      0.9510516621502252, 0.30903193349764657`}, {2.75, 0.8909958270419003, 
      0.4540114934601547}, {2.5, 0.8909958270419003, 0.4540114934601547}, {
      2.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.5, 0.8909958270419003, 0.4540114934601547}, {2.75, 
      0.8909958270419003, 0.4540114934601547}, {2.75, 0.808998528157412, 
      0.5878106680208697}, {2.5, 0.808998528157412, 0.5878106680208697}, {2.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.5, 0.8089985281574118, 0.58781066802087}, {2.75, 
      0.8089985281574118, 0.58781066802087}, {2.75, 0.7070790126229676, 
      0.70713454865968}, {2.5, 0.7070790126229676, 0.70713454865968}, {2.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.5, 0.7070790126229676, 0.70713454865968}, {2.75, 
      0.7070790126229676, 0.70713454865968}, {2.75, 0.5877471276121592, 
      0.8090446922041181}, {2.5, 0.5877471276121592, 0.8090446922041181}, {
      2.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.5, 0.5877471276121592, 0.8090446922041181}, {2.75, 
      0.5877471276121592, 0.8090446922041181}, {2.75, 0.45394151341132644`, 
      0.8910314822731207}, {2.5, 0.45394151341132644`, 0.8910314822731207}, {
      2.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.5, 0.45394151341132644`, 0.8910314822731207}, {2.75, 
      0.45394151341132644`, 0.8910314822731207}, {2.75, 0.3089572371217171, 
      0.9510759305282176}, {2.5, 0.3089572371217171, 0.9510759305282176}, {
      2.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.5, 0.3089572371217171, 0.9510759305282176}, {2.75, 
      0.3089572371217171, 0.9510759305282176}, {2.75, 0.15636464907469383`, 
      0.9876993958283805}, {2.5, 0.15636464907469383`, 0.9876993958283805}, {
      2.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.5, 0.15636464907469383`, 0.9876993958283805}, {2.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.75, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {2.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.75, -0.00007853981625862234, 0.9999999969157486}, {
      2.75, -0.156519794603278, 0.9876748219415881}, {2.5, -0.156519794603278,
       0.9876748219415881}, {2.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.5, -0.156519794603278, 0.9876748219415881}, {
      2.75, -0.156519794603278, 0.9876748219415881}, {
      2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.3091066279673126, 0.9510273879056678}, {2.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{2.5, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.707190080334431, 0.7070234722246362}, {2.5, -0.707190080334431,
       0.7070234722246362}, {2.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.5, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8090908512602302, 0.5876835835779286}, {2.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{2.5, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}, {
      2.75, -0.9999999876629945, -0.0001570796320327716}, {
      2.5, -0.9999999876629945, -0.0001570796320327716}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.75, -0.9999999876629945, 0.00015707963203365978`}, {
      3., -0.9999999876629945, 0.00015707963203365978`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.75, -0.987711673632875, -0.15628707486335794`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.75, -0.951100193039496, -0.3088825388399828}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.75, -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.75, -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.75, -0.7071900803344316, -0.7070234722246357}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.75, -0.5878742048036698, -0.8089523591203952}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.75, -0.45408147070841337`, -0.890960166314569}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      3., -0.3091066279673134, -0.9510273879056674}, {
      2.75, -0.3091066279673134, -0.9510273879056674}, {
      2.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.75, -0.3091066279673132, -0.9510273879056675}, {
      3., -0.3091066279673132, -0.9510273879056675}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.75, -0.15651979460327867`, -0.987674821941588}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.75, -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.75, 0.15636464907469316`, -0.9876993958283806}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {3., 
      0.30895723712171647`, -0.9510759305282178}, {2.75, 
      0.30895723712171647`, -0.9510759305282178}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.75, 0.3089572371217167, -0.9510759305282178}, {3., 
      0.3089572371217167, -0.9510759305282178}, {3., 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.75, 0.453941513411326, -0.8910314822731209}, {3., 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.75, 0.5877471276121589, -0.8090446922041185}, {3., 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.75, 0.7070790126229672, -0.7071345486596803}, {3., 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.75, 0.8089985281574115, -0.5878106680208703}, {3., 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.75, 0.8909958270419, -0.45401149346015546`}, {3., 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.75, 0.951051662150225, -0.3090319334976474}, {3., 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.9876871119312596, -0.15644222232149346`}, {2.75, 
      0.9876871119312596, -0.15644222232149346`}, {2.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.75, 0.9876871119312596, -0.1564422223214935}, {3., 
      0.9876871119312596, -0.1564422223214935}, {3., 
      1., -4.163336342344337*^-16}, {2.75, 1., -4.163336342344337*^-16}, {
      2.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.75, 1., -4.440892098500626*^-16}, {3., 
      1., -4.440892098500626*^-16}, {3., 0.9876871119312597, 
      0.15644222232149263`}, {2.75, 0.9876871119312597, 
      0.15644222232149263`}, {2.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.75, 0.9876871119312597, 0.1564422223214926}, {3., 
      0.9876871119312597, 0.1564422223214926}, {3., 0.9510516621502252, 
      0.30903193349764657`}, {2.75, 0.9510516621502252, 
      0.30903193349764657`}, {2.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{2.75, 0.9510516621502252, 0.30903193349764657`}, {3., 
      0.9510516621502252, 0.30903193349764657`}, {3., 0.8909958270419003, 
      0.4540114934601547}, {2.75, 0.8909958270419003, 0.4540114934601547}, {
      2.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.75, 0.8909958270419003, 0.4540114934601547}, {3., 
      0.8909958270419003, 0.4540114934601547}, {3., 0.808998528157412, 
      0.5878106680208697}, {2.75, 0.808998528157412, 0.5878106680208697}, {
      2.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.75, 0.8089985281574118, 0.58781066802087}, {3., 
      0.8089985281574118, 0.58781066802087}, {3., 0.7070790126229676, 
      0.70713454865968}, {2.75, 0.7070790126229676, 0.70713454865968}, {2.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.75, 0.7070790126229676, 0.70713454865968}, {3., 
      0.7070790126229676, 0.70713454865968}, {3., 0.5877471276121592, 
      0.8090446922041181}, {2.75, 0.5877471276121592, 0.8090446922041181}, {
      2.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.75, 0.5877471276121592, 0.8090446922041181}, {3., 
      0.5877471276121592, 0.8090446922041181}, {3., 0.45394151341132644`, 
      0.8910314822731207}, {2.75, 0.45394151341132644`, 0.8910314822731207}, {
      2.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.75, 0.45394151341132644`, 0.8910314822731207}, {3., 
      0.45394151341132644`, 0.8910314822731207}, {3., 0.3089572371217171, 
      0.9510759305282176}, {2.75, 0.3089572371217171, 0.9510759305282176}, {
      2.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.75, 0.3089572371217171, 0.9510759305282176}, {3., 
      0.3089572371217171, 0.9510759305282176}, {3., 0.15636464907469383`, 
      0.9876993958283805}, {2.75, 0.15636464907469383`, 0.9876993958283805}, {
      2.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.75, 0.15636464907469383`, 0.9876993958283805}, {3., 
      0.15636464907469383`, 0.9876993958283805}, {3., -0.00007853981625862234,
       0.9999999969157486}, {2.75, -0.00007853981625862234, 
      0.9999999969157486}, {2.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{2.75, -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.156519794603278, 0.9876748219415881}, {2.75, -0.156519794603278, 
      0.9876748219415881}, {2.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.75, -0.156519794603278, 0.9876748219415881}, {
      3., -0.156519794603278, 0.9876748219415881}, {3., -0.3091066279673126, 
      0.9510273879056678}, {2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{2.75, -0.3091066279673126, 0.9510273879056678}, {
      3., -0.3091066279673126, 0.9510273879056678}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.75, -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.75, -0.5878742048036691, 0.8089523591203958}, {
      3., -0.5878742048036691, 0.8089523591203958}, {3., -0.707190080334431, 
      0.7070234722246362}, {2.75, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.75, -0.707190080334431, 0.7070234722246362}, {
      3., -0.707190080334431, 0.7070234722246362}, {3., -0.8090908512602302, 
      0.5876835835779286}, {2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{2.75, -0.8090908512602302, 0.5876835835779286}, {
      3., -0.8090908512602302, 0.5876835835779286}, {3., -0.8910671320080111, 
      0.4538715305623583}, {2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.75, -0.8910671320080111, 0.4538715305623583}, {
      3., -0.8910671320080111, 0.4538715305623583}, {3., -0.9511001930394957, 
      0.3088825388399836}, {2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.75, -0.9511001930394957, 0.3088825388399836}, {
      3., -0.9511001930394957, 0.3088825388399836}, {3., -0.9877116736328749, 
      0.15628707486335883`}, {2.75, -0.9877116736328749, 
      0.15628707486335883`}, {2.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{2.75, -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9999999876629945, -0.0001570796320327716}, {
      2.75, -0.9999999876629945, -0.0001570796320327716}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3., -0.9999999876629945, 0.00015707963203365978`}, {
      3.25, -0.9999999876629945, 0.00015707963203365978`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      3., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3., -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      3., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3., -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      3., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3., -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3., -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      3., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3., -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      3., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3., -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      3., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3., -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.3091066279673134, -0.9510273879056674}, {
      3., -0.3091066279673134, -0.9510273879056674}, {
      3., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3., -0.3091066279673132, -0.9510273879056675}, {
      3.25, -0.3091066279673132, -0.9510273879056675}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      3., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3., -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3., -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {
      3., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3., 0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.30895723712171647`, -0.9510759305282178}, {3., 
      0.30895723712171647`, -0.9510759305282178}, {3., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3., 0.3089572371217167, -0.9510759305282178}, {3.25, 
      0.3089572371217167, -0.9510759305282178}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3., 0.453941513411326, -0.8910314822731209}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3., 0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3., 0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3., 0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3., 0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3., 0.951051662150225, -0.3090319334976474}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.9876871119312596, -0.15644222232149346`}, {3., 
      0.9876871119312596, -0.15644222232149346`}, {3., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3., 0.9876871119312596, -0.1564422223214935}, {3.25, 
      0.9876871119312596, -0.1564422223214935}, {3.25, 
      1., -4.163336342344337*^-16}, {3., 1., -4.163336342344337*^-16}, {3., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3., 1., -4.440892098500626*^-16}, {3.25, 
      1., -4.440892098500626*^-16}, {3.25, 0.9876871119312597, 
      0.15644222232149263`}, {3., 0.9876871119312597, 0.15644222232149263`}, {
      3., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3., 0.9876871119312597, 0.1564422223214926}, {3.25, 
      0.9876871119312597, 0.1564422223214926}, {3.25, 0.9510516621502252, 
      0.30903193349764657`}, {3., 0.9510516621502252, 0.30903193349764657`}, {
      3., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{3., 0.9510516621502252, 0.30903193349764657`}, {3.25, 
      0.9510516621502252, 0.30903193349764657`}, {3.25, 0.8909958270419003, 
      0.4540114934601547}, {3., 0.8909958270419003, 0.4540114934601547}, {3., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3., 0.8909958270419003, 0.4540114934601547}, {3.25, 
      0.8909958270419003, 0.4540114934601547}, {3.25, 0.808998528157412, 
      0.5878106680208697}, {3., 0.808998528157412, 0.5878106680208697}, {3., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3., 0.8089985281574118, 0.58781066802087}, {3.25, 
      0.8089985281574118, 0.58781066802087}, {3.25, 0.7070790126229676, 
      0.70713454865968}, {3., 0.7070790126229676, 0.70713454865968}, {3., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3., 0.7070790126229676, 0.70713454865968}, {3.25, 
      0.7070790126229676, 0.70713454865968}, {3.25, 0.5877471276121592, 
      0.8090446922041181}, {3., 0.5877471276121592, 0.8090446922041181}, {3., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3., 0.5877471276121592, 0.8090446922041181}, {3.25, 
      0.5877471276121592, 0.8090446922041181}, {3.25, 0.45394151341132644`, 
      0.8910314822731207}, {3., 0.45394151341132644`, 0.8910314822731207}, {
      3., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3., 0.45394151341132644`, 0.8910314822731207}, {3.25, 
      0.45394151341132644`, 0.8910314822731207}, {3.25, 0.3089572371217171, 
      0.9510759305282176}, {3., 0.3089572371217171, 0.9510759305282176}, {3., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3., 0.3089572371217171, 0.9510759305282176}, {3.25, 
      0.3089572371217171, 0.9510759305282176}, {3.25, 0.15636464907469383`, 
      0.9876993958283805}, {3., 0.15636464907469383`, 0.9876993958283805}, {
      3., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3., 0.15636464907469383`, 0.9876993958283805}, {3.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.00007853981625862234, 0.9999999969157486}, {3., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3., -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.156519794603278, 0.9876748219415881}, {3., -0.156519794603278, 
      0.9876748219415881}, {3., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3., -0.156519794603278, 0.9876748219415881}, {
      3.25, -0.156519794603278, 0.9876748219415881}, {
      3.25, -0.3091066279673126, 0.9510273879056678}, {
      3., -0.3091066279673126, 0.9510273879056678}, {3., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{3., -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3., -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3., -0.5878742048036691, 0.8089523591203958}, {
      3., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3., -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.707190080334431, 0.7070234722246362}, {3., -0.707190080334431, 
      0.7070234722246362}, {3., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3., -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.8090908512602302, 0.5876835835779286}, {
      3., -0.8090908512602302, 0.5876835835779286}, {3., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{3., -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3., -0.8910671320080111, 0.4538715305623583}, {3., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{3., -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3., -0.9511001930394957, 0.3088825388399836}, {3., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{3., -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3., -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9999999876629945, -0.0001570796320327716}, {
      3., -0.9999999876629945, -0.0001570796320327716}, {
      3., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.25, -0.9999999876629945, 0.00015707963203365978`}, {
      3.5, -0.9999999876629945, 0.00015707963203365978`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.25, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.3091066279673134, -0.9510273879056674}, {
      3.25, -0.3091066279673134, -0.9510273879056674}, {
      3.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.25, -0.3091066279673132, -0.9510273879056675}, {
      3.5, -0.3091066279673132, -0.9510273879056675}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.25, 0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.30895723712171647`, -0.9510759305282178}, {3.25, 
      0.30895723712171647`, -0.9510759305282178}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.25, 0.3089572371217167, -0.9510759305282178}, {3.5, 
      0.3089572371217167, -0.9510759305282178}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.25, 0.453941513411326, -0.8910314822731209}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.25, 0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.25, 0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.25, 0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.25, 0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.25, 0.951051662150225, -0.3090319334976474}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.9876871119312596, -0.15644222232149346`}, {3.25, 
      0.9876871119312596, -0.15644222232149346`}, {3.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.25, 0.9876871119312596, -0.1564422223214935}, {3.5, 
      0.9876871119312596, -0.1564422223214935}, {3.5, 
      1., -4.163336342344337*^-16}, {3.25, 1., -4.163336342344337*^-16}, {
      3.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.25, 1., -4.440892098500626*^-16}, {3.5, 
      1., -4.440892098500626*^-16}, {3.5, 0.9876871119312597, 
      0.15644222232149263`}, {3.25, 0.9876871119312597, 
      0.15644222232149263`}, {3.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.25, 0.9876871119312597, 0.1564422223214926}, {3.5, 
      0.9876871119312597, 0.1564422223214926}, {3.5, 0.9510516621502252, 
      0.30903193349764657`}, {3.25, 0.9510516621502252, 
      0.30903193349764657`}, {3.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{3.25, 0.9510516621502252, 0.30903193349764657`}, {3.5, 
      0.9510516621502252, 0.30903193349764657`}, {3.5, 0.8909958270419003, 
      0.4540114934601547}, {3.25, 0.8909958270419003, 0.4540114934601547}, {
      3.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.25, 0.8909958270419003, 0.4540114934601547}, {3.5, 
      0.8909958270419003, 0.4540114934601547}, {3.5, 0.808998528157412, 
      0.5878106680208697}, {3.25, 0.808998528157412, 0.5878106680208697}, {
      3.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.25, 0.8089985281574118, 0.58781066802087}, {3.5, 
      0.8089985281574118, 0.58781066802087}, {3.5, 0.7070790126229676, 
      0.70713454865968}, {3.25, 0.7070790126229676, 0.70713454865968}, {3.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.25, 0.7070790126229676, 0.70713454865968}, {3.5, 
      0.7070790126229676, 0.70713454865968}, {3.5, 0.5877471276121592, 
      0.8090446922041181}, {3.25, 0.5877471276121592, 0.8090446922041181}, {
      3.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.25, 0.5877471276121592, 0.8090446922041181}, {3.5, 
      0.5877471276121592, 0.8090446922041181}, {3.5, 0.45394151341132644`, 
      0.8910314822731207}, {3.25, 0.45394151341132644`, 0.8910314822731207}, {
      3.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.25, 0.45394151341132644`, 0.8910314822731207}, {3.5, 
      0.45394151341132644`, 0.8910314822731207}, {3.5, 0.3089572371217171, 
      0.9510759305282176}, {3.25, 0.3089572371217171, 0.9510759305282176}, {
      3.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.25, 0.3089572371217171, 0.9510759305282176}, {3.5, 
      0.3089572371217171, 0.9510759305282176}, {3.5, 0.15636464907469383`, 
      0.9876993958283805}, {3.25, 0.15636464907469383`, 0.9876993958283805}, {
      3.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.25, 0.15636464907469383`, 0.9876993958283805}, {3.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {3.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.156519794603278, 0.9876748219415881}, {3.25, -0.156519794603278,
       0.9876748219415881}, {3.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.25, -0.156519794603278, 0.9876748219415881}, {
      3.5, -0.156519794603278, 0.9876748219415881}, {3.5, -0.3091066279673126,
       0.9510273879056678}, {3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {3.5, -0.707190080334431,
       0.7070234722246362}, {3.25, -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.25, -0.707190080334431, 0.7070234722246362}, {
      3.5, -0.707190080334431, 0.7070234722246362}, {3.5, -0.8090908512602302,
       0.5876835835779286}, {3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9999999876629945, -0.0001570796320327716}, {
      3.25, -0.9999999876629945, -0.0001570796320327716}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.5, -0.9999999876629945, 0.00015707963203365978`}, {
      3.75, -0.9999999876629945, 0.00015707963203365978`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.5, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.3091066279673134, -0.9510273879056674}, {
      3.5, -0.3091066279673134, -0.9510273879056674}, {
      3.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.5, -0.3091066279673132, -0.9510273879056675}, {
      3.75, -0.3091066279673132, -0.9510273879056675}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.5, 0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.30895723712171647`, -0.9510759305282178}, {3.5, 
      0.30895723712171647`, -0.9510759305282178}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.5, 0.3089572371217167, -0.9510759305282178}, {3.75, 
      0.3089572371217167, -0.9510759305282178}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.5, 0.453941513411326, -0.8910314822731209}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.5, 0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.5, 0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.5, 0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.5, 0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.5, 0.951051662150225, -0.3090319334976474}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.9876871119312596, -0.15644222232149346`}, {3.5, 
      0.9876871119312596, -0.15644222232149346`}, {3.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.5, 0.9876871119312596, -0.1564422223214935}, {3.75, 
      0.9876871119312596, -0.1564422223214935}, {3.75, 
      1., -4.163336342344337*^-16}, {3.5, 1., -4.163336342344337*^-16}, {3.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.5, 1., -4.440892098500626*^-16}, {3.75, 
      1., -4.440892098500626*^-16}, {3.75, 0.9876871119312597, 
      0.15644222232149263`}, {3.5, 0.9876871119312597, 
      0.15644222232149263`}, {3.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.5, 0.9876871119312597, 0.1564422223214926}, {3.75, 
      0.9876871119312597, 0.1564422223214926}, {3.75, 0.9510516621502252, 
      0.30903193349764657`}, {3.5, 0.9510516621502252, 
      0.30903193349764657`}, {3.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{3.5, 0.9510516621502252, 0.30903193349764657`}, {3.75, 
      0.9510516621502252, 0.30903193349764657`}, {3.75, 0.8909958270419003, 
      0.4540114934601547}, {3.5, 0.8909958270419003, 0.4540114934601547}, {
      3.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.5, 0.8909958270419003, 0.4540114934601547}, {3.75, 
      0.8909958270419003, 0.4540114934601547}, {3.75, 0.808998528157412, 
      0.5878106680208697}, {3.5, 0.808998528157412, 0.5878106680208697}, {3.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.5, 0.8089985281574118, 0.58781066802087}, {3.75, 
      0.8089985281574118, 0.58781066802087}, {3.75, 0.7070790126229676, 
      0.70713454865968}, {3.5, 0.7070790126229676, 0.70713454865968}, {3.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.5, 0.7070790126229676, 0.70713454865968}, {3.75, 
      0.7070790126229676, 0.70713454865968}, {3.75, 0.5877471276121592, 
      0.8090446922041181}, {3.5, 0.5877471276121592, 0.8090446922041181}, {
      3.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.5, 0.5877471276121592, 0.8090446922041181}, {3.75, 
      0.5877471276121592, 0.8090446922041181}, {3.75, 0.45394151341132644`, 
      0.8910314822731207}, {3.5, 0.45394151341132644`, 0.8910314822731207}, {
      3.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.5, 0.45394151341132644`, 0.8910314822731207}, {3.75, 
      0.45394151341132644`, 0.8910314822731207}, {3.75, 0.3089572371217171, 
      0.9510759305282176}, {3.5, 0.3089572371217171, 0.9510759305282176}, {
      3.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.5, 0.3089572371217171, 0.9510759305282176}, {3.75, 
      0.3089572371217171, 0.9510759305282176}, {3.75, 0.15636464907469383`, 
      0.9876993958283805}, {3.5, 0.15636464907469383`, 0.9876993958283805}, {
      3.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.5, 0.15636464907469383`, 0.9876993958283805}, {3.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.75, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {3.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.75, -0.00007853981625862234, 0.9999999969157486}, {
      3.75, -0.156519794603278, 0.9876748219415881}, {3.5, -0.156519794603278,
       0.9876748219415881}, {3.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.5, -0.156519794603278, 0.9876748219415881}, {
      3.75, -0.156519794603278, 0.9876748219415881}, {
      3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.3091066279673126, 0.9510273879056678}, {3.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{3.5, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.707190080334431, 0.7070234722246362}, {3.5, -0.707190080334431,
       0.7070234722246362}, {3.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.5, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8090908512602302, 0.5876835835779286}, {3.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{3.5, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}, {
      3.75, -0.9999999876629945, -0.0001570796320327716}, {
      3.5, -0.9999999876629945, -0.0001570796320327716}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.75, -0.9999999876629945, 0.00015707963203365978`}, {
      4., -0.9999999876629945, 0.00015707963203365978`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.75, -0.987711673632875, -0.15628707486335794`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.75, -0.951100193039496, -0.3088825388399828}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.75, -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.75, -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.75, -0.7071900803344316, -0.7070234722246357}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.75, -0.5878742048036698, -0.8089523591203952}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.75, -0.45408147070841337`, -0.890960166314569}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      4., -0.3091066279673134, -0.9510273879056674}, {
      3.75, -0.3091066279673134, -0.9510273879056674}, {
      3.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.75, -0.3091066279673132, -0.9510273879056675}, {
      4., -0.3091066279673132, -0.9510273879056675}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.75, -0.15651979460327867`, -0.987674821941588}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.75, -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.75, 0.15636464907469316`, -0.9876993958283806}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {4., 
      0.30895723712171647`, -0.9510759305282178}, {3.75, 
      0.30895723712171647`, -0.9510759305282178}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.75, 0.3089572371217167, -0.9510759305282178}, {4., 
      0.3089572371217167, -0.9510759305282178}, {4., 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.75, 0.453941513411326, -0.8910314822731209}, {4., 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.75, 0.5877471276121589, -0.8090446922041185}, {4., 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.75, 0.7070790126229672, -0.7071345486596803}, {4., 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.75, 0.8089985281574115, -0.5878106680208703}, {4., 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.75, 0.8909958270419, -0.45401149346015546`}, {4., 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.75, 0.951051662150225, -0.3090319334976474}, {4., 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.9876871119312596, -0.15644222232149346`}, {3.75, 
      0.9876871119312596, -0.15644222232149346`}, {3.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.75, 0.9876871119312596, -0.1564422223214935}, {4., 
      0.9876871119312596, -0.1564422223214935}, {4., 
      1., -4.163336342344337*^-16}, {3.75, 1., -4.163336342344337*^-16}, {
      3.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.75, 1., -4.440892098500626*^-16}, {4., 
      1., -4.440892098500626*^-16}, {4., 0.9876871119312597, 
      0.15644222232149263`}, {3.75, 0.9876871119312597, 
      0.15644222232149263`}, {3.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.75, 0.9876871119312597, 0.1564422223214926}, {4., 
      0.9876871119312597, 0.1564422223214926}, {4., 0.9510516621502252, 
      0.30903193349764657`}, {3.75, 0.9510516621502252, 
      0.30903193349764657`}, {3.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{3.75, 0.9510516621502252, 0.30903193349764657`}, {4., 
      0.9510516621502252, 0.30903193349764657`}, {4., 0.8909958270419003, 
      0.4540114934601547}, {3.75, 0.8909958270419003, 0.4540114934601547}, {
      3.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.75, 0.8909958270419003, 0.4540114934601547}, {4., 
      0.8909958270419003, 0.4540114934601547}, {4., 0.808998528157412, 
      0.5878106680208697}, {3.75, 0.808998528157412, 0.5878106680208697}, {
      3.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.75, 0.8089985281574118, 0.58781066802087}, {4., 
      0.8089985281574118, 0.58781066802087}, {4., 0.7070790126229676, 
      0.70713454865968}, {3.75, 0.7070790126229676, 0.70713454865968}, {3.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.75, 0.7070790126229676, 0.70713454865968}, {4., 
      0.7070790126229676, 0.70713454865968}, {4., 0.5877471276121592, 
      0.8090446922041181}, {3.75, 0.5877471276121592, 0.8090446922041181}, {
      3.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.75, 0.5877471276121592, 0.8090446922041181}, {4., 
      0.5877471276121592, 0.8090446922041181}, {4., 0.45394151341132644`, 
      0.8910314822731207}, {3.75, 0.45394151341132644`, 0.8910314822731207}, {
      3.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.75, 0.45394151341132644`, 0.8910314822731207}, {4., 
      0.45394151341132644`, 0.8910314822731207}, {4., 0.3089572371217171, 
      0.9510759305282176}, {3.75, 0.3089572371217171, 0.9510759305282176}, {
      3.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.75, 0.3089572371217171, 0.9510759305282176}, {4., 
      0.3089572371217171, 0.9510759305282176}, {4., 0.15636464907469383`, 
      0.9876993958283805}, {3.75, 0.15636464907469383`, 0.9876993958283805}, {
      3.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.75, 0.15636464907469383`, 0.9876993958283805}, {4., 
      0.15636464907469383`, 0.9876993958283805}, {4., -0.00007853981625862234,
       0.9999999969157486}, {3.75, -0.00007853981625862234, 
      0.9999999969157486}, {3.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{3.75, -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.156519794603278, 0.9876748219415881}, {3.75, -0.156519794603278, 
      0.9876748219415881}, {3.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.75, -0.156519794603278, 0.9876748219415881}, {
      4., -0.156519794603278, 0.9876748219415881}, {4., -0.3091066279673126, 
      0.9510273879056678}, {3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{3.75, -0.3091066279673126, 0.9510273879056678}, {
      4., -0.3091066279673126, 0.9510273879056678}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.75, -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.75, -0.5878742048036691, 0.8089523591203958}, {
      4., -0.5878742048036691, 0.8089523591203958}, {4., -0.707190080334431, 
      0.7070234722246362}, {3.75, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.75, -0.707190080334431, 0.7070234722246362}, {
      4., -0.707190080334431, 0.7070234722246362}, {4., -0.8090908512602302, 
      0.5876835835779286}, {3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{3.75, -0.8090908512602302, 0.5876835835779286}, {
      4., -0.8090908512602302, 0.5876835835779286}, {4., -0.8910671320080111, 
      0.4538715305623583}, {3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.75, -0.8910671320080111, 0.4538715305623583}, {
      4., -0.8910671320080111, 0.4538715305623583}, {4., -0.9511001930394957, 
      0.3088825388399836}, {3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.75, -0.9511001930394957, 0.3088825388399836}, {
      4., -0.9511001930394957, 0.3088825388399836}, {4., -0.9877116736328749, 
      0.15628707486335883`}, {3.75, -0.9877116736328749, 
      0.15628707486335883`}, {3.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{3.75, -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9999999876629945, -0.0001570796320327716}, {
      3.75, -0.9999999876629945, -0.0001570796320327716}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4., -0.9999999876629945, 0.00015707963203365978`}, {
      4.25, -0.9999999876629945, 0.00015707963203365978`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      4., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4., -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      4., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4., -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      4., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4., -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4., -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      4., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4., -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      4., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4., -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      4., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4., -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.3091066279673134, -0.9510273879056674}, {
      4., -0.3091066279673134, -0.9510273879056674}, {
      4., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4., -0.3091066279673132, -0.9510273879056675}, {
      4.25, -0.3091066279673132, -0.9510273879056675}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      4., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4., -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4., -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {
      4., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4., 0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.30895723712171647`, -0.9510759305282178}, {4., 
      0.30895723712171647`, -0.9510759305282178}, {4., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4., 0.3089572371217167, -0.9510759305282178}, {4.25, 
      0.3089572371217167, -0.9510759305282178}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4., 0.453941513411326, -0.8910314822731209}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4., 0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4., 0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4., 0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4., 0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4., 0.951051662150225, -0.3090319334976474}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.9876871119312596, -0.15644222232149346`}, {4., 
      0.9876871119312596, -0.15644222232149346`}, {4., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4., 0.9876871119312596, -0.1564422223214935}, {4.25, 
      0.9876871119312596, -0.1564422223214935}, {4.25, 
      1., -4.163336342344337*^-16}, {4., 1., -4.163336342344337*^-16}, {4., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4., 1., -4.440892098500626*^-16}, {4.25, 
      1., -4.440892098500626*^-16}, {4.25, 0.9876871119312597, 
      0.15644222232149263`}, {4., 0.9876871119312597, 0.15644222232149263`}, {
      4., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4., 0.9876871119312597, 0.1564422223214926}, {4.25, 
      0.9876871119312597, 0.1564422223214926}, {4.25, 0.9510516621502252, 
      0.30903193349764657`}, {4., 0.9510516621502252, 0.30903193349764657`}, {
      4., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{4., 0.9510516621502252, 0.30903193349764657`}, {4.25, 
      0.9510516621502252, 0.30903193349764657`}, {4.25, 0.8909958270419003, 
      0.4540114934601547}, {4., 0.8909958270419003, 0.4540114934601547}, {4., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4., 0.8909958270419003, 0.4540114934601547}, {4.25, 
      0.8909958270419003, 0.4540114934601547}, {4.25, 0.808998528157412, 
      0.5878106680208697}, {4., 0.808998528157412, 0.5878106680208697}, {4., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4., 0.8089985281574118, 0.58781066802087}, {4.25, 
      0.8089985281574118, 0.58781066802087}, {4.25, 0.7070790126229676, 
      0.70713454865968}, {4., 0.7070790126229676, 0.70713454865968}, {4., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4., 0.7070790126229676, 0.70713454865968}, {4.25, 
      0.7070790126229676, 0.70713454865968}, {4.25, 0.5877471276121592, 
      0.8090446922041181}, {4., 0.5877471276121592, 0.8090446922041181}, {4., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4., 0.5877471276121592, 0.8090446922041181}, {4.25, 
      0.5877471276121592, 0.8090446922041181}, {4.25, 0.45394151341132644`, 
      0.8910314822731207}, {4., 0.45394151341132644`, 0.8910314822731207}, {
      4., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4., 0.45394151341132644`, 0.8910314822731207}, {4.25, 
      0.45394151341132644`, 0.8910314822731207}, {4.25, 0.3089572371217171, 
      0.9510759305282176}, {4., 0.3089572371217171, 0.9510759305282176}, {4., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4., 0.3089572371217171, 0.9510759305282176}, {4.25, 
      0.3089572371217171, 0.9510759305282176}, {4.25, 0.15636464907469383`, 
      0.9876993958283805}, {4., 0.15636464907469383`, 0.9876993958283805}, {
      4., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4., 0.15636464907469383`, 0.9876993958283805}, {4.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.00007853981625862234, 0.9999999969157486}, {4., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4., -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.156519794603278, 0.9876748219415881}, {4., -0.156519794603278, 
      0.9876748219415881}, {4., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4., -0.156519794603278, 0.9876748219415881}, {
      4.25, -0.156519794603278, 0.9876748219415881}, {
      4.25, -0.3091066279673126, 0.9510273879056678}, {
      4., -0.3091066279673126, 0.9510273879056678}, {4., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{4., -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4., -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4., -0.5878742048036691, 0.8089523591203958}, {
      4., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4., -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.707190080334431, 0.7070234722246362}, {4., -0.707190080334431, 
      0.7070234722246362}, {4., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4., -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.8090908512602302, 0.5876835835779286}, {
      4., -0.8090908512602302, 0.5876835835779286}, {4., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{4., -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4., -0.8910671320080111, 0.4538715305623583}, {4., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{4., -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4., -0.9511001930394957, 0.3088825388399836}, {4., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{4., -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4., -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9999999876629945, -0.0001570796320327716}, {
      4., -0.9999999876629945, -0.0001570796320327716}, {
      4., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.25, -0.9999999876629945, 0.00015707963203365978`}, {
      4.5, -0.9999999876629945, 0.00015707963203365978`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.25, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.3091066279673134, -0.9510273879056674}, {
      4.25, -0.3091066279673134, -0.9510273879056674}, {
      4.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.25, -0.3091066279673132, -0.9510273879056675}, {
      4.5, -0.3091066279673132, -0.9510273879056675}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.25, 0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.30895723712171647`, -0.9510759305282178}, {4.25, 
      0.30895723712171647`, -0.9510759305282178}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.25, 0.3089572371217167, -0.9510759305282178}, {4.5, 
      0.3089572371217167, -0.9510759305282178}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.25, 0.453941513411326, -0.8910314822731209}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.25, 0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.25, 0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.25, 0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.25, 0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.25, 0.951051662150225, -0.3090319334976474}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.9876871119312596, -0.15644222232149346`}, {4.25, 
      0.9876871119312596, -0.15644222232149346`}, {4.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.25, 0.9876871119312596, -0.1564422223214935}, {4.5, 
      0.9876871119312596, -0.1564422223214935}, {4.5, 
      1., -4.163336342344337*^-16}, {4.25, 1., -4.163336342344337*^-16}, {
      4.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.25, 1., -4.440892098500626*^-16}, {4.5, 
      1., -4.440892098500626*^-16}, {4.5, 0.9876871119312597, 
      0.15644222232149263`}, {4.25, 0.9876871119312597, 
      0.15644222232149263`}, {4.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.25, 0.9876871119312597, 0.1564422223214926}, {4.5, 
      0.9876871119312597, 0.1564422223214926}, {4.5, 0.9510516621502252, 
      0.30903193349764657`}, {4.25, 0.9510516621502252, 
      0.30903193349764657`}, {4.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{4.25, 0.9510516621502252, 0.30903193349764657`}, {4.5, 
      0.9510516621502252, 0.30903193349764657`}, {4.5, 0.8909958270419003, 
      0.4540114934601547}, {4.25, 0.8909958270419003, 0.4540114934601547}, {
      4.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.25, 0.8909958270419003, 0.4540114934601547}, {4.5, 
      0.8909958270419003, 0.4540114934601547}, {4.5, 0.808998528157412, 
      0.5878106680208697}, {4.25, 0.808998528157412, 0.5878106680208697}, {
      4.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.25, 0.8089985281574118, 0.58781066802087}, {4.5, 
      0.8089985281574118, 0.58781066802087}, {4.5, 0.7070790126229676, 
      0.70713454865968}, {4.25, 0.7070790126229676, 0.70713454865968}, {4.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.25, 0.7070790126229676, 0.70713454865968}, {4.5, 
      0.7070790126229676, 0.70713454865968}, {4.5, 0.5877471276121592, 
      0.8090446922041181}, {4.25, 0.5877471276121592, 0.8090446922041181}, {
      4.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.25, 0.5877471276121592, 0.8090446922041181}, {4.5, 
      0.5877471276121592, 0.8090446922041181}, {4.5, 0.45394151341132644`, 
      0.8910314822731207}, {4.25, 0.45394151341132644`, 0.8910314822731207}, {
      4.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.25, 0.45394151341132644`, 0.8910314822731207}, {4.5, 
      0.45394151341132644`, 0.8910314822731207}, {4.5, 0.3089572371217171, 
      0.9510759305282176}, {4.25, 0.3089572371217171, 0.9510759305282176}, {
      4.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.25, 0.3089572371217171, 0.9510759305282176}, {4.5, 
      0.3089572371217171, 0.9510759305282176}, {4.5, 0.15636464907469383`, 
      0.9876993958283805}, {4.25, 0.15636464907469383`, 0.9876993958283805}, {
      4.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.25, 0.15636464907469383`, 0.9876993958283805}, {4.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {4.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.156519794603278, 0.9876748219415881}, {4.25, -0.156519794603278,
       0.9876748219415881}, {4.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.25, -0.156519794603278, 0.9876748219415881}, {
      4.5, -0.156519794603278, 0.9876748219415881}, {4.5, -0.3091066279673126,
       0.9510273879056678}, {4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {4.5, -0.707190080334431,
       0.7070234722246362}, {4.25, -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.25, -0.707190080334431, 0.7070234722246362}, {
      4.5, -0.707190080334431, 0.7070234722246362}, {4.5, -0.8090908512602302,
       0.5876835835779286}, {4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9999999876629945, -0.0001570796320327716}, {
      4.25, -0.9999999876629945, -0.0001570796320327716}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.5, -0.9999999876629945, 0.00015707963203365978`}, {
      4.75, -0.9999999876629945, 0.00015707963203365978`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.5, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.3091066279673134, -0.9510273879056674}, {
      4.5, -0.3091066279673134, -0.9510273879056674}, {
      4.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.5, -0.3091066279673132, -0.9510273879056675}, {
      4.75, -0.3091066279673132, -0.9510273879056675}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.5, 0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.30895723712171647`, -0.9510759305282178}, {4.5, 
      0.30895723712171647`, -0.9510759305282178}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.5, 0.3089572371217167, -0.9510759305282178}, {4.75, 
      0.3089572371217167, -0.9510759305282178}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.5, 0.453941513411326, -0.8910314822731209}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.5, 0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.5, 0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.5, 0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.5, 0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.5, 0.951051662150225, -0.3090319334976474}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.9876871119312596, -0.15644222232149346`}, {4.5, 
      0.9876871119312596, -0.15644222232149346`}, {4.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.5, 0.9876871119312596, -0.1564422223214935}, {4.75, 
      0.9876871119312596, -0.1564422223214935}, {4.75, 
      1., -4.163336342344337*^-16}, {4.5, 1., -4.163336342344337*^-16}, {4.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.5, 1., -4.440892098500626*^-16}, {4.75, 
      1., -4.440892098500626*^-16}, {4.75, 0.9876871119312597, 
      0.15644222232149263`}, {4.5, 0.9876871119312597, 
      0.15644222232149263`}, {4.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.5, 0.9876871119312597, 0.1564422223214926}, {4.75, 
      0.9876871119312597, 0.1564422223214926}, {4.75, 0.9510516621502252, 
      0.30903193349764657`}, {4.5, 0.9510516621502252, 
      0.30903193349764657`}, {4.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{4.5, 0.9510516621502252, 0.30903193349764657`}, {4.75, 
      0.9510516621502252, 0.30903193349764657`}, {4.75, 0.8909958270419003, 
      0.4540114934601547}, {4.5, 0.8909958270419003, 0.4540114934601547}, {
      4.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.5, 0.8909958270419003, 0.4540114934601547}, {4.75, 
      0.8909958270419003, 0.4540114934601547}, {4.75, 0.808998528157412, 
      0.5878106680208697}, {4.5, 0.808998528157412, 0.5878106680208697}, {4.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.5, 0.8089985281574118, 0.58781066802087}, {4.75, 
      0.8089985281574118, 0.58781066802087}, {4.75, 0.7070790126229676, 
      0.70713454865968}, {4.5, 0.7070790126229676, 0.70713454865968}, {4.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.5, 0.7070790126229676, 0.70713454865968}, {4.75, 
      0.7070790126229676, 0.70713454865968}, {4.75, 0.5877471276121592, 
      0.8090446922041181}, {4.5, 0.5877471276121592, 0.8090446922041181}, {
      4.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.5, 0.5877471276121592, 0.8090446922041181}, {4.75, 
      0.5877471276121592, 0.8090446922041181}, {4.75, 0.45394151341132644`, 
      0.8910314822731207}, {4.5, 0.45394151341132644`, 0.8910314822731207}, {
      4.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.5, 0.45394151341132644`, 0.8910314822731207}, {4.75, 
      0.45394151341132644`, 0.8910314822731207}, {4.75, 0.3089572371217171, 
      0.9510759305282176}, {4.5, 0.3089572371217171, 0.9510759305282176}, {
      4.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.5, 0.3089572371217171, 0.9510759305282176}, {4.75, 
      0.3089572371217171, 0.9510759305282176}, {4.75, 0.15636464907469383`, 
      0.9876993958283805}, {4.5, 0.15636464907469383`, 0.9876993958283805}, {
      4.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.5, 0.15636464907469383`, 0.9876993958283805}, {4.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.75, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {4.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.75, -0.00007853981625862234, 0.9999999969157486}, {
      4.75, -0.156519794603278, 0.9876748219415881}, {4.5, -0.156519794603278,
       0.9876748219415881}, {4.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.5, -0.156519794603278, 0.9876748219415881}, {
      4.75, -0.156519794603278, 0.9876748219415881}, {
      4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.3091066279673126, 0.9510273879056678}, {4.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{4.5, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.707190080334431, 0.7070234722246362}, {4.5, -0.707190080334431,
       0.7070234722246362}, {4.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.5, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8090908512602302, 0.5876835835779286}, {4.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{4.5, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}, {
      4.75, -0.9999999876629945, -0.0001570796320327716}, {
      4.5, -0.9999999876629945, -0.0001570796320327716}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.75, -0.9999999876629945, 0.00015707963203365978`}, {
      5., -0.9999999876629945, 0.00015707963203365978`}, {
      5., -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.75, -0.987711673632875, -0.15628707486335794`}, {
      5., -0.987711673632875, -0.15628707486335794`}, {
      5., -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.75, -0.951100193039496, -0.3088825388399828}, {
      5., -0.951100193039496, -0.3088825388399828}, {
      5., -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.75, -0.8910671320080115, -0.4538715305623575}, {
      5., -0.8910671320080115, -0.4538715305623575}, {
      5., -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.75, -0.8090908512602306, -0.5876835835779278}, {
      5., -0.8090908512602306, -0.5876835835779278}, {
      5., -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.75, -0.7071900803344316, -0.7070234722246357}, {
      5., -0.7071900803344316, -0.7070234722246357}, {
      5., -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.75, -0.5878742048036698, -0.8089523591203952}, {
      5., -0.5878742048036698, -0.8089523591203952}, {
      5., -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.75, -0.45408147070841337`, -0.890960166314569}, {
      5., -0.45408147070841337`, -0.890960166314569}, {
      5., -0.3091066279673134, -0.9510273879056674}, {
      4.75, -0.3091066279673134, -0.9510273879056674}, {
      4.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.75, -0.3091066279673132, -0.9510273879056675}, {
      5., -0.3091066279673132, -0.9510273879056675}, {
      5., -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.75, -0.15651979460327867`, -0.987674821941588}, {
      5., -0.15651979460327867`, -0.987674821941588}, {
      5., -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.75, -0.00007853981625928847, -0.9999999969157486}, {
      5., -0.00007853981625928847, -0.9999999969157486}, {5., 
      0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.75, 0.15636464907469316`, -0.9876993958283806}, {5., 
      0.15636464907469316`, -0.9876993958283806}, {5., 
      0.30895723712171647`, -0.9510759305282178}, {4.75, 
      0.30895723712171647`, -0.9510759305282178}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.75, 0.3089572371217167, -0.9510759305282178}, {5., 
      0.3089572371217167, -0.9510759305282178}, {5., 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.75, 0.453941513411326, -0.8910314822731209}, {5., 
      0.453941513411326, -0.8910314822731209}, {5., 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.75, 0.5877471276121589, -0.8090446922041185}, {5., 
      0.5877471276121589, -0.8090446922041185}, {5., 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.75, 0.7070790126229672, -0.7071345486596803}, {5., 
      0.7070790126229672, -0.7071345486596803}, {5., 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.75, 0.8089985281574115, -0.5878106680208703}, {5., 
      0.8089985281574115, -0.5878106680208703}, {5., 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.75, 0.8909958270419, -0.45401149346015546`}, {5., 
      0.8909958270419, -0.45401149346015546`}, {5., 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.75, 0.951051662150225, -0.3090319334976474}, {5., 
      0.951051662150225, -0.3090319334976474}, {5., 
      0.9876871119312596, -0.15644222232149346`}, {4.75, 
      0.9876871119312596, -0.15644222232149346`}, {4.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.75, 0.9876871119312596, -0.1564422223214935}, {5., 
      0.9876871119312596, -0.1564422223214935}, {5., 
      1., -4.163336342344337*^-16}, {4.75, 1., -4.163336342344337*^-16}, {
      4.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.75, 1., -4.440892098500626*^-16}, {5., 
      1., -4.440892098500626*^-16}, {5., 0.9876871119312597, 
      0.15644222232149263`}, {4.75, 0.9876871119312597, 
      0.15644222232149263`}, {4.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.75, 0.9876871119312597, 0.1564422223214926}, {5., 
      0.9876871119312597, 0.1564422223214926}, {5., 0.9510516621502252, 
      0.30903193349764657`}, {4.75, 0.9510516621502252, 
      0.30903193349764657`}, {4.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{4.75, 0.9510516621502252, 0.30903193349764657`}, {5., 
      0.9510516621502252, 0.30903193349764657`}, {5., 0.8909958270419003, 
      0.4540114934601547}, {4.75, 0.8909958270419003, 0.4540114934601547}, {
      4.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.75, 0.8909958270419003, 0.4540114934601547}, {5., 
      0.8909958270419003, 0.4540114934601547}, {5., 0.808998528157412, 
      0.5878106680208697}, {4.75, 0.808998528157412, 0.5878106680208697}, {
      4.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.75, 0.8089985281574118, 0.58781066802087}, {5., 
      0.8089985281574118, 0.58781066802087}, {5., 0.7070790126229676, 
      0.70713454865968}, {4.75, 0.7070790126229676, 0.70713454865968}, {4.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.75, 0.7070790126229676, 0.70713454865968}, {5., 
      0.7070790126229676, 0.70713454865968}, {5., 0.5877471276121592, 
      0.8090446922041181}, {4.75, 0.5877471276121592, 0.8090446922041181}, {
      4.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.75, 0.5877471276121592, 0.8090446922041181}, {5., 
      0.5877471276121592, 0.8090446922041181}, {5., 0.45394151341132644`, 
      0.8910314822731207}, {4.75, 0.45394151341132644`, 0.8910314822731207}, {
      4.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.75, 0.45394151341132644`, 0.8910314822731207}, {5., 
      0.45394151341132644`, 0.8910314822731207}, {5., 0.3089572371217171, 
      0.9510759305282176}, {4.75, 0.3089572371217171, 0.9510759305282176}, {
      4.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.75, 0.3089572371217171, 0.9510759305282176}, {5., 
      0.3089572371217171, 0.9510759305282176}, {5., 0.15636464907469383`, 
      0.9876993958283805}, {4.75, 0.15636464907469383`, 0.9876993958283805}, {
      4.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.75, 0.15636464907469383`, 0.9876993958283805}, {5., 
      0.15636464907469383`, 0.9876993958283805}, {5., -0.00007853981625862234,
       0.9999999969157486}, {4.75, -0.00007853981625862234, 
      0.9999999969157486}, {4.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{4.75, -0.00007853981625862234, 0.9999999969157486}, {
      5., -0.00007853981625862234, 0.9999999969157486}, {
      5., -0.156519794603278, 0.9876748219415881}, {4.75, -0.156519794603278, 
      0.9876748219415881}, {4.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.75, -0.156519794603278, 0.9876748219415881}, {
      5., -0.156519794603278, 0.9876748219415881}, {5., -0.3091066279673126, 
      0.9510273879056678}, {4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{4.75, -0.3091066279673126, 0.9510273879056678}, {
      5., -0.3091066279673126, 0.9510273879056678}, {
      5., -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.75, -0.45408147070841254`, 0.8909601663145693}, {
      5., -0.45408147070841254`, 0.8909601663145693}, {
      5., -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.75, -0.5878742048036691, 0.8089523591203958}, {
      5., -0.5878742048036691, 0.8089523591203958}, {5., -0.707190080334431, 
      0.7070234722246362}, {4.75, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.75, -0.707190080334431, 0.7070234722246362}, {
      5., -0.707190080334431, 0.7070234722246362}, {5., -0.8090908512602302, 
      0.5876835835779286}, {4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{4.75, -0.8090908512602302, 0.5876835835779286}, {
      5., -0.8090908512602302, 0.5876835835779286}, {5., -0.8910671320080111, 
      0.4538715305623583}, {4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.75, -0.8910671320080111, 0.4538715305623583}, {
      5., -0.8910671320080111, 0.4538715305623583}, {5., -0.9511001930394957, 
      0.3088825388399836}, {4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.75, -0.9511001930394957, 0.3088825388399836}, {
      5., -0.9511001930394957, 0.3088825388399836}, {5., -0.9877116736328749, 
      0.15628707486335883`}, {4.75, -0.9877116736328749, 
      0.15628707486335883`}, {4.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{4.75, -0.9877116736328749, 0.15628707486335883`}, {
      5., -0.9877116736328749, 0.15628707486335883`}, {
      5., -0.9999999876629945, -0.0001570796320327716}, {
      4.75, -0.9999999876629945, -0.0001570796320327716}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5., -0.9999999876629945, -0.00015707963203365978`}, \
{-4.75, -0.9999999876629945, -0.00015707963203365978`}, {-4.5, \
-0.9999999876629945, -0.00015707963203365978`}, {-4.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-4., -0.9999999876629945, \
-0.00015707963203365978`}, {-3.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-3.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-3.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-3., -0.9999999876629945, \
-0.00015707963203365978`}, {-2.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-2.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-2.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-2., -0.9999999876629945, \
-0.00015707963203365978`}, {-1.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-1.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-1.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-1., -0.9999999876629945, \
-0.00015707963203365978`}, {-0.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-0.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-0.25, -0.9999999876629945, \
-0.00015707963203365978`}, {
        0., -0.9999999876629945, -0.00015707963203365978`}, {
        0.25, -0.9999999876629945, -0.00015707963203365978`}, {
        0.5, -0.9999999876629945, -0.00015707963203365978`}, {
        0.75, -0.9999999876629945, -0.00015707963203365978`}, {
        1., -0.9999999876629945, -0.00015707963203365978`}, {
        1.25, -0.9999999876629945, -0.00015707963203365978`}, {
        1.5, -0.9999999876629945, -0.00015707963203365978`}, {
        1.75, -0.9999999876629945, -0.00015707963203365978`}, {
        2., -0.9999999876629945, -0.00015707963203365978`}, {
        2.25, -0.9999999876629945, -0.00015707963203365978`}, {
        2.5, -0.9999999876629945, -0.00015707963203365978`}, {
        2.75, -0.9999999876629945, -0.00015707963203365978`}, {
        3., -0.9999999876629945, -0.00015707963203365978`}, {
        3.25, -0.9999999876629945, -0.00015707963203365978`}, {
        3.5, -0.9999999876629945, -0.00015707963203365978`}, {
        3.75, -0.9999999876629945, -0.00015707963203365978`}, {
        4., -0.9999999876629945, -0.00015707963203365978`}, {
        4.25, -0.9999999876629945, -0.00015707963203365978`}, {
        4.5, -0.9999999876629945, -0.00015707963203365978`}, {
        4.75, -0.9999999876629945, -0.00015707963203365978`}, {
        5., -0.9999999876629945, -0.00015707963203365978`}, {
        5, -0.9999999876629945, -0.00015707963203365978`}, {
        5, -0.987711673632875, 0.15628707486335794`}, {
        5, -0.951100193039496, 0.3088825388399828}, {
        5, -0.8910671320080115, 0.4538715305623575}, {
        5, -0.8090908512602306, 0.5876835835779278}, {
        5, -0.7071900803344316, 0.7070234722246357}, {
        5, -0.5878742048036698, 0.8089523591203952}, {
        5, -0.45408147070841337`, 0.890960166314569}, {
        5, -0.3091066279673132, 0.9510273879056675}, {
        5, -0.15651979460327867`, 0.987674821941588}, {
        5, -0.00007853981625928847, 0.9999999969157486}, {
        5, 0.15636464907469316`, 0.9876993958283806}, {
        5, 0.3089572371217167, 0.9510759305282178}, {
        5, 0.453941513411326, 0.8910314822731209}, {
        5, 0.5877471276121589, 0.8090446922041185}, {
        5, 0.7070790126229672, 0.7071345486596803}, {
        5, 0.8089985281574115, 0.5878106680208703}, {
        5, 0.8909958270419, 0.45401149346015546`}, {
        5, 0.951051662150225, 0.3090319334976474}, {
        5, 0.9876871119312596, 0.1564422223214935}, {
        5, 1., 4.440892098500626*^-16}, {
        5, 0.9876871119312597, -0.1564422223214926}, {
        5, 0.9510516621502252, -0.30903193349764657`}, {
        5, 0.8909958270419003, -0.4540114934601547}, {
        5, 0.8089985281574118, -0.58781066802087}, {
        5, 0.7070790126229676, -0.70713454865968}, {
        5, 0.5877471276121592, -0.8090446922041181}, {
        5, 0.45394151341132644`, -0.8910314822731207}, {
        5, 0.3089572371217171, -0.9510759305282176}, {
        5, 0.15636464907469383`, -0.9876993958283805}, {
        5, -0.00007853981625862234, -0.9999999969157486}, {
        5, -0.156519794603278, -0.9876748219415881}, {
        5, -0.3091066279673126, -0.9510273879056678}, {
        5, -0.45408147070841254`, -0.8909601663145693}, {
        5, -0.5878742048036691, -0.8089523591203958}, {
        5, -0.707190080334431, -0.7070234722246362}, {
        5, -0.8090908512602302, -0.5876835835779286}, {
        5, -0.8910671320080111, -0.4538715305623583}, {
        5, -0.9511001930394957, -0.3088825388399836}, {
        5, -0.9877116736328749, -0.15628707486335883`}, {
        5, -0.9999999876629945, 0.0001570796320327716}, {
        5., -0.9999999876629945, 0.00015707963203365978`}, {
        4.75, -0.9999999876629945, 0.00015707963203365978`}, {
        4.5, -0.9999999876629945, 0.00015707963203365978`}, {
        4.25, -0.9999999876629945, 0.00015707963203365978`}, {
        4., -0.9999999876629945, 0.00015707963203365978`}, {
        3.75, -0.9999999876629945, 0.00015707963203365978`}, {
        3.5, -0.9999999876629945, 0.00015707963203365978`}, {
        3.25, -0.9999999876629945, 0.00015707963203365978`}, {
        3., -0.9999999876629945, 0.00015707963203365978`}, {
        2.75, -0.9999999876629945, 0.00015707963203365978`}, {
        2.5, -0.9999999876629945, 0.00015707963203365978`}, {
        2.25, -0.9999999876629945, 0.00015707963203365978`}, {
        2., -0.9999999876629945, 0.00015707963203365978`}, {
        1.75, -0.9999999876629945, 0.00015707963203365978`}, {
        1.5, -0.9999999876629945, 0.00015707963203365978`}, {
        1.25, -0.9999999876629945, 0.00015707963203365978`}, {
        1., -0.9999999876629945, 0.00015707963203365978`}, {
        0.75, -0.9999999876629945, 0.00015707963203365978`}, {
        0.5, -0.9999999876629945, 0.00015707963203365978`}, {
        0.25, -0.9999999876629945, 0.00015707963203365978`}, {
        0., -0.9999999876629945, 
        0.00015707963203365978`}, {-0.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-0.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-0.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-1., -0.9999999876629945, 
        0.00015707963203365978`}, {-1.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-1.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-1.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-2., -0.9999999876629945, 
        0.00015707963203365978`}, {-2.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-2.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-2.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-3., -0.9999999876629945, 
        0.00015707963203365978`}, {-3.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-3.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-3.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-4., -0.9999999876629945, 
        0.00015707963203365978`}, {-4.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-4.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-4.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-5., -0.9999999876629945, 
        0.00015707963203365978`}, {-5, -0.9999999876629945, 
         0.00015707963203365978`}, {-5, -0.987711673632875, \
-0.15628707486335794`}, {-5, -0.951100193039496, -0.3088825388399828}, {-5, \
-0.8910671320080115, -0.4538715305623575}, {-5, -0.8090908512602306, \
-0.5876835835779278}, {-5, -0.7071900803344316, -0.7070234722246357}, {-5, \
-0.5878742048036698, -0.8089523591203952}, {-5, -0.45408147070841337`, \
-0.890960166314569}, {-5, -0.3091066279673132, -0.9510273879056675}, {-5, \
-0.15651979460327867`, -0.987674821941588}, {-5, -0.00007853981625928847, \
-0.9999999969157486}, {-5, 0.15636464907469316`, -0.9876993958283806}, {-5, 
         0.3089572371217167, -0.9510759305282178}, {-5, 
         0.453941513411326, -0.8910314822731209}, {-5, 
         0.5877471276121589, -0.8090446922041185}, {-5, 
         0.7070790126229672, -0.7071345486596803}, {-5, 
         0.8089985281574115, -0.5878106680208703}, {-5, 
         0.8909958270419, -0.45401149346015546`}, {-5, 
         0.951051662150225, -0.3090319334976474}, {-5, 
         0.9876871119312596, -0.1564422223214935}, {-5, 
         1., -4.440892098500626*^-16}, {-5, 0.9876871119312597, 
         0.1564422223214926}, {-5, 0.9510516621502252, 
         0.30903193349764657`}, {-5, 0.8909958270419003, 
         0.4540114934601547}, {-5, 0.8089985281574118, 0.58781066802087}, {-5,
          0.7070790126229676, 0.70713454865968}, {-5, 0.5877471276121592, 
         0.8090446922041181}, {-5, 0.45394151341132644`, 
         0.8910314822731207}, {-5, 0.3089572371217171, 
         0.9510759305282176}, {-5, 0.15636464907469383`, 
         0.9876993958283805}, {-5, -0.00007853981625862234, 
         0.9999999969157486}, {-5, -0.156519794603278, 
         0.9876748219415881}, {-5, -0.3091066279673126, 
         0.9510273879056678}, {-5, -0.45408147070841254`, 
         0.8909601663145693}, {-5, -0.5878742048036691, 
         0.8089523591203958}, {-5, -0.707190080334431, 
         0.7070234722246362}, {-5, -0.8090908512602302, 
         0.5876835835779286}, {-5, -0.8910671320080111, 
         0.4538715305623583}, {-5, -0.9511001930394957, 
         0.3088825388399836}, {-5, -0.9877116736328749, 
         0.15628707486335883`}, {-5, -0.9999999876629945, \
-0.0001570796320327716}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301541846837*^9, 3.6147093086843157`*^9, 
  3.614729164354694*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->
  "During evaluation of \
In[244]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAIBmIQDQEf7BlQwCh/lD/KH+WP8tH5AA5DZD4=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJyF1G1IU1EYB/Crq7BWFiIFgh+KPklG0dVlIx7p5Yu5qOxlHypMevGlXFJR
2YeBIyHQigqhrFwvUFIMB4WU1FPsShZrW9wPSXAJrzlYrM1EogVpV88J6t+H
LlzG4eye8z/P8+MsrvFsO5CtKEqV9U79ltRXZyYn01z4Ohbq7VhKectn+HZ0
WuNAd5YjS+NLe+Y8rPOkuNC8t6FP03ldc8zR5Uuy+9jCYudcgwcyqjfvU4Jt
/jNvXRGT73ytWeS6FecLwZ096a44nzt4+qIRNbmpNJI7aib42b5rTx/MN7jJ
Zx953pLkkmWtRYcGdP7xLf9nrDHFzsfeVe9zNH6yqX5NjpXDfnZI6+3I5/YC
98RUzrt7bfzSppHrSkPIac1nHFWXx/t1GlPVN6VWzvXeq4+q5xk0sbrl+HYr
p2fFkQV6xKTy6y+CweEEN37eXbTfH6cTAfvtQX+co7tuDm0ZTtDKk4e3uq2c
786XB2b7kqQPFpS15hrc3ecYsXlSFO4Z+1j8SufKG+3Kks40hcIVzZWzNFam
n1FS5PN7XhfzdF9+r4vvKSrX/yDWp7DcXxX7U4PMd0rko1qZf6PIT6o8X3bZ
9Pnoizz/uDg/tcn6bBb1IftM88/6UcXf9aW1sv7fRf2pX/bnqOgPtcn+eUT/
CPpL0H8CHwR+0BeBP8Yx/h/Xw/0wD+YFjwQeCTwSeCTwSOCRwCOBRwKPBB4J
PBJ4JPBI4JH+45HBI4NHBo8MHhk8Mnhk8MjgkcEjg0cGjwweGTz+c9/gfYT3
Fd5neN/hfYjjX+FtxtI=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJzt1N1L02EUB/DZKsyVlUiB4EXRlakULddacaR1U7novV1UmJSRmgs0KrsY
ONhVZtQQykx7gd5kOColjb6Gv5HFcqPfRRKMcOVgMTbtDUal/drzgHT+Ai82
GA/n9/C8nXP4rKhy7Dk+R6fT3dX+/8b1NZWp6ekkCl+HhvraViETZ+LZFOeV
znXtb9di74MsU5ZCVw7ndJ90JFAYubd1QFFpS1PI1OmKw96wrMSyMEzDKaMz
73MM+q4Lb20jEbozWbXcdiuKVt+BnmRnlC5Wn78cDkbgKBvJnYjEyH/0ev+j
xWGcdhnGXzTHyVzsLjoxrCL1M/9PqD5B1qfOde+zFTzbUbMxuz1JBv+Y0teW
j5YC+5R2T/Ic0eOlXqGdntohizb/w7T36ne/St+MxjdljgRZnNeeVC4Kk87c
3LjPFae6NaeWqNq9rDcGfb5PMar9cqjoWFeUznkNt0e1MXDw5tgu7bvxbN1u
ezBCwUvl3gXaug+jBWZ3bpjuD5jG9dq+as/XjyWvVKroaNGt1M5VA9ubKuYr
pEv/JuQ4uMkm5x+LeTyU6xWxHu/k/gGxP4Ly/LXifNTL+50R94ND3r9c3B9W
+b6pDen34bd8/6R4P7plfmwiPzDM+y9/WC3z2y/yi1KZ/18i/+iV9WkQ9YFb
1q9R1A8dsr4eUV8osv45ov4g2R/Voj/QKvunWPQPlsr+2iz6a6b/tqX7j1g/
ZuJMPKti5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOY
j2A+gvn4nPlIzEdiPhLzkZiPxHwk5iMxH4n5SMxHYj4S85GYj8R8JOYjMR+J
+UjMR2I+zvSf8BF/AfXe99M=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301541846837*^9, 3.6147093086843157`*^9, 
  3.6147291645236883`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"During evaluation of In[244]:="]
}, Open  ]],

Cell[TextData[{
 "The facets given by the default ",
 StyleBox["TriangleNet", "Input",
  FontSlant->"Plain"],
 " inscribe the tube-shaped surface."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell["\<\
 For most ray directions, this geometry still functions correctly.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[CellGroupData[{

Cell["\<\
trace = AnalyzeSystem[{
\tMove[PointOfRays[{30,30}],0,30],
\tMove[Resonate[tubemirror],6],
\tBoundary[15,5]},
\tPlotType->TopView];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"In[249]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 1.}, {2.6666666666666665`, 1.}, {4.333333333333333, 1.}, {
       6., 1.}, {7.666666666666666, 1.}, {9.333333333333332, 1.}, {11., 1.}, {
       11., 1.}, {9.333333333333334, 1.}, {7.666666666666667, 1.}, {6., 1.}, {
       4.333333333333334, 1.}, {2.666666666666668, 1.}, {1., 1.}, {1., 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6., -0.9999999876629945}, {6., -0.5000906872264895}, {6., 
       0.4999546543305255}, {6., 1.}, {6., 0.4999546543305259}, {
       6., -0.5000906872264888}, {6., -0.9999999876629945}, {
       6., -0.9999999876629945}, {6., -0.5000906872264895}, {6., 
       0.4999546543305255}, {6., 1.}, {6., 0.4999546543305259}, {
       6., -0.5000906872264888}, {6., -0.9999999876629945}, {
       6., -0.9999999876629945}}]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1., -0.9999999876629945}, {
      2.666666666666667, -0.9999999876629945}, {
      2.666666666666667, -0.5000906872264895}, {1., -0.5000906872264895}, {
      1., -0.9999999876629945}}], 
     PolygonBox[{{1., -0.5000906872264895}, {
      2.666666666666667, -0.5000906872264895}, {2.666666666666667, 
      0.4999546543305253}, {1., 0.4999546543305253}, {
      1., -0.5000906872264895}}], 
     PolygonBox[{{1., 0.4999546543305255}, {2.666666666666667, 
      0.4999546543305255}, {2.666666666666667, 1.}, {1., 1.}, {1., 
      0.4999546543305255}}], 
     PolygonBox[{{1., 1.}, {2.666666666666667, 1.}, {2.666666666666667, 
      0.4999546543305257}, {1., 0.4999546543305257}, {1., 1.}}], 
     PolygonBox[{{1., 0.4999546543305259}, {2.666666666666667, 
      0.4999546543305259}, {2.666666666666667, -0.5000906872264888}, {
      1., -0.5000906872264888}, {1., 0.4999546543305259}}], 
     PolygonBox[{{1., -0.5000906872264888}, {
      2.666666666666667, -0.5000906872264888}, {
      2.666666666666667, -0.9999999876629945}, {1., -0.9999999876629945}, {
      1., -0.5000906872264888}}], 
     PolygonBox[{{2.666666666666667, -0.9999999876629945}, {
      4.333333333333334, -0.9999999876629945}, {
      4.333333333333334, -0.5000906872264895}, {
      2.666666666666667, -0.5000906872264895}, {
      2.666666666666667, -0.9999999876629945}}], 
     PolygonBox[{{2.666666666666667, -0.5000906872264895}, {
      4.333333333333334, -0.5000906872264895}, {4.333333333333334, 
      0.4999546543305253}, {2.666666666666667, 0.4999546543305253}, {
      2.666666666666667, -0.5000906872264895}}], 
     PolygonBox[{{2.666666666666667, 0.4999546543305255}, {4.333333333333334, 
      0.4999546543305255}, {4.333333333333334, 1.}, {2.666666666666667, 1.}, {
      2.666666666666667, 0.4999546543305255}}], 
     PolygonBox[{{2.666666666666667, 1.}, {4.333333333333334, 1.}, {
      4.333333333333334, 0.4999546543305257}, {2.666666666666667, 
      0.4999546543305257}, {2.666666666666667, 1.}}], 
     PolygonBox[{{2.666666666666667, 0.4999546543305259}, {4.333333333333334, 
      0.4999546543305259}, {4.333333333333334, -0.5000906872264888}, {
      2.666666666666667, -0.5000906872264888}, {2.666666666666667, 
      0.4999546543305259}}], 
     PolygonBox[{{2.666666666666667, -0.5000906872264888}, {
      4.333333333333334, -0.5000906872264888}, {
      4.333333333333334, -0.9999999876629945}, {
      2.666666666666667, -0.9999999876629945}, {
      2.666666666666667, -0.5000906872264888}}], 
     PolygonBox[{{4.333333333333334, -0.9999999876629945}, {
      6., -0.9999999876629945}, {6., -0.5000906872264895}, {
      4.333333333333334, -0.5000906872264895}, {
      4.333333333333334, -0.9999999876629945}}], 
     PolygonBox[{{4.333333333333334, -0.5000906872264895}, {
      6., -0.5000906872264895}, {6., 0.4999546543305253}, {4.333333333333334, 
      0.4999546543305253}, {4.333333333333334, -0.5000906872264895}}], 
     PolygonBox[{{4.333333333333334, 0.4999546543305255}, {6., 
      0.4999546543305255}, {6., 1.}, {4.333333333333334, 1.}, {
      4.333333333333334, 0.4999546543305255}}], 
     PolygonBox[{{4.333333333333334, 1.}, {6., 1.}, {6., 
      0.4999546543305257}, {4.333333333333334, 0.4999546543305257}, {
      4.333333333333334, 1.}}], 
     PolygonBox[{{4.333333333333334, 0.4999546543305259}, {6., 
      0.4999546543305259}, {6., -0.5000906872264888}, {
      4.333333333333334, -0.5000906872264888}, {4.333333333333334, 
      0.4999546543305259}}], 
     PolygonBox[{{4.333333333333334, -0.5000906872264888}, {
      6., -0.5000906872264888}, {6., -0.9999999876629945}, {
      4.333333333333334, -0.9999999876629945}, {
      4.333333333333334, -0.5000906872264888}}], 
     PolygonBox[{{6., -0.9999999876629945}, {
      7.666666666666667, -0.9999999876629945}, {
      7.666666666666667, -0.5000906872264895}, {6., -0.5000906872264895}, {
      6., -0.9999999876629945}}], 
     PolygonBox[{{6., -0.5000906872264895}, {
      7.666666666666667, -0.5000906872264895}, {7.666666666666667, 
      0.4999546543305253}, {6., 0.4999546543305253}, {
      6., -0.5000906872264895}}], 
     PolygonBox[{{6., 0.4999546543305255}, {7.666666666666667, 
      0.4999546543305255}, {7.666666666666667, 1.}, {6., 1.}, {6., 
      0.4999546543305255}}], 
     PolygonBox[{{6., 1.}, {7.666666666666667, 1.}, {7.666666666666667, 
      0.4999546543305257}, {6., 0.4999546543305257}, {6., 1.}}], 
     PolygonBox[{{6., 0.4999546543305259}, {7.666666666666667, 
      0.4999546543305259}, {7.666666666666667, -0.5000906872264888}, {
      6., -0.5000906872264888}, {6., 0.4999546543305259}}], 
     PolygonBox[{{6., -0.5000906872264888}, {
      7.666666666666667, -0.5000906872264888}, {
      7.666666666666667, -0.9999999876629945}, {6., -0.9999999876629945}, {
      6., -0.5000906872264888}}], 
     PolygonBox[{{7.666666666666667, -0.9999999876629945}, {
      9.333333333333334, -0.9999999876629945}, {
      9.333333333333334, -0.5000906872264895}, {
      7.666666666666667, -0.5000906872264895}, {
      7.666666666666667, -0.9999999876629945}}], 
     PolygonBox[{{7.666666666666667, -0.5000906872264895}, {
      9.333333333333334, -0.5000906872264895}, {9.333333333333334, 
      0.4999546543305253}, {7.666666666666667, 0.4999546543305253}, {
      7.666666666666667, -0.5000906872264895}}], 
     PolygonBox[{{7.666666666666667, 0.4999546543305255}, {9.333333333333334, 
      0.4999546543305255}, {9.333333333333334, 1.}, {7.666666666666667, 1.}, {
      7.666666666666667, 0.4999546543305255}}], 
     PolygonBox[{{7.666666666666667, 1.}, {9.333333333333334, 1.}, {
      9.333333333333334, 0.4999546543305257}, {7.666666666666667, 
      0.4999546543305257}, {7.666666666666667, 1.}}], 
     PolygonBox[{{7.666666666666667, 0.4999546543305259}, {9.333333333333334, 
      0.4999546543305259}, {9.333333333333334, -0.5000906872264888}, {
      7.666666666666667, -0.5000906872264888}, {7.666666666666667, 
      0.4999546543305259}}], 
     PolygonBox[{{7.666666666666667, -0.5000906872264888}, {
      9.333333333333334, -0.5000906872264888}, {
      9.333333333333334, -0.9999999876629945}, {
      7.666666666666667, -0.9999999876629945}, {
      7.666666666666667, -0.5000906872264888}}], 
     PolygonBox[{{9.333333333333334, -0.9999999876629945}, {
      11., -0.9999999876629945}, {11., -0.5000906872264895}, {
      9.333333333333334, -0.5000906872264895}, {
      9.333333333333334, -0.9999999876629945}}], 
     PolygonBox[{{9.333333333333334, -0.5000906872264895}, {
      11., -0.5000906872264895}, {11., 0.4999546543305253}, {
      9.333333333333334, 0.4999546543305253}, {
      9.333333333333334, -0.5000906872264895}}], 
     PolygonBox[{{9.333333333333334, 0.4999546543305255}, {11., 
      0.4999546543305255}, {11., 1.}, {9.333333333333334, 1.}, {
      9.333333333333334, 0.4999546543305255}}], 
     PolygonBox[{{9.333333333333334, 1.}, {11., 1.}, {11., 
      0.4999546543305257}, {9.333333333333334, 0.4999546543305257}, {
      9.333333333333334, 1.}}], 
     PolygonBox[{{9.333333333333334, 0.4999546543305259}, {11., 
      0.4999546543305259}, {11., -0.5000906872264888}, {
      9.333333333333334, -0.5000906872264888}, {9.333333333333334, 
      0.4999546543305259}}], 
     PolygonBox[{{9.333333333333334, -0.5000906872264888}, {
      11., -0.5000906872264888}, {11., -0.9999999876629945}, {
      9.333333333333334, -0.9999999876629945}, {
      9.333333333333334, -0.5000906872264888}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7E2zEn7+//9+f1goCLA6oPIF4XyIegk4f/Uq
EJBD4yuhqVcjyG9uCNXfx/AAztf3LD3n+P++PYwPcyeMb4YmX4OmH5d9q9Dc
twrN/ej+C0Xzfwha+KCHHy4+qv8+2KP67wMGbYYmX4OmH2Y+AIhgsyg=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{15., 2.5}, {15., -2.5}, {15., -2.5}, {15., 2.5}, {15., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{15., -2.5}, {0., -2.5}, {0., -2.5}, {15., -2.5}, {
       15., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[NCache[{{0, Rational[-5, 2]}, {0, Rational[5, 2]}, {
         0, Rational[5, 2]}, {0, Rational[-5, 2]}, {0, Rational[-5, 2]}}, {{
         0, -2.5}, {0, 2.5}, {0, 2.5}, {0, -2.5}, {0, -2.5}}]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 2.5}, {15., 2.5}, {15., 2.5}, {0., 2.5}, {0., 2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{15., -2.5}, {15., 2.5}, {0., 2.5}, {0., -2.5}, {15., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{15., 2.5}, {15., -2.5}, {0., -2.5}, {0., 2.5}, {15., 2.5}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[{{0., 0.}, {0., 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {1.5266510880691841`, 0.8814124166553785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {2.7362564911230405`, 0.7091251267873577}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {1., 1.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {1.7320508075688767`, 1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {3.732050807568877, 1.0000000000000002`}}], 
      LineBox[{{0., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {1.5266510880691841`, 0.8814124166553785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {2.7362564911230405`, 0.7091251267873577}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1.5266510880691841`, 0.8814124166553785}, {
       4.579953264207552, -0.8814124166553785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{2.7362564911230405`, 0.7091251267873577}, {
       8.208769473369124, -0.709125126787358}}]}, 
     {Arrowheads[Small], ArrowBox[{{1., 1.}, {3., -1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1.7320508075688767`, 1.}, {5.196152422706631, -1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{3.732050807568877, 1.0000000000000002`}, {
       15., -2.0192378864668408`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{1.5266510880691841`, 0.8814124166553785}, {
       4.579953264207552, -0.8814124166553785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{2.7362564911230405`, 0.7091251267873577}, {
       8.208769473369122, -0.7091251267873577}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.579953264207552, -0.8814124166553785}, {7.633255440345918, 
       0.8814124166553778}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{8.208769473369124, -0.709125126787358}, {15., 
       1.0508824689416294`}}]}, 
     {Arrowheads[Small], ArrowBox[{{3., -1.}, {5., 1.0000000000000004`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{5.196152422706631, -1.}, {8.660254037844386, 1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.579953264207552, -0.8814124166553785}, {7.633255440345918, 
       0.8814124166553781}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{8.208769473369122, -0.7091251267873577}, {15., 
       1.05088246894163}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{7.633255440345918, 0.8814124166553778}, {
       10.686557616484283`, -0.8814124166553774}}]}, 
     {Arrowheads[Small], ArrowBox[{{5., 1.0000000000000004`}, {7., -1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{8.660254037844386, 1.}, {14.722431864335455`, -2.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{7.633255440345918, 0.8814124166553781}, {
       10.686557616484283`, -0.8814124166553774}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.686557616484283`, -0.8814124166553774}, {15., 
       1.608954704601361}}]}, 
     {Arrowheads[Small], ArrowBox[{{7., -1.}, {9., 1.0000000000000004`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{10.686557616484283`, -0.8814124166553774}, {15., 
       1.608954704601361}}]}, 
     {Arrowheads[Small], ArrowBox[{{9., 1.0000000000000004`}, {11., -1.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{11., -1.}, {14.5, 2.4999999999999996`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQjQ5M+n9t0Mz9YV8W/ut8u8kb+527ygpvPWZ1mBDV
pau+8Zk9RNUHOL3CJ+JF1bbfcH6omk6J7W1eB0YUdcSbn/56t8v9QCEHqPx+
Hh7Jq4+zFBwmQeT3Q0zhcIDat7/e0knvzgkROB9C6zkwHcw0TFNnOIBuHjfU
PKh9+/8ZWcqWdMg5FEDdA9Mfu+WAUtYFmPtFHJig/nmlb36RJ0gRZp89TH8R
mv4EqH4v29tVLfGqDjlQ+yHyMnD3lly8O+1RoS6Uz3IAu3o9hw7FC57u+35C
zVeCuwe7vBpaeOg6/AcDZgcAD3qgnw==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301542897724*^9, 3.614709309913315*^9, 
  3.614729165300785*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"During evaluation of In[249]:="]
}, Open  ]],

Cell["The trace works correctly.", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell["\<\
However, the trace can fail in some situations. Here is one such example\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{Move[SingleRay[],{0,0,-.9},{0,1,0}],
\tResonate[tubemirror],
\tMove[Boundary[10,2, GraphicDesign-> Off],-5]},
\tPlotPoints->100, SurfacePoints->Mesh, PlotType->FrontView];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"In[250]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.9999999878195741, 0.00015607963204577864`}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{-0.5000898212532002, -0.865973539248713}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.499955520381858, -0.8660510825809905}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.9999999999995, 9.999999999998333*^-7}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{0.49995378827869347`, 0.8660520824902989}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.500091553199278, 0.8659725390673388}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   PointBox[{-0.9999999875054149, -0.00015807963202138384`}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.9999999878195741, 0.00015607963204577864`}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.9999999878195741, 
    0.00015607963204577864`}, {-0.5000898212532002, -0.865973539248713}, \
{-0.5000898212532002, -0.865973539248713}, {-0.9999999878195741, 
    0.00015607963204577864`}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}, {-0.5000898212532002, -0.865973539248713}}], 
   LineBox[{{-0.5000898212532002, -0.865973539248713}, {
    0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}, {-0.5000898212532002, \
-0.865973539248713}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.499955520381858, -0.8660510825809905}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.499955520381858, -0.8660510825809905}, {0.9999999999995, 
    9.999999999998333*^-7}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.499955520381858, -0.8660510825809905}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.9999999999995, 9.999999999998333*^-7}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.9999999999995, 9.999999999998333*^-7}, {0.49995378827869347`, 
    0.8660520824902989}, {0.49995378827869347`, 0.8660520824902989}, {
    0.9999999999995, 9.999999999998333*^-7}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {0.49995378827869347`, 0.8660520824902989}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{0.49995378827869347`, 0.8660520824902989}, {-0.500091553199278, 
    0.8659725390673388}, {-0.500091553199278, 0.8659725390673388}, {
    0.49995378827869347`, 0.8660520824902989}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.500091553199278, 0.8659725390673388}, {-0.500091553199278, 
    0.8659725390673388}}], 
   LineBox[{{-0.500091553199278, 
    0.8659725390673388}, {-0.9999999875054149, -0.00015807963202138384`}, \
{-0.9999999875054149, -0.00015807963202138384`}, {-0.500091553199278, 
    0.8659725390673388}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAIBmIQDQEf7BlQwCh/lD/KH+WP8tH5AA5DZD4=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJyF1G1IU1EYB/Crq7BWFiIFgh+KPklG0dVlIx7p5Yu5qOxlHypMevGlXFJR
2YeBIyHQigqhrFwvUFIMB4WU1FPsShZrW9wPSXAJrzlYrM1EogVpV88J6t+H
LlzG4eye8z/P8+MsrvFsO5CtKEqV9U79ltRXZyYn01z4Ohbq7VhKectn+HZ0
WuNAd5YjS+NLe+Y8rPOkuNC8t6FP03ldc8zR5Uuy+9jCYudcgwcyqjfvU4Jt
/jNvXRGT73ytWeS6FecLwZ096a44nzt4+qIRNbmpNJI7aib42b5rTx/MN7jJ
Zx953pLkkmWtRYcGdP7xLf9nrDHFzsfeVe9zNH6yqX5NjpXDfnZI6+3I5/YC
98RUzrt7bfzSppHrSkPIac1nHFWXx/t1GlPVN6VWzvXeq4+q5xk0sbrl+HYr
p2fFkQV6xKTy6y+CweEEN37eXbTfH6cTAfvtQX+co7tuDm0ZTtDKk4e3uq2c
786XB2b7kqQPFpS15hrc3ecYsXlSFO4Z+1j8SufKG+3Kks40hcIVzZWzNFam
n1FS5PN7XhfzdF9+r4vvKSrX/yDWp7DcXxX7U4PMd0rko1qZf6PIT6o8X3bZ
9Pnoizz/uDg/tcn6bBb1IftM88/6UcXf9aW1sv7fRf2pX/bnqOgPtcn+eUT/
CPpL0H8CHwR+0BeBP8Yx/h/Xw/0wD+YFjwQeCTwSeCTwSOCRwCOBRwKPBB4J
PBJ4JPBI4JH+45HBI4NHBo8MHhk8Mnhk8MjgkcEjg0cGjwweGTz+c9/gfYT3
Fd5neN/hfYjjX+FtxtI=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJzt1N1L02EUB/DZKsyVlUiB4EXRlakULddacaR1U7novV1UmJSRmgs0KrsY
ONhVZtQQykx7gd5kOColjb6Gv5HFcqPfRRKMcOVgMTbtDUal/drzgHT+Ai82
GA/n9/C8nXP4rKhy7Dk+R6fT3dX+/8b1NZWp6ekkCl+HhvraViETZ+LZFOeV
znXtb9di74MsU5ZCVw7ndJ90JFAYubd1QFFpS1PI1OmKw96wrMSyMEzDKaMz
73MM+q4Lb20jEbozWbXcdiuKVt+BnmRnlC5Wn78cDkbgKBvJnYjEyH/0ev+j
xWGcdhnGXzTHyVzsLjoxrCL1M/9PqD5B1qfOde+zFTzbUbMxuz1JBv+Y0teW
j5YC+5R2T/Ic0eOlXqGdntohizb/w7T36ne/St+MxjdljgRZnNeeVC4Kk87c
3LjPFae6NaeWqNq9rDcGfb5PMar9cqjoWFeUznkNt0e1MXDw5tgu7bvxbN1u
ezBCwUvl3gXaug+jBWZ3bpjuD5jG9dq+as/XjyWvVKroaNGt1M5VA9ubKuYr
pEv/JuQ4uMkm5x+LeTyU6xWxHu/k/gGxP4Ly/LXifNTL+50R94ND3r9c3B9W
+b6pDen34bd8/6R4P7plfmwiPzDM+y9/WC3z2y/yi1KZ/18i/+iV9WkQ9YFb
1q9R1A8dsr4eUV8osv45ov4g2R/Voj/QKvunWPQPlsr+2iz6a6b/tqX7j1g/
ZuJMPKti5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOY
j2A+gvn4nPlIzEdiPhLzkZiPxHwk5iMxH4n5SMxHYj4S85GYj8R8JOYjMR+J
+UjMR2I+zvSf8BF/AfXe99M=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -0.9}, {1., -0.9}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[{1., -0.9}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301543605451*^9, 3.614709311102672*^9, 
  3.6147291662550077`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"During evaluation of In[250]:="]
}, Open  ]],

Cell["The trace has failed.", "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[TextData[{
 "The problem is solved when a second, bigger surface function is supplied to \
",
 StyleBox["SurfaceApproximation", "Input"],
 ". The resulting ",
 StyleBox["TriangleNet", "Input"],
 " facets now fully enclose the tube surface and the trace works correctly."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[CellGroupData[{

Cell[TextData[{
 "tubemirror2 = CustomMirror[Function[{#1,Cos[#2],Sin[#2]}],{10,2.0001*Pi}, \n\
\t",
 StyleBox["SurfaceApproximation -> {TriangleNet -> ", "Input"],
 "Function[{#1,1.15*Cos[#2],1.15*Sin[#2]}]",
 StyleBox["}", "Input"],
 "];\n\nShowSystem[tubemirror2, PlotPoints->100, SurfacePoints->Mesh];\n\n\
AnalyzeSystem[\n\t{Move[SingleRay[],{1,0,-.9},{0,1,0}],\n\t\
Resonate[tubemirror2]},\n\tPlotPoints->100, SurfacePoints->Mesh, \
PlotType->FrontView];"
}], "Input",
 CellChangeTimes->{{3.563457996365883*^9, 3.5634579985940104`*^9}},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"In[251]:="],

Cell[BoxData[
 Graphics3DBox[{
   Point3DBox[{-4.999999, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{-4.999999, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-4.999999, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{-4.999999, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{-4.999999, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-3.3333323333333333`, 0.5749488484391366, -0.995958744968139}],
    Point3DBox[{-4.999999, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-4.999999, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-4.999999, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 0.5749488484391366, -0.995958744968139}],
    Point3DBox[{-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-4.999999, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{-4.999999, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{-4.999999, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 0.9959598948638436}],
    Point3DBox[{-4.999999, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-4.999999, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-4.999999, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 0.9959598948638436}],
    Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-4.999999, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-4.999999, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-4.999999, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{-4.999999, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}],
    Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-3.3333323333333333`, 0.5749488484391366, -0.995958744968139}],
    Point3DBox[{-1.666665666666667, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}],
    Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-3.3333323333333333`, 0.5749488484391366, -0.995958744968139}],
    Point3DBox[{-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 0.9959598948638436}],
    Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 0.9959598948638436}],
    Point3DBox[{-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}],
    Point3DBox[{1.*^-6, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{1.*^-6, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}],
    Point3DBox[{-1.666665666666667, -0.5751032944411802, \
-0.9958695701360198}], 
   Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-1.666665666666667, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-1.666665666666667, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{-1.666665666666667, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{-1.666665666666667, -1.149999985631227, \
-0.0001817915768245914}], 
   Point3DBox[{1.*^-6, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{1.666667666666666, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.*^-6, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.*^-6, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{1.*^-6, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{1.666667666666666, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{3.3333343333333323`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{3.3333343333333323`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}],
    Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{1.666667666666666, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}],
    Point3DBox[{3.3333343333333323`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{3.3333343333333323`, -1.14999998599251, 
    0.00017949157685264542`}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{5.000001, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{5.000001, -1.14999998599251, 0.00017949157685264542`}], 
   Point3DBox[{5.000001, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{5.000001, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{5.000001, -0.5751032944411802, -0.9958695701360198}], 
   Point3DBox[{5.000001, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{5.000001, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{5.000001, 0.5749488484391366, -0.995958744968139}], 
   Point3DBox[{5.000001, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{5.000001, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{5.000001, 1.1499999999994248`, 1.1499999999998081`*^-6}], 
   Point3DBox[{5.000001, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}],
    Point3DBox[{5.000001, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{5.000001, 0.5749468565204975, 0.9959598948638436}], 
   Point3DBox[{5.000001, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}],
    Point3DBox[{3.3333343333333323`, -0.5751052861791697, 
    0.9958684199274396}], 
   Point3DBox[{
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{5.000001, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{5.000001, -0.5751052861791697, 0.9958684199274396}], 
   Point3DBox[{5.000001, -1.149999985631227, -0.0001817915768245914}], 
   Point3DBox[{
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}], 
   Line3DBox[{{-4.999999, -1.14999998599251, 
    0.00017949157685264542`}, {-4.999999, -0.5751032944411802, \
-0.9958695701360198}, {-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}, {-4.999999, -1.14999998599251, 
    0.00017949157685264542`}}], 
   Line3DBox[{{-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}, {-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}, {-4.999999, -0.5751032944411802, -0.9958695701360198}, \
{-3.3333323333333333`, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{-4.999999, -0.5751032944411802, -0.9958695701360198}, \
{-4.999999, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, \
-0.5751032944411802, -0.9958695701360198}, {-4.999999, -0.5751032944411802, \
-0.9958695701360198}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-4.999999, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, \
-0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{-4.999999, 0.5749488484391366, -0.995958744968139}, {-4.999999,
     1.1499999999994248`, 1.1499999999998081`*^-6}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-4.999999, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-4.999999, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{-4.999999, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-4.999999, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-4.999999, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-4.999999, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{-4.999999, 0.5749468565204975, 
    0.9959598948638436}, {-4.999999, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-4.999999, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-4.999999, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{-4.999999, -0.5751052861791697, 
    0.9958684199274396}, {-4.999999, -1.149999985631227, \
-0.0001817915768245914}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-4.999999, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}, {-4.999999, -1.149999985631227, \
-0.0001817915768245914}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}, {-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}, {-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}, {-3.3333323333333333`, -1.14999998599251, 
    0.00017949157685264542`}}], 
   Line3DBox[{{-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}, {-1.666665666666667, -0.5751032944411802, \
-0.9958695701360198}, {-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}, {-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5751032944411802, \
-0.9958695701360198}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, \
-0.5751032944411802, -0.9958695701360198}, {-3.3333323333333333`, \
-0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}, \
{-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, \
-0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}, {-3.3333323333333333`, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-3.3333323333333333`, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-3.3333323333333333`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}, {-3.3333323333333333`, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {-3.3333323333333333`, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, -1.149999985631227, \
-0.0001817915768245914}, {-3.3333323333333333`, -1.149999985631227, \
-0.0001817915768245914}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}, {-1.666665666666667, -0.5751032944411802, \
-0.9958695701360198}, {1.*^-6, -1.14999998599251, 
    0.00017949157685264542`}, {-1.666665666666667, -1.14999998599251, 
    0.00017949157685264542`}}], 
   Line3DBox[{{1.*^-6, -1.14999998599251, 0.00017949157685264542`}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}, {-1.666665666666667, \
-0.5751032944411802, -0.9958695701360198}, {1.*^-6, -1.14999998599251, 
    0.00017949157685264542`}}], 
   Line3DBox[{{-1.666665666666667, -0.5751032944411802, -0.9958695701360198}, \
{-1.666665666666667, 0.5749488484391366, -0.995958744968139}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}, {-1.666665666666667, \
-0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{1.*^-6, -0.5751032944411802, -0.9958695701360198}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}, {-1.666665666666667, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{1.*^-6, 0.5749488484391366, -0.995958744968139}, {1.*^-6, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {-1.666665666666667, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}, {1.*^-6, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {-1.666665666666667, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6,
     0.5749468565204975, 0.9959598948638436}, {-1.666665666666667, 
    0.5749468565204975, 0.9959598948638436}, {1.*^-6, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {1.*^-6, 0.5749468565204975, 
    0.9959598948638436}, {-1.666665666666667, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{1.*^-6, 0.5749468565204975, 0.9959598948638436}, {
    1.*^-6, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {1.*^-6, 0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, -1.149999985631227, \
-0.0001817915768245914}, {1.*^-6, -0.5751052861791697, 
    0.9958684199274396}, {-1.666665666666667, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{1.*^-6, -0.5751052861791697, 0.9958684199274396}, {
    1.*^-6, -1.149999985631227, -0.0001817915768245914}, {-1.666665666666667, \
-1.149999985631227, -0.0001817915768245914}, {1.*^-6, -0.5751052861791697, 
    0.9958684199274396}}], 
   Line3DBox[{{1.*^-6, -1.14999998599251, 0.00017949157685264542`}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, -1.14999998599251, 0.00017949157685264542`}, {
    1.*^-6, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{1.666667666666666, -1.14999998599251, 
    0.00017949157685264542`}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{1.*^-6, -0.5751032944411802, -0.9958695701360198}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    1.*^-6, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, 0.5749488484391366, -0.995958744968139}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{1.*^-6, 0.5749488484391366, -0.995958744968139}, {1.*^-6, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {1.666667666666666, 
    0.5749488484391366, -0.995958744968139}, {1.*^-6, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{1.666667666666666, 0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, 1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6,
     1.1499999999994248`, 1.1499999999998081`*^-6}, {1.666667666666666, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{1.*^-6, 1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6,
     0.5749468565204975, 0.9959598948638436}, {1.666667666666666, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {1.*^-6, 
    1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   Line3DBox[{{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.666667666666666, 0.5749468565204975, 
    0.9959598948638436}, {1.*^-6, 0.5749468565204975, 0.9959598948638436}, {
    1.666667666666666, 1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   Line3DBox[{{1.*^-6, 0.5749468565204975, 0.9959598948638436}, {
    1.*^-6, -0.5751052861791697, 0.9958684199274396}, {1.666667666666666, 
    0.5749468565204975, 0.9959598948638436}, {1.*^-6, 0.5749468565204975, 
    0.9959598948638436}}], 
   Line3DBox[{{1.666667666666666, 0.5749468565204975, 0.9959598948638436}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    1.*^-6, -0.5751052861791697, 0.9958684199274396}, {1.666667666666666, 
    0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{1.*^-6, -0.5751052861791697, 0.9958684199274396}, {
    1.*^-6, -1.149999985631227, -0.0001817915768245914}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    1.*^-6, -0.5751052861791697, 0.9958684199274396}}], 
   Line3DBox[{{1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}, {
    1.*^-6, -1.149999985631227, -0.0001817915768245914}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}}], 
   Line3DBox[{{1.666667666666666, -1.14999998599251, 
    0.00017949157685264542`}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, -1.14999998599251, 0.00017949157685264542`}, {
    1.666667666666666, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{3.3333343333333323`, -1.14999998599251, 
    0.00017949157685264542`}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{1.666667666666666, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, 0.5749488484391366, -0.995958744968139}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    1.666667666666666, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, 0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, 0.5749488484391366, -0.995958744968139}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{1.666667666666666, 0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, 1.1499999999994248`, 1.1499999999998081`*^-6}, {
    3.3333343333333323`, 0.5749488484391366, -0.995958744968139}, {
    1.666667666666666, 0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}, {
    3.3333343333333323`, 1.1499999999994248`, 1.1499999999998081`*^-6}, {
    1.666667666666666, 1.1499999999994248`, 1.1499999999998081`*^-6}, {
    3.3333343333333323`, 0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.666667666666666, 0.5749468565204975, 
    0.9959598948638436}, {3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.666667666666666, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {3.3333343333333323`, 0.5749468565204975, 
    0.9959598948638436}, {1.666667666666666, 0.5749468565204975, 
    0.9959598948638436}, {3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{1.666667666666666, 0.5749468565204975, 0.9959598948638436}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}, {
    1.666667666666666, 0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{1.666667666666666, -0.5751052861791697, 0.9958684199274396}, {
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}, {
    1.666667666666666, -0.5751052861791697, 0.9958684199274396}}], 
   Line3DBox[{{3.3333343333333323`, -0.5751052861791697, 
    0.9958684199274396}, {
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}, {
    1.666667666666666, -1.149999985631227, -0.0001817915768245914}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}}], 
   Line3DBox[{{3.3333343333333323`, -1.14999998599251, 
    0.00017949157685264542`}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    5.000001, -1.14999998599251, 0.00017949157685264542`}, {
    3.3333343333333323`, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{5.000001, -1.14999998599251, 0.00017949157685264542`}, {
    5.000001, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    5.000001, -1.14999998599251, 0.00017949157685264542`}}], 
   Line3DBox[{{
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, 0.5749488484391366, -0.995958744968139}, {
    5.000001, -0.5751032944411802, -0.9958695701360198}, {
    3.3333343333333323`, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{5.000001, -0.5751032944411802, -0.9958695701360198}, {5.000001,
     0.5749488484391366, -0.995958744968139}, {3.3333343333333323`, 
    0.5749488484391366, -0.995958744968139}, {
    5.000001, -0.5751032944411802, -0.9958695701360198}}], 
   Line3DBox[{{3.3333343333333323`, 0.5749488484391366, -0.995958744968139}, {
    3.3333343333333323`, 1.1499999999994248`, 1.1499999999998081`*^-6}, {
    5.000001, 0.5749488484391366, -0.995958744968139}, {3.3333343333333323`, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{5.000001, 0.5749488484391366, -0.995958744968139}, {5.000001, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {3.3333343333333323`, 
    1.1499999999994248`, 1.1499999999998081`*^-6}, {5.000001, 
    0.5749488484391366, -0.995958744968139}}], 
   Line3DBox[{{3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {3.3333343333333323`, 0.5749468565204975, 
    0.9959598948638436}, {5.000001, 1.1499999999994248`, 
    1.1499999999998081`*^-6}, {3.3333343333333323`, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{5.000001, 1.1499999999994248`, 1.1499999999998081`*^-6}, {
    5.000001, 0.5749468565204975, 0.9959598948638436}, {3.3333343333333323`, 
    0.5749468565204975, 0.9959598948638436}, {5.000001, 1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   Line3DBox[{{3.3333343333333323`, 0.5749468565204975, 0.9959598948638436}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}, {5.000001, 
    0.5749468565204975, 0.9959598948638436}, {3.3333343333333323`, 
    0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{5.000001, 0.5749468565204975, 0.9959598948638436}, {
    5.000001, -0.5751052861791697, 0.9958684199274396}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}, {5.000001, 
    0.5749468565204975, 0.9959598948638436}}], 
   Line3DBox[{{3.3333343333333323`, -0.5751052861791697, 
    0.9958684199274396}, {
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}, {
    5.000001, -0.5751052861791697, 0.9958684199274396}, {
    3.3333343333333323`, -0.5751052861791697, 0.9958684199274396}}], 
   Line3DBox[{{5.000001, -0.5751052861791697, 0.9958684199274396}, {
    5.000001, -1.149999985631227, -0.0001817915768245914}, {
    3.3333343333333323`, -1.149999985631227, -0.0001817915768245914}, {
    5.000001, -0.5751052861791697, 0.9958684199274396}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyV1UsKglAABdDHSyREwt8GWomtoXYQNG6JtYSW0LChAwcOHBREQuYZJIhw
EF+9z73b43l/iiGEw+tehc/VXN/Prg1fVw2v4CW8gG/gOTyDr+EpPIFHeICP
l2Uf4D28gz/gd/gNPo0zf7/F9+EPeAfv4QN8hIfdskd4Ak/ha3gGz+EbeAEv
4RW8hjd/ur6jcfU79b80D5o3zbPWReuodY9w7SvtQ+1b7XOdC50jnTud0/k4
0/t/5oZyRrmkHFPuKSeVq8ph5XYKVy+oR9Q76in1mnpQvameVS//+hMtS6j/

       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFlV1IU1EcwK+uwlpZiBQIPhQ9SUbRdNmII328LBeVfeyhQqVPLW9SUdnD
wJEQZEWFUFauDygphoNCSuoYm2SxtsV9SIIRXnOwWJuJRAvSVufsf7x/OOzA
Xn47nPv/+p2ztEHdcTBfUZTazM+kiFXRWJeenk7R0ncRf1/ncpLlRStnuXd1
Zbi3J8+aF6BZfm3fvKdH1SQt1R9t6g9owDe0Rqzd7gR1nlxcbpsfBT6UtriK
vsapyXP+gyOkA3/wo2GJ416MXvHt7k11x4BfPHTuajSs05bKUOG4Hgf+qv7W
yycLo7TFbR573ZYAXrGivezwkEZ//yz+E2lOArc9d635VBCgL7Y0rivI5JHl
5gsjgb7OYtpR4pz6l3eWP9xvom9MAeK40eS3zdifttZenxzUyITF8r5SFedv
dN18VrcgSqbWtp3a6RbxqKuOL9JCOqm+PeDzjYr4m7/tLTvgiZHTXvP9YY/I
N7zn7si20ThZfebYdmdY1Ofj5WrvXHeCaMMlVe2Fop49/dYxk5okwd6JL+Vv
Rf1r7nQoy7pSxB+0t9bMEf1ia5woaGX3a2w//P+Yn6+x84GHeTyfWTzAgzx+
C4sfeBPP9yzLF/gRXp/NrD7ALbye+VX/6wn8O6//JKs/8Eu8X1tZv4CbZ+sz
+wvcbpwH4Ov5/Pxi8wN8kM/bCTZv4rt8PlU2n8DRPANH8w8c+QIc+SXzETjy
l+bisnNk35XFKctLVgfkNXDktcjL6DVwm6SPyGvgyGvgyGvgyGvgyGvgyGvh
i9Fr4Mhr4Mhr4Mhr5HFOr6HvyGtx/xi9Bo68Bo68Bo68Bo68Bo68Bo68Fve2
0Wvgdsk9j7wGjrwW3zV6nfOdkr1rsndQ9m7K3lnZu4z5X3H4xtM=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5., -0.9999999876629945, 
      0.00015707963203365978`}, {-4.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.75, -0.987711673632875, \
-0.15628707486335794`}, {-5., -0.987711673632875, -0.15628707486335794`}, \
{-5., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-5., -0.987711673632875, -0.15628707486335794`}, {-4.75, \
-0.987711673632875, -0.15628707486335794`}, {-4.75, -0.951100193039496, \
-0.3088825388399828}, {-5., -0.951100193039496, -0.3088825388399828}, {-5., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-5., -0.951100193039496, -0.3088825388399828}, {-4.75, \
-0.951100193039496, -0.3088825388399828}, {-4.75, -0.8910671320080115, \
-0.4538715305623575}, {-5., -0.8910671320080115, -0.4538715305623575}, {-5., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-5., -0.8910671320080115, -0.4538715305623575}, {-4.75, \
-0.8910671320080115, -0.4538715305623575}, {-4.75, -0.8090908512602306, \
-0.5876835835779278}, {-5., -0.8090908512602306, -0.5876835835779278}, {-5., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-5., -0.8090908512602306, -0.5876835835779278}, {-4.75, \
-0.8090908512602306, -0.5876835835779278}, {-4.75, -0.7071900803344316, \
-0.7070234722246357}, {-5., -0.7071900803344316, -0.7070234722246357}, {-5., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-5., -0.7071900803344316, -0.7070234722246357}, {-4.75, \
-0.7071900803344316, -0.7070234722246357}, {-4.75, -0.5878742048036698, \
-0.8089523591203952}, {-5., -0.5878742048036698, -0.8089523591203952}, {-5., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-5., -0.5878742048036698, -0.8089523591203952}, {-4.75, \
-0.5878742048036698, -0.8089523591203952}, {-4.75, -0.45408147070841337`, \
-0.890960166314569}, {-5., -0.45408147070841337`, -0.890960166314569}, {-5., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-5., -0.45408147070841337`, -0.890960166314569}, {-4.75, \
-0.45408147070841337`, -0.890960166314569}, {-4.75, -0.3091066279673134, \
-0.9510273879056674}, {-5., -0.3091066279673134, -0.9510273879056674}, {-5., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-5., -0.3091066279673132, -0.9510273879056675}, {-4.75, \
-0.3091066279673132, -0.9510273879056675}, {-4.75, -0.15651979460327867`, \
-0.987674821941588}, {-5., -0.15651979460327867`, -0.987674821941588}, {-5., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-5., -0.15651979460327867`, -0.987674821941588}, {-4.75, \
-0.15651979460327867`, -0.987674821941588}, {-4.75, -0.00007853981625928847, \
-0.9999999969157486}, {-5., -0.00007853981625928847, -0.9999999969157486}, \
{-5., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-5., -0.00007853981625928847, -0.9999999969157486}, \
{-4.75, -0.00007853981625928847, -0.9999999969157486}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-5., 
      0.15636464907469316`, -0.9876993958283806}, {-5., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-5., 0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.30895723712171647`, -0.9510759305282178}, {-5., 
      0.30895723712171647`, -0.9510759305282178}, {-5., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-5., 0.3089572371217167, -0.9510759305282178}, {-4.75, 
      0.3089572371217167, -0.9510759305282178}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-5., 
      0.453941513411326, -0.8910314822731209}, {-5., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-5., 0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-5., 
      0.5877471276121589, -0.8090446922041185}, {-5., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-5., 0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-5., 
      0.7070790126229672, -0.7071345486596803}, {-5., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-5., 0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-5., 
      0.8089985281574115, -0.5878106680208703}, {-5., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-5., 0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-5., 
      0.8909958270419, -0.45401149346015546`}, {-5., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-5., 0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-5., 
      0.951051662150225, -0.3090319334976474}, {-5., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-5., 0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.9876871119312596, -0.15644222232149346`}, {-5., 
      0.9876871119312596, -0.15644222232149346`}, {-5., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-5., 0.9876871119312596, -0.1564422223214935}, {-4.75, 
      0.9876871119312596, -0.1564422223214935}, {-4.75, 
      1., -4.163336342344337*^-16}, {-5., 1., -4.163336342344337*^-16}, {-5., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-5., 1., -4.440892098500626*^-16}, {-4.75, 
      1., -4.440892098500626*^-16}, {-4.75, 0.9876871119312597, 
      0.15644222232149263`}, {-5., 0.9876871119312597, 
      0.15644222232149263`}, {-5., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-5., 0.9876871119312597, 0.1564422223214926}, {-4.75, 
      0.9876871119312597, 0.1564422223214926}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}, {-5., 0.9510516621502252, 
      0.30903193349764657`}, {-5., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-5., 0.9510516621502252, 0.30903193349764657`}, {-4.75, 
      0.9510516621502252, 0.30903193349764657`}, {-4.75, 0.8909958270419003, 
      0.4540114934601547}, {-5., 0.8909958270419003, 
      0.4540114934601547}, {-5., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-5., 0.8909958270419003, 0.4540114934601547}, {-4.75, 
      0.8909958270419003, 0.4540114934601547}, {-4.75, 0.808998528157412, 
      0.5878106680208697}, {-5., 0.808998528157412, 0.5878106680208697}, {-5.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-5., 0.8089985281574118, 0.58781066802087}, {-4.75, 
      0.8089985281574118, 0.58781066802087}, {-4.75, 0.7070790126229676, 
      0.70713454865968}, {-5., 0.7070790126229676, 0.70713454865968}, {-5., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-5., 0.7070790126229676, 0.70713454865968}, {-4.75, 
      0.7070790126229676, 0.70713454865968}, {-4.75, 0.5877471276121592, 
      0.8090446922041181}, {-5., 0.5877471276121592, 
      0.8090446922041181}, {-5., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-5., 0.5877471276121592, 0.8090446922041181}, {-4.75, 
      0.5877471276121592, 0.8090446922041181}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}, {-5., 0.45394151341132644`, 
      0.8910314822731207}, {-5., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-5., 0.45394151341132644`, 0.8910314822731207}, {-4.75, 
      0.45394151341132644`, 0.8910314822731207}, {-4.75, 0.3089572371217171, 
      0.9510759305282176}, {-5., 0.3089572371217171, 
      0.9510759305282176}, {-5., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-5., 0.3089572371217171, 0.9510759305282176}, {-4.75, 
      0.3089572371217171, 0.9510759305282176}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}, {-5., 0.15636464907469383`, 
      0.9876993958283805}, {-5., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-5., 0.15636464907469383`, 0.9876993958283805}, {-4.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-5., -0.00007853981625862234, 
      0.9999999969157486}, {-5., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-5., -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-5., -0.156519794603278, 
      0.9876748219415881}, {-5., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-5., -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-5., -0.3091066279673126, 
      0.9510273879056678}, {-5., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-5., -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-5., -0.45408147070841254`, 
      0.8909601663145693}, {-5., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-5., -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-5., -0.5878742048036691, 
      0.8089523591203958}, {-5., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-5., -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-5., -0.707190080334431, 
      0.7070234722246362}, {-5., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-5., -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-5., -0.8090908512602302, 
      0.5876835835779286}, {-5., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-5., -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-5., -0.8910671320080111, 
      0.4538715305623583}, {-5., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-5., -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-5., -0.9511001930394957, 
      0.3088825388399836}, {-5., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-5., -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-5., -0.9877116736328749, 
      0.15628707486335883`}, {-5., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-5., -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9999999876629945, \
-0.0001570796320327716}, {-5., -0.9999999876629945, -0.0001570796320327716}, \
{-5., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-4.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.5, -0.987711673632875, \
-0.15628707486335794`}, {-4.75, -0.987711673632875, -0.15628707486335794`}, \
{-4.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.75, -0.987711673632875, -0.15628707486335794`}, {-4.5, \
-0.987711673632875, -0.15628707486335794`}, {-4.5, -0.951100193039496, \
-0.3088825388399828}, {-4.75, -0.951100193039496, -0.3088825388399828}, \
{-4.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.75, -0.951100193039496, -0.3088825388399828}, {-4.5, \
-0.951100193039496, -0.3088825388399828}, {-4.5, -0.8910671320080115, \
-0.4538715305623575}, {-4.75, -0.8910671320080115, -0.4538715305623575}, \
{-4.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.75, -0.8910671320080115, -0.4538715305623575}, {-4.5, \
-0.8910671320080115, -0.4538715305623575}, {-4.5, -0.8090908512602306, \
-0.5876835835779278}, {-4.75, -0.8090908512602306, -0.5876835835779278}, \
{-4.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.75, -0.8090908512602306, -0.5876835835779278}, {-4.5, \
-0.8090908512602306, -0.5876835835779278}, {-4.5, -0.7071900803344316, \
-0.7070234722246357}, {-4.75, -0.7071900803344316, -0.7070234722246357}, \
{-4.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.75, -0.7071900803344316, -0.7070234722246357}, {-4.5, \
-0.7071900803344316, -0.7070234722246357}, {-4.5, -0.5878742048036698, \
-0.8089523591203952}, {-4.75, -0.5878742048036698, -0.8089523591203952}, \
{-4.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.75, -0.5878742048036698, -0.8089523591203952}, {-4.5, \
-0.5878742048036698, -0.8089523591203952}, {-4.5, -0.45408147070841337`, \
-0.890960166314569}, {-4.75, -0.45408147070841337`, -0.890960166314569}, \
{-4.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.75, -0.45408147070841337`, -0.890960166314569}, {-4.5, \
-0.45408147070841337`, -0.890960166314569}, {-4.5, -0.3091066279673134, \
-0.9510273879056674}, {-4.75, -0.3091066279673134, -0.9510273879056674}, \
{-4.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.75, -0.3091066279673132, -0.9510273879056675}, {-4.5, \
-0.3091066279673132, -0.9510273879056675}, {-4.5, -0.15651979460327867`, \
-0.987674821941588}, {-4.75, -0.15651979460327867`, -0.987674821941588}, \
{-4.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.75, -0.15651979460327867`, -0.987674821941588}, {-4.5, \
-0.15651979460327867`, -0.987674821941588}, {-4.5, -0.00007853981625928847, \
-0.9999999969157486}, {-4.75, -0.00007853981625928847, -0.9999999969157486}, \
{-4.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.75, -0.00007853981625928847, -0.9999999969157486}, \
{-4.5, -0.00007853981625928847, -0.9999999969157486}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.75, 0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.30895723712171647`, -0.9510759305282178}, {-4.75, 
      0.30895723712171647`, -0.9510759305282178}, {-4.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.75, 0.3089572371217167, -0.9510759305282178}, {-4.5, 
      0.3089572371217167, -0.9510759305282178}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.453941513411326, -0.8910314822731209}, {-4.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.75, 0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}, {-4.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.75, 0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}, {-4.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.75, 0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}, {-4.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.75, 0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}, {-4.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.75, 0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.951051662150225, -0.3090319334976474}, {-4.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.75, 0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.9876871119312596, -0.15644222232149346`}, {-4.75, 
      0.9876871119312596, -0.15644222232149346`}, {-4.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.75, 0.9876871119312596, -0.1564422223214935}, {-4.5, 
      0.9876871119312596, -0.1564422223214935}, {-4.5, 
      1., -4.163336342344337*^-16}, {-4.75, 
      1., -4.163336342344337*^-16}, {-4.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.75, 1., -4.440892098500626*^-16}, {-4.5, 
      1., -4.440892098500626*^-16}, {-4.5, 0.9876871119312597, 
      0.15644222232149263`}, {-4.75, 0.9876871119312597, 
      0.15644222232149263`}, {-4.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.75, 0.9876871119312597, 0.1564422223214926}, {-4.5, 
      0.9876871119312597, 0.1564422223214926}, {-4.5, 0.9510516621502252, 
      0.30903193349764657`}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}, {-4.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-4.75, 0.9510516621502252, 0.30903193349764657`}, {-4.5, 
      0.9510516621502252, 0.30903193349764657`}, {-4.5, 0.8909958270419003, 
      0.4540114934601547}, {-4.75, 0.8909958270419003, 
      0.4540114934601547}, {-4.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-4.75, 0.8909958270419003, 0.4540114934601547}, {-4.5, 
      0.8909958270419003, 0.4540114934601547}, {-4.5, 0.808998528157412, 
      0.5878106680208697}, {-4.75, 0.808998528157412, 
      0.5878106680208697}, {-4.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.75, 0.8089985281574118, 0.58781066802087}, {-4.5, 
      0.8089985281574118, 0.58781066802087}, {-4.5, 0.7070790126229676, 
      0.70713454865968}, {-4.75, 0.7070790126229676, 
      0.70713454865968}, {-4.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.75, 0.7070790126229676, 0.70713454865968}, {-4.5, 
      0.7070790126229676, 0.70713454865968}, {-4.5, 0.5877471276121592, 
      0.8090446922041181}, {-4.75, 0.5877471276121592, 
      0.8090446922041181}, {-4.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.75, 0.5877471276121592, 0.8090446922041181}, {-4.5, 
      0.5877471276121592, 0.8090446922041181}, {-4.5, 0.45394151341132644`, 
      0.8910314822731207}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}, {-4.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.75, 0.45394151341132644`, 0.8910314822731207}, {-4.5, 
      0.45394151341132644`, 0.8910314822731207}, {-4.5, 0.3089572371217171, 
      0.9510759305282176}, {-4.75, 0.3089572371217171, 
      0.9510759305282176}, {-4.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-4.75, 0.3089572371217171, 0.9510759305282176}, {-4.5, 
      0.3089572371217171, 0.9510759305282176}, {-4.5, 0.15636464907469383`, 
      0.9876993958283805}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}, {-4.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.75, 0.15636464907469383`, 0.9876993958283805}, {-4.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-4.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.75, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.75, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-4.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.75, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-4.75, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.75, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-4.75, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-4.75, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9999999876629945, \
-0.0001570796320327716}, {-4.75, -0.9999999876629945, \
-0.0001570796320327716}, {-4.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-4.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-4.25, -0.987711673632875, \
-0.15628707486335794`}, {-4.5, -0.987711673632875, -0.15628707486335794`}, \
{-4.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.5, -0.987711673632875, -0.15628707486335794`}, {-4.25, \
-0.987711673632875, -0.15628707486335794`}, {-4.25, -0.951100193039496, \
-0.3088825388399828}, {-4.5, -0.951100193039496, -0.3088825388399828}, {-4.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.5, -0.951100193039496, -0.3088825388399828}, {-4.25, \
-0.951100193039496, -0.3088825388399828}, {-4.25, -0.8910671320080115, \
-0.4538715305623575}, {-4.5, -0.8910671320080115, -0.4538715305623575}, \
{-4.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.5, -0.8910671320080115, -0.4538715305623575}, {-4.25, \
-0.8910671320080115, -0.4538715305623575}, {-4.25, -0.8090908512602306, \
-0.5876835835779278}, {-4.5, -0.8090908512602306, -0.5876835835779278}, \
{-4.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.5, -0.8090908512602306, -0.5876835835779278}, {-4.25, \
-0.8090908512602306, -0.5876835835779278}, {-4.25, -0.7071900803344316, \
-0.7070234722246357}, {-4.5, -0.7071900803344316, -0.7070234722246357}, \
{-4.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.5, -0.7071900803344316, -0.7070234722246357}, {-4.25, \
-0.7071900803344316, -0.7070234722246357}, {-4.25, -0.5878742048036698, \
-0.8089523591203952}, {-4.5, -0.5878742048036698, -0.8089523591203952}, \
{-4.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.5, -0.5878742048036698, -0.8089523591203952}, {-4.25, \
-0.5878742048036698, -0.8089523591203952}, {-4.25, -0.45408147070841337`, \
-0.890960166314569}, {-4.5, -0.45408147070841337`, -0.890960166314569}, \
{-4.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.5, -0.45408147070841337`, -0.890960166314569}, {-4.25, \
-0.45408147070841337`, -0.890960166314569}, {-4.25, -0.3091066279673134, \
-0.9510273879056674}, {-4.5, -0.3091066279673134, -0.9510273879056674}, \
{-4.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.5, -0.3091066279673132, -0.9510273879056675}, {-4.25, \
-0.3091066279673132, -0.9510273879056675}, {-4.25, -0.15651979460327867`, \
-0.987674821941588}, {-4.5, -0.15651979460327867`, -0.987674821941588}, \
{-4.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.5, -0.15651979460327867`, -0.987674821941588}, {-4.25, \
-0.15651979460327867`, -0.987674821941588}, {-4.25, -0.00007853981625928847, \
-0.9999999969157486}, {-4.5, -0.00007853981625928847, -0.9999999969157486}, \
{-4.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.5, -0.00007853981625928847, -0.9999999969157486}, \
{-4.25, -0.00007853981625928847, -0.9999999969157486}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}, {-4.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.5, 0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.30895723712171647`, -0.9510759305282178}, {-4.5, 
      0.30895723712171647`, -0.9510759305282178}, {-4.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.5, 0.3089572371217167, -0.9510759305282178}, {-4.25, 
      0.3089572371217167, -0.9510759305282178}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.453941513411326, -0.8910314822731209}, {-4.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.5, 0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}, {-4.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.5, 0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}, {-4.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.5, 0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}, {-4.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.5, 0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}, {-4.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.5, 0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.951051662150225, -0.3090319334976474}, {-4.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.5, 0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.9876871119312596, -0.15644222232149346`}, {-4.5, 
      0.9876871119312596, -0.15644222232149346`}, {-4.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.5, 0.9876871119312596, -0.1564422223214935}, {-4.25, 
      0.9876871119312596, -0.1564422223214935}, {-4.25, 
      1., -4.163336342344337*^-16}, {-4.5, 
      1., -4.163336342344337*^-16}, {-4.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.5, 1., -4.440892098500626*^-16}, {-4.25, 
      1., -4.440892098500626*^-16}, {-4.25, 0.9876871119312597, 
      0.15644222232149263`}, {-4.5, 0.9876871119312597, 
      0.15644222232149263`}, {-4.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.5, 0.9876871119312597, 0.1564422223214926}, {-4.25, 
      0.9876871119312597, 0.1564422223214926}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}, {-4.5, 0.9510516621502252, 
      0.30903193349764657`}, {-4.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-4.5, 0.9510516621502252, 0.30903193349764657`}, {-4.25, 
      0.9510516621502252, 0.30903193349764657`}, {-4.25, 0.8909958270419003, 
      0.4540114934601547}, {-4.5, 0.8909958270419003, 
      0.4540114934601547}, {-4.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-4.5, 0.8909958270419003, 0.4540114934601547}, {-4.25, 
      0.8909958270419003, 0.4540114934601547}, {-4.25, 0.808998528157412, 
      0.5878106680208697}, {-4.5, 0.808998528157412, 
      0.5878106680208697}, {-4.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.5, 0.8089985281574118, 0.58781066802087}, {-4.25, 
      0.8089985281574118, 0.58781066802087}, {-4.25, 0.7070790126229676, 
      0.70713454865968}, {-4.5, 0.7070790126229676, 0.70713454865968}, {-4.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.5, 0.7070790126229676, 0.70713454865968}, {-4.25, 
      0.7070790126229676, 0.70713454865968}, {-4.25, 0.5877471276121592, 
      0.8090446922041181}, {-4.5, 0.5877471276121592, 
      0.8090446922041181}, {-4.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.5, 0.5877471276121592, 0.8090446922041181}, {-4.25, 
      0.5877471276121592, 0.8090446922041181}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}, {-4.5, 0.45394151341132644`, 
      0.8910314822731207}, {-4.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.5, 0.45394151341132644`, 0.8910314822731207}, {-4.25, 
      0.45394151341132644`, 0.8910314822731207}, {-4.25, 0.3089572371217171, 
      0.9510759305282176}, {-4.5, 0.3089572371217171, 
      0.9510759305282176}, {-4.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-4.5, 0.3089572371217171, 0.9510759305282176}, {-4.25, 
      0.3089572371217171, 0.9510759305282176}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}, {-4.5, 0.15636464907469383`, 
      0.9876993958283805}, {-4.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.5, 0.15636464907469383`, 0.9876993958283805}, {-4.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-4.5, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.5, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.5, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-4.5, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.5, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-4.5, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.5, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-4.5, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-4.5, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.5, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9999999876629945, \
-0.0001570796320327716}, {-4.5, -0.9999999876629945, -0.0001570796320327716}, \
{-4.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-4.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-4., -0.9999999876629945, 
      0.00015707963203365978`}, {-4., -0.987711673632875, \
-0.15628707486335794`}, {-4.25, -0.987711673632875, -0.15628707486335794`}, \
{-4.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4.25, -0.987711673632875, -0.15628707486335794`}, {-4., \
-0.987711673632875, -0.15628707486335794`}, {-4., -0.951100193039496, \
-0.3088825388399828}, {-4.25, -0.951100193039496, -0.3088825388399828}, \
{-4.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4.25, -0.951100193039496, -0.3088825388399828}, {-4., \
-0.951100193039496, -0.3088825388399828}, {-4., -0.8910671320080115, \
-0.4538715305623575}, {-4.25, -0.8910671320080115, -0.4538715305623575}, \
{-4.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4.25, -0.8910671320080115, -0.4538715305623575}, {-4., \
-0.8910671320080115, -0.4538715305623575}, {-4., -0.8090908512602306, \
-0.5876835835779278}, {-4.25, -0.8090908512602306, -0.5876835835779278}, \
{-4.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4.25, -0.8090908512602306, -0.5876835835779278}, {-4., \
-0.8090908512602306, -0.5876835835779278}, {-4., -0.7071900803344316, \
-0.7070234722246357}, {-4.25, -0.7071900803344316, -0.7070234722246357}, \
{-4.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4.25, -0.7071900803344316, -0.7070234722246357}, {-4., \
-0.7071900803344316, -0.7070234722246357}, {-4., -0.5878742048036698, \
-0.8089523591203952}, {-4.25, -0.5878742048036698, -0.8089523591203952}, \
{-4.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4.25, -0.5878742048036698, -0.8089523591203952}, {-4., \
-0.5878742048036698, -0.8089523591203952}, {-4., -0.45408147070841337`, \
-0.890960166314569}, {-4.25, -0.45408147070841337`, -0.890960166314569}, \
{-4.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4.25, -0.45408147070841337`, -0.890960166314569}, {-4., \
-0.45408147070841337`, -0.890960166314569}, {-4., -0.3091066279673134, \
-0.9510273879056674}, {-4.25, -0.3091066279673134, -0.9510273879056674}, \
{-4.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4.25, -0.3091066279673132, -0.9510273879056675}, {-4., \
-0.3091066279673132, -0.9510273879056675}, {-4., -0.15651979460327867`, \
-0.987674821941588}, {-4.25, -0.15651979460327867`, -0.987674821941588}, \
{-4.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4.25, -0.15651979460327867`, -0.987674821941588}, {-4., \
-0.15651979460327867`, -0.987674821941588}, {-4., -0.00007853981625928847, \
-0.9999999969157486}, {-4.25, -0.00007853981625928847, -0.9999999969157486}, \
{-4.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4.25, -0.00007853981625928847, -0.9999999969157486}, \
{-4., -0.00007853981625928847, -0.9999999969157486}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}, {-4.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4.25, 0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.30895723712171647`, -0.9510759305282178}, {-4.25, 
      0.30895723712171647`, -0.9510759305282178}, {-4.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4.25, 0.3089572371217167, -0.9510759305282178}, {-4., 
      0.3089572371217167, -0.9510759305282178}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.453941513411326, -0.8910314822731209}, {-4.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4.25, 0.453941513411326, -0.8910314822731209}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}, {-4.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4.25, 0.5877471276121589, -0.8090446922041185}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}, {-4.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4.25, 0.7070790126229672, -0.7071345486596803}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}, {-4.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4.25, 0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}, {-4.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4.25, 0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.951051662150225, -0.3090319334976474}, {-4.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4.25, 0.951051662150225, -0.3090319334976474}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.9876871119312596, -0.15644222232149346`}, {-4.25, 
      0.9876871119312596, -0.15644222232149346`}, {-4.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4.25, 0.9876871119312596, -0.1564422223214935}, {-4., 
      0.9876871119312596, -0.1564422223214935}, {-4., 
      1., -4.163336342344337*^-16}, {-4.25, 
      1., -4.163336342344337*^-16}, {-4.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4.25, 1., -4.440892098500626*^-16}, {-4., 
      1., -4.440892098500626*^-16}, {-4., 0.9876871119312597, 
      0.15644222232149263`}, {-4.25, 0.9876871119312597, 
      0.15644222232149263`}, {-4.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4.25, 0.9876871119312597, 0.1564422223214926}, {-4., 
      0.9876871119312597, 0.1564422223214926}, {-4., 0.9510516621502252, 
      0.30903193349764657`}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}, {-4.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-4.25, 0.9510516621502252, 0.30903193349764657`}, {-4., 
      0.9510516621502252, 0.30903193349764657`}, {-4., 0.8909958270419003, 
      0.4540114934601547}, {-4.25, 0.8909958270419003, 
      0.4540114934601547}, {-4.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-4.25, 0.8909958270419003, 0.4540114934601547}, {-4., 
      0.8909958270419003, 0.4540114934601547}, {-4., 0.808998528157412, 
      0.5878106680208697}, {-4.25, 0.808998528157412, 
      0.5878106680208697}, {-4.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4.25, 0.8089985281574118, 0.58781066802087}, {-4., 
      0.8089985281574118, 0.58781066802087}, {-4., 0.7070790126229676, 
      0.70713454865968}, {-4.25, 0.7070790126229676, 
      0.70713454865968}, {-4.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4.25, 0.7070790126229676, 0.70713454865968}, {-4., 
      0.7070790126229676, 0.70713454865968}, {-4., 0.5877471276121592, 
      0.8090446922041181}, {-4.25, 0.5877471276121592, 
      0.8090446922041181}, {-4.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4.25, 0.5877471276121592, 0.8090446922041181}, {-4., 
      0.5877471276121592, 0.8090446922041181}, {-4., 0.45394151341132644`, 
      0.8910314822731207}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}, {-4.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4.25, 0.45394151341132644`, 0.8910314822731207}, {-4., 
      0.45394151341132644`, 0.8910314822731207}, {-4., 0.3089572371217171, 
      0.9510759305282176}, {-4.25, 0.3089572371217171, 
      0.9510759305282176}, {-4.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-4.25, 0.3089572371217171, 0.9510759305282176}, {-4., 
      0.3089572371217171, 0.9510759305282176}, {-4., 0.15636464907469383`, 
      0.9876993958283805}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}, {-4.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4.25, 0.15636464907469383`, 0.9876993958283805}, {-4., 
      0.15636464907469383`, 
      0.9876993958283805}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-4.25, -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4.25, -0.156519794603278, 
      0.9876748219415881}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4.25, -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-4.25, -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-4.25, -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-4.25, -0.707190080334431, 
      0.7070234722246362}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4.25, -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-4.25, -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-4.25, -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-4.25, -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9999999876629945, \
-0.0001570796320327716}, {-4.25, -0.9999999876629945, \
-0.0001570796320327716}, {-4.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-4., -0.9999999876629945, 
      0.00015707963203365978`}, {-3.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.75, -0.987711673632875, \
-0.15628707486335794`}, {-4., -0.987711673632875, -0.15628707486335794`}, \
{-4., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-4., -0.987711673632875, -0.15628707486335794`}, {-3.75, \
-0.987711673632875, -0.15628707486335794`}, {-3.75, -0.951100193039496, \
-0.3088825388399828}, {-4., -0.951100193039496, -0.3088825388399828}, {-4., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-4., -0.951100193039496, -0.3088825388399828}, {-3.75, \
-0.951100193039496, -0.3088825388399828}, {-3.75, -0.8910671320080115, \
-0.4538715305623575}, {-4., -0.8910671320080115, -0.4538715305623575}, {-4., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-4., -0.8910671320080115, -0.4538715305623575}, {-3.75, \
-0.8910671320080115, -0.4538715305623575}, {-3.75, -0.8090908512602306, \
-0.5876835835779278}, {-4., -0.8090908512602306, -0.5876835835779278}, {-4., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-4., -0.8090908512602306, -0.5876835835779278}, {-3.75, \
-0.8090908512602306, -0.5876835835779278}, {-3.75, -0.7071900803344316, \
-0.7070234722246357}, {-4., -0.7071900803344316, -0.7070234722246357}, {-4., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-4., -0.7071900803344316, -0.7070234722246357}, {-3.75, \
-0.7071900803344316, -0.7070234722246357}, {-3.75, -0.5878742048036698, \
-0.8089523591203952}, {-4., -0.5878742048036698, -0.8089523591203952}, {-4., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-4., -0.5878742048036698, -0.8089523591203952}, {-3.75, \
-0.5878742048036698, -0.8089523591203952}, {-3.75, -0.45408147070841337`, \
-0.890960166314569}, {-4., -0.45408147070841337`, -0.890960166314569}, {-4., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-4., -0.45408147070841337`, -0.890960166314569}, {-3.75, \
-0.45408147070841337`, -0.890960166314569}, {-3.75, -0.3091066279673134, \
-0.9510273879056674}, {-4., -0.3091066279673134, -0.9510273879056674}, {-4., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-4., -0.3091066279673132, -0.9510273879056675}, {-3.75, \
-0.3091066279673132, -0.9510273879056675}, {-3.75, -0.15651979460327867`, \
-0.987674821941588}, {-4., -0.15651979460327867`, -0.987674821941588}, {-4., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-4., -0.15651979460327867`, -0.987674821941588}, {-3.75, \
-0.15651979460327867`, -0.987674821941588}, {-3.75, -0.00007853981625928847, \
-0.9999999969157486}, {-4., -0.00007853981625928847, -0.9999999969157486}, \
{-4., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-4., -0.00007853981625928847, -0.9999999969157486}, \
{-3.75, -0.00007853981625928847, -0.9999999969157486}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-4., 
      0.15636464907469316`, -0.9876993958283806}, {-4., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-4., 0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.30895723712171647`, -0.9510759305282178}, {-4., 
      0.30895723712171647`, -0.9510759305282178}, {-4., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-4., 0.3089572371217167, -0.9510759305282178}, {-3.75, 
      0.3089572371217167, -0.9510759305282178}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.453941513411326, -0.8910314822731209}, {-4., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-4., 0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.5877471276121589, -0.8090446922041185}, {-4., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-4., 0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.7070790126229672, -0.7071345486596803}, {-4., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-4., 0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.8089985281574115, -0.5878106680208703}, {-4., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-4., 0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8909958270419, -0.45401149346015546`}, {-4., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-4., 0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.951051662150225, -0.3090319334976474}, {-4., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-4., 0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.9876871119312596, -0.15644222232149346`}, {-4., 
      0.9876871119312596, -0.15644222232149346`}, {-4., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-4., 0.9876871119312596, -0.1564422223214935}, {-3.75, 
      0.9876871119312596, -0.1564422223214935}, {-3.75, 
      1., -4.163336342344337*^-16}, {-4., 1., -4.163336342344337*^-16}, {-4., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-4., 1., -4.440892098500626*^-16}, {-3.75, 
      1., -4.440892098500626*^-16}, {-3.75, 0.9876871119312597, 
      0.15644222232149263`}, {-4., 0.9876871119312597, 
      0.15644222232149263`}, {-4., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-4., 0.9876871119312597, 0.1564422223214926}, {-3.75, 
      0.9876871119312597, 0.1564422223214926}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}, {-4., 0.9510516621502252, 
      0.30903193349764657`}, {-4., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-4., 0.9510516621502252, 0.30903193349764657`}, {-3.75, 
      0.9510516621502252, 0.30903193349764657`}, {-3.75, 0.8909958270419003, 
      0.4540114934601547}, {-4., 0.8909958270419003, 
      0.4540114934601547}, {-4., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-4., 0.8909958270419003, 0.4540114934601547}, {-3.75, 
      0.8909958270419003, 0.4540114934601547}, {-3.75, 0.808998528157412, 
      0.5878106680208697}, {-4., 0.808998528157412, 0.5878106680208697}, {-4.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-4., 0.8089985281574118, 0.58781066802087}, {-3.75, 
      0.8089985281574118, 0.58781066802087}, {-3.75, 0.7070790126229676, 
      0.70713454865968}, {-4., 0.7070790126229676, 0.70713454865968}, {-4., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-4., 0.7070790126229676, 0.70713454865968}, {-3.75, 
      0.7070790126229676, 0.70713454865968}, {-3.75, 0.5877471276121592, 
      0.8090446922041181}, {-4., 0.5877471276121592, 
      0.8090446922041181}, {-4., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-4., 0.5877471276121592, 0.8090446922041181}, {-3.75, 
      0.5877471276121592, 0.8090446922041181}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}, {-4., 0.45394151341132644`, 
      0.8910314822731207}, {-4., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-4., 0.45394151341132644`, 0.8910314822731207}, {-3.75, 
      0.45394151341132644`, 0.8910314822731207}, {-3.75, 0.3089572371217171, 
      0.9510759305282176}, {-4., 0.3089572371217171, 
      0.9510759305282176}, {-4., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-4., 0.3089572371217171, 0.9510759305282176}, {-3.75, 
      0.3089572371217171, 0.9510759305282176}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}, {-4., 0.15636464907469383`, 
      0.9876993958283805}, {-4., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-4., 0.15636464907469383`, 0.9876993958283805}, {-3.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-4., -0.00007853981625862234, 
      0.9999999969157486}, {-4., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-4., -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-4., -0.156519794603278, 
      0.9876748219415881}, {-4., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-4., -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.3091066279673126, 
      0.9510273879056678}, {-4., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-4., -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.45408147070841254`, 
      0.8909601663145693}, {-4., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-4., -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.5878742048036691, 
      0.8089523591203958}, {-4., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-4., -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-4., -0.707190080334431, 
      0.7070234722246362}, {-4., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-4., -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.8090908512602302, 
      0.5876835835779286}, {-4., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-4., -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8910671320080111, 
      0.4538715305623583}, {-4., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-4., -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.9511001930394957, 
      0.3088825388399836}, {-4., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-4., -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9877116736328749, 
      0.15628707486335883`}, {-4., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-4., -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9999999876629945, \
-0.0001570796320327716}, {-4., -0.9999999876629945, -0.0001570796320327716}, \
{-4., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-3.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.5, -0.987711673632875, \
-0.15628707486335794`}, {-3.75, -0.987711673632875, -0.15628707486335794`}, \
{-3.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.75, -0.987711673632875, -0.15628707486335794`}, {-3.5, \
-0.987711673632875, -0.15628707486335794`}, {-3.5, -0.951100193039496, \
-0.3088825388399828}, {-3.75, -0.951100193039496, -0.3088825388399828}, \
{-3.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.75, -0.951100193039496, -0.3088825388399828}, {-3.5, \
-0.951100193039496, -0.3088825388399828}, {-3.5, -0.8910671320080115, \
-0.4538715305623575}, {-3.75, -0.8910671320080115, -0.4538715305623575}, \
{-3.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.75, -0.8910671320080115, -0.4538715305623575}, {-3.5, \
-0.8910671320080115, -0.4538715305623575}, {-3.5, -0.8090908512602306, \
-0.5876835835779278}, {-3.75, -0.8090908512602306, -0.5876835835779278}, \
{-3.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.75, -0.8090908512602306, -0.5876835835779278}, {-3.5, \
-0.8090908512602306, -0.5876835835779278}, {-3.5, -0.7071900803344316, \
-0.7070234722246357}, {-3.75, -0.7071900803344316, -0.7070234722246357}, \
{-3.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.75, -0.7071900803344316, -0.7070234722246357}, {-3.5, \
-0.7071900803344316, -0.7070234722246357}, {-3.5, -0.5878742048036698, \
-0.8089523591203952}, {-3.75, -0.5878742048036698, -0.8089523591203952}, \
{-3.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.75, -0.5878742048036698, -0.8089523591203952}, {-3.5, \
-0.5878742048036698, -0.8089523591203952}, {-3.5, -0.45408147070841337`, \
-0.890960166314569}, {-3.75, -0.45408147070841337`, -0.890960166314569}, \
{-3.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.75, -0.45408147070841337`, -0.890960166314569}, {-3.5, \
-0.45408147070841337`, -0.890960166314569}, {-3.5, -0.3091066279673134, \
-0.9510273879056674}, {-3.75, -0.3091066279673134, -0.9510273879056674}, \
{-3.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.75, -0.3091066279673132, -0.9510273879056675}, {-3.5, \
-0.3091066279673132, -0.9510273879056675}, {-3.5, -0.15651979460327867`, \
-0.987674821941588}, {-3.75, -0.15651979460327867`, -0.987674821941588}, \
{-3.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.75, -0.15651979460327867`, -0.987674821941588}, {-3.5, \
-0.15651979460327867`, -0.987674821941588}, {-3.5, -0.00007853981625928847, \
-0.9999999969157486}, {-3.75, -0.00007853981625928847, -0.9999999969157486}, \
{-3.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.75, -0.00007853981625928847, -0.9999999969157486}, \
{-3.5, -0.00007853981625928847, -0.9999999969157486}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.75, 0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.30895723712171647`, -0.9510759305282178}, {-3.75, 
      0.30895723712171647`, -0.9510759305282178}, {-3.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.75, 0.3089572371217167, -0.9510759305282178}, {-3.5, 
      0.3089572371217167, -0.9510759305282178}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.453941513411326, -0.8910314822731209}, {-3.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.75, 0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}, {-3.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.75, 0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}, {-3.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.75, 0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}, {-3.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.75, 0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}, {-3.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.75, 0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.951051662150225, -0.3090319334976474}, {-3.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.75, 0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.9876871119312596, -0.15644222232149346`}, {-3.75, 
      0.9876871119312596, -0.15644222232149346`}, {-3.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.75, 0.9876871119312596, -0.1564422223214935}, {-3.5, 
      0.9876871119312596, -0.1564422223214935}, {-3.5, 
      1., -4.163336342344337*^-16}, {-3.75, 
      1., -4.163336342344337*^-16}, {-3.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.75, 1., -4.440892098500626*^-16}, {-3.5, 
      1., -4.440892098500626*^-16}, {-3.5, 0.9876871119312597, 
      0.15644222232149263`}, {-3.75, 0.9876871119312597, 
      0.15644222232149263`}, {-3.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.75, 0.9876871119312597, 0.1564422223214926}, {-3.5, 
      0.9876871119312597, 0.1564422223214926}, {-3.5, 0.9510516621502252, 
      0.30903193349764657`}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}, {-3.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-3.75, 0.9510516621502252, 0.30903193349764657`}, {-3.5, 
      0.9510516621502252, 0.30903193349764657`}, {-3.5, 0.8909958270419003, 
      0.4540114934601547}, {-3.75, 0.8909958270419003, 
      0.4540114934601547}, {-3.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-3.75, 0.8909958270419003, 0.4540114934601547}, {-3.5, 
      0.8909958270419003, 0.4540114934601547}, {-3.5, 0.808998528157412, 
      0.5878106680208697}, {-3.75, 0.808998528157412, 
      0.5878106680208697}, {-3.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.75, 0.8089985281574118, 0.58781066802087}, {-3.5, 
      0.8089985281574118, 0.58781066802087}, {-3.5, 0.7070790126229676, 
      0.70713454865968}, {-3.75, 0.7070790126229676, 
      0.70713454865968}, {-3.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.75, 0.7070790126229676, 0.70713454865968}, {-3.5, 
      0.7070790126229676, 0.70713454865968}, {-3.5, 0.5877471276121592, 
      0.8090446922041181}, {-3.75, 0.5877471276121592, 
      0.8090446922041181}, {-3.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.75, 0.5877471276121592, 0.8090446922041181}, {-3.5, 
      0.5877471276121592, 0.8090446922041181}, {-3.5, 0.45394151341132644`, 
      0.8910314822731207}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}, {-3.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.75, 0.45394151341132644`, 0.8910314822731207}, {-3.5, 
      0.45394151341132644`, 0.8910314822731207}, {-3.5, 0.3089572371217171, 
      0.9510759305282176}, {-3.75, 0.3089572371217171, 
      0.9510759305282176}, {-3.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-3.75, 0.3089572371217171, 0.9510759305282176}, {-3.5, 
      0.3089572371217171, 0.9510759305282176}, {-3.5, 0.15636464907469383`, 
      0.9876993958283805}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}, {-3.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.75, 0.15636464907469383`, 0.9876993958283805}, {-3.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-3.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.75, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.75, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-3.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.75, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-3.75, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.75, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-3.75, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-3.75, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9999999876629945, \
-0.0001570796320327716}, {-3.75, -0.9999999876629945, \
-0.0001570796320327716}, {-3.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-3.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-3.25, -0.987711673632875, \
-0.15628707486335794`}, {-3.5, -0.987711673632875, -0.15628707486335794`}, \
{-3.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.5, -0.987711673632875, -0.15628707486335794`}, {-3.25, \
-0.987711673632875, -0.15628707486335794`}, {-3.25, -0.951100193039496, \
-0.3088825388399828}, {-3.5, -0.951100193039496, -0.3088825388399828}, {-3.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.5, -0.951100193039496, -0.3088825388399828}, {-3.25, \
-0.951100193039496, -0.3088825388399828}, {-3.25, -0.8910671320080115, \
-0.4538715305623575}, {-3.5, -0.8910671320080115, -0.4538715305623575}, \
{-3.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.5, -0.8910671320080115, -0.4538715305623575}, {-3.25, \
-0.8910671320080115, -0.4538715305623575}, {-3.25, -0.8090908512602306, \
-0.5876835835779278}, {-3.5, -0.8090908512602306, -0.5876835835779278}, \
{-3.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.5, -0.8090908512602306, -0.5876835835779278}, {-3.25, \
-0.8090908512602306, -0.5876835835779278}, {-3.25, -0.7071900803344316, \
-0.7070234722246357}, {-3.5, -0.7071900803344316, -0.7070234722246357}, \
{-3.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.5, -0.7071900803344316, -0.7070234722246357}, {-3.25, \
-0.7071900803344316, -0.7070234722246357}, {-3.25, -0.5878742048036698, \
-0.8089523591203952}, {-3.5, -0.5878742048036698, -0.8089523591203952}, \
{-3.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.5, -0.5878742048036698, -0.8089523591203952}, {-3.25, \
-0.5878742048036698, -0.8089523591203952}, {-3.25, -0.45408147070841337`, \
-0.890960166314569}, {-3.5, -0.45408147070841337`, -0.890960166314569}, \
{-3.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.5, -0.45408147070841337`, -0.890960166314569}, {-3.25, \
-0.45408147070841337`, -0.890960166314569}, {-3.25, -0.3091066279673134, \
-0.9510273879056674}, {-3.5, -0.3091066279673134, -0.9510273879056674}, \
{-3.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.5, -0.3091066279673132, -0.9510273879056675}, {-3.25, \
-0.3091066279673132, -0.9510273879056675}, {-3.25, -0.15651979460327867`, \
-0.987674821941588}, {-3.5, -0.15651979460327867`, -0.987674821941588}, \
{-3.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.5, -0.15651979460327867`, -0.987674821941588}, {-3.25, \
-0.15651979460327867`, -0.987674821941588}, {-3.25, -0.00007853981625928847, \
-0.9999999969157486}, {-3.5, -0.00007853981625928847, -0.9999999969157486}, \
{-3.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.5, -0.00007853981625928847, -0.9999999969157486}, \
{-3.25, -0.00007853981625928847, -0.9999999969157486}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}, {-3.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.5, 0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.30895723712171647`, -0.9510759305282178}, {-3.5, 
      0.30895723712171647`, -0.9510759305282178}, {-3.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.5, 0.3089572371217167, -0.9510759305282178}, {-3.25, 
      0.3089572371217167, -0.9510759305282178}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.453941513411326, -0.8910314822731209}, {-3.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.5, 0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}, {-3.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.5, 0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}, {-3.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.5, 0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}, {-3.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.5, 0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}, {-3.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.5, 0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.951051662150225, -0.3090319334976474}, {-3.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.5, 0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.9876871119312596, -0.15644222232149346`}, {-3.5, 
      0.9876871119312596, -0.15644222232149346`}, {-3.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.5, 0.9876871119312596, -0.1564422223214935}, {-3.25, 
      0.9876871119312596, -0.1564422223214935}, {-3.25, 
      1., -4.163336342344337*^-16}, {-3.5, 
      1., -4.163336342344337*^-16}, {-3.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.5, 1., -4.440892098500626*^-16}, {-3.25, 
      1., -4.440892098500626*^-16}, {-3.25, 0.9876871119312597, 
      0.15644222232149263`}, {-3.5, 0.9876871119312597, 
      0.15644222232149263`}, {-3.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.5, 0.9876871119312597, 0.1564422223214926}, {-3.25, 
      0.9876871119312597, 0.1564422223214926}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}, {-3.5, 0.9510516621502252, 
      0.30903193349764657`}, {-3.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-3.5, 0.9510516621502252, 0.30903193349764657`}, {-3.25, 
      0.9510516621502252, 0.30903193349764657`}, {-3.25, 0.8909958270419003, 
      0.4540114934601547}, {-3.5, 0.8909958270419003, 
      0.4540114934601547}, {-3.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-3.5, 0.8909958270419003, 0.4540114934601547}, {-3.25, 
      0.8909958270419003, 0.4540114934601547}, {-3.25, 0.808998528157412, 
      0.5878106680208697}, {-3.5, 0.808998528157412, 
      0.5878106680208697}, {-3.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.5, 0.8089985281574118, 0.58781066802087}, {-3.25, 
      0.8089985281574118, 0.58781066802087}, {-3.25, 0.7070790126229676, 
      0.70713454865968}, {-3.5, 0.7070790126229676, 0.70713454865968}, {-3.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.5, 0.7070790126229676, 0.70713454865968}, {-3.25, 
      0.7070790126229676, 0.70713454865968}, {-3.25, 0.5877471276121592, 
      0.8090446922041181}, {-3.5, 0.5877471276121592, 
      0.8090446922041181}, {-3.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.5, 0.5877471276121592, 0.8090446922041181}, {-3.25, 
      0.5877471276121592, 0.8090446922041181}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}, {-3.5, 0.45394151341132644`, 
      0.8910314822731207}, {-3.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.5, 0.45394151341132644`, 0.8910314822731207}, {-3.25, 
      0.45394151341132644`, 0.8910314822731207}, {-3.25, 0.3089572371217171, 
      0.9510759305282176}, {-3.5, 0.3089572371217171, 
      0.9510759305282176}, {-3.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-3.5, 0.3089572371217171, 0.9510759305282176}, {-3.25, 
      0.3089572371217171, 0.9510759305282176}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}, {-3.5, 0.15636464907469383`, 
      0.9876993958283805}, {-3.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.5, 0.15636464907469383`, 0.9876993958283805}, {-3.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-3.5, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.5, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.5, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-3.5, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.5, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-3.5, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.5, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-3.5, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-3.5, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.5, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9999999876629945, \
-0.0001570796320327716}, {-3.5, -0.9999999876629945, -0.0001570796320327716}, \
{-3.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-3.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-3., -0.9999999876629945, 
      0.00015707963203365978`}, {-3., -0.987711673632875, \
-0.15628707486335794`}, {-3.25, -0.987711673632875, -0.15628707486335794`}, \
{-3.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3.25, -0.987711673632875, -0.15628707486335794`}, {-3., \
-0.987711673632875, -0.15628707486335794`}, {-3., -0.951100193039496, \
-0.3088825388399828}, {-3.25, -0.951100193039496, -0.3088825388399828}, \
{-3.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3.25, -0.951100193039496, -0.3088825388399828}, {-3., \
-0.951100193039496, -0.3088825388399828}, {-3., -0.8910671320080115, \
-0.4538715305623575}, {-3.25, -0.8910671320080115, -0.4538715305623575}, \
{-3.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3.25, -0.8910671320080115, -0.4538715305623575}, {-3., \
-0.8910671320080115, -0.4538715305623575}, {-3., -0.8090908512602306, \
-0.5876835835779278}, {-3.25, -0.8090908512602306, -0.5876835835779278}, \
{-3.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3.25, -0.8090908512602306, -0.5876835835779278}, {-3., \
-0.8090908512602306, -0.5876835835779278}, {-3., -0.7071900803344316, \
-0.7070234722246357}, {-3.25, -0.7071900803344316, -0.7070234722246357}, \
{-3.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3.25, -0.7071900803344316, -0.7070234722246357}, {-3., \
-0.7071900803344316, -0.7070234722246357}, {-3., -0.5878742048036698, \
-0.8089523591203952}, {-3.25, -0.5878742048036698, -0.8089523591203952}, \
{-3.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3.25, -0.5878742048036698, -0.8089523591203952}, {-3., \
-0.5878742048036698, -0.8089523591203952}, {-3., -0.45408147070841337`, \
-0.890960166314569}, {-3.25, -0.45408147070841337`, -0.890960166314569}, \
{-3.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3.25, -0.45408147070841337`, -0.890960166314569}, {-3., \
-0.45408147070841337`, -0.890960166314569}, {-3., -0.3091066279673134, \
-0.9510273879056674}, {-3.25, -0.3091066279673134, -0.9510273879056674}, \
{-3.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3.25, -0.3091066279673132, -0.9510273879056675}, {-3., \
-0.3091066279673132, -0.9510273879056675}, {-3., -0.15651979460327867`, \
-0.987674821941588}, {-3.25, -0.15651979460327867`, -0.987674821941588}, \
{-3.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3.25, -0.15651979460327867`, -0.987674821941588}, {-3., \
-0.15651979460327867`, -0.987674821941588}, {-3., -0.00007853981625928847, \
-0.9999999969157486}, {-3.25, -0.00007853981625928847, -0.9999999969157486}, \
{-3.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3.25, -0.00007853981625928847, -0.9999999969157486}, \
{-3., -0.00007853981625928847, -0.9999999969157486}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}, {-3.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3.25, 0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.30895723712171647`, -0.9510759305282178}, {-3.25, 
      0.30895723712171647`, -0.9510759305282178}, {-3.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3.25, 0.3089572371217167, -0.9510759305282178}, {-3., 
      0.3089572371217167, -0.9510759305282178}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.453941513411326, -0.8910314822731209}, {-3.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3.25, 0.453941513411326, -0.8910314822731209}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}, {-3.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3.25, 0.5877471276121589, -0.8090446922041185}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}, {-3.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3.25, 0.7070790126229672, -0.7071345486596803}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}, {-3.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3.25, 0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}, {-3.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3.25, 0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.951051662150225, -0.3090319334976474}, {-3.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3.25, 0.951051662150225, -0.3090319334976474}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.9876871119312596, -0.15644222232149346`}, {-3.25, 
      0.9876871119312596, -0.15644222232149346`}, {-3.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3.25, 0.9876871119312596, -0.1564422223214935}, {-3., 
      0.9876871119312596, -0.1564422223214935}, {-3., 
      1., -4.163336342344337*^-16}, {-3.25, 
      1., -4.163336342344337*^-16}, {-3.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3.25, 1., -4.440892098500626*^-16}, {-3., 
      1., -4.440892098500626*^-16}, {-3., 0.9876871119312597, 
      0.15644222232149263`}, {-3.25, 0.9876871119312597, 
      0.15644222232149263`}, {-3.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3.25, 0.9876871119312597, 0.1564422223214926}, {-3., 
      0.9876871119312597, 0.1564422223214926}, {-3., 0.9510516621502252, 
      0.30903193349764657`}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}, {-3.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-3.25, 0.9510516621502252, 0.30903193349764657`}, {-3., 
      0.9510516621502252, 0.30903193349764657`}, {-3., 0.8909958270419003, 
      0.4540114934601547}, {-3.25, 0.8909958270419003, 
      0.4540114934601547}, {-3.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-3.25, 0.8909958270419003, 0.4540114934601547}, {-3., 
      0.8909958270419003, 0.4540114934601547}, {-3., 0.808998528157412, 
      0.5878106680208697}, {-3.25, 0.808998528157412, 
      0.5878106680208697}, {-3.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3.25, 0.8089985281574118, 0.58781066802087}, {-3., 
      0.8089985281574118, 0.58781066802087}, {-3., 0.7070790126229676, 
      0.70713454865968}, {-3.25, 0.7070790126229676, 
      0.70713454865968}, {-3.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3.25, 0.7070790126229676, 0.70713454865968}, {-3., 
      0.7070790126229676, 0.70713454865968}, {-3., 0.5877471276121592, 
      0.8090446922041181}, {-3.25, 0.5877471276121592, 
      0.8090446922041181}, {-3.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3.25, 0.5877471276121592, 0.8090446922041181}, {-3., 
      0.5877471276121592, 0.8090446922041181}, {-3., 0.45394151341132644`, 
      0.8910314822731207}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}, {-3.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3.25, 0.45394151341132644`, 0.8910314822731207}, {-3., 
      0.45394151341132644`, 0.8910314822731207}, {-3., 0.3089572371217171, 
      0.9510759305282176}, {-3.25, 0.3089572371217171, 
      0.9510759305282176}, {-3.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-3.25, 0.3089572371217171, 0.9510759305282176}, {-3., 
      0.3089572371217171, 0.9510759305282176}, {-3., 0.15636464907469383`, 
      0.9876993958283805}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}, {-3.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3.25, 0.15636464907469383`, 0.9876993958283805}, {-3., 
      0.15636464907469383`, 
      0.9876993958283805}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-3.25, -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3.25, -0.156519794603278, 
      0.9876748219415881}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3.25, -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-3.25, -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-3.25, -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-3.25, -0.707190080334431, 
      0.7070234722246362}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3.25, -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-3.25, -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-3.25, -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-3.25, -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9999999876629945, \
-0.0001570796320327716}, {-3.25, -0.9999999876629945, \
-0.0001570796320327716}, {-3.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-3., -0.9999999876629945, 
      0.00015707963203365978`}, {-2.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.75, -0.987711673632875, \
-0.15628707486335794`}, {-3., -0.987711673632875, -0.15628707486335794`}, \
{-3., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-3., -0.987711673632875, -0.15628707486335794`}, {-2.75, \
-0.987711673632875, -0.15628707486335794`}, {-2.75, -0.951100193039496, \
-0.3088825388399828}, {-3., -0.951100193039496, -0.3088825388399828}, {-3., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-3., -0.951100193039496, -0.3088825388399828}, {-2.75, \
-0.951100193039496, -0.3088825388399828}, {-2.75, -0.8910671320080115, \
-0.4538715305623575}, {-3., -0.8910671320080115, -0.4538715305623575}, {-3., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-3., -0.8910671320080115, -0.4538715305623575}, {-2.75, \
-0.8910671320080115, -0.4538715305623575}, {-2.75, -0.8090908512602306, \
-0.5876835835779278}, {-3., -0.8090908512602306, -0.5876835835779278}, {-3., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-3., -0.8090908512602306, -0.5876835835779278}, {-2.75, \
-0.8090908512602306, -0.5876835835779278}, {-2.75, -0.7071900803344316, \
-0.7070234722246357}, {-3., -0.7071900803344316, -0.7070234722246357}, {-3., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-3., -0.7071900803344316, -0.7070234722246357}, {-2.75, \
-0.7071900803344316, -0.7070234722246357}, {-2.75, -0.5878742048036698, \
-0.8089523591203952}, {-3., -0.5878742048036698, -0.8089523591203952}, {-3., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-3., -0.5878742048036698, -0.8089523591203952}, {-2.75, \
-0.5878742048036698, -0.8089523591203952}, {-2.75, -0.45408147070841337`, \
-0.890960166314569}, {-3., -0.45408147070841337`, -0.890960166314569}, {-3., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-3., -0.45408147070841337`, -0.890960166314569}, {-2.75, \
-0.45408147070841337`, -0.890960166314569}, {-2.75, -0.3091066279673134, \
-0.9510273879056674}, {-3., -0.3091066279673134, -0.9510273879056674}, {-3., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-3., -0.3091066279673132, -0.9510273879056675}, {-2.75, \
-0.3091066279673132, -0.9510273879056675}, {-2.75, -0.15651979460327867`, \
-0.987674821941588}, {-3., -0.15651979460327867`, -0.987674821941588}, {-3., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-3., -0.15651979460327867`, -0.987674821941588}, {-2.75, \
-0.15651979460327867`, -0.987674821941588}, {-2.75, -0.00007853981625928847, \
-0.9999999969157486}, {-3., -0.00007853981625928847, -0.9999999969157486}, \
{-3., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-3., -0.00007853981625928847, -0.9999999969157486}, \
{-2.75, -0.00007853981625928847, -0.9999999969157486}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-3., 
      0.15636464907469316`, -0.9876993958283806}, {-3., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-3., 0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.30895723712171647`, -0.9510759305282178}, {-3., 
      0.30895723712171647`, -0.9510759305282178}, {-3., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-3., 0.3089572371217167, -0.9510759305282178}, {-2.75, 
      0.3089572371217167, -0.9510759305282178}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.453941513411326, -0.8910314822731209}, {-3., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-3., 0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.5877471276121589, -0.8090446922041185}, {-3., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-3., 0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.7070790126229672, -0.7071345486596803}, {-3., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-3., 0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.8089985281574115, -0.5878106680208703}, {-3., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-3., 0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8909958270419, -0.45401149346015546`}, {-3., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-3., 0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.951051662150225, -0.3090319334976474}, {-3., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-3., 0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.9876871119312596, -0.15644222232149346`}, {-3., 
      0.9876871119312596, -0.15644222232149346`}, {-3., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-3., 0.9876871119312596, -0.1564422223214935}, {-2.75, 
      0.9876871119312596, -0.1564422223214935}, {-2.75, 
      1., -4.163336342344337*^-16}, {-3., 1., -4.163336342344337*^-16}, {-3., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-3., 1., -4.440892098500626*^-16}, {-2.75, 
      1., -4.440892098500626*^-16}, {-2.75, 0.9876871119312597, 
      0.15644222232149263`}, {-3., 0.9876871119312597, 
      0.15644222232149263`}, {-3., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-3., 0.9876871119312597, 0.1564422223214926}, {-2.75, 
      0.9876871119312597, 0.1564422223214926}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}, {-3., 0.9510516621502252, 
      0.30903193349764657`}, {-3., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-3., 0.9510516621502252, 0.30903193349764657`}, {-2.75, 
      0.9510516621502252, 0.30903193349764657`}, {-2.75, 0.8909958270419003, 
      0.4540114934601547}, {-3., 0.8909958270419003, 
      0.4540114934601547}, {-3., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-3., 0.8909958270419003, 0.4540114934601547}, {-2.75, 
      0.8909958270419003, 0.4540114934601547}, {-2.75, 0.808998528157412, 
      0.5878106680208697}, {-3., 0.808998528157412, 0.5878106680208697}, {-3.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-3., 0.8089985281574118, 0.58781066802087}, {-2.75, 
      0.8089985281574118, 0.58781066802087}, {-2.75, 0.7070790126229676, 
      0.70713454865968}, {-3., 0.7070790126229676, 0.70713454865968}, {-3., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-3., 0.7070790126229676, 0.70713454865968}, {-2.75, 
      0.7070790126229676, 0.70713454865968}, {-2.75, 0.5877471276121592, 
      0.8090446922041181}, {-3., 0.5877471276121592, 
      0.8090446922041181}, {-3., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-3., 0.5877471276121592, 0.8090446922041181}, {-2.75, 
      0.5877471276121592, 0.8090446922041181}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}, {-3., 0.45394151341132644`, 
      0.8910314822731207}, {-3., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-3., 0.45394151341132644`, 0.8910314822731207}, {-2.75, 
      0.45394151341132644`, 0.8910314822731207}, {-2.75, 0.3089572371217171, 
      0.9510759305282176}, {-3., 0.3089572371217171, 
      0.9510759305282176}, {-3., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-3., 0.3089572371217171, 0.9510759305282176}, {-2.75, 
      0.3089572371217171, 0.9510759305282176}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}, {-3., 0.15636464907469383`, 
      0.9876993958283805}, {-3., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-3., 0.15636464907469383`, 0.9876993958283805}, {-2.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-3., -0.00007853981625862234, 
      0.9999999969157486}, {-3., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-3., -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-3., -0.156519794603278, 
      0.9876748219415881}, {-3., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-3., -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.3091066279673126, 
      0.9510273879056678}, {-3., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-3., -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.45408147070841254`, 
      0.8909601663145693}, {-3., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-3., -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.5878742048036691, 
      0.8089523591203958}, {-3., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-3., -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-3., -0.707190080334431, 
      0.7070234722246362}, {-3., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-3., -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.8090908512602302, 
      0.5876835835779286}, {-3., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-3., -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8910671320080111, 
      0.4538715305623583}, {-3., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-3., -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.9511001930394957, 
      0.3088825388399836}, {-3., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-3., -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9877116736328749, 
      0.15628707486335883`}, {-3., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-3., -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9999999876629945, \
-0.0001570796320327716}, {-3., -0.9999999876629945, -0.0001570796320327716}, \
{-3., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-2.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.5, -0.987711673632875, \
-0.15628707486335794`}, {-2.75, -0.987711673632875, -0.15628707486335794`}, \
{-2.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.75, -0.987711673632875, -0.15628707486335794`}, {-2.5, \
-0.987711673632875, -0.15628707486335794`}, {-2.5, -0.951100193039496, \
-0.3088825388399828}, {-2.75, -0.951100193039496, -0.3088825388399828}, \
{-2.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.75, -0.951100193039496, -0.3088825388399828}, {-2.5, \
-0.951100193039496, -0.3088825388399828}, {-2.5, -0.8910671320080115, \
-0.4538715305623575}, {-2.75, -0.8910671320080115, -0.4538715305623575}, \
{-2.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.75, -0.8910671320080115, -0.4538715305623575}, {-2.5, \
-0.8910671320080115, -0.4538715305623575}, {-2.5, -0.8090908512602306, \
-0.5876835835779278}, {-2.75, -0.8090908512602306, -0.5876835835779278}, \
{-2.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.75, -0.8090908512602306, -0.5876835835779278}, {-2.5, \
-0.8090908512602306, -0.5876835835779278}, {-2.5, -0.7071900803344316, \
-0.7070234722246357}, {-2.75, -0.7071900803344316, -0.7070234722246357}, \
{-2.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.75, -0.7071900803344316, -0.7070234722246357}, {-2.5, \
-0.7071900803344316, -0.7070234722246357}, {-2.5, -0.5878742048036698, \
-0.8089523591203952}, {-2.75, -0.5878742048036698, -0.8089523591203952}, \
{-2.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.75, -0.5878742048036698, -0.8089523591203952}, {-2.5, \
-0.5878742048036698, -0.8089523591203952}, {-2.5, -0.45408147070841337`, \
-0.890960166314569}, {-2.75, -0.45408147070841337`, -0.890960166314569}, \
{-2.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.75, -0.45408147070841337`, -0.890960166314569}, {-2.5, \
-0.45408147070841337`, -0.890960166314569}, {-2.5, -0.3091066279673134, \
-0.9510273879056674}, {-2.75, -0.3091066279673134, -0.9510273879056674}, \
{-2.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.75, -0.3091066279673132, -0.9510273879056675}, {-2.5, \
-0.3091066279673132, -0.9510273879056675}, {-2.5, -0.15651979460327867`, \
-0.987674821941588}, {-2.75, -0.15651979460327867`, -0.987674821941588}, \
{-2.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.75, -0.15651979460327867`, -0.987674821941588}, {-2.5, \
-0.15651979460327867`, -0.987674821941588}, {-2.5, -0.00007853981625928847, \
-0.9999999969157486}, {-2.75, -0.00007853981625928847, -0.9999999969157486}, \
{-2.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.75, -0.00007853981625928847, -0.9999999969157486}, \
{-2.5, -0.00007853981625928847, -0.9999999969157486}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.75, 0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.30895723712171647`, -0.9510759305282178}, {-2.75, 
      0.30895723712171647`, -0.9510759305282178}, {-2.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.75, 0.3089572371217167, -0.9510759305282178}, {-2.5, 
      0.3089572371217167, -0.9510759305282178}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.453941513411326, -0.8910314822731209}, {-2.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.75, 0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}, {-2.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.75, 0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}, {-2.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.75, 0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}, {-2.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.75, 0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}, {-2.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.75, 0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.951051662150225, -0.3090319334976474}, {-2.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.75, 0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.9876871119312596, -0.15644222232149346`}, {-2.75, 
      0.9876871119312596, -0.15644222232149346`}, {-2.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.75, 0.9876871119312596, -0.1564422223214935}, {-2.5, 
      0.9876871119312596, -0.1564422223214935}, {-2.5, 
      1., -4.163336342344337*^-16}, {-2.75, 
      1., -4.163336342344337*^-16}, {-2.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.75, 1., -4.440892098500626*^-16}, {-2.5, 
      1., -4.440892098500626*^-16}, {-2.5, 0.9876871119312597, 
      0.15644222232149263`}, {-2.75, 0.9876871119312597, 
      0.15644222232149263`}, {-2.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.75, 0.9876871119312597, 0.1564422223214926}, {-2.5, 
      0.9876871119312597, 0.1564422223214926}, {-2.5, 0.9510516621502252, 
      0.30903193349764657`}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}, {-2.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-2.75, 0.9510516621502252, 0.30903193349764657`}, {-2.5, 
      0.9510516621502252, 0.30903193349764657`}, {-2.5, 0.8909958270419003, 
      0.4540114934601547}, {-2.75, 0.8909958270419003, 
      0.4540114934601547}, {-2.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-2.75, 0.8909958270419003, 0.4540114934601547}, {-2.5, 
      0.8909958270419003, 0.4540114934601547}, {-2.5, 0.808998528157412, 
      0.5878106680208697}, {-2.75, 0.808998528157412, 
      0.5878106680208697}, {-2.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.75, 0.8089985281574118, 0.58781066802087}, {-2.5, 
      0.8089985281574118, 0.58781066802087}, {-2.5, 0.7070790126229676, 
      0.70713454865968}, {-2.75, 0.7070790126229676, 
      0.70713454865968}, {-2.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.75, 0.7070790126229676, 0.70713454865968}, {-2.5, 
      0.7070790126229676, 0.70713454865968}, {-2.5, 0.5877471276121592, 
      0.8090446922041181}, {-2.75, 0.5877471276121592, 
      0.8090446922041181}, {-2.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.75, 0.5877471276121592, 0.8090446922041181}, {-2.5, 
      0.5877471276121592, 0.8090446922041181}, {-2.5, 0.45394151341132644`, 
      0.8910314822731207}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}, {-2.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.75, 0.45394151341132644`, 0.8910314822731207}, {-2.5, 
      0.45394151341132644`, 0.8910314822731207}, {-2.5, 0.3089572371217171, 
      0.9510759305282176}, {-2.75, 0.3089572371217171, 
      0.9510759305282176}, {-2.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-2.75, 0.3089572371217171, 0.9510759305282176}, {-2.5, 
      0.3089572371217171, 0.9510759305282176}, {-2.5, 0.15636464907469383`, 
      0.9876993958283805}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}, {-2.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.75, 0.15636464907469383`, 0.9876993958283805}, {-2.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-2.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.75, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.75, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-2.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.75, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-2.75, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.75, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-2.75, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-2.75, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9999999876629945, \
-0.0001570796320327716}, {-2.75, -0.9999999876629945, \
-0.0001570796320327716}, {-2.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-2.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-2.25, -0.987711673632875, \
-0.15628707486335794`}, {-2.5, -0.987711673632875, -0.15628707486335794`}, \
{-2.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.5, -0.987711673632875, -0.15628707486335794`}, {-2.25, \
-0.987711673632875, -0.15628707486335794`}, {-2.25, -0.951100193039496, \
-0.3088825388399828}, {-2.5, -0.951100193039496, -0.3088825388399828}, {-2.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.5, -0.951100193039496, -0.3088825388399828}, {-2.25, \
-0.951100193039496, -0.3088825388399828}, {-2.25, -0.8910671320080115, \
-0.4538715305623575}, {-2.5, -0.8910671320080115, -0.4538715305623575}, \
{-2.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.5, -0.8910671320080115, -0.4538715305623575}, {-2.25, \
-0.8910671320080115, -0.4538715305623575}, {-2.25, -0.8090908512602306, \
-0.5876835835779278}, {-2.5, -0.8090908512602306, -0.5876835835779278}, \
{-2.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.5, -0.8090908512602306, -0.5876835835779278}, {-2.25, \
-0.8090908512602306, -0.5876835835779278}, {-2.25, -0.7071900803344316, \
-0.7070234722246357}, {-2.5, -0.7071900803344316, -0.7070234722246357}, \
{-2.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.5, -0.7071900803344316, -0.7070234722246357}, {-2.25, \
-0.7071900803344316, -0.7070234722246357}, {-2.25, -0.5878742048036698, \
-0.8089523591203952}, {-2.5, -0.5878742048036698, -0.8089523591203952}, \
{-2.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.5, -0.5878742048036698, -0.8089523591203952}, {-2.25, \
-0.5878742048036698, -0.8089523591203952}, {-2.25, -0.45408147070841337`, \
-0.890960166314569}, {-2.5, -0.45408147070841337`, -0.890960166314569}, \
{-2.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.5, -0.45408147070841337`, -0.890960166314569}, {-2.25, \
-0.45408147070841337`, -0.890960166314569}, {-2.25, -0.3091066279673134, \
-0.9510273879056674}, {-2.5, -0.3091066279673134, -0.9510273879056674}, \
{-2.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.5, -0.3091066279673132, -0.9510273879056675}, {-2.25, \
-0.3091066279673132, -0.9510273879056675}, {-2.25, -0.15651979460327867`, \
-0.987674821941588}, {-2.5, -0.15651979460327867`, -0.987674821941588}, \
{-2.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.5, -0.15651979460327867`, -0.987674821941588}, {-2.25, \
-0.15651979460327867`, -0.987674821941588}, {-2.25, -0.00007853981625928847, \
-0.9999999969157486}, {-2.5, -0.00007853981625928847, -0.9999999969157486}, \
{-2.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.5, -0.00007853981625928847, -0.9999999969157486}, \
{-2.25, -0.00007853981625928847, -0.9999999969157486}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}, {-2.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.5, 0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.30895723712171647`, -0.9510759305282178}, {-2.5, 
      0.30895723712171647`, -0.9510759305282178}, {-2.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.5, 0.3089572371217167, -0.9510759305282178}, {-2.25, 
      0.3089572371217167, -0.9510759305282178}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.453941513411326, -0.8910314822731209}, {-2.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.5, 0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}, {-2.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.5, 0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}, {-2.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.5, 0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}, {-2.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.5, 0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}, {-2.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.5, 0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.951051662150225, -0.3090319334976474}, {-2.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.5, 0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.9876871119312596, -0.15644222232149346`}, {-2.5, 
      0.9876871119312596, -0.15644222232149346`}, {-2.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.5, 0.9876871119312596, -0.1564422223214935}, {-2.25, 
      0.9876871119312596, -0.1564422223214935}, {-2.25, 
      1., -4.163336342344337*^-16}, {-2.5, 
      1., -4.163336342344337*^-16}, {-2.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.5, 1., -4.440892098500626*^-16}, {-2.25, 
      1., -4.440892098500626*^-16}, {-2.25, 0.9876871119312597, 
      0.15644222232149263`}, {-2.5, 0.9876871119312597, 
      0.15644222232149263`}, {-2.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.5, 0.9876871119312597, 0.1564422223214926}, {-2.25, 
      0.9876871119312597, 0.1564422223214926}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}, {-2.5, 0.9510516621502252, 
      0.30903193349764657`}, {-2.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-2.5, 0.9510516621502252, 0.30903193349764657`}, {-2.25, 
      0.9510516621502252, 0.30903193349764657`}, {-2.25, 0.8909958270419003, 
      0.4540114934601547}, {-2.5, 0.8909958270419003, 
      0.4540114934601547}, {-2.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-2.5, 0.8909958270419003, 0.4540114934601547}, {-2.25, 
      0.8909958270419003, 0.4540114934601547}, {-2.25, 0.808998528157412, 
      0.5878106680208697}, {-2.5, 0.808998528157412, 
      0.5878106680208697}, {-2.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.5, 0.8089985281574118, 0.58781066802087}, {-2.25, 
      0.8089985281574118, 0.58781066802087}, {-2.25, 0.7070790126229676, 
      0.70713454865968}, {-2.5, 0.7070790126229676, 0.70713454865968}, {-2.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.5, 0.7070790126229676, 0.70713454865968}, {-2.25, 
      0.7070790126229676, 0.70713454865968}, {-2.25, 0.5877471276121592, 
      0.8090446922041181}, {-2.5, 0.5877471276121592, 
      0.8090446922041181}, {-2.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.5, 0.5877471276121592, 0.8090446922041181}, {-2.25, 
      0.5877471276121592, 0.8090446922041181}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}, {-2.5, 0.45394151341132644`, 
      0.8910314822731207}, {-2.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.5, 0.45394151341132644`, 0.8910314822731207}, {-2.25, 
      0.45394151341132644`, 0.8910314822731207}, {-2.25, 0.3089572371217171, 
      0.9510759305282176}, {-2.5, 0.3089572371217171, 
      0.9510759305282176}, {-2.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-2.5, 0.3089572371217171, 0.9510759305282176}, {-2.25, 
      0.3089572371217171, 0.9510759305282176}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}, {-2.5, 0.15636464907469383`, 
      0.9876993958283805}, {-2.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.5, 0.15636464907469383`, 0.9876993958283805}, {-2.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-2.5, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.5, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.5, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-2.5, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.5, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-2.5, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.5, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-2.5, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-2.5, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.5, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9999999876629945, \
-0.0001570796320327716}, {-2.5, -0.9999999876629945, -0.0001570796320327716}, \
{-2.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-2.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-2., -0.9999999876629945, 
      0.00015707963203365978`}, {-2., -0.987711673632875, \
-0.15628707486335794`}, {-2.25, -0.987711673632875, -0.15628707486335794`}, \
{-2.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2.25, -0.987711673632875, -0.15628707486335794`}, {-2., \
-0.987711673632875, -0.15628707486335794`}, {-2., -0.951100193039496, \
-0.3088825388399828}, {-2.25, -0.951100193039496, -0.3088825388399828}, \
{-2.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2.25, -0.951100193039496, -0.3088825388399828}, {-2., \
-0.951100193039496, -0.3088825388399828}, {-2., -0.8910671320080115, \
-0.4538715305623575}, {-2.25, -0.8910671320080115, -0.4538715305623575}, \
{-2.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2.25, -0.8910671320080115, -0.4538715305623575}, {-2., \
-0.8910671320080115, -0.4538715305623575}, {-2., -0.8090908512602306, \
-0.5876835835779278}, {-2.25, -0.8090908512602306, -0.5876835835779278}, \
{-2.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2.25, -0.8090908512602306, -0.5876835835779278}, {-2., \
-0.8090908512602306, -0.5876835835779278}, {-2., -0.7071900803344316, \
-0.7070234722246357}, {-2.25, -0.7071900803344316, -0.7070234722246357}, \
{-2.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2.25, -0.7071900803344316, -0.7070234722246357}, {-2., \
-0.7071900803344316, -0.7070234722246357}, {-2., -0.5878742048036698, \
-0.8089523591203952}, {-2.25, -0.5878742048036698, -0.8089523591203952}, \
{-2.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2.25, -0.5878742048036698, -0.8089523591203952}, {-2., \
-0.5878742048036698, -0.8089523591203952}, {-2., -0.45408147070841337`, \
-0.890960166314569}, {-2.25, -0.45408147070841337`, -0.890960166314569}, \
{-2.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2.25, -0.45408147070841337`, -0.890960166314569}, {-2., \
-0.45408147070841337`, -0.890960166314569}, {-2., -0.3091066279673134, \
-0.9510273879056674}, {-2.25, -0.3091066279673134, -0.9510273879056674}, \
{-2.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2.25, -0.3091066279673132, -0.9510273879056675}, {-2., \
-0.3091066279673132, -0.9510273879056675}, {-2., -0.15651979460327867`, \
-0.987674821941588}, {-2.25, -0.15651979460327867`, -0.987674821941588}, \
{-2.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2.25, -0.15651979460327867`, -0.987674821941588}, {-2., \
-0.15651979460327867`, -0.987674821941588}, {-2., -0.00007853981625928847, \
-0.9999999969157486}, {-2.25, -0.00007853981625928847, -0.9999999969157486}, \
{-2.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2.25, -0.00007853981625928847, -0.9999999969157486}, \
{-2., -0.00007853981625928847, -0.9999999969157486}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}, {-2.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2.25, 0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.30895723712171647`, -0.9510759305282178}, {-2.25, 
      0.30895723712171647`, -0.9510759305282178}, {-2.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2.25, 0.3089572371217167, -0.9510759305282178}, {-2., 
      0.3089572371217167, -0.9510759305282178}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.453941513411326, -0.8910314822731209}, {-2.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2.25, 0.453941513411326, -0.8910314822731209}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}, {-2.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2.25, 0.5877471276121589, -0.8090446922041185}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}, {-2.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2.25, 0.7070790126229672, -0.7071345486596803}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}, {-2.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2.25, 0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}, {-2.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2.25, 0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.951051662150225, -0.3090319334976474}, {-2.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2.25, 0.951051662150225, -0.3090319334976474}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.9876871119312596, -0.15644222232149346`}, {-2.25, 
      0.9876871119312596, -0.15644222232149346`}, {-2.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2.25, 0.9876871119312596, -0.1564422223214935}, {-2., 
      0.9876871119312596, -0.1564422223214935}, {-2., 
      1., -4.163336342344337*^-16}, {-2.25, 
      1., -4.163336342344337*^-16}, {-2.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2.25, 1., -4.440892098500626*^-16}, {-2., 
      1., -4.440892098500626*^-16}, {-2., 0.9876871119312597, 
      0.15644222232149263`}, {-2.25, 0.9876871119312597, 
      0.15644222232149263`}, {-2.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2.25, 0.9876871119312597, 0.1564422223214926}, {-2., 
      0.9876871119312597, 0.1564422223214926}, {-2., 0.9510516621502252, 
      0.30903193349764657`}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}, {-2.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-2.25, 0.9510516621502252, 0.30903193349764657`}, {-2., 
      0.9510516621502252, 0.30903193349764657`}, {-2., 0.8909958270419003, 
      0.4540114934601547}, {-2.25, 0.8909958270419003, 
      0.4540114934601547}, {-2.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-2.25, 0.8909958270419003, 0.4540114934601547}, {-2., 
      0.8909958270419003, 0.4540114934601547}, {-2., 0.808998528157412, 
      0.5878106680208697}, {-2.25, 0.808998528157412, 
      0.5878106680208697}, {-2.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2.25, 0.8089985281574118, 0.58781066802087}, {-2., 
      0.8089985281574118, 0.58781066802087}, {-2., 0.7070790126229676, 
      0.70713454865968}, {-2.25, 0.7070790126229676, 
      0.70713454865968}, {-2.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2.25, 0.7070790126229676, 0.70713454865968}, {-2., 
      0.7070790126229676, 0.70713454865968}, {-2., 0.5877471276121592, 
      0.8090446922041181}, {-2.25, 0.5877471276121592, 
      0.8090446922041181}, {-2.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2.25, 0.5877471276121592, 0.8090446922041181}, {-2., 
      0.5877471276121592, 0.8090446922041181}, {-2., 0.45394151341132644`, 
      0.8910314822731207}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}, {-2.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2.25, 0.45394151341132644`, 0.8910314822731207}, {-2., 
      0.45394151341132644`, 0.8910314822731207}, {-2., 0.3089572371217171, 
      0.9510759305282176}, {-2.25, 0.3089572371217171, 
      0.9510759305282176}, {-2.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-2.25, 0.3089572371217171, 0.9510759305282176}, {-2., 
      0.3089572371217171, 0.9510759305282176}, {-2., 0.15636464907469383`, 
      0.9876993958283805}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}, {-2.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2.25, 0.15636464907469383`, 0.9876993958283805}, {-2., 
      0.15636464907469383`, 
      0.9876993958283805}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-2.25, -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2.25, -0.156519794603278, 
      0.9876748219415881}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2.25, -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-2.25, -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-2.25, -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-2.25, -0.707190080334431, 
      0.7070234722246362}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2.25, -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-2.25, -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-2.25, -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-2.25, -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9999999876629945, \
-0.0001570796320327716}, {-2.25, -0.9999999876629945, \
-0.0001570796320327716}, {-2.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-2., -0.9999999876629945, 
      0.00015707963203365978`}, {-1.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.75, -0.987711673632875, \
-0.15628707486335794`}, {-2., -0.987711673632875, -0.15628707486335794`}, \
{-2., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-2., -0.987711673632875, -0.15628707486335794`}, {-1.75, \
-0.987711673632875, -0.15628707486335794`}, {-1.75, -0.951100193039496, \
-0.3088825388399828}, {-2., -0.951100193039496, -0.3088825388399828}, {-2., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-2., -0.951100193039496, -0.3088825388399828}, {-1.75, \
-0.951100193039496, -0.3088825388399828}, {-1.75, -0.8910671320080115, \
-0.4538715305623575}, {-2., -0.8910671320080115, -0.4538715305623575}, {-2., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-2., -0.8910671320080115, -0.4538715305623575}, {-1.75, \
-0.8910671320080115, -0.4538715305623575}, {-1.75, -0.8090908512602306, \
-0.5876835835779278}, {-2., -0.8090908512602306, -0.5876835835779278}, {-2., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-2., -0.8090908512602306, -0.5876835835779278}, {-1.75, \
-0.8090908512602306, -0.5876835835779278}, {-1.75, -0.7071900803344316, \
-0.7070234722246357}, {-2., -0.7071900803344316, -0.7070234722246357}, {-2., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-2., -0.7071900803344316, -0.7070234722246357}, {-1.75, \
-0.7071900803344316, -0.7070234722246357}, {-1.75, -0.5878742048036698, \
-0.8089523591203952}, {-2., -0.5878742048036698, -0.8089523591203952}, {-2., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-2., -0.5878742048036698, -0.8089523591203952}, {-1.75, \
-0.5878742048036698, -0.8089523591203952}, {-1.75, -0.45408147070841337`, \
-0.890960166314569}, {-2., -0.45408147070841337`, -0.890960166314569}, {-2., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-2., -0.45408147070841337`, -0.890960166314569}, {-1.75, \
-0.45408147070841337`, -0.890960166314569}, {-1.75, -0.3091066279673134, \
-0.9510273879056674}, {-2., -0.3091066279673134, -0.9510273879056674}, {-2., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-2., -0.3091066279673132, -0.9510273879056675}, {-1.75, \
-0.3091066279673132, -0.9510273879056675}, {-1.75, -0.15651979460327867`, \
-0.987674821941588}, {-2., -0.15651979460327867`, -0.987674821941588}, {-2., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-2., -0.15651979460327867`, -0.987674821941588}, {-1.75, \
-0.15651979460327867`, -0.987674821941588}, {-1.75, -0.00007853981625928847, \
-0.9999999969157486}, {-2., -0.00007853981625928847, -0.9999999969157486}, \
{-2., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-2., -0.00007853981625928847, -0.9999999969157486}, \
{-1.75, -0.00007853981625928847, -0.9999999969157486}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-2., 
      0.15636464907469316`, -0.9876993958283806}, {-2., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-2., 0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.30895723712171647`, -0.9510759305282178}, {-2., 
      0.30895723712171647`, -0.9510759305282178}, {-2., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-2., 0.3089572371217167, -0.9510759305282178}, {-1.75, 
      0.3089572371217167, -0.9510759305282178}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.453941513411326, -0.8910314822731209}, {-2., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-2., 0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.5877471276121589, -0.8090446922041185}, {-2., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-2., 0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.7070790126229672, -0.7071345486596803}, {-2., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-2., 0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.8089985281574115, -0.5878106680208703}, {-2., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-2., 0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8909958270419, -0.45401149346015546`}, {-2., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-2., 0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.951051662150225, -0.3090319334976474}, {-2., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-2., 0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.9876871119312596, -0.15644222232149346`}, {-2., 
      0.9876871119312596, -0.15644222232149346`}, {-2., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-2., 0.9876871119312596, -0.1564422223214935}, {-1.75, 
      0.9876871119312596, -0.1564422223214935}, {-1.75, 
      1., -4.163336342344337*^-16}, {-2., 1., -4.163336342344337*^-16}, {-2., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-2., 1., -4.440892098500626*^-16}, {-1.75, 
      1., -4.440892098500626*^-16}, {-1.75, 0.9876871119312597, 
      0.15644222232149263`}, {-2., 0.9876871119312597, 
      0.15644222232149263`}, {-2., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-2., 0.9876871119312597, 0.1564422223214926}, {-1.75, 
      0.9876871119312597, 0.1564422223214926}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}, {-2., 0.9510516621502252, 
      0.30903193349764657`}, {-2., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-2., 0.9510516621502252, 0.30903193349764657`}, {-1.75, 
      0.9510516621502252, 0.30903193349764657`}, {-1.75, 0.8909958270419003, 
      0.4540114934601547}, {-2., 0.8909958270419003, 
      0.4540114934601547}, {-2., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-2., 0.8909958270419003, 0.4540114934601547}, {-1.75, 
      0.8909958270419003, 0.4540114934601547}, {-1.75, 0.808998528157412, 
      0.5878106680208697}, {-2., 0.808998528157412, 0.5878106680208697}, {-2.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-2., 0.8089985281574118, 0.58781066802087}, {-1.75, 
      0.8089985281574118, 0.58781066802087}, {-1.75, 0.7070790126229676, 
      0.70713454865968}, {-2., 0.7070790126229676, 0.70713454865968}, {-2., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-2., 0.7070790126229676, 0.70713454865968}, {-1.75, 
      0.7070790126229676, 0.70713454865968}, {-1.75, 0.5877471276121592, 
      0.8090446922041181}, {-2., 0.5877471276121592, 
      0.8090446922041181}, {-2., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-2., 0.5877471276121592, 0.8090446922041181}, {-1.75, 
      0.5877471276121592, 0.8090446922041181}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}, {-2., 0.45394151341132644`, 
      0.8910314822731207}, {-2., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-2., 0.45394151341132644`, 0.8910314822731207}, {-1.75, 
      0.45394151341132644`, 0.8910314822731207}, {-1.75, 0.3089572371217171, 
      0.9510759305282176}, {-2., 0.3089572371217171, 
      0.9510759305282176}, {-2., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-2., 0.3089572371217171, 0.9510759305282176}, {-1.75, 
      0.3089572371217171, 0.9510759305282176}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}, {-2., 0.15636464907469383`, 
      0.9876993958283805}, {-2., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-2., 0.15636464907469383`, 0.9876993958283805}, {-1.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-2., -0.00007853981625862234, 
      0.9999999969157486}, {-2., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-2., -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-2., -0.156519794603278, 
      0.9876748219415881}, {-2., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-2., -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.3091066279673126, 
      0.9510273879056678}, {-2., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-2., -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.45408147070841254`, 
      0.8909601663145693}, {-2., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-2., -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.5878742048036691, 
      0.8089523591203958}, {-2., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-2., -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-2., -0.707190080334431, 
      0.7070234722246362}, {-2., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-2., -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.8090908512602302, 
      0.5876835835779286}, {-2., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-2., -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8910671320080111, 
      0.4538715305623583}, {-2., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-2., -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.9511001930394957, 
      0.3088825388399836}, {-2., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-2., -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9877116736328749, 
      0.15628707486335883`}, {-2., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-2., -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9999999876629945, \
-0.0001570796320327716}, {-2., -0.9999999876629945, -0.0001570796320327716}, \
{-2., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-1.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.5, -0.987711673632875, \
-0.15628707486335794`}, {-1.75, -0.987711673632875, -0.15628707486335794`}, \
{-1.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.75, -0.987711673632875, -0.15628707486335794`}, {-1.5, \
-0.987711673632875, -0.15628707486335794`}, {-1.5, -0.951100193039496, \
-0.3088825388399828}, {-1.75, -0.951100193039496, -0.3088825388399828}, \
{-1.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.75, -0.951100193039496, -0.3088825388399828}, {-1.5, \
-0.951100193039496, -0.3088825388399828}, {-1.5, -0.8910671320080115, \
-0.4538715305623575}, {-1.75, -0.8910671320080115, -0.4538715305623575}, \
{-1.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.75, -0.8910671320080115, -0.4538715305623575}, {-1.5, \
-0.8910671320080115, -0.4538715305623575}, {-1.5, -0.8090908512602306, \
-0.5876835835779278}, {-1.75, -0.8090908512602306, -0.5876835835779278}, \
{-1.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.75, -0.8090908512602306, -0.5876835835779278}, {-1.5, \
-0.8090908512602306, -0.5876835835779278}, {-1.5, -0.7071900803344316, \
-0.7070234722246357}, {-1.75, -0.7071900803344316, -0.7070234722246357}, \
{-1.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.75, -0.7071900803344316, -0.7070234722246357}, {-1.5, \
-0.7071900803344316, -0.7070234722246357}, {-1.5, -0.5878742048036698, \
-0.8089523591203952}, {-1.75, -0.5878742048036698, -0.8089523591203952}, \
{-1.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.75, -0.5878742048036698, -0.8089523591203952}, {-1.5, \
-0.5878742048036698, -0.8089523591203952}, {-1.5, -0.45408147070841337`, \
-0.890960166314569}, {-1.75, -0.45408147070841337`, -0.890960166314569}, \
{-1.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.75, -0.45408147070841337`, -0.890960166314569}, {-1.5, \
-0.45408147070841337`, -0.890960166314569}, {-1.5, -0.3091066279673134, \
-0.9510273879056674}, {-1.75, -0.3091066279673134, -0.9510273879056674}, \
{-1.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.75, -0.3091066279673132, -0.9510273879056675}, {-1.5, \
-0.3091066279673132, -0.9510273879056675}, {-1.5, -0.15651979460327867`, \
-0.987674821941588}, {-1.75, -0.15651979460327867`, -0.987674821941588}, \
{-1.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.75, -0.15651979460327867`, -0.987674821941588}, {-1.5, \
-0.15651979460327867`, -0.987674821941588}, {-1.5, -0.00007853981625928847, \
-0.9999999969157486}, {-1.75, -0.00007853981625928847, -0.9999999969157486}, \
{-1.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.75, -0.00007853981625928847, -0.9999999969157486}, \
{-1.5, -0.00007853981625928847, -0.9999999969157486}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.75, 0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.30895723712171647`, -0.9510759305282178}, {-1.75, 
      0.30895723712171647`, -0.9510759305282178}, {-1.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.75, 0.3089572371217167, -0.9510759305282178}, {-1.5, 
      0.3089572371217167, -0.9510759305282178}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.453941513411326, -0.8910314822731209}, {-1.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.75, 0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}, {-1.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.75, 0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}, {-1.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.75, 0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}, {-1.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.75, 0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}, {-1.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.75, 0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.951051662150225, -0.3090319334976474}, {-1.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.75, 0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.9876871119312596, -0.15644222232149346`}, {-1.75, 
      0.9876871119312596, -0.15644222232149346`}, {-1.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.75, 0.9876871119312596, -0.1564422223214935}, {-1.5, 
      0.9876871119312596, -0.1564422223214935}, {-1.5, 
      1., -4.163336342344337*^-16}, {-1.75, 
      1., -4.163336342344337*^-16}, {-1.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.75, 1., -4.440892098500626*^-16}, {-1.5, 
      1., -4.440892098500626*^-16}, {-1.5, 0.9876871119312597, 
      0.15644222232149263`}, {-1.75, 0.9876871119312597, 
      0.15644222232149263`}, {-1.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.75, 0.9876871119312597, 0.1564422223214926}, {-1.5, 
      0.9876871119312597, 0.1564422223214926}, {-1.5, 0.9510516621502252, 
      0.30903193349764657`}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}, {-1.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-1.75, 0.9510516621502252, 0.30903193349764657`}, {-1.5, 
      0.9510516621502252, 0.30903193349764657`}, {-1.5, 0.8909958270419003, 
      0.4540114934601547}, {-1.75, 0.8909958270419003, 
      0.4540114934601547}, {-1.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-1.75, 0.8909958270419003, 0.4540114934601547}, {-1.5, 
      0.8909958270419003, 0.4540114934601547}, {-1.5, 0.808998528157412, 
      0.5878106680208697}, {-1.75, 0.808998528157412, 
      0.5878106680208697}, {-1.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.75, 0.8089985281574118, 0.58781066802087}, {-1.5, 
      0.8089985281574118, 0.58781066802087}, {-1.5, 0.7070790126229676, 
      0.70713454865968}, {-1.75, 0.7070790126229676, 
      0.70713454865968}, {-1.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.75, 0.7070790126229676, 0.70713454865968}, {-1.5, 
      0.7070790126229676, 0.70713454865968}, {-1.5, 0.5877471276121592, 
      0.8090446922041181}, {-1.75, 0.5877471276121592, 
      0.8090446922041181}, {-1.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.75, 0.5877471276121592, 0.8090446922041181}, {-1.5, 
      0.5877471276121592, 0.8090446922041181}, {-1.5, 0.45394151341132644`, 
      0.8910314822731207}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}, {-1.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.75, 0.45394151341132644`, 0.8910314822731207}, {-1.5, 
      0.45394151341132644`, 0.8910314822731207}, {-1.5, 0.3089572371217171, 
      0.9510759305282176}, {-1.75, 0.3089572371217171, 
      0.9510759305282176}, {-1.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-1.75, 0.3089572371217171, 0.9510759305282176}, {-1.5, 
      0.3089572371217171, 0.9510759305282176}, {-1.5, 0.15636464907469383`, 
      0.9876993958283805}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}, {-1.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.75, 0.15636464907469383`, 0.9876993958283805}, {-1.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-1.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.75, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.75, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-1.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.75, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-1.75, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.75, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-1.75, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-1.75, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9999999876629945, \
-0.0001570796320327716}, {-1.75, -0.9999999876629945, \
-0.0001570796320327716}, {-1.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-1.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-1.25, -0.987711673632875, \
-0.15628707486335794`}, {-1.5, -0.987711673632875, -0.15628707486335794`}, \
{-1.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.5, -0.987711673632875, -0.15628707486335794`}, {-1.25, \
-0.987711673632875, -0.15628707486335794`}, {-1.25, -0.951100193039496, \
-0.3088825388399828}, {-1.5, -0.951100193039496, -0.3088825388399828}, {-1.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.5, -0.951100193039496, -0.3088825388399828}, {-1.25, \
-0.951100193039496, -0.3088825388399828}, {-1.25, -0.8910671320080115, \
-0.4538715305623575}, {-1.5, -0.8910671320080115, -0.4538715305623575}, \
{-1.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.5, -0.8910671320080115, -0.4538715305623575}, {-1.25, \
-0.8910671320080115, -0.4538715305623575}, {-1.25, -0.8090908512602306, \
-0.5876835835779278}, {-1.5, -0.8090908512602306, -0.5876835835779278}, \
{-1.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.5, -0.8090908512602306, -0.5876835835779278}, {-1.25, \
-0.8090908512602306, -0.5876835835779278}, {-1.25, -0.7071900803344316, \
-0.7070234722246357}, {-1.5, -0.7071900803344316, -0.7070234722246357}, \
{-1.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.5, -0.7071900803344316, -0.7070234722246357}, {-1.25, \
-0.7071900803344316, -0.7070234722246357}, {-1.25, -0.5878742048036698, \
-0.8089523591203952}, {-1.5, -0.5878742048036698, -0.8089523591203952}, \
{-1.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.5, -0.5878742048036698, -0.8089523591203952}, {-1.25, \
-0.5878742048036698, -0.8089523591203952}, {-1.25, -0.45408147070841337`, \
-0.890960166314569}, {-1.5, -0.45408147070841337`, -0.890960166314569}, \
{-1.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.5, -0.45408147070841337`, -0.890960166314569}, {-1.25, \
-0.45408147070841337`, -0.890960166314569}, {-1.25, -0.3091066279673134, \
-0.9510273879056674}, {-1.5, -0.3091066279673134, -0.9510273879056674}, \
{-1.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.5, -0.3091066279673132, -0.9510273879056675}, {-1.25, \
-0.3091066279673132, -0.9510273879056675}, {-1.25, -0.15651979460327867`, \
-0.987674821941588}, {-1.5, -0.15651979460327867`, -0.987674821941588}, \
{-1.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.5, -0.15651979460327867`, -0.987674821941588}, {-1.25, \
-0.15651979460327867`, -0.987674821941588}, {-1.25, -0.00007853981625928847, \
-0.9999999969157486}, {-1.5, -0.00007853981625928847, -0.9999999969157486}, \
{-1.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.5, -0.00007853981625928847, -0.9999999969157486}, \
{-1.25, -0.00007853981625928847, -0.9999999969157486}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}, {-1.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.5, 0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.30895723712171647`, -0.9510759305282178}, {-1.5, 
      0.30895723712171647`, -0.9510759305282178}, {-1.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.5, 0.3089572371217167, -0.9510759305282178}, {-1.25, 
      0.3089572371217167, -0.9510759305282178}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.453941513411326, -0.8910314822731209}, {-1.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.5, 0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}, {-1.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.5, 0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}, {-1.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.5, 0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}, {-1.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.5, 0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}, {-1.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.5, 0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.951051662150225, -0.3090319334976474}, {-1.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.5, 0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.9876871119312596, -0.15644222232149346`}, {-1.5, 
      0.9876871119312596, -0.15644222232149346`}, {-1.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.5, 0.9876871119312596, -0.1564422223214935}, {-1.25, 
      0.9876871119312596, -0.1564422223214935}, {-1.25, 
      1., -4.163336342344337*^-16}, {-1.5, 
      1., -4.163336342344337*^-16}, {-1.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.5, 1., -4.440892098500626*^-16}, {-1.25, 
      1., -4.440892098500626*^-16}, {-1.25, 0.9876871119312597, 
      0.15644222232149263`}, {-1.5, 0.9876871119312597, 
      0.15644222232149263`}, {-1.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.5, 0.9876871119312597, 0.1564422223214926}, {-1.25, 
      0.9876871119312597, 0.1564422223214926}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}, {-1.5, 0.9510516621502252, 
      0.30903193349764657`}, {-1.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-1.5, 0.9510516621502252, 0.30903193349764657`}, {-1.25, 
      0.9510516621502252, 0.30903193349764657`}, {-1.25, 0.8909958270419003, 
      0.4540114934601547}, {-1.5, 0.8909958270419003, 
      0.4540114934601547}, {-1.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-1.5, 0.8909958270419003, 0.4540114934601547}, {-1.25, 
      0.8909958270419003, 0.4540114934601547}, {-1.25, 0.808998528157412, 
      0.5878106680208697}, {-1.5, 0.808998528157412, 
      0.5878106680208697}, {-1.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.5, 0.8089985281574118, 0.58781066802087}, {-1.25, 
      0.8089985281574118, 0.58781066802087}, {-1.25, 0.7070790126229676, 
      0.70713454865968}, {-1.5, 0.7070790126229676, 0.70713454865968}, {-1.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.5, 0.7070790126229676, 0.70713454865968}, {-1.25, 
      0.7070790126229676, 0.70713454865968}, {-1.25, 0.5877471276121592, 
      0.8090446922041181}, {-1.5, 0.5877471276121592, 
      0.8090446922041181}, {-1.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.5, 0.5877471276121592, 0.8090446922041181}, {-1.25, 
      0.5877471276121592, 0.8090446922041181}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}, {-1.5, 0.45394151341132644`, 
      0.8910314822731207}, {-1.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.5, 0.45394151341132644`, 0.8910314822731207}, {-1.25, 
      0.45394151341132644`, 0.8910314822731207}, {-1.25, 0.3089572371217171, 
      0.9510759305282176}, {-1.5, 0.3089572371217171, 
      0.9510759305282176}, {-1.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-1.5, 0.3089572371217171, 0.9510759305282176}, {-1.25, 
      0.3089572371217171, 0.9510759305282176}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}, {-1.5, 0.15636464907469383`, 
      0.9876993958283805}, {-1.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.5, 0.15636464907469383`, 0.9876993958283805}, {-1.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-1.5, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.5, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.5, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-1.5, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.5, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-1.5, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.5, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-1.5, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-1.5, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.5, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9999999876629945, \
-0.0001570796320327716}, {-1.5, -0.9999999876629945, -0.0001570796320327716}, \
{-1.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-1.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-1., -0.9999999876629945, 
      0.00015707963203365978`}, {-1., -0.987711673632875, \
-0.15628707486335794`}, {-1.25, -0.987711673632875, -0.15628707486335794`}, \
{-1.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1.25, -0.987711673632875, -0.15628707486335794`}, {-1., \
-0.987711673632875, -0.15628707486335794`}, {-1., -0.951100193039496, \
-0.3088825388399828}, {-1.25, -0.951100193039496, -0.3088825388399828}, \
{-1.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1.25, -0.951100193039496, -0.3088825388399828}, {-1., \
-0.951100193039496, -0.3088825388399828}, {-1., -0.8910671320080115, \
-0.4538715305623575}, {-1.25, -0.8910671320080115, -0.4538715305623575}, \
{-1.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1.25, -0.8910671320080115, -0.4538715305623575}, {-1., \
-0.8910671320080115, -0.4538715305623575}, {-1., -0.8090908512602306, \
-0.5876835835779278}, {-1.25, -0.8090908512602306, -0.5876835835779278}, \
{-1.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1.25, -0.8090908512602306, -0.5876835835779278}, {-1., \
-0.8090908512602306, -0.5876835835779278}, {-1., -0.7071900803344316, \
-0.7070234722246357}, {-1.25, -0.7071900803344316, -0.7070234722246357}, \
{-1.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1.25, -0.7071900803344316, -0.7070234722246357}, {-1., \
-0.7071900803344316, -0.7070234722246357}, {-1., -0.5878742048036698, \
-0.8089523591203952}, {-1.25, -0.5878742048036698, -0.8089523591203952}, \
{-1.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1.25, -0.5878742048036698, -0.8089523591203952}, {-1., \
-0.5878742048036698, -0.8089523591203952}, {-1., -0.45408147070841337`, \
-0.890960166314569}, {-1.25, -0.45408147070841337`, -0.890960166314569}, \
{-1.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1.25, -0.45408147070841337`, -0.890960166314569}, {-1., \
-0.45408147070841337`, -0.890960166314569}, {-1., -0.3091066279673134, \
-0.9510273879056674}, {-1.25, -0.3091066279673134, -0.9510273879056674}, \
{-1.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1.25, -0.3091066279673132, -0.9510273879056675}, {-1., \
-0.3091066279673132, -0.9510273879056675}, {-1., -0.15651979460327867`, \
-0.987674821941588}, {-1.25, -0.15651979460327867`, -0.987674821941588}, \
{-1.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1.25, -0.15651979460327867`, -0.987674821941588}, {-1., \
-0.15651979460327867`, -0.987674821941588}, {-1., -0.00007853981625928847, \
-0.9999999969157486}, {-1.25, -0.00007853981625928847, -0.9999999969157486}, \
{-1.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1.25, -0.00007853981625928847, -0.9999999969157486}, \
{-1., -0.00007853981625928847, -0.9999999969157486}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}, {-1.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1.25, 0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.30895723712171647`, -0.9510759305282178}, {-1.25, 
      0.30895723712171647`, -0.9510759305282178}, {-1.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1.25, 0.3089572371217167, -0.9510759305282178}, {-1., 
      0.3089572371217167, -0.9510759305282178}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.453941513411326, -0.8910314822731209}, {-1.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1.25, 0.453941513411326, -0.8910314822731209}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}, {-1.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1.25, 0.5877471276121589, -0.8090446922041185}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}, {-1.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1.25, 0.7070790126229672, -0.7071345486596803}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}, {-1.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1.25, 0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}, {-1.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1.25, 0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.951051662150225, -0.3090319334976474}, {-1.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1.25, 0.951051662150225, -0.3090319334976474}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.9876871119312596, -0.15644222232149346`}, {-1.25, 
      0.9876871119312596, -0.15644222232149346`}, {-1.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1.25, 0.9876871119312596, -0.1564422223214935}, {-1., 
      0.9876871119312596, -0.1564422223214935}, {-1., 
      1., -4.163336342344337*^-16}, {-1.25, 
      1., -4.163336342344337*^-16}, {-1.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1.25, 1., -4.440892098500626*^-16}, {-1., 
      1., -4.440892098500626*^-16}, {-1., 0.9876871119312597, 
      0.15644222232149263`}, {-1.25, 0.9876871119312597, 
      0.15644222232149263`}, {-1.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1.25, 0.9876871119312597, 0.1564422223214926}, {-1., 
      0.9876871119312597, 0.1564422223214926}, {-1., 0.9510516621502252, 
      0.30903193349764657`}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}, {-1.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-1.25, 0.9510516621502252, 0.30903193349764657`}, {-1., 
      0.9510516621502252, 0.30903193349764657`}, {-1., 0.8909958270419003, 
      0.4540114934601547}, {-1.25, 0.8909958270419003, 
      0.4540114934601547}, {-1.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-1.25, 0.8909958270419003, 0.4540114934601547}, {-1., 
      0.8909958270419003, 0.4540114934601547}, {-1., 0.808998528157412, 
      0.5878106680208697}, {-1.25, 0.808998528157412, 
      0.5878106680208697}, {-1.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1.25, 0.8089985281574118, 0.58781066802087}, {-1., 
      0.8089985281574118, 0.58781066802087}, {-1., 0.7070790126229676, 
      0.70713454865968}, {-1.25, 0.7070790126229676, 
      0.70713454865968}, {-1.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1.25, 0.7070790126229676, 0.70713454865968}, {-1., 
      0.7070790126229676, 0.70713454865968}, {-1., 0.5877471276121592, 
      0.8090446922041181}, {-1.25, 0.5877471276121592, 
      0.8090446922041181}, {-1.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1.25, 0.5877471276121592, 0.8090446922041181}, {-1., 
      0.5877471276121592, 0.8090446922041181}, {-1., 0.45394151341132644`, 
      0.8910314822731207}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}, {-1.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1.25, 0.45394151341132644`, 0.8910314822731207}, {-1., 
      0.45394151341132644`, 0.8910314822731207}, {-1., 0.3089572371217171, 
      0.9510759305282176}, {-1.25, 0.3089572371217171, 
      0.9510759305282176}, {-1.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-1.25, 0.3089572371217171, 0.9510759305282176}, {-1., 
      0.3089572371217171, 0.9510759305282176}, {-1., 0.15636464907469383`, 
      0.9876993958283805}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}, {-1.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1.25, 0.15636464907469383`, 0.9876993958283805}, {-1., 
      0.15636464907469383`, 
      0.9876993958283805}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-1.25, -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1.25, -0.156519794603278, 
      0.9876748219415881}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1.25, -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-1.25, -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-1.25, -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-1.25, -0.707190080334431, 
      0.7070234722246362}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1.25, -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-1.25, -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-1.25, -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-1.25, -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9999999876629945, \
-0.0001570796320327716}, {-1.25, -0.9999999876629945, \
-0.0001570796320327716}, {-1.25, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-1., -0.9999999876629945, 
      0.00015707963203365978`}, {-0.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.75, -0.987711673632875, \
-0.15628707486335794`}, {-1., -0.987711673632875, -0.15628707486335794`}, \
{-1., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-1., -0.987711673632875, -0.15628707486335794`}, {-0.75, \
-0.987711673632875, -0.15628707486335794`}, {-0.75, -0.951100193039496, \
-0.3088825388399828}, {-1., -0.951100193039496, -0.3088825388399828}, {-1., \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-1., -0.951100193039496, -0.3088825388399828}, {-0.75, \
-0.951100193039496, -0.3088825388399828}, {-0.75, -0.8910671320080115, \
-0.4538715305623575}, {-1., -0.8910671320080115, -0.4538715305623575}, {-1., \
-0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-1., -0.8910671320080115, -0.4538715305623575}, {-0.75, \
-0.8910671320080115, -0.4538715305623575}, {-0.75, -0.8090908512602306, \
-0.5876835835779278}, {-1., -0.8090908512602306, -0.5876835835779278}, {-1., \
-0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-1., -0.8090908512602306, -0.5876835835779278}, {-0.75, \
-0.8090908512602306, -0.5876835835779278}, {-0.75, -0.7071900803344316, \
-0.7070234722246357}, {-1., -0.7071900803344316, -0.7070234722246357}, {-1., \
-0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-1., -0.7071900803344316, -0.7070234722246357}, {-0.75, \
-0.7071900803344316, -0.7070234722246357}, {-0.75, -0.5878742048036698, \
-0.8089523591203952}, {-1., -0.5878742048036698, -0.8089523591203952}, {-1., \
-0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-1., -0.5878742048036698, -0.8089523591203952}, {-0.75, \
-0.5878742048036698, -0.8089523591203952}, {-0.75, -0.45408147070841337`, \
-0.890960166314569}, {-1., -0.45408147070841337`, -0.890960166314569}, {-1., \
-0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-1., -0.45408147070841337`, -0.890960166314569}, {-0.75, \
-0.45408147070841337`, -0.890960166314569}, {-0.75, -0.3091066279673134, \
-0.9510273879056674}, {-1., -0.3091066279673134, -0.9510273879056674}, {-1., \
-0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-1., -0.3091066279673132, -0.9510273879056675}, {-0.75, \
-0.3091066279673132, -0.9510273879056675}, {-0.75, -0.15651979460327867`, \
-0.987674821941588}, {-1., -0.15651979460327867`, -0.987674821941588}, {-1., \
-0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-1., -0.15651979460327867`, -0.987674821941588}, {-0.75, \
-0.15651979460327867`, -0.987674821941588}, {-0.75, -0.00007853981625928847, \
-0.9999999969157486}, {-1., -0.00007853981625928847, -0.9999999969157486}, \
{-1., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-1., -0.00007853981625928847, -0.9999999969157486}, \
{-0.75, -0.00007853981625928847, -0.9999999969157486}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-1., 
      0.15636464907469316`, -0.9876993958283806}, {-1., \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-1., 0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.30895723712171647`, -0.9510759305282178}, {-1., 
      0.30895723712171647`, -0.9510759305282178}, {-1., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-1., 0.3089572371217167, -0.9510759305282178}, {-0.75, 
      0.3089572371217167, -0.9510759305282178}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.453941513411326, -0.8910314822731209}, {-1., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-1., 0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.5877471276121589, -0.8090446922041185}, {-1., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-1., 0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.7070790126229672, -0.7071345486596803}, {-1., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-1., 0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.8089985281574115, -0.5878106680208703}, {-1., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-1., 0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8909958270419, -0.45401149346015546`}, {-1., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-1., 0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.951051662150225, -0.3090319334976474}, {-1., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-1., 0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.9876871119312596, -0.15644222232149346`}, {-1., 
      0.9876871119312596, -0.15644222232149346`}, {-1., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-1., 0.9876871119312596, -0.1564422223214935}, {-0.75, 
      0.9876871119312596, -0.1564422223214935}, {-0.75, 
      1., -4.163336342344337*^-16}, {-1., 1., -4.163336342344337*^-16}, {-1., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-1., 1., -4.440892098500626*^-16}, {-0.75, 
      1., -4.440892098500626*^-16}, {-0.75, 0.9876871119312597, 
      0.15644222232149263`}, {-1., 0.9876871119312597, 
      0.15644222232149263`}, {-1., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-1., 0.9876871119312597, 0.1564422223214926}, {-0.75, 
      0.9876871119312597, 0.1564422223214926}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}, {-1., 0.9510516621502252, 
      0.30903193349764657`}, {-1., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{-1., 0.9510516621502252, 0.30903193349764657`}, {-0.75, 
      0.9510516621502252, 0.30903193349764657`}, {-0.75, 0.8909958270419003, 
      0.4540114934601547}, {-1., 0.8909958270419003, 
      0.4540114934601547}, {-1., 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{-1., 0.8909958270419003, 0.4540114934601547}, {-0.75, 
      0.8909958270419003, 0.4540114934601547}, {-0.75, 0.808998528157412, 
      0.5878106680208697}, {-1., 0.808998528157412, 0.5878106680208697}, {-1.,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-1., 0.8089985281574118, 0.58781066802087}, {-0.75, 
      0.8089985281574118, 0.58781066802087}, {-0.75, 0.7070790126229676, 
      0.70713454865968}, {-1., 0.7070790126229676, 0.70713454865968}, {-1., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-1., 0.7070790126229676, 0.70713454865968}, {-0.75, 
      0.7070790126229676, 0.70713454865968}, {-0.75, 0.5877471276121592, 
      0.8090446922041181}, {-1., 0.5877471276121592, 
      0.8090446922041181}, {-1., 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-1., 0.5877471276121592, 0.8090446922041181}, {-0.75, 
      0.5877471276121592, 0.8090446922041181}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}, {-1., 0.45394151341132644`, 
      0.8910314822731207}, {-1., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-1., 0.45394151341132644`, 0.8910314822731207}, {-0.75, 
      0.45394151341132644`, 0.8910314822731207}, {-0.75, 0.3089572371217171, 
      0.9510759305282176}, {-1., 0.3089572371217171, 
      0.9510759305282176}, {-1., 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{-1., 0.3089572371217171, 0.9510759305282176}, {-0.75, 
      0.3089572371217171, 0.9510759305282176}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}, {-1., 0.15636464907469383`, 
      0.9876993958283805}, {-1., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-1., 0.15636464907469383`, 0.9876993958283805}, {-0.75, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-1., -0.00007853981625862234, 
      0.9999999969157486}, {-1., 0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{-1., -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-1., -0.156519794603278, 
      0.9876748219415881}, {-1., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-1., -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.3091066279673126, 
      0.9510273879056678}, {-1., -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-1., -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.45408147070841254`, 
      0.8909601663145693}, {-1., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-1., -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.5878742048036691, 
      0.8089523591203958}, {-1., -0.45408147070841254`, 0.8909601663145693}}],
      Polygon3DBox[{{-1., -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-1., -0.707190080334431, 
      0.7070234722246362}, {-1., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-1., -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.8090908512602302, 
      0.5876835835779286}, {-1., -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-1., -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8910671320080111, 
      0.4538715305623583}, {-1., -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-1., -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.9511001930394957, 
      0.3088825388399836}, {-1., -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-1., -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9877116736328749, 
      0.15628707486335883`}, {-1., -0.9511001930394957, 0.3088825388399836}}],
      Polygon3DBox[{{-1., -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9999999876629945, \
-0.0001570796320327716}, {-1., -0.9999999876629945, -0.0001570796320327716}, \
{-1., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-0.75, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.5, -0.987711673632875, \
-0.15628707486335794`}, {-0.75, -0.987711673632875, -0.15628707486335794`}, \
{-0.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.75, -0.987711673632875, -0.15628707486335794`}, {-0.5, \
-0.987711673632875, -0.15628707486335794`}, {-0.5, -0.951100193039496, \
-0.3088825388399828}, {-0.75, -0.951100193039496, -0.3088825388399828}, \
{-0.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-0.75, -0.951100193039496, -0.3088825388399828}, {-0.5, \
-0.951100193039496, -0.3088825388399828}, {-0.5, -0.8910671320080115, \
-0.4538715305623575}, {-0.75, -0.8910671320080115, -0.4538715305623575}, \
{-0.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-0.75, -0.8910671320080115, -0.4538715305623575}, {-0.5, \
-0.8910671320080115, -0.4538715305623575}, {-0.5, -0.8090908512602306, \
-0.5876835835779278}, {-0.75, -0.8090908512602306, -0.5876835835779278}, \
{-0.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-0.75, -0.8090908512602306, -0.5876835835779278}, {-0.5, \
-0.8090908512602306, -0.5876835835779278}, {-0.5, -0.7071900803344316, \
-0.7070234722246357}, {-0.75, -0.7071900803344316, -0.7070234722246357}, \
{-0.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-0.75, -0.7071900803344316, -0.7070234722246357}, {-0.5, \
-0.7071900803344316, -0.7070234722246357}, {-0.5, -0.5878742048036698, \
-0.8089523591203952}, {-0.75, -0.5878742048036698, -0.8089523591203952}, \
{-0.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-0.75, -0.5878742048036698, -0.8089523591203952}, {-0.5, \
-0.5878742048036698, -0.8089523591203952}, {-0.5, -0.45408147070841337`, \
-0.890960166314569}, {-0.75, -0.45408147070841337`, -0.890960166314569}, \
{-0.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-0.75, -0.45408147070841337`, -0.890960166314569}, {-0.5, \
-0.45408147070841337`, -0.890960166314569}, {-0.5, -0.3091066279673134, \
-0.9510273879056674}, {-0.75, -0.3091066279673134, -0.9510273879056674}, \
{-0.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-0.75, -0.3091066279673132, -0.9510273879056675}, {-0.5, \
-0.3091066279673132, -0.9510273879056675}, {-0.5, -0.15651979460327867`, \
-0.987674821941588}, {-0.75, -0.15651979460327867`, -0.987674821941588}, \
{-0.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-0.75, -0.15651979460327867`, -0.987674821941588}, {-0.5, \
-0.15651979460327867`, -0.987674821941588}, {-0.5, -0.00007853981625928847, \
-0.9999999969157486}, {-0.75, -0.00007853981625928847, -0.9999999969157486}, \
{-0.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-0.75, -0.00007853981625928847, -0.9999999969157486}, \
{-0.5, -0.00007853981625928847, -0.9999999969157486}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}, {-0.75, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.75, 0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.30895723712171647`, -0.9510759305282178}, {-0.75, 
      0.30895723712171647`, -0.9510759305282178}, {-0.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.75, 0.3089572371217167, -0.9510759305282178}, {-0.5, 
      0.3089572371217167, -0.9510759305282178}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.453941513411326, -0.8910314822731209}, {-0.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.75, 0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}, {-0.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.75, 0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}, {-0.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.75, 0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}, {-0.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.75, 0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}, {-0.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.75, 0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.951051662150225, -0.3090319334976474}, {-0.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.75, 0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.9876871119312596, -0.15644222232149346`}, {-0.75, 
      0.9876871119312596, -0.15644222232149346`}, {-0.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.75, 0.9876871119312596, -0.1564422223214935}, {-0.5, 
      0.9876871119312596, -0.1564422223214935}, {-0.5, 
      1., -4.163336342344337*^-16}, {-0.75, 
      1., -4.163336342344337*^-16}, {-0.75, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.75, 1., -4.440892098500626*^-16}, {-0.5, 
      1., -4.440892098500626*^-16}, {-0.5, 0.9876871119312597, 
      0.15644222232149263`}, {-0.75, 0.9876871119312597, 
      0.15644222232149263`}, {-0.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.75, 0.9876871119312597, 0.1564422223214926}, {-0.5, 
      0.9876871119312597, 0.1564422223214926}, {-0.5, 0.9510516621502252, 
      0.30903193349764657`}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}, {-0.75, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-0.75, 0.9510516621502252, 0.30903193349764657`}, {-0.5, 
      0.9510516621502252, 0.30903193349764657`}, {-0.5, 0.8909958270419003, 
      0.4540114934601547}, {-0.75, 0.8909958270419003, 
      0.4540114934601547}, {-0.75, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-0.75, 0.8909958270419003, 0.4540114934601547}, {-0.5, 
      0.8909958270419003, 0.4540114934601547}, {-0.5, 0.808998528157412, 
      0.5878106680208697}, {-0.75, 0.808998528157412, 
      0.5878106680208697}, {-0.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.75, 0.8089985281574118, 0.58781066802087}, {-0.5, 
      0.8089985281574118, 0.58781066802087}, {-0.5, 0.7070790126229676, 
      0.70713454865968}, {-0.75, 0.7070790126229676, 
      0.70713454865968}, {-0.75, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.75, 0.7070790126229676, 0.70713454865968}, {-0.5, 
      0.7070790126229676, 0.70713454865968}, {-0.5, 0.5877471276121592, 
      0.8090446922041181}, {-0.75, 0.5877471276121592, 
      0.8090446922041181}, {-0.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.75, 0.5877471276121592, 0.8090446922041181}, {-0.5, 
      0.5877471276121592, 0.8090446922041181}, {-0.5, 0.45394151341132644`, 
      0.8910314822731207}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}, {-0.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.75, 0.45394151341132644`, 0.8910314822731207}, {-0.5, 
      0.45394151341132644`, 0.8910314822731207}, {-0.5, 0.3089572371217171, 
      0.9510759305282176}, {-0.75, 0.3089572371217171, 
      0.9510759305282176}, {-0.75, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-0.75, 0.3089572371217171, 0.9510759305282176}, {-0.5, 
      0.3089572371217171, 0.9510759305282176}, {-0.5, 0.15636464907469383`, 
      0.9876993958283805}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}, {-0.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.75, 0.15636464907469383`, 0.9876993958283805}, {-0.5, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.75, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-0.75, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.75, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.75, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.75, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-0.75, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.75, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.75, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.75, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-0.75, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.75, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.75, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-0.75, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.75, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-0.75, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.75, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9999999876629945, \
-0.0001570796320327716}, {-0.75, -0.9999999876629945, \
-0.0001570796320327716}, {-0.75, -0.9877116736328749, 0.15628707486335883`}}],
      Polygon3DBox[{{-0.5, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.25, -0.9999999876629945, 
      0.00015707963203365978`}, {-0.25, -0.987711673632875, \
-0.15628707486335794`}, {-0.5, -0.987711673632875, -0.15628707486335794`}, \
{-0.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.5, -0.987711673632875, -0.15628707486335794`}, {-0.25, \
-0.987711673632875, -0.15628707486335794`}, {-0.25, -0.951100193039496, \
-0.3088825388399828}, {-0.5, -0.951100193039496, -0.3088825388399828}, {-0.5, \
-0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{-0.5, -0.951100193039496, -0.3088825388399828}, {-0.25, \
-0.951100193039496, -0.3088825388399828}, {-0.25, -0.8910671320080115, \
-0.4538715305623575}, {-0.5, -0.8910671320080115, -0.4538715305623575}, \
{-0.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{-0.5, -0.8910671320080115, -0.4538715305623575}, {-0.25, \
-0.8910671320080115, -0.4538715305623575}, {-0.25, -0.8090908512602306, \
-0.5876835835779278}, {-0.5, -0.8090908512602306, -0.5876835835779278}, \
{-0.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{-0.5, -0.8090908512602306, -0.5876835835779278}, {-0.25, \
-0.8090908512602306, -0.5876835835779278}, {-0.25, -0.7071900803344316, \
-0.7070234722246357}, {-0.5, -0.7071900803344316, -0.7070234722246357}, \
{-0.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{-0.5, -0.7071900803344316, -0.7070234722246357}, {-0.25, \
-0.7071900803344316, -0.7070234722246357}, {-0.25, -0.5878742048036698, \
-0.8089523591203952}, {-0.5, -0.5878742048036698, -0.8089523591203952}, \
{-0.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{-0.5, -0.5878742048036698, -0.8089523591203952}, {-0.25, \
-0.5878742048036698, -0.8089523591203952}, {-0.25, -0.45408147070841337`, \
-0.890960166314569}, {-0.5, -0.45408147070841337`, -0.890960166314569}, \
{-0.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{-0.5, -0.45408147070841337`, -0.890960166314569}, {-0.25, \
-0.45408147070841337`, -0.890960166314569}, {-0.25, -0.3091066279673134, \
-0.9510273879056674}, {-0.5, -0.3091066279673134, -0.9510273879056674}, \
{-0.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{-0.5, -0.3091066279673132, -0.9510273879056675}, {-0.25, \
-0.3091066279673132, -0.9510273879056675}, {-0.25, -0.15651979460327867`, \
-0.987674821941588}, {-0.5, -0.15651979460327867`, -0.987674821941588}, \
{-0.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{-0.5, -0.15651979460327867`, -0.987674821941588}, {-0.25, \
-0.15651979460327867`, -0.987674821941588}, {-0.25, -0.00007853981625928847, \
-0.9999999969157486}, {-0.5, -0.00007853981625928847, -0.9999999969157486}, \
{-0.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{-0.5, -0.00007853981625928847, -0.9999999969157486}, \
{-0.25, -0.00007853981625928847, -0.9999999969157486}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}, {-0.5, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.5, 0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.30895723712171647`, -0.9510759305282178}, {-0.5, 
      0.30895723712171647`, -0.9510759305282178}, {-0.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.5, 0.3089572371217167, -0.9510759305282178}, {-0.25, 
      0.3089572371217167, -0.9510759305282178}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.453941513411326, -0.8910314822731209}, {-0.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.5, 0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}, {-0.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.5, 0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}, {-0.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.5, 0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}, {-0.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.5, 0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}, {-0.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.5, 0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.951051662150225, -0.3090319334976474}, {-0.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.5, 0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.9876871119312596, -0.15644222232149346`}, {-0.5, 
      0.9876871119312596, -0.15644222232149346`}, {-0.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.5, 0.9876871119312596, -0.1564422223214935}, {-0.25, 
      0.9876871119312596, -0.1564422223214935}, {-0.25, 
      1., -4.163336342344337*^-16}, {-0.5, 
      1., -4.163336342344337*^-16}, {-0.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.5, 1., -4.440892098500626*^-16}, {-0.25, 
      1., -4.440892098500626*^-16}, {-0.25, 0.9876871119312597, 
      0.15644222232149263`}, {-0.5, 0.9876871119312597, 
      0.15644222232149263`}, {-0.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.5, 0.9876871119312597, 0.1564422223214926}, {-0.25, 
      0.9876871119312597, 0.1564422223214926}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}, {-0.5, 0.9510516621502252, 
      0.30903193349764657`}, {-0.5, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{-0.5, 0.9510516621502252, 0.30903193349764657`}, {-0.25, 
      0.9510516621502252, 0.30903193349764657`}, {-0.25, 0.8909958270419003, 
      0.4540114934601547}, {-0.5, 0.8909958270419003, 
      0.4540114934601547}, {-0.5, 0.9510516621502252, 0.30903193349764657`}}],
      Polygon3DBox[{{-0.5, 0.8909958270419003, 0.4540114934601547}, {-0.25, 
      0.8909958270419003, 0.4540114934601547}, {-0.25, 0.808998528157412, 
      0.5878106680208697}, {-0.5, 0.808998528157412, 
      0.5878106680208697}, {-0.5, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.5, 0.8089985281574118, 0.58781066802087}, {-0.25, 
      0.8089985281574118, 0.58781066802087}, {-0.25, 0.7070790126229676, 
      0.70713454865968}, {-0.5, 0.7070790126229676, 0.70713454865968}, {-0.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.5, 0.7070790126229676, 0.70713454865968}, {-0.25, 
      0.7070790126229676, 0.70713454865968}, {-0.25, 0.5877471276121592, 
      0.8090446922041181}, {-0.5, 0.5877471276121592, 
      0.8090446922041181}, {-0.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.5, 0.5877471276121592, 0.8090446922041181}, {-0.25, 
      0.5877471276121592, 0.8090446922041181}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}, {-0.5, 0.45394151341132644`, 
      0.8910314822731207}, {-0.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.5, 0.45394151341132644`, 0.8910314822731207}, {-0.25, 
      0.45394151341132644`, 0.8910314822731207}, {-0.25, 0.3089572371217171, 
      0.9510759305282176}, {-0.5, 0.3089572371217171, 
      0.9510759305282176}, {-0.5, 0.45394151341132644`, 0.8910314822731207}}],
      Polygon3DBox[{{-0.5, 0.3089572371217171, 0.9510759305282176}, {-0.25, 
      0.3089572371217171, 0.9510759305282176}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}, {-0.5, 0.15636464907469383`, 
      0.9876993958283805}, {-0.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.5, 0.15636464907469383`, 0.9876993958283805}, {-0.25, 
      0.15636464907469383`, 
      0.9876993958283805}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.5, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{-0.5, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.5, -0.156519794603278, 
      0.9876748219415881}, {-0.25, -0.156519794603278, 
      0.9876748219415881}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.5, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.5, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{-0.5, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.5, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.5, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{-0.5, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.5, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.5, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{-0.5, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{-0.5, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.5, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.5, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9999999876629945, \
-0.0001570796320327716}, {-0.5, -0.9999999876629945, -0.0001570796320327716}, \
{-0.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{-0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0., -0.9999999876629945, 0.00015707963203365978`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {-0.25, \
-0.987711673632875, -0.15628707486335794`}, {-0.25, -0.9999999876629945, 
      0.00015707963203365978`}}], 
     Polygon3DBox[{{-0.25, -0.987711673632875, -0.15628707486335794`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {
      0., -0.951100193039496, -0.3088825388399828}, {-0.25, \
-0.951100193039496, -0.3088825388399828}, {-0.25, -0.987711673632875, \
-0.15628707486335794`}}], 
     Polygon3DBox[{{-0.25, -0.951100193039496, -0.3088825388399828}, {
      0., -0.951100193039496, -0.3088825388399828}, {
      0., -0.8910671320080115, -0.4538715305623575}, {-0.25, \
-0.8910671320080115, -0.4538715305623575}, {-0.25, -0.951100193039496, \
-0.3088825388399828}}], 
     Polygon3DBox[{{-0.25, -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8090908512602306, -0.5876835835779278}, {-0.25, \
-0.8090908512602306, -0.5876835835779278}, {-0.25, -0.8910671320080115, \
-0.4538715305623575}}], 
     Polygon3DBox[{{-0.25, -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8090908512602306, -0.5876835835779278}, {
      0., -0.7071900803344316, -0.7070234722246357}, {-0.25, \
-0.7071900803344316, -0.7070234722246357}, {-0.25, -0.8090908512602306, \
-0.5876835835779278}}], 
     Polygon3DBox[{{-0.25, -0.7071900803344316, -0.7070234722246357}, {
      0., -0.7071900803344316, -0.7070234722246357}, {
      0., -0.5878742048036698, -0.8089523591203952}, {-0.25, \
-0.5878742048036698, -0.8089523591203952}, {-0.25, -0.7071900803344316, \
-0.7070234722246357}}], 
     Polygon3DBox[{{-0.25, -0.5878742048036698, -0.8089523591203952}, {
      0., -0.5878742048036698, -0.8089523591203952}, {
      0., -0.45408147070841337`, -0.890960166314569}, {-0.25, \
-0.45408147070841337`, -0.890960166314569}, {-0.25, -0.5878742048036698, \
-0.8089523591203952}}], 
     Polygon3DBox[{{-0.25, -0.45408147070841337`, -0.890960166314569}, {
      0., -0.45408147070841337`, -0.890960166314569}, {
      0., -0.3091066279673134, -0.9510273879056674}, {-0.25, \
-0.3091066279673134, -0.9510273879056674}, {-0.25, -0.45408147070841337`, \
-0.890960166314569}}], 
     Polygon3DBox[{{-0.25, -0.3091066279673132, -0.9510273879056675}, {
      0., -0.3091066279673132, -0.9510273879056675}, {
      0., -0.15651979460327867`, -0.987674821941588}, {-0.25, \
-0.15651979460327867`, -0.987674821941588}, {-0.25, -0.3091066279673132, \
-0.9510273879056675}}], 
     Polygon3DBox[{{-0.25, -0.15651979460327867`, -0.987674821941588}, {
      0., -0.15651979460327867`, -0.987674821941588}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {-0.25, \
-0.00007853981625928847, -0.9999999969157486}, {-0.25, -0.15651979460327867`, \
-0.987674821941588}}], 
     Polygon3DBox[{{-0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}, {-0.25, \
-0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{-0.25, 0.15636464907469316`, -0.9876993958283806}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {0., 
      0.30895723712171647`, -0.9510759305282178}, {-0.25, 
      0.30895723712171647`, -0.9510759305282178}, {-0.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{-0.25, 0.3089572371217167, -0.9510759305282178}, {0., 
      0.3089572371217167, -0.9510759305282178}, {0., 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.453941513411326, -0.8910314822731209}, {-0.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{-0.25, 0.453941513411326, -0.8910314822731209}, {0., 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}, {-0.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{-0.25, 0.5877471276121589, -0.8090446922041185}, {0., 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}, {-0.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{-0.25, 0.7070790126229672, -0.7071345486596803}, {0., 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}, {-0.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{-0.25, 0.8089985281574115, -0.5878106680208703}, {0., 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}, {-0.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{-0.25, 0.8909958270419, -0.45401149346015546`}, {0., 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.951051662150225, -0.3090319334976474}, {-0.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{-0.25, 0.951051662150225, -0.3090319334976474}, {0., 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.9876871119312596, -0.15644222232149346`}, {-0.25, 
      0.9876871119312596, -0.15644222232149346`}, {-0.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{-0.25, 0.9876871119312596, -0.1564422223214935}, {0., 
      0.9876871119312596, -0.1564422223214935}, {0., 
      1., -4.163336342344337*^-16}, {-0.25, 
      1., -4.163336342344337*^-16}, {-0.25, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{-0.25, 1., -4.440892098500626*^-16}, {0., 
      1., -4.440892098500626*^-16}, {0., 0.9876871119312597, 
      0.15644222232149263`}, {-0.25, 0.9876871119312597, 
      0.15644222232149263`}, {-0.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{-0.25, 0.9876871119312597, 0.1564422223214926}, {0., 
      0.9876871119312597, 0.1564422223214926}, {0., 0.9510516621502252, 
      0.30903193349764657`}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}, {-0.25, 0.9876871119312597, 
      0.1564422223214926}}], 
     Polygon3DBox[{{-0.25, 0.9510516621502252, 0.30903193349764657`}, {0., 
      0.9510516621502252, 0.30903193349764657`}, {0., 0.8909958270419003, 
      0.4540114934601547}, {-0.25, 0.8909958270419003, 
      0.4540114934601547}, {-0.25, 0.9510516621502252, 
      0.30903193349764657`}}], 
     Polygon3DBox[{{-0.25, 0.8909958270419003, 0.4540114934601547}, {0., 
      0.8909958270419003, 0.4540114934601547}, {0., 0.808998528157412, 
      0.5878106680208697}, {-0.25, 0.808998528157412, 
      0.5878106680208697}, {-0.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{-0.25, 0.8089985281574118, 0.58781066802087}, {0., 
      0.8089985281574118, 0.58781066802087}, {0., 0.7070790126229676, 
      0.70713454865968}, {-0.25, 0.7070790126229676, 
      0.70713454865968}, {-0.25, 0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{-0.25, 0.7070790126229676, 0.70713454865968}, {0., 
      0.7070790126229676, 0.70713454865968}, {0., 0.5877471276121592, 
      0.8090446922041181}, {-0.25, 0.5877471276121592, 
      0.8090446922041181}, {-0.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{-0.25, 0.5877471276121592, 0.8090446922041181}, {0., 
      0.5877471276121592, 0.8090446922041181}, {0., 0.45394151341132644`, 
      0.8910314822731207}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}, {-0.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{-0.25, 0.45394151341132644`, 0.8910314822731207}, {0., 
      0.45394151341132644`, 0.8910314822731207}, {0., 0.3089572371217171, 
      0.9510759305282176}, {-0.25, 0.3089572371217171, 
      0.9510759305282176}, {-0.25, 0.45394151341132644`, 
      0.8910314822731207}}], 
     Polygon3DBox[{{-0.25, 0.3089572371217171, 0.9510759305282176}, {0., 
      0.3089572371217171, 0.9510759305282176}, {0., 0.15636464907469383`, 
      0.9876993958283805}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}, {-0.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{-0.25, 0.15636464907469383`, 0.9876993958283805}, {0., 
      0.15636464907469383`, 0.9876993958283805}, {0., -0.00007853981625862234,
       0.9999999969157486}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}, {-0.25, 0.15636464907469383`, 
      0.9876993958283805}}], 
     Polygon3DBox[{{-0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.156519794603278, 0.9876748219415881}, {-0.25, -0.156519794603278,
       0.9876748219415881}, {-0.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{-0.25, -0.156519794603278, 0.9876748219415881}, {
      0., -0.156519794603278, 0.9876748219415881}, {0., -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.3091066279673126, 
      0.9510273879056678}, {-0.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{-0.25, -0.3091066279673126, 0.9510273879056678}, {
      0., -0.3091066279673126, 0.9510273879056678}, {
      0., -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}, {-0.25, -0.3091066279673126, 0.9510273879056678}}],
      Polygon3DBox[{{-0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.5878742048036691, 
      0.8089523591203958}, {-0.25, -0.45408147070841254`, 
      0.8909601663145693}}], 
     Polygon3DBox[{{-0.25, -0.5878742048036691, 0.8089523591203958}, {
      0., -0.5878742048036691, 0.8089523591203958}, {0., -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.707190080334431, 
      0.7070234722246362}, {-0.25, -0.5878742048036691, 0.8089523591203958}}],
      Polygon3DBox[{{-0.25, -0.707190080334431, 0.7070234722246362}, {
      0., -0.707190080334431, 0.7070234722246362}, {0., -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.8090908512602302, 
      0.5876835835779286}, {-0.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{-0.25, -0.8090908512602302, 0.5876835835779286}, {
      0., -0.8090908512602302, 0.5876835835779286}, {0., -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8910671320080111, 
      0.4538715305623583}, {-0.25, -0.8090908512602302, 0.5876835835779286}}],
      Polygon3DBox[{{-0.25, -0.8910671320080111, 0.4538715305623583}, {
      0., -0.8910671320080111, 0.4538715305623583}, {0., -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}, {-0.25, -0.8910671320080111, 0.4538715305623583}}],
      Polygon3DBox[{{-0.25, -0.9511001930394957, 0.3088825388399836}, {
      0., -0.9511001930394957, 0.3088825388399836}, {0., -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}, {-0.25, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{-0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9999999876629945, -0.0001570796320327716}, {-0.25, \
-0.9999999876629945, -0.0001570796320327716}, {-0.25, -0.9877116736328749, 
      0.15628707486335883`}}], 
     Polygon3DBox[{{0., -0.9999999876629945, 0.00015707963203365978`}, {
      0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0., -0.987711673632875, -0.15628707486335794`}, {
      0., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0., -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0., -0.951100193039496, -0.3088825388399828}, {
      0., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0., -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0., -0.8910671320080115, -0.4538715305623575}, {
      0., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0., -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8090908512602306, -0.5876835835779278}, {
      0., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0., -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0., -0.7071900803344316, -0.7070234722246357}, {
      0., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0., -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0., -0.5878742048036698, -0.8089523591203952}, {
      0., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0., -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0., -0.45408147070841337`, -0.890960166314569}, {
      0., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0., -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.3091066279673134, -0.9510273879056674}, {
      0., -0.3091066279673134, -0.9510273879056674}, {
      0., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0., -0.3091066279673132, -0.9510273879056675}, {
      0.25, -0.3091066279673132, -0.9510273879056675}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0., -0.15651979460327867`, -0.987674821941588}, {
      0., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0., -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.00007853981625928847, -0.9999999969157486}, {
      0., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0., -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {0., 
      0.15636464907469316`, -0.9876993958283806}, {
      0., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0., 0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.30895723712171647`, -0.9510759305282178}, {0., 
      0.30895723712171647`, -0.9510759305282178}, {0., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0., 0.3089572371217167, -0.9510759305282178}, {0.25, 
      0.3089572371217167, -0.9510759305282178}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.453941513411326, -0.8910314822731209}, {0., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0., 0.453941513411326, -0.8910314822731209}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.5877471276121589, -0.8090446922041185}, {0., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0., 0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.7070790126229672, -0.7071345486596803}, {0., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0., 0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.8089985281574115, -0.5878106680208703}, {0., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0., 0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.8909958270419, -0.45401149346015546`}, {0., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0., 0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.951051662150225, -0.3090319334976474}, {0., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0., 0.951051662150225, -0.3090319334976474}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.9876871119312596, -0.15644222232149346`}, {0., 
      0.9876871119312596, -0.15644222232149346`}, {0., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0., 0.9876871119312596, -0.1564422223214935}, {0.25, 
      0.9876871119312596, -0.1564422223214935}, {0.25, 
      1., -4.163336342344337*^-16}, {0., 1., -4.163336342344337*^-16}, {0., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0., 1., -4.440892098500626*^-16}, {0.25, 
      1., -4.440892098500626*^-16}, {0.25, 0.9876871119312597, 
      0.15644222232149263`}, {0., 0.9876871119312597, 0.15644222232149263`}, {
      0., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0., 0.9876871119312597, 0.1564422223214926}, {0.25, 
      0.9876871119312597, 0.1564422223214926}, {0.25, 0.9510516621502252, 
      0.30903193349764657`}, {0., 0.9510516621502252, 0.30903193349764657`}, {
      0., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{0., 0.9510516621502252, 0.30903193349764657`}, {0.25, 
      0.9510516621502252, 0.30903193349764657`}, {0.25, 0.8909958270419003, 
      0.4540114934601547}, {0., 0.8909958270419003, 0.4540114934601547}, {0., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0., 0.8909958270419003, 0.4540114934601547}, {0.25, 
      0.8909958270419003, 0.4540114934601547}, {0.25, 0.808998528157412, 
      0.5878106680208697}, {0., 0.808998528157412, 0.5878106680208697}, {0., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0., 0.8089985281574118, 0.58781066802087}, {0.25, 
      0.8089985281574118, 0.58781066802087}, {0.25, 0.7070790126229676, 
      0.70713454865968}, {0., 0.7070790126229676, 0.70713454865968}, {0., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0., 0.7070790126229676, 0.70713454865968}, {0.25, 
      0.7070790126229676, 0.70713454865968}, {0.25, 0.5877471276121592, 
      0.8090446922041181}, {0., 0.5877471276121592, 0.8090446922041181}, {0., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0., 0.5877471276121592, 0.8090446922041181}, {0.25, 
      0.5877471276121592, 0.8090446922041181}, {0.25, 0.45394151341132644`, 
      0.8910314822731207}, {0., 0.45394151341132644`, 0.8910314822731207}, {
      0., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0., 0.45394151341132644`, 0.8910314822731207}, {0.25, 
      0.45394151341132644`, 0.8910314822731207}, {0.25, 0.3089572371217171, 
      0.9510759305282176}, {0., 0.3089572371217171, 0.9510759305282176}, {0., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0., 0.3089572371217171, 0.9510759305282176}, {0.25, 
      0.3089572371217171, 0.9510759305282176}, {0.25, 0.15636464907469383`, 
      0.9876993958283805}, {0., 0.15636464907469383`, 0.9876993958283805}, {
      0., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0., 0.15636464907469383`, 0.9876993958283805}, {0.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0., -0.00007853981625862234, 0.9999999969157486}, {0., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0., -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.156519794603278, 0.9876748219415881}, {0., -0.156519794603278, 
      0.9876748219415881}, {0., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0., -0.156519794603278, 0.9876748219415881}, {
      0.25, -0.156519794603278, 0.9876748219415881}, {
      0.25, -0.3091066279673126, 0.9510273879056678}, {
      0., -0.3091066279673126, 0.9510273879056678}, {0., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{0., -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.45408147070841254`, 0.8909601663145693}, {
      0., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0., -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0., -0.5878742048036691, 0.8089523591203958}, {
      0., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0., -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.707190080334431, 0.7070234722246362}, {0., -0.707190080334431, 
      0.7070234722246362}, {0., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0., -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.8090908512602302, 0.5876835835779286}, {
      0., -0.8090908512602302, 0.5876835835779286}, {0., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{0., -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0., -0.8910671320080111, 0.4538715305623583}, {0., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{0., -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0., -0.9511001930394957, 0.3088825388399836}, {0., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{0., -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9877116736328749, 0.15628707486335883`}, {
      0., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0., -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9999999876629945, -0.0001570796320327716}, {
      0., -0.9999999876629945, -0.0001570796320327716}, {
      0., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.25, -0.9999999876629945, 0.00015707963203365978`}, {
      0.5, -0.9999999876629945, 0.00015707963203365978`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.25, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.951100193039496, -0.3088825388399828}, {
      0.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.25, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.25, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.25, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.25, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.25, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.25, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.3091066279673134, -0.9510273879056674}, {
      0.25, -0.3091066279673134, -0.9510273879056674}, {
      0.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.25, -0.3091066279673132, -0.9510273879056675}, {
      0.5, -0.3091066279673132, -0.9510273879056675}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.25, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.25, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.25, 0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.30895723712171647`, -0.9510759305282178}, {0.25, 
      0.30895723712171647`, -0.9510759305282178}, {0.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.25, 0.3089572371217167, -0.9510759305282178}, {0.5, 
      0.3089572371217167, -0.9510759305282178}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.453941513411326, -0.8910314822731209}, {0.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.25, 0.453941513411326, -0.8910314822731209}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.5877471276121589, -0.8090446922041185}, {0.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.25, 0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.7070790126229672, -0.7071345486596803}, {0.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.25, 0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.8089985281574115, -0.5878106680208703}, {0.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.25, 0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8909958270419, -0.45401149346015546`}, {0.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.25, 0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.951051662150225, -0.3090319334976474}, {0.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.25, 0.951051662150225, -0.3090319334976474}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.9876871119312596, -0.15644222232149346`}, {0.25, 
      0.9876871119312596, -0.15644222232149346`}, {0.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.25, 0.9876871119312596, -0.1564422223214935}, {0.5, 
      0.9876871119312596, -0.1564422223214935}, {0.5, 
      1., -4.163336342344337*^-16}, {0.25, 1., -4.163336342344337*^-16}, {
      0.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.25, 1., -4.440892098500626*^-16}, {0.5, 
      1., -4.440892098500626*^-16}, {0.5, 0.9876871119312597, 
      0.15644222232149263`}, {0.25, 0.9876871119312597, 
      0.15644222232149263`}, {0.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.25, 0.9876871119312597, 0.1564422223214926}, {0.5, 
      0.9876871119312597, 0.1564422223214926}, {0.5, 0.9510516621502252, 
      0.30903193349764657`}, {0.25, 0.9510516621502252, 
      0.30903193349764657`}, {0.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{0.25, 0.9510516621502252, 0.30903193349764657`}, {0.5, 
      0.9510516621502252, 0.30903193349764657`}, {0.5, 0.8909958270419003, 
      0.4540114934601547}, {0.25, 0.8909958270419003, 0.4540114934601547}, {
      0.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.25, 0.8909958270419003, 0.4540114934601547}, {0.5, 
      0.8909958270419003, 0.4540114934601547}, {0.5, 0.808998528157412, 
      0.5878106680208697}, {0.25, 0.808998528157412, 0.5878106680208697}, {
      0.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.25, 0.8089985281574118, 0.58781066802087}, {0.5, 
      0.8089985281574118, 0.58781066802087}, {0.5, 0.7070790126229676, 
      0.70713454865968}, {0.25, 0.7070790126229676, 0.70713454865968}, {0.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.25, 0.7070790126229676, 0.70713454865968}, {0.5, 
      0.7070790126229676, 0.70713454865968}, {0.5, 0.5877471276121592, 
      0.8090446922041181}, {0.25, 0.5877471276121592, 0.8090446922041181}, {
      0.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.25, 0.5877471276121592, 0.8090446922041181}, {0.5, 
      0.5877471276121592, 0.8090446922041181}, {0.5, 0.45394151341132644`, 
      0.8910314822731207}, {0.25, 0.45394151341132644`, 0.8910314822731207}, {
      0.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.25, 0.45394151341132644`, 0.8910314822731207}, {0.5, 
      0.45394151341132644`, 0.8910314822731207}, {0.5, 0.3089572371217171, 
      0.9510759305282176}, {0.25, 0.3089572371217171, 0.9510759305282176}, {
      0.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.25, 0.3089572371217171, 0.9510759305282176}, {0.5, 
      0.3089572371217171, 0.9510759305282176}, {0.5, 0.15636464907469383`, 
      0.9876993958283805}, {0.25, 0.15636464907469383`, 0.9876993958283805}, {
      0.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.25, 0.15636464907469383`, 0.9876993958283805}, {0.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.25, -0.00007853981625862234, 0.9999999969157486}, {0.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0.25, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.156519794603278, 0.9876748219415881}, {0.25, -0.156519794603278,
       0.9876748219415881}, {0.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.25, -0.156519794603278, 0.9876748219415881}, {
      0.5, -0.156519794603278, 0.9876748219415881}, {0.5, -0.3091066279673126,
       0.9510273879056678}, {0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{0.25, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.25, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.25, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {0.5, -0.707190080334431,
       0.7070234722246362}, {0.25, -0.707190080334431, 0.7070234722246362}, {
      0.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.25, -0.707190080334431, 0.7070234722246362}, {
      0.5, -0.707190080334431, 0.7070234722246362}, {0.5, -0.8090908512602302,
       0.5876835835779286}, {0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{0.25, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.25, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.25, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0.25, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9999999876629945, -0.0001570796320327716}, {
      0.25, -0.9999999876629945, -0.0001570796320327716}, {
      0.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.5, -0.9999999876629945, 0.00015707963203365978`}, {
      0.75, -0.9999999876629945, 0.00015707963203365978`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.5, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.951100193039496, -0.3088825388399828}, {
      0.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.5, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.5, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.5, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.5, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.5, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.5, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.3091066279673134, -0.9510273879056674}, {
      0.5, -0.3091066279673134, -0.9510273879056674}, {
      0.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.5, -0.3091066279673132, -0.9510273879056675}, {
      0.75, -0.3091066279673132, -0.9510273879056675}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.5, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.5, -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.5, 0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.30895723712171647`, -0.9510759305282178}, {0.5, 
      0.30895723712171647`, -0.9510759305282178}, {0.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.5, 0.3089572371217167, -0.9510759305282178}, {0.75, 
      0.3089572371217167, -0.9510759305282178}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.453941513411326, -0.8910314822731209}, {0.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.5, 0.453941513411326, -0.8910314822731209}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.5877471276121589, -0.8090446922041185}, {0.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.5, 0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.7070790126229672, -0.7071345486596803}, {0.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.5, 0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.8089985281574115, -0.5878106680208703}, {0.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.5, 0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8909958270419, -0.45401149346015546`}, {0.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.5, 0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.951051662150225, -0.3090319334976474}, {0.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.5, 0.951051662150225, -0.3090319334976474}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.9876871119312596, -0.15644222232149346`}, {0.5, 
      0.9876871119312596, -0.15644222232149346`}, {0.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.5, 0.9876871119312596, -0.1564422223214935}, {0.75, 
      0.9876871119312596, -0.1564422223214935}, {0.75, 
      1., -4.163336342344337*^-16}, {0.5, 1., -4.163336342344337*^-16}, {0.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.5, 1., -4.440892098500626*^-16}, {0.75, 
      1., -4.440892098500626*^-16}, {0.75, 0.9876871119312597, 
      0.15644222232149263`}, {0.5, 0.9876871119312597, 
      0.15644222232149263`}, {0.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.5, 0.9876871119312597, 0.1564422223214926}, {0.75, 
      0.9876871119312597, 0.1564422223214926}, {0.75, 0.9510516621502252, 
      0.30903193349764657`}, {0.5, 0.9510516621502252, 
      0.30903193349764657`}, {0.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{0.5, 0.9510516621502252, 0.30903193349764657`}, {0.75, 
      0.9510516621502252, 0.30903193349764657`}, {0.75, 0.8909958270419003, 
      0.4540114934601547}, {0.5, 0.8909958270419003, 0.4540114934601547}, {
      0.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.5, 0.8909958270419003, 0.4540114934601547}, {0.75, 
      0.8909958270419003, 0.4540114934601547}, {0.75, 0.808998528157412, 
      0.5878106680208697}, {0.5, 0.808998528157412, 0.5878106680208697}, {0.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.5, 0.8089985281574118, 0.58781066802087}, {0.75, 
      0.8089985281574118, 0.58781066802087}, {0.75, 0.7070790126229676, 
      0.70713454865968}, {0.5, 0.7070790126229676, 0.70713454865968}, {0.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.5, 0.7070790126229676, 0.70713454865968}, {0.75, 
      0.7070790126229676, 0.70713454865968}, {0.75, 0.5877471276121592, 
      0.8090446922041181}, {0.5, 0.5877471276121592, 0.8090446922041181}, {
      0.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.5, 0.5877471276121592, 0.8090446922041181}, {0.75, 
      0.5877471276121592, 0.8090446922041181}, {0.75, 0.45394151341132644`, 
      0.8910314822731207}, {0.5, 0.45394151341132644`, 0.8910314822731207}, {
      0.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.5, 0.45394151341132644`, 0.8910314822731207}, {0.75, 
      0.45394151341132644`, 0.8910314822731207}, {0.75, 0.3089572371217171, 
      0.9510759305282176}, {0.5, 0.3089572371217171, 0.9510759305282176}, {
      0.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.5, 0.3089572371217171, 0.9510759305282176}, {0.75, 
      0.3089572371217171, 0.9510759305282176}, {0.75, 0.15636464907469383`, 
      0.9876993958283805}, {0.5, 0.15636464907469383`, 0.9876993958283805}, {
      0.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.5, 0.15636464907469383`, 0.9876993958283805}, {0.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      0.75, -0.00007853981625862234, 0.9999999969157486}, {
      0.5, -0.00007853981625862234, 0.9999999969157486}, {0.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{0.5, -0.00007853981625862234, 0.9999999969157486}, {
      0.75, -0.00007853981625862234, 0.9999999969157486}, {
      0.75, -0.156519794603278, 0.9876748219415881}, {0.5, -0.156519794603278,
       0.9876748219415881}, {0.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.5, -0.156519794603278, 0.9876748219415881}, {
      0.75, -0.156519794603278, 0.9876748219415881}, {
      0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.5, -0.3091066279673126, 0.9510273879056678}, {0.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{0.5, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.5, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.5, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.707190080334431, 0.7070234722246362}, {0.5, -0.707190080334431,
       0.7070234722246362}, {0.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.5, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.5, -0.8090908512602302, 0.5876835835779286}, {0.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{0.5, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.5, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.5, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{0.5, -0.9877116736328749, 0.15628707486335883`}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}, {
      0.75, -0.9999999876629945, -0.0001570796320327716}, {
      0.5, -0.9999999876629945, -0.0001570796320327716}, {
      0.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{0.75, -0.9999999876629945, 0.00015707963203365978`}, {
      1., -0.9999999876629945, 0.00015707963203365978`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.987711673632875, -0.15628707486335794`}, {
      0.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{0.75, -0.987711673632875, -0.15628707486335794`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.951100193039496, -0.3088825388399828}, {
      0.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{0.75, -0.951100193039496, -0.3088825388399828}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.8910671320080115, -0.4538715305623575}, {
      0.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{0.75, -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8090908512602306, -0.5876835835779278}, {
      0.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{0.75, -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.7071900803344316, -0.7070234722246357}, {
      0.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{0.75, -0.7071900803344316, -0.7070234722246357}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.5878742048036698, -0.8089523591203952}, {
      0.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{0.75, -0.5878742048036698, -0.8089523591203952}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.45408147070841337`, -0.890960166314569}, {
      0.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{0.75, -0.45408147070841337`, -0.890960166314569}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      1., -0.3091066279673134, -0.9510273879056674}, {
      0.75, -0.3091066279673134, -0.9510273879056674}, {
      0.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{0.75, -0.3091066279673132, -0.9510273879056675}, {
      1., -0.3091066279673132, -0.9510273879056675}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.15651979460327867`, -0.987674821941588}, {
      0.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{0.75, -0.15651979460327867`, -0.987674821941588}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}, {
      0.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{0.75, -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      0.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{0.75, 0.15636464907469316`, -0.9876993958283806}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {1., 
      0.30895723712171647`, -0.9510759305282178}, {0.75, 
      0.30895723712171647`, -0.9510759305282178}, {0.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{0.75, 0.3089572371217167, -0.9510759305282178}, {1., 
      0.3089572371217167, -0.9510759305282178}, {1., 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.453941513411326, -0.8910314822731209}, {0.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{0.75, 0.453941513411326, -0.8910314822731209}, {1., 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.5877471276121589, -0.8090446922041185}, {0.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{0.75, 0.5877471276121589, -0.8090446922041185}, {1., 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.7070790126229672, -0.7071345486596803}, {0.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{0.75, 0.7070790126229672, -0.7071345486596803}, {1., 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.8089985281574115, -0.5878106680208703}, {0.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{0.75, 0.8089985281574115, -0.5878106680208703}, {1., 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8909958270419, -0.45401149346015546`}, {0.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{0.75, 0.8909958270419, -0.45401149346015546`}, {1., 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.951051662150225, -0.3090319334976474}, {0.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{0.75, 0.951051662150225, -0.3090319334976474}, {1., 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.9876871119312596, -0.15644222232149346`}, {0.75, 
      0.9876871119312596, -0.15644222232149346`}, {0.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{0.75, 0.9876871119312596, -0.1564422223214935}, {1., 
      0.9876871119312596, -0.1564422223214935}, {1., 
      1., -4.163336342344337*^-16}, {0.75, 1., -4.163336342344337*^-16}, {
      0.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{0.75, 1., -4.440892098500626*^-16}, {1., 
      1., -4.440892098500626*^-16}, {1., 0.9876871119312597, 
      0.15644222232149263`}, {0.75, 0.9876871119312597, 
      0.15644222232149263`}, {0.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{0.75, 0.9876871119312597, 0.1564422223214926}, {1., 
      0.9876871119312597, 0.1564422223214926}, {1., 0.9510516621502252, 
      0.30903193349764657`}, {0.75, 0.9510516621502252, 
      0.30903193349764657`}, {0.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{0.75, 0.9510516621502252, 0.30903193349764657`}, {1., 
      0.9510516621502252, 0.30903193349764657`}, {1., 0.8909958270419003, 
      0.4540114934601547}, {0.75, 0.8909958270419003, 0.4540114934601547}, {
      0.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{0.75, 0.8909958270419003, 0.4540114934601547}, {1., 
      0.8909958270419003, 0.4540114934601547}, {1., 0.808998528157412, 
      0.5878106680208697}, {0.75, 0.808998528157412, 0.5878106680208697}, {
      0.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{0.75, 0.8089985281574118, 0.58781066802087}, {1., 
      0.8089985281574118, 0.58781066802087}, {1., 0.7070790126229676, 
      0.70713454865968}, {0.75, 0.7070790126229676, 0.70713454865968}, {0.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{0.75, 0.7070790126229676, 0.70713454865968}, {1., 
      0.7070790126229676, 0.70713454865968}, {1., 0.5877471276121592, 
      0.8090446922041181}, {0.75, 0.5877471276121592, 0.8090446922041181}, {
      0.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{0.75, 0.5877471276121592, 0.8090446922041181}, {1., 
      0.5877471276121592, 0.8090446922041181}, {1., 0.45394151341132644`, 
      0.8910314822731207}, {0.75, 0.45394151341132644`, 0.8910314822731207}, {
      0.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{0.75, 0.45394151341132644`, 0.8910314822731207}, {1., 
      0.45394151341132644`, 0.8910314822731207}, {1., 0.3089572371217171, 
      0.9510759305282176}, {0.75, 0.3089572371217171, 0.9510759305282176}, {
      0.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{0.75, 0.3089572371217171, 0.9510759305282176}, {1., 
      0.3089572371217171, 0.9510759305282176}, {1., 0.15636464907469383`, 
      0.9876993958283805}, {0.75, 0.15636464907469383`, 0.9876993958283805}, {
      0.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{0.75, 0.15636464907469383`, 0.9876993958283805}, {1., 
      0.15636464907469383`, 0.9876993958283805}, {1., -0.00007853981625862234,
       0.9999999969157486}, {0.75, -0.00007853981625862234, 
      0.9999999969157486}, {0.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{0.75, -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.156519794603278, 0.9876748219415881}, {0.75, -0.156519794603278, 
      0.9876748219415881}, {0.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{0.75, -0.156519794603278, 0.9876748219415881}, {
      1., -0.156519794603278, 0.9876748219415881}, {1., -0.3091066279673126, 
      0.9510273879056678}, {0.75, -0.3091066279673126, 0.9510273879056678}, {
      0.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{0.75, -0.3091066279673126, 0.9510273879056678}, {
      1., -0.3091066279673126, 0.9510273879056678}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}, {
      0.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{0.75, -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.5878742048036691, 0.8089523591203958}, {
      0.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{0.75, -0.5878742048036691, 0.8089523591203958}, {
      1., -0.5878742048036691, 0.8089523591203958}, {1., -0.707190080334431, 
      0.7070234722246362}, {0.75, -0.707190080334431, 0.7070234722246362}, {
      0.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{0.75, -0.707190080334431, 0.7070234722246362}, {
      1., -0.707190080334431, 0.7070234722246362}, {1., -0.8090908512602302, 
      0.5876835835779286}, {0.75, -0.8090908512602302, 0.5876835835779286}, {
      0.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{0.75, -0.8090908512602302, 0.5876835835779286}, {
      1., -0.8090908512602302, 0.5876835835779286}, {1., -0.8910671320080111, 
      0.4538715305623583}, {0.75, -0.8910671320080111, 0.4538715305623583}, {
      0.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{0.75, -0.8910671320080111, 0.4538715305623583}, {
      1., -0.8910671320080111, 0.4538715305623583}, {1., -0.9511001930394957, 
      0.3088825388399836}, {0.75, -0.9511001930394957, 0.3088825388399836}, {
      0.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{0.75, -0.9511001930394957, 0.3088825388399836}, {
      1., -0.9511001930394957, 0.3088825388399836}, {1., -0.9877116736328749, 
      0.15628707486335883`}, {0.75, -0.9877116736328749, 
      0.15628707486335883`}, {0.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{0.75, -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9999999876629945, -0.0001570796320327716}, {
      0.75, -0.9999999876629945, -0.0001570796320327716}, {
      0.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1., -0.9999999876629945, 0.00015707963203365978`}, {
      1.25, -0.9999999876629945, 0.00015707963203365978`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1., -0.987711673632875, -0.15628707486335794`}, {
      1., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1., -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1., -0.951100193039496, -0.3088825388399828}, {
      1., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1., -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1., -0.8910671320080115, -0.4538715305623575}, {
      1., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1., -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8090908512602306, -0.5876835835779278}, {
      1., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1., -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1., -0.7071900803344316, -0.7070234722246357}, {
      1., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1., -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1., -0.5878742048036698, -0.8089523591203952}, {
      1., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1., -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1., -0.45408147070841337`, -0.890960166314569}, {
      1., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1., -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.3091066279673134, -0.9510273879056674}, {
      1., -0.3091066279673134, -0.9510273879056674}, {
      1., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1., -0.3091066279673132, -0.9510273879056675}, {
      1.25, -0.3091066279673132, -0.9510273879056675}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1., -0.15651979460327867`, -0.987674821941588}, {
      1., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1., -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.00007853981625928847, -0.9999999969157486}, {
      1., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1., -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {1., 
      0.15636464907469316`, -0.9876993958283806}, {
      1., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1., 0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.30895723712171647`, -0.9510759305282178}, {1., 
      0.30895723712171647`, -0.9510759305282178}, {1., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1., 0.3089572371217167, -0.9510759305282178}, {1.25, 
      0.3089572371217167, -0.9510759305282178}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.453941513411326, -0.8910314822731209}, {1., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1., 0.453941513411326, -0.8910314822731209}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.5877471276121589, -0.8090446922041185}, {1., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1., 0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.7070790126229672, -0.7071345486596803}, {1., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1., 0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.8089985281574115, -0.5878106680208703}, {1., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1., 0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.8909958270419, -0.45401149346015546`}, {1., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1., 0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.951051662150225, -0.3090319334976474}, {1., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1., 0.951051662150225, -0.3090319334976474}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.9876871119312596, -0.15644222232149346`}, {1., 
      0.9876871119312596, -0.15644222232149346`}, {1., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1., 0.9876871119312596, -0.1564422223214935}, {1.25, 
      0.9876871119312596, -0.1564422223214935}, {1.25, 
      1., -4.163336342344337*^-16}, {1., 1., -4.163336342344337*^-16}, {1., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1., 1., -4.440892098500626*^-16}, {1.25, 
      1., -4.440892098500626*^-16}, {1.25, 0.9876871119312597, 
      0.15644222232149263`}, {1., 0.9876871119312597, 0.15644222232149263`}, {
      1., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1., 0.9876871119312597, 0.1564422223214926}, {1.25, 
      0.9876871119312597, 0.1564422223214926}, {1.25, 0.9510516621502252, 
      0.30903193349764657`}, {1., 0.9510516621502252, 0.30903193349764657`}, {
      1., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{1., 0.9510516621502252, 0.30903193349764657`}, {1.25, 
      0.9510516621502252, 0.30903193349764657`}, {1.25, 0.8909958270419003, 
      0.4540114934601547}, {1., 0.8909958270419003, 0.4540114934601547}, {1., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1., 0.8909958270419003, 0.4540114934601547}, {1.25, 
      0.8909958270419003, 0.4540114934601547}, {1.25, 0.808998528157412, 
      0.5878106680208697}, {1., 0.808998528157412, 0.5878106680208697}, {1., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1., 0.8089985281574118, 0.58781066802087}, {1.25, 
      0.8089985281574118, 0.58781066802087}, {1.25, 0.7070790126229676, 
      0.70713454865968}, {1., 0.7070790126229676, 0.70713454865968}, {1., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1., 0.7070790126229676, 0.70713454865968}, {1.25, 
      0.7070790126229676, 0.70713454865968}, {1.25, 0.5877471276121592, 
      0.8090446922041181}, {1., 0.5877471276121592, 0.8090446922041181}, {1., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1., 0.5877471276121592, 0.8090446922041181}, {1.25, 
      0.5877471276121592, 0.8090446922041181}, {1.25, 0.45394151341132644`, 
      0.8910314822731207}, {1., 0.45394151341132644`, 0.8910314822731207}, {
      1., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1., 0.45394151341132644`, 0.8910314822731207}, {1.25, 
      0.45394151341132644`, 0.8910314822731207}, {1.25, 0.3089572371217171, 
      0.9510759305282176}, {1., 0.3089572371217171, 0.9510759305282176}, {1., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1., 0.3089572371217171, 0.9510759305282176}, {1.25, 
      0.3089572371217171, 0.9510759305282176}, {1.25, 0.15636464907469383`, 
      0.9876993958283805}, {1., 0.15636464907469383`, 0.9876993958283805}, {
      1., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1., 0.15636464907469383`, 0.9876993958283805}, {1.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1., -0.00007853981625862234, 0.9999999969157486}, {1., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1., -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.156519794603278, 0.9876748219415881}, {1., -0.156519794603278, 
      0.9876748219415881}, {1., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1., -0.156519794603278, 0.9876748219415881}, {
      1.25, -0.156519794603278, 0.9876748219415881}, {
      1.25, -0.3091066279673126, 0.9510273879056678}, {
      1., -0.3091066279673126, 0.9510273879056678}, {1., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{1., -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.45408147070841254`, 0.8909601663145693}, {
      1., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1., -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1., -0.5878742048036691, 0.8089523591203958}, {
      1., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1., -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.707190080334431, 0.7070234722246362}, {1., -0.707190080334431, 
      0.7070234722246362}, {1., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1., -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.8090908512602302, 0.5876835835779286}, {
      1., -0.8090908512602302, 0.5876835835779286}, {1., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{1., -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1., -0.8910671320080111, 0.4538715305623583}, {1., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{1., -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1., -0.9511001930394957, 0.3088825388399836}, {1., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{1., -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9877116736328749, 0.15628707486335883`}, {
      1., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1., -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9999999876629945, -0.0001570796320327716}, {
      1., -0.9999999876629945, -0.0001570796320327716}, {
      1., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.25, -0.9999999876629945, 0.00015707963203365978`}, {
      1.5, -0.9999999876629945, 0.00015707963203365978`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.25, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.951100193039496, -0.3088825388399828}, {
      1.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.25, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.25, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.25, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.25, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.25, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.25, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.3091066279673134, -0.9510273879056674}, {
      1.25, -0.3091066279673134, -0.9510273879056674}, {
      1.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.25, -0.3091066279673132, -0.9510273879056675}, {
      1.5, -0.3091066279673132, -0.9510273879056675}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.25, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.25, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.25, 0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.30895723712171647`, -0.9510759305282178}, {1.25, 
      0.30895723712171647`, -0.9510759305282178}, {1.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.25, 0.3089572371217167, -0.9510759305282178}, {1.5, 
      0.3089572371217167, -0.9510759305282178}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.453941513411326, -0.8910314822731209}, {1.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.25, 0.453941513411326, -0.8910314822731209}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.5877471276121589, -0.8090446922041185}, {1.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.25, 0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.7070790126229672, -0.7071345486596803}, {1.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.25, 0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.8089985281574115, -0.5878106680208703}, {1.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.25, 0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8909958270419, -0.45401149346015546`}, {1.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.25, 0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.951051662150225, -0.3090319334976474}, {1.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.25, 0.951051662150225, -0.3090319334976474}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.9876871119312596, -0.15644222232149346`}, {1.25, 
      0.9876871119312596, -0.15644222232149346`}, {1.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.25, 0.9876871119312596, -0.1564422223214935}, {1.5, 
      0.9876871119312596, -0.1564422223214935}, {1.5, 
      1., -4.163336342344337*^-16}, {1.25, 1., -4.163336342344337*^-16}, {
      1.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.25, 1., -4.440892098500626*^-16}, {1.5, 
      1., -4.440892098500626*^-16}, {1.5, 0.9876871119312597, 
      0.15644222232149263`}, {1.25, 0.9876871119312597, 
      0.15644222232149263`}, {1.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.25, 0.9876871119312597, 0.1564422223214926}, {1.5, 
      0.9876871119312597, 0.1564422223214926}, {1.5, 0.9510516621502252, 
      0.30903193349764657`}, {1.25, 0.9510516621502252, 
      0.30903193349764657`}, {1.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{1.25, 0.9510516621502252, 0.30903193349764657`}, {1.5, 
      0.9510516621502252, 0.30903193349764657`}, {1.5, 0.8909958270419003, 
      0.4540114934601547}, {1.25, 0.8909958270419003, 0.4540114934601547}, {
      1.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.25, 0.8909958270419003, 0.4540114934601547}, {1.5, 
      0.8909958270419003, 0.4540114934601547}, {1.5, 0.808998528157412, 
      0.5878106680208697}, {1.25, 0.808998528157412, 0.5878106680208697}, {
      1.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.25, 0.8089985281574118, 0.58781066802087}, {1.5, 
      0.8089985281574118, 0.58781066802087}, {1.5, 0.7070790126229676, 
      0.70713454865968}, {1.25, 0.7070790126229676, 0.70713454865968}, {1.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.25, 0.7070790126229676, 0.70713454865968}, {1.5, 
      0.7070790126229676, 0.70713454865968}, {1.5, 0.5877471276121592, 
      0.8090446922041181}, {1.25, 0.5877471276121592, 0.8090446922041181}, {
      1.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.25, 0.5877471276121592, 0.8090446922041181}, {1.5, 
      0.5877471276121592, 0.8090446922041181}, {1.5, 0.45394151341132644`, 
      0.8910314822731207}, {1.25, 0.45394151341132644`, 0.8910314822731207}, {
      1.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.25, 0.45394151341132644`, 0.8910314822731207}, {1.5, 
      0.45394151341132644`, 0.8910314822731207}, {1.5, 0.3089572371217171, 
      0.9510759305282176}, {1.25, 0.3089572371217171, 0.9510759305282176}, {
      1.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.25, 0.3089572371217171, 0.9510759305282176}, {1.5, 
      0.3089572371217171, 0.9510759305282176}, {1.5, 0.15636464907469383`, 
      0.9876993958283805}, {1.25, 0.15636464907469383`, 0.9876993958283805}, {
      1.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.25, 0.15636464907469383`, 0.9876993958283805}, {1.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.25, -0.00007853981625862234, 0.9999999969157486}, {1.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1.25, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.156519794603278, 0.9876748219415881}, {1.25, -0.156519794603278,
       0.9876748219415881}, {1.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.25, -0.156519794603278, 0.9876748219415881}, {
      1.5, -0.156519794603278, 0.9876748219415881}, {1.5, -0.3091066279673126,
       0.9510273879056678}, {1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{1.25, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.25, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.25, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {1.5, -0.707190080334431,
       0.7070234722246362}, {1.25, -0.707190080334431, 0.7070234722246362}, {
      1.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.25, -0.707190080334431, 0.7070234722246362}, {
      1.5, -0.707190080334431, 0.7070234722246362}, {1.5, -0.8090908512602302,
       0.5876835835779286}, {1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{1.25, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.25, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.25, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1.25, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9999999876629945, -0.0001570796320327716}, {
      1.25, -0.9999999876629945, -0.0001570796320327716}, {
      1.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.5, -0.9999999876629945, 0.00015707963203365978`}, {
      1.75, -0.9999999876629945, 0.00015707963203365978`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.5, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.951100193039496, -0.3088825388399828}, {
      1.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.5, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.5, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.5, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.5, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.5, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.5, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.3091066279673134, -0.9510273879056674}, {
      1.5, -0.3091066279673134, -0.9510273879056674}, {
      1.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.5, -0.3091066279673132, -0.9510273879056675}, {
      1.75, -0.3091066279673132, -0.9510273879056675}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.5, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.5, -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.5, 0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.30895723712171647`, -0.9510759305282178}, {1.5, 
      0.30895723712171647`, -0.9510759305282178}, {1.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.5, 0.3089572371217167, -0.9510759305282178}, {1.75, 
      0.3089572371217167, -0.9510759305282178}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.453941513411326, -0.8910314822731209}, {1.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.5, 0.453941513411326, -0.8910314822731209}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.5877471276121589, -0.8090446922041185}, {1.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.5, 0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.7070790126229672, -0.7071345486596803}, {1.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.5, 0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.8089985281574115, -0.5878106680208703}, {1.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.5, 0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8909958270419, -0.45401149346015546`}, {1.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.5, 0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.951051662150225, -0.3090319334976474}, {1.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.5, 0.951051662150225, -0.3090319334976474}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.9876871119312596, -0.15644222232149346`}, {1.5, 
      0.9876871119312596, -0.15644222232149346`}, {1.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.5, 0.9876871119312596, -0.1564422223214935}, {1.75, 
      0.9876871119312596, -0.1564422223214935}, {1.75, 
      1., -4.163336342344337*^-16}, {1.5, 1., -4.163336342344337*^-16}, {1.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.5, 1., -4.440892098500626*^-16}, {1.75, 
      1., -4.440892098500626*^-16}, {1.75, 0.9876871119312597, 
      0.15644222232149263`}, {1.5, 0.9876871119312597, 
      0.15644222232149263`}, {1.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.5, 0.9876871119312597, 0.1564422223214926}, {1.75, 
      0.9876871119312597, 0.1564422223214926}, {1.75, 0.9510516621502252, 
      0.30903193349764657`}, {1.5, 0.9510516621502252, 
      0.30903193349764657`}, {1.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{1.5, 0.9510516621502252, 0.30903193349764657`}, {1.75, 
      0.9510516621502252, 0.30903193349764657`}, {1.75, 0.8909958270419003, 
      0.4540114934601547}, {1.5, 0.8909958270419003, 0.4540114934601547}, {
      1.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.5, 0.8909958270419003, 0.4540114934601547}, {1.75, 
      0.8909958270419003, 0.4540114934601547}, {1.75, 0.808998528157412, 
      0.5878106680208697}, {1.5, 0.808998528157412, 0.5878106680208697}, {1.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.5, 0.8089985281574118, 0.58781066802087}, {1.75, 
      0.8089985281574118, 0.58781066802087}, {1.75, 0.7070790126229676, 
      0.70713454865968}, {1.5, 0.7070790126229676, 0.70713454865968}, {1.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.5, 0.7070790126229676, 0.70713454865968}, {1.75, 
      0.7070790126229676, 0.70713454865968}, {1.75, 0.5877471276121592, 
      0.8090446922041181}, {1.5, 0.5877471276121592, 0.8090446922041181}, {
      1.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.5, 0.5877471276121592, 0.8090446922041181}, {1.75, 
      0.5877471276121592, 0.8090446922041181}, {1.75, 0.45394151341132644`, 
      0.8910314822731207}, {1.5, 0.45394151341132644`, 0.8910314822731207}, {
      1.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.5, 0.45394151341132644`, 0.8910314822731207}, {1.75, 
      0.45394151341132644`, 0.8910314822731207}, {1.75, 0.3089572371217171, 
      0.9510759305282176}, {1.5, 0.3089572371217171, 0.9510759305282176}, {
      1.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.5, 0.3089572371217171, 0.9510759305282176}, {1.75, 
      0.3089572371217171, 0.9510759305282176}, {1.75, 0.15636464907469383`, 
      0.9876993958283805}, {1.5, 0.15636464907469383`, 0.9876993958283805}, {
      1.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.5, 0.15636464907469383`, 0.9876993958283805}, {1.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      1.75, -0.00007853981625862234, 0.9999999969157486}, {
      1.5, -0.00007853981625862234, 0.9999999969157486}, {1.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{1.5, -0.00007853981625862234, 0.9999999969157486}, {
      1.75, -0.00007853981625862234, 0.9999999969157486}, {
      1.75, -0.156519794603278, 0.9876748219415881}, {1.5, -0.156519794603278,
       0.9876748219415881}, {1.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.5, -0.156519794603278, 0.9876748219415881}, {
      1.75, -0.156519794603278, 0.9876748219415881}, {
      1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.5, -0.3091066279673126, 0.9510273879056678}, {1.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{1.5, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.5, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.5, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.707190080334431, 0.7070234722246362}, {1.5, -0.707190080334431,
       0.7070234722246362}, {1.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.5, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.5, -0.8090908512602302, 0.5876835835779286}, {1.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{1.5, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.5, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.5, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{1.5, -0.9877116736328749, 0.15628707486335883`}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}, {
      1.75, -0.9999999876629945, -0.0001570796320327716}, {
      1.5, -0.9999999876629945, -0.0001570796320327716}, {
      1.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{1.75, -0.9999999876629945, 0.00015707963203365978`}, {
      2., -0.9999999876629945, 0.00015707963203365978`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.987711673632875, -0.15628707486335794`}, {
      1.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{1.75, -0.987711673632875, -0.15628707486335794`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.951100193039496, -0.3088825388399828}, {
      1.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{1.75, -0.951100193039496, -0.3088825388399828}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.8910671320080115, -0.4538715305623575}, {
      1.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{1.75, -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8090908512602306, -0.5876835835779278}, {
      1.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{1.75, -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.7071900803344316, -0.7070234722246357}, {
      1.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{1.75, -0.7071900803344316, -0.7070234722246357}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.5878742048036698, -0.8089523591203952}, {
      1.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{1.75, -0.5878742048036698, -0.8089523591203952}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.45408147070841337`, -0.890960166314569}, {
      1.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{1.75, -0.45408147070841337`, -0.890960166314569}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      2., -0.3091066279673134, -0.9510273879056674}, {
      1.75, -0.3091066279673134, -0.9510273879056674}, {
      1.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{1.75, -0.3091066279673132, -0.9510273879056675}, {
      2., -0.3091066279673132, -0.9510273879056675}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.15651979460327867`, -0.987674821941588}, {
      1.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{1.75, -0.15651979460327867`, -0.987674821941588}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}, {
      1.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{1.75, -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      1.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{1.75, 0.15636464907469316`, -0.9876993958283806}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {2., 
      0.30895723712171647`, -0.9510759305282178}, {1.75, 
      0.30895723712171647`, -0.9510759305282178}, {1.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{1.75, 0.3089572371217167, -0.9510759305282178}, {2., 
      0.3089572371217167, -0.9510759305282178}, {2., 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.453941513411326, -0.8910314822731209}, {1.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{1.75, 0.453941513411326, -0.8910314822731209}, {2., 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.5877471276121589, -0.8090446922041185}, {1.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{1.75, 0.5877471276121589, -0.8090446922041185}, {2., 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.7070790126229672, -0.7071345486596803}, {1.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{1.75, 0.7070790126229672, -0.7071345486596803}, {2., 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.8089985281574115, -0.5878106680208703}, {1.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{1.75, 0.8089985281574115, -0.5878106680208703}, {2., 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8909958270419, -0.45401149346015546`}, {1.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{1.75, 0.8909958270419, -0.45401149346015546`}, {2., 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.951051662150225, -0.3090319334976474}, {1.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{1.75, 0.951051662150225, -0.3090319334976474}, {2., 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.9876871119312596, -0.15644222232149346`}, {1.75, 
      0.9876871119312596, -0.15644222232149346`}, {1.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{1.75, 0.9876871119312596, -0.1564422223214935}, {2., 
      0.9876871119312596, -0.1564422223214935}, {2., 
      1., -4.163336342344337*^-16}, {1.75, 1., -4.163336342344337*^-16}, {
      1.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{1.75, 1., -4.440892098500626*^-16}, {2., 
      1., -4.440892098500626*^-16}, {2., 0.9876871119312597, 
      0.15644222232149263`}, {1.75, 0.9876871119312597, 
      0.15644222232149263`}, {1.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{1.75, 0.9876871119312597, 0.1564422223214926}, {2., 
      0.9876871119312597, 0.1564422223214926}, {2., 0.9510516621502252, 
      0.30903193349764657`}, {1.75, 0.9510516621502252, 
      0.30903193349764657`}, {1.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{1.75, 0.9510516621502252, 0.30903193349764657`}, {2., 
      0.9510516621502252, 0.30903193349764657`}, {2., 0.8909958270419003, 
      0.4540114934601547}, {1.75, 0.8909958270419003, 0.4540114934601547}, {
      1.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{1.75, 0.8909958270419003, 0.4540114934601547}, {2., 
      0.8909958270419003, 0.4540114934601547}, {2., 0.808998528157412, 
      0.5878106680208697}, {1.75, 0.808998528157412, 0.5878106680208697}, {
      1.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{1.75, 0.8089985281574118, 0.58781066802087}, {2., 
      0.8089985281574118, 0.58781066802087}, {2., 0.7070790126229676, 
      0.70713454865968}, {1.75, 0.7070790126229676, 0.70713454865968}, {1.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{1.75, 0.7070790126229676, 0.70713454865968}, {2., 
      0.7070790126229676, 0.70713454865968}, {2., 0.5877471276121592, 
      0.8090446922041181}, {1.75, 0.5877471276121592, 0.8090446922041181}, {
      1.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{1.75, 0.5877471276121592, 0.8090446922041181}, {2., 
      0.5877471276121592, 0.8090446922041181}, {2., 0.45394151341132644`, 
      0.8910314822731207}, {1.75, 0.45394151341132644`, 0.8910314822731207}, {
      1.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{1.75, 0.45394151341132644`, 0.8910314822731207}, {2., 
      0.45394151341132644`, 0.8910314822731207}, {2., 0.3089572371217171, 
      0.9510759305282176}, {1.75, 0.3089572371217171, 0.9510759305282176}, {
      1.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{1.75, 0.3089572371217171, 0.9510759305282176}, {2., 
      0.3089572371217171, 0.9510759305282176}, {2., 0.15636464907469383`, 
      0.9876993958283805}, {1.75, 0.15636464907469383`, 0.9876993958283805}, {
      1.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{1.75, 0.15636464907469383`, 0.9876993958283805}, {2., 
      0.15636464907469383`, 0.9876993958283805}, {2., -0.00007853981625862234,
       0.9999999969157486}, {1.75, -0.00007853981625862234, 
      0.9999999969157486}, {1.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{1.75, -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.156519794603278, 0.9876748219415881}, {1.75, -0.156519794603278, 
      0.9876748219415881}, {1.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{1.75, -0.156519794603278, 0.9876748219415881}, {
      2., -0.156519794603278, 0.9876748219415881}, {2., -0.3091066279673126, 
      0.9510273879056678}, {1.75, -0.3091066279673126, 0.9510273879056678}, {
      1.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{1.75, -0.3091066279673126, 0.9510273879056678}, {
      2., -0.3091066279673126, 0.9510273879056678}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}, {
      1.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{1.75, -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.5878742048036691, 0.8089523591203958}, {
      1.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{1.75, -0.5878742048036691, 0.8089523591203958}, {
      2., -0.5878742048036691, 0.8089523591203958}, {2., -0.707190080334431, 
      0.7070234722246362}, {1.75, -0.707190080334431, 0.7070234722246362}, {
      1.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{1.75, -0.707190080334431, 0.7070234722246362}, {
      2., -0.707190080334431, 0.7070234722246362}, {2., -0.8090908512602302, 
      0.5876835835779286}, {1.75, -0.8090908512602302, 0.5876835835779286}, {
      1.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{1.75, -0.8090908512602302, 0.5876835835779286}, {
      2., -0.8090908512602302, 0.5876835835779286}, {2., -0.8910671320080111, 
      0.4538715305623583}, {1.75, -0.8910671320080111, 0.4538715305623583}, {
      1.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{1.75, -0.8910671320080111, 0.4538715305623583}, {
      2., -0.8910671320080111, 0.4538715305623583}, {2., -0.9511001930394957, 
      0.3088825388399836}, {1.75, -0.9511001930394957, 0.3088825388399836}, {
      1.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{1.75, -0.9511001930394957, 0.3088825388399836}, {
      2., -0.9511001930394957, 0.3088825388399836}, {2., -0.9877116736328749, 
      0.15628707486335883`}, {1.75, -0.9877116736328749, 
      0.15628707486335883`}, {1.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{1.75, -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9999999876629945, -0.0001570796320327716}, {
      1.75, -0.9999999876629945, -0.0001570796320327716}, {
      1.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2., -0.9999999876629945, 0.00015707963203365978`}, {
      2.25, -0.9999999876629945, 0.00015707963203365978`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2., -0.987711673632875, -0.15628707486335794`}, {
      2., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2., -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2., -0.951100193039496, -0.3088825388399828}, {
      2., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2., -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2., -0.8910671320080115, -0.4538715305623575}, {
      2., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2., -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8090908512602306, -0.5876835835779278}, {
      2., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2., -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2., -0.7071900803344316, -0.7070234722246357}, {
      2., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2., -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2., -0.5878742048036698, -0.8089523591203952}, {
      2., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2., -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2., -0.45408147070841337`, -0.890960166314569}, {
      2., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2., -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.3091066279673134, -0.9510273879056674}, {
      2., -0.3091066279673134, -0.9510273879056674}, {
      2., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2., -0.3091066279673132, -0.9510273879056675}, {
      2.25, -0.3091066279673132, -0.9510273879056675}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2., -0.15651979460327867`, -0.987674821941588}, {
      2., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2., -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.00007853981625928847, -0.9999999969157486}, {
      2., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2., -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {2., 
      0.15636464907469316`, -0.9876993958283806}, {
      2., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2., 0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.30895723712171647`, -0.9510759305282178}, {2., 
      0.30895723712171647`, -0.9510759305282178}, {2., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2., 0.3089572371217167, -0.9510759305282178}, {2.25, 
      0.3089572371217167, -0.9510759305282178}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.453941513411326, -0.8910314822731209}, {2., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2., 0.453941513411326, -0.8910314822731209}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.5877471276121589, -0.8090446922041185}, {2., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2., 0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.7070790126229672, -0.7071345486596803}, {2., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2., 0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.8089985281574115, -0.5878106680208703}, {2., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2., 0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.8909958270419, -0.45401149346015546`}, {2., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2., 0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.951051662150225, -0.3090319334976474}, {2., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2., 0.951051662150225, -0.3090319334976474}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.9876871119312596, -0.15644222232149346`}, {2., 
      0.9876871119312596, -0.15644222232149346`}, {2., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2., 0.9876871119312596, -0.1564422223214935}, {2.25, 
      0.9876871119312596, -0.1564422223214935}, {2.25, 
      1., -4.163336342344337*^-16}, {2., 1., -4.163336342344337*^-16}, {2., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2., 1., -4.440892098500626*^-16}, {2.25, 
      1., -4.440892098500626*^-16}, {2.25, 0.9876871119312597, 
      0.15644222232149263`}, {2., 0.9876871119312597, 0.15644222232149263`}, {
      2., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2., 0.9876871119312597, 0.1564422223214926}, {2.25, 
      0.9876871119312597, 0.1564422223214926}, {2.25, 0.9510516621502252, 
      0.30903193349764657`}, {2., 0.9510516621502252, 0.30903193349764657`}, {
      2., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{2., 0.9510516621502252, 0.30903193349764657`}, {2.25, 
      0.9510516621502252, 0.30903193349764657`}, {2.25, 0.8909958270419003, 
      0.4540114934601547}, {2., 0.8909958270419003, 0.4540114934601547}, {2., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2., 0.8909958270419003, 0.4540114934601547}, {2.25, 
      0.8909958270419003, 0.4540114934601547}, {2.25, 0.808998528157412, 
      0.5878106680208697}, {2., 0.808998528157412, 0.5878106680208697}, {2., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2., 0.8089985281574118, 0.58781066802087}, {2.25, 
      0.8089985281574118, 0.58781066802087}, {2.25, 0.7070790126229676, 
      0.70713454865968}, {2., 0.7070790126229676, 0.70713454865968}, {2., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2., 0.7070790126229676, 0.70713454865968}, {2.25, 
      0.7070790126229676, 0.70713454865968}, {2.25, 0.5877471276121592, 
      0.8090446922041181}, {2., 0.5877471276121592, 0.8090446922041181}, {2., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2., 0.5877471276121592, 0.8090446922041181}, {2.25, 
      0.5877471276121592, 0.8090446922041181}, {2.25, 0.45394151341132644`, 
      0.8910314822731207}, {2., 0.45394151341132644`, 0.8910314822731207}, {
      2., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2., 0.45394151341132644`, 0.8910314822731207}, {2.25, 
      0.45394151341132644`, 0.8910314822731207}, {2.25, 0.3089572371217171, 
      0.9510759305282176}, {2., 0.3089572371217171, 0.9510759305282176}, {2., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2., 0.3089572371217171, 0.9510759305282176}, {2.25, 
      0.3089572371217171, 0.9510759305282176}, {2.25, 0.15636464907469383`, 
      0.9876993958283805}, {2., 0.15636464907469383`, 0.9876993958283805}, {
      2., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2., 0.15636464907469383`, 0.9876993958283805}, {2.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2., -0.00007853981625862234, 0.9999999969157486}, {2., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2., -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.156519794603278, 0.9876748219415881}, {2., -0.156519794603278, 
      0.9876748219415881}, {2., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2., -0.156519794603278, 0.9876748219415881}, {
      2.25, -0.156519794603278, 0.9876748219415881}, {
      2.25, -0.3091066279673126, 0.9510273879056678}, {
      2., -0.3091066279673126, 0.9510273879056678}, {2., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{2., -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.45408147070841254`, 0.8909601663145693}, {
      2., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2., -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2., -0.5878742048036691, 0.8089523591203958}, {
      2., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2., -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.707190080334431, 0.7070234722246362}, {2., -0.707190080334431, 
      0.7070234722246362}, {2., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2., -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.8090908512602302, 0.5876835835779286}, {
      2., -0.8090908512602302, 0.5876835835779286}, {2., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{2., -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2., -0.8910671320080111, 0.4538715305623583}, {2., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{2., -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2., -0.9511001930394957, 0.3088825388399836}, {2., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{2., -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9877116736328749, 0.15628707486335883`}, {
      2., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2., -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9999999876629945, -0.0001570796320327716}, {
      2., -0.9999999876629945, -0.0001570796320327716}, {
      2., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.25, -0.9999999876629945, 0.00015707963203365978`}, {
      2.5, -0.9999999876629945, 0.00015707963203365978`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.25, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.951100193039496, -0.3088825388399828}, {
      2.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.25, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.25, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.25, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.25, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.25, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.25, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.3091066279673134, -0.9510273879056674}, {
      2.25, -0.3091066279673134, -0.9510273879056674}, {
      2.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.25, -0.3091066279673132, -0.9510273879056675}, {
      2.5, -0.3091066279673132, -0.9510273879056675}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.25, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.25, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.25, 0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.30895723712171647`, -0.9510759305282178}, {2.25, 
      0.30895723712171647`, -0.9510759305282178}, {2.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.25, 0.3089572371217167, -0.9510759305282178}, {2.5, 
      0.3089572371217167, -0.9510759305282178}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.453941513411326, -0.8910314822731209}, {2.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.25, 0.453941513411326, -0.8910314822731209}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.5877471276121589, -0.8090446922041185}, {2.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.25, 0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.7070790126229672, -0.7071345486596803}, {2.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.25, 0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.8089985281574115, -0.5878106680208703}, {2.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.25, 0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8909958270419, -0.45401149346015546`}, {2.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.25, 0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.951051662150225, -0.3090319334976474}, {2.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.25, 0.951051662150225, -0.3090319334976474}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.9876871119312596, -0.15644222232149346`}, {2.25, 
      0.9876871119312596, -0.15644222232149346`}, {2.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.25, 0.9876871119312596, -0.1564422223214935}, {2.5, 
      0.9876871119312596, -0.1564422223214935}, {2.5, 
      1., -4.163336342344337*^-16}, {2.25, 1., -4.163336342344337*^-16}, {
      2.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.25, 1., -4.440892098500626*^-16}, {2.5, 
      1., -4.440892098500626*^-16}, {2.5, 0.9876871119312597, 
      0.15644222232149263`}, {2.25, 0.9876871119312597, 
      0.15644222232149263`}, {2.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.25, 0.9876871119312597, 0.1564422223214926}, {2.5, 
      0.9876871119312597, 0.1564422223214926}, {2.5, 0.9510516621502252, 
      0.30903193349764657`}, {2.25, 0.9510516621502252, 
      0.30903193349764657`}, {2.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{2.25, 0.9510516621502252, 0.30903193349764657`}, {2.5, 
      0.9510516621502252, 0.30903193349764657`}, {2.5, 0.8909958270419003, 
      0.4540114934601547}, {2.25, 0.8909958270419003, 0.4540114934601547}, {
      2.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.25, 0.8909958270419003, 0.4540114934601547}, {2.5, 
      0.8909958270419003, 0.4540114934601547}, {2.5, 0.808998528157412, 
      0.5878106680208697}, {2.25, 0.808998528157412, 0.5878106680208697}, {
      2.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.25, 0.8089985281574118, 0.58781066802087}, {2.5, 
      0.8089985281574118, 0.58781066802087}, {2.5, 0.7070790126229676, 
      0.70713454865968}, {2.25, 0.7070790126229676, 0.70713454865968}, {2.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.25, 0.7070790126229676, 0.70713454865968}, {2.5, 
      0.7070790126229676, 0.70713454865968}, {2.5, 0.5877471276121592, 
      0.8090446922041181}, {2.25, 0.5877471276121592, 0.8090446922041181}, {
      2.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.25, 0.5877471276121592, 0.8090446922041181}, {2.5, 
      0.5877471276121592, 0.8090446922041181}, {2.5, 0.45394151341132644`, 
      0.8910314822731207}, {2.25, 0.45394151341132644`, 0.8910314822731207}, {
      2.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.25, 0.45394151341132644`, 0.8910314822731207}, {2.5, 
      0.45394151341132644`, 0.8910314822731207}, {2.5, 0.3089572371217171, 
      0.9510759305282176}, {2.25, 0.3089572371217171, 0.9510759305282176}, {
      2.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.25, 0.3089572371217171, 0.9510759305282176}, {2.5, 
      0.3089572371217171, 0.9510759305282176}, {2.5, 0.15636464907469383`, 
      0.9876993958283805}, {2.25, 0.15636464907469383`, 0.9876993958283805}, {
      2.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.25, 0.15636464907469383`, 0.9876993958283805}, {2.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.25, -0.00007853981625862234, 0.9999999969157486}, {2.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2.25, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.156519794603278, 0.9876748219415881}, {2.25, -0.156519794603278,
       0.9876748219415881}, {2.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.25, -0.156519794603278, 0.9876748219415881}, {
      2.5, -0.156519794603278, 0.9876748219415881}, {2.5, -0.3091066279673126,
       0.9510273879056678}, {2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{2.25, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.25, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.25, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {2.5, -0.707190080334431,
       0.7070234722246362}, {2.25, -0.707190080334431, 0.7070234722246362}, {
      2.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.25, -0.707190080334431, 0.7070234722246362}, {
      2.5, -0.707190080334431, 0.7070234722246362}, {2.5, -0.8090908512602302,
       0.5876835835779286}, {2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{2.25, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.25, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.25, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2.25, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9999999876629945, -0.0001570796320327716}, {
      2.25, -0.9999999876629945, -0.0001570796320327716}, {
      2.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.5, -0.9999999876629945, 0.00015707963203365978`}, {
      2.75, -0.9999999876629945, 0.00015707963203365978`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.5, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.951100193039496, -0.3088825388399828}, {
      2.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.5, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.5, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.5, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.5, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.5, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.5, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.3091066279673134, -0.9510273879056674}, {
      2.5, -0.3091066279673134, -0.9510273879056674}, {
      2.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.5, -0.3091066279673132, -0.9510273879056675}, {
      2.75, -0.3091066279673132, -0.9510273879056675}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.5, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.5, -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.5, 0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.30895723712171647`, -0.9510759305282178}, {2.5, 
      0.30895723712171647`, -0.9510759305282178}, {2.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.5, 0.3089572371217167, -0.9510759305282178}, {2.75, 
      0.3089572371217167, -0.9510759305282178}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.453941513411326, -0.8910314822731209}, {2.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.5, 0.453941513411326, -0.8910314822731209}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.5877471276121589, -0.8090446922041185}, {2.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.5, 0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.7070790126229672, -0.7071345486596803}, {2.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.5, 0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.8089985281574115, -0.5878106680208703}, {2.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.5, 0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8909958270419, -0.45401149346015546`}, {2.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.5, 0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.951051662150225, -0.3090319334976474}, {2.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.5, 0.951051662150225, -0.3090319334976474}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.9876871119312596, -0.15644222232149346`}, {2.5, 
      0.9876871119312596, -0.15644222232149346`}, {2.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.5, 0.9876871119312596, -0.1564422223214935}, {2.75, 
      0.9876871119312596, -0.1564422223214935}, {2.75, 
      1., -4.163336342344337*^-16}, {2.5, 1., -4.163336342344337*^-16}, {2.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.5, 1., -4.440892098500626*^-16}, {2.75, 
      1., -4.440892098500626*^-16}, {2.75, 0.9876871119312597, 
      0.15644222232149263`}, {2.5, 0.9876871119312597, 
      0.15644222232149263`}, {2.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.5, 0.9876871119312597, 0.1564422223214926}, {2.75, 
      0.9876871119312597, 0.1564422223214926}, {2.75, 0.9510516621502252, 
      0.30903193349764657`}, {2.5, 0.9510516621502252, 
      0.30903193349764657`}, {2.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{2.5, 0.9510516621502252, 0.30903193349764657`}, {2.75, 
      0.9510516621502252, 0.30903193349764657`}, {2.75, 0.8909958270419003, 
      0.4540114934601547}, {2.5, 0.8909958270419003, 0.4540114934601547}, {
      2.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.5, 0.8909958270419003, 0.4540114934601547}, {2.75, 
      0.8909958270419003, 0.4540114934601547}, {2.75, 0.808998528157412, 
      0.5878106680208697}, {2.5, 0.808998528157412, 0.5878106680208697}, {2.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.5, 0.8089985281574118, 0.58781066802087}, {2.75, 
      0.8089985281574118, 0.58781066802087}, {2.75, 0.7070790126229676, 
      0.70713454865968}, {2.5, 0.7070790126229676, 0.70713454865968}, {2.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.5, 0.7070790126229676, 0.70713454865968}, {2.75, 
      0.7070790126229676, 0.70713454865968}, {2.75, 0.5877471276121592, 
      0.8090446922041181}, {2.5, 0.5877471276121592, 0.8090446922041181}, {
      2.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.5, 0.5877471276121592, 0.8090446922041181}, {2.75, 
      0.5877471276121592, 0.8090446922041181}, {2.75, 0.45394151341132644`, 
      0.8910314822731207}, {2.5, 0.45394151341132644`, 0.8910314822731207}, {
      2.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.5, 0.45394151341132644`, 0.8910314822731207}, {2.75, 
      0.45394151341132644`, 0.8910314822731207}, {2.75, 0.3089572371217171, 
      0.9510759305282176}, {2.5, 0.3089572371217171, 0.9510759305282176}, {
      2.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.5, 0.3089572371217171, 0.9510759305282176}, {2.75, 
      0.3089572371217171, 0.9510759305282176}, {2.75, 0.15636464907469383`, 
      0.9876993958283805}, {2.5, 0.15636464907469383`, 0.9876993958283805}, {
      2.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.5, 0.15636464907469383`, 0.9876993958283805}, {2.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      2.75, -0.00007853981625862234, 0.9999999969157486}, {
      2.5, -0.00007853981625862234, 0.9999999969157486}, {2.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{2.5, -0.00007853981625862234, 0.9999999969157486}, {
      2.75, -0.00007853981625862234, 0.9999999969157486}, {
      2.75, -0.156519794603278, 0.9876748219415881}, {2.5, -0.156519794603278,
       0.9876748219415881}, {2.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.5, -0.156519794603278, 0.9876748219415881}, {
      2.75, -0.156519794603278, 0.9876748219415881}, {
      2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.5, -0.3091066279673126, 0.9510273879056678}, {2.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{2.5, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.5, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.5, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.707190080334431, 0.7070234722246362}, {2.5, -0.707190080334431,
       0.7070234722246362}, {2.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.5, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.5, -0.8090908512602302, 0.5876835835779286}, {2.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{2.5, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.5, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.5, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{2.5, -0.9877116736328749, 0.15628707486335883`}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}, {
      2.75, -0.9999999876629945, -0.0001570796320327716}, {
      2.5, -0.9999999876629945, -0.0001570796320327716}, {
      2.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{2.75, -0.9999999876629945, 0.00015707963203365978`}, {
      3., -0.9999999876629945, 0.00015707963203365978`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.987711673632875, -0.15628707486335794`}, {
      2.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{2.75, -0.987711673632875, -0.15628707486335794`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.951100193039496, -0.3088825388399828}, {
      2.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{2.75, -0.951100193039496, -0.3088825388399828}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.8910671320080115, -0.4538715305623575}, {
      2.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{2.75, -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8090908512602306, -0.5876835835779278}, {
      2.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{2.75, -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.7071900803344316, -0.7070234722246357}, {
      2.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{2.75, -0.7071900803344316, -0.7070234722246357}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.5878742048036698, -0.8089523591203952}, {
      2.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{2.75, -0.5878742048036698, -0.8089523591203952}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.45408147070841337`, -0.890960166314569}, {
      2.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{2.75, -0.45408147070841337`, -0.890960166314569}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      3., -0.3091066279673134, -0.9510273879056674}, {
      2.75, -0.3091066279673134, -0.9510273879056674}, {
      2.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{2.75, -0.3091066279673132, -0.9510273879056675}, {
      3., -0.3091066279673132, -0.9510273879056675}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.15651979460327867`, -0.987674821941588}, {
      2.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{2.75, -0.15651979460327867`, -0.987674821941588}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}, {
      2.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{2.75, -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      2.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{2.75, 0.15636464907469316`, -0.9876993958283806}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {3., 
      0.30895723712171647`, -0.9510759305282178}, {2.75, 
      0.30895723712171647`, -0.9510759305282178}, {2.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{2.75, 0.3089572371217167, -0.9510759305282178}, {3., 
      0.3089572371217167, -0.9510759305282178}, {3., 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.453941513411326, -0.8910314822731209}, {2.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{2.75, 0.453941513411326, -0.8910314822731209}, {3., 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.5877471276121589, -0.8090446922041185}, {2.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{2.75, 0.5877471276121589, -0.8090446922041185}, {3., 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.7070790126229672, -0.7071345486596803}, {2.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{2.75, 0.7070790126229672, -0.7071345486596803}, {3., 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.8089985281574115, -0.5878106680208703}, {2.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{2.75, 0.8089985281574115, -0.5878106680208703}, {3., 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8909958270419, -0.45401149346015546`}, {2.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{2.75, 0.8909958270419, -0.45401149346015546`}, {3., 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.951051662150225, -0.3090319334976474}, {2.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{2.75, 0.951051662150225, -0.3090319334976474}, {3., 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.9876871119312596, -0.15644222232149346`}, {2.75, 
      0.9876871119312596, -0.15644222232149346`}, {2.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{2.75, 0.9876871119312596, -0.1564422223214935}, {3., 
      0.9876871119312596, -0.1564422223214935}, {3., 
      1., -4.163336342344337*^-16}, {2.75, 1., -4.163336342344337*^-16}, {
      2.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{2.75, 1., -4.440892098500626*^-16}, {3., 
      1., -4.440892098500626*^-16}, {3., 0.9876871119312597, 
      0.15644222232149263`}, {2.75, 0.9876871119312597, 
      0.15644222232149263`}, {2.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{2.75, 0.9876871119312597, 0.1564422223214926}, {3., 
      0.9876871119312597, 0.1564422223214926}, {3., 0.9510516621502252, 
      0.30903193349764657`}, {2.75, 0.9510516621502252, 
      0.30903193349764657`}, {2.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{2.75, 0.9510516621502252, 0.30903193349764657`}, {3., 
      0.9510516621502252, 0.30903193349764657`}, {3., 0.8909958270419003, 
      0.4540114934601547}, {2.75, 0.8909958270419003, 0.4540114934601547}, {
      2.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{2.75, 0.8909958270419003, 0.4540114934601547}, {3., 
      0.8909958270419003, 0.4540114934601547}, {3., 0.808998528157412, 
      0.5878106680208697}, {2.75, 0.808998528157412, 0.5878106680208697}, {
      2.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{2.75, 0.8089985281574118, 0.58781066802087}, {3., 
      0.8089985281574118, 0.58781066802087}, {3., 0.7070790126229676, 
      0.70713454865968}, {2.75, 0.7070790126229676, 0.70713454865968}, {2.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{2.75, 0.7070790126229676, 0.70713454865968}, {3., 
      0.7070790126229676, 0.70713454865968}, {3., 0.5877471276121592, 
      0.8090446922041181}, {2.75, 0.5877471276121592, 0.8090446922041181}, {
      2.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{2.75, 0.5877471276121592, 0.8090446922041181}, {3., 
      0.5877471276121592, 0.8090446922041181}, {3., 0.45394151341132644`, 
      0.8910314822731207}, {2.75, 0.45394151341132644`, 0.8910314822731207}, {
      2.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{2.75, 0.45394151341132644`, 0.8910314822731207}, {3., 
      0.45394151341132644`, 0.8910314822731207}, {3., 0.3089572371217171, 
      0.9510759305282176}, {2.75, 0.3089572371217171, 0.9510759305282176}, {
      2.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{2.75, 0.3089572371217171, 0.9510759305282176}, {3., 
      0.3089572371217171, 0.9510759305282176}, {3., 0.15636464907469383`, 
      0.9876993958283805}, {2.75, 0.15636464907469383`, 0.9876993958283805}, {
      2.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{2.75, 0.15636464907469383`, 0.9876993958283805}, {3., 
      0.15636464907469383`, 0.9876993958283805}, {3., -0.00007853981625862234,
       0.9999999969157486}, {2.75, -0.00007853981625862234, 
      0.9999999969157486}, {2.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{2.75, -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.156519794603278, 0.9876748219415881}, {2.75, -0.156519794603278, 
      0.9876748219415881}, {2.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{2.75, -0.156519794603278, 0.9876748219415881}, {
      3., -0.156519794603278, 0.9876748219415881}, {3., -0.3091066279673126, 
      0.9510273879056678}, {2.75, -0.3091066279673126, 0.9510273879056678}, {
      2.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{2.75, -0.3091066279673126, 0.9510273879056678}, {
      3., -0.3091066279673126, 0.9510273879056678}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}, {
      2.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{2.75, -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.5878742048036691, 0.8089523591203958}, {
      2.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{2.75, -0.5878742048036691, 0.8089523591203958}, {
      3., -0.5878742048036691, 0.8089523591203958}, {3., -0.707190080334431, 
      0.7070234722246362}, {2.75, -0.707190080334431, 0.7070234722246362}, {
      2.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{2.75, -0.707190080334431, 0.7070234722246362}, {
      3., -0.707190080334431, 0.7070234722246362}, {3., -0.8090908512602302, 
      0.5876835835779286}, {2.75, -0.8090908512602302, 0.5876835835779286}, {
      2.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{2.75, -0.8090908512602302, 0.5876835835779286}, {
      3., -0.8090908512602302, 0.5876835835779286}, {3., -0.8910671320080111, 
      0.4538715305623583}, {2.75, -0.8910671320080111, 0.4538715305623583}, {
      2.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{2.75, -0.8910671320080111, 0.4538715305623583}, {
      3., -0.8910671320080111, 0.4538715305623583}, {3., -0.9511001930394957, 
      0.3088825388399836}, {2.75, -0.9511001930394957, 0.3088825388399836}, {
      2.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{2.75, -0.9511001930394957, 0.3088825388399836}, {
      3., -0.9511001930394957, 0.3088825388399836}, {3., -0.9877116736328749, 
      0.15628707486335883`}, {2.75, -0.9877116736328749, 
      0.15628707486335883`}, {2.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{2.75, -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9999999876629945, -0.0001570796320327716}, {
      2.75, -0.9999999876629945, -0.0001570796320327716}, {
      2.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3., -0.9999999876629945, 0.00015707963203365978`}, {
      3.25, -0.9999999876629945, 0.00015707963203365978`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3., -0.987711673632875, -0.15628707486335794`}, {
      3., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3., -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3., -0.951100193039496, -0.3088825388399828}, {
      3., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3., -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3., -0.8910671320080115, -0.4538715305623575}, {
      3., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3., -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8090908512602306, -0.5876835835779278}, {
      3., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3., -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3., -0.7071900803344316, -0.7070234722246357}, {
      3., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3., -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3., -0.5878742048036698, -0.8089523591203952}, {
      3., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3., -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3., -0.45408147070841337`, -0.890960166314569}, {
      3., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3., -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.3091066279673134, -0.9510273879056674}, {
      3., -0.3091066279673134, -0.9510273879056674}, {
      3., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3., -0.3091066279673132, -0.9510273879056675}, {
      3.25, -0.3091066279673132, -0.9510273879056675}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3., -0.15651979460327867`, -0.987674821941588}, {
      3., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3., -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.00007853981625928847, -0.9999999969157486}, {
      3., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3., -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {3., 
      0.15636464907469316`, -0.9876993958283806}, {
      3., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3., 0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.30895723712171647`, -0.9510759305282178}, {3., 
      0.30895723712171647`, -0.9510759305282178}, {3., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3., 0.3089572371217167, -0.9510759305282178}, {3.25, 
      0.3089572371217167, -0.9510759305282178}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.453941513411326, -0.8910314822731209}, {3., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3., 0.453941513411326, -0.8910314822731209}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.5877471276121589, -0.8090446922041185}, {3., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3., 0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.7070790126229672, -0.7071345486596803}, {3., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3., 0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.8089985281574115, -0.5878106680208703}, {3., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3., 0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.8909958270419, -0.45401149346015546`}, {3., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3., 0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.951051662150225, -0.3090319334976474}, {3., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3., 0.951051662150225, -0.3090319334976474}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.9876871119312596, -0.15644222232149346`}, {3., 
      0.9876871119312596, -0.15644222232149346`}, {3., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3., 0.9876871119312596, -0.1564422223214935}, {3.25, 
      0.9876871119312596, -0.1564422223214935}, {3.25, 
      1., -4.163336342344337*^-16}, {3., 1., -4.163336342344337*^-16}, {3., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3., 1., -4.440892098500626*^-16}, {3.25, 
      1., -4.440892098500626*^-16}, {3.25, 0.9876871119312597, 
      0.15644222232149263`}, {3., 0.9876871119312597, 0.15644222232149263`}, {
      3., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3., 0.9876871119312597, 0.1564422223214926}, {3.25, 
      0.9876871119312597, 0.1564422223214926}, {3.25, 0.9510516621502252, 
      0.30903193349764657`}, {3., 0.9510516621502252, 0.30903193349764657`}, {
      3., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{3., 0.9510516621502252, 0.30903193349764657`}, {3.25, 
      0.9510516621502252, 0.30903193349764657`}, {3.25, 0.8909958270419003, 
      0.4540114934601547}, {3., 0.8909958270419003, 0.4540114934601547}, {3., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3., 0.8909958270419003, 0.4540114934601547}, {3.25, 
      0.8909958270419003, 0.4540114934601547}, {3.25, 0.808998528157412, 
      0.5878106680208697}, {3., 0.808998528157412, 0.5878106680208697}, {3., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3., 0.8089985281574118, 0.58781066802087}, {3.25, 
      0.8089985281574118, 0.58781066802087}, {3.25, 0.7070790126229676, 
      0.70713454865968}, {3., 0.7070790126229676, 0.70713454865968}, {3., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3., 0.7070790126229676, 0.70713454865968}, {3.25, 
      0.7070790126229676, 0.70713454865968}, {3.25, 0.5877471276121592, 
      0.8090446922041181}, {3., 0.5877471276121592, 0.8090446922041181}, {3., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3., 0.5877471276121592, 0.8090446922041181}, {3.25, 
      0.5877471276121592, 0.8090446922041181}, {3.25, 0.45394151341132644`, 
      0.8910314822731207}, {3., 0.45394151341132644`, 0.8910314822731207}, {
      3., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3., 0.45394151341132644`, 0.8910314822731207}, {3.25, 
      0.45394151341132644`, 0.8910314822731207}, {3.25, 0.3089572371217171, 
      0.9510759305282176}, {3., 0.3089572371217171, 0.9510759305282176}, {3., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3., 0.3089572371217171, 0.9510759305282176}, {3.25, 
      0.3089572371217171, 0.9510759305282176}, {3.25, 0.15636464907469383`, 
      0.9876993958283805}, {3., 0.15636464907469383`, 0.9876993958283805}, {
      3., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3., 0.15636464907469383`, 0.9876993958283805}, {3.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3., -0.00007853981625862234, 0.9999999969157486}, {3., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3., -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.156519794603278, 0.9876748219415881}, {3., -0.156519794603278, 
      0.9876748219415881}, {3., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3., -0.156519794603278, 0.9876748219415881}, {
      3.25, -0.156519794603278, 0.9876748219415881}, {
      3.25, -0.3091066279673126, 0.9510273879056678}, {
      3., -0.3091066279673126, 0.9510273879056678}, {3., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{3., -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.45408147070841254`, 0.8909601663145693}, {
      3., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3., -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3., -0.5878742048036691, 0.8089523591203958}, {
      3., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3., -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.707190080334431, 0.7070234722246362}, {3., -0.707190080334431, 
      0.7070234722246362}, {3., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3., -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.8090908512602302, 0.5876835835779286}, {
      3., -0.8090908512602302, 0.5876835835779286}, {3., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{3., -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3., -0.8910671320080111, 0.4538715305623583}, {3., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{3., -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3., -0.9511001930394957, 0.3088825388399836}, {3., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{3., -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9877116736328749, 0.15628707486335883`}, {
      3., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3., -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9999999876629945, -0.0001570796320327716}, {
      3., -0.9999999876629945, -0.0001570796320327716}, {
      3., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.25, -0.9999999876629945, 0.00015707963203365978`}, {
      3.5, -0.9999999876629945, 0.00015707963203365978`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.25, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.951100193039496, -0.3088825388399828}, {
      3.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.25, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.25, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.25, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.25, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.25, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.25, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.3091066279673134, -0.9510273879056674}, {
      3.25, -0.3091066279673134, -0.9510273879056674}, {
      3.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.25, -0.3091066279673132, -0.9510273879056675}, {
      3.5, -0.3091066279673132, -0.9510273879056675}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.25, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.25, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.25, 0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.30895723712171647`, -0.9510759305282178}, {3.25, 
      0.30895723712171647`, -0.9510759305282178}, {3.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.25, 0.3089572371217167, -0.9510759305282178}, {3.5, 
      0.3089572371217167, -0.9510759305282178}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.453941513411326, -0.8910314822731209}, {3.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.25, 0.453941513411326, -0.8910314822731209}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.5877471276121589, -0.8090446922041185}, {3.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.25, 0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.7070790126229672, -0.7071345486596803}, {3.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.25, 0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.8089985281574115, -0.5878106680208703}, {3.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.25, 0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8909958270419, -0.45401149346015546`}, {3.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.25, 0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.951051662150225, -0.3090319334976474}, {3.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.25, 0.951051662150225, -0.3090319334976474}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.9876871119312596, -0.15644222232149346`}, {3.25, 
      0.9876871119312596, -0.15644222232149346`}, {3.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.25, 0.9876871119312596, -0.1564422223214935}, {3.5, 
      0.9876871119312596, -0.1564422223214935}, {3.5, 
      1., -4.163336342344337*^-16}, {3.25, 1., -4.163336342344337*^-16}, {
      3.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.25, 1., -4.440892098500626*^-16}, {3.5, 
      1., -4.440892098500626*^-16}, {3.5, 0.9876871119312597, 
      0.15644222232149263`}, {3.25, 0.9876871119312597, 
      0.15644222232149263`}, {3.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.25, 0.9876871119312597, 0.1564422223214926}, {3.5, 
      0.9876871119312597, 0.1564422223214926}, {3.5, 0.9510516621502252, 
      0.30903193349764657`}, {3.25, 0.9510516621502252, 
      0.30903193349764657`}, {3.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{3.25, 0.9510516621502252, 0.30903193349764657`}, {3.5, 
      0.9510516621502252, 0.30903193349764657`}, {3.5, 0.8909958270419003, 
      0.4540114934601547}, {3.25, 0.8909958270419003, 0.4540114934601547}, {
      3.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.25, 0.8909958270419003, 0.4540114934601547}, {3.5, 
      0.8909958270419003, 0.4540114934601547}, {3.5, 0.808998528157412, 
      0.5878106680208697}, {3.25, 0.808998528157412, 0.5878106680208697}, {
      3.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.25, 0.8089985281574118, 0.58781066802087}, {3.5, 
      0.8089985281574118, 0.58781066802087}, {3.5, 0.7070790126229676, 
      0.70713454865968}, {3.25, 0.7070790126229676, 0.70713454865968}, {3.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.25, 0.7070790126229676, 0.70713454865968}, {3.5, 
      0.7070790126229676, 0.70713454865968}, {3.5, 0.5877471276121592, 
      0.8090446922041181}, {3.25, 0.5877471276121592, 0.8090446922041181}, {
      3.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.25, 0.5877471276121592, 0.8090446922041181}, {3.5, 
      0.5877471276121592, 0.8090446922041181}, {3.5, 0.45394151341132644`, 
      0.8910314822731207}, {3.25, 0.45394151341132644`, 0.8910314822731207}, {
      3.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.25, 0.45394151341132644`, 0.8910314822731207}, {3.5, 
      0.45394151341132644`, 0.8910314822731207}, {3.5, 0.3089572371217171, 
      0.9510759305282176}, {3.25, 0.3089572371217171, 0.9510759305282176}, {
      3.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.25, 0.3089572371217171, 0.9510759305282176}, {3.5, 
      0.3089572371217171, 0.9510759305282176}, {3.5, 0.15636464907469383`, 
      0.9876993958283805}, {3.25, 0.15636464907469383`, 0.9876993958283805}, {
      3.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.25, 0.15636464907469383`, 0.9876993958283805}, {3.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.25, -0.00007853981625862234, 0.9999999969157486}, {3.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3.25, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.156519794603278, 0.9876748219415881}, {3.25, -0.156519794603278,
       0.9876748219415881}, {3.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.25, -0.156519794603278, 0.9876748219415881}, {
      3.5, -0.156519794603278, 0.9876748219415881}, {3.5, -0.3091066279673126,
       0.9510273879056678}, {3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{3.25, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.25, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.25, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {3.5, -0.707190080334431,
       0.7070234722246362}, {3.25, -0.707190080334431, 0.7070234722246362}, {
      3.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.25, -0.707190080334431, 0.7070234722246362}, {
      3.5, -0.707190080334431, 0.7070234722246362}, {3.5, -0.8090908512602302,
       0.5876835835779286}, {3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{3.25, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.25, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.25, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3.25, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9999999876629945, -0.0001570796320327716}, {
      3.25, -0.9999999876629945, -0.0001570796320327716}, {
      3.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.5, -0.9999999876629945, 0.00015707963203365978`}, {
      3.75, -0.9999999876629945, 0.00015707963203365978`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.5, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.951100193039496, -0.3088825388399828}, {
      3.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.5, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.5, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.5, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.5, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.5, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.5, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.3091066279673134, -0.9510273879056674}, {
      3.5, -0.3091066279673134, -0.9510273879056674}, {
      3.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.5, -0.3091066279673132, -0.9510273879056675}, {
      3.75, -0.3091066279673132, -0.9510273879056675}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.5, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.5, -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.5, 0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.30895723712171647`, -0.9510759305282178}, {3.5, 
      0.30895723712171647`, -0.9510759305282178}, {3.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.5, 0.3089572371217167, -0.9510759305282178}, {3.75, 
      0.3089572371217167, -0.9510759305282178}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.453941513411326, -0.8910314822731209}, {3.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.5, 0.453941513411326, -0.8910314822731209}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.5877471276121589, -0.8090446922041185}, {3.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.5, 0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.7070790126229672, -0.7071345486596803}, {3.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.5, 0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.8089985281574115, -0.5878106680208703}, {3.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.5, 0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8909958270419, -0.45401149346015546`}, {3.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.5, 0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.951051662150225, -0.3090319334976474}, {3.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.5, 0.951051662150225, -0.3090319334976474}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.9876871119312596, -0.15644222232149346`}, {3.5, 
      0.9876871119312596, -0.15644222232149346`}, {3.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.5, 0.9876871119312596, -0.1564422223214935}, {3.75, 
      0.9876871119312596, -0.1564422223214935}, {3.75, 
      1., -4.163336342344337*^-16}, {3.5, 1., -4.163336342344337*^-16}, {3.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.5, 1., -4.440892098500626*^-16}, {3.75, 
      1., -4.440892098500626*^-16}, {3.75, 0.9876871119312597, 
      0.15644222232149263`}, {3.5, 0.9876871119312597, 
      0.15644222232149263`}, {3.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.5, 0.9876871119312597, 0.1564422223214926}, {3.75, 
      0.9876871119312597, 0.1564422223214926}, {3.75, 0.9510516621502252, 
      0.30903193349764657`}, {3.5, 0.9510516621502252, 
      0.30903193349764657`}, {3.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{3.5, 0.9510516621502252, 0.30903193349764657`}, {3.75, 
      0.9510516621502252, 0.30903193349764657`}, {3.75, 0.8909958270419003, 
      0.4540114934601547}, {3.5, 0.8909958270419003, 0.4540114934601547}, {
      3.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.5, 0.8909958270419003, 0.4540114934601547}, {3.75, 
      0.8909958270419003, 0.4540114934601547}, {3.75, 0.808998528157412, 
      0.5878106680208697}, {3.5, 0.808998528157412, 0.5878106680208697}, {3.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.5, 0.8089985281574118, 0.58781066802087}, {3.75, 
      0.8089985281574118, 0.58781066802087}, {3.75, 0.7070790126229676, 
      0.70713454865968}, {3.5, 0.7070790126229676, 0.70713454865968}, {3.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.5, 0.7070790126229676, 0.70713454865968}, {3.75, 
      0.7070790126229676, 0.70713454865968}, {3.75, 0.5877471276121592, 
      0.8090446922041181}, {3.5, 0.5877471276121592, 0.8090446922041181}, {
      3.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.5, 0.5877471276121592, 0.8090446922041181}, {3.75, 
      0.5877471276121592, 0.8090446922041181}, {3.75, 0.45394151341132644`, 
      0.8910314822731207}, {3.5, 0.45394151341132644`, 0.8910314822731207}, {
      3.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.5, 0.45394151341132644`, 0.8910314822731207}, {3.75, 
      0.45394151341132644`, 0.8910314822731207}, {3.75, 0.3089572371217171, 
      0.9510759305282176}, {3.5, 0.3089572371217171, 0.9510759305282176}, {
      3.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.5, 0.3089572371217171, 0.9510759305282176}, {3.75, 
      0.3089572371217171, 0.9510759305282176}, {3.75, 0.15636464907469383`, 
      0.9876993958283805}, {3.5, 0.15636464907469383`, 0.9876993958283805}, {
      3.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.5, 0.15636464907469383`, 0.9876993958283805}, {3.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      3.75, -0.00007853981625862234, 0.9999999969157486}, {
      3.5, -0.00007853981625862234, 0.9999999969157486}, {3.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{3.5, -0.00007853981625862234, 0.9999999969157486}, {
      3.75, -0.00007853981625862234, 0.9999999969157486}, {
      3.75, -0.156519794603278, 0.9876748219415881}, {3.5, -0.156519794603278,
       0.9876748219415881}, {3.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.5, -0.156519794603278, 0.9876748219415881}, {
      3.75, -0.156519794603278, 0.9876748219415881}, {
      3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.5, -0.3091066279673126, 0.9510273879056678}, {3.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{3.5, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.5, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.5, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.707190080334431, 0.7070234722246362}, {3.5, -0.707190080334431,
       0.7070234722246362}, {3.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.5, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.5, -0.8090908512602302, 0.5876835835779286}, {3.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{3.5, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.5, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.5, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{3.5, -0.9877116736328749, 0.15628707486335883`}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}, {
      3.75, -0.9999999876629945, -0.0001570796320327716}, {
      3.5, -0.9999999876629945, -0.0001570796320327716}, {
      3.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{3.75, -0.9999999876629945, 0.00015707963203365978`}, {
      4., -0.9999999876629945, 0.00015707963203365978`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.987711673632875, -0.15628707486335794`}, {
      3.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{3.75, -0.987711673632875, -0.15628707486335794`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.951100193039496, -0.3088825388399828}, {
      3.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{3.75, -0.951100193039496, -0.3088825388399828}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.8910671320080115, -0.4538715305623575}, {
      3.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{3.75, -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8090908512602306, -0.5876835835779278}, {
      3.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{3.75, -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.7071900803344316, -0.7070234722246357}, {
      3.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{3.75, -0.7071900803344316, -0.7070234722246357}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.5878742048036698, -0.8089523591203952}, {
      3.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{3.75, -0.5878742048036698, -0.8089523591203952}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.45408147070841337`, -0.890960166314569}, {
      3.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{3.75, -0.45408147070841337`, -0.890960166314569}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      4., -0.3091066279673134, -0.9510273879056674}, {
      3.75, -0.3091066279673134, -0.9510273879056674}, {
      3.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{3.75, -0.3091066279673132, -0.9510273879056675}, {
      4., -0.3091066279673132, -0.9510273879056675}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.15651979460327867`, -0.987674821941588}, {
      3.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{3.75, -0.15651979460327867`, -0.987674821941588}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}, {
      3.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{3.75, -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      3.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{3.75, 0.15636464907469316`, -0.9876993958283806}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {4., 
      0.30895723712171647`, -0.9510759305282178}, {3.75, 
      0.30895723712171647`, -0.9510759305282178}, {3.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{3.75, 0.3089572371217167, -0.9510759305282178}, {4., 
      0.3089572371217167, -0.9510759305282178}, {4., 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.453941513411326, -0.8910314822731209}, {3.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{3.75, 0.453941513411326, -0.8910314822731209}, {4., 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.5877471276121589, -0.8090446922041185}, {3.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{3.75, 0.5877471276121589, -0.8090446922041185}, {4., 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.7070790126229672, -0.7071345486596803}, {3.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{3.75, 0.7070790126229672, -0.7071345486596803}, {4., 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.8089985281574115, -0.5878106680208703}, {3.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{3.75, 0.8089985281574115, -0.5878106680208703}, {4., 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8909958270419, -0.45401149346015546`}, {3.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{3.75, 0.8909958270419, -0.45401149346015546`}, {4., 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.951051662150225, -0.3090319334976474}, {3.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{3.75, 0.951051662150225, -0.3090319334976474}, {4., 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.9876871119312596, -0.15644222232149346`}, {3.75, 
      0.9876871119312596, -0.15644222232149346`}, {3.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{3.75, 0.9876871119312596, -0.1564422223214935}, {4., 
      0.9876871119312596, -0.1564422223214935}, {4., 
      1., -4.163336342344337*^-16}, {3.75, 1., -4.163336342344337*^-16}, {
      3.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{3.75, 1., -4.440892098500626*^-16}, {4., 
      1., -4.440892098500626*^-16}, {4., 0.9876871119312597, 
      0.15644222232149263`}, {3.75, 0.9876871119312597, 
      0.15644222232149263`}, {3.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{3.75, 0.9876871119312597, 0.1564422223214926}, {4., 
      0.9876871119312597, 0.1564422223214926}, {4., 0.9510516621502252, 
      0.30903193349764657`}, {3.75, 0.9510516621502252, 
      0.30903193349764657`}, {3.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{3.75, 0.9510516621502252, 0.30903193349764657`}, {4., 
      0.9510516621502252, 0.30903193349764657`}, {4., 0.8909958270419003, 
      0.4540114934601547}, {3.75, 0.8909958270419003, 0.4540114934601547}, {
      3.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{3.75, 0.8909958270419003, 0.4540114934601547}, {4., 
      0.8909958270419003, 0.4540114934601547}, {4., 0.808998528157412, 
      0.5878106680208697}, {3.75, 0.808998528157412, 0.5878106680208697}, {
      3.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{3.75, 0.8089985281574118, 0.58781066802087}, {4., 
      0.8089985281574118, 0.58781066802087}, {4., 0.7070790126229676, 
      0.70713454865968}, {3.75, 0.7070790126229676, 0.70713454865968}, {3.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{3.75, 0.7070790126229676, 0.70713454865968}, {4., 
      0.7070790126229676, 0.70713454865968}, {4., 0.5877471276121592, 
      0.8090446922041181}, {3.75, 0.5877471276121592, 0.8090446922041181}, {
      3.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{3.75, 0.5877471276121592, 0.8090446922041181}, {4., 
      0.5877471276121592, 0.8090446922041181}, {4., 0.45394151341132644`, 
      0.8910314822731207}, {3.75, 0.45394151341132644`, 0.8910314822731207}, {
      3.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{3.75, 0.45394151341132644`, 0.8910314822731207}, {4., 
      0.45394151341132644`, 0.8910314822731207}, {4., 0.3089572371217171, 
      0.9510759305282176}, {3.75, 0.3089572371217171, 0.9510759305282176}, {
      3.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{3.75, 0.3089572371217171, 0.9510759305282176}, {4., 
      0.3089572371217171, 0.9510759305282176}, {4., 0.15636464907469383`, 
      0.9876993958283805}, {3.75, 0.15636464907469383`, 0.9876993958283805}, {
      3.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{3.75, 0.15636464907469383`, 0.9876993958283805}, {4., 
      0.15636464907469383`, 0.9876993958283805}, {4., -0.00007853981625862234,
       0.9999999969157486}, {3.75, -0.00007853981625862234, 
      0.9999999969157486}, {3.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{3.75, -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.156519794603278, 0.9876748219415881}, {3.75, -0.156519794603278, 
      0.9876748219415881}, {3.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{3.75, -0.156519794603278, 0.9876748219415881}, {
      4., -0.156519794603278, 0.9876748219415881}, {4., -0.3091066279673126, 
      0.9510273879056678}, {3.75, -0.3091066279673126, 0.9510273879056678}, {
      3.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{3.75, -0.3091066279673126, 0.9510273879056678}, {
      4., -0.3091066279673126, 0.9510273879056678}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}, {
      3.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{3.75, -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.5878742048036691, 0.8089523591203958}, {
      3.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{3.75, -0.5878742048036691, 0.8089523591203958}, {
      4., -0.5878742048036691, 0.8089523591203958}, {4., -0.707190080334431, 
      0.7070234722246362}, {3.75, -0.707190080334431, 0.7070234722246362}, {
      3.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{3.75, -0.707190080334431, 0.7070234722246362}, {
      4., -0.707190080334431, 0.7070234722246362}, {4., -0.8090908512602302, 
      0.5876835835779286}, {3.75, -0.8090908512602302, 0.5876835835779286}, {
      3.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{3.75, -0.8090908512602302, 0.5876835835779286}, {
      4., -0.8090908512602302, 0.5876835835779286}, {4., -0.8910671320080111, 
      0.4538715305623583}, {3.75, -0.8910671320080111, 0.4538715305623583}, {
      3.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{3.75, -0.8910671320080111, 0.4538715305623583}, {
      4., -0.8910671320080111, 0.4538715305623583}, {4., -0.9511001930394957, 
      0.3088825388399836}, {3.75, -0.9511001930394957, 0.3088825388399836}, {
      3.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{3.75, -0.9511001930394957, 0.3088825388399836}, {
      4., -0.9511001930394957, 0.3088825388399836}, {4., -0.9877116736328749, 
      0.15628707486335883`}, {3.75, -0.9877116736328749, 
      0.15628707486335883`}, {3.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{3.75, -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9999999876629945, -0.0001570796320327716}, {
      3.75, -0.9999999876629945, -0.0001570796320327716}, {
      3.75, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4., -0.9999999876629945, 0.00015707963203365978`}, {
      4.25, -0.9999999876629945, 0.00015707963203365978`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4., -0.987711673632875, -0.15628707486335794`}, {
      4., -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4., -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4., -0.951100193039496, -0.3088825388399828}, {
      4., -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4., -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4., -0.8910671320080115, -0.4538715305623575}, {
      4., -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4., -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8090908512602306, -0.5876835835779278}, {
      4., -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4., -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4., -0.7071900803344316, -0.7070234722246357}, {
      4., -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4., -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4., -0.5878742048036698, -0.8089523591203952}, {
      4., -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4., -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4., -0.45408147070841337`, -0.890960166314569}, {
      4., -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4., -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.3091066279673134, -0.9510273879056674}, {
      4., -0.3091066279673134, -0.9510273879056674}, {
      4., -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4., -0.3091066279673132, -0.9510273879056675}, {
      4.25, -0.3091066279673132, -0.9510273879056675}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4., -0.15651979460327867`, -0.987674821941588}, {
      4., -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4., -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.00007853981625928847, -0.9999999969157486}, {
      4., -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4., -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {4., 
      0.15636464907469316`, -0.9876993958283806}, {
      4., -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4., 0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.30895723712171647`, -0.9510759305282178}, {4., 
      0.30895723712171647`, -0.9510759305282178}, {4., 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4., 0.3089572371217167, -0.9510759305282178}, {4.25, 
      0.3089572371217167, -0.9510759305282178}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.453941513411326, -0.8910314822731209}, {4., 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4., 0.453941513411326, -0.8910314822731209}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.5877471276121589, -0.8090446922041185}, {4., 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4., 0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.7070790126229672, -0.7071345486596803}, {4., 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4., 0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.8089985281574115, -0.5878106680208703}, {4., 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4., 0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.8909958270419, -0.45401149346015546`}, {4., 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4., 0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.951051662150225, -0.3090319334976474}, {4., 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4., 0.951051662150225, -0.3090319334976474}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.9876871119312596, -0.15644222232149346`}, {4., 
      0.9876871119312596, -0.15644222232149346`}, {4., 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4., 0.9876871119312596, -0.1564422223214935}, {4.25, 
      0.9876871119312596, -0.1564422223214935}, {4.25, 
      1., -4.163336342344337*^-16}, {4., 1., -4.163336342344337*^-16}, {4., 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4., 1., -4.440892098500626*^-16}, {4.25, 
      1., -4.440892098500626*^-16}, {4.25, 0.9876871119312597, 
      0.15644222232149263`}, {4., 0.9876871119312597, 0.15644222232149263`}, {
      4., 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4., 0.9876871119312597, 0.1564422223214926}, {4.25, 
      0.9876871119312597, 0.1564422223214926}, {4.25, 0.9510516621502252, 
      0.30903193349764657`}, {4., 0.9510516621502252, 0.30903193349764657`}, {
      4., 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{4., 0.9510516621502252, 0.30903193349764657`}, {4.25, 
      0.9510516621502252, 0.30903193349764657`}, {4.25, 0.8909958270419003, 
      0.4540114934601547}, {4., 0.8909958270419003, 0.4540114934601547}, {4., 
      0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4., 0.8909958270419003, 0.4540114934601547}, {4.25, 
      0.8909958270419003, 0.4540114934601547}, {4.25, 0.808998528157412, 
      0.5878106680208697}, {4., 0.808998528157412, 0.5878106680208697}, {4., 
      0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4., 0.8089985281574118, 0.58781066802087}, {4.25, 
      0.8089985281574118, 0.58781066802087}, {4.25, 0.7070790126229676, 
      0.70713454865968}, {4., 0.7070790126229676, 0.70713454865968}, {4., 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4., 0.7070790126229676, 0.70713454865968}, {4.25, 
      0.7070790126229676, 0.70713454865968}, {4.25, 0.5877471276121592, 
      0.8090446922041181}, {4., 0.5877471276121592, 0.8090446922041181}, {4., 
      0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4., 0.5877471276121592, 0.8090446922041181}, {4.25, 
      0.5877471276121592, 0.8090446922041181}, {4.25, 0.45394151341132644`, 
      0.8910314822731207}, {4., 0.45394151341132644`, 0.8910314822731207}, {
      4., 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4., 0.45394151341132644`, 0.8910314822731207}, {4.25, 
      0.45394151341132644`, 0.8910314822731207}, {4.25, 0.3089572371217171, 
      0.9510759305282176}, {4., 0.3089572371217171, 0.9510759305282176}, {4., 
      0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4., 0.3089572371217171, 0.9510759305282176}, {4.25, 
      0.3089572371217171, 0.9510759305282176}, {4.25, 0.15636464907469383`, 
      0.9876993958283805}, {4., 0.15636464907469383`, 0.9876993958283805}, {
      4., 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4., 0.15636464907469383`, 0.9876993958283805}, {4.25, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4., -0.00007853981625862234, 0.9999999969157486}, {4., 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4., -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.156519794603278, 0.9876748219415881}, {4., -0.156519794603278, 
      0.9876748219415881}, {4., -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4., -0.156519794603278, 0.9876748219415881}, {
      4.25, -0.156519794603278, 0.9876748219415881}, {
      4.25, -0.3091066279673126, 0.9510273879056678}, {
      4., -0.3091066279673126, 0.9510273879056678}, {4., -0.156519794603278, 
      0.9876748219415881}}], 
     Polygon3DBox[{{4., -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.45408147070841254`, 0.8909601663145693}, {
      4., -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4., -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4., -0.5878742048036691, 0.8089523591203958}, {
      4., -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4., -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.707190080334431, 0.7070234722246362}, {4., -0.707190080334431, 
      0.7070234722246362}, {4., -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4., -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.8090908512602302, 0.5876835835779286}, {
      4., -0.8090908512602302, 0.5876835835779286}, {4., -0.707190080334431, 
      0.7070234722246362}}], 
     Polygon3DBox[{{4., -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4., -0.8910671320080111, 0.4538715305623583}, {4., -0.8090908512602302, 
      0.5876835835779286}}], 
     Polygon3DBox[{{4., -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4., -0.9511001930394957, 0.3088825388399836}, {4., -0.8910671320080111, 
      0.4538715305623583}}], 
     Polygon3DBox[{{4., -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9877116736328749, 0.15628707486335883`}, {
      4., -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4., -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9999999876629945, -0.0001570796320327716}, {
      4., -0.9999999876629945, -0.0001570796320327716}, {
      4., -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.25, -0.9999999876629945, 0.00015707963203365978`}, {
      4.5, -0.9999999876629945, 0.00015707963203365978`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.25, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.25, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.951100193039496, -0.3088825388399828}, {
      4.25, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.25, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.25, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.25, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.25, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.25, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.25, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.25, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.25, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.25, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.25, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.25, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.3091066279673134, -0.9510273879056674}, {
      4.25, -0.3091066279673134, -0.9510273879056674}, {
      4.25, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.25, -0.3091066279673132, -0.9510273879056675}, {
      4.5, -0.3091066279673132, -0.9510273879056675}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.25, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.25, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4.25, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.25, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.25, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.25, 0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.30895723712171647`, -0.9510759305282178}, {4.25, 
      0.30895723712171647`, -0.9510759305282178}, {4.25, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.25, 0.3089572371217167, -0.9510759305282178}, {4.5, 
      0.3089572371217167, -0.9510759305282178}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.453941513411326, -0.8910314822731209}, {4.25, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.25, 0.453941513411326, -0.8910314822731209}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.5877471276121589, -0.8090446922041185}, {4.25, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.25, 0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.7070790126229672, -0.7071345486596803}, {4.25, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.25, 0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.8089985281574115, -0.5878106680208703}, {4.25, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.25, 0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8909958270419, -0.45401149346015546`}, {4.25, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.25, 0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.951051662150225, -0.3090319334976474}, {4.25, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.25, 0.951051662150225, -0.3090319334976474}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.9876871119312596, -0.15644222232149346`}, {4.25, 
      0.9876871119312596, -0.15644222232149346`}, {4.25, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.25, 0.9876871119312596, -0.1564422223214935}, {4.5, 
      0.9876871119312596, -0.1564422223214935}, {4.5, 
      1., -4.163336342344337*^-16}, {4.25, 1., -4.163336342344337*^-16}, {
      4.25, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.25, 1., -4.440892098500626*^-16}, {4.5, 
      1., -4.440892098500626*^-16}, {4.5, 0.9876871119312597, 
      0.15644222232149263`}, {4.25, 0.9876871119312597, 
      0.15644222232149263`}, {4.25, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.25, 0.9876871119312597, 0.1564422223214926}, {4.5, 
      0.9876871119312597, 0.1564422223214926}, {4.5, 0.9510516621502252, 
      0.30903193349764657`}, {4.25, 0.9510516621502252, 
      0.30903193349764657`}, {4.25, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{4.25, 0.9510516621502252, 0.30903193349764657`}, {4.5, 
      0.9510516621502252, 0.30903193349764657`}, {4.5, 0.8909958270419003, 
      0.4540114934601547}, {4.25, 0.8909958270419003, 0.4540114934601547}, {
      4.25, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.25, 0.8909958270419003, 0.4540114934601547}, {4.5, 
      0.8909958270419003, 0.4540114934601547}, {4.5, 0.808998528157412, 
      0.5878106680208697}, {4.25, 0.808998528157412, 0.5878106680208697}, {
      4.25, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.25, 0.8089985281574118, 0.58781066802087}, {4.5, 
      0.8089985281574118, 0.58781066802087}, {4.5, 0.7070790126229676, 
      0.70713454865968}, {4.25, 0.7070790126229676, 0.70713454865968}, {4.25, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.25, 0.7070790126229676, 0.70713454865968}, {4.5, 
      0.7070790126229676, 0.70713454865968}, {4.5, 0.5877471276121592, 
      0.8090446922041181}, {4.25, 0.5877471276121592, 0.8090446922041181}, {
      4.25, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.25, 0.5877471276121592, 0.8090446922041181}, {4.5, 
      0.5877471276121592, 0.8090446922041181}, {4.5, 0.45394151341132644`, 
      0.8910314822731207}, {4.25, 0.45394151341132644`, 0.8910314822731207}, {
      4.25, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.25, 0.45394151341132644`, 0.8910314822731207}, {4.5, 
      0.45394151341132644`, 0.8910314822731207}, {4.5, 0.3089572371217171, 
      0.9510759305282176}, {4.25, 0.3089572371217171, 0.9510759305282176}, {
      4.25, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.25, 0.3089572371217171, 0.9510759305282176}, {4.5, 
      0.3089572371217171, 0.9510759305282176}, {4.5, 0.15636464907469383`, 
      0.9876993958283805}, {4.25, 0.15636464907469383`, 0.9876993958283805}, {
      4.25, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.25, 0.15636464907469383`, 0.9876993958283805}, {4.5, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.25, -0.00007853981625862234, 0.9999999969157486}, {4.25, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4.25, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.156519794603278, 0.9876748219415881}, {4.25, -0.156519794603278,
       0.9876748219415881}, {4.25, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.25, -0.156519794603278, 0.9876748219415881}, {
      4.5, -0.156519794603278, 0.9876748219415881}, {4.5, -0.3091066279673126,
       0.9510273879056678}, {4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.25, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{4.25, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.25, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.25, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.25, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.25, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {4.5, -0.707190080334431,
       0.7070234722246362}, {4.25, -0.707190080334431, 0.7070234722246362}, {
      4.25, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.25, -0.707190080334431, 0.7070234722246362}, {
      4.5, -0.707190080334431, 0.7070234722246362}, {4.5, -0.8090908512602302,
       0.5876835835779286}, {4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.25, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{4.25, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.25, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.25, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.25, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.25, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.25, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4.25, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9999999876629945, -0.0001570796320327716}, {
      4.25, -0.9999999876629945, -0.0001570796320327716}, {
      4.25, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.5, -0.9999999876629945, 0.00015707963203365978`}, {
      4.75, -0.9999999876629945, 0.00015707963203365978`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.5, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.5, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.951100193039496, -0.3088825388399828}, {
      4.5, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.5, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.5, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.5, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.5, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.5, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.5, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.5, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.5, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.5, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.5, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.5, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.3091066279673134, -0.9510273879056674}, {
      4.5, -0.3091066279673134, -0.9510273879056674}, {
      4.5, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.5, -0.3091066279673132, -0.9510273879056675}, {
      4.75, -0.3091066279673132, -0.9510273879056675}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.5, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.5, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.5, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.5, -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.5, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.5, 0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.30895723712171647`, -0.9510759305282178}, {4.5, 
      0.30895723712171647`, -0.9510759305282178}, {4.5, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.5, 0.3089572371217167, -0.9510759305282178}, {4.75, 
      0.3089572371217167, -0.9510759305282178}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.453941513411326, -0.8910314822731209}, {4.5, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.5, 0.453941513411326, -0.8910314822731209}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.5877471276121589, -0.8090446922041185}, {4.5, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.5, 0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.7070790126229672, -0.7071345486596803}, {4.5, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.5, 0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.8089985281574115, -0.5878106680208703}, {4.5, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.5, 0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8909958270419, -0.45401149346015546`}, {4.5, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.5, 0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.951051662150225, -0.3090319334976474}, {4.5, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.5, 0.951051662150225, -0.3090319334976474}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.9876871119312596, -0.15644222232149346`}, {4.5, 
      0.9876871119312596, -0.15644222232149346`}, {4.5, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.5, 0.9876871119312596, -0.1564422223214935}, {4.75, 
      0.9876871119312596, -0.1564422223214935}, {4.75, 
      1., -4.163336342344337*^-16}, {4.5, 1., -4.163336342344337*^-16}, {4.5, 
      0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.5, 1., -4.440892098500626*^-16}, {4.75, 
      1., -4.440892098500626*^-16}, {4.75, 0.9876871119312597, 
      0.15644222232149263`}, {4.5, 0.9876871119312597, 
      0.15644222232149263`}, {4.5, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.5, 0.9876871119312597, 0.1564422223214926}, {4.75, 
      0.9876871119312597, 0.1564422223214926}, {4.75, 0.9510516621502252, 
      0.30903193349764657`}, {4.5, 0.9510516621502252, 
      0.30903193349764657`}, {4.5, 0.9876871119312597, 0.1564422223214926}}], 
     Polygon3DBox[{{4.5, 0.9510516621502252, 0.30903193349764657`}, {4.75, 
      0.9510516621502252, 0.30903193349764657`}, {4.75, 0.8909958270419003, 
      0.4540114934601547}, {4.5, 0.8909958270419003, 0.4540114934601547}, {
      4.5, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.5, 0.8909958270419003, 0.4540114934601547}, {4.75, 
      0.8909958270419003, 0.4540114934601547}, {4.75, 0.808998528157412, 
      0.5878106680208697}, {4.5, 0.808998528157412, 0.5878106680208697}, {4.5,
       0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.5, 0.8089985281574118, 0.58781066802087}, {4.75, 
      0.8089985281574118, 0.58781066802087}, {4.75, 0.7070790126229676, 
      0.70713454865968}, {4.5, 0.7070790126229676, 0.70713454865968}, {4.5, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.5, 0.7070790126229676, 0.70713454865968}, {4.75, 
      0.7070790126229676, 0.70713454865968}, {4.75, 0.5877471276121592, 
      0.8090446922041181}, {4.5, 0.5877471276121592, 0.8090446922041181}, {
      4.5, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.5, 0.5877471276121592, 0.8090446922041181}, {4.75, 
      0.5877471276121592, 0.8090446922041181}, {4.75, 0.45394151341132644`, 
      0.8910314822731207}, {4.5, 0.45394151341132644`, 0.8910314822731207}, {
      4.5, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.5, 0.45394151341132644`, 0.8910314822731207}, {4.75, 
      0.45394151341132644`, 0.8910314822731207}, {4.75, 0.3089572371217171, 
      0.9510759305282176}, {4.5, 0.3089572371217171, 0.9510759305282176}, {
      4.5, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.5, 0.3089572371217171, 0.9510759305282176}, {4.75, 
      0.3089572371217171, 0.9510759305282176}, {4.75, 0.15636464907469383`, 
      0.9876993958283805}, {4.5, 0.15636464907469383`, 0.9876993958283805}, {
      4.5, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.5, 0.15636464907469383`, 0.9876993958283805}, {4.75, 
      0.15636464907469383`, 0.9876993958283805}, {
      4.75, -0.00007853981625862234, 0.9999999969157486}, {
      4.5, -0.00007853981625862234, 0.9999999969157486}, {4.5, 
      0.15636464907469383`, 0.9876993958283805}}], 
     Polygon3DBox[{{4.5, -0.00007853981625862234, 0.9999999969157486}, {
      4.75, -0.00007853981625862234, 0.9999999969157486}, {
      4.75, -0.156519794603278, 0.9876748219415881}, {4.5, -0.156519794603278,
       0.9876748219415881}, {4.5, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.5, -0.156519794603278, 0.9876748219415881}, {
      4.75, -0.156519794603278, 0.9876748219415881}, {
      4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.5, -0.3091066279673126, 0.9510273879056678}, {4.5, -0.156519794603278,
       0.9876748219415881}}], 
     Polygon3DBox[{{4.5, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.5, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.5, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.5, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.5, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.707190080334431, 0.7070234722246362}, {4.5, -0.707190080334431,
       0.7070234722246362}, {4.5, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.5, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.5, -0.8090908512602302, 0.5876835835779286}, {4.5, -0.707190080334431,
       0.7070234722246362}}], 
     Polygon3DBox[{{4.5, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.5, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.5, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.5, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.5, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.5, -0.9511001930394957, 0.3088825388399836}}], 
     Polygon3DBox[{{4.5, -0.9877116736328749, 0.15628707486335883`}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}, {
      4.75, -0.9999999876629945, -0.0001570796320327716}, {
      4.5, -0.9999999876629945, -0.0001570796320327716}, {
      4.5, -0.9877116736328749, 0.15628707486335883`}}], 
     Polygon3DBox[{{4.75, -0.9999999876629945, 0.00015707963203365978`}, {
      5., -0.9999999876629945, 0.00015707963203365978`}, {
      5., -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.987711673632875, -0.15628707486335794`}, {
      4.75, -0.9999999876629945, 0.00015707963203365978`}}], 
     Polygon3DBox[{{4.75, -0.987711673632875, -0.15628707486335794`}, {
      5., -0.987711673632875, -0.15628707486335794`}, {
      5., -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.951100193039496, -0.3088825388399828}, {
      4.75, -0.987711673632875, -0.15628707486335794`}}], 
     Polygon3DBox[{{4.75, -0.951100193039496, -0.3088825388399828}, {
      5., -0.951100193039496, -0.3088825388399828}, {
      5., -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.8910671320080115, -0.4538715305623575}, {
      4.75, -0.951100193039496, -0.3088825388399828}}], 
     Polygon3DBox[{{4.75, -0.8910671320080115, -0.4538715305623575}, {
      5., -0.8910671320080115, -0.4538715305623575}, {
      5., -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8090908512602306, -0.5876835835779278}, {
      4.75, -0.8910671320080115, -0.4538715305623575}}], 
     Polygon3DBox[{{4.75, -0.8090908512602306, -0.5876835835779278}, {
      5., -0.8090908512602306, -0.5876835835779278}, {
      5., -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.7071900803344316, -0.7070234722246357}, {
      4.75, -0.8090908512602306, -0.5876835835779278}}], 
     Polygon3DBox[{{4.75, -0.7071900803344316, -0.7070234722246357}, {
      5., -0.7071900803344316, -0.7070234722246357}, {
      5., -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.5878742048036698, -0.8089523591203952}, {
      4.75, -0.7071900803344316, -0.7070234722246357}}], 
     Polygon3DBox[{{4.75, -0.5878742048036698, -0.8089523591203952}, {
      5., -0.5878742048036698, -0.8089523591203952}, {
      5., -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.45408147070841337`, -0.890960166314569}, {
      4.75, -0.5878742048036698, -0.8089523591203952}}], 
     Polygon3DBox[{{4.75, -0.45408147070841337`, -0.890960166314569}, {
      5., -0.45408147070841337`, -0.890960166314569}, {
      5., -0.3091066279673134, -0.9510273879056674}, {
      4.75, -0.3091066279673134, -0.9510273879056674}, {
      4.75, -0.45408147070841337`, -0.890960166314569}}], 
     Polygon3DBox[{{4.75, -0.3091066279673132, -0.9510273879056675}, {
      5., -0.3091066279673132, -0.9510273879056675}, {
      5., -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.15651979460327867`, -0.987674821941588}, {
      4.75, -0.3091066279673132, -0.9510273879056675}}], 
     Polygon3DBox[{{4.75, -0.15651979460327867`, -0.987674821941588}, {
      5., -0.15651979460327867`, -0.987674821941588}, {
      5., -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}, {
      4.75, -0.15651979460327867`, -0.987674821941588}}], 
     Polygon3DBox[{{4.75, -0.00007853981625928847, -0.9999999969157486}, {
      5., -0.00007853981625928847, -0.9999999969157486}, {5., 
      0.15636464907469316`, -0.9876993958283806}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}, {
      4.75, -0.00007853981625928847, -0.9999999969157486}}], 
     Polygon3DBox[{{4.75, 0.15636464907469316`, -0.9876993958283806}, {5., 
      0.15636464907469316`, -0.9876993958283806}, {5., 
      0.30895723712171647`, -0.9510759305282178}, {4.75, 
      0.30895723712171647`, -0.9510759305282178}, {4.75, 
      0.15636464907469316`, -0.9876993958283806}}], 
     Polygon3DBox[{{4.75, 0.3089572371217167, -0.9510759305282178}, {5., 
      0.3089572371217167, -0.9510759305282178}, {5., 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.453941513411326, -0.8910314822731209}, {4.75, 
      0.3089572371217167, -0.9510759305282178}}], 
     Polygon3DBox[{{4.75, 0.453941513411326, -0.8910314822731209}, {5., 
      0.453941513411326, -0.8910314822731209}, {5., 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.5877471276121589, -0.8090446922041185}, {4.75, 
      0.453941513411326, -0.8910314822731209}}], 
     Polygon3DBox[{{4.75, 0.5877471276121589, -0.8090446922041185}, {5., 
      0.5877471276121589, -0.8090446922041185}, {5., 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.7070790126229672, -0.7071345486596803}, {4.75, 
      0.5877471276121589, -0.8090446922041185}}], 
     Polygon3DBox[{{4.75, 0.7070790126229672, -0.7071345486596803}, {5., 
      0.7070790126229672, -0.7071345486596803}, {5., 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.8089985281574115, -0.5878106680208703}, {4.75, 
      0.7070790126229672, -0.7071345486596803}}], 
     Polygon3DBox[{{4.75, 0.8089985281574115, -0.5878106680208703}, {5., 
      0.8089985281574115, -0.5878106680208703}, {5., 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8909958270419, -0.45401149346015546`}, {4.75, 
      0.8089985281574115, -0.5878106680208703}}], 
     Polygon3DBox[{{4.75, 0.8909958270419, -0.45401149346015546`}, {5., 
      0.8909958270419, -0.45401149346015546`}, {5., 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.951051662150225, -0.3090319334976474}, {4.75, 
      0.8909958270419, -0.45401149346015546`}}], 
     Polygon3DBox[{{4.75, 0.951051662150225, -0.3090319334976474}, {5., 
      0.951051662150225, -0.3090319334976474}, {5., 
      0.9876871119312596, -0.15644222232149346`}, {4.75, 
      0.9876871119312596, -0.15644222232149346`}, {4.75, 
      0.951051662150225, -0.3090319334976474}}], 
     Polygon3DBox[{{4.75, 0.9876871119312596, -0.1564422223214935}, {5., 
      0.9876871119312596, -0.1564422223214935}, {5., 
      1., -4.163336342344337*^-16}, {4.75, 1., -4.163336342344337*^-16}, {
      4.75, 0.9876871119312596, -0.1564422223214935}}], 
     Polygon3DBox[{{4.75, 1., -4.440892098500626*^-16}, {5., 
      1., -4.440892098500626*^-16}, {5., 0.9876871119312597, 
      0.15644222232149263`}, {4.75, 0.9876871119312597, 
      0.15644222232149263`}, {4.75, 1., -4.440892098500626*^-16}}], 
     Polygon3DBox[{{4.75, 0.9876871119312597, 0.1564422223214926}, {5., 
      0.9876871119312597, 0.1564422223214926}, {5., 0.9510516621502252, 
      0.30903193349764657`}, {4.75, 0.9510516621502252, 
      0.30903193349764657`}, {4.75, 0.9876871119312597, 0.1564422223214926}}],
      Polygon3DBox[{{4.75, 0.9510516621502252, 0.30903193349764657`}, {5., 
      0.9510516621502252, 0.30903193349764657`}, {5., 0.8909958270419003, 
      0.4540114934601547}, {4.75, 0.8909958270419003, 0.4540114934601547}, {
      4.75, 0.9510516621502252, 0.30903193349764657`}}], 
     Polygon3DBox[{{4.75, 0.8909958270419003, 0.4540114934601547}, {5., 
      0.8909958270419003, 0.4540114934601547}, {5., 0.808998528157412, 
      0.5878106680208697}, {4.75, 0.808998528157412, 0.5878106680208697}, {
      4.75, 0.8909958270419003, 0.4540114934601547}}], 
     Polygon3DBox[{{4.75, 0.8089985281574118, 0.58781066802087}, {5., 
      0.8089985281574118, 0.58781066802087}, {5., 0.7070790126229676, 
      0.70713454865968}, {4.75, 0.7070790126229676, 0.70713454865968}, {4.75, 
      0.8089985281574118, 0.58781066802087}}], 
     Polygon3DBox[{{4.75, 0.7070790126229676, 0.70713454865968}, {5., 
      0.7070790126229676, 0.70713454865968}, {5., 0.5877471276121592, 
      0.8090446922041181}, {4.75, 0.5877471276121592, 0.8090446922041181}, {
      4.75, 0.7070790126229676, 0.70713454865968}}], 
     Polygon3DBox[{{4.75, 0.5877471276121592, 0.8090446922041181}, {5., 
      0.5877471276121592, 0.8090446922041181}, {5., 0.45394151341132644`, 
      0.8910314822731207}, {4.75, 0.45394151341132644`, 0.8910314822731207}, {
      4.75, 0.5877471276121592, 0.8090446922041181}}], 
     Polygon3DBox[{{4.75, 0.45394151341132644`, 0.8910314822731207}, {5., 
      0.45394151341132644`, 0.8910314822731207}, {5., 0.3089572371217171, 
      0.9510759305282176}, {4.75, 0.3089572371217171, 0.9510759305282176}, {
      4.75, 0.45394151341132644`, 0.8910314822731207}}], 
     Polygon3DBox[{{4.75, 0.3089572371217171, 0.9510759305282176}, {5., 
      0.3089572371217171, 0.9510759305282176}, {5., 0.15636464907469383`, 
      0.9876993958283805}, {4.75, 0.15636464907469383`, 0.9876993958283805}, {
      4.75, 0.3089572371217171, 0.9510759305282176}}], 
     Polygon3DBox[{{4.75, 0.15636464907469383`, 0.9876993958283805}, {5., 
      0.15636464907469383`, 0.9876993958283805}, {5., -0.00007853981625862234,
       0.9999999969157486}, {4.75, -0.00007853981625862234, 
      0.9999999969157486}, {4.75, 0.15636464907469383`, 0.9876993958283805}}],
      Polygon3DBox[{{4.75, -0.00007853981625862234, 0.9999999969157486}, {
      5., -0.00007853981625862234, 0.9999999969157486}, {
      5., -0.156519794603278, 0.9876748219415881}, {4.75, -0.156519794603278, 
      0.9876748219415881}, {4.75, -0.00007853981625862234, 
      0.9999999969157486}}], 
     Polygon3DBox[{{4.75, -0.156519794603278, 0.9876748219415881}, {
      5., -0.156519794603278, 0.9876748219415881}, {5., -0.3091066279673126, 
      0.9510273879056678}, {4.75, -0.3091066279673126, 0.9510273879056678}, {
      4.75, -0.156519794603278, 0.9876748219415881}}], 
     Polygon3DBox[{{4.75, -0.3091066279673126, 0.9510273879056678}, {
      5., -0.3091066279673126, 0.9510273879056678}, {
      5., -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}, {
      4.75, -0.3091066279673126, 0.9510273879056678}}], 
     Polygon3DBox[{{4.75, -0.45408147070841254`, 0.8909601663145693}, {
      5., -0.45408147070841254`, 0.8909601663145693}, {
      5., -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.5878742048036691, 0.8089523591203958}, {
      4.75, -0.45408147070841254`, 0.8909601663145693}}], 
     Polygon3DBox[{{4.75, -0.5878742048036691, 0.8089523591203958}, {
      5., -0.5878742048036691, 0.8089523591203958}, {5., -0.707190080334431, 
      0.7070234722246362}, {4.75, -0.707190080334431, 0.7070234722246362}, {
      4.75, -0.5878742048036691, 0.8089523591203958}}], 
     Polygon3DBox[{{4.75, -0.707190080334431, 0.7070234722246362}, {
      5., -0.707190080334431, 0.7070234722246362}, {5., -0.8090908512602302, 
      0.5876835835779286}, {4.75, -0.8090908512602302, 0.5876835835779286}, {
      4.75, -0.707190080334431, 0.7070234722246362}}], 
     Polygon3DBox[{{4.75, -0.8090908512602302, 0.5876835835779286}, {
      5., -0.8090908512602302, 0.5876835835779286}, {5., -0.8910671320080111, 
      0.4538715305623583}, {4.75, -0.8910671320080111, 0.4538715305623583}, {
      4.75, -0.8090908512602302, 0.5876835835779286}}], 
     Polygon3DBox[{{4.75, -0.8910671320080111, 0.4538715305623583}, {
      5., -0.8910671320080111, 0.4538715305623583}, {5., -0.9511001930394957, 
      0.3088825388399836}, {4.75, -0.9511001930394957, 0.3088825388399836}, {
      4.75, -0.8910671320080111, 0.4538715305623583}}], 
     Polygon3DBox[{{4.75, -0.9511001930394957, 0.3088825388399836}, {
      5., -0.9511001930394957, 0.3088825388399836}, {5., -0.9877116736328749, 
      0.15628707486335883`}, {4.75, -0.9877116736328749, 
      0.15628707486335883`}, {4.75, -0.9511001930394957, 
      0.3088825388399836}}], 
     Polygon3DBox[{{4.75, -0.9877116736328749, 0.15628707486335883`}, {
      5., -0.9877116736328749, 0.15628707486335883`}, {
      5., -0.9999999876629945, -0.0001570796320327716}, {
      4.75, -0.9999999876629945, -0.0001570796320327716}, {
      4.75, -0.9877116736328749, 0.15628707486335883`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5., -0.9999999876629945, -0.00015707963203365978`}, \
{-4.75, -0.9999999876629945, -0.00015707963203365978`}, {-4.5, \
-0.9999999876629945, -0.00015707963203365978`}, {-4.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-4., -0.9999999876629945, \
-0.00015707963203365978`}, {-3.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-3.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-3.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-3., -0.9999999876629945, \
-0.00015707963203365978`}, {-2.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-2.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-2.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-2., -0.9999999876629945, \
-0.00015707963203365978`}, {-1.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-1.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-1.25, -0.9999999876629945, \
-0.00015707963203365978`}, {-1., -0.9999999876629945, \
-0.00015707963203365978`}, {-0.75, -0.9999999876629945, \
-0.00015707963203365978`}, {-0.5, -0.9999999876629945, \
-0.00015707963203365978`}, {-0.25, -0.9999999876629945, \
-0.00015707963203365978`}, {
        0., -0.9999999876629945, -0.00015707963203365978`}, {
        0.25, -0.9999999876629945, -0.00015707963203365978`}, {
        0.5, -0.9999999876629945, -0.00015707963203365978`}, {
        0.75, -0.9999999876629945, -0.00015707963203365978`}, {
        1., -0.9999999876629945, -0.00015707963203365978`}, {
        1.25, -0.9999999876629945, -0.00015707963203365978`}, {
        1.5, -0.9999999876629945, -0.00015707963203365978`}, {
        1.75, -0.9999999876629945, -0.00015707963203365978`}, {
        2., -0.9999999876629945, -0.00015707963203365978`}, {
        2.25, -0.9999999876629945, -0.00015707963203365978`}, {
        2.5, -0.9999999876629945, -0.00015707963203365978`}, {
        2.75, -0.9999999876629945, -0.00015707963203365978`}, {
        3., -0.9999999876629945, -0.00015707963203365978`}, {
        3.25, -0.9999999876629945, -0.00015707963203365978`}, {
        3.5, -0.9999999876629945, -0.00015707963203365978`}, {
        3.75, -0.9999999876629945, -0.00015707963203365978`}, {
        4., -0.9999999876629945, -0.00015707963203365978`}, {
        4.25, -0.9999999876629945, -0.00015707963203365978`}, {
        4.5, -0.9999999876629945, -0.00015707963203365978`}, {
        4.75, -0.9999999876629945, -0.00015707963203365978`}, {
        5., -0.9999999876629945, -0.00015707963203365978`}, {
        5, -0.9999999876629945, -0.00015707963203365978`}, {
        5, -0.987711673632875, 0.15628707486335794`}, {
        5, -0.951100193039496, 0.3088825388399828}, {
        5, -0.8910671320080115, 0.4538715305623575}, {
        5, -0.8090908512602306, 0.5876835835779278}, {
        5, -0.7071900803344316, 0.7070234722246357}, {
        5, -0.5878742048036698, 0.8089523591203952}, {
        5, -0.45408147070841337`, 0.890960166314569}, {
        5, -0.3091066279673132, 0.9510273879056675}, {
        5, -0.15651979460327867`, 0.987674821941588}, {
        5, -0.00007853981625928847, 0.9999999969157486}, {
        5, 0.15636464907469316`, 0.9876993958283806}, {
        5, 0.3089572371217167, 0.9510759305282178}, {
        5, 0.453941513411326, 0.8910314822731209}, {
        5, 0.5877471276121589, 0.8090446922041185}, {
        5, 0.7070790126229672, 0.7071345486596803}, {
        5, 0.8089985281574115, 0.5878106680208703}, {
        5, 0.8909958270419, 0.45401149346015546`}, {
        5, 0.951051662150225, 0.3090319334976474}, {
        5, 0.9876871119312596, 0.1564422223214935}, {
        5, 1., 4.440892098500626*^-16}, {
        5, 0.9876871119312597, -0.1564422223214926}, {
        5, 0.9510516621502252, -0.30903193349764657`}, {
        5, 0.8909958270419003, -0.4540114934601547}, {
        5, 0.8089985281574118, -0.58781066802087}, {
        5, 0.7070790126229676, -0.70713454865968}, {
        5, 0.5877471276121592, -0.8090446922041181}, {
        5, 0.45394151341132644`, -0.8910314822731207}, {
        5, 0.3089572371217171, -0.9510759305282176}, {
        5, 0.15636464907469383`, -0.9876993958283805}, {
        5, -0.00007853981625862234, -0.9999999969157486}, {
        5, -0.156519794603278, -0.9876748219415881}, {
        5, -0.3091066279673126, -0.9510273879056678}, {
        5, -0.45408147070841254`, -0.8909601663145693}, {
        5, -0.5878742048036691, -0.8089523591203958}, {
        5, -0.707190080334431, -0.7070234722246362}, {
        5, -0.8090908512602302, -0.5876835835779286}, {
        5, -0.8910671320080111, -0.4538715305623583}, {
        5, -0.9511001930394957, -0.3088825388399836}, {
        5, -0.9877116736328749, -0.15628707486335883`}, {
        5, -0.9999999876629945, 0.0001570796320327716}, {
        5., -0.9999999876629945, 0.00015707963203365978`}, {
        4.75, -0.9999999876629945, 0.00015707963203365978`}, {
        4.5, -0.9999999876629945, 0.00015707963203365978`}, {
        4.25, -0.9999999876629945, 0.00015707963203365978`}, {
        4., -0.9999999876629945, 0.00015707963203365978`}, {
        3.75, -0.9999999876629945, 0.00015707963203365978`}, {
        3.5, -0.9999999876629945, 0.00015707963203365978`}, {
        3.25, -0.9999999876629945, 0.00015707963203365978`}, {
        3., -0.9999999876629945, 0.00015707963203365978`}, {
        2.75, -0.9999999876629945, 0.00015707963203365978`}, {
        2.5, -0.9999999876629945, 0.00015707963203365978`}, {
        2.25, -0.9999999876629945, 0.00015707963203365978`}, {
        2., -0.9999999876629945, 0.00015707963203365978`}, {
        1.75, -0.9999999876629945, 0.00015707963203365978`}, {
        1.5, -0.9999999876629945, 0.00015707963203365978`}, {
        1.25, -0.9999999876629945, 0.00015707963203365978`}, {
        1., -0.9999999876629945, 0.00015707963203365978`}, {
        0.75, -0.9999999876629945, 0.00015707963203365978`}, {
        0.5, -0.9999999876629945, 0.00015707963203365978`}, {
        0.25, -0.9999999876629945, 0.00015707963203365978`}, {
        0., -0.9999999876629945, 
        0.00015707963203365978`}, {-0.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-0.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-0.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-1., -0.9999999876629945, 
        0.00015707963203365978`}, {-1.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-1.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-1.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-2., -0.9999999876629945, 
        0.00015707963203365978`}, {-2.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-2.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-2.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-3., -0.9999999876629945, 
        0.00015707963203365978`}, {-3.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-3.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-3.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-4., -0.9999999876629945, 
        0.00015707963203365978`}, {-4.25, -0.9999999876629945, 
        0.00015707963203365978`}, {-4.5, -0.9999999876629945, 
        0.00015707963203365978`}, {-4.75, -0.9999999876629945, 
        0.00015707963203365978`}, {-5., -0.9999999876629945, 
        0.00015707963203365978`}, {-5, -0.9999999876629945, 
         0.00015707963203365978`}, {-5, -0.987711673632875, \
-0.15628707486335794`}, {-5, -0.951100193039496, -0.3088825388399828}, {-5, \
-0.8910671320080115, -0.4538715305623575}, {-5, -0.8090908512602306, \
-0.5876835835779278}, {-5, -0.7071900803344316, -0.7070234722246357}, {-5, \
-0.5878742048036698, -0.8089523591203952}, {-5, -0.45408147070841337`, \
-0.890960166314569}, {-5, -0.3091066279673132, -0.9510273879056675}, {-5, \
-0.15651979460327867`, -0.987674821941588}, {-5, -0.00007853981625928847, \
-0.9999999969157486}, {-5, 0.15636464907469316`, -0.9876993958283806}, {-5, 
         0.3089572371217167, -0.9510759305282178}, {-5, 
         0.453941513411326, -0.8910314822731209}, {-5, 
         0.5877471276121589, -0.8090446922041185}, {-5, 
         0.7070790126229672, -0.7071345486596803}, {-5, 
         0.8089985281574115, -0.5878106680208703}, {-5, 
         0.8909958270419, -0.45401149346015546`}, {-5, 
         0.951051662150225, -0.3090319334976474}, {-5, 
         0.9876871119312596, -0.1564422223214935}, {-5, 
         1., -4.440892098500626*^-16}, {-5, 0.9876871119312597, 
         0.1564422223214926}, {-5, 0.9510516621502252, 
         0.30903193349764657`}, {-5, 0.8909958270419003, 
         0.4540114934601547}, {-5, 0.8089985281574118, 0.58781066802087}, {-5,
          0.7070790126229676, 0.70713454865968}, {-5, 0.5877471276121592, 
         0.8090446922041181}, {-5, 0.45394151341132644`, 
         0.8910314822731207}, {-5, 0.3089572371217171, 
         0.9510759305282176}, {-5, 0.15636464907469383`, 
         0.9876993958283805}, {-5, -0.00007853981625862234, 
         0.9999999969157486}, {-5, -0.156519794603278, 
         0.9876748219415881}, {-5, -0.3091066279673126, 
         0.9510273879056678}, {-5, -0.45408147070841254`, 
         0.8909601663145693}, {-5, -0.5878742048036691, 
         0.8089523591203958}, {-5, -0.707190080334431, 
         0.7070234722246362}, {-5, -0.8090908512602302, 
         0.5876835835779286}, {-5, -0.8910671320080111, 
         0.4538715305623583}, {-5, -0.9511001930394957, 
         0.3088825388399836}, {-5, -0.9877116736328749, 
         0.15628707486335883`}, {-5, -0.9999999876629945, \
-0.0001570796320327716}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301544375805*^9, 3.614709312118828*^9, 
  3.6147291674823647`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"During evaluation of In[251]:="],

Cell[BoxData[
 GraphicsBox[{PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-1.14999998599251, 0.00017949157685264542`}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{-0.5751032944411802, -0.9958695701360198}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{0.5749488484391366, -0.995958744968139}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{1.1499999999994248`, 1.1499999999998081`*^-6}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{0.5749468565204975, 0.9959598948638436}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-0.5751052861791697, 0.9958684199274396}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   PointBox[{-1.149999985631227, -0.0001817915768245914}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-1.14999998599251, 0.00017949157685264542`}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-1.14999998599251, 
    0.00017949157685264542`}, {-0.5751032944411802, -0.9958695701360198}, \
{-0.5751032944411802, -0.9958695701360198}, {-1.14999998599251, 
    0.00017949157685264542`}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}, {-0.5751032944411802, -0.9958695701360198}}], 
   LineBox[{{-0.5751032944411802, -0.9958695701360198}, {
    0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}, {-0.5751032944411802, \
-0.9958695701360198}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}, {
    0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{0.5749488484391366, -0.995958744968139}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {0.5749488484391366, -0.995958744968139}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}, {1.1499999999994248`, 
    1.1499999999998081`*^-6}}], 
   LineBox[{{1.1499999999994248`, 1.1499999999998081`*^-6}, {
    0.5749468565204975, 0.9959598948638436}, {0.5749468565204975, 
    0.9959598948638436}, {1.1499999999994248`, 1.1499999999998081`*^-6}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {0.5749468565204975, 0.9959598948638436}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{0.5749468565204975, 0.9959598948638436}, {-0.5751052861791697, 
    0.9958684199274396}, {-0.5751052861791697, 0.9958684199274396}, {
    0.5749468565204975, 0.9959598948638436}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-0.5751052861791697, 0.9958684199274396}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   LineBox[{{-0.5751052861791697, 
    0.9958684199274396}, {-1.149999985631227, -0.0001817915768245914}, \
{-1.149999985631227, -0.0001817915768245914}, {-0.5751052861791697, 
    0.9958684199274396}}], 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAIBmIQDQEf7BlQwCh/lD/KH+WP8tH5AA5DZD4=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJyF1G1IU1EYB/Crq7BWFiIFgh+KPklG0dVlIx7p5Yu5qOxlHypMevGlXFJR
2YeBIyHQigqhrFwvUFIMB4WU1FPsShZrW9wPSXAJrzlYrM1EogVpV88J6t+H
LlzG4eye8z/P8+MsrvFsO5CtKEqV9U79ltRXZyYn01z4Ohbq7VhKectn+HZ0
WuNAd5YjS+NLe+Y8rPOkuNC8t6FP03ldc8zR5Uuy+9jCYudcgwcyqjfvU4Jt
/jNvXRGT73ytWeS6FecLwZ096a44nzt4+qIRNbmpNJI7aib42b5rTx/MN7jJ
Zx953pLkkmWtRYcGdP7xLf9nrDHFzsfeVe9zNH6yqX5NjpXDfnZI6+3I5/YC
98RUzrt7bfzSppHrSkPIac1nHFWXx/t1GlPVN6VWzvXeq4+q5xk0sbrl+HYr
p2fFkQV6xKTy6y+CweEEN37eXbTfH6cTAfvtQX+co7tuDm0ZTtDKk4e3uq2c
786XB2b7kqQPFpS15hrc3ecYsXlSFO4Z+1j8SufKG+3Kks40hcIVzZWzNFam
n1FS5PN7XhfzdF9+r4vvKSrX/yDWp7DcXxX7U4PMd0rko1qZf6PIT6o8X3bZ
9Pnoizz/uDg/tcn6bBb1IftM88/6UcXf9aW1sv7fRf2pX/bnqOgPtcn+eUT/
CPpL0H8CHwR+0BeBP8Yx/h/Xw/0wD+YFjwQeCTwSeCTwSOCRwCOBRwKPBB4J
PBJ4JPBI4JH+45HBI4NHBo8MHhk8Mnhk8MjgkcEjg0cGjwweGTz+c9/gfYT3
Fd5neN/hfYjjX+FtxtI=
       "]]}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     PolygonBox[{{-0.9999999876629945, 
      0.00015707963203365978`}, {-0.9999999876629945, 
      0.00015707963203365978`}, {-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.9999999876629945, 
      0.00015707963203365978`}}], 
     PolygonBox[{{-0.987711673632875, -0.15628707486335794`}, \
{-0.987711673632875, -0.15628707486335794`}, {-0.951100193039496, \
-0.3088825388399828}, {-0.951100193039496, -0.3088825388399828}, \
{-0.987711673632875, -0.15628707486335794`}}], 
     PolygonBox[{{-0.951100193039496, -0.3088825388399828}, \
{-0.951100193039496, -0.3088825388399828}, {-0.8910671320080115, \
-0.4538715305623575}, {-0.8910671320080115, -0.4538715305623575}, \
{-0.951100193039496, -0.3088825388399828}}], 
     PolygonBox[{{-0.8910671320080115, -0.4538715305623575}, \
{-0.8910671320080115, -0.4538715305623575}, {-0.8090908512602306, \
-0.5876835835779278}, {-0.8090908512602306, -0.5876835835779278}, \
{-0.8910671320080115, -0.4538715305623575}}], 
     PolygonBox[{{-0.8090908512602306, -0.5876835835779278}, \
{-0.8090908512602306, -0.5876835835779278}, {-0.7071900803344316, \
-0.7070234722246357}, {-0.7071900803344316, -0.7070234722246357}, \
{-0.8090908512602306, -0.5876835835779278}}], 
     PolygonBox[{{-0.7071900803344316, -0.7070234722246357}, \
{-0.7071900803344316, -0.7070234722246357}, {-0.5878742048036698, \
-0.8089523591203952}, {-0.5878742048036698, -0.8089523591203952}, \
{-0.7071900803344316, -0.7070234722246357}}], 
     PolygonBox[{{-0.5878742048036698, -0.8089523591203952}, \
{-0.5878742048036698, -0.8089523591203952}, {-0.45408147070841337`, \
-0.890960166314569}, {-0.45408147070841337`, -0.890960166314569}, \
{-0.5878742048036698, -0.8089523591203952}}], 
     PolygonBox[{{-0.45408147070841337`, -0.890960166314569}, \
{-0.45408147070841337`, -0.890960166314569}, {-0.3091066279673134, \
-0.9510273879056674}, {-0.3091066279673134, -0.9510273879056674}, \
{-0.45408147070841337`, -0.890960166314569}}], 
     PolygonBox[{{-0.3091066279673132, -0.9510273879056675}, \
{-0.3091066279673132, -0.9510273879056675}, {-0.15651979460327867`, \
-0.987674821941588}, {-0.15651979460327867`, -0.987674821941588}, \
{-0.3091066279673132, -0.9510273879056675}}], 
     PolygonBox[{{-0.15651979460327867`, -0.987674821941588}, \
{-0.15651979460327867`, -0.987674821941588}, {-0.00007853981625928847, \
-0.9999999969157486}, {-0.00007853981625928847, -0.9999999969157486}, \
{-0.15651979460327867`, -0.987674821941588}}], 
     PolygonBox[{{-0.00007853981625928847, -0.9999999969157486}, \
{-0.00007853981625928847, -0.9999999969157486}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {-0.00007853981625928847, \
-0.9999999969157486}}], 
     PolygonBox[{{0.15636464907469316`, -0.9876993958283806}, {
      0.15636464907469316`, -0.9876993958283806}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.30895723712171647`, -0.9510759305282178}, {
      0.15636464907469316`, -0.9876993958283806}}], 
     PolygonBox[{{0.3089572371217167, -0.9510759305282178}, {
      0.3089572371217167, -0.9510759305282178}, {
      0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.3089572371217167, -0.9510759305282178}}], 
     PolygonBox[{{0.453941513411326, -0.8910314822731209}, {
      0.453941513411326, -0.8910314822731209}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.453941513411326, -0.8910314822731209}}], 
     PolygonBox[{{0.5877471276121589, -0.8090446922041185}, {
      0.5877471276121589, -0.8090446922041185}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.5877471276121589, -0.8090446922041185}}], 
     PolygonBox[{{0.7070790126229672, -0.7071345486596803}, {
      0.7070790126229672, -0.7071345486596803}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.7070790126229672, -0.7071345486596803}}], 
     PolygonBox[{{0.8089985281574115, -0.5878106680208703}, {
      0.8089985281574115, -0.5878106680208703}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.8089985281574115, -0.5878106680208703}}], 
     PolygonBox[{{0.8909958270419, -0.45401149346015546`}, {
      0.8909958270419, -0.45401149346015546`}, {
      0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.8909958270419, -0.45401149346015546`}}], 
     PolygonBox[{{0.951051662150225, -0.3090319334976474}, {
      0.951051662150225, -0.3090319334976474}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.9876871119312596, -0.15644222232149346`}, {
      0.951051662150225, -0.3090319334976474}}], 
     PolygonBox[{{0.9876871119312596, -0.1564422223214935}, {
      0.9876871119312596, -0.1564422223214935}, {
      1., -4.163336342344337*^-16}, {1., -4.163336342344337*^-16}, {
      0.9876871119312596, -0.1564422223214935}}], 
     PolygonBox[{{1., -4.440892098500626*^-16}, {
      1., -4.440892098500626*^-16}, {0.9876871119312597, 
      0.15644222232149263`}, {0.9876871119312597, 0.15644222232149263`}, {
      1., -4.440892098500626*^-16}}], 
     PolygonBox[{{0.9876871119312597, 0.1564422223214926}, {
      0.9876871119312597, 0.1564422223214926}, {0.9510516621502252, 
      0.30903193349764657`}, {0.9510516621502252, 0.30903193349764657`}, {
      0.9876871119312597, 0.1564422223214926}}], 
     PolygonBox[{{0.9510516621502252, 0.30903193349764657`}, {
      0.9510516621502252, 0.30903193349764657`}, {0.8909958270419003, 
      0.4540114934601547}, {0.8909958270419003, 0.4540114934601547}, {
      0.9510516621502252, 0.30903193349764657`}}], 
     PolygonBox[{{0.8909958270419003, 0.4540114934601547}, {
      0.8909958270419003, 0.4540114934601547}, {0.808998528157412, 
      0.5878106680208697}, {0.808998528157412, 0.5878106680208697}, {
      0.8909958270419003, 0.4540114934601547}}], 
     PolygonBox[{{0.8089985281574118, 0.58781066802087}, {0.8089985281574118, 
      0.58781066802087}, {0.7070790126229676, 0.70713454865968}, {
      0.7070790126229676, 0.70713454865968}, {0.8089985281574118, 
      0.58781066802087}}], 
     PolygonBox[{{0.7070790126229676, 0.70713454865968}, {0.7070790126229676, 
      0.70713454865968}, {0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.7070790126229676, 
      0.70713454865968}}], 
     PolygonBox[{{0.5877471276121592, 0.8090446922041181}, {
      0.5877471276121592, 0.8090446922041181}, {0.45394151341132644`, 
      0.8910314822731207}, {0.45394151341132644`, 0.8910314822731207}, {
      0.5877471276121592, 0.8090446922041181}}], 
     PolygonBox[{{0.45394151341132644`, 0.8910314822731207}, {
      0.45394151341132644`, 0.8910314822731207}, {0.3089572371217171, 
      0.9510759305282176}, {0.3089572371217171, 0.9510759305282176}, {
      0.45394151341132644`, 0.8910314822731207}}], 
     PolygonBox[{{0.3089572371217171, 0.9510759305282176}, {
      0.3089572371217171, 0.9510759305282176}, {0.15636464907469383`, 
      0.9876993958283805}, {0.15636464907469383`, 0.9876993958283805}, {
      0.3089572371217171, 0.9510759305282176}}], 
     PolygonBox[{{0.15636464907469383`, 0.9876993958283805}, {
      0.15636464907469383`, 0.9876993958283805}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 0.9999999969157486}, {
      0.15636464907469383`, 0.9876993958283805}}], 
     PolygonBox[{{-0.00007853981625862234, 
      0.9999999969157486}, {-0.00007853981625862234, 
      0.9999999969157486}, {-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.00007853981625862234, 0.9999999969157486}}], 
     PolygonBox[{{-0.156519794603278, 
      0.9876748219415881}, {-0.156519794603278, 
      0.9876748219415881}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.156519794603278, 0.9876748219415881}}], 
     PolygonBox[{{-0.3091066279673126, 
      0.9510273879056678}, {-0.3091066279673126, 
      0.9510273879056678}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.3091066279673126, 0.9510273879056678}}], 
     PolygonBox[{{-0.45408147070841254`, 
      0.8909601663145693}, {-0.45408147070841254`, 
      0.8909601663145693}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.45408147070841254`, 0.8909601663145693}}], 
     PolygonBox[{{-0.5878742048036691, 
      0.8089523591203958}, {-0.5878742048036691, 
      0.8089523591203958}, {-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.5878742048036691, 0.8089523591203958}}], 
     PolygonBox[{{-0.707190080334431, 
      0.7070234722246362}, {-0.707190080334431, 
      0.7070234722246362}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.707190080334431, 0.7070234722246362}}], 
     PolygonBox[{{-0.8090908512602302, 
      0.5876835835779286}, {-0.8090908512602302, 
      0.5876835835779286}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.8090908512602302, 0.5876835835779286}}], 
     PolygonBox[{{-0.8910671320080111, 
      0.4538715305623583}, {-0.8910671320080111, 
      0.4538715305623583}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.8910671320080111, 0.4538715305623583}}], 
     PolygonBox[{{-0.9511001930394957, 
      0.3088825388399836}, {-0.9511001930394957, 
      0.3088825388399836}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9511001930394957, 0.3088825388399836}}], 
     PolygonBox[{{-0.9877116736328749, 
      0.15628707486335883`}, {-0.9877116736328749, 
      0.15628707486335883`}, {-0.9999999876629945, -0.0001570796320327716}, \
{-0.9999999876629945, -0.0001570796320327716}, {-0.9877116736328749, 
      0.15628707486335883`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJzt1N1L02EUB/DZKsyVlUiB4EXRlakULddacaR1U7novV1UmJSRmgs0KrsY
ONhVZtQQykx7gd5kOColjb6Gv5HFcqPfRRKMcOVgMTbtDUal/drzgHT+Ai82
GA/n9/C8nXP4rKhy7Dk+R6fT3dX+/8b1NZWp6ekkCl+HhvraViETZ+LZFOeV
znXtb9di74MsU5ZCVw7ndJ90JFAYubd1QFFpS1PI1OmKw96wrMSyMEzDKaMz
73MM+q4Lb20jEbozWbXcdiuKVt+BnmRnlC5Wn78cDkbgKBvJnYjEyH/0ev+j
xWGcdhnGXzTHyVzsLjoxrCL1M/9PqD5B1qfOde+zFTzbUbMxuz1JBv+Y0teW
j5YC+5R2T/Ic0eOlXqGdntohizb/w7T36ne/St+MxjdljgRZnNeeVC4Kk87c
3LjPFae6NaeWqNq9rDcGfb5PMar9cqjoWFeUznkNt0e1MXDw5tgu7bvxbN1u
ezBCwUvl3gXaug+jBWZ3bpjuD5jG9dq+as/XjyWvVKroaNGt1M5VA9ubKuYr
pEv/JuQ4uMkm5x+LeTyU6xWxHu/k/gGxP4Ly/LXifNTL+50R94ND3r9c3B9W
+b6pDen34bd8/6R4P7plfmwiPzDM+y9/WC3z2y/yi1KZ/18i/+iV9WkQ9YFb
1q9R1A8dsr4eUV8osv45ov4g2R/Voj/QKvunWPQPlsr+2iz6a6b/tqX7j1g/
ZuJMPKti5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOYj2A+gvkI5iOY
j2A+gvn4nPlIzEdiPhLzkZiPxHwk5iMxH4n5SMxHYj4S85GYj8R8JOYjMR+J
+UjMR2I+zvSf8BF/AfXe99M=
       "]]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx11Hs01HkfB/BB2umsnSTaWhGy8ZTsltXK9vjSs91WVOyTtCi5VJTYJJFS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      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwVkns01Akfxgdpp7N2kuitFSHbeEt2y2plW1/a7baiYt+kFyWXihKbJFJT
aZLLiXVJ7tuhUSqXWSRt30Fa45rLZMxMzI25z48SJZfVc85znj8/5zznY3ns
jGewLolEClno5/Vd4fS0cIQPnR2fo8Y51yi3AmcC5F1TXpLSdkxUQmdMuxzm
+E/zGE5SIAVaJkwQt5C0/fIMaZ6AlfUGSaKTCry/PY/x3e8SYNseMEjWI9B2
Ke3gpsRutB6qMPZYwcM5YeZQuqMGX5KfT8w8egM+O48+5/uosXh/Wq0skoCJ
tL0t1c/+QW893ROSdXJQbPw4aTwnhbRjzwOnxxko9GyAJVMEuEtGNkzqKPEH
d6vF4hIxdIeoHiNLizuXbrnjWdWD0ZnOQZdcuKg3GmlmWKBBI+5H86nwYUhy
Znvyh1XoTJXc8CsgwHit6FNOZzNWs88e/PWiDL5JHKfsfjYCEUf+yCCNMzGn
dW2TqWzhB059X1qGEiOaUga0vSJoKTvCcYvWojJOWWyd24eZJVRGSdBrDA6b
v2o3rcFGVWgNJVMIy3dlqhT+Kkya5KnfsQhoJXOvWTIR9S6sMea2j4L3MI2+
7NwoxEwzmQbSBnTp+jpuWzcBr+AgpJqrME1nWVDyjBB0q+aWbLfW4mHhbrLJ
JQ4mhD70/eFaPwZfnRzi7NNiDrlwjnZKBCvbu0uoA0oUL5DuCgjYv/8LR9vm
OlyUEJT+xGQUXB3TfX62kcGYeXTIcnkjKpPP+0ZWEBCXeKa39a4Kuyg8isZS
COW/VTytbdOgWh62t9x3AMVGKccf5/diLGlCMFagxcHm+oR8FzH4rPjKvXa3
Eo3ZRlNHxwgoZkb+Nye3Am3i6TarDo9AG/WWvJIjgxdKL+WDwRZ8vfHLA003
CLDYCkVWFmqkuMWkZ9KHwH4t1551UoPGyiKIcBjEEMJm7GrVK5S7tC45JdVi
/uaZc7aGEnC3ee9bz1RgCHm8Y8MMAaxQ8HjrXoRG4oA/bO5IwTWJrvdtvBwe
zp6+2NPCxtENZU5bDxFAtasLj8tW43qPvfo1jQJoE/fkRutokBVpSNV+wcfM
8PoU/4ROjFm2j+uwlsBG+2CrWZ4EyKfOav+3UoHP8v7MnV/wnHTofqzK6heI
vs3mreiTgKRCMpFhrgDHpEJKanknBng8JEQWBHy4uau1Rn/Buyv34OF7HvTu
kMrepauRdHUVt7JPgIuCF9P9Ctlom91V6nyYwOz4LLKgWAohiTHM6mg5Jl9c
d4r/aYH3xiFqZlcxELO3fjMhS4Dh8Tq5rl4B683eZr198QrbvqI4tom0cDTa
4WPNaQ06xtK61VaDsPj/XcNepmrsMHPg7MgZwo7+656fqlpQYSD4O+YmgYMe
x8S3A0bgRJa3eqpLhv5NV/awCALGbpYwKswqofa2c+pBRzGUlXqtO+uhBMN8
i7zxil7sIGvZOnla0Epopse6NBg0200o9wxA2gGBwV8FKnQlgUPheiFaTG9Z
upnViG0XWvy4lQS+vPt1FclsFFimLL99ljIMl57dUsVf8NMqvdpv+RPw23fZ
hRIkgg+eNU//FChBGmXkuSe7H8PCHu3I3auFxFTv1XepWuT5ZIWuDuOA3C2l
zn6VCsvthFIjfRE++VE/cDqjAdMCLtd5vSIwkhvLlvWOQra/907p6VH8O6lh
ExMJ6EjkR9N1WBBxxcktMlkIX55/K1wTpALd1LJC2vnXmOGStIkxqYGs0uVN
Ry5oce4kPe4DvQ+mTV4MvUtV4jSHnPErX4Rp4VvTq4uZ2D5gMiGWEajtdRte
c00Gh26885L8NYJN5gP2nXkEXFxtWBPwvhlcdHnbwvyGgTMQwW+XqiClPKt8
jRcXVS+bJn66o4GZRy+q6M1a/JDgVz1V0AOCijvf/mdGgY/3R8mWPhKjYcrl
acoBBlrvKHagTRFY9PiBYfxGOVAC4nJiJ6XYGLp7IzmCANr1a7m/SP+BqJrf
A63z38C9/rCi6/5qKGt3IFfa8NBp1qX33PcauGLqGrVoMYEnaIz71IBumK+t
nGkMVGCHu3epXawESfrf3L4floqhJ+tyqPMLvmybHOvvkYP6+OlLg5ulGFR7
eNGZbQRYJzwI/b6zHe75n1HF9/Ghx5AQ2PWoISrP4OWzKT66N3SLj7eq4V8H
LZWp
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301544375805*^9, 3.614709312118828*^9, 
  3.6147291682797003`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"},
 CellLabel->"During evaluation of In[251]:="]
}, Open  ]],

Cell[TextData[{
 "The facets given by the ",
 StyleBox["TriangleNet", "Input",
  FontSlant->"Plain"],
 " of a second surface function lie outside the tube-shaped surface. This \
produces in a more robust ray-trace."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3.7 ",
 StyleBox["SurfaceApproximation -> PlanarShape", "Input"]
}], "Subsection",
 CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}],

Cell[TextData[{
 "In addition to the ",
 StyleBox["TriangleNet", "Input"],
 " settings of ",
 StyleBox["SurfaceApproximation", "Input"],
 ", you can use one of the built-in surface intercept solutions to construct \
the initial starting point for an interative procedure. If the custom surface \
is semi-flat then ",
 StyleBox["SurfaceApproximation -> PlanarShape", "Input"],
 " can work very well. In this case, the ray intercept solution of a planar \
surface is used as an estimate for the curved surface solution. Here is one \
such example."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],

Cell[CellGroupData[{

Cell[TextData[{
 "sinusoidmirror = CustomMirror[Function[{Sin[Sqrt[#1^2+#2^2]],#1,#2}], \
{30,30}, \n\t",
 StyleBox["SurfaceApproximation -> PlanarShape", "Input"],
 "];",
 "\n\nTurboPlot[{Move[GridOfRays[{25,25},NumberOfRays->8, MonteCarlo -> \
Stratified], 30, 180], sinusoidmirror, Boundary[40]}, PlotPoints->100];"
}], "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"In[256]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \
\[NoBreak]\\!\\(Optica`Optica`Private`values \[LeftDoubleBracket] 3 \
\[RightDoubleBracket]\\)\[NoBreak] is longer than depth of object. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/partd\\\", \
ButtonNote -> \\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301546087247*^9, 3.614709313542626*^9, 
  3.6147291690366507`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"During evaluation of In[256]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \
\[NoBreak]\\!\\(Optica`Optica`Private`values \[LeftDoubleBracket] 3 \
\[RightDoubleBracket]\\)\[NoBreak] is longer than depth of object. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/partd\\\", \
ButtonNote -> \\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301546087247*^9, 3.614709313542626*^9, 
  3.614729169081826*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"During evaluation of In[256]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partd"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part specification \
\[NoBreak]\\!\\(Optica`Optica`Private`values \[LeftDoubleBracket] 2 \
\[RightDoubleBracket]\\)\[NoBreak] is longer than depth of object. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/partd\\\", \
ButtonNote -> \\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301546087247*^9, 3.614709313542626*^9, 
  3.614729169144835*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"During evaluation of In[256]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Part :: \
partd\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301546087247*^9, 3.614709313542626*^9, 
  3.614729169147241*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"During evaluation of In[256]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyl3Xm831V953FEFrWRTcJS2SRljSxayEREEgZGHaYWEIYCClIWzTDYssha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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJyF1U8ow2EYB/Bfo+WApGilFpMZFnORlKymyNEuSqFFOZC0pJbDLnMgyZVS
SNlFO8ltGrWDGGUpSflXE9u4MOVA9vgenvrmrd9hn95+e37v+/yp8U31j5kM
w/D+PAU/Typ2Ou1IPHQZv6v5wJB142+cSB1n8x50wiMDNuvq/pPsb4K3+mLL
48Nx2d8A3x67/Fhtuo3mfzng63FPoDeXyXvQDq/wvO7P2l9kfx2823u4Yfgv
ZH8tfKWluM0+ciXx2ODZ+iPPZygt8VTDXbtf85bCjOy3ws1D4Z3QybV4Ffxg
M7Lwdnsu8VjgW0tJ1+jcs3gFPOiOd6Z7suLl8BrzzHtH3514KXwwuTfZXhaT
/y2Ch+/PYp+PKXETfHHSuRZ4lnsxctE/L1mOVn4lHsVTcLbU/i7yfriKx03i
h6vvhavzgavzhKvzh6v7gqv7hat8gKv8gat8g6v8hKt8hqv8h6t6gav6gqt6
hKv6/dfZe9j/sjjZd7FzYOfGzpndC7tHdu8sT1hesTxkecvynNUFqyNWd6xO
2WJ9gPUN1mdYX2J9jPU91idZX2V9mPVt1ufZXGBzhM0dNqfYXGNzkM1NNmfZ
XGb+DXx6rBY=
       "], CompressedData["
1:eJx1VT1IQlEUflhIQ0UEhhBIGpmllC0RQXjAoGjMJQgqJKEhiZAIpMHFhiKk
1SCoCHIJp3Dz8AocoixIgojASnhhai2l4JBbvAPfhbd8HN4995zvx+pfmw0Y
FEXxNb6mxqept+uO7LtH0Z0hfgkNrmrXFT0ecXFyzmaJpz5EvZNH/GpsZTEj
6gf4NPD4G3fm0/p6Bx9mvOHpalmPR+xs8n6lNu2for6PJ32XR0roQdT38v5w
66h96Un0Y+NK/5W3Fi2JfnrYfV7fNjeXRb2FjQuJs+jNs8C7mY+TO9/5e9GP
mU/2cu7lraLATRyhzERpqiLwTrYaN37GZ14F3s7zuYvgWIcq7m3hxNudWito
AjfwbtB1EC6KvSjVdFss3VXPFgSuifv+D6j3gP97QD8E+ifwXgLzITBPAvMn
sC8C+yXABwL8IcA3AvwkwGcC/CegFwL6IqBHAvqFOPoPuhf1id6F5oDmhuaM
9oL2iPaOeIJ4hXiIeIt4jnSBdIR0h3SqgIN8APkG8hnkS8jHkO8hn0S+inwY
+TbyeZQLKEdQ7qCcQrmGchDlJspZlMsI/wNmbKwW
       "], CompressedData["
1:eJyFlktoU2EQha8RtELJohCIBENMSExJ6cIX3aULURSE4kZaiGhB6EZrqaUg
KFVUBBEEFxVRwQfiRoS6sXSRQQt2o8WN2IilFh+hRQMqNJuCwcwM3FMODYTA
x+Hmv/PPnDnb+wePnIwEQfC48d3Y+HbFRnMHR74Xg/+fTtHf7ssXV89NfPzV
5GMdzrfduL+jFKupvuD8/dXnJ1Ze/1B9u/PPD/s2Va59UH3eeennqeHJocly
U59zfmZ6f6oytNDkQdb5+ZlD0dKuJdVnnJ/+cmx8ZV9N9Wnn/XeevJweVz6W
cj66M/P70t9l1Sedb7j7rHXq9jflCee9rQNLmyc+KY8775mfmxoZfqM85vzw
2+MvtvQ81fdtc75SWR78s2dWedT5hZlbewduzilvcX509+qj+bMLyiPO+x5c
ub61tqi8Xja+uth14F7vV+VV59VX74bys8bts0Zv94/Pdw7n6Sbndw7v6xzq
4xzq6Rzq7xzuyzncr3PoB+fQP86h35xDfzqHfnYO/e8c5sU5zJdzmEfnML/r
8tBzjDeeF/5f0xfC53R9O7yX6fPhOrg+B3UzfTZcZ9dn4F5Mnw7fo+tTcO+m
T0KfGE9AXxmPQx8aj0HfGm+DPjcehbkw3gJzZDwCc2e8XgzPqfFqMTzXxoOA
6Mvk+WVyHiHnF/K+QuojpJ5C6i/kvoTcr5B+ENI/QvpNSH8K6Wch/S9kXoTM
l5B5FDK/lBN/EOInQvxHiF8J8TchfijEP4X4rRB/FuLnQvxfyL4Qsl+E7CMh
+0vIvhOyH4XsUyH7V8i+Rr31Iz7fOckPeH7nJJ9gfZyT/IP1d07yFd6vc5Lf
sH+ck3yI/emc5E/sf+ck3+J8OSf5Ged3XQ7+IPY88BOx/wf/ETsv+JXY+4G/
idUD/FCsfuCfqs+g36o+jf6s+hT6ueqT6P/KE7gvlMdxvyiP4T5S3ob7S3kU
953yFpgj4xGYO+P1Muxf5dUy7Gvla/a16Yvk+UVyHswbdn7MJ/a+mGesPph/
lMcwLymPY75SnsA8pjyJ+a3JG35P+gfzoeozmCdVn8X8qfoc5lXV5zHfqr4d
87DqC5ifVd+BeVv1nd3/AMdw0Xw=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxIcDFAUKbwOgDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTALuFNSs=
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFlgs01NkfwG8hj5Bixng/hyG9hB6se1OivDa1lR6bCr3sVjaLdtNUyoRS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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxllXdQVFcbxlcBKQKisMvSt7NUFQELxHNEKVIjGhBLBARsJCqBACbiIigr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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301547494471*^9, 3.614709314912673*^9, 
  3.614729170588808*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"},
 CellLabel->"During evaluation of In[256]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["SurfaceApproximation -> PlanarShape", "Input"],
 " produces a very robust ray-trace for semi-flat surface shapes."
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3.8 ",
 StyleBox["SurfaceApproximation -> {SphericalShape -> ", "Input"],
 StyleBox["radius", "Input",
  FontSlant->"Italic"],
 StyleBox["}", "Input"]
}], "Subsection",
 CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[TextData[{
 "The built-in spherical shape can also be used as an ray-surface intercept \
estimate. This is accomplished with ",
 StyleBox["SurfaceApproximation -> {SphericalShape -> ", "Input"],
 StyleBox["radius",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 ". This is particularly useful to model the effects of imperfect \
manufacturing on spherical lenses. In what follows, we will model the effect \
from a sinusoidal perturbation of a spherical lens surface. Before examining \
a perturbed spherical lens, however, we will first review the behavior of a \
perfect spherical lens."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[CellGroupData[{

Cell["\<\
sphericalLens = SphericalLens[Infinity, -50, {50,50}, 20, \
GraphicDesign->Solid];

sphericaltrace = TurboPlot[{
\tMove[GridOfRays[{45,45},NumberOfRays->16, MonteCarlo -> Stratified], 150, \
180], 
\tMove[sphericalLens,100], 
\tScreen[50]}, PlotPoints->50];

FindFocus[sphericaltrace];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"In[259]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyl3W2sZdVdx/E7zJAUG5s0kNYSxacJKTVFkSmEqM2VxocXbRMlpR3mdqrU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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     Line3DBox[{{{100., -25., -25.}, {100., 25., -25.}, {100., 25., 25.}, {
       100., -25., 25.}, {100., -25., -25.}}, CompressedData["
1:eJyFlL1KA3EQxI+YIvZpbA6ENGmCwXCQ7iwEC0mhYqFBJBCxM41gYSBv4AvY
KIoWFoqFjR+rlYUIPoAQxMJWG0s99D8LmTDk4Dj4seztzu7OZGtroZ2Lomgp
e8eyt3k53r9ZXkmjv6du4ZseJpvHj3eB9xLnRwdn298TqyG+5vxp56PT3wi8
V3VemH6rX5wgvuK88/N8P/8KXnb+ft2dWis0Ay853zv/nGmXwWPnL+ut3dsU
vOi8cTW7f9oAzzv/6j7k5hbB8QzFQw/O75zqcU71O6d+nZM+zklP56S/c5qX
c5rvSD6QBzzLN/hfxNcG6/T4KvWF+ArpAF4m3cBLpDN4THMBL9IcwfM0d/Ao
EvEm8puox0T9Jvo1oY8JPU3ob2JeJuYrudgfE/tmYj9N7LOJ/TdxLybuy8Q9
mrhfE/fO8SbyOxf+w/U7F/7G+jgX/sn6Oxf+zPMdyWl/DPlo3wz/p/001Ev7
bOiP9t+gB91L4CW+r8BjvsfAizRH8DzNHXzo3hHPfoL87D+oh/0K9bO/oV/2
Q+jD/vnPs3sS+rM/h/iE/TzE19NffhW7Dg==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJyV07EJhEAQheFBLcFYEDaRA0EQwcwaLEEwvhYszdK8y0T9Agc2+XnM7s68
Vy/fec0i4vM7eVxr3G/oX9vwzKOHvoO+BW/AE3gFXoIX4KpiQn/wCjyBN+Dt
M9866HvoB+jHd5x9dK/eiX9xDpqb5qy9aI8q+US+kg/lW/kcuWCOlDvlFLk+
8QNa6SDn
       "], CompressedData["
1:eJyV07EJgDAQheFDHcFaEGxECAgi2DmDIwjWruBojmYGyFd4kObncUnu3uvP
+7iqiJjyqUO1vUX8rGUeC/Qz9Al8BB/AO/AWvAFXNTv6g3fgA/gInsr8maFf
oF+h3/5x9tG9eif+xTlobpqz9qI9quQT+Uo+lG/lc+SCOVLulFPkOvMPYnIg
5w==
       "], CompressedData["
1:eJxdlF1Ik1EYx8e6HtEHJRVGU7oQgsnW3BuDzkUF1UUmfSzYNJblEErXBxFB
t2XRB3lTdNGVgZVL0TUdQg9lKwoTxVGwoG7qJukq8GIXSzj//5E9L4yxH+c9
e87/9zxnR7qv46zf5/MdXfms8enHM5oMVAPJ/Usx0/H3WmM0XdtLnul9PxgZ
i5ke//J89uBa995UYPhny5GYKXQnB8KJzY73pAO1t6U2c+f7nlL5d6PjXTd+
eIsNbeb45dj6U8Emx/Ofvm7KHoia/tnZdRvHdzq+ZSk09Kt9t1lsqB2ubm9x
vKlwL5v3IiacWn797Mwuxz+k24OP/WHzvDiauxoPOT55boNcH2k1BXyTcx3f
I+e+/B/yMupgXeRZ1D2Bc5CfwDl5bvK7yIU5uTyRI3Ml70Xu9ECegCd6I/88
N/fqyWAlbn+tej5k17/R67vt/qL3z9t6pKjquW3rl4yqH15Fn7fP5iN5lQ+8
ylaVZ6vNX3T+w9aXfFS+4FUmlV94lReqH4J2X4mo/oFXKat+g1e5qPoT55ST
qp/hVe6r/odXKep5sbnLeTVf8CSn1TzaxxPr+U9cr98Hz+TwKl3wTA6vMg7P
bj3qvwXP+rzH4JkcXoWeyeFVFuCZvBn50zM5vAo9u9zgl57JR7BuBu+Rw6vQ
M/k86tiGusjhVeiZPIVzpnBu8gfIhZ7JR+vnxfF+5E7P5I/q59Hxb5XKu4nc
v2n7y1vdp37eHU/W3w+OD6HPdD030ZcZVX8CfdypznsBfZ9X+XzBnOg8Q5ir
ZpX/S8xhSfnivTyl/MKryal+gFcTVf3De0T3G+/lS6o/4dV0qn7mvfxQ9T/v
wTE1L/Bqrqj54j37VM2jfTxj57c6/R/a3Uqg
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyF3Hk4VP/j93H7vu/7vq8zxlapeUeLpF2yzEiRVEKRtCsqtKkolaRCkqRF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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxN2Xk4lN8bOH77vox937exzxhrqTmW5C0iZJ2RLSlCWVLJErKXilIJFUKy
VMraHLIWspSlZAvZEllD+c33e/0+z/Pt6q/XdV/3uc99zjznnJLxDLQ9SUdD
/UP/f//SXF8VOXvFxRW85hZ96pyjAyKUy1lnvutAf8ONkMwMV6AT8vTIKS0t
sFh3uz3XSg+aeZ4puUlHAiJe0QZvf+BASa1j4EU5HXjlQ03IEBcJFJYVvc/9
rgbo3M5azCTqwpyNXxunBEnA9E/HvnJaJaB7QSxBaEMPOhxR7w0LJgHm+qB7
PSqiIIr84ZGIth6Us4+m86gggYX6BptTG3xgaIpFEtbowIOvj2cdyCGBXR+D
BYbkRaLHL8OxtM+6cIhDsUcolgQ4Ar1DGGY3KU9azY2ysvXg4lcJlbRQEngp
Wnzx6DwGklWDR5JK9eDnXhspgWgSODcZtN27Xwpeqx8Be/66sMxc5nWxEAlw
WxiOdlOU4IuGb+SMt3rwb7bOGy8cCeSn+x/J/qIG2W6r64kk6UBsTkCyqgIJ
hGulhD6U14CttBaZa0FUb3pbr/baFfg90z3BcZwA3Yc+t+We1IG8NzwCCn66
gBvLInmScXqw5cmIBdesLhwdKxlovOUKVh296cVV9ICKRy1IDNSCXLs1ZZL3
XUHgeJKB+oo2MDPjKV57qQ0fKa7MLhpQ6+897cbgrAFsIypl26u0YVY5MfZZ
AgkEqLjL14qogWmHTx0+o1rw+LahZP8gCdie2FhkcFAAFVW+E5oiWrDb0fiV
8y8SSA883dQkIQKSVD1+juAJMMKMP/nSOgmoGtcVvfnIDlT+pOThSgmw1Nog
9hc9GVSEghHu0nfEgbOxN8yDCdBScP2tPQcZ2Phaa03XVlOkfdxOC8kR4Pjd
Zdm0LRLwvMt8x1tECGL8Dbbt6AiQjuZ3ad8iCWzcWBKq5ZKCMC3x0YUGLdh6
d+vJ2SoSuDX/kS00ThYeaSeVHxLVhrPHNTTulJLAxCaFN/OrMsxU63b/ZaUF
RenIF3qNSSDo2fcrH300IOPVI0zHfLShm30HxpCPBIqnMqotRQnQuEL8oFKW
FsT5PnhnHuAKfs3L9JoCPSitesFwPoEAhxvkVPVkSaBs4VdPxT4doLh+qmbp
rwYsnbi/TX+BBNRrTCItwrWAxp5qjmipBuTnZz/HdIoEfGOHvtZAPDhNi61v
7cPBuCiSMNNXEogNEmyYeoQFjTdvUZoncfDknc825v9I4HGBwNW5F0rgtu7t
ArcTmvDFRYmeg0ZkcCpcG6NBFgYeR14kT0BNuN4UHCAvTgb6X0XE00J4QTKn
UaXebzzkWzR1vmBGBtVDpuSrHgPEk+RdAdVWHDRXMJTi1CIDJxuvmRTTb5T1
8fM25vl4GFe24gPkySDD1XvUvFMAun+t4P5yAg+57gxxkTFkgD/GupRcJQ1f
4hx4ZTjw8GCh+ttQGTJYcFzqvH9SFsa4BxeOlWvCwkYLt9dvSCAVO3djUUUd
Sus+rlJOw0FLozIXzWoSOPQ+tEPTQRPaehxmaaHXhKkjQT9xTCRQLtQlh3PQ
hq+1L/3xrMVD6bNEk42frsBbwsyEbVcHzknebJbIxcERfF9DuiYJRAtgxVx7
dMAXLQ+rUwJqsGKEQ+Q49Xd9tblUv2SRAIJ+B/5zvqIMNWKvyfO/IIEXOTKf
9Ah40Co0Nr+JU4OhcpTPWOr+JHoGupkrqoICvQt99Cuq1P6w4uXEyGDWMYw5
w0YJfD3+579Ts2pwrb1Z+YwdGfBKmzwYFhYH09ECL63x6nDg6tEZ8xRqf2z3
5g9w8IOwNUsFhR4sXL//QvZ2LBnkE6M+GaavEr2lH3MExajCEocvqu4xZDB0
vubTkwsbFL1EltreKlXIZJA2ff4qGVx/sKZ3MxADeSguDM+uqEAarpDiiWNk
8O/frlaGrDR8L8nfxm6kBnOc1F993k8Ge7wBAq+IshDE6F8OJKrD2I6ZP+fZ
qa5sddrinTpcXnhxMV8VC//eP1cpXEsCdN1eJnHU9eu53h4h0KQKVQc8Xqtf
ovaH0M7yjV8bqn7qv166rQzzU13+LlP3uUzUg/NFuTpQxfFYCU+vOvzQNXFy
3J0EXPIiVoeMdYFN5BfTQ7wK0P0W+U97Bwl8qb6tKONCAIcG9m825srCmTts
Do1rJND9oT68g4gHX5LSpKSN5eGHnDfxm8fJACbdfbHPGAsmqu7NH5NUgOdL
OIzeBZLBZgvGP+GoHHhCG3/yaKoizJ6l43peQAac5XIPmdbEQc/GwZnCPFk4
dS3DPucVGcwliR3UmxQEw5NBOcZHZCGTzxKbVBMZqNjvSdV1rRPTQ5n89Dzk
YFw1U8qP92SQJfN47WDwMGVuo0E+R0oW0nJX/decSwZLv4NUol0EYePMgSWZ
XAX4sZbxnUEaGdjaKXdSTCTgW9n5zBV5RVhVORIu50UG2pdpcb9+KsC7NxZN
MN0K8M9w1Ok4PTJwm+fsuqmkDgPzuY+V8srBWl+9rvci1H21iL2Cf6wBbWsq
LI9qKMA35cF9MQ9J4C80OXGrnwAzRa/iU3sUYfFSMNOxdBKw3z8upHteBwbR
C3nucstCtqvFkvnPSYBl5OW8crwOmMZv372cKAxnDMwa3fpIYG5oALTbEEAe
x9Dl44EysGRxioNPgQzEVp119e9pAlHdVPWdLRn4vX27mNGYDCzbnksM/1AH
mLu9GEkuaZi59c34QCIZYBn21Pu85QGe2M1CHpaBTVfv5De9IYN3YEZLREAG
5LgrHdr6Jgw1speSxbrJ4JGrEtabUxDM6LdPD/iKQd/rrPliI2RQO3ZAyER4
ixhkdLRh0EgCjuxmOH2eJgPJKzM/G8V+UliWi0wiTURgd6lMddo7MjAqGyWm
VmGgz6mNmw/Py0DDkvThztfU38u0g/tdFWk4Wps/fvKxGCw9XKwncZMMwsc1
lp3D5OCG15jmI08ZyLaebXmPuq9mH77VWdBWh38SS8znRcTgmbvEjZ8sZKDw
35L+OjseOjgyvzqyKgO1Q2I3L+2RQIw5x2ueU1qwRfzWz1UlMRjknq3tHEYC
H9Ra2ib2dOH1aD8z1/diUC2MPkTjMQn46axpxfvogjbDhTfB81xQ8puOItM2
CfS/aMu5GUoAY8REutYhThjWZqnQfoAMrrrNY9W+48Due5fFFmEWaLebbdLl
TAblxU+/iM6qg6jRdZOUEgF4Ll0/RjedDAblXwbxZymBsNC4F1PtgjC9dMDf
lLpvc2k11hvjxcELblZpmxZB6BT81Ov3BBmcEOB/7BjPB7Jqx3ojFflg0+ix
Jbot6veNTdNhsOMvMeVGRrQYDQtsKm0R014jA7O62o7DJluUXLxOUgYHBhZP
LlpcnCODEeE6syoyP8RrXahY1GKB5Y+ONlQPkUFn6gHRlBBx+ErZTM+ogxWy
6e/29tdQ10Wrn09IUxamCPfwiFnzQ80VRukVTzIwxDOvWjOrw7Cw5xSfQAF4
auebLjxIrceyEitBPQ+yt1Iw1Z480N3vSpnTCglIb56V/eRDgFuY6A56LwGo
coDlIW8WCQjKMN5RidGF4qJ3OtWq+WDckR/CA/dJICRMv0CmSxcw6W2qH9Rm
hGLng2m/i/+fPpcvepO1wCd+UeeaaVrY+Uk0aUKFDMTPvaz/sIAHTsxjWLqH
C5SUgqOSLfFkUP81a+k6rSr4Lz5+6CE1vmjVuVKd+j15bJBznmZcHmS5dV0Q
6maCjh4H7SfHycC+Z1Gu310UCNtxYStf0EK3c+Pnmn+QAYbm0l6KtiCY0k4A
AwyMsCfwV0f5HhkIV9wjsW1NEzHSk2YVhxspd3rYJE9SvXOhvj9v5ielmujJ
aobrpQxy2w6OUdeFXstajl+EC972KG0VyNmlRGUJv4vpIYOI8RPtjRgZKJxV
Uc0Q/ZMyGfZeOayIWk9yx8ivWEV4c1fZonKUCeq8kRhmpZ5H3l09vIzPqOfH
6Gmaa45rlELTiUZv6rlfKsf/lZSLh2s5xOax798phvrkFn5WMvg4KGZ21IgA
bU7PlfPJf6G0nyuiM3tFAsk33W3lpXXhbDM//pXiBuWIZrrms/ck4M6eGV15
VAcE4HtoM5PoQTCHpiA39fflsS9/qvAwAaQ3cR8kXZknNjvJ8vG5kEGN4Fla
iVhNYOvjaOx3nQYschRfNcgig8bhSLkuTWVwx6Ld2vzjEnHrTOjYmRdkEDZd
xJXgoQDMy2LpQ17RAa5kDzZz6j6MsyxwkveXAIEm5psjdEzAELZfjqf2bSqF
p+zmFAaEP45MK37SQxTMFTt2cocMSKzvbkrnfSfSgvNG1ycYQOmbvBsn/pEB
LrOr2dhhhJJzrcMrKHqLuE+4n/BongwUMRdiErmE4NBlWaxXURcxNZH/JamP
DDgalpIE3KXh7/F31qGse8TmW4GP6Kuo56z39oMdMwXoyS9yB379QxQ+Eiji
e54MuvqFU8L/qkF2Ck+hwg49GO14o8GsSgYT/o9eyC/gobaP7JL8vjkig8uJ
Nh45MjBZN261AFqws6VPov/kV+Kf/GIVpnckan/cTdljdeDstTtKb+4zAfCB
i737GfUcz/J9scKlC/SPi+HkSBgQL/Gv/Acj9bvaH1qwIEMA4SZHcV/usoA0
fTWTAGp+Vp0ps67PeCA7cE2j9wkXYCjgOy19iwwKQz8afWZVBuH0I0tHXrOD
dIF7BwWp39u6gaUnltdlwRnWY5GdeAFA9+mB1+QYGZzfEWAkyIqA2q/O9S1f
WcHstzrzNOr3/IZSnWvziABwkYX2o6NsoNdFH7f+i3q+C6iuFcF/xOaiwurf
YbxgPYFXCa5T1+Wdpb7Ko2XKUa+ysurvXCDh2/afywvU8z0hcMv4CQbuvmnW
IeVygbzl5AbKFzJ478ocKkX9LmeyrVn8C2MHD+8d+uBD/f4wYMJWk4/IwWRh
oQRbOgwo/jfU0UK9P8x9s5cKrlSFvBVu664nBIBmJz5ijnpfkv6Kk6psw8GH
P8e+vffnBkvHPT2DqO+av0+uD1wrI0DaQ2JuwZy8wOE5Jiv/GgmsZgrDB5Z6
UGGe/lcktT95bE0/u6jvpoLli4O2bLqgU2I6sP+sNHhz+cELBQbqvlp4FDl4
RgvoMh+/R/opDCieS99/SJNBk2IKlLmNA2dUzlTp+UuBaO2KpHPU72Rx8NvR
e39VwDm3svHTYZIAc/JOjQT1/P01LdXuu08JNG/xurluiwE1Mbbt7Epqfr0N
l/3WMiCYrrOlTlEMDF0q9xuinrNHra+zTeqxg4urWfojB0UB8zGXCCXquRw+
k9jV4dRPXAtxydW+JQPGzfIZJUbJYN9U+Pgh1lnKKZN9JtFj4qBQliRxmBqP
Y2vvJDtyQ9HV5o/0AVJg5nutfHw+GViYzVdck5OGhKgb55lOywCHny17e/9n
/wzQrOYaKkCWf8ZOzbckwGRVmUdPHPUdoTR6Qk0fC7ub7Bl9NkSAPH+ByRkJ
Moh1kA1XYsXDvo2fb08ViIN/Yr+kX38igZR9l5b1ygnQO2veWiNZEnzpKJ4Y
vE0CTukxp9YSdCCuU+pXpJAMta9OdvdOkMCVvtBnt1/qgp6PC+Fzh+UAY6ZP
0VwyCWDs6RfO9miDzfcGHDJxCuC2lFrFmDC1Hhb5M3ctcYDfIZd0GSsLXh3p
Gy+gvnd+ut9PEGBSB/QOY/6LKwpApeX03iXquvjlWmu9E1EE7tp0++uqFYBJ
vYmFSzkZ/G7NWh9+IwLCRnbj5vfJAnH/SHM1an98PwS33r6EAepV59tfWSsC
h7bPqj3U71jErPYbgicNOE/+6pR4TgFkxeuEWFHPl+ZM4g8r+11Kq117S4y9
Ash1c3BTpn5PXuFHTMxL+CCrp/fFT5Jy4B9mQkPzJfX7sDPzhuAkDDOY+x+e
4ZYFosffhk1foN5vt+Zt97fIw6FM0+TjzPLgnP33Pms1MsiWHdMyuq0Km/V+
yMe0KYK+KKHNgF0SUOwJz2An4ODke7ZI7VhF0G5yqlO+mwQm792m1xfUghUT
h9sZcxVBFueFO6VxJJBNY+Yk+FoHjoWo8pjflAVTm65C7lYkcPqOqdfMiA6w
eX4ozWIGC/T5BtNybpDA0y47ldWvBHA6SyOV7IAFlpbU45l6jtx48vSc0Vs8
kNvqa868owLsMfRNr6nvApzHFx/nXHWwtc+O8HlKBegGrSnzKlPvPwZ6eRzM
CsAtn22Pz1gdhA3wPub3JwP+tXSenVlJsDS0VEPTqkx95zXyuPmQwUrA8S1L
H17wPlvPo1hLHZy/2qStRP0OuIvWDJ8dqScKmpRoPnurDtRy2TJz75PB87tD
Jh4zDJDppI0h1g8Lsu5PxXxPIgOar1UbJyAv1AnPrQzbrwzuYU+8VaLe87G/
u//DcspAh1iWENlOZbABguIqqeea+WK3Bf2aHHSgD8nTKMECpignJmFtMtiR
dMKst2Ih00DTzOA0Fgh+lO91bKXeJ03qPq59xsPFM4f4e+2wgOVxu7DRPRLg
fNn/p05GC05++yVjbK0Gimcmklw2XYFXCDb2UYEeXNf8Pb4ToAoqmgeyzne4
ApYKzOsGF13QlH2e5+41PMjyy3KzO0ICWUeDq6XyCIDZkV5pp0gT5BAvYl9a
kMAR+50LKo144NY94G78Ew+qjW7L1X4hgW0VQuY1JlWwzOe8aT2vCSQVhXcz
Bqjv6O5F8LNOEXx5UGZc9gYPvseJx5QdIYN1nLjM2S5hUP+g5tBwmQaQ5PtP
X0+HDI7HXBBQvcUHNF1KWB724sCc9fbqFT8yEFSc/dL9+TfRJ+tQQQmDBgg/
5Zb8nzUZlDE2HXXYm6Go/TIXqHTDgZBw2otY6v3N6ocTW81vPtggGN3uP4QH
7JIVhDxJ6ncjJGly20kU7qc5xoDRw4NjBYMHqqj7eTz5a6RImSJs+sc0tCSN
A7M9JK71IhI4JurzbWtCFV70Gv0dXoEH3fXn/mBekwA3tumX05ImjCxkS5rM
0gBFWkZWL4Sp90mPshnFFwQolsl8S/cdHiw3l5ioFLqC+OJLTYGX9ODhjiHz
/xypea4TPttR/Yje1/DJX7rA6I+TdSK7Fugglg8doiGBgxYH17VttcDpnZ2C
kT0CMK/TUSnwJYHF59s+5YIagDe3zGzBgAD2fLe5V06SQM0NKe6K/9SArqaz
XcJfAlhydi7wod57D3fPfMi/Jgemy0/i933VBhPn25Npu0iAwpSFFbkmDi4K
DyeLKmiDmRt597Q5yICHx/GSqQ8PKCnnV1fJ1wLddrvzJ7ip76C2Fe8m+VHi
G5G+F6oMBLD6pr1PjhqfHVKTefsZI8Rb6u6rXNUC8GKOxCz1/uZ9W22b1ogX
hrdaBtS+0QL3/+NjLJklgShtOZwGpzgUfKNRdAlHANJxX4ZdykmgaEM6/JGq
IsT/DVY4504Au75vfzKeJYEBlnZW0ow6/Nzw2em3PAGEZmzFxHGSwK2Wo5WM
vnjYThseleGuDVpSy0+Z33QFHq4e1fH/tOE7SSVe5gVtcO3W2+0TJa4gIG20
+luqLrzVJ6nG6aUFFO3U/rIauoKIA88mlA7qgdGAxvFObh3gkLZTqP7GFUwG
7ew+OKYFRGoPPfp9QBfMXl6PXepyBYG/Va6pd2gCbUrpy8d+esBvf9+sAJ4E
4uw+zvC8UAeeecFLrQY6YNfdIHD8FAncsb7nx6stB+iDwy6uXNAF18fiOBXc
ScB/34c2hQIJsDCsGM1xVQ/o6uz45EMSKOk/zmwXyguW6g73hh3WAVdp2zbM
q0ig/XJfdErrGLF25IXLAxld0PEIxpCp51rRGd+M/s0NivC/c+FxsnqgTG55
Ion6rtmKDWSkbWOBK1/2fWVq1AV0nrKXPp6mfrefZ9CPvpOAx8csfK7o6QGb
2JZpfTIJyLTmfGQQVoAnWMTL/5B1wcQPnFm8BPXe3ivdctBNGV4ISoqvUNID
/5IXXzIwkMDv/vfeOd9w0OzoACeztA6wvZW4F+ziCnYnChRe3yZA48qRXs56
PdCfumhbNu0Cqq5oOT19rQu/P/ekXgb0AM3//eMMJv/1EnPXCeCRub7RZx1t
+D/38UoLel2BA/ucU/tfntBB3D7tupdZvgZof2V80xJLQLzpj/izFgUVQFvx
eNz/JJqHPTKrNbJbHmyWC4glPkPz2NFZPjgeJAQK3mus17aj8Q/HncS6W3iA
3+G1pSeOaH6Gm8PPDoTMEYd6OT8VktH48XXp+8Ye65T03jtj3RJofvfjXiPL
R7hgR7EI9gIB9cHqG+f+LYtBJun3AsPcaJ7/HmwtVV1UgKwOfCn3wtH4ewVy
bZJMKrDGrimC7I/W48F4/dq8niosyIyt9yah3sIwJudfgoeV3A2jAWmoDxMM
Mqr+6sBYXQl8sx+af9LzGPsBQH1/7WyuF8/hEI99//y+iRYBiD2eiVPY1kL8
FuXxDz4nVdB3vfIGazHqlsBRM1VSGdBgdvb//obmEZwk1WAXZYEE/68wAU7U
jz5ueHLNQBAkjOJHFXZRH7W7HuaaxQJoRgRT2k7iEddc9L6SdKKRGHjqR4+3
Ouq2dXu8D/qqKFn6YoUy39E8lIJcZlp/fnhhKDnMsht1WbHoTaErYvBjG7ub
xh3Ubxkf9Xe6JA39MwJ7w76j+c+7Lms/ZlaCv419k0Ot0HjOmzlPON1UocV0
wyUxMtqHWb/Sk0rmeGjhNNl4ug+Nv/nDTwBD7XvO+5p/bX/R/IqPvSvn1Agg
jIulnvxPFfFm1t6kxiQcKLhB+2soDPVZZh/T7UFNIFjiEqisroH4wI65ztCA
ArBl7pjXXFFHXOcg6Vfnsjwo+lnalFON5vElR7+p9RYAKqX/Dr2fQP0jm9eh
GWMMIOsU5knmaSJemqnjlpDfT3QttrC9ew7NX/fjNsm2fpiSLW9MimBC40XM
mxVU8HzQLD1del8WWmffolVJwCUJ6HvxmzSOD/WVsx9LiwjScEgAN7b1A63n
/tgYhXlVGU7VHHpjFoyOWyN/83PluCq8JTu8eeIuGv9O4CdrkL8W5Cw9tRbC
jfZfevHHwe5NAvQ/5/cqD4+Ou8soN415TgB5c7EbH+2VEX8ZIlQa34sHdZJc
XjkfFBG/qpGQy5+rAcBsd7eOMBrfl9Dx9Oq2Ergcreeb/hyLOIlwvz4xRR68
NF27a3IRjT++d8Xi2CNhADvCFdXuoi5YlVW7L4IH/L6X3EPIV0C8nDU+V4Rv
hYhj/86QT4vmb5f9t7CQvUqp+xfslIlDvYVu+YZtJQfcimxKj5NSQlx7jeFw
v4U4LKTey863oPEOR2W71VikoViAefpQJVrPkvnLSiFTFfjZ3j6o0B6tZ2ws
wRBjrwE/TKy1X6tA84DwRqeqP3iYRBFcVTNCx1U4Q2dfl0CAh58+ey+wpIK4
XMNgo9k2AQQGxGiszMoibnWRZu61Jh6wYcN5CMnSiN8c5QUdVzXAZQ0HUuW8
DOKeb+iJz4wVgL1eeoHkVTTPoIj0k4sT0sBH9vCd3ddyiPv+N6PphxcByxwR
Tx110PzTl4Uzn0/ygZC91zt2H6QQty0Nt3q2+Jto/rWkU6gPjR9P+/P3Fu8A
xYcv61ZDIBrvVnT+72IoHyQE1Jl396H1eD6XwtDGi8DH9urYcGu0nv29YkxK
WnJwzcZZ0kgQ9YoVQmNMrjJM20fHZfgOHdezP5jm/J4K9Bn+OttUguZP2r73
aX85HoZdWfmQ7iyP1qPJFh6rRIBppXnzX2TQPEVXa4kKKgSgIx7YwDosgPiB
u4kYKIcHfYdoRPlWJNF15Po196BXFVhoROYQC9D57vuEvfnbSAVo7Wy1R+DF
Eb8vsPOj9r0M4M4lpLTK/z/xV02c1MskQK3gpTj3++i4nb5LCR8k+UBVtqfG
zDshxA9uN3MWfFsj9haqO0s6iCCeaYp99VpzjuLL/ymKZwTNs2ViInyRhhNG
vF+++tgcrd+0W5dwXEgclh68j3WgE0a8VJ9FZf+mNJT9ySgaaI3G2+sdSWa8
pwyvEsd/5UC0HpojeD8rYQ14tntS7E0FOq+jbt+0/zPGwT0XL1XZf2i83TNi
mF+WNrQUXO6omETHTQqQN8/dIgCzMPU1+XR2xB1lYh3SCXigem0nyMCTDfH4
6ASFeyXqgCev+biPCiPiTwt3Si8TVMDl7XTpozu8iC8LVlS+vCkP2lQf/+P7
xod4SbeLM1eDMEi9swPXKKhnO7c/D5nGAMUtCW/SbQziHsvdRLb6P0SbrISH
a3UMiOtrLO7Ub65R4KqQkHYDWr8hIUOv6yEPFL7bIZyyhMaLZExwaRYKw6RO
TX0LBybEmZTzHhXfkYKjd97e+/KEB3Gfibw/YqeVYdktN49L79B5hXUJj1F4
1eFTpeL69SQuxAvipvfUVPAwr/OIbssCGl9lmuCfJKANZ40LPuy7h+aP/PTT
Z8ZRG2xfD6cILtAhzhNSVaCtgQM94l4fkpL2KP9zGfvCDwVJmuCJIxcLl+Us
4v0x0tMD6UqAaf38jZ/70fhohm0OBnlZcOXJrJRXLz2Sv1cxbyr4syCQYsEw
9jz5h8SnDJ3M/KDDBxiXaPY4NNF6CqpljS9tThI/iYx8sR1oQOLxLKfj63vm
KO+fNIkJlHUhLh60m2lOxwbP+JqEt9VuIa5lozCpe0cCdpj87ku7NYd42oBj
nswdOXjCtOoN/zRaZ8+xYNJVYyW4nv1K8G/DChKvXZhTlfFXA6pvnTbad2UC
8aZzRydk9nDwINv1OHm+QcQ9pn9pjlYQoED3onbV61XEp3U/bA8uaIEfkP7S
RWda8D/vbsjYU2LEg7un1nISPX8Q/+cDEzvVXg9UwbOIP68d6P4iLnNJNU1m
RQH4qb1dUR6cR9w9advVJlMWvJflpkwY0SD5m876js1FiICOBd0qJx56xNl+
hLyy1uIEWru252SaOpE8pLBVernVcaL3nvDXBhY6JD7HkPVxzoUhymM/J6Fx
pXUk/rRvYYHkCh/8fC2Ms6ywA/H7WSkWDZ7iUHSk91/UzDbiTtl0n7FXZGHm
WTzdgfANxKe2PH+4OSpDN8YHffYX0P6klPiEeiVqwoFrBcEXtWaQ+FcWkZfV
eXEw2LcglE56CPHD7swXtyUIsLbiJ1OcIAOSZz1SILCxgADcTr1iaZfnRDyr
Lo+xbgoHuj7W/cG8YUR8JmhKLcVXE4Q2/GzM3WZDvPp+v4JwvwI43Dn+96US
C+LYwbgBTylpgJGO8j96hhfxPtKTI1JNAkBffVqq1ZMJ8b1HIqNt87xgLI0w
hwXMiPd+vM6xlblNLN3iOr2+yI14wAG/XdaGRUq04cKPiQq0HndZg29KbRww
g6XwR8dl1G/eaCBbxQnBkLJn6pc60PwlnQ6M6U3U++eROJ26j+yIB3luns7R
xcJXM4/7hsvR+qUt4u0fXVaHvR5sV889QOO1p66s+53BQ8aKJ3u1v9E69Xq8
pk980oZaJ6JVolrR/mj4Ja4WvySAUMq+c8onJBAnfQhMbTHBAX2yieVVekHE
l3gq5Pm11MGHQ1daGkvF0P7fDLV6kacE5rId3JpLRBH3urd5octEHthKXojL
8xVG/JjbWQMXIUnQFJha8/SeEOLTtDU91TeZwVUdjhqBWnTcLKvr341be4il
7zduHQiXRNf3aj2h4eMURdb+qtzQHpp/j0kiMEqNHV5//PiyLEDrzHo7klgk
KA657PTwqlZoHu3xhxMB1HvbJ8diQnSrCLpPLPTlOmUVoEZHgrhuEVrPvdSt
7AgGDXhiqy1p0BCN37px9XJiGPX+mRfkPSmEjntC+EwqwYAAn8tZNwnGo+PG
sifrSrlrg9LI4Xj1ozLovtJVuXj3nhYwLir7oLZPDnFncljmiTo1oHGQZk6G
Vhpx2+ON2Iw0ZfD1CqVV0haNtwjrSuhxkgPswa6ZY/SoS3dd5p5xFQT5LQIx
FS+kEFc1yFLxLuMA2TFrJzPPoPGKUYlz8Zd2iQwxwXNcT2QRP8tupmWRs0UJ
F+Hz00lCfbcxLCJCkAeOvltKsH6I1vmNmH3WGSsArVN0HB280XH3yUwalCrI
wiuiZUeaotA+PLoknpZvjIXj94U/XWaTR3x7gX2U87EajBlPinKYRutcHHwu
b82FgwWarpYt/Gh8gd3M18XTBDgqGjBjfh+t59Sg0aX+IgLQL3uYMuqliPjo
PpsrO/V48PrW4Nf1egW0/3mqcQsZmmCwN77hSbES4q8iXXpGtFTALN1MDX8H
6hs6/BYnYmTBgpL882cUZcQzfhY/2WURA6KO9g1fk9Fx89yvjqyIYMCfzqrb
9GlovCp9Zay3YQ3R4dwPNj06FcQpNHgNYW06OJItjy0yRevc2jx55qgrBopY
hKpdpUPzexiWtXN/kYDDEQ+l5zNQj/ua9+jtJRnItH151v0BmieI89k933YF
OMLVOnXjO+r8jS3y5RWaMO3Bgkp1NurFK95cDBo46EzXQsNqgtZfkGyl/zlE
B7YfCP3rOYVF/FlN/RFvT23gaKvF5bahiXjfallBbSEe1P+98PvZRTXEW8fD
R84uawId+xKacSkc4r588eKaG0ogMI6ujcsSjZ8oi7xOUJEHe0JLHRoBaH7O
fSeOLDYKAJkk1yMJ82g/B+pWfPZp84DUS5+9m2+qIz4jfLf3+sVlIp7twMWn
Rmj8m5k/JcMqU5QWln0FO1XouEdAYO+j2zxQMvZ54dPz6Lgv114bNOoIweRk
rq1Iew3Ef8gNdIuzU99L+h6+wzFoHhBx486DQSzcupeoYxeP5mnez3r31mk1
6P8zf6jeQBVx5rhjHLPdeHj+II32KW60Pydp0kxYInVgSIFfww0Kmueh9u0Q
0T1t8PHBfttXcWj8cqmX6rMHOLDPozBFUUYL8ZJU58OiOyrgX+4nk7QDeMQb
iquPxpxQBuXv9wnqL6Eu65VtPOEvA3p0xgr7stE8x/44bH63FQFvfDRGkybR
eAzG57llFRc4eOj4YfVgtJ7udPbZjLtfiF2TAQLZragzi00fuyBFD2tcP3/2
qEFdDdv2Y0McAzd7z2w3xaNecyVnMXZAGMrcPJDw+i/qo79Nq5Ia5OAE1tqs
AaD1VGU57L3pVIGNd2/tvceinjd9y/NMrCas1H5irHkende5rAcKJBMCFLn0
jfYinoD4g4hsc+HH2nDvYXLC9z50XHLl9/LRRB3wXP1KRGosGu8z70QzXo8D
NqJug4m22oiz97/n99tSAyeNOJvTnXQQ3z73U2u1TQXs7cf8vCCP5okaHFZ8
qi8DdOq6nhIV0TzZj0eWNB6IAtpZeyc5ETTPvuWOAmNfDHAJMLyEnUfn1TEz
rPPabISoVfLkybNKNP9Rr2rv6Zg1So2G8ln6IjR/TcvrIF8xJmhg9YjZyAr1
UBy+mLlCFEol8ulv96Du1cMdOvuLev5y+dQm8aNuszK3N7yoCHW6Oie/LP4/
+QVGdt6ka8AfWOUnfv/PfPmfJlDE+bRgt57JQuscOq+YAQ7nLmMd6Bya27fj
pvv/Ow3NJ67LfssrUvBtSMsrFzVpxEv/dV264CkC7zyEAwxGqOfPXpUHogJw
SmhvjdNLFPEtG+EF4W4eGLQsEMDQJoZ4T0dF0D05DmjoYbyScFQCcdMLWrYq
rH8pqaYn/5pRRBDP4k55Z0lZo2CLnVq9MgQRX8Y9n5kndlOWodmHeYIw4vq8
J941Cn4hRtBotZ9vRvMsslu9IdX+JuZtv0qg10XrfBH0wH5dmBbkvRQ6aZ2G
5slgmaLE0HGCxT1KJi0tWqeD4b2P7uo8IFEw5pRgPppfVzFZNFuJF6gxY+Bg
P+pwVZy2lE8UxD3rOlA0Io54dElqZh71XqJP2D7v3SeL+FHtZZUOTWmIC1eN
aXiH5hk/ahKSzykBt+LDSqqq0Tyf5o7nkr7zQP613WClM2j9Ts+Y7LBxXDD9
kYNz8RV+xPMyhe8nGzLCqbVB89v0vIh3eg7KvXbZohTJPbnemY16kfe8/v32
ecpUBGcn72/U7YdFrw08eUzZCnwzwBqA+iw3g6WC7l3i2jM8j8kGD+L8Ci6W
FqrUd9R4Z7HnQTQeV/T7hjXhHzGvN8qR1wD1qQdfDn6UowemAZcUTNvQ+nvU
6r/o7LKBvJGpSCDKh/iZjTO24o08QPjTxN+sfiHEU3FF7YNBQiDj+llt+V50
/5w/+7X3yZA0SCVLZBKt0H5iBsq2rxWKQJutummZGrQeU1fGB8Nn+GGroOQ1
xjUM4tln7jl8X+eDNjwH+Z3n0XhD0tQ9mwAWiKV5r3CagsbvHiNkWNxjgr6T
hpdvzHMinuXH/f1T/DoFq+efvcTBgXjcQk5qMv0KJWDeRcYrBc3j39l5+m3h
S4oaf4zVXAiax3K7Q0vCppa4zJjV8rSaG3F43eUw49wqEdB4WhxrQN338zVh
DYM9YnTfl6ztL6j32Mr9iPxKA9yPYshcrGh+3AWD1npeLlB//htLFQZd36tl
YzsRChgALrqeYt9A85R+fyL9ykIE4NSvHsdxoP035Pigs8gkDnpaGB8W4ATQ
/L8tvub+E4GJpi6N+XXofNM3l0vm6wWguWFWmBnyHqTO9/jBrJFBHjj+i7ug
7yBaJ2a5RNyLwgpf2Q/fL4xiQ7wnKoCtKo4Rvir9dEy3DPWQ5yPDg5ZblJ5r
sVGniKyIr0n5j1kZLFMSGysw8fwMiI9HDuDurn+kNJ/ktkq+wIS4tIva5WCf
PqK7ArG0uBL15sMB8z8m54mvun6EjZQwIr6Vf8wkb32H6HvlV8HwJRbEDTdk
ncb1acCU1fOUmT20nvYoXWL6Bjuo9i2Xi6hC80fuN7KyS+QBWIeE+uIUdP9E
mz3R7pMSBLCOeVQvF3WayiJctJgouJOiPjC7h66jzZxzhxVeBDYXBbvkDDEj
njfxouX7DT6Ypao9FNlPh3ihQP0ftjwMNA9PTo69Ro+45eRfwsY8A7R8MCvT
rIPGmysb5P9SoIHLpf/8N76izvIzOfVOxQYFo3H2gJjW//4diYYmInm1U/7B
CsWXb8bkuOIu4hgvXd3lyB4KWIwjr9ui8aTHHjgr9pdEHE+X2C2pHcSHdD7I
yBSsEDnMNN328dAi4+Ynbw6m5G0Ssx1uOk6Ooz4+WDtrmUMH6uU+TxyIResM
p8ub+c7OBraimB7IsaHxNEYZeO5jHKC9OueUVgbaB0P3yQp2FgHAMXUnJZaA
rm+1DWewOp8QiJgYVVYJROPjmu+0fggQhFiuhwb9t/4g9S9+uikf5MgHg4pO
X3QMRcdN9Y7arv7MAe05co/c8qFBfHnzqsmmNxt00iC6CjqifZMu+7aakk4D
GZ4cFu79hzpu9QTHT41tSvTk31PvuFYR78QMhJ8NXKZsybUdSj27hnj1LuFh
TH4vxfRawzOc/zri8GRPgCJnC9E9klvb7tBvxIvUE13mDOeI458ujl922UbX
cVV9m/XjFnHrWRqrojaax2ZRSNHu8B4x68sVl9ZldB21o76v7eJZgb5Cfg+9
xybi7Xnm/zVzY4BoxSO7+jm0D068R/86XOMBpGLpFbsRtJ+WDg+q7M+JAPcj
Kj8F3/5DPC+pNOxUvhBUo8c9uWOzjDi/6+le4QJeOCV3+hLDvUV0XdxZaT+s
ccJxet07x09MI54frSHIUcoKaT4wLWveQ/sQotkfsrhNB+1DXDuB/f/Tn3Ps
frqkdUr1x5QrsZwriKdbM9nJuS9StoTO15oOLCBujq+Kr2T/TDEf7fQdXBtH
82vwLS4Z9BJZrBl9Bd7PIN5D/7dFxvYnkcXxxB8vvwnEvTuW+XsX14j5FV7a
zhuT6LrUFRSOdu4Ql8deZ2Rw/EL3CTPtgbeFLCCoQDVsjYDW35MYtvrCjhMY
uvGwanYvIT675zEa0MIL3E94iYpVovsn+36IlT69MOBvlkgMZkPXPciU27DR
SBiKO3I8encdrZ8DuJnEzWOg/F3zs/9FoPN9Pej8vPkgBubdbftvlbkD8Vd7
yp2aNEwQOnwR+IH9hrhTznfBdzw00J/T7r7YdbQPu5KH+O5rrVJMT4s71zcN
I55Y5Ju6wrBMsTkr+KbMbhTtQ9QnP9n6t5ShcivmPrUsxLc0v8rGLjYTsc4x
909yFaHfJWJJWpvzNFF8WzF4yfITuu5hvAlWpD9EtRa8Y+BCC+LyKiZ/72fS
Av99UeoRI2id7d6fn4beYQTjGcpbly70IO4etuCdXUo9d3Pjt2jGGxHPyCz+
XSDHC1jOwVmTvGrEASW2fG5aEAhrfNN5tTiAuHC+3ffEOAGofboyYLX2OwWZ
F0+y5p4GL2Sxk2yFO+2IJ67z1z1hY4feVrMlhmdGELdUHzr+AsMAM4w5msJT
0PhdHvfUokgauDVRRGsxgsbzJyUZ7BSsU7L/lFyn1RpHPLrB/JvJ9g9Knv4b
Nrmcp4jbNFyOEs2uo9D4tudbun9DHHPraqHg15fEoeFAMynVXsQ7swxj824t
E4NWnq0aHytAfNb64kPC4S1iogGf4i7tIOLpJW4HXpJogKm1UUXaZD86r7at
ml5VFvDqe8LD0SK0zjLx/zIvHsAAeadDAgbfWhEXfkh+GViJAabpSu/5uWsQ
H1mWWj44KwCKYl0TuBh/oF40Gq/CJgQtBZuqQwVXEGd4GzNZKMgLfXPe77MC
aDxgnBiwPoqBpU/LPxrRLyL+6V25jb8wAzT1XuR6d2AG8fFzG+w60bsUy2il
uFGzZcQ57oCEUpvfFBvHaZ0fg5NoPx3N98s+/kWx4Z4PzA1C94M/50sd+bXP
lJ5uqfI10jzivqOfE+hvthGrK6rVcN+nEYcp31mJUz+I6bINidm7qGO+fQ+N
nV8lRuQo9QorTKF9s5CgpcT+JfpGSphvR8wiTjrZmpCmzAywpzSMtcbR/kj3
LJ1N/8QJ5EtpFaqXFhDPthzL1xLgA1cPYtx6otF4FhN7xyh76vvKWdZuVHoJ
8Z7nfUejl4Rgslw9oX6AFv7PK36WDJ46zwMjzml+EX+4icQH4Zy92E5yQfu4
Ty9qP+6iv5f9zCtKv5hgKmv3Na/JP+h+vmNo9HCUDpruV9X1qd1AfxdPmw0W
6rYppcG25OzNNbSff2cc9819p4ifb7HlJqwiXjEs6MYxUEqJrrgoEI3bRjxr
6G83z/VGYpy8E+6M4Dri2mrGc2dcfhCdXPuxR/zQ+reEErZf2P+hrstjm7t2
O4g7tf37VM1EC8Rb3Wnrq9B4+ZzJqgFID7BlxkZtamh+eUFVnZNkbmDJx6/8
yQ2tp76KkLFbxAdM7VqVY6P/IW5/nj5Vjl8IuHyXy/h37H//r0rN03qnH9aI
wHoTD4ugYUbE/V9UjAZdE4RxNDaZc+bMiKdunf/Mq8IF/UffDXp30SCeeN6l
PyWKDQ4ptFfwsjIgPmtVpEBso4PVsdtWXSHouDYBTmPR86sUjFfRcT5DdB3j
3jyyUhyfo9jA+CmXOHQ/+CrP0+83HaaE40KwvxLRcUMqZhemuz4TOWIqxLvO
oA6APZfxgSUiPGuK6/P5i+SnYYvVOPnuN9GfUtczOYD2v+jMAT8/bVowJELB
Sd1F89AEyJXdX2MB8ku40MiH6LxYko9YJK5zgexHoYrisWjf6i11RAW1eEGI
jbTPeCMTWk9p9N/DT4XAuMKZ4Mv70DwMhlesiUYiEJj9+UB8x4H4q6gXZ7Ce
AjDoDmNAujYb4vNf1V/okHmhfr3gwbY4dsSr21Zfu6RxwOoDjyL4FlkR9w/5
YNApQg8/JS4oNd1G8+CY8wfPb/6h5IPrva2FaP3LS4ZptVK/KP6x7M3TlSyI
Txk+/KSKzaI4qYTyJ02jHmSDa/t7b5zY4+8VefUkPeLY6yyMd3yWiEXX4pRw
Ieh8vT2uYGjWdonVxB/fJmbQcbXNCx4ridMC0xn8erAi6qVOn43UDZiA6cIh
qQl7tJ/CShixbWFe4E/5yru/HK3HvXk2/aItH9g9FfOWS5UL8YqwOoaJrxIg
MbF76dcxHsT9y0gKs7ckoAaPrUSyphDi0hvrkULV1HfBsAStpR0v4iPXM3gF
b/LDNVPRH8rN/Gh/PqgG4XrYICl2k1GhhBtxS+Wa8foiJugzwjhaU4SOW0rA
G5lRz9/8jtOegm3ouoCMs9qrCSsUrLUAU4kMWn91RVTeRslHilrqG1VlQ3R9
t85dUvHdfUdkqMb4fgtG909RAMapzes3cbF7PjkxGIO4/ZjFmQz9LSKu296t
uhCt097Dz9uL+k6G1tu6ET3ouOa2bNZ3dTlBvstBr5uJaB8YOq0OPLqCAfrR
oyfT76N51t7VPTrHIgyEL+1rjCsVQLy9ffzMf0LSYMRea2q7Ge2z/AXlLudA
KRhyGavNUCeMeE98YE/UIrX/piOcwkwiiKczxvuMTGJgz+GN9ZgMNH9qo/nb
m4PcsPToA634aEHEPylHa7zpZ4ClD130/x1EPZvw8QGxbpeSPXtJKN8CXUfp
0MelTseXKXElDzbfRaHrBTgrCvbw9RQOzS/Yax2o47Z/nuZ0miJWX1Gmb3qP
eojf+F8ewgox/blj79Jj1Dubop8EnNohhqc/1BOmoP30xgGpYzzMYA1bd1ZT
Ga0nJ7W0Y+QlBngfwJ2J9ULnC/6LSdWJEACYk/wefxXR/njv//AK6ykBnMxD
e8bMJBDPC73mn98mCWg24s2+CaPxzc9DDF5XysCBiHaVQhZpxLVfNzE5lQtD
bWvMYNUWmifyVPwj/SV+mMfLPS44JIl4tRLW6UQJD5zywftvAjQ/6ajfkcBb
jBATzld46gDqr1TX7TI7aOBUb2tEV64o4hWFd7Vrh35TSI4F81y16Hx1rVj6
C/0hxTfly5+tcXQdI+QWQeWjIWJI6INXFz+i+2eEXnW/oNs8cZw/YOqbLurX
R5/RiJfTAPEyYedFJnTcVybWcnUbzKATf9GS9TRap/jLqNeLnVxgnMj1i11C
HHHerEb1bEYBUH8qIbLWHs2TZZ/5euGnOCg8oPGMlCSD+FBbnnVHtyxQCciL
Un8vB/8/ffW+XA==
      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301548616434*^9, 3.614709316063208*^9, 
  3.614729171789756*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"During evaluation of In[259]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`],
    AbsolutePointSize[2.5], 
   PointBox[{-0.7721256826470433, 1.8803587659853824`}], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7381369739434236, 1.3377646577238378`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.33320685166278063`, 0.6267891018369076}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.34997242113042804`, 0.5224679153143168}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3774874303038994, 0.4397538162581769}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03366045613998329, 0.03944002116007385}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.18754518667649953`, -0.12294280691892157`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.14104942446148797`, -0.05335882548722314}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.031143641523540704`, 0.002107993017888582}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03166865252765019, 0.020340333308360055`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.018698389599865736`, 0.012116486729012131`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5606292362390013, -0.022299106649696226`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4023970735952044, -0.06387073841855201}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4668898537532612, -0.08717715126807027}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.1785696660620524`, -0.39615415743521415`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.8607791433138425`, -1.1906818993264183`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.41269445329367377`, 1.4878449640945135`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.54599684001742, 1.3789659043144566`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.18189024697927408`, 0.31602182237826737`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.027074564635960315`, -0.03463538706755954}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.22477366118919473`, -0.29115490223331947`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.34144715609695153`, -0.28472597531100263`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3950616106891136, -0.2432878329540148}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.468646112921495, -0.18959955644115692`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.49089867791588687`, -0.19169632542051357`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4770216304123868, -0.03701847022071536}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4453626759411572, 0.010185385458068269`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.25165616424246373`, 0.021398294414685937`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2112330032678087, 0.05976872422241973}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2936513037912619, -0.05830214001256451}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.543691242071131, -0.21527524808113402`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6414275798977482`, -0.824224251746632}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.11418674078019267`, 0.49513748287060705`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.008084599953921445, 0.03649063628312529}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03785791011019257, 0.11144459333631108`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1995710519125996, -0.32092855686743604`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.24734935822060866`, -0.41671245932282}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4569689571845958, -0.4275374685294322}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4517665258554554, -0.3320576300432304}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.585573994493936, -0.24919174796153032`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5686667777268232, -0.21027610382992376`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5826075785513478, -0.04284547909005784}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5408373066459491, 0.04361237656431541}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5750372477033813, 0.08639853493359201}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2472732882863525, 0.09635146256063451}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.24274354807028165`, 0.11380697258356186`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.606358748621099, -0.2818151863279379}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7261710883942768, -0.40503872250865325`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.07190088798073341, 0.4209967191591676}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.004822924899174993, -0.021416390073057318`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.06660421711295801, -0.21645934945932227`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1972877684934975, -0.4561754648614671}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2669878030377738, -0.4867258272387688}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4335224414742074, -0.4798939839544535}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.47436858959224526`, -0.4606911520850058}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.594736678972462, -0.30340406528486913`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6443686438721591, -0.18555827297293143`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6707215414284411, -0.05345943813581211}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6501203562409446, 0.09118862719964688}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6189784898682559, 0.11209983572133606`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.46758118258160875`, 0.26263464261526326`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.23844565155270914`, 0.14042871018042402`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.008257574715581837, 0.008558141178017422}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4145602489717024, -0.24995894759926185`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.006866865044650554, 0.14999615962641952`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01487467833110942, -0.3162418697604447}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.060266717012156995`, -0.45261909243544673`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.20415183128016948`, -0.6137804985394413}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3003161478463158, -0.5909229506682894}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3133343112303588, -0.5485861101815741}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.352480732386794, -0.4905031133449433}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.496365320639388, -0.2846124937210858}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.514821605461528, -0.17852986987330433`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6493469071784999, 0.06365292970487002}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6578237316174473, 0.1359763806923974}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6188511388293543, 0.26697623287309336`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5145234885233616, 0.3597590579524199}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.47532909853565336`, 0.3160101912068155}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.12150420590381728`, 0.1063727606710124}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.06725689548306821, 0.08000485525174628}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0281837357483376, -0.20666137291112882`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.007511487698932451, -0.3469972136482481}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.06762349590415612, -0.5707374930940038}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.05783943732374183, -0.6208225036961795}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.20993397668844171`, -0.6257137325367512}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.13705665374624787`, -0.578933303312968}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2537947663501392, -0.4607530503082049}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.38919271719342086`, -0.25537458127976076`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.40010787993117936`, -0.09202564668085908}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.573725234445605, 0.040196641340973976`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5449305394715026, 0.2863896697548217}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6023406441999275, 0.2987621354405787}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4874836401613104, 0.45632748949348995`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4047104922635873, 0.3457471898285115}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3408749797717604, 0.3779996729179208}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.018627179596436276`, -0.00766084131350532}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.04064656613751953, -0.1560408608296915}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.10250496411804774`, -0.4609223106152519}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.1409623900632085, -0.6018479597054665}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.035910300051783944`, -0.6489838393020532}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.032167964476352146`, -0.6540686235412375}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.14832596795034533`, -0.5188567118513369}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.16046198883838747`, -0.3961112388143445}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1372556291901154, -0.18233041835168312`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2872872649083682, 0.0022527971773021044`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3116673408957448, 0.24373578990273484`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.35995692271611845`, 0.3466726491969853}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4747168494741538, 0.38385152130703637`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4571792082540801, 0.5017372241111067}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.38490606985044945`, 0.5140894288402481}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.28413779297106767`, 0.37427599362472114`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.07403277478555376, 0.11964948355938673`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.04103574333047526, -0.12319961573754995`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.1583328914023216, -0.5358368414960759}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.20770981209056125`, -0.5492479694939006}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.1586289941924383, -0.6420907937966885}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.08312774796392919, -0.5977379143348185}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.035189320660950985`, -0.4320443383320898}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01574352419612088, -0.3874364437241685}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.011002112212428672`, -0.03391897501294731}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.041085210021376245`, 0.0656107506520172}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.20864536759280677`, 0.20000466390619542`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.25584449969580353`, 0.47537173563760243`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.38517438894834066`, 0.5229458197401883}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3179234672765248, 0.6043303093641401}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2572136061502657, 0.5689639770813583}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2135095488451703, 0.49246461198397423`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.10967927671651612`, 0.23564781980924313`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.1650026128603758, -0.27676356901284255`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.22504604623040547`, -0.45867024322054084`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3369131882151303, -0.5589095852353243}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3043290074722455, -0.5742929923082388}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3592868505963239, -0.49328893666986584`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.34043603940309464`, -0.34507279692705006`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.12800004802783344`, -0.2417302069961704}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.18196041555617462`, 0.04430241784455363}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.08641090823684121, 0.08258183399231664}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.13248497207399118`, 0.3685477492276127}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.08563911074613809, 0.5269240984482293}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1504959804086424, 0.6090730088652472}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.15254426614754177`, 0.671567864271767}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.20784677828146783`, 0.5753271205190323}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.21364297274012442`, 0.5565376163498542}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.08008709506234901, 0.3075175474477577}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.11911922776568815`, -0.165394434463421}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.27543610234944466`, -0.42479957692200554`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3369412837672136, -0.4655154389537687}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.41520425868768157`, -0.5093202416023033}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.487832655507327, -0.3580534610481454}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.34863510001415593`, -0.2767432817532819}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.34041471153173575`, -0.22869323564330185`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3342507469486365, 0.01522477215284651}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2139700714158236, 0.17960560871171466`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.12674087739473347`, 0.3641680834228593}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03392102103447239, 0.4933700715314891}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0029629819066571694`, 0.6175266970083182}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.02029915067375382, 0.6883491874916412}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1051613723222787, 0.6323871723221374}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.07780504347711172, 0.46086257754088555`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.011589314424716418`, 0.06268894718065425}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03980288900502031, -0.02755821574048354}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3414175547620742, -0.3697124450168598}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.43385324107970447`, -0.37245361077638467`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5312881143800638, -0.3955397147609314}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5455681002331898, -0.3824999731528633}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5454573895345997, -0.28801393299359923`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.46962398562571817`, -0.023382755908538833`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5037239812849245, 0.20581032083395773`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.40653254734921845`, 0.23682774386968566`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.35088784088063074`, 0.42175728182769473`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.26636161447806617`, 0.6021610440034946}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.13880910740095262`, 0.6650824829294961}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.06309311514922417, 0.6849777610232675}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.00005116463062340704, 0.5857242496908265}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.009932500974656533, 0.38177327819108686`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0013463410164476775`, 0.12472527927249194`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.10194014406199903`, 0.11318293805937395`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.05552917047252736, -0.031843572864227496`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4446468066439808, -0.33265015511982565`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5098593208257336, -0.2801789917321069}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6193895943594796, -0.24366621420548332`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6136385216817968, -0.11991910786030124`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6467520672121077, 0.04328296262185338}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6069786984008487, 0.14334086409522773`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5218254148615487, 0.3431469329607728}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3949372013054635, 0.4849494972594241}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.33906450137528815`, 0.5317628184972679}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2440008704703286, 0.6448100951133213}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.17350097780400808`, 0.5901330111143508}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.10229256281961863`, 0.4945221829104981}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0557895991326571, 0.35465633399637037`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0012906266174940867`, 0.05505833276454329}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.19105647192798803`, 0.16045506042539304`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.07620472566960934, -0.040317151552305086`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.21549610536486075`, -0.11156024567396586`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.42759383103378135`, -0.1840656580091755}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5823232678541808, -0.11849215048970022`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6687602757867711, -0.08078927301285355}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6698564022748079, 0.07696715713691477}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6250006287202585, 0.2716211898134585}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5407333612933041, 0.3911915867760133}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.49034688127460624`, 0.47446493693287173`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3720197315841768, 0.5712725644885832}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.313959504142127, 0.5990620979741046}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.23393430336423546`, 0.5833055263253017}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0637272809709178, 0.32459860106821037`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03628944898466232, 0.14411270224705536`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0957052833444747, -0.7532591164717971}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9616009590004716, 0.5467309609614104}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.22219536981258825`, 0.13310529458557535`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.23736437718951858`, 0.1088172052972806}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.37245775040278667`, -0.10253172676968711`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3707184904754873, -0.050200798361693694`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.650297724727346, 0.023729906602447753`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6144745099810969, 0.08543791278381357}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6405497588775183, 0.2265327675692957}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5910847430361573, 0.29394633703871237`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.44677114463396095`, 0.36829520362806134`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.41570809677138804`, 0.41176386654889174`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2618496744210452, 0.4311349789898557}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.09876801259144985, 0.19073672289491717`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.09208119241808285, 0.2521112709197982}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.1804674437867615, -0.5101920471773178}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3200749409079505, -1.3212835900011017`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.2001234019201892`, 0.6762210416315134}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6706122624150399, 0.2522533023370201}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.09191211148943733, 0.03855015309887154}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.10663247728326568`, 0.03702257230741956}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.13265683145554635`, 0.008429996189958787}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.3421374146606348, 0.033816499639666764`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5262233845882238, 0.10395180911266513`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5040591604507533, 0.21151340132555257`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4574537256515255, 0.28816699232705567`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.42216667618730636`, 0.3263306976636471}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.31843894340034634`, 0.3092417280391404}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.1397125111886392, 0.19527842571575726`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.034869003436731064`, -0.05126898701852658}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.2788208992096952, -0.5461732298044575}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5762649168629335, -1.4172902471472557`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3742123990027306, -1.2722523591498502`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.089711519045755, 0.9839370203718683}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.1869707398489586`, 0.36661917864300764`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.0456090711887152`, 0.221463539067366}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.39461923458037174`, 0.09792109740522534}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.09919862648005898, 0.013791629893671803`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.13881696492439582`, 0.0001278968292088012}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.29225010764254694`, 0.06832381147484884}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.23574470427919705`, 0.10645672999826365`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.09889869913866872, 0.06208941032528084}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.12240398142238422`, 0.08533075255901652}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0674127605543107, -0.04552160858783676}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.10292510130795528`, -0.10281681503110837`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.324098229340112, -0.39738748967419135`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.32688207597004415`, -0.5912361954968175}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9336642475243737, -1.7773528247701065`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.2730040520172663`, -2.9114307087709195`}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{5.167309729905722, 0.}, {4.720572331987787, 
     2.101734213274773}, {3.457605092815844, 3.840059487418429}, {
     1.5967865217398878`, 4.914403590342187}, {-0.5401309452950386, 
     5.139002666540759}, {-2.583654864952861, 
     4.475021495320862}, {-4.180441386692749, 
     3.037268453265986}, {-5.0543916145557315`, 
     1.074344102923758}, {-5.0543916145557315`, -1.074344102923758}, \
{-4.180441386692749, -3.037268453265986}, {-2.583654864952861, \
-4.475021495320862}, {-0.5401309452950386, -5.139002666540759}, {
     1.5967865217398878`, -4.914403590342187}, {
     3.457605092815844, -3.840059487418429}, {
     4.720572331987787, -2.101734213274773}, {5.167309729905722, 0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 0.3369919260658976]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.601301548616434*^9, 3.614709316063208*^9, 
  3.6147291722361317`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"During evaluation of In[259]:="]
}, Open  ]],

Cell[TextData[StyleBox["A perfect spherical lens and resulting focus.", \
"Text"]], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[TextData[{
 "In order to create a perturbed spherical surface function, we use ",
 StyleBox["ModelSurfaceShape", "Input"],
 " to obtain the model of a perfect spherical shape."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[CellGroupData[{

Cell["sphericalfunction = ModelSurfaceShape[SphericalShape,-50]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"In[264]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"1", " ", 
      SqrtBox[
       RowBox[{"2500", "-", 
        SuperscriptBox["#1", "2"], "-", 
        SuperscriptBox["#2", "2"]}]]}], "-", "50"}], ",", "#1", ",", "#2"}], 
   "}"}], "&"}]], "Output",
 CellChangeTimes->{3.5634042951295424`*^9, 3.563458206487101*^9, 
  3.564487642078108*^9, 3.566100788900703*^9, 3.601301245085415*^9, 
  3.601301549333603*^9, 3.614709316649291*^9, 3.61472917238037*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"Out[264]="]
}, Open  ]],

Cell["\<\
We can now create a new surface function that combines the perfect spherical \
shape with a sinusoidal perturbation function.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[CellGroupData[{

Cell["\<\
perturbedsphericalfunction = \
Function[Evaluate[First[sphericalfunction]+{.1*Sin[Sqrt[#1^2+#2^2]],0,0}]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"In[265]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "50"}], "+", 
     RowBox[{"0.1`", " ", 
      RowBox[{"Sin", "[", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["#1", "2"], "+", 
         SuperscriptBox["#2", "2"]}]], "]"}]}], "+", 
     SqrtBox[
      RowBox[{"2500", "-", 
       SuperscriptBox["#1", "2"], "-", 
       SuperscriptBox["#2", "2"]}]]}], ",", "#1", ",", "#2"}], "}"}], 
  "&"}]], "Output",
 CellChangeTimes->{3.563404295179716*^9, 3.5634582065241833`*^9, 
  3.564487642210507*^9, 3.566100789314249*^9, 3.601301245130872*^9, 
  3.6013015493752623`*^9, 3.614709316696353*^9, 3.614729172421402*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"Out[265]="]
}, Open  ]],

Cell[TextData[{
 "We are now ready to build a ",
 StyleBox["CustomLens", "Input"],
 " with this perturbed surface function. (When you wish to use a planar shape \
for one of the ",
 StyleBox["Custom", "Input"],
 " surfaces, you can use ",
 StyleBox["Infinity", "Input"],
 " for the desired planar surface parameter, as shown below.) Finally, we can \
model the ray-trace behavior of the perturbed spherical lens."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[CellGroupData[{

Cell["\<\
perturbedSphericalLens = CustomLens[Infinity, perturbedsphericalfunction, \
{50,50}, 20, GraphicDesign->Solid,
\tSurfaceApproximation -> {SphericalShape -> -50}];

perturbedtrace = TurboPlot[{
\tMove[GridOfRays[{45,45},NumberOfRays->16, MonteCarlo -> Stratified], 150, \
180], 
\tMove[perturbedSphericalLens,100], 
\tScreen[50]}, PlotPoints->100];

FindFocus[perturbedtrace];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"In[266]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyl3X/8rfWc7/+tUGFCdrfph61MW9Q+du1GaiRtIjrIrxr92PvLTEqyk2YU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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     Line3DBox[{{{100., -25., -25.}, {100., 25., -25.}, {100., 25., 25.}, {
       100., -25., 25.}, {100., -25., -25.}}, CompressedData["
1:eJyFlj9ok2EQxj9sBkEJCAUTxGggxsZgmpS2aQXJJwWLi2hAB81ioaBCyRbR
KXRz0EnpoFNxEDdxqCCYozhKOzgoUlFQHPwzFIIVXPwwd1fepzwYCIEfx+V9
77177snPtZvzu6IoepR8h5Jv/cWnvaXmpTj695kW/Y1vvlt7tnJHudSdb77f
uP/5lfLupPNTp1faP/rK4wnnc+vHR+4dvKz5x50fuvF6dDNWLmPOV55fXfxw
RXm35nxtKbNwcVF5XHWe7WxEq8uWv+L8zZfM46lVy1N2Pn/y190LHy2+5Lyw
NFLe+m3xxe06zNZmH6ZbGl9wvn7g6HLrsPJu3vm33Ue+P6lYfM751su3+/ed
MJ51nhntzAzNGB923upXO2tnjKedf43/XH9w1njK+Z6nP8/dOm+83zM+dfva
sXbTuH12xDdI/picxzmc3znc1znUxznU0znU3zm8l3N4X+fQD86hf5xDvzmH
/nQO/ewc+t85zItzmK/tOoTz6Bzm9788yGM8yRf8r/Hk/4NzGk/OG97L8o+H
dfD8Y2HdPH8trLPnr8K7WP5K+I6epwzvbvGlsE88vgh9ZfGFsA89Pg99a/E5
6HPjWZgL48MwR8bTMHfGUzCnxvuNcK6NRxGJ75H8Qs4j5PxC7iukPkLqKaT+
Qt5LyPsK6Qch/SOk34T0p5B+FtL/QuZFyHwJmUch80s50QcheiJEf4TolRB9
E6KHQvRTiN4K0Wchei5E/4XsCyH7Rcg+ErK/hOw7IftRyD4Vsn+F7GuMt/2O
+YWcxznxG3hf58TPYD2dE7+E7+Wc+DHsB+fE72G/OSd+EvvZOfGrOC/OiR/G
eXRO/DbloA9i+UBPxP4f9EfsvKBXYvcDfROrB+ihWP1APzV/FfVW81dQnzVP
GfVc40uo/xpfxH2h8QXcLxqfx32k8TncX8qzuO+UD+N+VJ6GuTOegjk13u/B
vla+Y19bfIPkR/9g50G/YedHf2L3RT9j9UH/M+CJXpL6o7/S+CL6MY0voX/T
+DL6PY2voD8c8GSfkP5E/zngyb4i/Y/+VvNPoB/W/JPonzV/Hf225p+O/wKW
f1Eg
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJyV1U8KgkAcxfGhWrdq00YQRJBAVPyDqzxD3SBo3RW8WR6qA1S7qPksGnDz
5fHUmd+8l15up+sqhHB+PevwvcblB73XMsT53Mf51MV5aOHfwL+GfwX/Ej4H
6Avoc+gz6FPoE/A9+A58C74Bf9zjXOtxhP+E7wHfge/BkzifU+gz6HPoC+gP
0JdxPlXwqeN8aeDfwr+Dfw//Af7jf1w+eq++U/+lfdC+aZ91LjxHnbvmRHOl
OcTccs51L3SPdO90T7WUA8oN5YxySTmG3GNOKldz6JXbynn0gnpEvaOeUq+p
B9Wb6ln18gd/AoTiTHc=
       "], CompressedData["
1:eJyV1T0Kg0AYhOElSZ3KJo0giCCCqPiDVTxDcoNA6lzBm8VDeYB4gH2KLNi8
DKPufjuTvT6P9ymE8Dyec9CatyjepjhfxzhfhjgPPfw7+Lfwb+Bfw6eCvoS+
gD6HPoM+Bb+BJ+BX8Av4/o1zrf0O/wXfA56A38DTOF8z6HPoC+hL6Cvo6zhf
Gvi0cb518O/hP8B/hP8E//k/Lh+9V9+p/9I+aN+0zzoXnqPOXXOiudIcYm45
57oXuke6d7qnWsoB5YZyRrmkHEPuMSeVqwX0ym3lPHpBPaLeUU+p19SD6k31
rHr54D8xHEx3
       "], CompressedData["
1:eJxdl29M1VUYxxk5edGYFf1xaiB415oJQy7CvY7VWX8sytKpKcK90Ii8FywE
wzXX1oJmBi1r+iLLF60aKomIci9w0cbTBUFpQpYsJ7R8Uy/S6Ytw1nhBbef7
Pez33I0xPrv87jnP+X6e59zs6l2b3khNSUn5+v+fe1L0K2g0WdgdunbfbMC0
DJam1UZvP0XeOpseeu5mwGy6tTezqHrO8bGh5aFvfwmY8s57c/9qTnPPi9ad
P1R4OmAiqXcvN5YucrzO7P1y4b6A6W8tuL2hJcPxRHrH9ZUbAqavJtTqL3vE
8cyJ8eO9iwLmB/+17Ou+pY5HqtPnkiPF5uPptSOTf2Y6Ptzw8qk3m4rN0dGa
qvWvZDte9d7vwSuLi82rTYEHtuescPzvI8dGHo0VmQ+TFWuv3vI5Hh/79eHG
dUWm4dKl+x/seczxsdiTe/6dWGPKFrQ9VF7/uONLbua3/7FxjbmyeO6l2ayV
jj9fn/FT5GKh6f9gedv60SccX9F3oDEeLDT+8N3eo6/nOt5SsPvptG/8Zsf0
5+mRmTzHR6s35nyR6jffDXR3vVOS7/iZg9NzHRUFJndZwLf5n3nevyND3j25
2vThN3ke3sf/I+dz+TnkXAfXRc51cx/kA9gn900+ibqwTuTbUUfWlbwRdY/h
HMj345x4buRbca48Z/JjyAFzQf4JcsMckSeRM+aOPIFcMqduv8gxc01eh9zT
A/IwPKE35GXwip6RH4CH9JL8x4mJU0cOTZXYv+Y9brLvH9Tvf9E+f1A/f6td
j+j11Nj1i15/r92v6P3GbX1kQNVn0NZTdD3bbP0lqurfbs9L9HnBW9Hn22Lz
IHdUHnbZ/Ehc5afc5k103uCtLFX5jNs8S6nK82qbf9H5j1pfRPvSYf2SC8qv
VdZH6VE+wlvpV/7CW9G+w1s5ofpDs12H1Kp+kmPXLYWq/7xg9ym6X8FbmVT9
7aKto4RVP4S3slv1zxl7TrJP9Vucq2xT/XnI5kBOqH4Ob+VT1f+RM/lezQt4
KwNqviDHklTzKGJzL2+p+QVPZIuad/BKXlPzER7KuJqn9hUU6/GNEv3+w/BY
P/9ZeKzXsw4ek8NbqYLHer9n4TE5vJUeeEyehXr2wWP3fNT/I3hMDm/lODwm
5/lugcfk8Faa4TE5vBV67PaLvNFjcngrP8Njcngr9Jjch/zTY3J4K/SYHN4K
PSaHt0KPyRPwlx6Tw1uhx+Qn8dxhfA75TqyDHpPDW6HH5PBWMH8dv4y6LEOd
yCtRR3pMDm+FHpPDW6HH5GGcaxjnTN6JHNBj8s+QG3pMruaF493e+eL4MHJc
i1yTNyD39Jh8m3feOX7YOx8d/807Tx2/OjU1FOuaOWf/Cjre5p3X8+vxznfH
n/HeBxwPee8Pjie89w3H29HXdH160QezVD33o29GVf3VfcnxMvTlSnW+8Nbc
UXmoR9+Pq/yo+57j45grOp8xzKFSled8zC2fyr+6rzreibk4ovyCt6ZH+ch7
c0L5y3tznvId3pou1R/exz1gp+on8NYUqf6jvi84znuJ7m8XcI+pVP2Q9+a3
Vf9U33cch7emUvXnJO5hnaqf8958UPV/9X3Ncd4LT6v5Am/NeTWP4K3Zo+YX
76kVat7xXvuVmo+8B99Q89S+gsbO39lz/wHH4pfj
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyF3Hk4VP/j/3/7nn3fd2MfY61onkpSihZJmZGk0o4klUJJSqJSyJKlUtpV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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxNmXc41e//x+2dvffe4zh20XmRRERDKOdIEtJCEqWQkZIoZO9KNJRs6twy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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601301551319759*^9, 3.614709318358301*^9, 
  3.614729174069345*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`],
    AbsolutePointSize[2.5], 
   PointBox[{1.5816951374819614`, 1.5068349864791757`}], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.52077487006762, 1.569489474103453}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.8664647375233967`, -3.1584782407134018`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.4982613199276344`, 2.0236572869097804`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.2632751570244827`, 2.4866297519505953`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.78508123886371, 4.063450640737374}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.1330159848184742`, -3.3726644554761793`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4678372302129118, -3.4941609482121727`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.00349220778831226, 0.3629566427869492}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.20348157670470873`, -3.461057112404015}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.8821626527445018, 3.64001617183579}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.0713500454244667`, 2.851587128288121}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.4396472602888242`, 2.612243263104479}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.8450581981089087`, -2.9352443441929035`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.508891483728941, -0.61901877951733}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7969932669975913, 0.9965241578584519}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.7650777854066186`, -2.6129010591169815`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.6609759318384922`, -2.7474189694800843`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.29882942048937383`, -0.21944220800772896`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.4927270414613845`, -1.5651150729705485`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6830464877513482`, -2.305698978727157}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.5321521345436884`, -3.018798781643312}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.0511316117311833`, 4.129722677416214}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4436462798891155, 4.783571958811639}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3805733658187759, 5.25526914174922}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.8146620017356774, 5.076751593146615}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.8123005576218877, -2.8977064448055656`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9494868286187856, -2.4491158314613055`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6351976640751893`, 2.8064807778551417`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.4547168464482767`, 3.6769058230381586`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.4202597979363354`, -1.7079856759218297`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.47371209966895644`, 0.5275138605311505}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.440646801061737, -0.8285473357596116}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.154546444893363, 1.6941490490942033`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.1422403451726346`, -1.7377784176794722`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.014657517524723298`, 0.08697599914228003}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.9631194831935663`, 3.2388280270120102`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.9332986721072025`, 3.062487001506131}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.2368304252661242`, -3.114942842252757}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.30147239684089217`, -2.7909495191458573`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.11569944180524083`, -1.7490006574507628`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.0016885706800316`, 4.958834980171951}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6350256458322319`, 4.640207996317339}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.873751685374835, 1.5321326191304854`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.0570588534922862`, -2.653483313009336}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.9711980606232292, 1.2887465431597733`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.9040066598898395`, 1.824609258672918}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.2099286913708425`, -2.608992928780784}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.700105759750057, 2.0589403037285794`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.809533732990579, -0.9447053657495593}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.7154139568422337`, -1.7216626730211146`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.278535728046667, 3.3749923001406015`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.7966436139315998`, 3.5155270670081196`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.42943605500951637`, 0.7304202396553491}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.7102551714938403`, 5.009916554708998}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.7521668666524263, 3.1074716478102196`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.02493757947476577, 0.8044371031933332}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.7025129692580018, -2.296822311083768}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6713958064127025, -1.529707892083696}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2638551905262279, 0.38553027645539784`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.4418257386678133`, 3.199551695449732}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.9617260872473339`, -2.01342716811689}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.5260799131991685`, -2.0708193944674647`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.4381238392325786, -0.264872870587113}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.6923386933291744`, 1.4205912666497265`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.1729420167558133`, -0.47848179893351617`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.6518997791185255`, 2.4224270520840916`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.9436684771809194`, 1.8447247038290475`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6466483750503482`, -1.3202673255347133`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.1501676297052748`, 1.4788281849176654`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.11176469219661812`, 0.2764658703106002}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.45064503074376305`, 1.836753416670879}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3214792589813062, -1.9882564485243461`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.8880855133885688, 4.810635152344058}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.3747133625363581, -0.5819057008838725}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.9219902764633563`, -2.4664674056485327`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.1061337854919795`, -1.028190610084415}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.4894830751778043`, 2.5331879581800925`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.9691810859567545`, -1.7282066791699773`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.492807762988276, 0.9996572390966929}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.220067866477679, 1.2322360738090896`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.07814954172549123, 0.12033662299922351`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.782685990250521, 0.42370660765360657`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.689307796063742, -0.9426211609581074}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.56257879913768, 1.3446018678165026`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.4650442104896033`, -1.0021883209340152`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.7203177827152276`, -1.923436463718425}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6234263038318031, 4.32031306777768}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0756178965010263, -1.0343678692302976`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5398254341291646, -0.8050827760210275}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.4172245272822497`, -1.5670921095460018`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.5390610234364694`, 3.0812224876816723`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.251605387501562, -1.5281308092045633`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.361685107197713, 2.55572810268239}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.04940293106905, -1.0613845102162036`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6084481104140093, -0.18576416842201024`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.07378194719071263, 0.07836920705476531}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{5.02008668029156, 0.7050339155379314}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.4810341914912275`, 0.6844227203822859}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.3370908699610724`, -0.937497449401226}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.4110573586027346`, -0.8956382109763892}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.249498166850527, -1.7768498468793257`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.178902626044966, 2.153406273004522}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.6061644716635122, -3.808477368396811}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.018688313597991828`, 0.13801272073555446`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.1367591111891038`, 3.3271057301537517`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.0489595369570117`, -2.011146657806445}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.479307433621903, 2.8286043596280863`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.7204755082480135, -0.3153473240414062}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.3504407250623, 1.7242510741721733`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.141900935103492, 1.1898641844554023`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6591362432053143`, 0.5966109088424577}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.384986666386046, 0.21917820072902583`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.0691750611287785`, -0.07357533328261265}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.3234854500525826`, 0.31464458782956606`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.0847058247029826`, 0.198366678643346}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.6199774154997573`, -0.1093482725177379}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.4823324786103327`, 0.001590792479402331}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.9998400354532935, -0.5983039818291029}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.8148234271695824`, -1.1354546297497856`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.5295372583530622`, -3.9384057459505506`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.4554150175365708`, 1.46247457666849}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.981198790209015, 1.0746808883522565`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.01169121955022, 1.4563216882188688`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.3887466174949639`, 0.21597013060208092`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.923386737808372, -0.15569324829928713`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.739074351763908, 0.14549248173309554`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.966414654085279, -0.20122474861979514`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5355224657501746, 0.007129675557801203}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.597107312460779, -0.47356484407956073`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5860992995982289, -0.006143265695187403}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.2275693208937284`, -0.4401601239304954}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.6904488073621686`, 0.8043213881746305}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.711722451406735, -1.265838214808214}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.7637676189026648`, 1.1171234252493698`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.8277437315588876`, 2.0963059667318458`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.36285841866247837`, 2.0252320872947447`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.13920155090984257`, 0.06476384392840562}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.5024047927135893`, -0.6995549083814654}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.5019573689379473`, 0.26334573145768236`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-5.268072283810806, 0.23654447010293084`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.501867753617375, 0.0023211303112732895`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.26691582489511256`, 0.0961123365502502}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.9532696329174666`, 0.08616249145959376}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.1644686938095417`, -0.7443794481346214}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.9898121028868745, 0.3255187889505398}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.658672111512854, -1.4041698196375412`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.164894696117971, 1.4726017123454518`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.175236879209368, -1.5283304718234212`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7560923908028748, 0.5760029551840621}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.7680741803032918`, -2.6909525493109028`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.4202313537703324`, -4.3913441237908835`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.6791301527806742, 0.9900686599790824}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.808185878392943, -1.9875008747616032`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.11999761867778, 1.3134402158718217`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.927617183115721, -0.6364779096272309}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.787317091506341, 0.43181092161354506`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.1951299381922253`, -0.7083481564975144}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.0068306041520954`, -0.01155600627245415}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.1785816662144, 0.25658811000977044`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4459370034942556, 0.24156152736190514`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.5631510630983676`, -0.8157936033569393}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.4090077105214953`, -1.925590933534714}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.21223305529637917`, 0.19842303946922704`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.5241828260859633`, -3.032842124100132}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.0563572712147904`, 2.8694176728422396`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.1054201208131458`, 3.673888656793226}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.10307672806650155`, -0.32565822581300485`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.3554195338427952`, 3.605556962052194}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.68612875063247, 2.6429974613795144`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5731362282335273, 0.7140964194794172}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.405811480009347, -1.1248106193352778`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.4582139127321354`, 1.2575856982446514`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.108426095517319, -1.266162498941909}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.387794883356498, -1.0196893568862127`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9807751222791378, 0.3366511592939634}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.4795656641575694`, -1.9405252388667942`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.4635684051266282`, 1.1356398502382903`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.3678574534199037`, -1.8060656842990503`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.1385999908914806`, -0.9519299380232489}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.737898348975553, 2.3146513567967872`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.5166521434452211`, -3.5647463855748893`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.5380784213382952`, -4.861835329395208}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.22058217793447635`, -1.2114594123477753`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.8431544961248769, 3.000466517858699}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.423720940381211, 3.3705871762445114`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.53734110872272, -3.6525848900884594`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.6615334165543088`, 2.2804297210842392`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.7969330111514685`, 1.368760247002328}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.350798808295089, -2.393560766969376}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9346088373355925, 0.5313595622705798}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.02382760847683, -1.117815379351823}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.015303750209768128`, 0.08574969436206561}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.860447894781876, 2.356039887101872}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.497922464033792, -1.296274494522141}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.8803733081135534`, -3.647055411758016}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.9685010114281405`, -4.20360193169126}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.8092166828110108, 2.095159541184208}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.4091013434962335, 1.6951007659045603`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.23679046306529136`, 2.1292040058309616`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7381467239530908, -5.1882730908335}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.883712069547941, -1.5869007374149784`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.4312014937006128`, 2.1736621326421504`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5506595643205116, -0.40461235341931834`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.680913959769988, -2.9194808900110547`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.0352735289429846`, 1.8412576168322545`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5994761650464566, -0.21241728293755036`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.741995879949477, -1.9198178058171453`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.2581327832007376`, 1.1389227385061997`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.1528129457336473`, -2.750886970578789}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.7303289511728484`, -1.8971891343804776`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.6896991149664269`, 2.2375542964956554`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.1235196451418927`, -4.627441622312997}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.3151350416974887`, -3.7832826926884735`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7004273533028366, 3.2726765673280345`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0010933265936823033`, -1.3256677097325915`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.23373862275222765`, -2.372022701282271}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7781624102681728, -2.087884293128855}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.3371078437736994`, -4.522421350835346}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.9616558168289595`, -3.6548242729552203`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.3330290570871326`, 2.444127090153806}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.41853175071166854`, -0.31583289406052645`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.59855297343005, -1.1472315358812706`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.552338026267819, 1.6516629473949052`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.9946554772194978, 1.0649236557565054`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.872394550516556, 3.565313707290314}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.5774294425295812`, -2.283028044143736}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.8569959250286006`, -3.030275400528702}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.0442638197268572`, 2.7674369910420715`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.37005549782332464`, -1.1805457009510372`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.04498095062691569, -0.3742150662483865}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.30132625465580776`, -5.124327564078207}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.1792496932390453`, -4.99747194937527}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.2566716287212563`, -4.9725102296835075`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5854538735235344, -1.0858868597602682`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.6505147111995522`, 2.9652502584919134`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.9080949823344678, -1.194720097726498}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.0252592567987968`, -0.9542184149918648}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.05353410900118577, 0.1500458397706426}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.909704683916769, -0.5970345503302004}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.052161058679377, -1.0385794948736735`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.9462753652090943, -1.1306264007237428`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-2.0257345582043054`, 3.3162529996728107`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.8202402240310374`, -3.9031185059548235`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.7189042863742312, -1.8721396123100371`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.7659844547971542, 3.6116473438119616`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.529478141235743, -3.4999140623417526`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.11851351660590295`, 2.6805313059651774`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.22685061817855398`, 2.5813239159538424`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.2609049912550713, -0.9570802182335313}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.07219388214389022, -0.0688706064503161}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.5713757474881903, -0.8090227233036402}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.5998498244039572, 0.8622689881470346}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{2.9637610838420336`, 3.501706250107023}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.2515745902350592`, 3.108148334122331}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.600715243103984, -1.1874677225007801`}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{10.994953680863691`, 0.}, {10.04438999214382, 
     4.472050550928411}, {7.357060023363882, 8.17084293429748}, {
     3.3976275397522633`, 10.456822344548797`}, {-1.1492856119597115`, 
     10.934722174178932`}, {-5.497476840431846, 
     9.521909201061177}, {-8.895104380184108, 
     6.462671623250521}, {-10.754687563116144`, 
     2.2859794102513167`}, {-10.754687563116144`, -2.2859794102513167`}, \
{-8.895104380184108, -6.462671623250521}, {-5.497476840431846, \
-9.521909201061177}, {-1.1492856119597115`, -10.934722174178932`}, {
     3.3976275397522633`, -10.456822344548797`}, {
     7.357060023363882, -8.17084293429748}, {
     10.04438999214382, -4.472050550928411}, {10.994953680863691`, 0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 1.5755256096042092`]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.601301551319759*^9, 3.614709318358301*^9, 
  3.614729174472373*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"},
 CellLabel->"During evaluation of In[266]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["A ", "Text"],
 "perturbed",
 StyleBox[" spherical lens trace and resulting focus.", "Text"]
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[TextData[{
 "In this case, the ",
 StyleBox["SurfaceApproximation", "Input"],
 " is only used with the second surface since the first surface was a \
built-in planar shape. In the event that two spherical surfaces are involved, \
it is necessary to specify ",
 StyleBox["SurfaceApproximation -> {{SphericalShape -> ", "Input"],
 StyleBox["radius1",
  FontSlant->"Italic"],
 StyleBox["},{SphericalShape -> ", "Input"],
 StyleBox["radius2",
  FontSlant->"Italic"],
 StyleBox["}}", "Input"],
 " instead. This two-input format can also be used with any of the other ",
 StyleBox["SurfaceApproximation", "Input"],
 " ",
 "methods",
 " as well."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3.9 Interpolated Surface Functions", "Subsection",
 CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[TextData[{
 "When you need to build an optical surface shape from measured experimental \
data, you can use the ",
 StyleBox["ListInterpolation", "Input"],
 " function of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to model this shape in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[CellGroupData[{

Cell["?ListInterpolation", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[271]:="],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"ListInterpolation\\\", \\\"[\\\", StyleBox[\
\\\"array\\\", \\\"TI\\\"], \\\"]\\\"}]\) constructs an InterpolatingFunction \
object that represents an approximate function that interpolates the array of \
values given. \\n\!\(\*RowBox[{\\\"ListInterpolation\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"array\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"min\\\", \\\"TI\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\) specifies the \
domain of the grid from which the values in \!\(\*StyleBox[\\\"array\\\", \
\\\"TI\\\"]\) are assumed to come. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListInterpolation"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.6147291750336437`*^9},
 CellTags->{
  "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}]
}, Open  ]],

Cell["\<\
In this example, we will simulate experimental data by sampling discrete \
values from an analytic function. In this case, we will sample the same \
perturbed spherical surface function used in the previous section. In \
practice, however, you can import a table of numbers from your experimental \
measurement.\
\>", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[CellGroupData[{

Cell["\<\
sphericalfunction = ModelSurfaceShape[SphericalShape,50];
perturbedsphericalfunction = \
Function[Evaluate[sphericalfunction[[1,1]]+.1*Sin[Sqrt[#1^2+#2^2]]]]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[272]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"50", "+", 
   RowBox[{"0.1`", " ", 
    RowBox[{"Sin", "[", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["#1", "2"], "+", 
       SuperscriptBox["#2", "2"]}]], "]"}]}], "-", 
   SqrtBox[
    RowBox[{"2500", "-", 
     SuperscriptBox["#1", "2"], "-", 
     SuperscriptBox["#2", "2"]}]]}], "&"}]], "Output",
 CellChangeTimes->{3.563404297948861*^9, 3.563458209275282*^9, 
  3.5644876461465387`*^9, 3.566100794213382*^9, 3.601301246047555*^9, 
  3.601301552352214*^9, 3.6147093196006527`*^9, 3.614729175181925*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"Out[273]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
samplepoints = Table[ perturbedsphericalfunction[x,y], {x,-25, 25, 1}, \
{y,-25, 25, 1}];
Dimensions[samplepoints]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[274]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"51", ",", "51"}], "}"}]], "Output",
 CellChangeTimes->{3.563404298006658*^9, 3.563458209317432*^9, 
  3.564487646179223*^9, 3.566100794267284*^9, 3.601301246154159*^9, 
  3.601301552386848*^9, 3.614709319636231*^9, 3.61472917521166*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"Out[275]="]
}, Open  ]],

Cell[TextData[{
 "You can use ",
 StyleBox["ListPlot3D", "Input"],
 " to examine your experimental data points in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell["ListPlot3D[samplepoints, PlotRange->All];", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[276]:="],

Cell[TextData[{
 "Finally, we define the surface function with ",
 StyleBox["ListInterpolation", "Input"],
 ". Note that ",
 StyleBox["ListInterpolation", "Input"],
 " requires that the data is sampled on an evenly spaced grid. As such, the \
sampled data is single-valued and does not contain coordinate information. \
Instead, the grid domain, given by ",
 StyleBox["{{-25,25},{-25,25}}", "Input"],
 ", is passed in a separate arguement from the sample-data information."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[CellGroupData[{

Cell["\<\
interpolationfunction = ListInterpolation[samplepoints,{{-25,25},{-25,25}}]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[277]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "25.`"}], ",", "25.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "25.`"}], ",", "25.`"}], "}"}]}], "}"}], 
    ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.5634042981223717`*^9, 3.563458209444803*^9, 
  3.5644876463143263`*^9, 3.5661007944516687`*^9, 3.6013015524946947`*^9, 
  3.614709319755927*^9, 3.6147291753218*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"Out[277]="]
}, Open  ]],

Cell[TextData[{
 "Next, we define a ",
 StyleBox["CustomMirror", "Input"],
 " with the interpolated surface function, ",
 StyleBox["interpolationfunction", "Input"],
 ". This time, the grid domain size is the aperture size of the mirror, ",
 StyleBox["{50,50}", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell["\<\
interpolatedmirror = 
\tCustomMirror[interpolationfunction, {50,50}, SurfaceApproximation -> \
{SphericalShape -> 50}];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[278]:="],

Cell["We can now perform a ray-trace on the interpolated mirror.", "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[CellGroupData[{

Cell["\<\
perturbedtrace = TurboPlot[{
\tMove[PointOfRays[{30,30},NumberOfRays->5, MonteCarlo -> Stratified], 50, \
180], 
\tinterpolatedmirror, 
\tBoundary[100, 50]}, PlotPoints->30];\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"In[279]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301554864883*^9, 3.614709322128191*^9, 
  3.614729177708118*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301554864883*^9, 3.614709322128191*^9, 
  3.6147291778418903`*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301554864883*^9, 3.614709322128191*^9, 
  3.614729177980842*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(SurfaceIntersectionFunction :: \
intersection\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during \
this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301554864883*^9, 3.614709322128191*^9, 
  3.614729178021187*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyVm12MFtUdh48fCFJiWg1+sLI7C6K7LNBNRWDLJExqrJQ0XjQRjcabJhiK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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGCQBmJmIHa46uH3aa+UAwMYWB5ggAKd54I3zvQIOYSFAsFV
E7j4nM1RGVOt2RxWrwIBA7j4wy0RUat9ftozgnmaCHPuGfUrar+0XwNWrwAX
n7S+bW7F6232G8DiAnBxAzHPydbflthAeB/2wMTroepXQNQ7wMRVoeZDxBXg
4peh7vnzHwQ04OJToe6HqDeAi2tC/RsC8S9c3AoaPv/A5ljAxdHCDS6OFm5w
cbRwg4ujhRvCHNRwg4ujhRtcHALg4WaDI9zg4YwWbnDxS6jhBhdHCze4OFq4
wcXRwg0ujiu9AQBJaso9
       "], CompressedData["
1:eJxTTMoPSmViYGCQBmJmIHa46uH3aa+UAwMKsDyg81zwxpkeIbh4WCgQXDU5
MGdzVMZUaza4+OpVIGBw4OGWiKjVPj/tYeKMYFLzgM49o35F7Zdw8TVg9QoH
Jq1vm1vxehtcfANYXOCAgZjnZOtvS2xQ3fNhTz2a+hUQ9Q6qaOZDxBUcLqO5
589/ENBwmIrmfoh6AwdNNP+GQPzrYIUWPv/A5lg44Ag3Bxzh5oAj3BxwhJsD
jnBzwBFuUHMxws0GR7gdwBFuBy5hD7cDOMLtAI5wO4Aj3A7gSm8AHpXKPQ==

       "], CompressedData["
1:eJyFlLFKA1EQRR9a2ti6GtkgAUMiBExj97ASCwvBfICgaBpLe0GwSuMPCDYi
ErCyEOV+QyBY+g9WKY27M1e8MPhgCXsYhnl3z6R5fHF4spBS6s+fxfkzux+e
DltbOVVnB/ab187H27e7m/no50z75CvXndeXz438WJ0e+ehj9DxpNa1Pm7xz
M7u8Olu3+pL8fX/pbjJezQ8VXybP072Dr7fC+vj5rX+q633e3LX+NS/JZR7y
wuav63vkDbvvoL4vueTzL/fc/N3yY27OLT+Z0/u0mdvf+pI5OLf8JDfvk5LW
W37oSn/LD8E8KGR+yw8Nua/lhyCfkItv5OIbefB9Ib6Ri2/kgW8Q3+BcfCMP
/If4Ri6+kQf7GHLxDb6v4ht8X+X7wucV3+D7Kv7A91V8gyen9b6v4ht8X4N5
svgG31fxDb6v0f/YNy/JbY4=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIAaxISDSAUJbwugDaOIHCIg74DAHlzgB82GAoDi6
+YTEiTXfgYC4A373kGo+wfDBZS8hcXRzDuAQR5PHZQ5cHJc5hMx3wKHeAYf5
6OK4zIHTAGZJN6c=
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBQAGImIAaxIcDTgQEd7K5/F335jL3Zup1T3sQyHSiO4khU
PyXsgFP9Ie0HQT5H7bev7piR1cp/YEt/4t+mtZwHcKqf8OCLU+pWex2f+B8Z
bxkPaBRv3rTgAAdu9VLu1ZFi++0rgr5MymsVcHgVU9lUfpoRt3qJ3qZm7sf2
ZydLn5mhLnhATWTPjyJmcdzqL1TteBNz1z5Yx+XBHcOX+4/rsmRu55bCqd5B
7ctXseBH9iGTCo8ESos5CFt4zbq2UBC3+VBwdpNT8EwvtQOLep7lLM9TcyCk
3st4j1iUpsiBmcme+6Vn6xNUvzhq8bHkPd/tJyrKGj9XIWw+R+9D7R1qKg6X
jWckSlhoElR/juvB3eoLOg5HF5nOCSkibD7f/vV3OnnUDyR/cfQ8cUmIoPpH
EXGSqZelDpx4IH+R77uCA/50GOkQsS6972O4gkP81CiRmiCDA4TMV+DKuX80
UcpBdN/RsG/qeNIzFPRFPN8XL6HjUHCjUsEtSIGgeqc992WKLhkcYDnz9Dnv
sR/7ceULRqj7LxjKGao8V3Q4OHf+o5xMoPk48sV/MIhwaPfqLbuVL32gONJG
6dQtxQO48gXM/C8TTXrq/ggd8NAJ4zxqy0jQ/cqpdit63ms6PBDfISoQyERQ
fVjKsfVpl/QPxH6drb5TWvgA/nwX6ZBgcl6loF7dYeqs3bbnvgLTM4585xex
2fmqZ4RDl2Ko95Yt7A4Q/1g64Mp3sPCZkubFKjjH4MAN1qbe/gItgu5vqOXx
1QlXd0hbwJluoq1wgJB6mSXPo37MUzsw+bnuVykhTYLqU/N0vZcdFztQZtlz
5qymNkH1Ul7LdKe8YHS41ST8uEdLl6D683pOVssDFB1s7XKyLXkJm9/4vrju
c6Seg/vzzQ73knQOAADojWgQ
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxTTMoPSmViYGBQAGJmIGbYXf8u+vIZe7N1O6e8iWU6UBzFkah+StiB4ZD2
gyCfo/bbV3fMyGrlP7ClP/Fv01rOAwwTHnxxSt1qr+MT/yPjLeMBjeLNmxYc
4DjAIOVeHSm2374i6MukvFYBh1cxlU3lpxkPMEj0NjVzP7Y/O1n6zAx1wQNq
Int+FDGLH2C4ULXjTcxd+2Adlwd3DF/uP67LkrmdW+qAg9qXr2LBj+xDJhUe
CZQWcxC28Jp1baHgAQYoOLvJKXiml9qBRT3PcpbnqTnAxL2M94hFaYocmJns
uV96tj5cfHHU4mPJe77bT1SUNX6uglDP0ftQe4eaisNl4xmJEhaacPFzXA/u
Vl/QcTi6yHROSBFCPd/+9Xc6edQPJH9x9DxxSQgu/igiTjL1stSBEw/kL/J9
V4CKRzpErEvv+xiu4BA/NUqkJsgA7n4Frpz7RxOlHET3HQ37pi4MN6cv4vm+
eAkdh4IblQpuQQpwcac992WKLhkcYDnz9DnvsR/7GaHmXzCUM1R5ruhwcO78
RzmZCg7/wSDCod2rt+xWvvSB4kgbpVO3FA/A1H+ZaNJT90fogIdOGOdRW0a4
+cqpdit63ms6PBDfISoQyAQXD0s5tj7tkv6B2K+z1XdKCx+A+SvB5LxKQb26
w9RZu23PfdV38IvY7HzVM8KhSzHUe8sWdgeIfZZw90xJ82IVnGNw4AZrU29/
gRbc/IZaHl+dcHWHtAWc6SbaCvDwkVnyPOrHPLUDk5/rfpUS0oSLp+bpei87
LnagzLLnzFlNbbi4lNcy3SkvGB1uNQk/7tHShYuf13OyWh6g6GBrl5NtyYtQ
3/i+uO5zpJ6D+/PNDveSdA4AAEaCDVE=
      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404300607173*^9, 3.5634582116883907`*^9, 
  3.56448764858062*^9, 3.566100798038962*^9, 3.601301555401758*^9, 
  3.614709322657168*^9, 3.614729178237783*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"},
 CellLabel->"During evaluation of In[279]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["A ", "Text"],
 "interpolated",
 StyleBox[" mirror trace. ", "Text"]
}], "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[TextData[StyleBox["In the ray-traced graphics shown above, the rendered \
mirror surface does not depict all of the details present in the actual \
surface function. Nevertheless, the final ray-trace still faithfully follows \
the actual surface shape, since it does not depend on the graphical rendering \
in any way.", "Text"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.3.10 ",
 StyleBox["SurfaceIntersectionFunction", "Input"]
}], "Subsection",
 CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}],

Cell[TextData[{
 "When a particular optical component is first defined, as part of the \
component creation process, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " stores within the component object a number of surface-specific functions \
that are used later on by ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " to perform surface-specific ray-trace operations. Among these \
surface-specific functions are: ",
 StyleBox["SurfaceFunction", "Input"],
 ", ",
 StyleBox["SurfaceNormalFunction", "Input"],
 ", and ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 ". These surface-specific functions are stored in the ",
 StyleBox["Surfaces", "Input"],
 " parameter of the ",
 StyleBox["Component", "Input"],
 " object. Here are the ",
 StyleBox["Surface", "Input"],
 " results for the planar-shaped ",
 StyleBox["Screen", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],

Cell[CellGroupData[{

Cell["Surfaces/.Screen[50]", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"},
 CellLabel->"In[280]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ComponentID", "\[Rule]", "111103"}], ",", 
    RowBox[{"SurfaceID", "\[Rule]", "111105"}], ",", 
    RowBox[{"SurfaceContinuation", "\[Rule]", "False"}], ",", 
    RowBox[{"ActiveComponent", "\[Rule]", "True"}], ",", 
    RowBox[{"SurfaceFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
    RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}], ",", 
    RowBox[{"SurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
    RowBox[{"SurfaceNormalFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"ActiveRegion", "\[Rule]", "0.`"}], ",", 
    RowBox[{"ComponentMedium", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"JacobianMatrix", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "RayL", ",", "SCx", ",", "SCy", ",", "RTx", ",", "RTy", ",", "RTz"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"RTx", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"RTy", ",", 
           RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"RTz", ",", "0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"SurfaceRayIntersections", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"RotationMatrix", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"TranslationVector", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"ComponentTransformation", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"SurfaceCenter", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.00001`", ",", "0.00001`"}], "}"}]}], ",", 
    RowBox[{"SurfaceBoundary", "\[Rule]", "50.`"}], ",", 
    RowBox[{"InsideSurfaceBoundaryQ", "\[Rule]", "\<\"-boundary check-\"\>"}],
     ",", 
    RowBox[{"OffAxis", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"CheckLimits", "\[Rule]", "False"}], ",", 
    RowBox[{"SymbolicValues", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"SymbolicRanges", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"SymbolicTranslationVector", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"SymbolicRotationMatrix", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"SymbolicComponentTransformation", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"SymbolicSurfaceApproximation", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"SymbolicSurfaceValue", "\[Rule]", "\[Infinity]"}], ",", 
    RowBox[{"SymbolicSurfaceFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "#1", ",", "#2"}], "}"}], "&"}], ")"}]}], ",", 
    RowBox[{"SymbolicSurfaceNormalFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"SymbolicSurfaceBoundary", "\[Rule]", "50"}], ",", 
    RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
    RowBox[{"SymbolicOffAxis", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{
    "SurfaceIntersectionFunction", 
     "\[Rule]", "\<\"-compiled surface intersection code-\"\>"}], ",", 
    RowBox[{"BoundaryChecked", "\[Rule]", "True"}], ",", 
    RowBox[{"SurfaceStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FillStyle", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"LineStyle", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5634043008220778`*^9, 3.5634582118451347`*^9, 
  3.564487648792018*^9, 3.5661007981603937`*^9, 3.6013015555970173`*^9, 
  3.6147093228020363`*^9, 3.61472917838445*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"},
 CellLabel->"Out[280]="]
}, Open  ]],

Cell[TextData[{
 "Here is how the ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 " is defined for ",
 StyleBox["Screen", "Input"],
 "."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],

Cell[CellGroupData[{

Cell["\<\
InputForm[SurfaceIntersectionFunction/.(Surfaces/.Screen[50])]\
\>", "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"},
 CellLabel->"In[281]:="],

Cell["\<\
{CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {_Real, _Real, _Real, \
_Real, _Real, _Real}, 
  {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 4}, {3, 0, 5}, {3, 2, \
1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {1, {2, 0, 1}}, {625., {3, 0, 14}}, 
   {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {2, {2, 0, 2}}, {False, {1, 0, 3}}, \
{0., {3, 0, 13}}, {0, {2, 0, 0}}, {3, {2, 0, 3}}, 
   {{-1., 0., 0.}, {3, 1, 2}}}, {5, 4, 15, 0, 5}, {{41, 269, 3, 0, 3, 3, 0, \
6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 7, 8, 0}, {2, 0, 37}, 
   {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {19, 8, 10}, {16, 0, 4, 8}, \
{16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11, 8}, {16, 0, 5, 11}, 
   {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 11}, {34, 10, 8, 11, 3, 0}, \
{38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 10, 3, 0, 6, 3, 0, 8}, 
   {27, 6, 9, 8, 13, 1}, {2, 1, 9}, {38, 0, 0, 2, 0, 8}, {40, 56, 3, 0, 8, 3, \
0, 11}, {38, 0, 0, 3, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 12}, 
   {13, 11, 12, 11}, {27, 4, 9, 11, 14, 2}, {5, 2, 4}, {3, 2}, {5, 3, 4}, {2, \
4, 7}, {38, 0, 0, 1, 0, 11}, {38, 0, 0, 2, 0, 8}, {38, 0, 0, 3, 0, 10}, 
   {34, 11, 8, 10, 3, 1}, {42, \"CopyTensor\", 3, 1, 1, 3, 1, 3}, {3, 2}, \
{42, \"CopyTensor\", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, 
   {42, \"CopyTensor\", 3, 2, 0, 3, 2, 1}, {3, 2}, {42, \"CopyTensor\", 3, 2, \
4, 3, 2, 1}, {1}}, 
  Function[{RSx, RSy, RSz, RTx, RTy, RTz}, Block[{Compile`$398}, If[Chop[RTx] \
!= 0, 
     {(If[N[Chop[#1[[1]]]] >= 0. && #1[[2]]^2 + #1[[3]]^2 <= 625., {#1[[1]], \
#1[[2]], #1[[3]]}, {-1., 0., 0.}] & )[
       Compile`$398 = RTx^(-1); {-(RSx*Compile`$398), RSy - \
(RSx*RTy)*Compile`$398, RSz - (RSx*RTz)*Compile`$398}]}, {{-1., 0., 0.}}]]], \
Evaluate]}\
\>", "Output",
 CellChangeTimes->{3.5634043008850813`*^9, 3.563458211901319*^9, 
  3.5644876488386*^9, 3.566100798220621*^9, 3.6013015556343813`*^9, 
  3.614709322844385*^9, 3.614729178423443*^9},
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"},
 CellLabel->"Out[281]//InputForm="]
}, Open  ]],

Cell[TextData[{
 "It is ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 " that is later used during the ray-trace operation to calculate the \
surface-ray intersection point. Normally, the ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 " is compiled in order to achieve maximum efficiency. In addition, the ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 " has built-in checks to see if the ray has passed through the surface \
aperture boundary. In general, the previously discussed ",
 StyleBox["SurfaceRayIntersections", "Input"],
 ", ",
 StyleBox["SurfaceApproximation", "Input"],
 ", ",
 StyleBox["SurfacePoints", "Input"],
 " options all help specify the format of ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 ". With some custom-surface shape settings, the resulting ",
 StyleBox["SurfaceIntersectionFunction", "Input"],
 " can get enormous."
}], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4 Holograms and Diffraction Gratings", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", "PR4.4.0"}
  ],

Cell[TextData[{
 "At the most fundamental level, the basic ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " package performs geometric ray-trace calculations. Within these limits, \
you can model diffraction gratings in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " using the ",
 StyleBox["Grating", "Input"],
 " function."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 StyleBox["Grating[", "Input"],
 StyleBox["gratingfunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["label",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " and ",
 StyleBox["Grating[", "Input"],
 StyleBox["surfacefunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["gratingfunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["label",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " denote a diffractive component that splits incoming rays into multiple \
diffracted orders according to the ",
 StyleBox["gratingfunction",
  FontSlant->"Italic"],
 " parameter and the ",
 StyleBox["DiffractedOrders", "Input"],
 " option. Here, the user-named ",
 StyleBox["label",
  FontSlant->"Italic"],
 " parameter is optional and can be omitted. The ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 " parameter refers to the thickness dimension of the grating substrate. If \
no ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 " value is given, the ",
 StyleBox["Grating", "Input"],
 " component is assumed to have no substrate."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 "In ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", diffraction gratings work by treating rays as plane waves in the \
far-field. Here is a simple example that uses ",
 StyleBox["Grating", "Input"],
 "."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[
\t{RainbowOfRays[{.4,.65},NumberOfRays->11],
\tMove[Grating[{0,500,0}&,50],50],
\tBoundary[150,100]}, PlotType->TopView];\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"},
 CellLabel->"In[282]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{50., -25.}, {50., -25.}, {50., -16.66666666666667}, {
      50., -16.666666666666668`}, {50., -25.}}], 
     PolygonBox[{{50., -16.666666666666668`}, {50., -16.66666666666667}, {
      50., -8.333333333333336}, {50., -8.333333333333336}, {
      50., -16.666666666666668`}}], 
     PolygonBox[{{50., -8.333333333333336}, {50., -8.333333333333336}, {
      50., -7.105427357601002*^-15}, {50., 0.}, {50., -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {50., 0.}, {50., 8.333333333333332}, {50., 
      8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50., 8.333333333333329}, {50., 8.333333333333332}, {50., 
      16.666666666666664`}, {50., 16.666666666666664`}, {50., 
      8.333333333333329}}], 
     PolygonBox[{{50., 16.666666666666664`}, {50., 16.666666666666664`}, {50.,
       24.999999999999996`}, {50., 24.999999999999993`}, {50., 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{50., 0.}, {50., 3.061616997868383*^-15}, {50., 
        2.551347498223653*^-15}, {50., 5.102694996447305*^-16}, {50., 0.}}], 
       PolygonBox[{{50., 5.102694996447305*^-16}, {50., 
        2.551347498223653*^-15}, {50., 2.0410779985789223`*^-15}, {50., 
        1.020538999289461*^-15}, {50., 5.102694996447305*^-16}}], 
       PolygonBox[{{50., 1.020538999289461*^-15}, {50., 
        2.0410779985789223`*^-15}, {50., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50., 1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {50., 
        1.5308084989341915`*^-15}, {50., 1.0205389992894611`*^-15}, {50., 
        2.041077998578922*^-15}, {50., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{50., 2.041077998578922*^-15}, {50., 
        1.0205389992894611`*^-15}, {50., 5.102694996447307*^-16}, {50., 
        2.5513474982236525`*^-15}, {50., 2.041077998578922*^-15}}], 
       PolygonBox[{{50., 2.5513474982236525`*^-15}, {50., 
        5.102694996447308*^-16}, {50., 2.5493082627129206`*^-31}, {50., 
        3.0616169978683826`*^-15}, {50., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
         0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
         0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 50.}, {150., -50.}, {150., -50.}, {150., 50.}, {150., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -50.}, {0., -50.}, {0., -50.}, {150., -50.}, {
       150., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {150., 50.}, {150., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -50.}, {150., 50.}, {0., 50.}, {0., -50.}, {
       150., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 50.}, {150., -50.}, {0., -50.}, {0., 50.}, {150., 
       50.}}]}}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0006415912423602954, 0.04815705237305168, 0.9328335129924137],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.003425903667870378, 0.33969077100157496`, 0.665082073141361], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.009278274287297161, 0.8365141310933903, 0.11051253918530801`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.026677450015989757`, 0.9092062080919896, 0.04691122747736448],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.19711098963458812`, 0.92310724726858, 0.02826503093051297], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.9166593418862699, 0.9037836753804734, 0.019669560409165676`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.947342704361055, 0.47353532394040115`, 0.014823955533973587`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.9516065558100608, 0.04091525691657022, 0.011757322891273903`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0014301774013306678`, 0.03162733424853975, 0.936548965138893],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 20.41241452319315}}]}}, 
    {RGBColor[0.0006415912423602954, 0.04815705237305168, 0.9328335129924137],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 21.746670766177864`}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 23.092110260585343`}}]}}, 
    {RGBColor[0.003425903667870378, 0.33969077100157496`, 0.665082073141361], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 24.449562155269128`}}]}}, 
    {RGBColor[0.009278274287297161, 0.8365141310933903, 0.11051253918530801`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 25.81988897471611}}]}}, 
    {RGBColor[0.026677450015989757`, 0.9092062080919896, 0.04691122747736448],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 27.20398971756006}}]}}, 
    {RGBColor[0.19711098963458812`, 0.92310724726858, 0.02826503093051297], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 28.602803212078914`}}]}}, 
    {RGBColor[0.9166593418862699, 0.9037836753804734, 0.019669560409165676`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 30.01731175971944}}]}}, 
    {RGBColor[0.947342704361055, 0.47353532394040115`, 0.014823955533973587`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 31.44854510165755}}]}}, 
    {RGBColor[0.9516065558100608, 0.04091525691657022, 0.011757322891273903`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 32.897584747988454`}}]}}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {150., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {150., 34.36556871445292}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQGeDgwoYJDzDyRh8Cc0df6fnGnigEv+15ydF1T3
m+KUF7i+p3OKuDlO+aK0pEaxYguc8lsP5tg9uWiJU559Se9qCxNrnPK1Zzf6
B86ywSl/6opidx6LHR738d26XGSPU/7m/xl8T4occMrzNS35ckrP0QEANThO
Jg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043017187147`*^9, 3.5634582126695433`*^9, 
  3.5644876496749287`*^9, 3.566100799347187*^9, 3.601301556291686*^9, 
  3.614709323554534*^9, 3.614729179126013*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"},
 CellLabel->
  "During evaluation of \
In[282]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[StyleBox["A constant diffraction grating.", "Text"]], \
"Commentary",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 "Here, the diffraction grating is behaves as a black box and the resulting \
rays contain the amplitude, polarization, and directional behavior of \
corresponding plane waves that diffracted through the grating.  However, \
gratings in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " can only hold a single grating vector value for each surface position, \
although you can specify multiple diffraction orders. In the above example, \
we specified a three-dimensional grating vector that remained constant for \
all surface points. In the examples that follow, we will see how to specify a \
grating vector function that varies according to the surface position."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 "According to the ",
 StyleBox["GratingThickness", "Input"],
 " option, the physical grating material may also have a physical thickness \
within a separate refractive emulsion layer. Note that the total thickness of \
the ",
 StyleBox["Grating", "Input"],
 " is given by the substrate ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 " in combination with ",
 StyleBox["GratingThickness", "Input"],
 ". When ",
 StyleBox["DoubleSubstrate -> True", "Input"],
 " is specified, the grating is sandwiched between two substrates of equal \
thickness. (Note that ",
 StyleBox["DoubleSubstrate", "Input"],
 " only applies to flat-surfaced gratings)."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 "The ",
 StyleBox["gratingfunction",
  FontSlant->"Italic"],
 " parameter specifies a grating vector either as a one-dimensional value, ",
 StyleBox["Gy",
  FontSlant->"Italic"],
 ", a two-dimensional list of values, ",
 "{",
 StyleBox["Gy, Gz",
  FontSlant->"Italic"],
 "}",
 ", a three-dimensional list of values, ",
 "{",
 StyleBox["Gx, Gy, Gz",
  FontSlant->"Italic"],
 "}",
 ", or a three-dimensional function, ",
 StyleBox["Function[{s,t},{", "Input"],
 StyleBox["Gx[",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["], Gy[",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["], Gz[",
  FontSlant->"Italic"],
 StyleBox["s,t", "Input"],
 StyleBox["]",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"],
 ", in which ",
 "{",
 StyleBox["Gx, Gy, Gz",
  FontSlant->"Italic"],
 "}",
 " specify the indicated grating directions with the grating surface \
initially oriented parallel to the y-z plane. These vector quantities have \
units of spatial frequency and are given in line pairs per millimeter. A \
single number used in the grating parameter indicates a uniformly distributed \
grating vector pointing in the direction of the y axis. A list of two numbers \
designates a uniformly distributed grating vector whose direction lies within \
the surface plane."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[{
 "If you compare results with calculations by hand, please keep track of the \
correspondence of the options ",
 StyleBox["VacuumFrequency", "Input"],
 " and ",
 StyleBox["GratingMedium", "Input"],
 ". Note that ",
 StyleBox["VacuumFrequency -> False", "Input"],
 " assumes the grating function has already incorporated the refractive index \
of the grating material. However, if ",
 StyleBox["VacuumFrequency -> True", "Input"],
 " is specified, then ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " will include an additional refractive index factor, given by ",
 StyleBox["GratingMedium", "Input"],
 ", to the grating magnitude."
}], "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Gratings", "PR4.4"}],

Cell[CellGroupData[{

Cell["4.4.1 Variable Pitch Grating", "Subsection",
 CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}],

Cell[CellGroupData[{

Cell["Solve[fe==m*d+fc,m]", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"In[283]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"m", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "fc"}], "+", "fe"}], "d"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.563404301863196*^9, 3.563458212734469*^9, 
  3.5644876497984962`*^9, 3.566100799448682*^9, 3.601301556308375*^9, 
  3.614709323572483*^9, 3.614729179143016*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"Out[283]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify[-(fc-fe)/d * r +fc]", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"In[284]:="],

Cell[BoxData[
 RowBox[{"fc", "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "fc"}], "+", "fe"}], ")"}], " ", "r"}], "d"]}]], "Output",
 CellChangeTimes->{3.563404301913204*^9, 3.563458212933146*^9, 
  3.564487649839149*^9, 3.566100799506263*^9, 3.601301556348591*^9, 
  3.614709323606721*^9, 3.614729179197639*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"Out[284]="]
}, Open  ]],

Cell["\<\
centerfrequency = 2000;
edgefrequency = 1200;
aperture = 25;
With[{fc = centerfrequency, fe = edgefrequency, d = aperture},
\tgratingfunction = Function[{s,t}, {0, fc + (-fc+fe)*Abs[s]/d, t}]
];\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"In[285]:="],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
    LineOfRays[45, NumberOfRays -> 18],
\tMove[GratingMirror[gratingfunction, 50, DiffractedOrders -> {{1, \
1},{0,1}}],100],
\tBoundary[{-50, -50, -50}, {200, 50, 50}]}, PlotType -> TopView];\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"In[289]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -25.}, {100., -16.666666666666668`}, {
       100., -8.333333333333336}, {100., -3.552713678800501*^-15}, {100., 
       8.333333333333329}, {100., 16.666666666666657`}, {100., 
       24.999999999999993`}, {100., 25.}, {100., 16.666666666666668`}, {100., 
       8.333333333333336}, {100., 3.552713678800501*^-15}, {
       100., -8.333333333333329}, {100., -16.666666666666657`}, {
       100., -24.999999999999993`}, {100., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {
       100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 
       0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGRDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AA1Fv/g==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 50.}, {200., -50.}, {200., -50.}, {200., 50.}, {200., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -50.}, {-50., -50.}, {-50., -50.}, {200., -50.}, {
       200., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., 50.}, {-50., 
       50.}, {-50., -50.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 50.}, {200., 50.}, {200., 50.}, {-50., 50.}, {-50., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -50.}, {200., 50.}, {-50., 50.}, {-50., -50.}, {
       200., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 50.}, {200., -50.}, {-50., -50.}, {-50., 50.}, {200., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {100., -22.5}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -19.852941176470587`}, {100., -19.852941176470587`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -17.205882352941178`}, {100., -17.205882352941178`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -14.558823529411764`}, {100., -14.558823529411764`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -11.911764705882353`}, {100., -11.911764705882353`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -9.264705882352942}, {100., -9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -6.617647058823529}, {100., -6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -3.9705882352941195`}, {100., -3.9705882352941195`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -1.3235294117647065`}, {100., -1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 1.3235294117647065`}, {100., 1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 3.970588235294116}, {100., 3.970588235294116}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 6.617647058823529}, {100., 6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 9.264705882352942}, {100., 9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 11.911764705882355`}, {100., 11.911764705882355`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 14.558823529411761`}, {100., 14.558823529411761`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 17.205882352941174`}, {100., 17.205882352941174`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 19.852941176470587`}, {100., 19.852941176470587`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {100., 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -22.5}, {22.031772274175793`, 50.}}]}, 
     {Arrowheads[Small], ArrowBox[{{100., -22.5}, {-50., -22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -19.852941176470587`}, {33.83718260968547, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -19.852941176470587`}, {-50., -19.852941176470587`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -17.205882352941178`}, {44.50434258488103, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -17.205882352941178`}, {-50., -17.205882352941178`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -14.558823529411764`}, {54.291985156489304`, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -14.558823529411764`}, {-50., -14.558823529411764`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -11.911764705882353`}, {63.463002362495985`, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -11.911764705882353`}, {-50., -11.911764705882353`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -9.264705882352942}, {72.359268371296, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -9.264705882352942}, {-50., -9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -6.617647058823529}, {81.66153718697961, 
       50.00000000000001}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -6.617647058823529}, {-50., -6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -3.9705882352941195`}, {95.41105464554339, 
       50.00000000000001}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -3.9705882352941195`}, {-50., -3.9705882352941195`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., -1.3235294117647065`}, {-50., -1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 1.3235294117647065`}, {-50., 1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 3.970588235294116}, {96.08626731350158, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 3.970588235294116}, {-50., 3.970588235294116}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 6.617647058823529}, {85.94845057184152, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 6.617647058823529}, {-50., 6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 9.264705882352942}, {81.00128371922827, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 9.264705882352942}, {-50., 9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 11.911764705882355`}, {77.5223696244334, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 11.911764705882355`}, {-50., 11.911764705882355`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 14.558823529411761`}, {74.90744515424585, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 14.558823529411761`}, {-50., 14.558823529411761`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 17.205882352941174`}, {72.92006213660497, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 17.205882352941174`}, {-50., 17.205882352941174`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 19.852941176470587`}, {71.44552091575899, 50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 19.852941176470587`}, {-50., 19.852941176470587`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{100., 22.5}, {70.42584465572185, 50.}}]}, 
     {Arrowheads[Small], ArrowBox[{{100., 22.5}, {-50., 22.5}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQDQGRDmCqwewAjB8FAreM4fytW4DAxBDOlwMDXTj/
8iUQUIfzO9pBQAnOrwADKTj/xGEQ4IfzDXRB4Ot+NL49jH8Aot4BzTw4H2of
nH8F4h44XwbiXjh/C8Q/cD7Uv3A+NDwcdBr9rJQ4zKDinjD6ACy8WjbsOaPx
2gFDHhZ+y1jtfPoc3DDkYeH5j4X1aLyqN4Y8LHx5ioJWOu/2x5CHhTeb7xGH
f2JBGPKw8J9ySnBBWFaIAyOaPCw+Jt9T2eF3KxxDHjV+PA+gxg+cb/+/Jyy9
lTUCw35YfC3+zZa1uSYUQx4Wf5PY/DlEHUJwud8hIZyxMS8xGEMeFr+TJa9P
Ed6F6X9YfKcd8PF5ZIUpD4v/2ds1sprvBGLIw9KDTMJHTsfZmPJgCpg+AHIn
1R4=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404302928917*^9, 3.563458213732252*^9, 
  3.564487651830679*^9, 3.566100800894483*^9, 3.601301557175901*^9, 
  3.614709324488241*^9, 3.6147291800562153`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[289]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tLineOfRays[45, NumberOfRays -> 18],
\tMove[CustomGratingMirror[
      \tFunction[{s, t}, 100 - ( 100^2 - s^2 - t^2 )^(1/2)], gratingfunction, \
50, 
      \t\tDiffractedOrders -> {{1, 1},{0,1}}],100, 180],
\tBoundary[{-50, -50, -50}, {200, 50, 50}]}, PlotType -> TopView];\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.6147291812642603`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CompiledFunction", "::", "cfn"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Numerical error encountered at instruction \
\[NoBreak]\\!\\(1304\\)\[NoBreak]; proceeding with uncompiled evaluation. \\!\
\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/CompiledFunction/cfn\\\", ButtonNote -> \\\
\"CompiledFunction::cfn\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.614729181285261*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.614729181558879*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Greater", "::", "nord"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Invalid comparison with \
\[NoBreak]\\!\\(\\(\\(1402.0695591386673` \[VeryThinSpace]\\)\\) - \
\\(\\(16.33338010133696`\\\\ \[ImaginaryI]\\)\\)\\)\[NoBreak] attempted. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/nord\\\", \
ButtonNote -> \\\"Greater::nord\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.614729181561077*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SurfaceIntersectionFunction", "::", "intersection"}], 
   "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Surface-Ray intersection failed to converge to the \
prescribed accuracy \[NoBreak]\\!\\(1.`*^-9\\)\[NoBreak] after \
\[NoBreak]\\!\\(50\\)\[NoBreak] iterations.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.614729181669684*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(SurfaceIntersectionFunction :: \
intersection\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during \
this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.601301558405476*^9, 3.6147093257433567`*^9, 
  3.614729181718128*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{96.82458365518542, 25.}, {98.60132971832694, 
       16.666666666666668`}, {99.65217285917831, 8.333333333333336}, {100., 
       3.552713678800501*^-15}, {99.65217285917831, -8.333333333333329}, {
       98.60132971832694, -16.666666666666657`}, {
       96.82458365518542, -24.999999999999993`}, {96.82458365518542, -25.}, {
       98.60132971832694, -16.666666666666668`}, {
       99.65217285917831, -8.333333333333336}, {
       100., -3.552713678800501*^-15}, {99.65217285917831, 
       8.333333333333329}, {98.60132971832694, 16.666666666666657`}, {
       96.82458365518542, 24.999999999999993`}, {96.82458365518542, 25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{96.82458365518542, 0.}, {98.60132971832694, 0.}, {
       99.65217285917831, 0.}, {100., 0.}, {99.65217285917831, 0.}, {
       98.60132971832694, 0.}, {96.82458365518542, 0.}, {96.82458365518542, 
       0.}, {98.60132971832694, 0.}, {99.65217285917831, 0.}, {100., 0.}, {
       99.65217285917831, 0.}, {98.60132971832694, 0.}, {96.82458365518542, 
       0.}, {96.82458365518542, 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQPetr66+jJhEODGBgeQDG97i64f4bVQs4/9nvFtYJ
y0zh/B1pwgeq1xrC+Uxg/Zpwvvuu0rojDyXh/NPnz6+fPfn2HhjfDiLvAOP/
/Q8CGnD+doj5cP4TiP0OaO5zQHM/nO+JJv8MTf8uNPPZIO6H88PR3Hfj9u3D
W9Z9sYHxTdD89x3i/gNo7ofzH6OFnzta+MLCHwChidUU
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 50.}, {200., -50.}, {200., -50.}, {200., 50.}, {200., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -50.}, {-50., -50.}, {-50., -50.}, {200., -50.}, {
       200., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., 50.}, {-50., 
       50.}, {-50., -50.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 50.}, {200., 50.}, {200., 50.}, {-50., 50.}, {-50., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -50.}, {200., 50.}, {-50., 50.}, {-50., -50.}, {
       200., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 50.}, {200., -50.}, {-50., -50.}, {-50., 50.}, {200., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {97.43587634952539, -22.5}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -19.852941176470587`}, {
       98.0094930434986, -19.852941176470587`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -17.205882352941178`}, {
       98.508667702171, -17.205882352941178`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -14.558823529411764`}, {
       98.93452712496, -14.558823529411764`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -11.911764705882353`}, {
       99.2880146925685, -11.911764705882353`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -9.264705882352942}, {
       99.56990119967728, -9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -6.617647058823529}, {
       99.78079347953114, -6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -3.9705882352941195`}, {
       99.92114105166006, -3.9705882352941195`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -1.3235294117647065`}, {
       99.99124096587758, -1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 1.3235294117647065`}, {99.99124096587758, 
       1.3235294117647065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 3.970588235294116}, {99.92114105166006, 
       3.970588235294116}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 6.617647058823529}, {99.78079347953114, 
       6.617647058823529}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 9.264705882352942}, {99.56990119967728, 
       9.264705882352942}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 11.911764705882355`}, {99.2880146925685, 
       11.911764705882355`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 14.558823529411761`}, {98.93452712496001, 
       14.558823529411761`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 17.205882352941174`}, {98.508667702171, 
       17.205882352941174`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 19.852941176470587`}, {98.0094930434986, 
       19.852941176470587`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {97.43587634952539, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.43587634952539, -22.5}, {-21.6295139164731, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.43587634952539, -22.5}, {-50.00000000000003, 
       49.427618557600255`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.0094930434986, -19.852941176470587`}, {
       12.477241189945744`, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.0094930434986, -19.852941176470587`}, {-50., 
       42.67466008074465}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.508667702171, -17.205882352941178`}, {
       31.491451003964315`, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.508667702171, -17.205882352941178`}, {-50., 
       36.304714709565786`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.93452712496, -14.558823529411764`}, {
       44.50774534196798, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.93452712496, -14.558823529411764`}, {-50., 
       30.24465414489747}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.2880146925685, -11.911764705882353`}, {
       54.767396677648556`, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.2880146925685, -11.911764705882353`}, {-50., 
       24.432052869863817`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.56990119967728, -9.264705882352942}, {
       63.85093054663394, -49.99999999999999}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.56990119967728, -9.264705882352942}, {-50.00000000000003, 
       18.812518026576868`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.78079347953114, -6.617647058823529}, {
       72.90530859953952, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.78079347953114, -6.617647058823529}, {-50.00000000000003, 
       13.33760724440636}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.92114105166006, -3.9705882352941195`}, {
       83.75480502594509, -49.99999999999999}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.92114105166006, -3.9705882352941195`}, {-50., 
       7.963154040439974}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.99124096587758, -1.3235294117647065`}, {-50., 
       2.647870566052925}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.99124096587758, 
       1.3235294117647065`}, {-50., -2.647870566052925}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.92114105166006, 
       3.970588235294116}, {-50., -7.96315404043996}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.78079347953114, 
       6.617647058823529}, {-50.00000000000003, -13.33760724440636}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.56990119967728, 9.264705882352942}, {
       99.15547180314641, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.56990119967728, 
       9.264705882352942}, {-50.00000000000003, -18.812518026576868`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.2880146925685, 11.911764705882355`}, {
       92.56000201160808, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{99.2880146925685, 
       11.911764705882355`}, {-50., -24.432052869863817`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.93452712496001, 14.558823529411761`}, {
       88.41279402092597, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.93452712496001, 
       14.558823529411761`}, {-50., -30.24465414489746}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.508667702171, 17.205882352941174`}, {
       84.95816748774558, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.508667702171, 
       17.205882352941174`}, {-50., -36.30471470956579}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.0094930434986, 19.852941176470587`}, {
       81.84458261375883, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.0094930434986, 
       19.852941176470587`}, {-50., -42.67466008074465}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.43587634952539, 22.5}, {78.93989490892493, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.43587634952539, 
       22.5}, {-50.00000000000003, -49.427618557600255`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQ/W7yq9Sn0REODCDQYHYg5/rWjtkNEQ5RIHDL+MDx
sF9MfQsiHLZuAQITwwNpu297nd8d4SAHBroHIsN0r+ZdinC4fAkE1A9oLXno
VPkkwqGjHQSUDnA/NGv98THCoQIMpA40/5jx8/OvCIcTh0GA/8CUnZ9qC/5H
OBjogsDX/Wh8e5j6AxD1DmjmOaDZ5wBzzxWIexzSoe6VgbjXAeafLRD/OKD5
1wEtPBz+LPh8SX2h6QEwn8HzAAuUVmEvMdmzzcOBwY7va8QXDQeYPIxujf7s
FB3m6vBlztLd52vtMeT/SDg8YVB3cii2XHzmr4MbhnysVv7yhXZ2DguPv+C1
SvLGkHcyDWKZnWfh8LzqlNfrN/4O/8HAA+6+B335eowXjByufK6a/MEyCK4f
Jp9lE3z71hoth5lBe3f6fQiB64epO3Cmidf1ljxcn+iLzMPX9FjR+XD1GyDq
0c0/sKmW0eHzyQgM+6HuO+CUvFbounI4Lv8dUPw+xzxbKgxDPgoSPgd8/u6c
G2QbiiH/FxK+B4LMbZbwloXgip8Dsx/8tFHfE4zhPmj8HgAA4cwt1Q==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404305562203*^9, 3.563458215542769*^9, 
  3.564487654757275*^9, 3.566100803495216*^9, 3.601301559179982*^9, 
  3.614709326524701*^9, 3.6147291819533253`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"},
 CellLabel->"During evaluation of In[290]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Gratings", "PR4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4.2 Holographic Optical Element", "Subsection",
 CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}],

Cell[CellGroupData[{

Cell["\<\
objectpoint = {-100,0,0};
gratingpoint = {0,s,t};
objectvector = (gratingpoint - objectpoint);
objectvector = objectvector/Sqrt[Dot[objectvector,objectvector]]\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[291]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["100", 
    SqrtBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["s", "2"], "+", 
      SuperscriptBox["t", "2"]}]]], ",", 
   FractionBox["s", 
    SqrtBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["s", "2"], "+", 
      SuperscriptBox["t", "2"]}]]], ",", 
   FractionBox["t", 
    SqrtBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["s", "2"], "+", 
      SuperscriptBox["t", "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.5634043057404118`*^9, 3.563458215715385*^9, 
  3.564487654979105*^9, 3.566100803590034*^9, 3.6013015593447647`*^9, 
  3.6147093266725903`*^9, 3.614729182094157*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[294]="]
}, Open  ]],

Cell["referencevector = {1,0,0};", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[295]:="],

Cell[CellGroupData[{

Cell["\<\
gratingvector = (objectvector - referencevector)/(.532*10^-3);
gratingfunction = Apply[Function,{{s,t},gratingvector}]\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[296]:="],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1879.6992481203006`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        FractionBox["100", 
         SqrtBox[
          RowBox[{"10000", "+", 
           SuperscriptBox["s", "2"], "+", 
           SuperscriptBox["t", "2"]}]]]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{"1879.6992481203006`", " ", "s"}], 
      SqrtBox[
       RowBox[{"10000", "+", 
        SuperscriptBox["s", "2"], "+", 
        SuperscriptBox["t", "2"]}]]], ",", 
     FractionBox[
      RowBox[{"1879.6992481203006`", " ", "t"}], 
      SqrtBox[
       RowBox[{"10000", "+", 
        SuperscriptBox["s", "2"], "+", 
        SuperscriptBox["t", "2"]}]]]}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.5634043070986557`*^9, 3.563458215783321*^9, 
  3.564487662257003*^9, 3.566100803653996*^9, 3.601301559398675*^9, 
  3.6147093267258177`*^9, 3.614729182145056*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[297]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = TurboPlot[{
\tMove[LineOfRays[45, NumberOfRays -> 11], -25],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{1, 1},{0,0}}],
\tMove[Screen[100],50]},PlotType->TopView];
\t\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[298]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGZiQAeWB3Dx16wCAQM4fzUaH109ujy6fghfAScf
u37c6qFgL4aX8KvHCVZB1DvA+CvQ+OgAXR5dP4RvgJOPXT9u9f/BwALO/4fG
R1ePDk6fP79+9uTXNjC+lq7uXsbfz+D89q6uU+lJh2yw68aUR9ffAZZ/hGbe
JZzmo8uj6z8Ldu9tOP80Gh9dP7o8Or8Dq3seETD/EU79nWj+0cQano9wyneh
6b9x+/bhLeumWML4p9DiC6YfAJ4H6rc=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{0., -25.}, {0., -16.666666666666668`}, {
       0., -8.333333333333336}, {0., -3.552713678800501*^-15}, {0., 
       8.333333333333329}, {0., 16.666666666666657`}, {0., 
       24.999999999999993`}, {0., 25.}, {0., 16.666666666666668`}, {0., 
       8.333333333333336}, {0., 3.552713678800501*^-15}, {
       0., -8.333333333333329}, {0., -16.666666666666657`}, {
       0., -24.999999999999993`}, {0., -25.}}, {{0., 0.}, {0., 0.}, {0., 
       0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 
       0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}, {0., 0.}}, {{0., -25.}, {
       0., 25.}, {0., 25.}, {0., -25.}, {0., -25.}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{50., -50.}, {50., -33.333333333333336`}, {
       50., -16.66666666666667}, {50., -7.105427357601002*^-15}, {50., 
       16.666666666666657`}, {50., 33.333333333333314`}, {50., 
       49.999999999999986`}, {50., 50.}, {50., 33.333333333333336`}, {50., 
       16.66666666666667}, {50., 7.105427357601002*^-15}, {
       50., -16.666666666666657`}, {50., -33.333333333333314`}, {
       50., -49.999999999999986`}, {50., -50.}}, {{50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDui0x9UN99+oesD5z363sE5Y5grn70gTPlC9
1hHOh5hlCee77yqtO/JQE84/ff78+tmTX9vA+HYQ+QMw/t//IGAB52+HmA/n
P4HYD+dD3QfnQ2k43xNN/hma/l1o5rNB3A/nh6O578bt24e3rGPZC+OboPnv
O8T9cP52tPB5jBZ+7mjhC6MBlSNu/w==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx10TsOwjAMgOEIbtCBgY2MeItQJZg8kpUjIDFzhd6LJTfhGgyIUkJikR+w
FEXOV+fhro7nw2nunFtMY1bGO7YpT0Of3GdYXtyF1i2vLnCBe7iHd/AO/i+s
XlGvOB/u4QIXeICH1oe+9e+87BP1MU5x1YT9zO8vH3dwMc//Tjdwn3LZuNdb
ntfw2s+ol+xLeI2ov9drP60e33nF+XCx+nJ/eDAv72/d+mn90ydEoGtT
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQjQIazA6gChih8bXR+EpofCE0PjoQckDTj8bXRuMb
ofIbzKB8T4d//4HgvsMBGP8PiP/fCs4H+83B5ABY+L+Hww8wrQWX3w3mS8H5
qPbC5R3Q9DugmQ/nQ+1Hd58DAIXBUYE=
      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404312264401*^9, 3.563458216455596*^9, 
  3.564487664103842*^9, 3.5661008046511717`*^9, 3.601301560065403*^9, 
  3.614709327474099*^9, 3.614729182846018*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[298]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["{FocalPoint, SpotSize}/.FindFocus[result]", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[300]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`],
    AbsolutePointSize[2.5], PointBox[{7.105427357601002*^-15, 0.}], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.552713678800501*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.907985046680551*^-14, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.2434497875801753`*^-14, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.163513729807164*^-13, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0., 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.163513729807164*^-13, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{1.2434497875801753`*^-14, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.907985046680551*^-14, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.552713678800501*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-7.105427357601002*^-15, 0.}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{7.500000000000001*^-9, 0.}, {6.851590932319508*^-9, 
     3.0505248230685016`*^-9}, {5.018479547691438*^-9, 
     5.573586191080457*^-9}, {2.3176274578121063`*^-9, 
     7.132923872213652*^-9}, {-7.83963474507401*^-10, 
     7.458914215262051*^-9}, {-3.7500000000000005`*^-9, 
     6.495190528383291*^-9}, {-6.067627457812107*^-9, 
     4.408389392193549*^-9}, {-7.336107005503543*^-9, 
     1.559337681133195*^-9}, {-7.336107005503543*^-9, \
-1.559337681133195*^-9}, {-6.067627457812107*^-9, -4.408389392193549*^-9}, \
{-3.7500000000000005`*^-9, -6.495190528383291*^-9}, {-7.83963474507401*^-10, \
-7.458914215262051*^-9}, {2.3176274578121063`*^-9, -7.132923872213652*^-9}, {
     5.018479547691438*^-9, -5.573586191080457*^-9}, {
     6.851590932319508*^-9, -3.0505248230685016`*^-9}, {7.500000000000001*^-9,
      0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 1.1920928955078125`*^-7]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.5634043128645477`*^9, 3.56345821657915*^9, 
  3.564487664406749*^9, 3.5661008047794113`*^9, 3.601301560105884*^9, 
  3.6147093275415163`*^9, 3.6147291828912773`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[300]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "100.00000000000011`"}], ",", "0.`", ",", "0.`"}], "}"}], 
   ",", "2.384185791015625`*^-7"}], "}"}]], "Output",
 CellChangeTimes->{3.563404312875784*^9, 3.563458216604166*^9, 
  3.564487664416991*^9, 3.566100804797636*^9, 3.601301560122415*^9, 
  3.614709327552046*^9, 3.614729182908113*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[300]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
conjugateresult = AnalyzeSystem[{
\tMove[LineOfRays[45, NumberOfRays -> 11], -25],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[50],150]},PlotType->TopView];
\t\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[301]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0, -25.}, {0, -25.}, {0, -16.66666666666667}, {
       0, -16.666666666666668`}, {0, -25.}}], 
     PolygonBox[{{0, -16.666666666666668`}, {0, -16.66666666666667}, {
       0, -8.333333333333336}, {0, -8.333333333333336}, {
       0, -16.666666666666668`}}], 
     PolygonBox[{{0, -8.333333333333336}, {0, -8.333333333333336}, {
       0, -7.105427357601002*^-15}, {0, 0.}, {0, -8.333333333333336}}], 
     PolygonBox[{{0, 0.}, {0, 0.}, {0, 8.333333333333332}, {
       0, 8.333333333333329}, {0, 0.}}], 
     PolygonBox[{{0, 8.333333333333329}, {0, 8.333333333333332}, {
       0, 16.666666666666664`}, {0, 16.666666666666664`}, {
       0, 8.333333333333329}}], 
     PolygonBox[{{0, 16.666666666666664`}, {0, 16.666666666666664`}, {
       0, 24.999999999999996`}, {0, 24.999999999999993`}, {
       0, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -25.}, {0, -16.666666666666668`}, {
        0, -8.333333333333336}, {0, -3.552713678800501*^-15}, {
        0, 8.333333333333329}, {0, 16.666666666666657`}, {
        0, 24.999999999999993`}, {0, 25.}, {0, 16.666666666666668`}, {
        0, 8.333333333333336}, {0, 3.552713678800501*^-15}, {
        0, -8.333333333333329}, {0, -16.666666666666657`}, {
        0, -24.999999999999993`}, {0, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0, 0.}, {0, 3.061616997868383*^-15}, {
         0, 2.551347498223653*^-15}, {0, 5.102694996447305*^-16}, {0, 0.}}], 
       PolygonBox[{{0, 5.102694996447305*^-16}, {0, 2.551347498223653*^-15}, {
         0, 2.0410779985789223`*^-15}, {0, 1.020538999289461*^-15}, {
         0, 5.102694996447305*^-16}}], 
       PolygonBox[{{0, 1.020538999289461*^-15}, {
         0, 2.0410779985789223`*^-15}, {0, 1.530808498934192*^-15}, {
         0, 1.5308084989341915`*^-15}, {0, 1.020538999289461*^-15}}], 
       PolygonBox[{{0, 1.5308084989341915`*^-15}, {
         0, 1.5308084989341915`*^-15}, {0, 1.0205389992894611`*^-15}, {
         0, 2.041077998578922*^-15}, {0, 1.5308084989341915`*^-15}}], 
       PolygonBox[{{0, 2.041077998578922*^-15}, {
         0, 1.0205389992894611`*^-15}, {0, 5.102694996447307*^-16}, {
         0, 2.5513474982236525`*^-15}, {0, 2.041077998578922*^-15}}], 
       PolygonBox[{{0, 2.5513474982236525`*^-15}, {
         0, 5.102694996447308*^-16}, {0, 2.5493082627129206`*^-31}, {
         0, 3.0616169978683826`*^-15}, {0, 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {
          0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {
          0, 0.}, {0, 0.}}]}}}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{0, -25}, {0, 25}, {0, 25}, {0, -25}, {0, -25}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
      "]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-25., -22.5}, {0., -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{-25., -18.}, {0., -18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -13.5}, {0., -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -9.}, {0., -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -4.5}, {0., -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 4.5}, {0., 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 9.}, {0., 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 13.5}, {0., 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 18.}, {0., 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 22.5}, {0., 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -22.5}, {150., 11.249999999999993`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {150., 8.999999999999993}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -13.5}, {150., 6.75}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -9.}, {149.99999999999997`, 4.4999999999999964`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -4.5}, {150., 2.2499999999999982`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {150., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 4.5}, {150., -2.2499999999999982`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 9.}, {149.99999999999997`, -4.4999999999999964`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 13.5}, {150., -6.75}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {150., -8.999999999999993}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 22.5}, {150., -11.249999999999993`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQjQIazA6gChih8bXR+EpofCE0PjoQckDTj8bXRuMb
ofIbzCD8A0kOf/4DQb0aKv+/IpwP0SDtABbeD5MXRFPPiKYeChDyB9D0H0Az
/wCqekVUfr3aAQCkKlcc
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"G\"\>", {0., -29.4}, {0., 0.}], 
    InsetBox["\<\"S\"\>", {150., -29.4}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404313785932*^9, 3.563458217268841*^9, 
  3.564487665124398*^9, 3.566100805625654*^9, 3.60130156063518*^9, 
  3.614709328071862*^9, 3.614729183443377*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[301]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["{FocalPoint, SpotSize}/.FindFocus[conjugateresult]", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[303]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`],
    AbsolutePointSize[2.5], PointBox[{1.7763568394002505`*^-15, 0.}], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{3.552713678800501*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.440892098500626*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-8.881784197001252*^-16, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{4.440892098500626*^-16, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0., 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.440892098500626*^-16, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{8.881784197001252*^-16, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-4.440892098500626*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-3.552713678800501*^-15, 0.}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-1.7763568394002505`*^-15, 0.}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{7.500000000000001*^-9, 0.}, {6.851590932319508*^-9, 
     3.0505248230685016`*^-9}, {5.018479547691438*^-9, 
     5.573586191080457*^-9}, {2.3176274578121063`*^-9, 
     7.132923872213652*^-9}, {-7.83963474507401*^-10, 
     7.458914215262051*^-9}, {-3.7500000000000005`*^-9, 
     6.495190528383291*^-9}, {-6.067627457812107*^-9, 
     4.408389392193549*^-9}, {-7.336107005503543*^-9, 
     1.559337681133195*^-9}, {-7.336107005503543*^-9, \
-1.559337681133195*^-9}, {-6.067627457812107*^-9, -4.408389392193549*^-9}, \
{-3.7500000000000005`*^-9, -6.495190528383291*^-9}, {-7.83963474507401*^-10, \
-7.458914215262051*^-9}, {2.3176274578121063`*^-9, -7.132923872213652*^-9}, {
     5.018479547691438*^-9, -5.573586191080457*^-9}, {
     6.851590932319508*^-9, -3.0505248230685016`*^-9}, {7.500000000000001*^-9,
      0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 5.960464477539063*^-8]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.5634043140291433`*^9, 3.563458217334949*^9, 
  3.5644876655167847`*^9, 3.566100805719315*^9, 3.601301560820444*^9, 
  3.614709328236455*^9, 3.614729183739423*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[303]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"100.00000000000004`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   "1.1920928955078125`*^-7"}], "}"}]], "Output",
 CellChangeTimes->{3.5634043140441637`*^9, 3.563458217345911*^9, 
  3.564487665531419*^9, 3.5661008057337217`*^9, 3.60130156083477*^9, 
  3.614709328247643*^9, 3.614729183752421*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[303]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
colorshiftedresult = AnalyzeSystem[{
\tMove[LineOfRays[45, NumberOfRays -> 11, WaveLength->.633], -25],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[{50,50}],150]},PlotType->TopView];
\t\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[304]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0, -25.}, {0, -25.}, {0, -16.66666666666667}, {
       0, -16.666666666666668`}, {0, -25.}}], 
     PolygonBox[{{0, -16.666666666666668`}, {0, -16.66666666666667}, {
       0, -8.333333333333336}, {0, -8.333333333333336}, {
       0, -16.666666666666668`}}], 
     PolygonBox[{{0, -8.333333333333336}, {0, -8.333333333333336}, {
       0, -7.105427357601002*^-15}, {0, 0.}, {0, -8.333333333333336}}], 
     PolygonBox[{{0, 0.}, {0, 0.}, {0, 8.333333333333332}, {
       0, 8.333333333333329}, {0, 0.}}], 
     PolygonBox[{{0, 8.333333333333329}, {0, 8.333333333333332}, {
       0, 16.666666666666664`}, {0, 16.666666666666664`}, {
       0, 8.333333333333329}}], 
     PolygonBox[{{0, 16.666666666666664`}, {0, 16.666666666666664`}, {
       0, 24.999999999999996`}, {0, 24.999999999999993`}, {
       0, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -25.}, {0, -16.666666666666668`}, {
        0, -8.333333333333336}, {0, -3.552713678800501*^-15}, {
        0, 8.333333333333329}, {0, 16.666666666666657`}, {
        0, 24.999999999999993`}, {0, 25.}, {0, 16.666666666666668`}, {
        0, 8.333333333333336}, {0, 3.552713678800501*^-15}, {
        0, -8.333333333333329}, {0, -16.666666666666657`}, {
        0, -24.999999999999993`}, {0, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0, 0.}, {0, 3.061616997868383*^-15}, {
         0, 2.551347498223653*^-15}, {0, 5.102694996447305*^-16}, {0, 0.}}], 
       PolygonBox[{{0, 5.102694996447305*^-16}, {0, 2.551347498223653*^-15}, {
         0, 2.0410779985789223`*^-15}, {0, 1.020538999289461*^-15}, {
         0, 5.102694996447305*^-16}}], 
       PolygonBox[{{0, 1.020538999289461*^-15}, {
         0, 2.0410779985789223`*^-15}, {0, 1.530808498934192*^-15}, {
         0, 1.5308084989341915`*^-15}, {0, 1.020538999289461*^-15}}], 
       PolygonBox[{{0, 1.5308084989341915`*^-15}, {
         0, 1.5308084989341915`*^-15}, {0, 1.0205389992894611`*^-15}, {
         0, 2.041077998578922*^-15}, {0, 1.5308084989341915`*^-15}}], 
       PolygonBox[{{0, 2.041077998578922*^-15}, {
         0, 1.0205389992894611`*^-15}, {0, 5.102694996447307*^-16}, {
         0, 2.5513474982236525`*^-15}, {0, 2.041077998578922*^-15}}], 
       PolygonBox[{{0, 2.5513474982236525`*^-15}, {
         0, 5.102694996447308*^-16}, {0, 2.5493082627129206`*^-31}, {
         0, 3.0616169978683826`*^-15}, {0, 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {
          0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {0, 0.}, {
          0, 0.}, {0, 0.}}]}}}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{0, -25}, {0, 25}, {0, 25}, {0, -25}, {0, -25}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     LineBox[{{150., -25.}, {150., 25.}, {150., 25.}, {150., -25.}, {
      150., -25.}}]}, 
    {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{-25., -22.5}, {0., -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{-25., -18.}, {0., -18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -13.5}, {0., -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -9.}, {0., -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., -4.5}, {0., -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 4.5}, {0., 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 9.}, {0., 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 13.5}, {0., 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 18.}, {0., 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{-25., 22.5}, {0., 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -22.5}, {150., 18.086810326945105`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {150., 14.34451948007466}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.5}, {150., 10.686257543544535`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -9.}, {150., 7.090084541495447}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -4.5}, {150.00000000000003`, 3.534867863029035}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {150., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 4.5}, {150.00000000000003`, -3.534867863029035}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 9.}, {150., -7.090084541495447}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 13.5}, {150., -10.686257543544535`}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {150., -14.34451948007466}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 22.5}, {150., -18.086810326945105`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQjQIazA6gChih8bXR+EpofCE0PjoQckDTj8bXRuMb
ofIbzCD8A0kOevqzjS3FjOD8O03lt1M26MD5OQEiarHxqnB+SYqdvH2MjAMj
lM+gGH02w50HLg+zAk3+AJr+A2jmw/lQ++F8qPsOAACr/DRQ
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"G\"\>", {0., -29.4}, {0., 0.}], 
    InsetBox["\<\"S\"\>", {150., -29.4}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404314839294*^9, 3.5634582178163357`*^9, 
  3.5644876663195753`*^9, 3.566100806713522*^9, 3.601301561320389*^9, 
  3.6147093287736397`*^9, 3.614729184287552*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[304]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["{FocalPoint, SpotSize}/.FindFocus[colorshiftedresult]", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[306]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
   AbsolutePointSize[2.5], PointBox[{0.0689741222920297, 0.}], 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014289438774923724`, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05082732005284818, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.052839611753880966`, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03207745531189188, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0., 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03207745531189188, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.052839611753880966`, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05082732005284818, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014289438774923724`, 0.}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0689741222920297, 0.}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{0.10346118343804456`, 0.}, {0.09451649417215349, 
     0.042081454440239814`}, {0.06922904440850382, 0.0768866431097503}, {
     0.03197126394049962, 0.0983974326923605}, {-0.010814638512631597`, 
     0.10289441224984867`}, {-0.05173059171902228, 
     0.08960001316294841}, {-0.0837018556595219, 
     0.06081295780960886}, {-0.10120030834900344`, 
     0.021510789582610202`}, {-0.10120030834900344`, -0.021510789582610202`}, \
{-0.0837018556595219, -0.06081295780960886}, {-0.05173059171902228, \
-0.08960001316294841}, {-0.010814638512631597`, -0.10289441224984867`}, {
     0.03197126394049962, -0.0983974326923605}, {
     0.06922904440850382, -0.0768866431097503}, {
     0.09451649417215349, -0.042081454440239814`}, {0.10346118343804456`, 
     0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 0.02272965801825772]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.563404315054772*^9, 3.563458218009181*^9, 
  3.564487666671978*^9, 3.5661008068428507`*^9, 3.6013015613853617`*^9, 
  3.614709328837627*^9, 3.614729184352141*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[306]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"83.4100066271114`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
   "0.04545931603651544`"}], "}"}]], "Output",
 CellChangeTimes->{3.563404315067692*^9, 3.5634582180186577`*^9, 
  3.56448766668454*^9, 3.566100806856783*^9, 3.6013015613935947`*^9, 
  3.614709328844215*^9, 3.614729184359169*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[306]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["?FindIntensity", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[307]:="],

Cell[BoxData[
 StyleBox["\<\"FindIntensity[system, options] and FindIntensity[system, \
absolutekernelsize, options] calculates the intensity function for each \
optical surface that gets reported from the ray trace of the system.\\n \
\\nFor its input, FindIntensity works best with either an untraced, raw, \
optical system or a previously calculated result of FindIntensity. However, \
when necessary, FindIntensity can also work with externally generated trace \
results. FindIntensity works equally well for surfaces that either are close \
to a focal plane or far from any focus. If a light sheet light source is used \
(ie. WedgeOfRays or LineOfRays), then a one-dimensional intensity function is \
automatically calculated. If a volume-filling light source is used (ie. \
PointOfRays, GaussianBeam, or GridOfRays), then the intensity calculations \
are automatically carried out for each reported surface in two-dimensions.\\n \
\\nFindIntensity uses the KernelScale and SmoothKernelSize options to specify \
a Gaussian smoothing kernel that gets convolved with the intensity data. In \
effect, this determines the maximum resolution of the FindIntensity \
calculation. As a second argument to FindIntensity, the absolutekernelsize \
parameter can be directly specified in FindIntensity in order manually set \
the SmoothKernelSize to an absolute value. For example, absolutekernelsize \
can be manually set by the user to a diffraction-limited spot-size of the \
systen in order to incorporate diffraction behavior together with the \
geometric ray-trace data. Otherwise, FindItensity automatically determines a \
SmoothKernelSize based on the surface area and number of available sample \
points. In that case, the kernel size has no relation to the diffraction \
performance of the system.\\n \\nFindIntensity uses the IntensityScale option \
to specify spatial scaling of the system.\\n \\nFindIntensity uses the Energy \
option to manually specify the total integrated energy at the surface. With \
the default Energy-> Automatic setting, the integrated energy is \
automatically determined from the ray-trace information. However, Energy -> \
number is used to manually specify a constant value for the total integrated \
energy. See also: IntensitySetting, KernelScale, SmoothKernelSize, and \
SmoothKernelRange.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6147291846108427`*^9},
 CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindIntensity[{
\tMove[LineOfRays[45, NumberOfRays -> 1024, WaveLength->.633], -25],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[{.25,.25}],83.3673]}, SequentialTrace->True, \
SmoothKernelSize->3, ReportedSurfaces -> {1,2}]\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[308]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.1319648093841721`"}]}], "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 1., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 1024, Optica`Optica`SmoothKernelSize -> 
    0.1319648093841721}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404318096394*^9, 3.563458220779015*^9, 
  3.564487671135879*^9, 3.566100810920477*^9, 3.601301564131393*^9, 
  3.614709332094058*^9, 3.6147291876232853`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[308]:="],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwtlXk81Nsbx02SpZtEhKGiSNPQ0Djtvo9CmTY3l6Jys5W0kOVSU7qEQm5U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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], 
     LineBox[{1, 112, 90, 129, 76, 121, 101, 138, 68, 117, 96, 134, 83, 125, 
      107, 142, 60, 115, 94, 132, 80, 123, 105, 140, 72, 119, 98, 136, 87, 
      127, 109, 144, 31, 64, 2, 32, 3, 33, 4, 34, 5, 35, 6, 36, 7, 37, 8, 38, 
      9, 39, 10, 40, 11, 41, 12, 42, 13, 43, 14, 44, 15, 45, 16, 46, 17, 47, 
      18, 48, 19, 49, 20, 50, 21, 51, 22, 52, 23, 53, 24, 61, 54, 92, 78, 103,
       70, 85, 65, 81, 74, 99, 88, 110, 25, 55, 26, 113, 91, 130, 77, 102, 69,
       84, 62, 73, 56, 66, 27, 57, 28, 58, 29, 63, 59, 114, 93, 131, 79, 122, 
      104, 139, 71, 118, 97, 135, 86, 126, 108, 143, 67, 116, 95, 133, 82, 
      124, 106, 141, 75, 120, 100, 137, 89, 128, 111, 145, 30},
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.65, 1, 0.1], 
     Hue[8.614425839326145*^-10, 1, 0.9999999988072333], 
     Hue[3.8719027983802334`*^-11, 1, 0.9999999999463891], 
     Hue[1.3006679067117943`*^-9, 1, 0.9999999981990751], 
     Hue[6.044661438053822*^-10, 1, 0.9999999991630469], 
     Hue[1.0663472327365753`*^-9, 1, 0.9999999985235193], 
     Hue[2.5794312241700368`*^-9, 1, 0.9999999964284799], 
     Hue[3.284260086111601*^-9, 1, 0.999999995452563], 
     Hue[4.001898479266686*^-9, 1, 0.9999999944589099], 
     Hue[5.23495391480111*^-9, 1, 0.9999999927516023], 
     Hue[2.6036557354558454`*^-9, 1, 0.9999999963949382], 
     Hue[3.759244249224025*^-9, 1, 0.9999999947948927], 
     Hue[3.0417744989463813`*^-9, 1, 0.9999999957883122], 
     Hue[8.535693263311828*^-10, 1, 0.9999999988181348], 
     Hue[6.079386993818048*^-9, 1, 0.9999999915823872], 
     Hue[7.682343650117218*^-10, 1, 0.9999999989362909], 
     Hue[5.783660772529231*^-9, 1, 0.9999999919918543], 
     Hue[6.189487811170125*^-9, 1, 0.9999999914299399], 
     Hue[5.739439701279991*^-9, 1, 0.9999999920530834], 
     Hue[4.098279493547352*^-10, 1, 0.9999999994325459], 
     Hue[6.194251556124186*^-9, 1, 0.9999999914233441], 
     Hue[2.8961680831329772`*^-9, 1, 0.9999999959899212], 
     Hue[4.9512752786640135`*^-9, 1, 0.9999999931443881], 
     Hue[1.4603124265377687`*^-9, 1, 0.999999997978029], 
     Hue[7.594344375583262*^-9, 1, 0.9999999894847539], 
     Hue[7.632621978892473*^-9, 1, 0.9999999894317542], 
     Hue[5.766563004883096*^-9, 1, 0.9999999920155281], 
     Hue[4.163279720970081*^-10, 1, 0.9999999994235459], 
     Hue[1.3383444352754736`*^-9, 1, 0.9999999981469078], 
     Hue[0.6499999999999999, 1, 0.10000000000000012`], 
     Hue[3.417381044812373*^-9, 1, 0.9999999952682416], 
     Hue[5.897885957395488*^-9, 1, 0.9999999918336964], 
     Hue[5.337305930552816*^-9, 1, 0.999999992609884], 
     Hue[9.182129501184022*^-10, 1, 0.9999999987286282], 
     Hue[3.2890172807498175`*^-9, 1, 0.9999999954459761], 
     Hue[6.697298271518548*^-11, 1, 0.9999999999072682], 
     Hue[1.7633672300121361`*^-12, 1, 0.9999999999975584], 
     Hue[0., 1, 1.], 
     Hue[7.269164936651862*^-9, 1, 0.9999999899350024], 
     Hue[6.107959693579801*^-10, 1, 0.9999999991542825], 
     Hue[1.4987233676322376`*^-11, 1, 0.9999999999792484], 
     Hue[3.3894812512258454`*^-9, 1, 0.9999999953068721], 
     Hue[1.89323945409825*^-9, 1, 0.9999999973785915], 
     Hue[4.1006523732178835`*^-9, 1, 0.9999999943221736], 
     Hue[1.1325956839058904`*^-9, 1, 0.9999999984317907], 
     Hue[4.973075284908646*^-10, 1, 0.9999999993114204], 
     Hue[7.875927687805984*^-9, 1, 0.9999999890948694], 
     Hue[1.1107981201519124`*^-10, 1, 0.9999999998461973], 
     Hue[6.711992073249462*^-10, 1, 0.9999999990706472], 
     Hue[7.402612967055688*^-10, 1, 0.9999999989750229], 
     Hue[1.1589074144779943`*^-10, 1, 0.9999999998395359], 
     Hue[6.591987622428519*^-9, 1, 0.9999999908726326], 
     Hue[1.01312425115907*^-9, 1, 0.9999999985972126], 
     Hue[4.808955456070407*^-10, 1, 0.9999999993341446], 
     Hue[8.100375814557026*^-9, 1, 0.999999988784095], 
     Hue[1.6209145137224823`*^-11, 1, 0.9999999999775565], 
     Hue[3.628892297768971*^-9, 1, 0.9999999949753798], 
     Hue[6.516865713734887*^-9, 1, 0.9999999909766475], 
     Hue[5.754285936632186*^-10, 1, 0.9999999992032528], 
     Hue[0.04653499916561643, 1, 0.9355669242322234], 
     Hue[6.510220029731784*^-9, 1, 0.9999999909858491], 
     Hue[1.9462302880413063`*^-9, 1, 0.9999999973052196], 
     Hue[3.002509352256766*^-11, 1, 0.9999999999584268], 
     Hue[1.7510971561662814`*^-9, 1, 0.9999999975754039], 
     Hue[1.0603322664337611`*^-9, 1, 0.9999999985318476], 
     Hue[1.154064288577672*^-9, 1, 0.9999999984020648], 
     Hue[0.03722173389401651, 1, 0.9484622146082848], 
     Hue[0.46844312518111275`, 1, 0.3513864420569208], 
     Hue[4.6130943509581357`*^-10, 1, 0.9999999993612639], 
     Hue[7.038868155007094*^-9, 1, 0.9999999902538749], 
     Hue[0.00007661246318169113, 1, 0.9998939212048253], 
     Hue[0.00014768578551460632`, 1, 0.9997955119892874], 
     Hue[3.8665847190699765`*^-9, 1, 0.9999999946462673], 
     Hue[6.105925764998688*^-10, 1, 0.9999999991545641], 
     Hue[0.4556566754680397, 1, 0.36909075704425287`], 
     Hue[0.616843801182634, 1, 0.14590858297789136`], 
     Hue[9.209699669554539*^-10, 1, 0.9999999987248108], 
     Hue[2.6745505810055192`*^-9, 1, 0.999999996296776], 
     Hue[7.399047154965643*^-7, 1, 0.9999989755165477], 
     Hue[0.004204920772583498, 1, 0.9941778020071921], 
     Hue[7.282174863121327*^-12, 1, 0.9999999999899171], 
     Hue[0.19436532511773652`, 1, 0.730878780606211], 
     Hue[0.21413299474227482`, 1, 0.703508161126081], 
     Hue[5.951821369087895*^-9, 1, 0.9999999917590165], 
     Hue[3.9736502976950305`*^-9, 1, 0.9999999944980227], 
     Hue[0.002791185327743917, 1, 0.9961352818538931], 
     Hue[1.941476692857158*^-6, 1, 0.9999973118015022], 
     Hue[2.9872180284939986`*^-9, 1, 0.999999995863852], 
     Hue[0.6147193900427812, 1, 0.1488500753253799], 
     Hue[0.6414207343370719, 1, 0.11187898322559278`], 
     Hue[3.3345670669149285`*^-9, 1, 0.9999999953829071], 
     Hue[1.3411991517386923`*^-9, 1, 0.999999998142955], 
     Hue[4.60762709098006*^-8, 1, 0.9999999362020865], 
     Hue[0.015692981445272203`, 1, 0.9782712564603924], 
     Hue[0.09502741424989869, 1, 0.868423580269371], 
     Hue[0.34335009243628195`, 1, 0.5245921797036097], 
     Hue[0.000525719009218828, 1, 0.9992720813718509], 
     Hue[0.00001920219573980919, 1, 0.9999734123443603], 
     Hue[1.5572324540968907`*^-9, 1, 0.999999997843832], 
     Hue[0.5559672552659221, 1, 0.23019918501641556`], 
     Hue[0.5622876879225109, 1, 0.22144781672267722`], 
     Hue[1.1412537581634297`*^-11, 1, 0.9999999999841981], 
     Hue[4.5443552254553765`*^-9, 1, 0.9999999937078158], 
     Hue[8.60513942524399*^-6, 1, 0.9999880851915651], 
     Hue[0.0008891998415959668, 1, 0.9987688002193287], 
     Hue[0.32479883836203005`, 1, 0.5502785314987276], 
     Hue[0.11069735280769111`, 1, 0.8467267422662739], 
     Hue[0.01152116944446513, 1, 0.9840476115384329], 
     Hue[1.4769425649152623`*^-7, 1, 0.9999997955002603], 
     Hue[4.968466749133427*^-9, 1, 0.9999999931205845], 
     Hue[0.6410110264019571, 1, 0.11244627113575173`], 
     Hue[0.6469588463683001, 1, 0.10421082810543068`], 
     Hue[2.2514679010043892`*^-10, 1, 0.9999999996882584], 
     Hue[5.189609852962462*^-9, 1, 0.9999999928143863], 
     Hue[0.027797190357037427`, 1, 0.9615115825825636], 
     Hue[0.06120418481400691, 1, 0.9152557441036827], 
     Hue[0.40843707866207224`, 1, 0.43447173723713084`], 
     Hue[0.00020728673367731432`, 1, 0.9997129875995237], 
     Hue[0.000054906812832933305`, 1, 0.9999239751822313], 
     Hue[0.5109018806806418, 1, 0.2925973959806498], 
     Hue[0.5941643738838212, 1, 0.1773108669300939], 
     Hue[2.619547671556255*^-6, 1, 0.9999963729339932], 
     Hue[0.001992396923342299, 1, 0.9972412965676799], 
     Hue[0.257297348471969, 1, 0.6437421328849661], 
     Hue[0.15782717323297346`, 1, 0.7814700678312675], 
     Hue[0.005849915965490338, 1, 0.9919001163554748], 
     Hue[5.620284995178082*^-7, 1, 0.999999221806693], 
     Hue[0.630944476733023, 1, 0.12638457067735281`], 
     Hue[0.6319676956457997, 1, 0.12496780602889271`], 
     Hue[1.7371442062596998`*^-9, 1, 0.9999999975947235], 
     Hue[2.049603393672328*^-7, 1, 0.9999997162087609], 
     Hue[0.008364165576177585, 1, 0.9884188476637541], 
     Hue[0.1395746168830967, 1, 0.8067428381618661], 
     Hue[0.27718126079490846`, 1, 0.6162105619762807], 
     Hue[0.0012505021722059029`, 1, 0.9982685354538687], 
     Hue[6.304383762145704*^-6, 1, 0.9999912708532523], 
     Hue[0.5902971468843932, 1, 0.18266548892930184`], 
     Hue[0.5202941509079908, 1, 0.2795927141273974], 
     Hue[0.000026538285961774655`, 1, 0.999963254680976], 
     Hue[0.00037357543735505594`, 1, 0.9994827417021237], 
     Hue[0.3924119543326812, 1, 0.4566603709239798], 
     Hue[0.07372287039717462, 1, 0.8979221794500659], 
     Hue[0.021341359765458923`, 1, 0.9704504249401338], 
     Hue[3.725068420390443*^-8, 1, 0.9999999484221296], 
     Hue[0.6468437719887734, 1, 0.10437016186169842`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563404318096394*^9, 3.563458220779015*^9, 
  3.564487671135879*^9, 3.566100810920477*^9, 3.601301564131393*^9, 
  3.614709332094058*^9, 3.61472918762803*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[308]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.0015669581305804425`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 2., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 1024, Optica`Optica`SmoothKernelSize -> 
    0.0015669581305804425`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404318096394*^9, 3.563458220779015*^9, 
  3.564487671135879*^9, 3.566100810920477*^9, 3.601301564131393*^9, 
  3.614709332094058*^9, 3.614729188444474*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[308]:="],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwdWXc81d//VyojlaRIyAqZKRkp51VKGSErKylblD0Td9iy93avebmjQkhO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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1nfcTgUYBuDPyCi7ouzPnhmZRXYoI6sUkpWUXWTvsipkK5TshtE0GjLL
CKWy9ywa9u56fv1xue/nOT7Oe95zDoltuzXumiQhIaFZ0oSEyE/98gAVzBvM
2eQUcx3Z25xMDjJXlZllUTlfNpCVHD+rv0Alc/yBeeUsudSYUX9Dz0cp/SOZ
y367fJyj+kTudOw1c444F32RfNr+muzFI3ZpZSH5gawnv3Y8s5xgriULy7Jy
qWwi43Q+00tQ0bDRnF1ONb+qJ9cH61mobD4nO5Ekztex2XKZfSb9TT0/pfWP
ZW77HXEeHNNz2c/QJ+l36a/rOXnGfF32Jh3fxPXkc70km/Q+3OFnhpjvi89q
/ku+SFKWmxPZqdfnuD6ZFtyIz0J6vo3PxBdxrflB70sV/ja/RDI+Nefh5/gO
OaFPoWWcB1/G5+RHvR9Vycsvdg05qU+lFSn4yu5BNuv9qUY+dtk9wSl9Gs+S
khV2ZdiiD6A6+fnVrhGn9em0JhUr43tlqz6QGhTgN7vGnNFn8BypWWVXjm36
IGpSkN/jvuAP/R3axH3Harvy/KQPphaF2G3XlD/1d2kb3y1fx7PCdn0Ij1KY
PXbNOKvPpB1p+CbuP3boQ6lNEfbaPck5fRbtScu3dg+xUx9GHf4xdyY5n5mL
sk9/ir/02XQgHd/ZPczP+nDq8q+5C3fwubkY+/Xm/K2/F+fqHhwZzyfPm2/K
PmTgO3MWx9/Wi8T9Zl4Tzzy/6Dkcm6aPiHtCH6rfTzF9gXzM/ryMF09luxTx
PMn34j0gv3D8bvmWuaYsEPeU/CS+Y1nc8QPxTojPZv7HnFu+E3+2fD+unRxl
ri5zx3MvF8c9KDs6fkvvS0YK282Va+zv0yfqReOzmr+Pc2SX/lrcs44PM2eN
czVfkN1IyZfmBzgYzzr/6nN4gdvmfmTie3NG1sbzza/669Tjork7qfjKXIJD
egvO6x/QiUyss6vCb/pI6lOSw3YtuaDP5cW4nqy3q8rv+igaUIojdq24qM/j
Je5hg101duujaUhpjto9yyV9Pp25l41xvdmjj+EJHuSYXWsu6wvoQmY22dVg
rz6WRpThuN1zXNEX0jXuN36I+4F9+hs0piwn7NpwVV9Et/ge+dGuFvv1N2lC
OU7ateWavpju3M9mu0c5oL9FU8pzyq4d1/UP6UFWttjV5qA+jmZcMvcgNSvM
FTitt+eG/hE9ycZWuzoc0sfzJJfNPbmTleaKnNE7cFP/OJ5r9+BocyIvm+Mf
t/763aw1ZmebXpfD+gRS+T3DzdniPWG+Ej/LXRSIZ0auiu9dH6cXpIy+JN4/
9n/Ee4BbeqL9u/onenp9jJ6HV8xJzAP0e1gX19U8Ka6rLCbLyWWyqczh+E/x
zMbfYT5izimnx7nH+8WcWo6I+1Bml8XlQtlQNnf8avy9pIlztpsjV8f9qI/X
C8U7wvyn7MhtPY9jM/UlegZ9bNyHMq8sKT+UjWSvuLRyYDxn8l5ZRM6T9eX6
uA/k5LgP4r0ky8vlSf7//1ROx/8DF5gRDQ==
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.6499999999999507, 1, 0.1000000000000682], 
     Hue[0.008631660682717479, 1, 0.9880484698239296], 
     Hue[0.3411024441442826, 1, 0.5277043081079165], 
     Hue[0.41118708738161014`, 1, 0.4306640328562322], 
     Hue[0.4443594476621555, 1, 0.38473307246778476`], 
     Hue[0.46598514141674685`, 1, 0.35478980419219674`], 
     Hue[0.4794742338289497, 1, 0.3361125993137619], 
     Hue[0.48987922258879857`, 1, 0.3217056918001251], 
     Hue[0.49733488145125904`, 1, 0.3113824718367183], 
     Hue[0.5025648988248637, 1, 0.3041409093194196], 
     Hue[0.5068309600262305, 1, 0.2982340553482963], 
     Hue[0.5097690513267186, 1, 0.2941659289322358], 
     Hue[0.5118367914133037, 1, 0.2913029041969641], 
     Hue[0.5132887824214429, 1, 0.2892924551087713], 
     Hue[0.5139676722455698, 1, 0.2883524538138264], 
     Hue[0.5140026089510753, 1, 0.2883040799138957], 
     Hue[0.5133287696623525, 1, 0.2892370881598195], 
     Hue[0.5120385000371563, 1, 0.29102361533316823`], 
     Hue[0.5098462122510407, 1, 0.2940590907293284], 
     Hue[0.5069459147377225, 1, 0.2980748872862304], 
     Hue[0.5026780352104829, 1, 0.30398425893933145`], 
     Hue[0.4970407984587504, 1, 0.3117896636724995], 
     Hue[0.4900507392424497, 1, 0.32146820720276204`], 
     Hue[0.4797779089611737, 1, 0.33569212605375953`], 
     Hue[0.4663131975615611, 1, 0.35433557260706927`], 
     Hue[0.4469672789597507, 1, 0.3811222291326529], 
     Hue[0.41219339843976094`, 1, 0.429270679083408], 
     Hue[0.3444735939379111, 1, 0.5230365622398154], 
     Hue[0.01729344392613963, 1, 0.9760552314868836], 
     Hue[0.65, 1, 0.1], 
     Hue[0.39300302140569543`, 1, 0.4558419703613448], 
     Hue[0.2530918798365331, 1, 0.649565089457108], 
     Hue[0.38390896668458585`, 1, 0.4684337384367273], 
     Hue[0.4300957158038956, 1, 0.40448285504076], 
     Hue[0.45640382818458747`, 1, 0.3680562378982636], 
     Hue[0.4733183000517881, 1, 0.3446361999282934], 
     Hue[0.4851069830588256, 1, 0.3283134080723954], 
     Hue[0.4938856199854357, 1, 0.31615837232785826`], 
     Hue[0.5001269825691879, 1, 0.30751648567343226`], 
     Hue[0.5048585699113393, 1, 0.30096505704583787`], 
     Hue[0.5084133146587163, 1, 0.29604310278023904`], 
     Hue[0.5108959414150447, 1, 0.2926056195791689], 
     Hue[0.5126601442609915, 1, 0.2901628771770887], 
     Hue[0.5137070538871978, 1, 0.2887133100023415], 
     Hue[0.5140753980223882, 1, 0.2882032950459241], 
     Hue[0.5137546670013229, 1, 0.2886473841520145], 
     Hue[0.5127665052311815, 1, 0.290015608141441], 
     Hue[0.5110517298922235, 1, 0.29238991245692136`], 
     Hue[0.5085080660322284, 1, 0.29591190857076066`], 
     Hue[0.5049743365652114, 1, 0.3008047647558612], 
     Hue[0.5000643860651114, 1, 0.30760315775599967`], 
     Hue[0.4937900098316187, 1, 0.3162907556177587], 
     Hue[0.4853358186542222, 1, 0.3279965587864616], 
     Hue[0.4736347036279991, 1, 0.34419810266892437`], 
     Hue[0.45764025880392817`, 1, 0.36634425704071494`], 
     Hue[0.4321632134198536, 1, 0.40162016603404893`], 
     Hue[0.3856694013071687, 1, 0.46599621357468957`], 
     Hue[0.26071691642748684`, 1, 0.6390073464850182], 
     Hue[0.3760557081339889, 1, 0.4793074810452461], 
     Hue[0.5993606655039979, 1, 0.17011600160984908`], 
     Hue[0.14522935955306637`, 1, 0.798913194464985], 
     Hue[0.36521973841680383`, 1, 0.49431113142288696`], 
     Hue[0.421363471651246, 1, 0.41657365463673635`], 
     Hue[0.45074690605554646`, 1, 0.37588889930770486`], 
     Hue[0.4698183633777694, 1, 0.3494822660923193], 
     Hue[0.48241056510054436`, 1, 0.3320469098607848], 
     Hue[0.491958457040392, 1, 0.31882675179022646`], 
     Hue[0.4987783274193394, 1, 0.3093838543424532], 
     Hue[0.5037544118276145, 1, 0.30249389131561066`], 
     Hue[0.5076517754193327, 1, 0.29709754172707786`], 
     Hue[0.5103565569158988, 1, 0.2933524596549094], 
     Hue[0.5122734297769793, 1, 0.2906983280011055], 
     Hue[0.5135178773985598, 1, 0.2889752466789172], 
     Hue[0.5140441330268604, 1, 0.2882465850397318], 
     Hue[0.5139006366828067, 1, 0.28844527228534467`], 
     Hue[0.5130679164888075, 1, 0.2895982694770358], 
     Hue[0.5115715100999538, 1, 0.2916702167846793], 
     Hue[0.5092039250569316, 1, 0.29494841145963313`], 
     Hue[0.5059983129909037, 1, 0.29938695124336423`], 
     Hue[0.5014187853670307, 1, 0.30572783564564976`], 
     Hue[0.4954715533646343, 1, 0.3139624645720449], 
     Hue[0.4877875773983039, 1, 0.3246018159100408], 
     Hue[0.47683576328194516`, 1, 0.33976586622499905`], 
     Hue[0.46218928905682755`, 1, 0.3600455997674695], 
     Hue[0.4400695798408826, 1, 0.3906728894510857], 
     Hue[0.40018927245159885`, 1, 0.4458917766054785], 
     Hue[0.3109969662248112, 1, 0.5693888159964152], 
     Hue[0.07060722354569526, 1, 0.9022361520136527], 
     Hue[0.08940689505109556, 1, 0.8762058376215599], 
     Hue[0.3064815813816538, 1, 0.5756408873177101], 
     Hue[0.39886911540669, 1, 0.44771968635996773`], 
     Hue[0.4376875598063924, 1, 0.3939710710373029], 
     Hue[0.4614516883063506, 1, 0.36106689311428386`], 
     Hue[0.4765256239367891, 1, 0.34019528993367665`], 
     Hue[0.487589248441497, 1, 0.3248764252348504], 
     Hue[0.4956739193764569, 1, 0.3136822654787521], 
     Hue[0.5013872623656188, 1, 0.305771482878374], 
     Hue[0.5058825480900392, 1, 0.29954724110609965`], 
     Hue[0.5091182655556272, 1, 0.29506701692297777`], 
     Hue[0.511388858290768, 1, 0.2919231192897058], 
     Hue[0.5129982269263232, 1, 0.2896947627173986], 
     Hue[0.5138568492443483, 1, 0.2885059010462871], 
     Hue[0.5140615716495079, 1, 0.28822243925452756`], 
     Hue[0.5135642454091889, 1, 0.28891104481804625`], 
     Hue[0.5124236937007133, 1, 0.29049027026055085`], 
     Hue[0.5104773234536872, 1, 0.2931852444487407], 
     Hue[0.5077562744320432, 1, 0.2969528507864017], 
     Hue[0.5038693299486363, 1, 0.3023347739172727], 
     Hue[0.4986077347488248, 1, 0.3096200595785503], 
     Hue[0.49198667707971033`, 1, 0.3187876778896319], 
     Hue[0.48267424758563615`, 1, 0.33168181103527306`], 
     Hue[0.4701407730219706, 1, 0.34903585273881], 
     Hue[0.4525956815314677, 1, 0.37332905634104485`], 
     Hue[0.422991362051545, 1, 0.4143196525440147], 
     Hue[0.36762558248323507`, 1, 0.4909799627155207], 
     Hue[0.16035284734257793`, 1, 0.7779729806025845], 
     Hue[0.5962409885966837, 1, 0.17443555425074556`], 
     Hue[0.6363115412476542, 1, 0.11895325058017109`], 
     Hue[0.0685068768711029, 1, 0.9051443243323191], 
     Hue[0.3539708394198714, 1, 0.5098865300340242], 
     Hue[0.41647911042468266`, 1, 0.4233366163350548], 
     Hue[0.4476533934355872, 1, 0.3801722244738024], 
     Hue[0.4679462723652026, 1, 0.3520743921097196], 
     Hue[0.48097417067548587`, 1, 0.3340357636800966], 
     Hue[0.4909387501086542, 1, 0.3202386536957097], 
     Hue[0.49806888600751553`, 1, 0.3103661578357477], 
     Hue[0.5031706717517279, 1, 0.30330214680529977`], 
     Hue[0.5072489562105813, 1, 0.29765529140073366`], 
     Hue[0.5100689289890702, 1, 0.2937507137074413], 
     Hue[0.5120614374086259, 1, 0.29099185589574883`], 
     Hue[0.5134083548778525, 1, 0.28912689324605045`], 
     Hue[0.5140115643180199, 1, 0.2882916801750495], 
     Hue[0.5139570998465275, 1, 0.28836709252019266`], 
     Hue[0.5132033681440683, 1, 0.28941072103129006`], 
     Hue[0.5118115004040839, 1, 0.2913379225174224], 
     Hue[0.5095316268640282, 1, 0.29449467049596095`], 
     Hue[0.5064813888429273, 1, 0.29871807698671615`], 
     Hue[0.5020598943859161, 1, 0.3048401462348854], 
     Hue[0.4962696616063115, 1, 0.3128573916220303], 
     Hue[0.48894153438068844`, 1, 0.3230040293190468], 
     Hue[0.4783373015426565, 1, 0.3376868132486295], 
     Hue[0.4643005516154751, 1, 0.35712231314780374`], 
     Hue[0.44363142448081055`, 1, 0.38574110456503163`], 
     Hue[0.40645927774028323`, 1, 0.4372102308211463], 
     Hue[0.3290459983992664, 1, 0.5443978483702465], 
     Hue[0.0034441103730811218`, 1, 0.9952312317911184], 
     Hue[0.23331314673803139`, 1, 0.676951027593495], 
     Hue[0.28360847710945747`, 1, 0.6073113393869051], 
     Hue[0.39177520207571415`, 1, 0.45754202789516507`], 
     Hue[0.434018844610488, 1, 0.39905083053932433`], 
     Hue[0.4589974426402542, 1, 0.36446507942118656`], 
     Hue[0.4749562795010561, 1, 0.34236822838315306`], 
     Hue[0.4863734346625327, 1, 0.32655985969803175`], 
     Hue[0.4947963694080756, 1, 0.31489733466574155`], 
     Hue[0.5007677964494137, 1, 0.3066292049161965], 
     Hue[0.5053802839871588, 1, 0.3002426837100878], 
     Hue[0.5087727067260719, 1, 0.29554548299466976`], 
     Hue[0.5111481146669794, 1, 0.29225645661495164`], 
     Hue[0.5128351927473693, 1, 0.2899205023497964], 
     Hue[0.5137868481912008, 1, 0.2886028255814143], 
     Hue[0.5140741184117765, 1, 0.28820506681446334`], 
     Hue[0.5136650484239367, 1, 0.28877147141301074`], 
     Hue[0.5126003342171618, 1, 0.29024569108392984`], 
     Hue[0.5107714808148899, 1, 0.2927779496409218], 
     Hue[0.5081393204754955, 1, 0.2964224793416217], 
     Hue[0.5044322773267702, 1, 0.3015553083167798], 
     Hue[0.499349320708152, 1, 0.30859324825025103`], 
     Hue[0.4929042112605926, 1, 0.3175172459468718], 
     Hue[0.4840327215968028, 1, 0.3298008470198115], 
     Hue[0.4719267177194495, 1, 0.34656300623460845`], 
     Hue[0.45518495458177616`, 1, 0.3697439090406176], 
     Hue[0.4277550218160592, 1, 0.407723815946995], 
     Hue[0.3771714333094461, 1, 0.4777626308023055], 
     Hue[0.21986972517066455`, 1, 0.6955649959175414], 
     Hue[0.5123467094653767, 1, 0.29059686381717065`], 
     Hue[0.5211993474394916, 1, 0.2783393650837809], 
     Hue[0.2087793345221719, 1, 0.7109209214308388], 
     Hue[0.3751206537217063, 1, 0.48060217176994513`], 
     Hue[0.42588875694158823`, 1, 0.4103078750039547], 
     Hue[0.5124729451347021, 1, 0.2904220759673356], 
     Hue[0.5136174173705665, 1, 0.2888374221022926], 
     Hue[0.5140654038251276, 1, 0.2882171331652081], 
     Hue[0.5138331757873733, 1, 0.2885386796790217], 
     Hue[0.5129223297410859, 1, 0.2897998511277273], 
     Hue[0.4362566033079124, 1, 0.39595239541981364`], 
     Hue[0.3932958055353149, 1, 0.4554365769511025], 
     Hue[0.28919441988023586`, 1, 0.5995769570889042], 
     Hue[0.2110016033313578, 1, 0.7078439338488892], 
     Hue[0.009531569972692555, 1, 0.986802441576272], 
     Hue[0.3251786887601785, 1, 0.549752584793599], 
     Hue[0.40530848475374365`, 1, 0.43880363649481646`], 
     Hue[0.5139171110179993, 1, 0.28842246166738555`], 
     Hue[0.5140377406942753, 1, 0.2882554359617726], 
     Hue[0.5134521799544653, 1, 0.28906621237074026`], 
     Hue[0.3568121978483322, 1, 0.5059523414407708], 
     Hue[0.08458032502186641, 1, 0.8828887807389542], 
     Hue[0.6356758115455341, 1, 0.11983349170618357`], 
     Hue[0.6450384179312573, 1, 0.10686988286441307`], 
     Hue[0.03359607627695704, 1, 0.9534823559242133], 
     Hue[0.34775701734842535`, 1, 0.518490283671411], 
     Hue[0.4138874509377585, 1, 0.4269250679323344], 
     Hue[0.446032727673337, 1, 0.38241622322153346`], 
     Hue[0.4669772231429448, 1, 0.3534161525713072], 
     Hue[0.48023238588302164`, 1, 0.3350628503158162], 
     Hue[0.49041408358879024`, 1, 0.32096511503090586`], 
     Hue[0.497705010561154, 1, 0.3108699853768637], 
     Hue[0.5028705854723123, 1, 0.3037176508844906], 
     Hue[0.5070418777589681, 1, 0.29794201541065957`], 
     Hue[0.5099205390979089, 1, 0.2939561766336646], 
     Hue[0.511950705469314, 1, 0.29114517704248843`], 
     Hue[0.5133498345066573, 1, 0.28920792145232077`], 
     Hue[0.513991034365259, 1, 0.2883201062634876], 
     Hue[0.5139812211209356, 1, 0.2883336938325507], 
     Hue[0.5132673170637271, 1, 0.289322176373301], 
     Hue[0.5119266092104874, 1, 0.2911785410931713], 
     Hue[0.5096905411235224, 1, 0.2942746353674306], 
     Hue[0.5067159402375504, 1, 0.29839331351723797`], 
     Hue[0.5023717873087139, 1, 0.304408294495627], 
     Hue[0.4966585392782995, 1, 0.31231894561466234`], 
     Hue[0.4895015895377642, 1, 0.32222856833232655`], 
     Hue[0.47906500310719036`, 1, 0.33667922646696724`], 
     Hue[0.4653187628084101, 1, 0.3557124822652784], 
     Hue[0.4453261709469837, 1, 0.3833945325349457], 
     Hue[0.40938854537196095`, 1, 0.43315432179266944`], 
     Hue[0.337050632270007, 1, 0.5333145091646058], 
     Hue[0.0016140478055113316`, 1, 0.9977651645769844], 
     Hue[0.31461498332396537`, 1, 0.5643792538591249], 
     Hue[0.2696360942905002, 1, 0.6266577155977691], 
     Hue[0.38794712962357225`, 1, 0.4628424359058231], 
     Hue[0.43209081472427224`, 1, 0.40172041038177697`], 
     Hue[0.4577187984316856, 1, 0.36623550986382003`], 
     Hue[0.47414613752524115`, 1, 0.3434899634265892], 
     Hue[0.48574671460475927`, 1, 0.32742762593187186`], 
     Hue[0.49434523509226, 1, 0.31552198217994765`], 
     Hue[0.5004501042521777, 1, 0.3070690864200616], 
     Hue[0.5051218910042077, 1, 0.3006004586095586], 
     Hue[0.5085947575934733, 1, 0.2957918741013447], 
     Hue[0.5110234661446331, 1, 0.29242904687666194`], 
     Hue[0.512749179382328, 1, 0.29003959777831506`], 
     Hue[0.5137481779382427, 1, 0.28865636900858704`], 
     Hue[0.51407616731696, 1, 0.2882022298688245], 
     Hue[0.5137112474580471, 1, 0.28870750351962715`], 
     Hue[0.5126847177987911, 1, 0.290128852278597], 
     Hue[0.5109133265372034, 1, 0.29258154787156443`], 
     Hue[0.5083254612438399, 1, 0.2961647459700677], 
     Hue[0.5047058782127758, 1, 0.30117647632077194`], 
     Hue[0.49971010762593016`, 1, 0.30809369713332757`], 
     Hue[0.4933509956917003, 1, 0.3168986213499534], 
     Hue[0.48469100341464266`, 1, 0.32888937988741784`], 
     Hue[0.47279014121472307`, 1, 0.3453674967796143], 
     Hue[0.45642867603955684`, 1, 0.36802183317599824`], 
     Hue[0.430000845628266, 1, 0.4046142137454778], 
     Hue[0.3815394037578763, 1, 0.4717146717198636], 
     Hue[0.24228629264284157`, 1, 0.6645266717252962], 
     Hue[0.45016891323671626`, 1, 0.37668919705685444`], 
     Hue[0.5664296425908716, 1, 0.2157128025664855], 
     Hue[0.17947468939404715`, 1, 0.7514965839159347], 
     Hue[0.3703229578541135, 1, 0.48724513527891977`], 
     Hue[0.42366828798322986`, 1, 0.4133823704847587], 
     Hue[0.512374738252007, 1, 0.29055805472799034`], 
     Hue[0.5135688875437916, 1, 0.28890461724705774`], 
     Hue[0.5140561759687793, 1, 0.2882299101970749], 
     Hue[0.5138682847952363, 1, 0.288490067206596], 
     Hue[0.512996396937305, 1, 0.28969729654834686`], 
     Hue[0.4381962061132486, 1, 0.39326679153550204`], 
     Hue[0.3968267248346203, 1, 0.45054761176744895`], 
     Hue[0.30068865749131873`, 1, 0.5836618588581741], 
     Hue[0.1340336381922056, 1, 0.8144149625031], 
     Hue[0.039488199603913365`, 1, 0.9453240313176585], 
     Hue[0.31623250725716845`, 1, 0.5621396053362283], 
     Hue[0.4021642739839565, 1, 0.4431571590991372], 
     Hue[0.5138881975675547, 1, 0.28846249567569354`], 
     Hue[0.5140510685976495, 1, 0.2882369819417162], 
     Hue[0.513509626729587, 1, 0.2889866706821103], 
     Hue[0.36239271280980356`, 1, 0.49822547457104127`], 
     Hue[0.12360307372675672`, 1, 0.828857282532183], 
     Hue[0.6203206092222473, 1, 0.1410945410768884], 
     Hue[0.6218626853427278, 1, 0.138959358756223], 
     Hue[0.10727871502578645`, 1, 0.8514602407335266], 
     Hue[0.3597801094155249, 1, 0.5018429254246579], 
     Hue[0.5140292601384399, 1, 0.2882671782698525], 
     Hue[0.5139302400595432, 1, 0.2884042829944787], 
     Hue[0.32039443604339213`, 1, 0.5563769347091494], 
     Hue[0.026217697325400025`, 1, 0.9636985729340616], 
     Hue[0.15592347241986693`, 1, 0.7841059612647997], 
     Hue[0.2957193053251254, 1, 0.5905425003190571], 
     Hue[0.5138230683167221, 1, 0.28855267463838485`], 
     Hue[0.5140692573655059, 1, 0.28821179749391496`], 
     Hue[0.37254219271234706`, 1, 0.48417234855213487`], 
     Hue[0.19266427103990857`, 1, 0.7332340862524342], 
     Hue[0.5608847221738127, 1, 0.2233903846824132], 
     Hue[0.4629974431064109, 1, 0.35892661723727726`], 
     Hue[0.23310461760358525`, 1, 0.6772397602411896], 
     Hue[0.5140718105064597, 1, 0.28820826237567126`], 
     Hue[0.2760802057003562, 1, 0.6177350997995068], 
     Hue[0.29420410080654835`, 1, 0.5926404758063177], 
     Hue[0., 1, 1.], 
     Hue[0.5139436018775285, 1, 0.28838578201572973`], 
     Hue[0.5140215889849076, 1, 0.28827779986705104`], 
     Hue[0.04726208360870199, 1, 0.9345601919264127], 
     Hue[0.6448538270395652, 1, 0.10712547025290983`], 
     Hue[0.6478867130632673, 1, 0.10292608960470682`], 
     Hue[0.019459854306446367`, 1, 0.9730555863449204], 
     Hue[0.34448715026683563`, 1, 0.5230177919382276], 
     Hue[0.4125513173047306, 1, 0.4287750991165269], 
     Hue[0.4452028281872674, 1, 0.3835653148176298], 
     Hue[0.46648411054943645`, 1, 0.3540989238546265], 
     Hue[0.4798553905317431, 1, 0.335584843879125], 
     Hue[0.4901479398056455, 1, 0.32133362180756775`], 
     Hue[0.49752073451977213`, 1, 0.31112513681877707`], 
     Hue[0.502718447330845, 1, 0.30392830369575297`], 
     Hue[0.5069369003870395, 1, 0.2980873686948683], 
     Hue[0.509845181840596, 1, 0.29406051745148254`], 
     Hue[0.5118941482822067, 1, 0.2912234869938677], 
     Hue[0.5133196210831168, 1, 0.2892497554233767], 
     Hue[0.513979706950032, 1, 0.28833579037687873`], 
     Hue[0.5139922564264884, 1, 0.2883184141787084], 
     Hue[0.5132983544242834, 1, 0.2892792015663769], 
     Hue[0.511982955690785, 1, 0.29110052288968236`], 
     Hue[0.5097687808849953, 1, 0.2941663033900066], 
     Hue[0.5068314971569847, 1, 0.29823331162879035`], 
     Hue[0.5025256103135542, 1, 0.3041953087966172], 
     Hue[0.49685049176095825`, 1, 0.3120531652540578], 
     Hue[0.4897775109545568, 1, 0.3218465232936906], 
     Hue[0.47942327699668646`, 1, 0.33618315492766493`], 
     Hue[0.46581890192408915`, 1, 0.35501998195126117`], 
     Hue[0.4461532644914935, 1, 0.3822493260887013], 
     Hue[0.41080598002122987`, 1, 0.4311917199706048], 
     Hue[0.3408314520420533, 1, 0.5280795279417724], 
     Hue[0.007560387590092588, 1, 0.9895317710291026], 
     Hue[0.3545587348815615, 1, 0.5090725209332226], 
     Hue[0.26173715015146864`, 1, 0.6375947151748896], 
     Hue[0.38595548951517683`, 1, 0.4656000914405244], 
     Hue[0.43110187888824625`, 1, 0.40308970615473594`], 
     Hue[0.45706595063698485`, 1, 0.36713945296417483`], 
     Hue[0.47373446226438376`, 1, 0.3440599753262379], 
     Hue[0.485428496256165, 1, 0.3278682359530023], 
     Hue[0.494116500040682, 1, 0.3158386922513634], 
     Hue[0.5002892254123086, 1, 0.3072918417368036], 
     Hue[0.5049908500102406, 1, 0.3007818999858208], 
     Hue[0.5085044752599074, 1, 0.29591688040935904`], 
     Hue[0.5109600663949231, 1, 0.2925168311454911], 
     Hue[0.5127050443073584, 1, 0.2901007078821191], 
     Hue[0.5137279228274281, 1, 0.28868441454663807`], 
     Hue[0.5140761353639516, 1, 0.2882022741114517], 
     Hue[0.5137333050421538, 1, 0.2886769622493256], 
     Hue[0.5127259376275944, 1, 0.2900717786694847], 
     Hue[0.5109829580615585, 1, 0.2924851349916884], 
     Hue[0.5084172031013412, 1, 0.29603771878275836`], 
     Hue[0.5048407472115264, 1, 0.3009897346301943], 
     Hue[0.49988805331049824`, 1, 0.3078473108008486], 
     Hue[0.49357146379658434`, 1, 0.316593357820114], 
     Hue[0.4850150700041927, 1, 0.3284406723018871], 
     Hue[0.47321474424831467`, 1, 0.34477958488694893`], 
     Hue[0.45703840411043917`, 1, 0.36717759430862273`], 
     Hue[0.43109214735031876`, 1, 0.40310318059186634`], 
     Hue[0.3836327968115259, 1, 0.4688161274917334], 
     Hue[0.2519418923975859, 1, 0.6511573797571887], 
     Hue[0.4144002996736071, 1, 0.4262149696826979], 
     Hue[0.584335277661921, 1, 0.19092038477580184`], 
     Hue[0.16292657703883812`, 1, 0.7744093548693011], 
     Hue[0.3678114066051019, 1, 0.49072266777755125`], 
     Hue[0.4225267423306409, 1, 0.41496297215757416`], 
     Hue[0.5123244730510517, 1, 0.2906276526985439], 
     Hue[0.5135436925491452, 1, 0.2889395026242605], 
     Hue[0.5140505084937093, 1, 0.28823775747024877`], 
     Hue[0.5138848052038986, 1, 0.28846719279460203`], 
     Hue[0.5130324738824221, 1, 0.2896473438551078], 
     Hue[0.4391409459249913, 1, 0.39195869025770447`], 
     Hue[0.39852821063321453`, 1, 0.4481917083540107], 
     Hue[0.3059706977536901, 1, 0.5763482646487368], 
     Hue[0.10022569195112963`, 1, 0.8612259649907436], 
     Hue[0.06209744610375878, 1, 0.9140189207794109], 
     Hue[0.31146807094064405`, 1, 0.5687365171591083], 
     Hue[0.40053629963640514`, 1, 0.445411277426516], 
     Hue[0.5138728274567489, 1, 0.2884837773675785], 
     Hue[0.5140566723688299, 1, 0.28822922287392794`], 
     Hue[0.5135372896053527, 1, 0.2889483682387425], 
     Hue[0.3650505887482465, 1, 0.49454533865627415`], 
     Hue[0.14243780952316587`, 1, 0.8027784175833087], 
     Hue[0.6095372644756121, 1, 0.15602532611069103`], 
     Hue[0.6299420216005884, 1, 0.1277725854761083], 
     Hue[0.08774346471726369, 1, 0.8785090488530195], 
     Hue[0.35692383176841197`, 1, 0.5057977713975834], 
     Hue[0.5140207649924593, 1, 0.28827894077967176`], 
     Hue[0.5139440126017514, 1, 0.2883852133206519], 
     Hue[0.32480616679446667`, 1, 0.5502683844384307], 
     Hue[0.012096748388922274`, 1, 0.9832506560768769], 
     Hue[0.1936811278509048, 1, 0.731826130667978], 
     Hue[0.28985996623301974`, 1, 0.598655431369665], 
     Hue[0.5138052630080445, 1, 0.2885773281427076], 
     Hue[0.514072041071303, 1, 0.28820794313204207`], 
     Hue[0.37489103657556894`, 1, 0.48092010320305845`], 
     Hue[0.20690219884234323`, 1, 0.7135200323721401], 
     Hue[0.5383354869620068, 1, 0.2546124026679906], 
     Hue[0.4936958822392804, 1, 0.31642108613022724`], 
     Hue[0.2215345756891528, 1, 0.6932598182765577], 
     Hue[0.5140689609247798, 1, 0.28821220795030494`], 
     Hue[0.28287433346591534`, 1, 0.608327845970271], 
     Hue[0.252309892043632, 1, 0.6506478417857403], 
     Hue[0.002296930775448569, 1, 0.9968196343109174], 
     Hue[0.5139306593030198, 1, 0.288403702503511], 
     Hue[0.5140300181272548, 1, 0.28826612874687796`], 
     Hue[0.06538852665231498, 1, 0.9094620400198716], 
     Hue[0.6408906458030285, 1, 0.11261295196503762`], 
     Hue[0.6412568366797197, 1, 0.11210591844346512`], 
     Hue[0.050212264510408944`, 1, 0.9304753260625107], 
     Hue[0.5140016523460559, 1, 0.2883054044439226], 
     Hue[0.00007171279394391217, 1, 0.9999007053622315], 
     Hue[0.276894792788384, 1, 0.6166072099853145], 
     Hue[0.514075496717338, 1, 0.2882031583913781], 
     Hue[0.23163271725979612`, 1, 0.6792777761018208], 
     Hue[0.4829134291720908, 1, 0.3313506365309513], 
     Hue[0.5454304176316049, 1, 0.24478865251008555`], 
     Hue[0.19476883483328283`, 1, 0.7303200748462237], 
     Hue[0.5140611435721838, 1, 0.2882230319769763], 
     Hue[0.29511263889182554`, 1, 0.5913824999959338], 
     Hue[0.17125616650450748`, 1, 0.762876077147605], 
     Hue[0.021916284789427865`, 1, 0.9696543749069461], 
     Hue[0.5140447590729791, 1, 0.2882457182066443], 
     Hue[0.6289234628399626, 1, 0.1291828976062057], 
     Hue[0.6117712145325602, 1, 0.15293216449337815`], 
     Hue[0.5140370485839638, 1, 0.2882563942683579], 
     Hue[0.045795142590402405`, 1, 0.9365913410286737], 
     Hue[0.12090390872011858`, 1, 0.8325945879259896], 
     Hue[0.5140657661714421, 1, 0.2882166314549264], 
     Hue[0.5801157707999095, 1, 0.19676277889243304`], 
     Hue[0.42931515726704234`, 1, 0.4055636283994799], 
     Hue[0.24358650109746693`, 1, 0.662726383095815], 
     Hue[0.514073953790436, 1, 0.28820529475170414`], 
     Hue[0.26872692996800157`, 1, 0.627916558505844], 
     Hue[0.0022748898613479396`, 1, 0.996850152499672], 
     Hue[0.030958025864093464`, 1, 0.9571350411112552], 
     Hue[0.6478180016189611, 1, 0.10302122852759234`], 
     Hue[0.6490241044763948, 1, 0.10135123995576108`], 
     Hue[0.013580709998720408`, 1, 0.9811959400017717], 
     Hue[0.3428094492290646, 1, 0.5253407626059106], 
     Hue[0.4118727743144928, 1, 0.4297146201799331], 
     Hue[0.44478284784490474`, 1, 0.3841468260609012], 
     Hue[0.4662353660161266, 1, 0.35444333936228634`], 
     Hue[0.4796653324099629, 1, 0.335848001278513], 
     Hue[0.49001390518980315`, 1, 0.32151920819873414`], 
     Hue[0.4974280070404634, 1, 0.3112535287132045], 
     Hue[0.5026418506119343, 1, 0.3040343606911678], 
     Hue[0.5068840505613028, 1, 0.2981605453766577], 
     Hue[0.5098072137333878, 1, 0.2941130886768476], 
     Hue[0.5118655687681113, 1, 0.291263058628769], 
     Hue[0.5133042802754985, 1, 0.2892709965416176], 
     Hue[0.5139737780944726, 1, 0.2883439995614994], 
     Hue[0.5139975174135407, 1, 0.28831112973509754`], 
     Hue[0.5133136398048785, 1, 0.28925803719324517`], 
     Hue[0.512010827808624, 1, 0.29106193072652065`], 
     Hue[0.5098075970740522, 1, 0.29411255789746615`], 
     Hue[0.5068888465435091, 1, 0.29815390478591064`], 
     Hue[0.5026019978306872, 1, 0.3040895414652024], 
     Hue[0.4969458479157277, 1, 0.3119211336551463], 
     Hue[0.48991446122703747`, 1, 0.32165689983948664`], 
     Hue[0.4796010436303819, 1, 0.3359370165117789], 
     Hue[0.4660667725315264, 1, 0.35467677649480966`], 
     Hue[0.44656188453734735`, 1, 0.3816835444867499], 
     Hue[0.41150337599495246`, 1, 0.43022609477621965`], 
     Hue[0.34266946917418695`, 1, 0.5255345811434334], 
     Hue[0.011995185198085068`, 1, 0.9833912820334206], 
     Hue[0.3740108491137147, 1, 0.4821388243040874], 
     Hue[0.2575147849175659, 1, 0.6434410670372164], 
     Hue[0.384939244868032, 1, 0.4670071994134942], 
     Hue[0.4306009827817033, 1, 0.40378325460994935`], 
     Hue[0.4567360598703961, 1, 0.3675962247948362], 
     Hue[0.47352694627363595`, 1, 0.344347305159581], 
     Hue[0.4852681536954455, 1, 0.3280902487293832], 
     Hue[0.49400133081650927`, 1, 0.31599815733098724`], 
     Hue[0.5002082774625266, 1, 0.3074039235134247], 
     Hue[0.5049248649418894, 1, 0.3008732639266148], 
     Hue[0.5084590045507571, 1, 0.29597983985279785`], 
     Hue[0.5109280949765262, 1, 0.29256109926327145`], 
     Hue[0.5126826867864367, 1, 0.2901316644495492], 
     Hue[0.5137175657596886, 1, 0.2886987551019696], 
     Hue[0.514075854490083, 1, 0.2882026630137314], 
     Hue[0.5137440732132407, 1, 0.2886620524739745], 
     Hue[0.5127463021957269, 1, 0.29004358157514737`], 
     Hue[0.5110174499126403, 1, 0.2924373770440365], 
     Hue[0.5084627434895944, 1, 0.2959746628605616], 
     Hue[0.5049077013361603, 1, 0.30089702891916276`], 
     Hue[0.4999764190173361, 1, 0.3077249582836885], 
     Hue[0.49368097472399186`, 1, 0.316441727305242], 
     Hue[0.4851758560634175, 1, 0.3282180454506527], 
     Hue[0.4734253005296681, 1, 0.34448804542045963`], 
     Hue[0.4573403051129879, 1, 0.36675957753586297`], 
     Hue[0.4316301710679163, 1, 0.4023582246751929], 
     Hue[0.38465803837467005`, 1, 0.4673965622504569], 
     Hue[0.2564321351790186, 1, 0.6449401205213589], 
     Hue[0.39551572037451255`, 1, 0.45236284871221344`], 
     Hue[0.5921923719416516, 1, 0.1800413311577132], 
     Hue[0.1542116558404391, 1, 0.7864761688363151], 
     Hue[0.36652582947252454`, 1, 0.4925026976534276], 
     Hue[0.4219478654610944, 1, 0.41576449397694626`], 
     Hue[0.512299049680129, 1, 0.29066285428905225`], 
     Hue[0.513530863214718, 1, 0.2889572663180828], 
     Hue[0.5140474107562237, 1, 0.2882420466452287], 
     Hue[0.513892808347615, 1, 0.28845611151868694`], 
     Hue[0.513050276942888, 1, 0.2896226934636935], 
     Hue[0.43960724836960086`, 1, 0.3913130407190143], 
     Hue[0.3993636948627518, 1, 0.44703488403618985`], 
     Hue[0.3085137633929711, 1, 0.5728270968405016], 
     Hue[0.08485009375241781, 1, 0.8825152548043447], 
     Hue[0.07519278972204846, 1, 0.8958869065387022], 
     Hue[0.3090042054729398, 1, 0.5721480231913142], 
     Hue[0.3997077048059, 1, 0.4465585625764462], 
     Hue[0.5138649142241445, 1, 0.2884947341511846], 
     Hue[0.5140592095531815, 1, 0.28822570984944107`], 
     Hue[0.5135508538954687, 1, 0.2889295869139665], 
     Hue[0.36634819911093386`, 1, 0.4927486473848609], 
     Hue[0.15152605101434558`, 1, 0.7901946985955215], 
     Hue[0.6032236268499935, 1, 0.16476728590000905`], 
     Hue[0.633322149965701, 1, 0.12309240773979867`], 
     Hue[0.07805006832865469, 1, 0.8919306746218627], 
     Hue[0.3554597017107072, 1, 0.5078250284005593], 
     Hue[0.5140162513824511, 1, 0.28828519039352923`], 
     Hue[0.5139506439033766, 1, 0.28837603151840163`], 
     Hue[0.32694684743547076`, 1, 0.5473043650893482], 
     Hue[0.007094168013062285, 1, 0.9901773058280675], 
     Hue[0.2133187242955601, 1, 0.7046356125138399], 
     Hue[0.2867873214448898, 1, 0.602909862614768], 
     Hue[0.5137961315332867, 1, 0.2885899717231415], 
     Hue[0.5140731664569507, 1, 0.2882063849057607], 
     Hue[0.37603958914973756`, 1, 0.47932979963882494`], 
     Hue[0.2135414996424817, 1, 0.7043271543411792], 
     Hue[0.5257743579313647, 1, 0.27200473517195656`], 
     Hue[0.5078548015570531, 1, 0.29681642861331115`], 
     Hue[0.21531027959316262`, 1, 0.7018780744094671], 
     Hue[0.5140672690008813, 1, 0.28821455061416434`], 
     Hue[0.2860888173722116, 1, 0.6038770221000147], 
     Hue[0.2315216624548186, 1, 0.6794315442933281], 
     Hue[0.005279866799499544, 1, 0.9926894152006929], 
     Hue[0.5139239607177777, 1, 0.2884129774676925], 
     Hue[0.5140339674947911, 1, 0.28826066039182763`], 
     Hue[0.07489531976037156, 1, 0.8962987880241009], 
     Hue[0.6384568258074018, 1, 0.11598285657436672`], 
     Hue[0.6432779493161761, 1, 0.10930745479298704`], 
     Hue[0.04164539293661984, 1, 0.9423371482416032], 
     Hue[0.5139964313270715, 1, 0.28831263354713177`], 
     Hue[0.0002574857565068589, 1, 0.9996434812602213], 
     Hue[0.27333924166162205`, 1, 0.6215302807762156], 
     Hue[0.5140759203529219, 1, 0.2882025718190313], 
     Hue[0.2370914657681812, 1, 0.6717195089363645], 
     Hue[0.4669408680912272, 1, 0.3534664903352239], 
     Hue[0.5563274008265534, 1, 0.2297005219324645], 
     Hue[0.1872819246117648, 1, 0.7406865659221719], 
     Hue[0.5140587485290995, 1, 0.2882263481904776], 
     Hue[0.2979401571788082, 1, 0.5874674746754964], 
     Hue[0.15227161525780203`, 1, 0.7891623788738126], 
     Hue[0.030058764188215847`, 1, 0.9583801726624703], 
     Hue[0.5140480015352548, 1, 0.28824122864349344`], 
     Hue[0.6248737222598818, 1, 0.13479023071708685`], 
     Hue[0.6170877098281088, 1, 0.14557086331492639`], 
     Hue[0.5140332424495696, 1, 0.2882616643005959], 
     Hue[0.03533327518132401, 1, 0.9510770035950897], 
     Hue[0.13802004353123853`, 1, 0.808895324341362], 
     Hue[0.51406760056958, 1, 0.2882140915190431], 
     Hue[0.5709035702149242, 1, 0.20951813354856652`], 
     Hue[0.4465105581573412, 1, 0.381754611782143], 
     Hue[0.2384748154344996, 1, 0.6698041017060774], 
     Hue[0.5140729722628761, 1, 0.2882066537898639], 
     Hue[0.27247928068940624`, 1, 0.6227209959685145], 
     Hue[0.0005940657434075902, 1, 0.9991774474322049], 
     Hue[0.038832163587489865`, 1, 0.9462323888788602], 
     Hue[0.6464463903605046, 1, 0.1049203825777629], 
     Hue[0.6465660745761747, 1, 0.10475466597145046`], 
     Hue[0.02616631854104301, 1, 0.9637697127893251], 
     Hue[0.004073282562297442, 1, 0.9943600702983574], 
     Hue[0.5140762410206148, 1, 0.28820212781761034`], 
     Hue[0.5757573128790235, 1, 0.20279756678289054`], 
     Hue[0.5140534299166117, 1, 0.28823371242315293`], 
     Hue[0.05017991614406847, 1, 0.930520116108213], 
     Hue[0.6152224177426603, 1, 0.1481535754332397], 
     Hue[0.6261347068479939, 1, 0.13304425205662387`], 
     Hue[0.018469552925900357`, 1, 0.9744267728718302], 
     Hue[0.5140707365624962, 1, 0.2882097493750053], 
     Hue[0.5500349047585459, 1, 0.23841320879585953`], 
     Hue[0.5140704731636794, 1, 0.28821011408105945`], 
     Hue[0.0005508351519450949, 1, 0.9992373051742299], 
     Hue[0.056146640371090295`, 1, 0.9222584979477212], 
     Hue[0.6430120798594648, 1, 0.10967558173304878`], 
     Hue[0.6389452733632661, 1, 0.11530654457393927`], 
     Hue[0.0011169039456718766`, 1, 0.9984535176136852], 
     Hue[0.5140748964419151, 1, 0.28820398954196375`], 
     Hue[0.5140633615891327, 1, 0.2882199608765855], 
     Hue[0.015073548664121028`, 1, 0.9791289326189093], 
     Hue[0.6325108484128179, 1, 0.12421574835148289`], 
     Hue[0.6058747831622758, 1, 0.16109645408300274`], 
     Hue[0.05756892274310843, 1, 0.9202891838941576], 
     Hue[0.5140637567981455, 1, 0.2882194136641062], 
     Hue[0.5885505082395134, 1, 0.18508391166836613`], 
     Hue[0.51407476484722, 1, 0.288204171750003], 
     Hue[0.004977589332110122, 1, 0.9931079532324629], 
     Hue[0.02374344100032999, 1, 0.9671244663072354], 
     Hue[0.6489946328642755, 1, 0.10139204680331093`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563404318096394*^9, 3.563458220779015*^9, 
  3.564487671135879*^9, 3.566100810920477*^9, 3.601301564131393*^9, 
  3.614709332094058*^9, 3.614729188587714*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[308]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "IntensityFunction", 
      "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
     RowBox[{"OutputGraphics", "\[Rule]", 
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwtlXk81Nsbx02SpZtEhKGiSNPQ0Djtvo9CmTY3l6Jys5W0kOVSU7qEQm5U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        "], {{}, {}, 
         {Hue[0.67, 0.6, 0.6], 
          LineBox[{1, 112, 90, 129, 76, 121, 101, 138, 68, 117, 96, 134, 83, 
           125, 107, 142, 60, 115, 94, 132, 80, 123, 105, 140, 72, 119, 98, 
           136, 87, 127, 109, 144, 31, 64, 2, 32, 3, 33, 4, 34, 5, 35, 6, 36, 
           7, 37, 8, 38, 9, 39, 10, 40, 11, 41, 12, 42, 13, 43, 14, 44, 15, 
           45, 16, 46, 17, 47, 18, 48, 19, 49, 20, 50, 21, 51, 22, 52, 23, 53,
            24, 61, 54, 92, 78, 103, 70, 85, 65, 81, 74, 99, 88, 110, 25, 55, 
           26, 113, 91, 130, 77, 102, 69, 84, 62, 73, 56, 66, 27, 57, 28, 58, 
           29, 63, 59, 114, 93, 131, 79, 122, 104, 139, 71, 118, 97, 135, 86, 
           126, 108, 143, 67, 116, 95, 133, 82, 124, 106, 141, 75, 120, 100, 
           137, 89, 128, 111, 145, 30},
           VertexColors->Automatic]}},
        VertexColors->{
          Hue[0.65, 1, 0.1], 
          Hue[8.614425839326145*^-10, 1, 0.9999999988072333], 
          Hue[3.8719027983802334`*^-11, 1, 0.9999999999463891], 
          Hue[1.3006679067117943`*^-9, 1, 0.9999999981990751], 
          Hue[6.044661438053822*^-10, 1, 0.9999999991630469], 
          Hue[1.0663472327365753`*^-9, 1, 0.9999999985235193], 
          Hue[2.5794312241700368`*^-9, 1, 0.9999999964284799], 
          Hue[3.284260086111601*^-9, 1, 0.999999995452563], 
          Hue[4.001898479266686*^-9, 1, 0.9999999944589099], 
          Hue[5.23495391480111*^-9, 1, 0.9999999927516023], 
          Hue[2.6036557354558454`*^-9, 1, 0.9999999963949382], 
          Hue[3.759244249224025*^-9, 1, 0.9999999947948927], 
          Hue[3.0417744989463813`*^-9, 1, 0.9999999957883122], 
          Hue[8.535693263311828*^-10, 1, 0.9999999988181348], 
          Hue[6.079386993818048*^-9, 1, 0.9999999915823872], 
          Hue[7.682343650117218*^-10, 1, 0.9999999989362909], 
          Hue[5.783660772529231*^-9, 1, 0.9999999919918543], 
          Hue[6.189487811170125*^-9, 1, 0.9999999914299399], 
          Hue[5.739439701279991*^-9, 1, 0.9999999920530834], 
          Hue[4.098279493547352*^-10, 1, 0.9999999994325459], 
          Hue[6.194251556124186*^-9, 1, 0.9999999914233441], 
          Hue[2.8961680831329772`*^-9, 1, 0.9999999959899212], 
          Hue[4.9512752786640135`*^-9, 1, 0.9999999931443881], 
          Hue[1.4603124265377687`*^-9, 1, 0.999999997978029], 
          Hue[7.594344375583262*^-9, 1, 0.9999999894847539], 
          Hue[7.632621978892473*^-9, 1, 0.9999999894317542], 
          Hue[5.766563004883096*^-9, 1, 0.9999999920155281], 
          Hue[4.163279720970081*^-10, 1, 0.9999999994235459], 
          Hue[1.3383444352754736`*^-9, 1, 0.9999999981469078], 
          Hue[0.6499999999999999, 1, 0.10000000000000012`], 
          Hue[3.417381044812373*^-9, 1, 0.9999999952682416], 
          Hue[5.897885957395488*^-9, 1, 0.9999999918336964], 
          Hue[5.337305930552816*^-9, 1, 0.999999992609884], 
          Hue[9.182129501184022*^-10, 1, 0.9999999987286282], 
          Hue[3.2890172807498175`*^-9, 1, 0.9999999954459761], 
          Hue[6.697298271518548*^-11, 1, 0.9999999999072682], 
          Hue[1.7633672300121361`*^-12, 1, 0.9999999999975584], 
          Hue[0., 1, 1.], 
          Hue[7.269164936651862*^-9, 1, 0.9999999899350024], 
          Hue[6.107959693579801*^-10, 1, 0.9999999991542825], 
          Hue[1.4987233676322376`*^-11, 1, 0.9999999999792484], 
          Hue[3.3894812512258454`*^-9, 1, 0.9999999953068721], 
          Hue[1.89323945409825*^-9, 1, 0.9999999973785915], 
          Hue[4.1006523732178835`*^-9, 1, 0.9999999943221736], 
          Hue[1.1325956839058904`*^-9, 1, 0.9999999984317907], 
          Hue[4.973075284908646*^-10, 1, 0.9999999993114204], 
          Hue[7.875927687805984*^-9, 1, 0.9999999890948694], 
          Hue[1.1107981201519124`*^-10, 1, 0.9999999998461973], 
          Hue[6.711992073249462*^-10, 1, 0.9999999990706472], 
          Hue[7.402612967055688*^-10, 1, 0.9999999989750229], 
          Hue[1.1589074144779943`*^-10, 1, 0.9999999998395359], 
          Hue[6.591987622428519*^-9, 1, 0.9999999908726326], 
          Hue[1.01312425115907*^-9, 1, 0.9999999985972126], 
          Hue[4.808955456070407*^-10, 1, 0.9999999993341446], 
          Hue[8.100375814557026*^-9, 1, 0.999999988784095], 
          Hue[1.6209145137224823`*^-11, 1, 0.9999999999775565], 
          Hue[3.628892297768971*^-9, 1, 0.9999999949753798], 
          Hue[6.516865713734887*^-9, 1, 0.9999999909766475], 
          Hue[5.754285936632186*^-10, 1, 0.9999999992032528], 
          Hue[0.04653499916561643, 1, 0.9355669242322234], 
          Hue[6.510220029731784*^-9, 1, 0.9999999909858491], 
          Hue[1.9462302880413063`*^-9, 1, 0.9999999973052196], 
          Hue[3.002509352256766*^-11, 1, 0.9999999999584268], 
          Hue[1.7510971561662814`*^-9, 1, 0.9999999975754039], 
          Hue[1.0603322664337611`*^-9, 1, 0.9999999985318476], 
          Hue[1.154064288577672*^-9, 1, 0.9999999984020648], 
          Hue[0.03722173389401651, 1, 0.9484622146082848], 
          Hue[0.46844312518111275`, 1, 0.3513864420569208], 
          Hue[4.6130943509581357`*^-10, 1, 0.9999999993612639], 
          Hue[7.038868155007094*^-9, 1, 0.9999999902538749], 
          Hue[0.00007661246318169113, 1, 0.9998939212048253], 
          Hue[0.00014768578551460632`, 1, 0.9997955119892874], 
          Hue[3.8665847190699765`*^-9, 1, 0.9999999946462673], 
          Hue[6.105925764998688*^-10, 1, 0.9999999991545641], 
          Hue[0.4556566754680397, 1, 0.36909075704425287`], 
          Hue[0.616843801182634, 1, 0.14590858297789136`], 
          Hue[9.209699669554539*^-10, 1, 0.9999999987248108], 
          Hue[2.6745505810055192`*^-9, 1, 0.999999996296776], 
          Hue[7.399047154965643*^-7, 1, 0.9999989755165477], 
          Hue[0.004204920772583498, 1, 0.9941778020071921], 
          Hue[7.282174863121327*^-12, 1, 0.9999999999899171], 
          Hue[0.19436532511773652`, 1, 0.730878780606211], 
          Hue[0.21413299474227482`, 1, 0.703508161126081], 
          Hue[5.951821369087895*^-9, 1, 0.9999999917590165], 
          Hue[3.9736502976950305`*^-9, 1, 0.9999999944980227], 
          Hue[0.002791185327743917, 1, 0.9961352818538931], 
          Hue[1.941476692857158*^-6, 1, 0.9999973118015022], 
          Hue[2.9872180284939986`*^-9, 1, 0.999999995863852], 
          Hue[0.6147193900427812, 1, 0.1488500753253799], 
          Hue[0.6414207343370719, 1, 0.11187898322559278`], 
          Hue[3.3345670669149285`*^-9, 1, 0.9999999953829071], 
          Hue[1.3411991517386923`*^-9, 1, 0.999999998142955], 
          Hue[4.60762709098006*^-8, 1, 0.9999999362020865], 
          Hue[0.015692981445272203`, 1, 0.9782712564603924], 
          Hue[0.09502741424989869, 1, 0.868423580269371], 
          Hue[0.34335009243628195`, 1, 0.5245921797036097], 
          Hue[0.000525719009218828, 1, 0.9992720813718509], 
          Hue[0.00001920219573980919, 1, 0.9999734123443603], 
          Hue[1.5572324540968907`*^-9, 1, 0.999999997843832], 
          Hue[0.5559672552659221, 1, 0.23019918501641556`], 
          Hue[0.5622876879225109, 1, 0.22144781672267722`], 
          Hue[1.1412537581634297`*^-11, 1, 0.9999999999841981], 
          Hue[4.5443552254553765`*^-9, 1, 0.9999999937078158], 
          Hue[8.60513942524399*^-6, 1, 0.9999880851915651], 
          Hue[0.0008891998415959668, 1, 0.9987688002193287], 
          Hue[0.32479883836203005`, 1, 0.5502785314987276], 
          Hue[0.11069735280769111`, 1, 0.8467267422662739], 
          Hue[0.01152116944446513, 1, 0.9840476115384329], 
          Hue[1.4769425649152623`*^-7, 1, 0.9999997955002603], 
          Hue[4.968466749133427*^-9, 1, 0.9999999931205845], 
          Hue[0.6410110264019571, 1, 0.11244627113575173`], 
          Hue[0.6469588463683001, 1, 0.10421082810543068`], 
          Hue[2.2514679010043892`*^-10, 1, 0.9999999996882584], 
          Hue[5.189609852962462*^-9, 1, 0.9999999928143863], 
          Hue[0.027797190357037427`, 1, 0.9615115825825636], 
          Hue[0.06120418481400691, 1, 0.9152557441036827], 
          Hue[0.40843707866207224`, 1, 0.43447173723713084`], 
          Hue[0.00020728673367731432`, 1, 0.9997129875995237], 
          Hue[0.000054906812832933305`, 1, 0.9999239751822313], 
          Hue[0.5109018806806418, 1, 0.2925973959806498], 
          Hue[0.5941643738838212, 1, 0.1773108669300939], 
          Hue[2.619547671556255*^-6, 1, 0.9999963729339932], 
          Hue[0.001992396923342299, 1, 0.9972412965676799], 
          Hue[0.257297348471969, 1, 0.6437421328849661], 
          Hue[0.15782717323297346`, 1, 0.7814700678312675], 
          Hue[0.005849915965490338, 1, 0.9919001163554748], 
          Hue[5.620284995178082*^-7, 1, 0.999999221806693], 
          Hue[0.630944476733023, 1, 0.12638457067735281`], 
          Hue[0.6319676956457997, 1, 0.12496780602889271`], 
          Hue[1.7371442062596998`*^-9, 1, 0.9999999975947235], 
          Hue[2.049603393672328*^-7, 1, 0.9999997162087609], 
          Hue[0.008364165576177585, 1, 0.9884188476637541], 
          Hue[0.1395746168830967, 1, 0.8067428381618661], 
          Hue[0.27718126079490846`, 1, 0.6162105619762807], 
          Hue[0.0012505021722059029`, 1, 0.9982685354538687], 
          Hue[6.304383762145704*^-6, 1, 0.9999912708532523], 
          Hue[0.5902971468843932, 1, 0.18266548892930184`], 
          Hue[0.5202941509079908, 1, 0.2795927141273974], 
          Hue[0.000026538285961774655`, 1, 0.999963254680976], 
          Hue[0.00037357543735505594`, 1, 0.9994827417021237], 
          Hue[0.3924119543326812, 1, 0.4566603709239798], 
          Hue[0.07372287039717462, 1, 0.8979221794500659], 
          Hue[0.021341359765458923`, 1, 0.9704504249401338], 
          Hue[3.725068420390443*^-8, 1, 0.9999999484221296], 
          Hue[0.6468437719887734, 1, 0.10437016186169842`]}],
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{None, None},
       AxesOrigin->{0., 0.},
       DisplayFunction->((Print[#]; #)& ),
       FormatType->OutputForm,
       Method->{},
       PlotLabel->"Surface Intensity",
       PlotRange->All,
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}]}], ",", 
     RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.1319648093841721`"}], ",", 
     RowBox[{"RayBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22.5`"}], ",", "22.5`"}], "}"}]}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
     RowBox[{"Energy", "\[Rule]", "100.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "IntensityFunction", 
      "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
     RowBox[{"OutputGraphics", "\[Rule]", 
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwdWXc81d//VyojlaRIyAqZKRkp51VKGSErKylblD0Td9iy93avebmjQkhO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        "], {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1nfcTgUYBuDPyCi7ouzPnhmZRXYoI6sUkpWUXWTvsipkK5TshtE0GjLL
CKWy9ywa9u56fv1xue/nOT7Oe95zDoltuzXumiQhIaFZ0oSEyE/98gAVzBvM
2eQUcx3Z25xMDjJXlZllUTlfNpCVHD+rv0Alc/yBeeUsudSYUX9Dz0cp/SOZ
y367fJyj+kTudOw1c444F32RfNr+muzFI3ZpZSH5gawnv3Y8s5xgriULy7Jy
qWwi43Q+00tQ0bDRnF1ONb+qJ9cH61mobD4nO5Ekztex2XKZfSb9TT0/pfWP
ZW77HXEeHNNz2c/QJ+l36a/rOXnGfF32Jh3fxPXkc70km/Q+3OFnhpjvi89q
/ku+SFKWmxPZqdfnuD6ZFtyIz0J6vo3PxBdxrflB70sV/ja/RDI+Nefh5/gO
OaFPoWWcB1/G5+RHvR9Vycsvdg05qU+lFSn4yu5BNuv9qUY+dtk9wSl9Gs+S
khV2ZdiiD6A6+fnVrhGn9em0JhUr43tlqz6QGhTgN7vGnNFn8BypWWVXjm36
IGpSkN/jvuAP/R3axH3Harvy/KQPphaF2G3XlD/1d2kb3y1fx7PCdn0Ij1KY
PXbNOKvPpB1p+CbuP3boQ6lNEfbaPck5fRbtScu3dg+xUx9GHf4xdyY5n5mL
sk9/ir/02XQgHd/ZPczP+nDq8q+5C3fwubkY+/Xm/K2/F+fqHhwZzyfPm2/K
PmTgO3MWx9/Wi8T9Zl4Tzzy/6Dkcm6aPiHtCH6rfTzF9gXzM/ryMF09luxTx
PMn34j0gv3D8bvmWuaYsEPeU/CS+Y1nc8QPxTojPZv7HnFu+E3+2fD+unRxl
ri5zx3MvF8c9KDs6fkvvS0YK282Va+zv0yfqReOzmr+Pc2SX/lrcs44PM2eN
czVfkN1IyZfmBzgYzzr/6nN4gdvmfmTie3NG1sbzza/669Tjork7qfjKXIJD
egvO6x/QiUyss6vCb/pI6lOSw3YtuaDP5cW4nqy3q8rv+igaUIojdq24qM/j
Je5hg101duujaUhpjto9yyV9Pp25l41xvdmjj+EJHuSYXWsu6wvoQmY22dVg
rz6WRpThuN1zXNEX0jXuN36I+4F9+hs0piwn7NpwVV9Et/ge+dGuFvv1N2lC
OU7ateWavpju3M9mu0c5oL9FU8pzyq4d1/UP6UFWttjV5qA+jmZcMvcgNSvM
FTitt+eG/hE9ycZWuzoc0sfzJJfNPbmTleaKnNE7cFP/OJ5r9+BocyIvm+Mf
t/763aw1ZmebXpfD+gRS+T3DzdniPWG+Ej/LXRSIZ0auiu9dH6cXpIy+JN4/
9n/Ee4BbeqL9u/onenp9jJ6HV8xJzAP0e1gX19U8Ka6rLCbLyWWyqczh+E/x
zMbfYT5izimnx7nH+8WcWo6I+1Bml8XlQtlQNnf8avy9pIlztpsjV8f9qI/X
C8U7wvyn7MhtPY9jM/UlegZ9bNyHMq8sKT+UjWSvuLRyYDxn8l5ZRM6T9eX6
uA/k5LgP4r0ky8vlSf7//1ROx/8DF5gRDQ==
           "],
           VertexColors->Automatic]}},
        VertexColors->{
          Hue[0.6499999999999507, 1, 0.1000000000000682], 
          Hue[0.008631660682717479, 1, 0.9880484698239296], 
          Hue[0.3411024441442826, 1, 0.5277043081079165], 
          Hue[0.41118708738161014`, 1, 0.4306640328562322], 
          Hue[0.4443594476621555, 1, 0.38473307246778476`], 
          Hue[0.46598514141674685`, 1, 0.35478980419219674`], 
          Hue[0.4794742338289497, 1, 0.3361125993137619], 
          Hue[0.48987922258879857`, 1, 0.3217056918001251], 
          Hue[0.49733488145125904`, 1, 0.3113824718367183], 
          Hue[0.5025648988248637, 1, 0.3041409093194196], 
          Hue[0.5068309600262305, 1, 0.2982340553482963], 
          Hue[0.5097690513267186, 1, 0.2941659289322358], 
          Hue[0.5118367914133037, 1, 0.2913029041969641], 
          Hue[0.5132887824214429, 1, 0.2892924551087713], 
          Hue[0.5139676722455698, 1, 0.2883524538138264], 
          Hue[0.5140026089510753, 1, 0.2883040799138957], 
          Hue[0.5133287696623525, 1, 0.2892370881598195], 
          Hue[0.5120385000371563, 1, 0.29102361533316823`], 
          Hue[0.5098462122510407, 1, 0.2940590907293284], 
          Hue[0.5069459147377225, 1, 0.2980748872862304], 
          Hue[0.5026780352104829, 1, 0.30398425893933145`], 
          Hue[0.4970407984587504, 1, 0.3117896636724995], 
          Hue[0.4900507392424497, 1, 0.32146820720276204`], 
          Hue[0.4797779089611737, 1, 0.33569212605375953`], 
          Hue[0.4663131975615611, 1, 0.35433557260706927`], 
          Hue[0.4469672789597507, 1, 0.3811222291326529], 
          Hue[0.41219339843976094`, 1, 0.429270679083408], 
          Hue[0.3444735939379111, 1, 0.5230365622398154], 
          Hue[0.01729344392613963, 1, 0.9760552314868836], 
          Hue[0.65, 1, 0.1], 
          Hue[0.39300302140569543`, 1, 0.4558419703613448], 
          Hue[0.2530918798365331, 1, 0.649565089457108], 
          Hue[0.38390896668458585`, 1, 0.4684337384367273], 
          Hue[0.4300957158038956, 1, 0.40448285504076], 
          Hue[0.45640382818458747`, 1, 0.3680562378982636], 
          Hue[0.4733183000517881, 1, 0.3446361999282934], 
          Hue[0.4851069830588256, 1, 0.3283134080723954], 
          Hue[0.4938856199854357, 1, 0.31615837232785826`], 
          Hue[0.5001269825691879, 1, 0.30751648567343226`], 
          Hue[0.5048585699113393, 1, 0.30096505704583787`], 
          Hue[0.5084133146587163, 1, 0.29604310278023904`], 
          Hue[0.5108959414150447, 1, 0.2926056195791689], 
          Hue[0.5126601442609915, 1, 0.2901628771770887], 
          Hue[0.5137070538871978, 1, 0.2887133100023415], 
          Hue[0.5140753980223882, 1, 0.2882032950459241], 
          Hue[0.5137546670013229, 1, 0.2886473841520145], 
          Hue[0.5127665052311815, 1, 0.290015608141441], 
          Hue[0.5110517298922235, 1, 0.29238991245692136`], 
          Hue[0.5085080660322284, 1, 0.29591190857076066`], 
          Hue[0.5049743365652114, 1, 0.3008047647558612], 
          Hue[0.5000643860651114, 1, 0.30760315775599967`], 
          Hue[0.4937900098316187, 1, 0.3162907556177587], 
          Hue[0.4853358186542222, 1, 0.3279965587864616], 
          Hue[0.4736347036279991, 1, 0.34419810266892437`], 
          Hue[0.45764025880392817`, 1, 0.36634425704071494`], 
          Hue[0.4321632134198536, 1, 0.40162016603404893`], 
          Hue[0.3856694013071687, 1, 0.46599621357468957`], 
          Hue[0.26071691642748684`, 1, 0.6390073464850182], 
          Hue[0.3760557081339889, 1, 0.4793074810452461], 
          Hue[0.5993606655039979, 1, 0.17011600160984908`], 
          Hue[0.14522935955306637`, 1, 0.798913194464985], 
          Hue[0.36521973841680383`, 1, 0.49431113142288696`], 
          Hue[0.421363471651246, 1, 0.41657365463673635`], 
          Hue[0.45074690605554646`, 1, 0.37588889930770486`], 
          Hue[0.4698183633777694, 1, 0.3494822660923193], 
          Hue[0.48241056510054436`, 1, 0.3320469098607848], 
          Hue[0.491958457040392, 1, 0.31882675179022646`], 
          Hue[0.4987783274193394, 1, 0.3093838543424532], 
          Hue[0.5037544118276145, 1, 0.30249389131561066`], 
          Hue[0.5076517754193327, 1, 0.29709754172707786`], 
          Hue[0.5103565569158988, 1, 0.2933524596549094], 
          Hue[0.5122734297769793, 1, 0.2906983280011055], 
          Hue[0.5135178773985598, 1, 0.2889752466789172], 
          Hue[0.5140441330268604, 1, 0.2882465850397318], 
          Hue[0.5139006366828067, 1, 0.28844527228534467`], 
          Hue[0.5130679164888075, 1, 0.2895982694770358], 
          Hue[0.5115715100999538, 1, 0.2916702167846793], 
          Hue[0.5092039250569316, 1, 0.29494841145963313`], 
          Hue[0.5059983129909037, 1, 0.29938695124336423`], 
          Hue[0.5014187853670307, 1, 0.30572783564564976`], 
          Hue[0.4954715533646343, 1, 0.3139624645720449], 
          Hue[0.4877875773983039, 1, 0.3246018159100408], 
          Hue[0.47683576328194516`, 1, 0.33976586622499905`], 
          Hue[0.46218928905682755`, 1, 0.3600455997674695], 
          Hue[0.4400695798408826, 1, 0.3906728894510857], 
          Hue[0.40018927245159885`, 1, 0.4458917766054785], 
          Hue[0.3109969662248112, 1, 0.5693888159964152], 
          Hue[0.07060722354569526, 1, 0.9022361520136527], 
          Hue[0.08940689505109556, 1, 0.8762058376215599], 
          Hue[0.3064815813816538, 1, 0.5756408873177101], 
          Hue[0.39886911540669, 1, 0.44771968635996773`], 
          Hue[0.4376875598063924, 1, 0.3939710710373029], 
          Hue[0.4614516883063506, 1, 0.36106689311428386`], 
          Hue[0.4765256239367891, 1, 0.34019528993367665`], 
          Hue[0.487589248441497, 1, 0.3248764252348504], 
          Hue[0.4956739193764569, 1, 0.3136822654787521], 
          Hue[0.5013872623656188, 1, 0.305771482878374], 
          Hue[0.5058825480900392, 1, 0.29954724110609965`], 
          Hue[0.5091182655556272, 1, 0.29506701692297777`], 
          Hue[0.511388858290768, 1, 0.2919231192897058], 
          Hue[0.5129982269263232, 1, 0.2896947627173986], 
          Hue[0.5138568492443483, 1, 0.2885059010462871], 
          Hue[0.5140615716495079, 1, 0.28822243925452756`], 
          Hue[0.5135642454091889, 1, 0.28891104481804625`], 
          Hue[0.5124236937007133, 1, 0.29049027026055085`], 
          Hue[0.5104773234536872, 1, 0.2931852444487407], 
          Hue[0.5077562744320432, 1, 0.2969528507864017], 
          Hue[0.5038693299486363, 1, 0.3023347739172727], 
          Hue[0.4986077347488248, 1, 0.3096200595785503], 
          Hue[0.49198667707971033`, 1, 0.3187876778896319], 
          Hue[0.48267424758563615`, 1, 0.33168181103527306`], 
          Hue[0.4701407730219706, 1, 0.34903585273881], 
          Hue[0.4525956815314677, 1, 0.37332905634104485`], 
          Hue[0.422991362051545, 1, 0.4143196525440147], 
          Hue[0.36762558248323507`, 1, 0.4909799627155207], 
          Hue[0.16035284734257793`, 1, 0.7779729806025845], 
          Hue[0.5962409885966837, 1, 0.17443555425074556`], 
          Hue[0.6363115412476542, 1, 0.11895325058017109`], 
          Hue[0.0685068768711029, 1, 0.9051443243323191], 
          Hue[0.3539708394198714, 1, 0.5098865300340242], 
          Hue[0.41647911042468266`, 1, 0.4233366163350548], 
          Hue[0.4476533934355872, 1, 0.3801722244738024], 
          Hue[0.4679462723652026, 1, 0.3520743921097196], 
          Hue[0.48097417067548587`, 1, 0.3340357636800966], 
          Hue[0.4909387501086542, 1, 0.3202386536957097], 
          Hue[0.49806888600751553`, 1, 0.3103661578357477], 
          Hue[0.5031706717517279, 1, 0.30330214680529977`], 
          Hue[0.5072489562105813, 1, 0.29765529140073366`], 
          Hue[0.5100689289890702, 1, 0.2937507137074413], 
          Hue[0.5120614374086259, 1, 0.29099185589574883`], 
          Hue[0.5134083548778525, 1, 0.28912689324605045`], 
          Hue[0.5140115643180199, 1, 0.2882916801750495], 
          Hue[0.5139570998465275, 1, 0.28836709252019266`], 
          Hue[0.5132033681440683, 1, 0.28941072103129006`], 
          Hue[0.5118115004040839, 1, 0.2913379225174224], 
          Hue[0.5095316268640282, 1, 0.29449467049596095`], 
          Hue[0.5064813888429273, 1, 0.29871807698671615`], 
          Hue[0.5020598943859161, 1, 0.3048401462348854], 
          Hue[0.4962696616063115, 1, 0.3128573916220303], 
          Hue[0.48894153438068844`, 1, 0.3230040293190468], 
          Hue[0.4783373015426565, 1, 0.3376868132486295], 
          Hue[0.4643005516154751, 1, 0.35712231314780374`], 
          Hue[0.44363142448081055`, 1, 0.38574110456503163`], 
          Hue[0.40645927774028323`, 1, 0.4372102308211463], 
          Hue[0.3290459983992664, 1, 0.5443978483702465], 
          Hue[0.0034441103730811218`, 1, 0.9952312317911184], 
          Hue[0.23331314673803139`, 1, 0.676951027593495], 
          Hue[0.28360847710945747`, 1, 0.6073113393869051], 
          Hue[0.39177520207571415`, 1, 0.45754202789516507`], 
          Hue[0.434018844610488, 1, 0.39905083053932433`], 
          Hue[0.4589974426402542, 1, 0.36446507942118656`], 
          Hue[0.4749562795010561, 1, 0.34236822838315306`], 
          Hue[0.4863734346625327, 1, 0.32655985969803175`], 
          Hue[0.4947963694080756, 1, 0.31489733466574155`], 
          Hue[0.5007677964494137, 1, 0.3066292049161965], 
          Hue[0.5053802839871588, 1, 0.3002426837100878], 
          Hue[0.5087727067260719, 1, 0.29554548299466976`], 
          Hue[0.5111481146669794, 1, 0.29225645661495164`], 
          Hue[0.5128351927473693, 1, 0.2899205023497964], 
          Hue[0.5137868481912008, 1, 0.2886028255814143], 
          Hue[0.5140741184117765, 1, 0.28820506681446334`], 
          Hue[0.5136650484239367, 1, 0.28877147141301074`], 
          Hue[0.5126003342171618, 1, 0.29024569108392984`], 
          Hue[0.5107714808148899, 1, 0.2927779496409218], 
          Hue[0.5081393204754955, 1, 0.2964224793416217], 
          Hue[0.5044322773267702, 1, 0.3015553083167798], 
          Hue[0.499349320708152, 1, 0.30859324825025103`], 
          Hue[0.4929042112605926, 1, 0.3175172459468718], 
          Hue[0.4840327215968028, 1, 0.3298008470198115], 
          Hue[0.4719267177194495, 1, 0.34656300623460845`], 
          Hue[0.45518495458177616`, 1, 0.3697439090406176], 
          Hue[0.4277550218160592, 1, 0.407723815946995], 
          Hue[0.3771714333094461, 1, 0.4777626308023055], 
          Hue[0.21986972517066455`, 1, 0.6955649959175414], 
          Hue[0.5123467094653767, 1, 0.29059686381717065`], 
          Hue[0.5211993474394916, 1, 0.2783393650837809], 
          Hue[0.2087793345221719, 1, 0.7109209214308388], 
          Hue[0.3751206537217063, 1, 0.48060217176994513`], 
          Hue[0.42588875694158823`, 1, 0.4103078750039547], 
          Hue[0.5124729451347021, 1, 0.2904220759673356], 
          Hue[0.5136174173705665, 1, 0.2888374221022926], 
          Hue[0.5140654038251276, 1, 0.2882171331652081], 
          Hue[0.5138331757873733, 1, 0.2885386796790217], 
          Hue[0.5129223297410859, 1, 0.2897998511277273], 
          Hue[0.4362566033079124, 1, 0.39595239541981364`], 
          Hue[0.3932958055353149, 1, 0.4554365769511025], 
          Hue[0.28919441988023586`, 1, 0.5995769570889042], 
          Hue[0.2110016033313578, 1, 0.7078439338488892], 
          Hue[0.009531569972692555, 1, 0.986802441576272], 
          Hue[0.3251786887601785, 1, 0.549752584793599], 
          Hue[0.40530848475374365`, 1, 0.43880363649481646`], 
          Hue[0.5139171110179993, 1, 0.28842246166738555`], 
          Hue[0.5140377406942753, 1, 0.2882554359617726], 
          Hue[0.5134521799544653, 1, 0.28906621237074026`], 
          Hue[0.3568121978483322, 1, 0.5059523414407708], 
          Hue[0.08458032502186641, 1, 0.8828887807389542], 
          Hue[0.6356758115455341, 1, 0.11983349170618357`], 
          Hue[0.6450384179312573, 1, 0.10686988286441307`], 
          Hue[0.03359607627695704, 1, 0.9534823559242133], 
          Hue[0.34775701734842535`, 1, 0.518490283671411], 
          Hue[0.4138874509377585, 1, 0.4269250679323344], 
          Hue[0.446032727673337, 1, 0.38241622322153346`], 
          Hue[0.4669772231429448, 1, 0.3534161525713072], 
          Hue[0.48023238588302164`, 1, 0.3350628503158162], 
          Hue[0.49041408358879024`, 1, 0.32096511503090586`], 
          Hue[0.497705010561154, 1, 0.3108699853768637], 
          Hue[0.5028705854723123, 1, 0.3037176508844906], 
          Hue[0.5070418777589681, 1, 0.29794201541065957`], 
          Hue[0.5099205390979089, 1, 0.2939561766336646], 
          Hue[0.511950705469314, 1, 0.29114517704248843`], 
          Hue[0.5133498345066573, 1, 0.28920792145232077`], 
          Hue[0.513991034365259, 1, 0.2883201062634876], 
          Hue[0.5139812211209356, 1, 0.2883336938325507], 
          Hue[0.5132673170637271, 1, 0.289322176373301], 
          Hue[0.5119266092104874, 1, 0.2911785410931713], 
          Hue[0.5096905411235224, 1, 0.2942746353674306], 
          Hue[0.5067159402375504, 1, 0.29839331351723797`], 
          Hue[0.5023717873087139, 1, 0.304408294495627], 
          Hue[0.4966585392782995, 1, 0.31231894561466234`], 
          Hue[0.4895015895377642, 1, 0.32222856833232655`], 
          Hue[0.47906500310719036`, 1, 0.33667922646696724`], 
          Hue[0.4653187628084101, 1, 0.3557124822652784], 
          Hue[0.4453261709469837, 1, 0.3833945325349457], 
          Hue[0.40938854537196095`, 1, 0.43315432179266944`], 
          Hue[0.337050632270007, 1, 0.5333145091646058], 
          Hue[0.0016140478055113316`, 1, 0.9977651645769844], 
          Hue[0.31461498332396537`, 1, 0.5643792538591249], 
          Hue[0.2696360942905002, 1, 0.6266577155977691], 
          Hue[0.38794712962357225`, 1, 0.4628424359058231], 
          Hue[0.43209081472427224`, 1, 0.40172041038177697`], 
          Hue[0.4577187984316856, 1, 0.36623550986382003`], 
          Hue[0.47414613752524115`, 1, 0.3434899634265892], 
          Hue[0.48574671460475927`, 1, 0.32742762593187186`], 
          Hue[0.49434523509226, 1, 0.31552198217994765`], 
          Hue[0.5004501042521777, 1, 0.3070690864200616], 
          Hue[0.5051218910042077, 1, 0.3006004586095586], 
          Hue[0.5085947575934733, 1, 0.2957918741013447], 
          Hue[0.5110234661446331, 1, 0.29242904687666194`], 
          Hue[0.512749179382328, 1, 0.29003959777831506`], 
          Hue[0.5137481779382427, 1, 0.28865636900858704`], 
          Hue[0.51407616731696, 1, 0.2882022298688245], 
          Hue[0.5137112474580471, 1, 0.28870750351962715`], 
          Hue[0.5126847177987911, 1, 0.290128852278597], 
          Hue[0.5109133265372034, 1, 0.29258154787156443`], 
          Hue[0.5083254612438399, 1, 0.2961647459700677], 
          Hue[0.5047058782127758, 1, 0.30117647632077194`], 
          Hue[0.49971010762593016`, 1, 0.30809369713332757`], 
          Hue[0.4933509956917003, 1, 0.3168986213499534], 
          Hue[0.48469100341464266`, 1, 0.32888937988741784`], 
          Hue[0.47279014121472307`, 1, 0.3453674967796143], 
          Hue[0.45642867603955684`, 1, 0.36802183317599824`], 
          Hue[0.430000845628266, 1, 0.4046142137454778], 
          Hue[0.3815394037578763, 1, 0.4717146717198636], 
          Hue[0.24228629264284157`, 1, 0.6645266717252962], 
          Hue[0.45016891323671626`, 1, 0.37668919705685444`], 
          Hue[0.5664296425908716, 1, 0.2157128025664855], 
          Hue[0.17947468939404715`, 1, 0.7514965839159347], 
          Hue[0.3703229578541135, 1, 0.48724513527891977`], 
          Hue[0.42366828798322986`, 1, 0.4133823704847587], 
          Hue[0.512374738252007, 1, 0.29055805472799034`], 
          Hue[0.5135688875437916, 1, 0.28890461724705774`], 
          Hue[0.5140561759687793, 1, 0.2882299101970749], 
          Hue[0.5138682847952363, 1, 0.288490067206596], 
          Hue[0.512996396937305, 1, 0.28969729654834686`], 
          Hue[0.4381962061132486, 1, 0.39326679153550204`], 
          Hue[0.3968267248346203, 1, 0.45054761176744895`], 
          Hue[0.30068865749131873`, 1, 0.5836618588581741], 
          Hue[0.1340336381922056, 1, 0.8144149625031], 
          Hue[0.039488199603913365`, 1, 0.9453240313176585], 
          Hue[0.31623250725716845`, 1, 0.5621396053362283], 
          Hue[0.4021642739839565, 1, 0.4431571590991372], 
          Hue[0.5138881975675547, 1, 0.28846249567569354`], 
          Hue[0.5140510685976495, 1, 0.2882369819417162], 
          Hue[0.513509626729587, 1, 0.2889866706821103], 
          Hue[0.36239271280980356`, 1, 0.49822547457104127`], 
          Hue[0.12360307372675672`, 1, 0.828857282532183], 
          Hue[0.6203206092222473, 1, 0.1410945410768884], 
          Hue[0.6218626853427278, 1, 0.138959358756223], 
          Hue[0.10727871502578645`, 1, 0.8514602407335266], 
          Hue[0.3597801094155249, 1, 0.5018429254246579], 
          Hue[0.5140292601384399, 1, 0.2882671782698525], 
          Hue[0.5139302400595432, 1, 0.2884042829944787], 
          Hue[0.32039443604339213`, 1, 0.5563769347091494], 
          Hue[0.026217697325400025`, 1, 0.9636985729340616], 
          Hue[0.15592347241986693`, 1, 0.7841059612647997], 
          Hue[0.2957193053251254, 1, 0.5905425003190571], 
          Hue[0.5138230683167221, 1, 0.28855267463838485`], 
          Hue[0.5140692573655059, 1, 0.28821179749391496`], 
          Hue[0.37254219271234706`, 1, 0.48417234855213487`], 
          Hue[0.19266427103990857`, 1, 0.7332340862524342], 
          Hue[0.5608847221738127, 1, 0.2233903846824132], 
          Hue[0.4629974431064109, 1, 0.35892661723727726`], 
          Hue[0.23310461760358525`, 1, 0.6772397602411896], 
          Hue[0.5140718105064597, 1, 0.28820826237567126`], 
          Hue[0.2760802057003562, 1, 0.6177350997995068], 
          Hue[0.29420410080654835`, 1, 0.5926404758063177], 
          Hue[0., 1, 1.], 
          Hue[0.5139436018775285, 1, 0.28838578201572973`], 
          Hue[0.5140215889849076, 1, 0.28827779986705104`], 
          Hue[0.04726208360870199, 1, 0.9345601919264127], 
          Hue[0.6448538270395652, 1, 0.10712547025290983`], 
          Hue[0.6478867130632673, 1, 0.10292608960470682`], 
          Hue[0.019459854306446367`, 1, 0.9730555863449204], 
          Hue[0.34448715026683563`, 1, 0.5230177919382276], 
          Hue[0.4125513173047306, 1, 0.4287750991165269], 
          Hue[0.4452028281872674, 1, 0.3835653148176298], 
          Hue[0.46648411054943645`, 1, 0.3540989238546265], 
          Hue[0.4798553905317431, 1, 0.335584843879125], 
          Hue[0.4901479398056455, 1, 0.32133362180756775`], 
          Hue[0.49752073451977213`, 1, 0.31112513681877707`], 
          Hue[0.502718447330845, 1, 0.30392830369575297`], 
          Hue[0.5069369003870395, 1, 0.2980873686948683], 
          Hue[0.509845181840596, 1, 0.29406051745148254`], 
          Hue[0.5118941482822067, 1, 0.2912234869938677], 
          Hue[0.5133196210831168, 1, 0.2892497554233767], 
          Hue[0.513979706950032, 1, 0.28833579037687873`], 
          Hue[0.5139922564264884, 1, 0.2883184141787084], 
          Hue[0.5132983544242834, 1, 0.2892792015663769], 
          Hue[0.511982955690785, 1, 0.29110052288968236`], 
          Hue[0.5097687808849953, 1, 0.2941663033900066], 
          Hue[0.5068314971569847, 1, 0.29823331162879035`], 
          Hue[0.5025256103135542, 1, 0.3041953087966172], 
          Hue[0.49685049176095825`, 1, 0.3120531652540578], 
          Hue[0.4897775109545568, 1, 0.3218465232936906], 
          Hue[0.47942327699668646`, 1, 0.33618315492766493`], 
          Hue[0.46581890192408915`, 1, 0.35501998195126117`], 
          Hue[0.4461532644914935, 1, 0.3822493260887013], 
          Hue[0.41080598002122987`, 1, 0.4311917199706048], 
          Hue[0.3408314520420533, 1, 0.5280795279417724], 
          Hue[0.007560387590092588, 1, 0.9895317710291026], 
          Hue[0.3545587348815615, 1, 0.5090725209332226], 
          Hue[0.26173715015146864`, 1, 0.6375947151748896], 
          Hue[0.38595548951517683`, 1, 0.4656000914405244], 
          Hue[0.43110187888824625`, 1, 0.40308970615473594`], 
          Hue[0.45706595063698485`, 1, 0.36713945296417483`], 
          Hue[0.47373446226438376`, 1, 0.3440599753262379], 
          Hue[0.485428496256165, 1, 0.3278682359530023], 
          Hue[0.494116500040682, 1, 0.3158386922513634], 
          Hue[0.5002892254123086, 1, 0.3072918417368036], 
          Hue[0.5049908500102406, 1, 0.3007818999858208], 
          Hue[0.5085044752599074, 1, 0.29591688040935904`], 
          Hue[0.5109600663949231, 1, 0.2925168311454911], 
          Hue[0.5127050443073584, 1, 0.2901007078821191], 
          Hue[0.5137279228274281, 1, 0.28868441454663807`], 
          Hue[0.5140761353639516, 1, 0.2882022741114517], 
          Hue[0.5137333050421538, 1, 0.2886769622493256], 
          Hue[0.5127259376275944, 1, 0.2900717786694847], 
          Hue[0.5109829580615585, 1, 0.2924851349916884], 
          Hue[0.5084172031013412, 1, 0.29603771878275836`], 
          Hue[0.5048407472115264, 1, 0.3009897346301943], 
          Hue[0.49988805331049824`, 1, 0.3078473108008486], 
          Hue[0.49357146379658434`, 1, 0.316593357820114], 
          Hue[0.4850150700041927, 1, 0.3284406723018871], 
          Hue[0.47321474424831467`, 1, 0.34477958488694893`], 
          Hue[0.45703840411043917`, 1, 0.36717759430862273`], 
          Hue[0.43109214735031876`, 1, 0.40310318059186634`], 
          Hue[0.3836327968115259, 1, 0.4688161274917334], 
          Hue[0.2519418923975859, 1, 0.6511573797571887], 
          Hue[0.4144002996736071, 1, 0.4262149696826979], 
          Hue[0.584335277661921, 1, 0.19092038477580184`], 
          Hue[0.16292657703883812`, 1, 0.7744093548693011], 
          Hue[0.3678114066051019, 1, 0.49072266777755125`], 
          Hue[0.4225267423306409, 1, 0.41496297215757416`], 
          Hue[0.5123244730510517, 1, 0.2906276526985439], 
          Hue[0.5135436925491452, 1, 0.2889395026242605], 
          Hue[0.5140505084937093, 1, 0.28823775747024877`], 
          Hue[0.5138848052038986, 1, 0.28846719279460203`], 
          Hue[0.5130324738824221, 1, 0.2896473438551078], 
          Hue[0.4391409459249913, 1, 0.39195869025770447`], 
          Hue[0.39852821063321453`, 1, 0.4481917083540107], 
          Hue[0.3059706977536901, 1, 0.5763482646487368], 
          Hue[0.10022569195112963`, 1, 0.8612259649907436], 
          Hue[0.06209744610375878, 1, 0.9140189207794109], 
          Hue[0.31146807094064405`, 1, 0.5687365171591083], 
          Hue[0.40053629963640514`, 1, 0.445411277426516], 
          Hue[0.5138728274567489, 1, 0.2884837773675785], 
          Hue[0.5140566723688299, 1, 0.28822922287392794`], 
          Hue[0.5135372896053527, 1, 0.2889483682387425], 
          Hue[0.3650505887482465, 1, 0.49454533865627415`], 
          Hue[0.14243780952316587`, 1, 0.8027784175833087], 
          Hue[0.6095372644756121, 1, 0.15602532611069103`], 
          Hue[0.6299420216005884, 1, 0.1277725854761083], 
          Hue[0.08774346471726369, 1, 0.8785090488530195], 
          Hue[0.35692383176841197`, 1, 0.5057977713975834], 
          Hue[0.5140207649924593, 1, 0.28827894077967176`], 
          Hue[0.5139440126017514, 1, 0.2883852133206519], 
          Hue[0.32480616679446667`, 1, 0.5502683844384307], 
          Hue[0.012096748388922274`, 1, 0.9832506560768769], 
          Hue[0.1936811278509048, 1, 0.731826130667978], 
          Hue[0.28985996623301974`, 1, 0.598655431369665], 
          Hue[0.5138052630080445, 1, 0.2885773281427076], 
          Hue[0.514072041071303, 1, 0.28820794313204207`], 
          Hue[0.37489103657556894`, 1, 0.48092010320305845`], 
          Hue[0.20690219884234323`, 1, 0.7135200323721401], 
          Hue[0.5383354869620068, 1, 0.2546124026679906], 
          Hue[0.4936958822392804, 1, 0.31642108613022724`], 
          Hue[0.2215345756891528, 1, 0.6932598182765577], 
          Hue[0.5140689609247798, 1, 0.28821220795030494`], 
          Hue[0.28287433346591534`, 1, 0.608327845970271], 
          Hue[0.252309892043632, 1, 0.6506478417857403], 
          Hue[0.002296930775448569, 1, 0.9968196343109174], 
          Hue[0.5139306593030198, 1, 0.288403702503511], 
          Hue[0.5140300181272548, 1, 0.28826612874687796`], 
          Hue[0.06538852665231498, 1, 0.9094620400198716], 
          Hue[0.6408906458030285, 1, 0.11261295196503762`], 
          Hue[0.6412568366797197, 1, 0.11210591844346512`], 
          Hue[0.050212264510408944`, 1, 0.9304753260625107], 
          Hue[0.5140016523460559, 1, 0.2883054044439226], 
          Hue[0.00007171279394391217, 1, 0.9999007053622315], 
          Hue[0.276894792788384, 1, 0.6166072099853145], 
          Hue[0.514075496717338, 1, 0.2882031583913781], 
          Hue[0.23163271725979612`, 1, 0.6792777761018208], 
          Hue[0.4829134291720908, 1, 0.3313506365309513], 
          Hue[0.5454304176316049, 1, 0.24478865251008555`], 
          Hue[0.19476883483328283`, 1, 0.7303200748462237], 
          Hue[0.5140611435721838, 1, 0.2882230319769763], 
          Hue[0.29511263889182554`, 1, 0.5913824999959338], 
          Hue[0.17125616650450748`, 1, 0.762876077147605], 
          Hue[0.021916284789427865`, 1, 0.9696543749069461], 
          Hue[0.5140447590729791, 1, 0.2882457182066443], 
          Hue[0.6289234628399626, 1, 0.1291828976062057], 
          Hue[0.6117712145325602, 1, 0.15293216449337815`], 
          Hue[0.5140370485839638, 1, 0.2882563942683579], 
          Hue[0.045795142590402405`, 1, 0.9365913410286737], 
          Hue[0.12090390872011858`, 1, 0.8325945879259896], 
          Hue[0.5140657661714421, 1, 0.2882166314549264], 
          Hue[0.5801157707999095, 1, 0.19676277889243304`], 
          Hue[0.42931515726704234`, 1, 0.4055636283994799], 
          Hue[0.24358650109746693`, 1, 0.662726383095815], 
          Hue[0.514073953790436, 1, 0.28820529475170414`], 
          Hue[0.26872692996800157`, 1, 0.627916558505844], 
          Hue[0.0022748898613479396`, 1, 0.996850152499672], 
          Hue[0.030958025864093464`, 1, 0.9571350411112552], 
          Hue[0.6478180016189611, 1, 0.10302122852759234`], 
          Hue[0.6490241044763948, 1, 0.10135123995576108`], 
          Hue[0.013580709998720408`, 1, 0.9811959400017717], 
          Hue[0.3428094492290646, 1, 0.5253407626059106], 
          Hue[0.4118727743144928, 1, 0.4297146201799331], 
          Hue[0.44478284784490474`, 1, 0.3841468260609012], 
          Hue[0.4662353660161266, 1, 0.35444333936228634`], 
          Hue[0.4796653324099629, 1, 0.335848001278513], 
          Hue[0.49001390518980315`, 1, 0.32151920819873414`], 
          Hue[0.4974280070404634, 1, 0.3112535287132045], 
          Hue[0.5026418506119343, 1, 0.3040343606911678], 
          Hue[0.5068840505613028, 1, 0.2981605453766577], 
          Hue[0.5098072137333878, 1, 0.2941130886768476], 
          Hue[0.5118655687681113, 1, 0.291263058628769], 
          Hue[0.5133042802754985, 1, 0.2892709965416176], 
          Hue[0.5139737780944726, 1, 0.2883439995614994], 
          Hue[0.5139975174135407, 1, 0.28831112973509754`], 
          Hue[0.5133136398048785, 1, 0.28925803719324517`], 
          Hue[0.512010827808624, 1, 0.29106193072652065`], 
          Hue[0.5098075970740522, 1, 0.29411255789746615`], 
          Hue[0.5068888465435091, 1, 0.29815390478591064`], 
          Hue[0.5026019978306872, 1, 0.3040895414652024], 
          Hue[0.4969458479157277, 1, 0.3119211336551463], 
          Hue[0.48991446122703747`, 1, 0.32165689983948664`], 
          Hue[0.4796010436303819, 1, 0.3359370165117789], 
          Hue[0.4660667725315264, 1, 0.35467677649480966`], 
          Hue[0.44656188453734735`, 1, 0.3816835444867499], 
          Hue[0.41150337599495246`, 1, 0.43022609477621965`], 
          Hue[0.34266946917418695`, 1, 0.5255345811434334], 
          Hue[0.011995185198085068`, 1, 0.9833912820334206], 
          Hue[0.3740108491137147, 1, 0.4821388243040874], 
          Hue[0.2575147849175659, 1, 0.6434410670372164], 
          Hue[0.384939244868032, 1, 0.4670071994134942], 
          Hue[0.4306009827817033, 1, 0.40378325460994935`], 
          Hue[0.4567360598703961, 1, 0.3675962247948362], 
          Hue[0.47352694627363595`, 1, 0.344347305159581], 
          Hue[0.4852681536954455, 1, 0.3280902487293832], 
          Hue[0.49400133081650927`, 1, 0.31599815733098724`], 
          Hue[0.5002082774625266, 1, 0.3074039235134247], 
          Hue[0.5049248649418894, 1, 0.3008732639266148], 
          Hue[0.5084590045507571, 1, 0.29597983985279785`], 
          Hue[0.5109280949765262, 1, 0.29256109926327145`], 
          Hue[0.5126826867864367, 1, 0.2901316644495492], 
          Hue[0.5137175657596886, 1, 0.2886987551019696], 
          Hue[0.514075854490083, 1, 0.2882026630137314], 
          Hue[0.5137440732132407, 1, 0.2886620524739745], 
          Hue[0.5127463021957269, 1, 0.29004358157514737`], 
          Hue[0.5110174499126403, 1, 0.2924373770440365], 
          Hue[0.5084627434895944, 1, 0.2959746628605616], 
          Hue[0.5049077013361603, 1, 0.30089702891916276`], 
          Hue[0.4999764190173361, 1, 0.3077249582836885], 
          Hue[0.49368097472399186`, 1, 0.316441727305242], 
          Hue[0.4851758560634175, 1, 0.3282180454506527], 
          Hue[0.4734253005296681, 1, 0.34448804542045963`], 
          Hue[0.4573403051129879, 1, 0.36675957753586297`], 
          Hue[0.4316301710679163, 1, 0.4023582246751929], 
          Hue[0.38465803837467005`, 1, 0.4673965622504569], 
          Hue[0.2564321351790186, 1, 0.6449401205213589], 
          Hue[0.39551572037451255`, 1, 0.45236284871221344`], 
          Hue[0.5921923719416516, 1, 0.1800413311577132], 
          Hue[0.1542116558404391, 1, 0.7864761688363151], 
          Hue[0.36652582947252454`, 1, 0.4925026976534276], 
          Hue[0.4219478654610944, 1, 0.41576449397694626`], 
          Hue[0.512299049680129, 1, 0.29066285428905225`], 
          Hue[0.513530863214718, 1, 0.2889572663180828], 
          Hue[0.5140474107562237, 1, 0.2882420466452287], 
          Hue[0.513892808347615, 1, 0.28845611151868694`], 
          Hue[0.513050276942888, 1, 0.2896226934636935], 
          Hue[0.43960724836960086`, 1, 0.3913130407190143], 
          Hue[0.3993636948627518, 1, 0.44703488403618985`], 
          Hue[0.3085137633929711, 1, 0.5728270968405016], 
          Hue[0.08485009375241781, 1, 0.8825152548043447], 
          Hue[0.07519278972204846, 1, 0.8958869065387022], 
          Hue[0.3090042054729398, 1, 0.5721480231913142], 
          Hue[0.3997077048059, 1, 0.4465585625764462], 
          Hue[0.5138649142241445, 1, 0.2884947341511846], 
          Hue[0.5140592095531815, 1, 0.28822570984944107`], 
          Hue[0.5135508538954687, 1, 0.2889295869139665], 
          Hue[0.36634819911093386`, 1, 0.4927486473848609], 
          Hue[0.15152605101434558`, 1, 0.7901946985955215], 
          Hue[0.6032236268499935, 1, 0.16476728590000905`], 
          Hue[0.633322149965701, 1, 0.12309240773979867`], 
          Hue[0.07805006832865469, 1, 0.8919306746218627], 
          Hue[0.3554597017107072, 1, 0.5078250284005593], 
          Hue[0.5140162513824511, 1, 0.28828519039352923`], 
          Hue[0.5139506439033766, 1, 0.28837603151840163`], 
          Hue[0.32694684743547076`, 1, 0.5473043650893482], 
          Hue[0.007094168013062285, 1, 0.9901773058280675], 
          Hue[0.2133187242955601, 1, 0.7046356125138399], 
          Hue[0.2867873214448898, 1, 0.602909862614768], 
          Hue[0.5137961315332867, 1, 0.2885899717231415], 
          Hue[0.5140731664569507, 1, 0.2882063849057607], 
          Hue[0.37603958914973756`, 1, 0.47932979963882494`], 
          Hue[0.2135414996424817, 1, 0.7043271543411792], 
          Hue[0.5257743579313647, 1, 0.27200473517195656`], 
          Hue[0.5078548015570531, 1, 0.29681642861331115`], 
          Hue[0.21531027959316262`, 1, 0.7018780744094671], 
          Hue[0.5140672690008813, 1, 0.28821455061416434`], 
          Hue[0.2860888173722116, 1, 0.6038770221000147], 
          Hue[0.2315216624548186, 1, 0.6794315442933281], 
          Hue[0.005279866799499544, 1, 0.9926894152006929], 
          Hue[0.5139239607177777, 1, 0.2884129774676925], 
          Hue[0.5140339674947911, 1, 0.28826066039182763`], 
          Hue[0.07489531976037156, 1, 0.8962987880241009], 
          Hue[0.6384568258074018, 1, 0.11598285657436672`], 
          Hue[0.6432779493161761, 1, 0.10930745479298704`], 
          Hue[0.04164539293661984, 1, 0.9423371482416032], 
          Hue[0.5139964313270715, 1, 0.28831263354713177`], 
          Hue[0.0002574857565068589, 1, 0.9996434812602213], 
          Hue[0.27333924166162205`, 1, 0.6215302807762156], 
          Hue[0.5140759203529219, 1, 0.2882025718190313], 
          Hue[0.2370914657681812, 1, 0.6717195089363645], 
          Hue[0.4669408680912272, 1, 0.3534664903352239], 
          Hue[0.5563274008265534, 1, 0.2297005219324645], 
          Hue[0.1872819246117648, 1, 0.7406865659221719], 
          Hue[0.5140587485290995, 1, 0.2882263481904776], 
          Hue[0.2979401571788082, 1, 0.5874674746754964], 
          Hue[0.15227161525780203`, 1, 0.7891623788738126], 
          Hue[0.030058764188215847`, 1, 0.9583801726624703], 
          Hue[0.5140480015352548, 1, 0.28824122864349344`], 
          Hue[0.6248737222598818, 1, 0.13479023071708685`], 
          Hue[0.6170877098281088, 1, 0.14557086331492639`], 
          Hue[0.5140332424495696, 1, 0.2882616643005959], 
          Hue[0.03533327518132401, 1, 0.9510770035950897], 
          Hue[0.13802004353123853`, 1, 0.808895324341362], 
          Hue[0.51406760056958, 1, 0.2882140915190431], 
          Hue[0.5709035702149242, 1, 0.20951813354856652`], 
          Hue[0.4465105581573412, 1, 0.381754611782143], 
          Hue[0.2384748154344996, 1, 0.6698041017060774], 
          Hue[0.5140729722628761, 1, 0.2882066537898639], 
          Hue[0.27247928068940624`, 1, 0.6227209959685145], 
          Hue[0.0005940657434075902, 1, 0.9991774474322049], 
          Hue[0.038832163587489865`, 1, 0.9462323888788602], 
          Hue[0.6464463903605046, 1, 0.1049203825777629], 
          Hue[0.6465660745761747, 1, 0.10475466597145046`], 
          Hue[0.02616631854104301, 1, 0.9637697127893251], 
          Hue[0.004073282562297442, 1, 0.9943600702983574], 
          Hue[0.5140762410206148, 1, 0.28820212781761034`], 
          Hue[0.5757573128790235, 1, 0.20279756678289054`], 
          Hue[0.5140534299166117, 1, 0.28823371242315293`], 
          Hue[0.05017991614406847, 1, 0.930520116108213], 
          Hue[0.6152224177426603, 1, 0.1481535754332397], 
          Hue[0.6261347068479939, 1, 0.13304425205662387`], 
          Hue[0.018469552925900357`, 1, 0.9744267728718302], 
          Hue[0.5140707365624962, 1, 0.2882097493750053], 
          Hue[0.5500349047585459, 1, 0.23841320879585953`], 
          Hue[0.5140704731636794, 1, 0.28821011408105945`], 
          Hue[0.0005508351519450949, 1, 0.9992373051742299], 
          Hue[0.056146640371090295`, 1, 0.9222584979477212], 
          Hue[0.6430120798594648, 1, 0.10967558173304878`], 
          Hue[0.6389452733632661, 1, 0.11530654457393927`], 
          Hue[0.0011169039456718766`, 1, 0.9984535176136852], 
          Hue[0.5140748964419151, 1, 0.28820398954196375`], 
          Hue[0.5140633615891327, 1, 0.2882199608765855], 
          Hue[0.015073548664121028`, 1, 0.9791289326189093], 
          Hue[0.6325108484128179, 1, 0.12421574835148289`], 
          Hue[0.6058747831622758, 1, 0.16109645408300274`], 
          Hue[0.05756892274310843, 1, 0.9202891838941576], 
          Hue[0.5140637567981455, 1, 0.2882194136641062], 
          Hue[0.5885505082395134, 1, 0.18508391166836613`], 
          Hue[0.51407476484722, 1, 0.288204171750003], 
          Hue[0.004977589332110122, 1, 0.9931079532324629], 
          Hue[0.02374344100032999, 1, 0.9671244663072354], 
          Hue[0.6489946328642755, 1, 0.10139204680331093`]}],
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{None, None},
       AxesOrigin->{0., 0.},
       DisplayFunction->((Print[#]; #)& ),
       FormatType->OutputForm,
       Method->{},
       PlotLabel->"Surface Intensity",
       PlotRange->All,
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}]}], ",", 
     RowBox[{"ComponentNumber", "\[Rule]", "2.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.0015669581305804425`"}], ",", 
     RowBox[{"RayBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.061148465922514106`"}], ",", "0.06114846592251766`"}],
        "}"}]}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
     RowBox[{"Energy", "\[Rule]", "100.`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563404323969454*^9, 3.563458222044435*^9, 
  3.564487672905373*^9, 3.56610081931918*^9, 3.601301565601892*^9, 
  3.614709338195606*^9, 3.6147291886471167`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[308]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tMove[GridOfRays[{45,45}, NumberOfRays -> 48, WaveLength->.633], -25],
\tMove[ApertureStop[{50,50},45],-20],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[{.25,.25}],83.3673]}, SequentialTrace->True, PlotType->Surface];\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[309]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
   AbsolutePointSize[2.5], 
   PointBox[{0.01542635872090159, 0.0533989340338934}], 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011820593137940705`, 0.048356971927944414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008831606671956926, 0.04415803335978552}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006346767122032304, 0.04080064578449338}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004253736986993051, 0.03828363288293346}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002440407561033364, 0.03660611341549469}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0007948333414418696, 0.03576750036488363}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0007948333414418696, 0.03576750036488363}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0024404075610335862`, 0.03660611341549469}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004253736986992163, 0.03828363288293346}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006346767122032304, 0.040800645784496936`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008831606671957815, 0.04415803335978552}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011820593137940705`, 0.048356971927944414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015426358720904254`, 0.05339893403389695}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017950862206147278`, 0.04540512205084468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013600215261497794`, 0.038987283749630564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010090595689100645`, 0.03337658574086433}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0073088755231314195`, 0.028571058863150256`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005142352774532455, 0.024569018811650523`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003478684917773478, 0.021369064494901835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0022058228686474557`, 0.018970076670370872`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0012119453620351717`, 0.01737121685584242}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00038539363988282505`, 0.016571926514956203`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00038539363988282505`, 0.016571926514956203`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0012119453620356158`, 0.01737121685584242}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0022058228686470116`, 0.018970076670370872`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003478684917774366, 0.021369064494901835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005142352774532455, 0.024569018811650523`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0073088755231314195`, 0.028571058863150256`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010090595689100645`, 0.03337658574086433}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013600215261497794`, 0.038987283749630564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017950862206149054`, 0.045405122050848234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021390746903323432`, 0.041762886811248734`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015810036904928992`, 0.0341163954264303}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011295534899385729`, 0.027242172404402965`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007733341861408505, 0.021137801087849795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005010117318461127, 0.015801139235147588`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0030130118578455267`, 0.011230316924695671`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0016296003065709996`, 0.007423734729936626}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.000747815491062287, 0.00438006216193898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0002558824847915808, 0.002098236375292828}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00004225325388862444, 0.0005774611364763871}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-4.458388987660378*^-6, -0.00018279394849329833`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{4.458388987660378*^-6, -0.00018279394849329833`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0000422532538884024, 0.0005774611364763871}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0002558824847915808, 0.002098236375292828}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0007478154910613988, 0.00438006216193898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0016296003065709996`, 0.007423734729936626}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0030130118578455267`, 0.011230316924695671`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005010117318461127, 0.015801139235147588`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007733341861410281, 0.021137801087849795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011295534899389281`, 0.027242172404406517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01581003690493077, 0.0341163954264303}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021390746903323432`, 0.041762886811248734`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026864984404426195`, 0.04190937567090813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019567190140122648`, 0.0331791484984727}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01356231979516842, 0.025187165333885986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008735425056338286, 0.01793060932617152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0049722508324716586`, 0.011406928380381487`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0021591664042972525`, 0.005613832651174988}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00018309743351618835`, 0.0005492923005547823}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010685412649156234`, -0.003788464484699716}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0017079122814891434`, -0.007400953219786288}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0018468215939848598`, -0.010289434595058822`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0015967840641515352`, -0.012454915700377711`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010690885385573612`, -0.013898151001253467`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00037486264280500725`, -0.014619643069394783`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00037486264280500725`, -0.014619643069394783`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010690885385578053`, -0.013898151001253467`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0015967840641515352`, -0.012454915700377711`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.001846821593985748, -0.010289434595058822`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0017079122814891434`, -0.007400953219786288}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010685412649156234`, -0.003788464484699716}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00018309743351618835`, 0.0005492923005547823}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0021591664042981407`, 0.005613832651174988}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0049722508324716586`, 0.011406928380381487`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008735425056340063, 0.01793060932617152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013562319795166644`, 0.025187165333885986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019567190140122648`, 0.0331791484984727}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026864984404426195`, 0.04190937567090813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02599112374986845, 0.03561746587944725}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018007792003496448`, 0.026651532165171687`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011429964729828157`, 0.01838733456538222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00614219220482326, 0.01082195769420835}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0020297849043124927`, 0.003952739024189356}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010212560394755599`, -0.0022227337329745467`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031243074292301998`, -0.00770662499209962}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004392191738989304, -0.012500853410966073`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00493724409114904, -0.01660709376113445}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004871378568175544, -0.020026778558055014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0043061539502096124`, -0.0227610994511096}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003352838970237748, -0.024811008379757027`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0021224771752228477`, -0.02617721849441068}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.000725951482331233, -0.02686020484625118}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.000725951482331233, -0.02686020484625118}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0021224771752224036`, -0.02617721849441068}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003352838970237304, -0.024811008379757027`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004306153950210501, -0.0227610994511096}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004871378568175544, -0.020026778558055014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00493724409114904, -0.01660709376113445}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004392191738989304, -0.012500853410966073`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031243074292301998`, -0.00770662499209962}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010212560394737835`, -0.0022227337329745467`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0020297849043124927`, 0.003952739024189356}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006142192204821484, 0.01082195769420835}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011429964729828157`, 0.01838733456538222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018007792003496448`, 0.026651532165171687`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02599112374986845, 0.03561746587944725}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03620687140642076, 0.04087872578144314}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02575299478494486, 0.03108120060252162}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016934627989977358`, 0.02195229554256528}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009634840997042815, 0.013488777395860296`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0037376031487124095`, 0.005687656965427834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0008722883377156876, -0.0014538138962016944`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004309278711867037, -0.00793814499554557}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006687124985687021, -0.013767610264647345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008118964280293461, -0.01894424998735289}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008717381322618678, -0.023469872791661572`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008594475186333383, -0.02734605741106222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007861925370479028, -0.030574154218527383`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006631057307159072, -0.03315528653579847}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005012907388638688, -0.03509035172047348}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031182876029411943`, -0.03638002203431867}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010578498654736923`, -0.0370247452915784}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010578498654736923`, -0.0370247452915784}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031182876029411943`, -0.03638002203431867}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005012907388638688, -0.03509035172047348}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006631057307159516, -0.03315528653579847}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007861925370479028, -0.030574154218527383`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008594475186333383, -0.02734605741106222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00871738132261779, -0.023469872791661572`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008118964280291685, -0.01894424998735289}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006687124985685244, -0.013767610264647345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004309278711867037, -0.00793814499554557}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0008722883377139112, -0.0014538138961981417`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0037376031487124095`, 0.005687656965427834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009634840997042815, 0.013488777395860296`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016934627989977358`, 0.02195229554256528}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02575299478494486, 0.031081200602525172`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036206871406422536`, 0.04087872578144314}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03792645086889479, 0.03792645086889479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026373169319297673`, 0.028074664114095427`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016569803384603787`, 0.01885529350661841}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00839869231791468, 0.010265068388559229`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0017431442458804014`, 0.00230095040456213}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003512636327728913, -0.005039869513700168}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007483619769905303, -0.011759973924135636`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010284021421703926`, -0.017861721416645437`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012027370659595249`, -0.023347248927446884`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01282657901307882, -0.02821847382877607}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012794007435910082`, -0.03247709579884983}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012041532824783374`, -0.036124598474348346`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010680613879261891`, -0.03916225089062664}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008822356393062059, -0.04159110871015237}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006577578067172407, -0.04341201524333904}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004056872932988398, -0.04462560226287593}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0013706754730992698`, -0.04523229061227241}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0013706754730992698`, -0.04523229061227241}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004056872932988398, -0.04462560226287593}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006577578067172851, -0.04341201524333904}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008822356393062059, -0.04159110871015237}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01068061387926278, -0.03916225089062664}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012041532824783374`, -0.036124598474348346`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012794007435910082`, -0.03247709579884983}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01282657901307882, -0.02821847382877607}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012027370659593473`, -0.023347248927446884`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01028402142170215, -0.017861721416645437`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007483619769903527, -0.01175997392413386}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003512636327728913, -0.005039869513700168}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0017431442458804014`, 0.00230095040456213}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00839869231791468, 0.010265068388559229`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016569803384603787`, 0.01885529350661841}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026373169319303003`, 0.028074664114097203`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03792645086889834, 0.037926450868896566`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04087872578144314, 0.03620687140642076}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028074664114095427`, 0.026373169319297673`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017135711738831105`, 0.017135711738831105`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007943394897955258, 0.008491215235745031}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0003802792849967318, 0.0004366169568470468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0056701035682475975`, -0.007030928424624605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010323328554219913`, -0.013914051529603455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013694148008493556`, -0.020215170869683163`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01589656158957453, -0.025936495225096223`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01704388512137278, -0.031080025809561818`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01724881849585813, -0.035647558224768616`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016623512732828694`, -0.039640684209052424`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015279636290934206`, -0.04306079318354605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013328440722188084`, -0.045909073598647154`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010880825760879898`, -0.048186514083896625`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008047403935774522, -0.049893904401805855`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004938564794518152, -0.05103183621002039}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0016645388268028416`, -0.05160070363088387}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0016645388268028416`, -0.05160070363088387}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00493856479451793, -0.05103183621002039}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008047403935774966, -0.049893904401805855`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010880825760879898`, -0.04818651408389307}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013328440722216506`, -0.04590907359875196}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015279636290934206`, -0.04306079318354605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016623512732827805`, -0.03964068420905065}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01724881849585813, -0.035647558224768616`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017043885121371005`, -0.031080025809561818`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01589656158957453, -0.025936495225096223`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013694148008495333`, -0.020215170869681387`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010323328554219913`, -0.013914051529603455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0056701035682475975`, -0.007030928424624605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0003802792849967318, 0.0004366169568470468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007943394897958811, 0.008491215235746807}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017135711738774262`, 0.017135711738776038`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02807466411409898, 0.026373169319297673`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04087872578144669, 0.03620687140642076}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03108120060252162, 0.02575299478494486}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01885529350661841, 0.016569803384603787`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008491215235745031, 0.007943394897955258}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00012929328064359424`, -0.00012929328064359424`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007123454719657474, -0.007651118032223181}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012607528753539654`, -0.01462473335410941}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01669688409361214, -0.02105259298759954}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019506069295696093`, -0.026936952836916106`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021148882431841542`, -0.03227987318544656}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02173843972754419, -0.03708322071169157}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021387243264249456`, -0.041348670310883406`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020207247841632636`, -0.045077706723644084`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018309927094829703`, -0.04827162597727508}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015806338957204957`, -0.050931536639883035`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012807190559919857`, -0.05305836089109839}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009422902657236776, -0.054652835411980405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005763673664920699, -0.055715512094229425`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0019395433990042066`, -0.05624675857112038}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0019395433990042066`, -0.05624675857112038}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005763673664920255, -0.055715512094229425`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009422902657238108, -0.054652835411980405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012807190559919412`, -0.05305836089109661}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015806338957204957`, -0.050931536639883035`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018309927094829703`, -0.04827162597727508}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020207247841633524`, -0.04507770672364053}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021387243264249456`, -0.04134867031087808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02173843972754419, -0.03708322071169157}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02114888243184332, -0.03227987318544656}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019506069295694317`, -0.026936952836912553`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01669688409361214, -0.02105259298759954}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012607528753539654`, -0.01462473335410941}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007123454719657474, -0.007651118032223181}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00012929328064004153`, -0.00012929328063826517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008491215235745031, 0.007943394897957035}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018855293506621962`, 0.016569803384603787`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.031081200602525172`, 0.025752994784946637`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03561746587944725, 0.02599112374986845}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02195229554256528, 0.016934627989977358`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010265068388559229`, 0.00839869231791468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0004366169568470468, 0.0003802792849967318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007651118032223181, -0.007123454719657474}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014115162307446028`, -0.014115162307446028`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019071581226555168`, -0.020597307724676384`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0226355516173804, -0.026572169289968528`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02492143238494826, -0.032041841637790114`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026042833988885405`, -0.037008237773681785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02611268689094004, -0.04147309094443585}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025243309070912545`, -0.04543795632764436}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023546472705392674`, -0.04890421254197008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021133470104708785`, -0.05187306298428318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018115178997491377`, -0.054345536992476795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01460212725465082, -0.056322490839367134`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01070455714024332, -0.05780460855731384}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006532489177378364, -0.058792402596404614`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0021957857154382143`, -0.0592862143168329}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0021957857154382143`, -0.0592862143168329}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00653248917737792, -0.058792402596404614`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01070455714024332, -0.05780460855731384}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014602127254650377`, -0.05632249083936536}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018115178997491377`, -0.054345536992476795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021133470104708785`, -0.05187306298428318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023546472705393562`, -0.04890421254197008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025243309070911657`, -0.04543795632764258}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02611268689094004, -0.04147309094443408}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026042833988885405`, -0.03700823777368001}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024921432384946485`, -0.03204184163778834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0226355516173804, -0.026572169289968528`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019071581226555168`, -0.020597307724676384`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014115162307446028`, -0.014115162307446028`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007651118032217852, -0.007123454719653921}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00043661695685415225`, 0.00038027928500383723`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010265068388562781`, 0.00839869231791468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02195229554256528, 0.016934627989979134`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035617465879450805`, 0.025991123749872003`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04190937567090813, 0.026864984404426195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026651532165171687`, 0.018007792003496448`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013488777395860296`, 0.009634840997042815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00230095040456213, 0.0017431442458804014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007030928424624605, -0.0056701035682475975`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01462473335410941, -0.012607528753539654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020597307724676384`, -0.019071581226555168`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02506453694319255, -0.02506453694319255}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02814142013542309, -0.030588500147196385`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02994214056995048, -0.035645405440416056`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030580134955947358`, -0.04023701967887661}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030168161715124597`, -0.04436494369871369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02881836832460305, -0.048030613874336936`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02664235782662505, -0.051235303512740415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023751254598132654`, -0.053980124086665526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020255769470815643`, -0.05626602630782074}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016266264292246646`, -0.05809380104373929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011892816015768748`, -0.05946408007884507}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007245280406583898, -0.060377336721535}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0024333554503604415`, -0.060833886259013426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0024333554503604415`, -0.060833886259013426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007245280406583898, -0.060377336721535}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011892816015768748`, -0.05946408007884507}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01626626429224709, -0.05809380104373929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020255769470814755`, -0.05626602630782074}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023751254598132654`, -0.053980124086665526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02664235782662505, -0.05123530351273686}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02881836832460216, -0.04803061387433516}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03016816171512282, -0.04436494369871191}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03058013495594558, -0.04023701967887661}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.029942140569948705`, -0.035645405440416056`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02814142013542309, -0.030588500147196385`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02506453694319255, -0.02506453694319255}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020597307724676384`, -0.019071581226555168`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014624733354105857`, -0.012607528753537878`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007030928424624605, -0.005670103568244045}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002300950404563906, 0.0017431442458804014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013488777395856744`, 0.009634840997042815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026651532165171687`, 0.018007792003498224`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.041909375670911686`, 0.026864984404431524`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0331791484984727, 0.019567190140122648`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01838733456538222, 0.011429964729828157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005687656965427834, 0.0037376031487124095`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005039869513700168, -0.003512636327728913}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013914051529603455`, -0.010323328554219913`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02105259298759954, -0.01669688409361214}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026572169289968528`, -0.0226355516173804}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030588500147196385`, -0.02814142013542309}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.033216421057348455`, -0.033216421057348455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03456995356162729, -0.03786233009130413}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03476237437692653, -0.0420807689825935}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03390628350572911, -0.045873207095983304`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032113671420730405`, -0.049240962845118474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.029495985418431125`, -0.05218520497106738}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026164195234691157`, -0.054706953672535974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.022228858013876973`, -0.05680708159101755}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017800182719759583`, -0.058486314650634696`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01298809407759105, -0.05974523275691901}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007902296132958675, -0.06058427035268288}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002652335514602977, -0.06100371683586836}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002652335514602977, -0.06100371683586836}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007902296132958453, -0.0605842703526811}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012988094077591494`, -0.05974523275691901}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017800182719759583`, -0.058486314650634696`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.022228858013876973`, -0.056807081591014}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026164195234691157`, -0.054706953672535974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.029495985418430237`, -0.05218520497106738}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03211367142072952, -0.049240962845118474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033906283505725554`, -0.045873207095983304`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.034762374376924754`, -0.0420807689825935}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03456995356162729, -0.03786233009130413}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033216421057348455`, -0.033216421057348455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.030588500147196385`, -0.02814142013542309}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026572169289968528`, -0.0226355516173804}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021052592987601315`, -0.01669688409361214}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013914051529670957`, -0.01032332855426965}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005039869513696615, -0.003512636327728913}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005687656965427834, 0.0037376031487124095`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01838733456538222, 0.011429964729828157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03317914849847625, 0.019567190140124424`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.041762886811248734`, 0.021390746903323432`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025187165333885986`, 0.01356231979516842}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01082195769420835, 0.00614219220482326}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0014538138962016944`, -0.0008722883377156876}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011759973924135636`, -0.007483619769905303}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020215170869683163`, -0.013694148008493556`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026936952836916106`, -0.019506069295696093`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032041841637790114`, -0.02492143238494826}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035645405440416056`, -0.02994214056995048}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03786233009130413, -0.03456995356162729}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03880648921664509, -0.03880648921664509}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03859101320339953, -0.042653225119549276`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.037328357162447645`, -0.04611150002420317}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03513036796701563, -0.04918251515382366}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032108350464416624`, -0.05186733536559629}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02837313295141186, -0.05416689017996923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0240351320041281, -0.05608197467629772}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01920441675271478, -0.057613250258146564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013990772688035058`, -0.05876124528974813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008503765085904558, -0.05952635560133146}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0028528021366392986`, -0.05990884486942427}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0028528021366392986`, -0.05990884486942427}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008503765085904558, -0.05952635560133146}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013990772688035502`, -0.05876124528974813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019204416752715225`, -0.05761325025814479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024035132004127213`, -0.05608197467629772}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02837313295141186, -0.05416689017996923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03210835046441485, -0.05186733536559274}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035130367967013854`, -0.049182515153820106`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.037328357162447645`, -0.04611150002420317}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0385910132034013, -0.0426532251195475}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03880648921664687, -0.03880648921664509}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03786233009130413, -0.03456995356162729}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035645405440416056`, -0.02994214056995048}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.032041841637790114`, -0.02492143238494826}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026936952836912553`, -0.019506069295694317`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020215170869677834`, -0.013694148008490004`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011759973924132083`, -0.007483619769903527}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0014538138961981417`, -0.0008722883377156876}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010821957694204798`, 0.00614219220482326}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025187165333885986`, 0.013562319795171973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.041762886811248734`, 0.021390746903323432`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0341163954264303, 0.015810036904928992`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01793060932617152, 0.008735425056338286}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003952739024189356, 0.0020297849043124927`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00793814499554557, -0.004309278711867037}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017861721416645437`, -0.010284021421703926`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025936495225096223`, -0.01589656158957453}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03227987318544656, -0.021148882431841542`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.037008237773681785`, -0.026042833988885405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04023701967887661, -0.030580134955947358`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0420807689825935, -0.03476237437692653}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042653225119549276`, -0.03859101320339953}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042067385723264294`, -0.042067385723264294`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.040435574453615786`, -0.04519270085992133}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03786950790538768, -0.04796804334682214}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03448036168992097, -0.0503943747775768}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030378835782808977`, -0.05247253453394407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025675219229753132`, -0.054203240596146784`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020479454295736943`, -0.05558709023128472}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014901200149625371`, -0.056624560568577564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009049896166617222, -0.05731600905524026}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0030348249368429836`, -0.05766167380001974}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0030348249368429836`, -0.05766167380001974}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009049896166617, -0.05731600905523848}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014901200149625371`, -0.056624560568577564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020479454295736055`, -0.05558709023128294}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025675219229753132`, -0.05420324059614501}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.030378835782808977`, -0.05247253453394407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03448036168992097, -0.050394374777575024`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0378695079053859, -0.04796804334681859}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04043557445361223, -0.045192700859919555`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.042067385723264294`, -0.042067385723264294`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0426532251195475, -0.03859101320339775}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0420807689825935, -0.03476237437692653}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04023701967887661, -0.030580134955947358`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.037008237773681785`, -0.026042833988885405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03227987318544301, -0.021148882431841542`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02593649522509267, -0.01589656158957098}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017861721416641885`, -0.010284021421703926`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007938144995542018, -0.0043092787118634845`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003952739024189356, 0.0020297849043124927`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01793060932617152, 0.008735425056341839}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0341163954264303, 0.015810036904928992`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04540512205084468, 0.017950862206147278`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027242172404402965`, 0.011295534899385729`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011406928380381487`, 0.0049722508324716586`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0022227337329745467`, -0.0010212560394755599`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013767610264647345`, -0.006687124985687021}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023347248927446884`, -0.012027370659595249`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.031080025809561818`, -0.01704388512137278}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03708322071169157, -0.02173843972754419}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04147309094443585, -0.02611268689094004}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04436494369871369, -0.030168161715124597`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045873207095983304`, -0.03390628350572911}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04611150002420317, -0.037328357162447645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04519270085992133, -0.040435574453615786`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04322901517655886, -0.04322901517655886}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04033204253407341, -0.04570964820528367}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03661284244480534, -0.04787833242782291}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03218199960767443, -0.04973581757549894}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02714968849985233, -0.051282744944165515`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021625737416437474`, -0.05251964801134967}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015719692043244304`, -0.053446952947034276`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009540878651053575, -0.05406497902263396}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031984669950723688`, -0.0543739389162301}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031984669950723688`, -0.0543739389162301}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009540878651052909, -0.05406497902263219}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015719692043245637`, -0.053446952947034276`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021625737416437474`, -0.05251964801134967}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027149688499850555`, -0.05128274494416374}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03218199960767443, -0.04973581757549894}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03661284244480534, -0.04787833242782291}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.040332042534070744`, -0.04570964820527834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04322901517655531, -0.04322901517655531}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04519270085992133, -0.040435574453615786`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04611150002420139, -0.037328357162447645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045873207095983304`, -0.03390628350572911}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04436494369871369, -0.030168161715124597`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04147309094443585, -0.02611268689094004}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03708322071168624, -0.021738439727542413`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.031080025809558265`, -0.01704388512136923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023347248927446884`, -0.012027370659595249`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013767610264647345`, -0.006687124985687021}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002222733732970994, -0.0010212560394755599`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011406928380381487`, 0.0049722508324716586`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.027242172404402965`, 0.011295534899385729`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04540512205084468, 0.017950862206147278`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.038987283749630564`, 0.013600215261497794`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021137801087849795`, 0.007733341861408505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005613832651174988, 0.0021591664042972525`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00770662499209962, -0.0031243074292301998`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01894424998735289, -0.008118964280293461}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02821847382877607, -0.01282657901307882}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035647558224768616`, -0.01724881849585813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.041348670310883406`, -0.021387243264249456`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04543795632764436, -0.025243309070912545`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.048030613874336936`, -0.02881836832460305}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049240962845118474`, -0.032113671420730405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04918251515382366, -0.03513036796701563}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04796804334682214, -0.03786950790538768}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04570964820528367, -0.04033204253407341}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042518825429469054`, -0.042518825429469054`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038506531502565444`, -0.044430613272191444`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03378324882256134, -0.04606806657622098}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028459050195089652`, -0.047431750325148236`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.022643662773131013`, -0.04852213451385179}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016446531533481856`, -0.049339594600445125`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009976882372817464, -0.04988441186408732}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0033437849117172735`, -0.050156773675759325`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0033437849117172735`, -0.050156773675759325`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009976882372817242, -0.04988441186408732}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016446531533481412`, -0.049339594600444237`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02264366277312968, -0.0485221345138509}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028459050195088764`, -0.047431750325148236`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03378324882256134, -0.04606806657622098}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03850653150256367, -0.04443061327218878}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04251882542946461, -0.0425188254294655}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04570964820528012, -0.040332042534070744`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.047968043346820366`, -0.037869507905385014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049182515153825435`, -0.03513036796701563}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049240962845118474`, -0.032113671420730405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048030613874336936`, -0.02881836832460305}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04543795632764436, -0.025243309070912545`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04134867031087808, -0.021387243264245903`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03564755822476329, -0.017248818495852802`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028218473828772517`, -0.01282657901307882}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018944249987349338`, -0.008118964280293461}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007706624992096067, -0.0031243074292301998`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005613832651178541, 0.002159166404299917}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021137801087849795`, 0.007733341861408505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038987283749630564`, 0.013600215261497794`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0533989340338934, 0.01542635872090159}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03337658574086433, 0.010090595689100645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015801139235147588`, 0.005010117318461127}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0005492923005547823, 0.00018309743351618835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012500853410966073`, -0.004392191738989304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023469872791661572`, -0.008717381322618678}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03247709579884983, -0.012794007435910082`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.039640684209052424`, -0.016623512732828694`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045077706723644084`, -0.020207247841632636`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04890421254197008, -0.023546472705392674`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.051235303512740415`, -0.02664235782662505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05218520497106738, -0.029495985418431125`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05186733536559629, -0.032108350464416624`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0503943747775768, -0.03448036168992097}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04787833242782291, -0.03661284244480534}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.044430613272191444`, -0.038506531502565444`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04016208377338426, -0.04016208377338426}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035183136945796, -0.04158007093593952}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.029603756760267608`, -0.042760981987052915`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02353358199825273, -0.04370522371104091}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01708196964206099, -0.04441312106935946}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010358057887386307`, -0.04488491751200829}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003470828862314035, -0.045120775210084396`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003470828862314035, -0.045120775210084396`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010358057887386307`, -0.04488491751200829}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01708196964206099, -0.04441312106935946}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02353358199825273, -0.04370522371104002}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02960375676026672, -0.042760981987052915`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035183136945796, -0.04158007093593952}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04016208377338071, -0.040162083773381596`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04443061327218967, -0.038506531502564556`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04787833242782291, -0.03661284244480534}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.050394374777575024`, -0.03448036168992008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05186733536570998, -0.03210835046448768}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05218520497106738, -0.029495985418431125`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.051235303512740415`, -0.02664235782662505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04890421254197008, -0.023546472705392674`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04507770672364053, -0.020207247841631748`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03964068420904887, -0.01662351273282603}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.032477095798848055`, -0.012794007435910082`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02346987279165802, -0.008717381322616014}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01250085341096252, -0.004392191738985751}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.000549292300558335, 0.0001830974335179647}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015801139235147588`, 0.005010117318461127}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03337658574086433, 0.010090595689100645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0533989340338934, 0.01542635872090159}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048356971927944414`, 0.011820593137940705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028571058863150256`, 0.0073088755231314195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011230316924695671`, 0.0030130118578455267`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003788464484699716, -0.0010685412649156234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01660709376113445, -0.00493724409114904}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02734605741106222, -0.008594475186333383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036124598474348346`, -0.012041532824783374`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04306079318354605, -0.015279636290934206`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04827162597727508, -0.018309927094829703`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05187306298428318, -0.021133470104708785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.053980124086665526`, -0.023751254598132654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054706953672535974`, -0.026164195234691157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05416689017996923, -0.02837313295141186}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05247253453394407, -0.030378835782808977`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04973581757549894, -0.03218199960767443}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04606806657622098, -0.03378324882256134}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04158007093593952, -0.035183136945796}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036382147149988775`, -0.036382147149988775`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03058420314058985, -0.0373806927273872}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0242958020362658, -0.03817911748556213}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01762622548944126, -0.03877769607677095}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01068453661681601, -0.039176634261659515`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00357964264582028, -0.03937606910402369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00357964264582028, -0.03937606910402369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01068453661681601, -0.03917663426165863}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017626225489440817`, -0.038777696076769175`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0242958020362658, -0.038179117485559466`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03058420314058896, -0.03738069272738631}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.036382147149988775`, -0.036382147149988775`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04158007093593863, -0.035183136945793336`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.046068066576217426`, -0.033783248822559564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04973581757549539, -0.03218199960767265}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05247253453394407, -0.03037883578280809}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05416689017996923, -0.028373132951410973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054706953672535974`, -0.026164195234691157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.053980124086665526`, -0.023751254598132654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05187306298428318, -0.021133470104708785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04827162597732304, -0.01830992709484569}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.043060793183540724`, -0.015279636290934206`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03612459847434479, -0.012041532824783374`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027346057411058666`, -0.008594475186333383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01660709376113445, -0.004937244091148152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0037884644846961635`, -0.0010685412649156234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011230316924695671`, 0.0030130118578455267`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028571058863150256`, 0.0073088755231314195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.048356971927944414`, 0.011820593137940705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04415803335978552, 0.008831606671956926}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024569018811650523`, 0.005142352774532455}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007423734729936626, 0.0016296003065709996`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007400953219786288, -0.0017079122814891434`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020026778558055014`, -0.004871378568175544}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030574154218527383`, -0.007861925370479028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03916225089062664, -0.010680613879261891`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045909073598647154`, -0.013328440722188084`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.050931536639883035`, -0.015806338957204957`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054345536992476795`, -0.018115178997491377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05626602630782074, -0.020255769470815643`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05680708159101755, -0.022228858013876973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05608197467629772, -0.0240351320041281}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054203240596146784`, -0.025675219229753132`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.051282744944165515`, -0.02714968849985233}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.047431750325148236`, -0.028459050195089652`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042760981987052915`, -0.029603756760267608`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0373806927273872, -0.03058420314058985}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0314007271611505, -0.0314007271611505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02493058543923965, -0.03205360985045136}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018079486505279796`, -0.03254307570950399}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010956430975632703`, -0.03286929292689855}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0036702637266983196`, -0.03303237354028443}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0036702637266983196`, -0.03303237354028443}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010956430975632703`, -0.032869292926897664`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018079486505278908`, -0.03254307570950221}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024930585439238317`, -0.03205360985044958}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.031400727161147834`, -0.03140072716114872}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0373806927273872, -0.03058420314058985}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04276098198705025, -0.029603756760264943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04743175032514646, -0.028459050195087876`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05128274494416374, -0.027149688499851443`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05420324059614323, -0.025675219229751356`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05608197467629594, -0.024035132004127213`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05680708159101755, -0.022228858013876973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05626602630782074, -0.020255769470815643`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054345536992476795`, -0.018115178997491377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05093153663987948, -0.01580633895720318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0459090735986436, -0.013328440722188084`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.039162250890628414`, -0.010680613879261891`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03057415421852383, -0.007861925370479028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020026778558055014`, -0.004871378568174656}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007400953219779183, -0.001707912281487367}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007423734729936626, 0.0016296003065709996`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.024569018811650523`, 0.005142352774532455}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04415803335978552, 0.008831606671956926}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04080064578449338, 0.006346767122032304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021369064494901835`, 0.003478684917773478}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00438006216193898, 0.000747815491062287}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010289434595058822`, -0.0018468215939848598`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0227610994511096, -0.0043061539502096124`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03315528653579847, -0.006631057307159072}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04159110871015237, -0.008822356393062059}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.048186514083896625`, -0.010880825760879898`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05305836089109839, -0.012807190559919857`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.056322490839367134`, -0.01460212725465082}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05809380104373929, -0.016266264292246646`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.058486314650634696`, -0.017800182719759583`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.057613250258146564`, -0.01920441675271478}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05558709023128472, -0.020479454295736943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05251964801134967, -0.021625737416437474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04852213451385179, -0.022643662773131013`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04370522371104091, -0.02353358199825273}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03817911748556213, -0.0242958020362658}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03205360985045136, -0.02493058543923965}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025438150617765665`, -0.025438150617765665`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01844190860794903, -0.025818672051129088`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01117383447942455, -0.02607228045199106}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003742723270731385, -0.026199062895118974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003742723270731385, -0.026199062895118974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011173834479423883`, -0.026072280451989727`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018441908607948587`, -0.025818672051127756`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02543815061776389, -0.025438150617763}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.032053609850448694`, -0.02493058543923743}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03817911748556213, -0.0242958020362658}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.043705223711038244`, -0.023533581998251396`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048522134513848236`, -0.022643662773129236`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05251964801134612, -0.02162573741643703}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05558709023143571, -0.020479454295793342`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05761325025814479, -0.019204416752713893`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058486314650634696`, -0.017800182719759583`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05809380104373929, -0.016266264292246646`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.056322490839367134`, -0.01460212725465082}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05305836089109128, -0.012807190559918524`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048186514083891296`, -0.010880825760878565`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.041591108710148816`, -0.008822356393061614}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033155286535794914`, -0.006631057307159072}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.022761099451106048`, -0.004306153950208724}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010289434595055269`, -0.0018468215939839716`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00438006216193898, 0.000747815491062287}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021369064494901835`, 0.003478684917773478}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04080064578449338, 0.006346767122032304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03828363288293346, 0.004253736986993051}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018970076670370872`, 0.0022058228686474557`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002098236375292828, 0.0002558824847915808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012454915700377711`, -0.0015967840641515352`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.024811008379757027`, -0.003352838970237748}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03509035172047348, -0.005012907388638688}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04341201524333904, -0.006577578067172407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049893904401805855`, -0.008047403935774522}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054652835411980405`, -0.009422902657236776}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05780460855731384, -0.01070455714024332}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05946408007884507, -0.011892816015768748`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05974523275691901, -0.01298809407759105}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05876124528974813, -0.013990772688035058`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.056624560568577564`, -0.014901200149625371`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.053446952947034276`, -0.015719692043244304`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049339594600445125`, -0.016446531533481856`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04441312106935946, -0.01708196964206099}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03877769607677095, -0.01762622548944126}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03254307570950399, -0.018079486505279796`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025818672051129088`, -0.01844190860794903}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018713616353819074`, -0.018713616353819074`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011336821833585198`, -0.01889470305597518}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003797046175039398, -0.01898523087519699}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003797046175039398, -0.01898523087519699}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011336821833584088`, -0.018894703055973405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01871361635381774, -0.018713616353817297`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02581867205112731, -0.018441908607948143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03254307570950132, -0.018079486505278464`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03877769607677095, -0.01762622548944126}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0444131210693568, -0.017081969642060546`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04933959460044246, -0.01644653153348008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0534469529470325, -0.01571969204324386}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05662456056857579, -0.014901200149624927`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058761245289746356`, -0.013990772688034614`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05974523275691901, -0.01298809407759105}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05946408007884507, -0.011892816015768748`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05780460855731384, -0.01070455714024332}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054652835411975076`, -0.009422902657236776}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049893904401800526`, -0.008047403935774522}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04341201524333549, -0.006577578067171519}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035090351720469926`, -0.005012907388638688}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024811008379753474`, -0.003352838970237748}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012454915700377711`, -0.001596784064150203}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002098236375292828, 0.0002558824847915808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018970076670370872`, 0.0022058228686474557`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03828363288293346, 0.004253736986993051}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03660611341549469, 0.002440407561033364}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01737121685584242, 0.0012119453620351717`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0005774611364763871, 0.00004225325388862444}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013898151001253467`, -0.0010690885385573612`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02617721849441068, -0.0021224771752228477`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03638002203431867, -0.0031182876029411943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04462560226287593, -0.004056872932988398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05103183621002039, -0.004938564794518152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.055715512094229425`, -0.005763673664920699}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.058792402596404614`, -0.006532489177378364}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.060377336721535, -0.007245280406583898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.06058427035268288, -0.007902296132958675}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05952635560133146, -0.008503765085904558}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05731600905524026, -0.009049896166617222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05406497902263396, -0.009540878651053575}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04988441186408732, -0.009976882372817464}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04488491751200829, -0.010358057887386307`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.039176634261659515`, -0.01068453661681601}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03286929292689855, -0.010956430975632703`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02607228045199106, -0.01117383447942455}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01889470305597518, -0.011336821833585198`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01144544900469091, -0.01144544900469091}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0038332510913355877`, -0.011499753274006874`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0038332510913355877`, -0.011499753274006874`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011445449004688912`, -0.011445449004688912`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018894703055972517`, -0.011336821833583643`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02607228045198795, -0.011173834479423439`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.032869292926896776`, -0.010956430975632259`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.039176634261659515`, -0.01068453661681601}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04488491751200474, -0.010358057887385641`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049884411864294265`, -0.009976882372858764}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05406497902263041, -0.009540878651052465}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05731600905523848, -0.009049896166617}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05952635560132791, -0.008503765085904336}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.06058427035268288, -0.007902296132958675}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.060377336721535, -0.007245280406583898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058792402596404614`, -0.006532489177378364}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.055715512094224096`, -0.005763673664920033}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05103183621001506, -0.004938564794517486}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04462560226287238, -0.004056872932988398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03638002203431512, -0.0031182876029411943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02617721849440713, -0.0021224771752226257`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013898151001249914`, -0.0010690885385573612`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0005774611364763871, 0.00004225325388862444}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01737121685584242, 0.0012119453620351717`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03660611341549469, 0.002440407561033364}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03576750036488363, 0.0007948333414418696}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016571926514910018`, 0.0003853936398817148}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00018279394849329833`, -4.458388987660378*^-6}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014619643069394783`, -0.00037486264280500725`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02686020484625118, -0.000725951482331233}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0370247452915784, -0.0010578498654736923`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04523229061227241, -0.0013706754730992698`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05160070363088387, -0.0016645388268028416`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05624675857112038, -0.0019395433990042066`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0592862143168329, -0.0021957857154382143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.060833886259013426`, -0.0024333554503604415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.06100371683586836, -0.002652335514602977}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05990884486942427, -0.0028528021366392986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05766167380001974, -0.0030348249368429836`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0543739389162301, -0.0031984669950723688`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.050156773675759325`, -0.0033437849117172735`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04512077521020874, -0.0034708288623236383`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03937606910402369, -0.00357964264582028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03303237354028443, -0.0036702637266983196`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026199062895118974`, -0.003742723270731385}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01898523087519699, -0.003797046175039398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011499753274006874`, -0.0038332510913355877`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0038513504456252345`, -0.0038513504456252345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0038513504456252345`, -0.0038513504456252345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011499753274003988`, -0.003833251091334644}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018985230875193437`, -0.0037970461750386764`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02619906289511542, -0.003742723270730608}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03303237354027999, -0.00367026372669782}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03937606910402369, -0.00357964264582028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04512077521020519, -0.0034708288623233607`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05015677367575577, -0.0033437849117169405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05437393891622655, -0.0031984669950722577`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05766167380001619, -0.0030348249368428726`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05990884486942072, -0.002852802136639132}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.06100371683586836, -0.002652335514602977}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.060833886259013426`, -0.0024333554503604415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0592862143168329, -0.0021957857154382143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05624675857111505, -0.001939543399003929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05160070363087321, -0.0016645388268023975`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045232290612268855`, -0.0013706754730992143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03702474529157129, -0.0010578498654735813`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026860204846247626`, -0.0007259514823310109}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01461964306939123, -0.0003748626428048407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00018279394849329833`, -4.458388987660378*^-6}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016571926514910018`, 0.0003853936398817148}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03576750036488363, 0.0007948333414418696}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03576750036488363, -0.0007948333414418696}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016571926514910018`, -0.0003853936398817148}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00018279394849329833`, 4.458388987660378*^-6}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014619643069394783`, 0.00037486264280500725`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02686020484625118, 0.000725951482331233}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0370247452915784, 0.0010578498654736923`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04523229061227241, 0.0013706754730992698`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05160070363088387, 0.0016645388268028416`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05624675857112038, 0.0019395433990042066`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0592862143168329, 0.0021957857154382143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.060833886259013426`, 0.0024333554503604415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.06100371683586836, 0.002652335514602977}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05990884486942427, 0.0028528021366392986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05766167380001974, 0.0030348249368429836`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0543739389162301, 0.0031984669950723688`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.050156773675759325`, 0.0033437849117172735`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04512077521020874, 0.0034708288623236383`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03937606910402369, 0.00357964264582028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03303237354028443, 0.0036702637266983196`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026199062895118974`, 0.003742723270731385}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01898523087519699, 0.003797046175039398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011499753274006874`, 0.0038332510913355877`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0038513504456252345`, 0.0038513504456252345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0038513504456252345`, 0.0038513504456252345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011499753274003988`, 0.003833251091334644}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018985230875193437`, 0.0037970461750386764`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02619906289511542, 0.003742723270730608}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03303237354027999, 0.00367026372669782}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03937606910402369, 0.00357964264582028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04512077521020519, 0.0034708288623233607`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05015677367575577, 0.0033437849117169405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05437393891622655, 0.0031984669950722577`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05766167380001619, 0.0030348249368428726`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05990884486942072, 0.002852802136639132}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.06100371683586836, 0.002652335514602977}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.060833886259013426`, 0.0024333554503604415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0592862143168329, 0.0021957857154382143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05624675857111505, 0.001939543399003929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05160070363087321, 0.0016645388268023975`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045232290612268855`, 0.0013706754730992143`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03702474529157129, 0.0010578498654735813`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026860204846247626`, 0.0007259514823310109}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01461964306939123, 0.0003748626428048407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00018279394849329833`, 4.458388987660378*^-6}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016571926514910018`, -0.0003853936398817148}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03576750036488363, -0.0007948333414418696}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03660611341549469, -0.0024404075610335862`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01737121685584242, -0.0012119453620356158`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0005774611364763871, -0.0000422532538884024}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013898151001253467`, 0.0010690885385578053`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02617721849441068, 0.0021224771752224036`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03638002203431867, 0.0031182876029411943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04462560226287593, 0.004056872932988398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05103183621002039, 0.00493856479451793}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.055715512094229425`, 0.005763673664920255}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.058792402596404614`, 0.00653248917737792}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.060377336721535, 0.007245280406583898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0605842703526811, 0.007902296132958453}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05952635560133146, 0.008503765085904558}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05731600905523848, 0.009049896166617}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05406497902263219, 0.009540878651052909}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04988441186408732, 0.009976882372817242}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04488491751200829, 0.010358057887386307`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03917663426165863, 0.01068453661681601}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032869292926897664`, 0.010956430975632703`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026072280451989727`, 0.011173834479423883`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018894703055973405`, 0.011336821833584088`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011445449004688912`, 0.011445449004688912`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003833251091334644, 0.011499753274003988`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003833251091334644, 0.011499753274003988`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011445449004687136`, 0.011445449004687136`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01889470305597074, 0.01133682183358209}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026072280451986174`, 0.011173834479422107`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.032869292926895, 0.010956430975632259`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03917663426165863, 0.01068453661681601}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04488491751200474, 0.010358057887385419`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049884411864294265`, 0.009976882372858764}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05406497902263041, 0.009540878651052243}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05731600905523848, 0.009049896166617}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05952635560132791, 0.008503765085904114}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0605842703526811, 0.007902296132958453}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.060377336721535, 0.007245280406583898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058792402596404614`, 0.00653248917737792}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.055715512094224096`, 0.005763673664920033}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05103183621001506, 0.004938564794517486}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04462560226287238, 0.004056872932988398}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03638002203431512, 0.0031182876029411943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02617721849440713, 0.0021224771752221816`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013898151001249914`, 0.0010690885385575832`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0005774611364763871, -0.0000422532538884024}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01737121685584242, -0.0012119453620356158`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03660611341549469, -0.0024404075610335862`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03828363288293346, -0.004253736986992163}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018970076670370872`, -0.0022058228686470116`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002098236375292828, -0.0002558824847915808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012454915700377711`, 0.0015967840641515352`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.024811008379757027`, 0.003352838970237304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03509035172047348, 0.005012907388638688}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04341201524333904, 0.006577578067172851}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049893904401805855`, 0.008047403935774966}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054652835411980405`, 0.009422902657238108}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05780460855731384, 0.01070455714024332}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05946408007884507, 0.011892816015768748`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05974523275691901, 0.012988094077591494`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05876124528974813, 0.013990772688035502`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.056624560568577564`, 0.014901200149625371`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.053446952947034276`, 0.015719692043245637`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049339594600444237`, 0.016446531533481412`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04441312106935946, 0.01708196964206099}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038777696076769175`, 0.017626225489440817`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03254307570950221, 0.018079486505278908`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025818672051127756`, 0.018441908607948587`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018713616353817297`, 0.01871361635381774}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011336821833583643`, 0.018894703055972517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0037970461750386764`, 0.018985230875193437`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0037970461750386764`, 0.018985230875193437`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01133682183358209, 0.01889470305597074}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01871361635381552, 0.01871361635381552}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025818672051125535`, 0.018441908607946367`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03254307570949955, 0.01807948650527802}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.038777696076769175`, 0.017626225489440817`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04441312106935591, 0.017081969642060102`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04933959460044157, 0.01644653153348008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.053446952947030724`, 0.01571969204324475}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05662456056857401, 0.014901200149624483`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058761245289746356`, 0.013990772688035502`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05974523275691901, 0.012988094077591494`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05946408007884507, 0.011892816015768748`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05780460855731384, 0.01070455714024332}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054652835411975076`, 0.009422902657238108}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049893904401800526`, 0.008047403935774078}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04341201524333549, 0.006577578067171519}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035090351720469926`, 0.005012907388638688}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024811008379753474`, 0.003352838970237304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012454915700374158`, 0.001596784064150203}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002098236375292828, -0.0002558824847915808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018970076670370872`, -0.0022058228686470116`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03828363288293346, -0.004253736986992163}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.040800645784496936`, -0.006346767122032304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021369064494901835`, -0.003478684917774366}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00438006216193898, -0.0007478154910613988}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010289434595058822`, 0.001846821593985748}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0227610994511096, 0.004306153950210501}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03315528653579847, 0.006631057307159516}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04159110871015237, 0.008822356393062059}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04818651408389307, 0.010880825760879898`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05305836089109661, 0.012807190559919412`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05632249083936536, 0.014602127254650377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05809380104373929, 0.01626626429224709}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.058486314650634696`, 0.017800182719759583`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05761325025814479, 0.019204416752715225`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05558709023128294, 0.020479454295736055`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05251964801134967, 0.021625737416437474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0485221345138509, 0.02264366277312968}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04370522371104002, 0.02353358199825273}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038179117485559466`, 0.0242958020362658}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03205360985044958, 0.024930585439238317`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025438150617763, 0.02543815061776389}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018441908607948143`, 0.02581867205112731}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011173834479423439`, 0.02607228045198795}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003742723270730608, 0.02619906289511542}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003742723270730608, 0.02619906289511542}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011173834479422107`, 0.026072280451986174`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018441908607946367`, 0.025818672051125535`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025438150617761668`, 0.025438150617761668`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03205360985044692, 0.02493058543923654}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.038179117485559466`, 0.0242958020362658}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04370522371103647, 0.023533581998250952`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04852213451384735, 0.022643662773128348`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.052519648011344344`, 0.02162573741643614}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05558709023143571, 0.020479454295792898`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05761325025814479, 0.019204416752715225`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.058486314650634696`, 0.017800182719759583`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05809380104373929, 0.01626626429224709}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05632249083936536, 0.014602127254650377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05305836089109128, 0.012807190559918524`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048186514083891296`, 0.010880825760878565`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.041591108710148816`, 0.00882235639306117}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033155286535794914`, 0.006631057307159516}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.022761099451102496`, 0.00430615395020828}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010289434595055269`, 0.0018468215939844157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00438006216193898, -0.0007478154910613988}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021369064494901835`, -0.003478684917774366}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.040800645784496936`, -0.006346767122032304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04415803335978552, -0.008831606671957815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024569018811650523`, -0.005142352774532455}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007423734729936626, -0.0016296003065709996`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007400953219786288, 0.0017079122814891434`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020026778558055014`, 0.004871378568175544}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030574154218527383`, 0.007861925370479028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03916225089062664, 0.01068061387926278}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04590907359875196, 0.013328440722216506`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.050931536639883035`, 0.015806338957204957`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054345536992476795`, 0.018115178997491377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05626602630782074, 0.020255769470814755`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.056807081591014, 0.022228858013876973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05608197467629772, 0.024035132004127213`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05420324059614501, 0.025675219229753132`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05128274494416374, 0.027149688499850555`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.047431750325148236`, 0.028459050195088764`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042760981987052915`, 0.02960375676026672}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03738069272738631, 0.03058420314058896}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03140072716114872, 0.031400727161147834`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02493058543923743, 0.032053609850448694`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018079486505278464`, 0.03254307570950132}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010956430975632259`, 0.032869292926896776`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00367026372669782, 0.03303237354027999}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00367026372669782, 0.03303237354027999}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010956430975632259`, 0.032869292926895}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01807948650527802, 0.03254307570949955}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02493058543923654, 0.03205360985044692}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.031400727161146946`, 0.031400727161146946`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03738069272738631, 0.03058420314058896}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04276098198704936, 0.029603756760264943`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.047431750325144684`, 0.028459050195086988`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.051282744944160186`, 0.027149688499850555`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05420324059614323, 0.025675219229752244`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05608197467629594, 0.024035132004126325`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.056807081591014, 0.022228858013876973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05626602630782074, 0.020255769470814755`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054345536992476795`, 0.018115178997491377`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.050931536639877706`, 0.01580633895720318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04590907359874663, 0.013328440722215618`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.039162250890628414`, 0.01068061387926278}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03057415421852383, 0.007861925370479028}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020026778558055014`, 0.004871378568174656}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007400953219779183, 0.001707912281487367}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007423734729936626, -0.0016296003065709996`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.024569018811650523`, -0.005142352774532455}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04415803335978552, -0.008831606671957815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.048356971927944414`, -0.011820593137940705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028571058863150256`, -0.0073088755231314195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011230316924695671`, -0.0030130118578455267`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003788464484699716, 0.0010685412649156234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01660709376113445, 0.00493724409114904}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02734605741106222, 0.008594475186333383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036124598474348346`, 0.012041532824783374`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04306079318354605, 0.015279636290934206`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04827162597727508, 0.018309927094829703`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05187306298428318, 0.021133470104708785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.053980124086665526`, 0.023751254598132654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.054706953672535974`, 0.026164195234691157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05416689017996923, 0.02837313295141186}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05247253453394407, 0.030378835782808977`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04973581757549894, 0.03218199960767443}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04606806657622098, 0.03378324882256134}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04158007093593952, 0.035183136945796}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036382147149988775`, 0.036382147149988775`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03058420314058985, 0.0373806927273872}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0242958020362658, 0.03817911748556213}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01762622548944126, 0.03877769607677095}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01068453661681601, 0.039176634261659515`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00357964264582028, 0.03937606910402369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00357964264582028, 0.03937606910402369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01068453661681601, 0.03917663426165863}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017626225489440817`, 0.038777696076769175`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0242958020362658, 0.038179117485559466`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03058420314058896, 0.03738069272738631}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.036382147149988775`, 0.036382147149988775`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04158007093593863, 0.035183136945793336`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.046068066576217426`, 0.033783248822559564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04973581757549539, 0.03218199960767265}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05247253453394407, 0.03037883578280809}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05416689017996923, 0.028373132951410973`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.054706953672535974`, 0.026164195234691157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.053980124086665526`, 0.023751254598132654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05187306298428318, 0.021133470104708785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04827162597732304, 0.01830992709484569}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.043060793183540724`, 0.015279636290934206`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03612459847434479, 0.012041532824783374`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027346057411058666`, 0.008594475186333383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01660709376113445, 0.004937244091148152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0037884644846961635`, 0.0010685412649156234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011230316924695671`, -0.0030130118578455267`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028571058863150256`, -0.0073088755231314195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.048356971927944414`, -0.011820593137940705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05339893403389695, -0.015426358720904254`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03337658574086433, -0.010090595689100645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015801139235147588`, -0.005010117318461127}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0005492923005547823, -0.00018309743351618835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012500853410966073`, 0.004392191738989304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023469872791661572`, 0.00871738132261779}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03247709579884983, 0.012794007435910082`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03964068420905065, 0.016623512732827805`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04507770672364053, 0.020207247841633524`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04890421254197008, 0.023546472705393562`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05123530351273686, 0.02664235782662505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05218520497106738, 0.029495985418430237`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05186733536559274, 0.03210835046441485}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.050394374777575024`, 0.03448036168992097}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04787833242782291, 0.03661284244480534}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04443061327218878, 0.03850653150256367}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.040162083773381596`, 0.04016208377338071}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035183136945793336`, 0.04158007093593863}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.029603756760264943`, 0.04276098198705025}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023533581998251396`, 0.043705223711038244`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017081969642060546`, 0.0444131210693568}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010358057887385641`, 0.04488491751200474}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0034708288623233607`, 0.04512077521020519}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0034708288623233607`, 0.04512077521020519}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010358057887385419`, 0.04488491751200474}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017081969642060102`, 0.04441312106935591}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023533581998250952`, 0.04370522371103647}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.029603756760264943`, 0.04276098198704936}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035183136945793336`, 0.04158007093593863}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04016208377337893, 0.04016208377337893}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.044430613272187, 0.038506531502561}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04787833242781936, 0.03661284244480356}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05039437477757325, 0.03448036168991919}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0518673353657082, 0.03210835046448679}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05218520497106738, 0.029495985418430237`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.05123530351273686, 0.02664235782662505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04890421254197008, 0.023546472705393562`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045077706723638755`, 0.02020724784162997}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03964068420904887, 0.016623512732826917`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03247709579884628, 0.012794007435909194`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02346987279165802, 0.008717381322616014}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01250085341096252, 0.004392191738988416}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.000549292300558335, -0.00018309743351885288`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015801139235147588`, -0.005010117318461127}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03337658574086433, -0.010090595689100645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.05339893403389695, -0.015426358720904254`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.038987283749630564`, -0.013600215261497794`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021137801087849795`, -0.007733341861410281}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005613832651174988, -0.0021591664042981407`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00770662499209962, 0.0031243074292301998`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01894424998735289, 0.008118964280291685}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02821847382877607, 0.01282657901307882}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035647558224768616`, 0.01724881849585813}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04134867031087808, 0.021387243264249456`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04543795632764258, 0.025243309070911657`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04803061387433516, 0.02881836832460216}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049240962845118474`, 0.03211367142072952}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.049182515153820106`, 0.035130367967013854`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04796804334681859, 0.0378695079053859}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04570964820527834, 0.040332042534070744`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0425188254294655, 0.04251882542946461}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038506531502564556`, 0.04443061327218967}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.033783248822559564`, 0.046068066576217426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028459050195087876`, 0.04743175032514646}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.022643662773129236`, 0.048522134513848236`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01644653153348008, 0.04933959460044246}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009976882372858764, 0.049884411864294265`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0033437849117169405`, 0.05015677367575577}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0033437849117169405`, 0.05015677367575577}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009976882372858764, 0.049884411864294265`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01644653153348008, 0.04933959460044157}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.022643662773128348`, 0.04852213451384735}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028459050195086988`, 0.047431750325144684`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033783248822559564`, 0.046068066576217426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.038506531502561, 0.044430613272187}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.042518825429463725`, 0.042518825429463725`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045709648205276565`, 0.04033204253406897}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04796804334681859, 0.037869507905385014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04918251515382188, 0.035130367967013854`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.049240962845118474`, 0.03211367142072952}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04803061387433516, 0.02881836832460216}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04543795632764258, 0.025243309070911657`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0413486703108763, 0.021387243264248568`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03564755822476329, 0.01724881849585458}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028218473828772517`, 0.01282657901307882}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018944249987349338`, 0.008118964280291685}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007706624992096067, 0.0031243074292284234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005613832651178541, -0.002159166404300805}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021137801087849795`, -0.007733341861410281}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.038987283749630564`, -0.013600215261497794`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045405122050848234`, -0.017950862206149054`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027242172404406517`, -0.011295534899389281`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011406928380381487`, -0.0049722508324716586`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0022227337329745467`, 0.0010212560394737835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013767610264647345`, 0.006687124985685244}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023347248927446884`, 0.012027370659593473`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.031080025809561818`, 0.017043885121371005`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03708322071169157, 0.02173843972754419}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04147309094443408, 0.02611268689094004}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04436494369871191, 0.03016816171512282}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045873207095983304`, 0.033906283505725554`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04611150002420317, 0.037328357162447645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045192700859919555`, 0.04043557445361223}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04322901517655531, 0.04322901517655531}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.040332042534070744`, 0.04570964820528012}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03661284244480534, 0.04787833242782291}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03218199960767265, 0.04973581757549539}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.027149688499851443`, 0.05128274494416374}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02162573741643703, 0.05251964801134612}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01571969204324386, 0.0534469529470325}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009540878651052465, 0.05406497902263041}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031984669950722577`, 0.05437393891622655}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031984669950722577`, 0.05437393891622655}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009540878651052243, 0.05406497902263041}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01571969204324475, 0.053446952947030724`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02162573741643614, 0.052519648011344344`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.027149688499850555`, 0.051282744944160186`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03218199960767265, 0.04973581757549539}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03661284244480356, 0.04787833242781936}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04033204253406897, 0.045709648205276565`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04322901517655353, 0.04322901517655353}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045192700859919555`, 0.04043557445361223}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04611150002420139, 0.037328357162447645`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.045873207095983304`, 0.033906283505725554`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04436494369871191, 0.03016816171512282}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04147309094443408, 0.02611268689094004}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03708322071168624, 0.02173843972754419}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.031080025809558265`, 0.01704388512136923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023347248927446884`, 0.012027370659593473`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013767610264643793`, 0.006687124985683468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002222733732970994, 0.0010212560394720072`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01140692838038504, -0.004972250832475211}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.027242172404406517`, -0.011295534899389281`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.045405122050848234`, -0.017950862206149054`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0341163954264303, -0.01581003690493077}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01793060932617152, -0.008735425056340063}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003952739024189356, -0.0020297849043124927`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00793814499554557, 0.004309278711867037}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017861721416645437`, 0.01028402142170215}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025936495225096223`, 0.01589656158957453}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03227987318544656, 0.02114888243184332}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03700823777368001, 0.026042833988885405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04023701967887661, 0.03058013495594558}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0420807689825935, 0.034762374376924754`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0426532251195475, 0.0385910132034013}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.042067385723264294`, 0.042067385723264294`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.040435574453615786`, 0.04519270085992133}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.037869507905385014`, 0.047968043346820366`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03448036168992008, 0.050394374777575024`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03037883578280809, 0.05247253453394407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025675219229751356`, 0.05420324059614323}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020479454295793342`, 0.05558709023143571}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014901200149624927`, 0.05662456056857579}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009049896166617, 0.05731600905523848}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0030348249368428726`, 0.05766167380001619}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0030348249368428726`, 0.05766167380001619}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009049896166617, 0.05731600905523848}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014901200149624483`, 0.05662456056857401}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020479454295792898`, 0.05558709023143571}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025675219229752244`, 0.05420324059614323}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03037883578280809, 0.05247253453394407}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03448036168991919, 0.05039437477757325}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.037869507905385014`, 0.04796804334681859}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04043557445361223, 0.045192700859919555`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04206738572326252, 0.04206738572326252}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.042653225119545723`, 0.03859101320339953}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0420807689825935, 0.034762374376924754`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04023701967887661, 0.03058013495594558}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03700823777368001, 0.026042833988885405`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03227987318544301, 0.021148882431839766`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02593649522508734, 0.01589656158957098}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017861721416641885`, 0.01028402142170215}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007938144995542018, 0.004309278711867037}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003952739024189356, -0.0020297849043124927`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01793060932617152, -0.008735425056343615}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0341163954264303, -0.01581003690493077}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.041762886811248734`, -0.021390746903323432`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025187165333885986`, -0.013562319795166644`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01082195769420835, -0.006142192204821484}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0014538138961981417`, 0.0008722883377139112}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01175997392413386, 0.007483619769903527}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020215170869681387`, 0.013694148008495333`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026936952836912553`, 0.019506069295694317`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03204184163778834, 0.024921432384946485`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035645405440416056`, 0.029942140569948705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03786233009130413, 0.03456995356162729}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03880648921664509, 0.03880648921664687}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03859101320339775, 0.0426532251195475}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.037328357162447645`, 0.04611150002420139}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03513036796701563, 0.049182515153825435`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032108350464415736`, 0.051867335365594514`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028373132951410973`, 0.05416689017996923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.024035132004127213`, 0.05608197467629594}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019204416752713893`, 0.05761325025814479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013990772688034614`, 0.058761245289746356`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008503765085904336, 0.05952635560132791}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002852802136639132, 0.05990884486942072}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002852802136639132, 0.05990884486942072}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008503765085904114, 0.05952635560132791}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013990772688035502`, 0.058761245289746356`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019204416752715225`, 0.05761325025814479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024035132004126325`, 0.05608197467629594}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028373132951410973`, 0.05416689017996923}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03210835046441396, 0.05186733536559096}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035130367967013854`, 0.04918251515382188}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.037328357162447645`, 0.04611150002420139}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03859101320339953, 0.042653225119545723`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03880648921664687, 0.03880648921664687}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03786233009130413, 0.03456995356162729}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.035645405440416056`, 0.029942140569948705`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03204184163778834, 0.024921432384946485`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026936952836912553`, 0.019506069295694317`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020215170869677834`, 0.01369414800849178}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011759973924132083`, 0.007483619769903527}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.001453813896194589, 0.0008722883377139112}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010821957694211903`, -0.00614219220482326}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025187165333885986`, -0.01356231979516842}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.041762886811248734`, -0.021390746903323432`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0331791484984727, -0.019567190140122648`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01838733456538222, -0.011429964729828157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005687656965427834, -0.0037376031487124095`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005039869513700168, 0.003512636327728913}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013914051529603455`, 0.010323328554219913`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02105259298759954, 0.01669688409361214}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026572169289968528`, 0.0226355516173804}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030588500147196385`, 0.02814142013542309}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.033216421057348455`, 0.033216421057348455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03456995356162729, 0.03786233009130413}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03476237437692653, 0.0420807689825935}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03390628350572911, 0.045873207095983304`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.032113671420730405`, 0.049240962845118474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.029495985418431125`, 0.05218520497106738}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026164195234691157`, 0.054706953672535974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.022228858013876973`, 0.05680708159101755}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017800182719759583`, 0.058486314650634696`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01298809407759105, 0.05974523275691901}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007902296132958675, 0.06058427035268288}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002652335514602977, 0.06100371683586836}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002652335514602977, 0.06100371683586836}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007902296132958453, 0.0605842703526811}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012988094077591494`, 0.05974523275691901}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017800182719759583`, 0.058486314650634696`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.022228858013876973`, 0.056807081591014}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026164195234691157`, 0.054706953672535974`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.029495985418430237`, 0.05218520497106738}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03211367142072952, 0.049240962845118474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033906283505725554`, 0.045873207095983304`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.034762374376924754`, 0.0420807689825935}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03456995356162729, 0.03786233009130413}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.033216421057348455`, 0.033216421057348455`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.030588500147196385`, 0.02814142013542309}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026572169289968528`, 0.0226355516173804}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021052592987601315`, 0.01669688409361214}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013914051529670957`, 0.01032332855426965}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005039869513696615, 0.003512636327728913}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005687656965427834, -0.0037376031487124095`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01838733456538222, -0.011429964729828157`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03317914849847625, -0.019567190140124424`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04190937567090813, -0.026864984404426195`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026651532165171687`, -0.018007792003496448`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013488777395860296`, -0.009634840997042815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00230095040456213, -0.0017431442458804014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007030928424624605, 0.0056701035682475975`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01462473335410941, 0.012607528753539654`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020597307724676384`, 0.019071581226555168`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02506453694319255, 0.02506453694319255}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02814142013542309, 0.030588500147196385`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02994214056995048, 0.035645405440416056`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030580134955947358`, 0.04023701967887661}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.030168161715124597`, 0.04436494369871369}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02881836832460305, 0.048030613874336936`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02664235782662505, 0.051235303512740415`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023751254598132654`, 0.053980124086665526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020255769470815643`, 0.05626602630782074}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016266264292246646`, 0.05809380104373929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011892816015768748`, 0.05946408007884507}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007245280406583898, 0.060377336721535}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0024333554503604415`, 0.060833886259013426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0024333554503604415`, 0.060833886259013426`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007245280406583898, 0.060377336721535}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011892816015768748`, 0.05946408007884507}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01626626429224709, 0.05809380104373929}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020255769470814755`, 0.05626602630782074}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023751254598132654`, 0.053980124086665526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02664235782662505, 0.05123530351273686}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02881836832460216, 0.04803061387433516}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03016816171512282, 0.04436494369871191}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03058013495594558, 0.04023701967887661}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.029942140569948705`, 0.035645405440416056`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02814142013542309, 0.030588500147196385`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02506453694319255, 0.02506453694319255}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.020597307724676384`, 0.019071581226555168`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014624733354105857`, 0.012607528753537878`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007030928424624605, 0.005670103568244045}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002300950404563906, -0.0017431442458804014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013488777395856744`, -0.009634840997042815}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026651532165171687`, -0.018007792003498224`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.041909375670911686`, -0.026864984404431524`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03561746587944725, -0.02599112374986845}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02195229554256528, -0.016934627989977358`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010265068388559229`, -0.00839869231791468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0004366169568470468, -0.0003802792849967318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007651118032223181, 0.007123454719657474}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.014115162307446028`, 0.014115162307446028`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019071581226555168`, 0.020597307724676384`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0226355516173804, 0.026572169289968528`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02492143238494826, 0.032041841637790114`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026042833988885405`, 0.037008237773681785`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02611268689094004, 0.04147309094443585}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025243309070912545`, 0.04543795632764436}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.023546472705392674`, 0.04890421254197008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021133470104708785`, 0.05187306298428318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018115178997491377`, 0.054345536992476795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01460212725465082, 0.056322490839367134`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01070455714024332, 0.05780460855731384}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006532489177378364, 0.058792402596404614`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0021957857154382143`, 0.0592862143168329}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0021957857154382143`, 0.0592862143168329}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00653248917737792, 0.058792402596404614`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01070455714024332, 0.05780460855731384}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014602127254650377`, 0.05632249083936536}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018115178997491377`, 0.054345536992476795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021133470104708785`, 0.05187306298428318}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.023546472705393562`, 0.04890421254197008}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025243309070911657`, 0.04543795632764258}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02611268689094004, 0.04147309094443408}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026042833988885405`, 0.03700823777368001}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.024921432384946485`, 0.03204184163778834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0226355516173804, 0.026572169289968528`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019071581226555168`, 0.020597307724676384`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.014115162307446028`, 0.014115162307446028`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007651118032217852, 0.007123454719653921}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00043661695685415225`, -0.00038027928500383723`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010265068388562781`, -0.00839869231791468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.02195229554256528, -0.016934627989979134`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.035617465879450805`, -0.025991123749872003`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.031081200602525172`, -0.02575299478494486}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01885529350661841, -0.016569803384603787`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008491215235746807, -0.007943394897958811}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00012929328063826517`, 0.00012929328064004153`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007123454719653921, 0.007651118032217852}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012607528753537878`, 0.014624733354105857`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01669688409361214, 0.021052592987601315`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019506069295694317`, 0.026936952836912553`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021148882431841542`, 0.03227987318544301}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021738439727542413`, 0.03708322071168624}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021387243264245903`, 0.04134867031087808}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.020207247841631748`, 0.04507770672364053}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01830992709484569, 0.04827162597732304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01580633895720318, 0.05093153663987948}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012807190559918524`, 0.05305836089109128}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009422902657236776, 0.054652835411975076`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005763673664920033, 0.055715512094224096`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.001939543399003929, 0.05624675857111505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.001939543399003929, 0.05624675857111505}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005763673664920033, 0.055715512094224096`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009422902657238108, 0.054652835411975076`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012807190559918524`, 0.05305836089109128}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01580633895720318, 0.050931536639877706`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01830992709484569, 0.04827162597732304}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02020724784162997, 0.045077706723638755`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021387243264248568`, 0.0413486703108763}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.02173843972754419, 0.03708322071168624}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021148882431839766`, 0.03227987318544301}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019506069295694317`, 0.026936952836912553`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01669688409361214, 0.021052592987601315`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012607528753537878`, 0.014624733354105857`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007123454719653921, 0.007651118032217852}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00012929328063826517`, 0.00012929328063826517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008491215235746807, -0.007943394897960587}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018855293506621962`, -0.016569803384603787`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.031081200602528725`, -0.025752994784948413`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.04087872578144314, -0.036206871406422536`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.028074664114097203`, -0.026373169319303003`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017135711738776038`, -0.017135711738774262`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007943394897957035, -0.008491215235745031}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00038027928500383723`, -0.00043661695685415225`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005670103568244045, 0.007030928424624605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01032332855421636, 0.01391405152959635}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013694148008490004`, 0.020215170869677834`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015896561589572755`, 0.02593649522509267}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01704388512136923, 0.031080025809558265`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01724881849585369, 0.03564755822476684}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01662351273282603, 0.03964068420904887}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015279636290933318`, 0.043060793183540724`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013328440722188084`, 0.0459090735986436}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010880825760878565`, 0.048186514083891296`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008047403935774078, 0.049893904401800526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00493856479451682, 0.05103183621001506}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0016645388268023975`, 0.05160070363087321}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0016645388268023975`, 0.05160070363087321}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004938564794517486, 0.05103183621001506}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008047403935774522, 0.049893904401800526`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010880825760878565`, 0.048186514083891296`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013328440722215618`, 0.04590907359874663}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015279636290933318`, 0.043060793183540724`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016623512732826917`, 0.03964068420904887}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01724881849585458, 0.03564755822476329}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01704388512136923, 0.031080025809558265`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01589656158957098, 0.02593649522509267}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01369414800849178, 0.020215170869677834`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01032332855421636, 0.01391405152959635}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005670103568244045, 0.007030928424624605}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00038027928500383723`, -0.00043661695685415225`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007943394897960587, -0.008491215235746807}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017135711738781367`, -0.017135711738781367`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.028074664114100756`, -0.026373169319303003`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.04087872578144669, -0.036206871406422536`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.037926450868896566`, -0.03792645086889834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026373169319297673`, -0.02807466411409898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016569803384603787`, -0.018855293506621962`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00839869231791468, -0.010265068388562781`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0017431442458804014`, -0.002300950404563906}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003512636327728913, 0.005039869513696615}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007483619769903527, 0.011759973924132083`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010284021421703926`, 0.017861721416641885`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012027370659595249`, 0.023347248927446884`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01282657901307882, 0.028218473828772517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012794007435910082`, 0.032477095798848055`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.012041532824783374`, 0.03612459847434479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010680613879261891`, 0.039162250890628414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008822356393061614, 0.041591108710148816`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006577578067171519, 0.04341201524333549}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004056872932988398, 0.04462560226287238}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0013706754730992143`, 0.045232290612268855`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0013706754730992143`, 0.045232290612268855`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004056872932988398, 0.04462560226287238}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006577578067171519, 0.04341201524333549}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00882235639306117, 0.041591108710148816`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01068061387926278, 0.039162250890628414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012041532824783374`, 0.03612459847434479}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012794007435909194`, 0.03247709579884628}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01282657901307882, 0.028218473828772517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.012027370659593473`, 0.023347248927446884`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01028402142170215, 0.017861721416641885`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007483619769903527, 0.011759973924132083`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003512636327728913, 0.005039869513696615}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0017431442458804014`, -0.002300950404563906}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00839869231791468, -0.010265068388562781`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016569803384603787`, -0.018855293506621962`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026373169319303003`, -0.028074664114100756`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.03792645086889834, -0.03792645086889834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.03620687140642076, -0.04087872578144669}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025752994784946637`, -0.031081200602525172`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.016934627989979134`, -0.02195229554256528}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.009634840997042815, -0.013488777395856744`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0037376031487124095`, -0.005687656965427834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0008722883377156876, 0.0014538138961981417`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0043092787118634845`, 0.007938144995542018}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006687124985687021, 0.013767610264647345`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008118964280293461, 0.018944249987349338`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008717381322616014, 0.02346987279165802}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008594475186333383, 0.027346057411058666`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007861925370479028, 0.03057415421852383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006631057307159072, 0.033155286535794914`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005012907388638688, 0.035090351720469926`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031182876029411943`, 0.03638002203431512}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010578498654764124`, 0.03702474529167432}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010578498654764124`, 0.03702474529167432}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031182876029411943`, 0.03638002203431512}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005012907388638688, 0.035090351720469926`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006631057307159516, 0.033155286535794914`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007861925370479028, 0.03057415421852383}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008594475186333383, 0.027346057411058666`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008717381322616014, 0.02346987279165802}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008118964280291685, 0.018944249987349338`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006687124985683468, 0.013767610264643793`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004309278711867037, 0.007938144995542018}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0008722883377139112, 0.001453813896194589}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0037376031487124095`, -0.005687656965427834}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.009634840997042815, -0.013488777395856744`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.016934627989979134`, -0.02195229554256528}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025752994784948413`, -0.031081200602528725`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.036206871406422536`, -0.04087872578144669}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.025991123749872003`, -0.035617465879450805`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.018007792003498224`, -0.026651532165171687`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011429964729828157`, -0.01838733456538222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00614219220482326, -0.010821957694204798`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0020297849043124927`, -0.003952739024189356}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010212560394755599`, 0.002222733732970994}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0031243074292301998`, 0.007706624992096067}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004392191738985751, 0.01250085341096252}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004937244091148152, 0.01660709376113445}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004871378568174656, 0.020026778558055014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004306153950208724, 0.022761099451106048`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003352838970237748, 0.024811008379753474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0021224771752226257`, 0.02617721849440713}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0007259514823310109, 0.026860204846247626`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0007259514823310109, 0.026860204846247626`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0021224771752221816`, 0.02617721849440713}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003352838970237304, 0.024811008379753474`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00430615395020828, 0.022761099451102496`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004871378568174656, 0.020026778558055014`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004937244091148152, 0.01660709376113445}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004392191738988416, 0.01250085341096252}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0031243074292284234`, 0.007706624992096067}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010212560394720072`, 0.002222733732970994}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0020297849043124927`, -0.003952739024189356}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00614219220482326, -0.010821957694211903`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011429964729828157`, -0.01838733456538222}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.018007792003498224`, -0.026651532165171687`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.025991123749872003`, -0.035617465879450805`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.026864984404431524`, -0.041909375670911686`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.019567190140124424`, -0.03317914849847625}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013562319795171973`, -0.025187165333885986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008735425056341839, -0.01793060932617152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0049722508324716586`, -0.011406928380381487`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002159166404299917, -0.005613832651178541}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0001830974335179647, -0.000549292300558335}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010685412649156234`, 0.0037884644846961635`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.001707912281487367, 0.007400953219779183}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0018468215939839716`, 0.010289434595055269`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.001596784064150203, 0.012454915700377711`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0010690885385573612`, 0.013898151001249914`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0003748626428048407, 0.01461964306939123}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0003748626428048407, 0.01461964306939123}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010690885385575832`, 0.013898151001249914`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.001596784064150203, 0.012454915700374158`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0018468215939844157`, 0.010289434595055269`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.001707912281487367, 0.007400953219779183}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0010685412649156234`, 0.0037884644846961635`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00018309743351885288`, -0.000549292300558335}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.002159166404300805, -0.005613832651178541}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004972250832475211, -0.01140692838038504}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008735425056343615, -0.01793060932617152}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01356231979516842, -0.025187165333885986`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.019567190140124424`, -0.03317914849847625}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.026864984404431524`, -0.041909375670911686`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.021390746903323432`, -0.041762886811248734`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.015810036904928992`, -0.0341163954264303}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011295534899385729`, -0.027242172404402965`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.007733341861408505, -0.021137801087849795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005010117318461127, -0.015801139235147588`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0030130118578455267`, -0.011230316924695671`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0016296003065709996`, -0.007423734729936626}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.000747815491062287, -0.00438006216193898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0002558824847915808, -0.002098236375292828}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00004225325388862444, -0.0005774611364763871}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-4.458388987660378*^-6, 0.00018279394849329833`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{4.458388987660378*^-6, 0.00018279394849329833`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0000422532538884024, -0.0005774611364763871}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0002558824847915808, -0.002098236375292828}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0007478154910613988, -0.00438006216193898}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0016296003065709996`, -0.007423734729936626}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0030130118578455267`, -0.011230316924695671`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005010117318461127, -0.015801139235147588`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.007733341861410281, -0.021137801087849795`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011295534899389281`, -0.027242172404406517`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.01581003690493077, -0.0341163954264303}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.021390746903323432`, -0.041762886811248734`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.017950862206147278`, -0.04540512205084468}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.013600215261497794`, -0.038987283749630564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.010090595689100645`, -0.03337658574086433}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0073088755231314195`, -0.028571058863150256`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.005142352774532455, -0.024569018811650523`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.003478684917773478, -0.021369064494901835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0022058228686474557`, -0.018970076670370872`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0012119453620351717`, -0.01737121685584242}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.00038539363988282505`, -0.016571926514956203`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.00038539363988282505`, -0.016571926514956203`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0012119453620356158`, -0.01737121685584242}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0022058228686470116`, -0.018970076670370872`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.003478684917774366, -0.021369064494901835`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.005142352774532455, -0.024569018811650523`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0073088755231314195`, -0.028571058863150256`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.010090595689100645`, -0.03337658574086433}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.013600215261497794`, -0.038987283749630564`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.017950862206149054`, -0.045405122050848234`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.01542635872090159, -0.0533989340338934}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.011820593137940705`, -0.048356971927944414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.008831606671956926, -0.04415803335978552}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.006346767122032304, -0.04080064578449338}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.004253736986993051, -0.03828363288293346}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.002440407561033364, -0.03660611341549469}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{0.0007948333414418696, -0.03576750036488363}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0007948333414418696, -0.03576750036488363}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.0024404075610335862`, -0.03660611341549469}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.004253736986992163, -0.03828363288293346}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.006346767122032304, -0.040800645784496936`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.008831606671957815, -0.04415803335978552}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.011820593137940705`, -0.048356971927944414`}]}, 
   {RGBColor[0.9509907706697254, 0.02708969345129464, 0.01100524662220348], 
    PointBox[{-0.015426358720904254`, -0.05339893403389695}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{-0.125, -0.125}, {0.125, -0.125}, {0.125, 0.125}, {-0.125, 
     0.125}, {-0.125, -0.125}}]}},
  AspectRatio->Automatic,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.5634043258605413`*^9, 3.56345822372405*^9, 
  3.5644876752203093`*^9, 3.566100821779181*^9, 3.6013015674751883`*^9, 
  3.6147093399157476`*^9, 3.6147291906523533`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[309]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindIntensity[{
\tMove[GridOfRays[{45,45}, NumberOfRays -> 48, WaveLength->.633], -25],
\tMove[ApertureStop[{50,50},45],-20],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[{.25,.25}],83.3673]}, SequentialTrace->True, \
SmoothKernelSize->4, Full3D -> False, CalibrateEnergy -> True, \
ReportedSurfaces -> Last]\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[310]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1716"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.01754622278237448`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 3., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 1716, Optica`Optica`SmoothKernelSize -> 
    0.01754622278237448}],
  Editable->False]], "Print",
 CellChangeTimes->{3.61472919572581*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[310]:="],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwlmXk01O/bx7XYisi+hVApIUtIdF98I1HKmi0KkSJbxdiZIfu+RrYsM2Pf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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne811Mcx/Hb0t5LRYPSUmnvSUqiNGmS0UK0RKEd2mlQKNo7ZbVU0la0
p9XetCd5fh7+eN3P6/35nvv7ne/5nvO9N1+7Lo1eTZSQkNA5cUJC1M1+VMMm
3hX59MfJeVFFTpC78zt0FvLghNwSx/lIFDVmslwEz8iZ5SE8E5b//xEJW3h1
bObdcJ/meDkfqsqJ5B4xIcxW8uIkb4UTfBRaIItx7+llxgo5CX7iNbCFd0e1
+E7jeuolwpy4L5zirXGSj0ZLJMVWvZr4ifdA9ZgfkmGbfi1s5T1RA/fjtF4b
nOJj0Ap34We9h7GNv4GaMUdzeUMvMebK+XGGt8Vp/iFaI6tx7+tlwUo5OX7h
j+Bn3iu+25gJ8n0xr5i/3IsnwTy5rDybl0EB+az6LM7wWq59w8fyB/kUXhQN
+Nq4H/1s/APeQs2q1lVXqC+q37teSV0Qn6lWVBurG9SOagrXt/PaaCb/Emup
LpHbqW/GvasfxXNV71frq6tjzWK9YwxPGp/Bl6rz9cvxObwsHpDPqc/hLB+H
tshuzFC9bFglp8QO/ii287fwCAoiFXbq18EO3hu1UQjnY644x8fjWaTGrlgL
7OR98CgK4y+953GeT8BzSIPdeo9hF38bdWJ/mONbesmwQC6Cv/kL+It/hHZI
iz169bCbv4O6sR/8fm+9u7Awzh0uxLPB3/xjFDPmc/nBmJd8tzyMZ8dqOR32
8sexh7+LAsZ8LOePOcsp5D48ORbFXsFF/hIu8IkobswXcrGYv5xDHs7vjs/g
K9U1+pX5Ql4J6eV98cyxN86Sa1/xvvwBPjHOp1pAfUJdo7ZX68XzVN+O90vs
s3iu6rL4bvVL18urc+NMqeXURup6tYNazPVL8Vl4Wr4oP6x+K0/iJfhUXhwN
+Y+xpvo5+QieI55F7H/1B/0qfBGvjAzy/pgv9vF+scdcnxR7NdY59pv8Dk+J
xbF2uBxzwyX+CR4yZppcItZZziWP5DmxVs6IA/xJ7Of9UT/2pnHv6qXCkrgX
XInziMv8U7RHJhyMs44DfACeiL3q9/vqpcZXMQ9c5Z1whX+GDsiMQ7E+OMgH
4kmUxDW9zrjKJ6MjsuBXvadwiA9CA5SK9xx+i2eEX/lgNERpXNd7Gdf4FHSK
dxJ+j3cNfuND4qya9ydywfiOODNyP54GX8sV5Hm8PMrIN9RXcD3eA659xz+P
+fPp/KH4HL4u7kX/Hj6Kt1RzxXNUV8Wzif3hetXYd/EeUquoTdSNsW5qdtf/
iB6ay7/LNdWv40zG3694d6ifym3UQvFc1R9iTeKM8v48bbyj+HL1G/2KfD6v
gLLyTTX+mN/gX8Tauj5DLhlrKN8rj+b3YF28C/Anb4o/+PtojPTGDdBLh2/l
crjFu+Amn4pX4ozjsF4z/Mk/QJM4e3FWcCTuF4f5UDSN54Dbeq/hFp+GV2N/
42icRxzhw9AMGcxlYLwr8F3cM/7hr+M2n44uyG3cGL17sT6eF47F+wFH+XA0
j3Nj3KA4p1gqV8K/vCv+4TNi3xkzUy4V85TzyB/y3NgQ64jjvAWO8REoYsxn
cuG4hzhf8mCeEcvkyrjDu+FfPhNljJkll477kfPKY3kebJSryYt51XhGfFOi
//9Py+3af37HGZo=
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.649938493065757, 1, 0.10008516344741332`], 
     Hue[0.6358741673773562, 1, 0.11955884516981446`], 
     Hue[0.5905873008762106, 1, 0.1822637372483239], 
     Hue[0.4979484307175077, 1, 0.3105329420834509], 
     Hue[0.35451602692890677`, 1, 0.5091316550215137], 
     Hue[0.17594571030521544`, 1, 0.7563828626543171], 
     Hue[0.04871156498928875, 1, 0.9325532177071387], 
     Hue[0.000013609696291161377`, 1, 0.9999811558051354], 
     Hue[0.0314036943625815, 1, 0.9565179616518102], 
     Hue[0.09156431400777065, 1, 0.8732186421430868], 
     Hue[0.15440729473713571`, 1, 0.7862052842101198], 
     Hue[0.19728975639734175`, 1, 0.7268295680652191], 
     Hue[0.22353088478615885`, 1, 0.6904956979883954], 
     Hue[0.2379237277953894, 1, 0.6705671461294608], 
     Hue[0.2425926025512165, 1, 0.6641025503137002], 
     Hue[0.24193191586286183`, 1, 0.6650173472668067], 
     Hue[0.23542808694625678`, 1, 0.6740226488436445], 
     Hue[0.2209138717928834, 1, 0.694119254440623], 
     Hue[0.19199095316047804`, 1, 0.7341663725470304], 
     Hue[0.15027256198639483`, 1, 0.7919302987880686], 
     Hue[0.09024026146077968, 1, 0.8750519456696897], 
     Hue[0.030201651163216492`, 1, 0.9581823291586233], 
     Hue[0.004638232614477711, 1, 0.9935778317645693], 
     Hue[0.052509982832162905`, 1, 0.9272938699246975], 
     Hue[0.1783815195657164, 1, 0.7530102036782388], 
     Hue[0.34101624848043155`, 1, 0.5278236559501718], 
     Hue[0.4972517255084437, 1, 0.3114976108344626], 
     Hue[0.5894055607044238, 1, 0.18389999287079783`], 
     Hue[0.6354581494053099, 1, 0.12013487005418634`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6449588292034519, 1, 0.10698008264137433`], 
     Hue[0.6187237577052757, 1, 0.14330556625423374`], 
     Hue[0.5514160646799522, 1, 0.23650083352006626`], 
     Hue[0.43176207292228613`, 1, 0.4021755913383731], 
     Hue[0.26421151941190163`, 1, 0.6341686654296746], 
     Hue[0.1039527542770432, 1, 0.8560654171548633], 
     Hue[0.012101677487688978`, 1, 0.9832438311708921], 
     Hue[0.00850856280765877, 1, 0.9882189130355494], 
     Hue[0.06019131412133816, 1, 0.9166581804473779], 
     Hue[0.12469346490218047`, 1, 0.8273475101354424], 
     Hue[0.17798752106493576`, 1, 0.7535557400639351], 
     Hue[0.2122139032390356, 1, 0.7061653647459507], 
     Hue[0.23225737272044306`, 1, 0.678412868540925], 
     Hue[0.24104723166655917`, 1, 0.6662422946155335], 
     Hue[0.24289680610768544`, 1, 0.6636813453893586], 
     Hue[0.2395855333102348, 1, 0.6682661846473672], 
     Hue[0.2294288501666213, 1, 0.6823292843846782], 
     Hue[0.20837155645829114`, 1, 0.7114855372115969], 
     Hue[0.1729771897632726, 1, 0.760493121866238], 
     Hue[0.12176466277218645`, 1, 0.8314027746231264], 
     Hue[0.058630755354584396`, 1, 0.9188189541244216], 
     Hue[0.011230179613809343`, 1, 0.9844505205347255], 
     Hue[0.016787527287653203`, 1, 0.9767557314478648], 
     Hue[0.10704567305450974`, 1, 0.8517829142322172], 
     Hue[0.2584223206823415, 1, 0.6421844790552195], 
     Hue[0.42524505184003053`, 1, 0.411199158990727], 
     Hue[0.5502953978065704, 1, 0.23805252611397937`], 
     Hue[0.6179872284458, 1, 0.14432537599812303`], 
     Hue[0.6448998313517809, 1, 0.10706177197445726`], 
     Hue[0.6478425042462428, 1, 0.10298730181289469`], 
     Hue[0.6284471834969069, 1, 0.12984236131197513`], 
     Hue[0.5727113716380293, 1, 0.20701502388580556`], 
     Hue[0.46645977421420126`, 1, 0.3541326203187982], 
     Hue[0.309714456936927, 1, 0.5711645980873319], 
     Hue[0.13821354400198216`, 1, 0.8086274006126402], 
     Hue[0.027260279179128544`, 1, 0.9622549980596681], 
     Hue[0.002069212291204714, 1, 0.9971349368275626], 
     Hue[0.045218768976820756`, 1, 0.937389396801325], 
     Hue[0.10843160848475886`, 1, 0.8498639267134108], 
     Hue[0.16672938513660746`, 1, 0.7691439282723896], 
     Hue[0.20522774408762623`, 1, 0.7158385081863637], 
     Hue[0.22831875753897807`, 1, 0.6838663357152611], 
     Hue[0.23971165280865592`, 1, 0.6680915576495534], 
     Hue[0.2429058564863416, 1, 0.6636688140958347], 
     Hue[0.24095387459151096`, 1, 0.6663715582579078], 
     Hue[0.23271526620601346`, 1, 0.677778862176289], 
     Hue[0.21509936709691735`, 1, 0.702170107096576], 
     Hue[0.18294451617238688`, 1, 0.7466922083766951], 
     Hue[0.1364862118626946, 1, 0.8110190912670383], 
     Hue[0.0743154558767265, 1, 0.8971016764783787], 
     Hue[0.019484451417796533`, 1, 0.9730215288061279], 
     Hue[0.007919586572809445, 1, 0.9890344185914945], 
     Hue[0.07737360557414119, 1, 0.8928673153588815], 
     Hue[0.21760732674709288`, 1, 0.6986975475809483], 
     Hue[0.38430159615894394`, 1, 0.4678900976260776], 
     Hue[0.5255548315465994, 1, 0.27230869478163156`], 
     Hue[0.6053083095286513, 1, 0.16188080219109816`], 
     Hue[0.6408614618092212, 1, 0.11265336057184766`], 
     Hue[0.641058804060438, 1, 0.11238011745477816`], 
     Hue[0.6062530894156665, 1, 0.16057264542446192`], 
     Hue[0.5265164802918042, 1, 0.270977181134425], 
     Hue[0.21920699381676656`, 1, 0.6964826239460156], 
     Hue[0.07392421199042642, 1, 0.8976433987824864], 
     Hue[0.0031391385562195007`, 1, 0.9956535004606192], 
     Hue[0.018555541470199777`, 1, 0.9743077118104926], 
     Hue[0.14007958618520522`, 1, 0.8060436498974081], 
     Hue[0.1881700337023799, 1, 0.7394568764120893], 
     Hue[0.21829677038255385`, 1, 0.6977429333164639], 
     Hue[0.23543052355545147`, 1, 0.6740192750770673], 
     Hue[0.24199045651332346`, 1, 0.6649362909815522], 
     Hue[0.2425760049028693, 1, 0.6641255316729502], 
     Hue[0.23776650936503085`, 1, 0.6707848331868804], 
     Hue[0.2255125268403259, 1, 0.6877518859133949], 
     Hue[0.20068248766214664`, 1, 0.7221319401601046], 
     Hue[0.16208264859084515`, 1, 0.7755778711819067], 
     Hue[0.04371614699044968, 1, 0.9394699503209158], 
     Hue[0.006076175184724919, 1, 0.9915868343596116], 
     Hue[0.031610607863258755`, 1, 0.9562314660354879], 
     Hue[0.1409633959215164, 1, 0.8048199133394389], 
     Hue[0.463077843340281, 1, 0.358815293836534], 
     Hue[0.5715231364312646, 1, 0.20866027263363357`], 
     Hue[0.6278869376704564, 1, 0.13061808630244504`], 
     Hue[0.6478637099087889, 1, 0.10295794012629222`], 
     Hue[0.6489762270491305, 1, 0.10141753177812704`], 
     Hue[0.6324202093044816, 1, 0.12434124865533322`], 
     Hue[0.5820613221864717, 1, 0.19406893851103924`], 
     Hue[0.4826238513839495, 1, 0.33175159039145463`], 
     Hue[0.33227410434763993`, 1, 0.5399281632109602], 
     Hue[0.15669914592620343`, 1, 0.7830319517944876], 
     Hue[0.03720450063175462, 1, 0.9484860760483398], 
     Hue[0.0004476301727304177, 1, 0.9993802043762193], 
     Hue[0.03813072504697368, 1, 0.947203611473421], 
     Hue[0.10005293944572924`, 1, 0.8614651607674517], 
     Hue[0.1606994254836548, 1, 0.777493103176478], 
     Hue[0.2013804731055241, 1, 0.7211654987769667], 
     Hue[0.2260360957880304, 1, 0.6870269442934964], 
     Hue[0.23887824876642644`, 1, 0.669245501708025], 
     Hue[0.2427910353345592, 1, 0.6638277972290718], 
     Hue[0.24148836081151637`, 1, 0.6656315004148236], 
     Hue[0.23413973704573654`, 1, 0.6758065179366725], 
     Hue[0.2181175332060996, 1, 0.6979911078684774], 
     Hue[0.1875819223195057, 1, 0.7402711844806844], 
     Hue[0.14350356859037128`, 1, 0.8013027511825628], 
     Hue[0.08227685123058825, 1, 0.8860782059884162], 
     Hue[0.024574860279835242`, 1, 0.9659732703817666], 
     Hue[0.00561206866708297, 1, 0.9922294433840391], 
     Hue[0.06431351135931318, 1, 0.9109505227332586], 
     Hue[0.19773673251696433`, 1, 0.726210678053434], 
     Hue[0.3628955549218317, 1, 0.4975292316466946], 
     Hue[0.5118463674385785, 1, 0.2912896450850453], 
     Hue[0.5977865571960401, 1, 0.17229553619009824`], 
     Hue[0.6383502117552429, 1, 0.11613047603120219`], 
     Hue[0.6431517151854681, 1, 0.10948224051242877`], 
     Hue[0.6128602541465582, 1, 0.15142426348938104`], 
     Hue[0.5394239938133354, 1, 0.25310523933538176`], 
     Hue[0.24156930349962946`, 1, 0.66551942592359], 
     Hue[0.0883684273530787, 1, 0.8776437159726603], 
     Hue[0.006862671766282191, 1, 0.9904978390928401], 
     Hue[0.013131414241654427`, 1, 0.9818180418192477], 
     Hue[0.1325092901431738, 1, 0.8165255982632977], 
     Hue[0.1832129128211965, 1, 0.7463205822475741], 
     Hue[0.21536496123231758`, 1, 0.7018023613706372], 
     Hue[0.23393430211034122`, 1, 0.6760909663087583], 
     Hue[0.2415644445110947, 1, 0.6655261537538689], 
     Hue[0.24277558294640866`, 1, 0.6638491928434341], 
     Hue[0.238736511159101, 1, 0.6694417537797064], 
     Hue[0.22755280483815737`, 1, 0.6849268856087052], 
     Hue[0.20464991989517733`, 1, 0.7166385724528314], 
     Hue[0.1676455927361552, 1, 0.7678753331345544], 
     Hue[0.051040025199387884`, 1, 0.9293291958777706], 
     Hue[0.008226201348992213, 1, 0.9886098750552414], 
     Hue[0.02344084860751061, 1, 0.9675434403896007], 
     Hue[0.1235165366848554, 1, 0.8289771030517387], 
     Hue[0.4445898743090676, 1, 0.38441402018744486`], 
     Hue[0.561340331093485, 1, 0.22275954156286684`], 
     Hue[0.6232561010513117, 1, 0.13703001392895314`], 
     Hue[0.6464996169089005, 1, 0.10484668427998399`], 
     Hue[0.6465124810522591, 1, 0.10482887238917975`], 
     Hue[0.6239004235147201, 1, 0.1361378751334646], 
     Hue[0.5625051715042461, 1, 0.2211466856095055], 
     Hue[0.12059793676902664`, 1, 0.8330182413967324], 
     Hue[0.018893835004392012`, 1, 0.9738393053785341], 
     Hue[0.0047880791116963195`, 1, 0.9933703519991898], 
     Hue[0.20883693238894285`, 1, 0.7108411705383868], 
     Hue[0.23038904986361058`, 1, 0.6809997771119238], 
     Hue[0.24043206695659142`, 1, 0.6670940611370273], 
     Hue[0.2429404403961949, 1, 0.6636209286821917], 
     Hue[0.24032201531881137`, 1, 0.6672464403277997], 
     Hue[0.23114735397537128`, 1, 0.6799498175725629], 
     Hue[0.2118527754603053, 1, 0.7066653878241927], 
     Hue[0.015009554352580334`, 1, 0.9792175401271964], 
     Hue[0.011626889497613702`, 1, 0.9839012299263811], 
     Hue[0.09163910013354026, 1, 0.8731150921227904], 
     Hue[0.5383704079854961, 1, 0.2545640504816208], 
     Hue[0.6120234756793664, 1, 0.15258287982856955`], 
     Hue[0.6430321108068267, 1, 0.10964784657516316`], 
     Hue[0.6386453224664642, 1, 0.1157218612002804], 
     Hue[0.598846580304952, 1, 0.1708278118854511], 
     Hue[0.06068719802985534, 1, 0.9159715719586617], 
     Hue[0.0008782352204227406, 1, 0.9987839820024916], 
     Hue[0.024679649691824457`, 1, 0.9658281773497815], 
     Hue[0.23675677058823957`, 1, 0.6721829330316683], 
     Hue[0.24233138026757767`, 1, 0.6644642427064309], 
     Hue[0.24229593452182274`, 1, 0.6645133214313224], 
     Hue[0.23666671620205776`, 1, 0.6723076237202278], 
     Hue[0.004856118727534553, 1, 0.9932761433003368], 
     Hue[0.041303831797003365`, 1, 0.942810079050303], 
     Hue[0.5808682231554523, 1, 0.19572092178475842`], 
     Hue[0.6319359910749897, 1, 0.1250117046653989], 
     Hue[0.6490215920645284, 1, 0.10135471867988384`], 
     Hue[0.6494773327055394, 1, 0.10072369317694538`], 
     Hue[0.6342087330231195, 1, 0.12186483119875761`], 
     Hue[0.5864250969640279, 1, 0.18802678881903834`], 
     Hue[0.49039283759310626`, 1, 0.3209945325633914], 
     Hue[0.3434432237934854, 1, 0.5244632285936357], 
     Hue[0.16623441922116738`, 1, 0.7698292656937683], 
     Hue[0.04276434577331989, 1, 0.9407878289292494], 
     Hue[0.00007679176017338918, 1, 0.9998936729474521], 
     Hue[0.03471739730175005, 1, 0.9519297575821922], 
     Hue[0.09581942617566908, 1, 0.8673269483721505], 
     Hue[0.1575857700781747, 1, 0.7818043183532966], 
     Hue[0.19936585815728924`, 1, 0.7239549656283688], 
     Hue[0.22481193449965298`, 1, 0.6887219368466344], 
     Hue[0.23841664749117847`, 1, 0.6698846419352913], 
     Hue[0.2427025327369567, 1, 0.6639503392872907], 
     Hue[0.24172113730854938`, 1, 0.6653091944958547], 
     Hue[0.23480046731546206`, 1, 0.6748916606401294], 
     Hue[0.21954300256722858`, 1, 0.6960173810607604], 
     Hue[0.18981483182634717`, 1, 0.7371794636250578], 
     Hue[0.1469198142750071, 1, 0.7965725648499901], 
     Hue[0.08626156846681077, 1, 0.8805609051998005], 
     Hue[0.0273260897853026, 1, 0.9621638756818888], 
     Hue[0.004963014184779402, 1, 0.99312813420569], 
     Hue[0.05825200866613822, 1, 0.9193433726161162], 
     Hue[0.18798748353570155`, 1, 0.7397096381813363], 
     Hue[0.35200740343737535`, 1, 0.5126051337020957], 
     Hue[0.5046590281883945, 1, 0.3012413455852999], 
     Hue[0.5937066226343508, 1, 0.17794467635243744`], 
     Hue[0.6369543886566887, 1, 0.11806315416766175`], 
     Hue[0.6440889167723793, 1, 0.10818457677670562`], 
     Hue[0.6158814261215018, 1, 0.14724110229330523`], 
     Hue[0.5455338694872526, 1, 0.24464541147918872`], 
     Hue[0.2528652141785069, 1, 0.6498789342143751], 
     Hue[0.09602275426955087, 1, 0.8670454171652372], 
     Hue[0.009290015362268256, 1, 0.98713690180609], 
     Hue[0.010713488270728377`, 1, 0.985165939317453], 
     Hue[0.12863061507223938`, 1, 0.8218960714384378], 
     Hue[0.18063384730919002`, 1, 0.7498915960334291], 
     Hue[0.21381726377169769`, 1, 0.7039453270853416], 
     Hue[0.23311909649528167`, 1, 0.6772197125449946], 
     Hue[0.24131764623154633`, 1, 0.6658678744486282], 
     Hue[0.24284590844423104`, 1, 0.6637518190772186], 
     Hue[0.23917560670778654`, 1, 0.6688337753276802], 
     Hue[0.2285109458103161, 1, 0.6836002288780239], 
     Hue[0.20654113455121414`, 1, 0.7140199675444727], 
     Hue[0.17034038401171164`, 1, 0.7641440836760915], 
     Hue[0.05480692141553578, 1, 0.9241134934246428], 
     Hue[0.009626310941832528, 1, 0.9866712617728473], 
     Hue[0.019925739857921787`, 1, 0.9724105140428776], 
     Hue[0.11515332965430136`, 1, 0.8405569281709673], 
     Hue[0.43502017112478353`, 1, 0.3976643784426075], 
     Hue[0.5559269137383687, 1, 0.2302550425161049], 
     Hue[0.6207049662420664, 1, 0.14056235443406198`], 
     Hue[0.6457311365595364, 1, 0.10591073399448812`], 
     Hue[0.6472036790882919, 1, 0.1038718289546728], 
     Hue[0.6262490055599088, 1, 0.13288599230166476`], 
     Hue[0.5677171136998695, 1, 0.21393015026171913`], 
     Hue[0.1292904969224421, 1, 0.8209823888766186], 
     Hue[0.02287962775689989, 1, 0.9683205154135233], 
     Hue[0.003297360104398517, 1, 0.9954344244708329], 
     Hue[0.20706174400905775`, 1, 0.7132991236797662], 
     Hue[0.22937980562046162`, 1, 0.6823971922178224], 
     Hue[0.24008549095091536`, 1, 0.6675739356064249], 
     Hue[0.24293301960059616`, 1, 0.6636312036299438], 
     Hue[0.24065055236164995`, 1, 0.6667915428838693], 
     Hue[0.23194969037143282`, 1, 0.6788388902549392], 
     Hue[0.2135050221085743, 1, 0.7043776616958202], 
     Hue[0.017165074748182296`, 1, 0.9762329734255938], 
     Hue[0.009594603545152736, 1, 0.9867151643220963], 
     Hue[0.08435939786654623, 1, 0.8831946798770898], 
     Hue[0.5320742886563394, 1, 0.26328175416814537`], 
     Hue[0.6087633130142094, 1, 0.15709695121109477`], 
     Hue[0.6419869437680921, 1, 0.11109500093648796`], 
     Hue[0.639894402724465, 1, 0.11399236545843314`], 
     Hue[0.6026531603603668, 1, 0.1655571625779538], 
     Hue[0.06715110997453766, 1, 0.9070215400352556], 
     Hue[0.0018297104640305761`, 1, 0.9974665547421115], 
     Hue[0.0215363966805433, 1, 0.97018037382694], 
     Hue[0.23611422526742082`, 1, 0.6730726111681866], 
     Hue[0.24217119975554213`, 1, 0.664686031107711], 
     Hue[0.24244621716265308`, 1, 0.6643052377747881], 
     Hue[0.23723339706884855`, 1, 0.671522988673902], 
     Hue[0.0053452853139202006`, 1, 0.9925988357191874], 
     Hue[0.036267025740151615`, 1, 0.949784118205944], 
     Hue[0.5762986393114093, 1, 0.20204803787651024`], 
     Hue[0.6299807161816376, 1, 0.1277190083638863], 
     Hue[0.6484666908473073, 1, 0.10212304344218984`], 
     Hue[0.6484322903213533, 1, 0.10217067493966464`], 
     Hue[0.6305019530049214, 1, 0.12699729583933958`], 
     Hue[0.0320356621989184, 1, 0.9556429292630361], 
     Hue[0.0011154721803823264`, 1, 0.9984555000579323], 
     Hue[0.2393095702974985, 1, 0.6686482872803867], 
     Hue[0.24285865529168527`, 1, 0.6637341695961281], 
     Hue[0.24123286620035844`, 1, 0.665985262184119], 
     Hue[0.021957695447173964`, 1, 0.9695970370731437], 
     Hue[0.006594711929210906, 1, 0.9908688604057079], 
     Hue[0.6396508698321707, 1, 0.1143295648477637], 
     Hue[0.642143102661376, 1, 0.11087878093040252`], 
     Hue[0.004814436689188906, 1, 0.9933338568918922], 
     Hue[0.23470433046146488`, 1, 0.6750247732072024], 
     Hue[0.2417884525642831, 1, 0.6652159887571465], 
     Hue[0.24268569021400233`, 1, 0.6639736597036892], 
     Hue[0.23826717656319502`, 1, 0.67009160168173], 
     Hue[0.007039619470834202, 1, 0.990252834578845], 
     Hue[0.027335329847204104`, 1, 0.9621510817500251], 
     Hue[0.6256477321184175, 1, 0.13371852475911425`], 
     Hue[0.647209217509856, 1, 0.10386416037096859`], 
     Hue[0.01530189122233161, 1, 0.9788127659998486], 
     Hue[0.006529258236329438, 1, 0.9909594885958515], 
     Hue[0.24292832841305323`, 1, 0.6636376991203878], 
     Hue[0.013027917563786517`, 1, 0.9819613449116802], 
     Hue[0.014022731969356772`, 1, 0.9805839095808907], 
     Hue[0.00027601563255674755`, 1, 0.9996178245087677], 
     Hue[0.24247164802389493`, 1, 0.6642700258130686], 
     Hue[0.24212468420495137`, 1, 0.6647504372546827], 
     Hue[0.004617574815177883, 1, 0.9936064348712922], 
     Hue[0.6495316619871018, 1, 0.10064846801785912`], 
     Hue[0.6497127318737437, 1, 0.10039775586712417`], 
     Hue[0.6350564277740989, 1, 0.12069110000509396`], 
     Hue[0.5885311054974225, 1, 0.18511077700356893`], 
     Hue[0.49419749404543645`, 1, 0.3157265467063187], 
     Hue[0.3489926849992745, 1, 0.5167793592317738], 
     Hue[0.17106897372176466`, 1, 0.7631352671544798], 
     Hue[0.04568980625769192, 1, 0.9367371913355035], 
     Hue[6.09978477783546*^-6, 1, 0.9999915541441537], 
     Hue[0.0330474952309282, 1, 0.9542419296802532], 
     Hue[0.09369417962716953, 1, 0.8702695974393038], 
     Hue[0.1560045839915159, 1, 0.7839936529348241], 
     Hue[0.19833552935589482`, 1, 0.7253815747379918], 
     Hue[0.22417859788538547`, 1, 0.6895988644663893], 
     Hue[0.23817416800661556`, 1, 0.6702203827600708], 
     Hue[0.24265028325262583`, 1, 0.6640226847271334], 
     Hue[0.24182923371526088`, 1, 0.6651595225481003], 
     Hue[0.23511835715024532`, 1, 0.6744515054842757], 
     Hue[0.22023520536433383`, 1, 0.6950589464186148], 
     Hue[0.19090997098705936`, 1, 0.7356631170948409], 
     Hue[0.1486042012792279, 1, 0.7942403366902998], 
     Hue[0.08825205226399624, 1, 0.8778048507113898], 
     Hue[0.028748931982809478`, 1, 0.9601937864853407], 
     Hue[0.004760696576692314, 1, 0.9934082662784259], 
     Hue[0.055340772600581234`, 1, 0.9233743148607337], 
     Hue[0.183165701609248, 1, 0.7463859516179643], 
     Hue[0.34652371010590977`, 1, 0.5201979398533557], 
     Hue[0.5009827401009612, 1, 0.3063315906294384], 
     Hue[0.5915841143633571, 1, 0.1808835339584286], 
     Hue[0.6362191549143262, 1, 0.1190811701186252], 
     Hue[0.6445320336833886, 1, 0.10757103028453881`], 
     Hue[0.6173245018682061, 1, 0.14524299741325317`], 
     Hue[0.5485033245222803, 1, 0.24053385835376578`], 
     Hue[0.2585332875126271, 1, 0.642030832674824], 
     Hue[0.09995392257689595, 1, 0.8616022610473748], 
     Hue[0.01064751818501719, 1, 0.9852572825130532], 
     Hue[0.009583609472613941, 1, 0.9867303868840731], 
     Hue[0.1266691499776148, 1, 0.824611946184841], 
     Hue[0.17931909965999165`, 1, 0.7517120158553962], 
     Hue[0.21302259351732472`, 1, 0.7050456397452427], 
     Hue[0.23269413314926196`, 1, 0.6778081233317912], 
     Hue[0.24118544409568593`, 1, 0.6660509235598195], 
     Hue[0.24287378042988478`, 1, 0.6637132270970826], 
     Hue[0.23938415028703458`, 1, 0.6685450226794906], 
     Hue[0.22897487463823663`, 1, 0.6829578658855185], 
     Hue[0.20746390315405155`, 1, 0.7127422879405441], 
     Hue[0.17166603997631985`, 1, 0.7623085600327879], 
     Hue[0.05671231197508109, 1, 0.9214752603421954], 
     Hue[0.010403391228921754`, 1, 0.9855953044522623], 
     Hue[0.01830971312023455, 1, 0.974648089525829], 
     Hue[0.11106687206369958`, 1, 0.8462151002194929], 
     Hue[0.4301576904613472, 1, 0.40439704397659615`], 
     Hue[0.5531385554966293, 1, 0.2341158462354365], 
     Hue[0.6193673682918347, 1, 0.1424144131343828], 
     Hue[0.6453235894943384, 1, 0.10647502993091609`], 
     Hue[0.6475294258467215, 1, 0.10342079498146263`], 
     Hue[0.6273664555249102, 1, 0.1313387538885859], 
     Hue[0.5702412407310771, 1, 0.21043520514158565`], 
     Hue[0.133723999532688, 1, 0.8148436929547397], 
     Hue[0.025020577955309653`, 1, 0.9653561228311096], 
     Hue[0.002649717550851971, 1, 0.996331160314205], 
     Hue[0.20615214077830568`, 1, 0.7145585743069613], 
     Hue[0.228855837231551, 1, 0.6831226869101602], 
     Hue[0.23990204047560543`, 1, 0.667827943956854], 
     Hue[0.24292192231072768`, 1, 0.6636465691082233], 
     Hue[0.2408053089310842, 1, 0.6665772645569603], 
     Hue[0.23233701789674444`, 1, 0.6783025906045077], 
     Hue[0.2143093849512548, 1, 0.7032639285290319], 
     Hue[0.018304909377876655`, 1, 0.9746547408614016], 
     Hue[0.008712862688169953, 1, 0.9879360362779186], 
     Hue[0.08082926427271286, 1, 0.888082557160859], 
     Hue[0.5288424918695671, 1, 0.26775654971906104`], 
     Hue[0.6070605966249363, 1, 0.1594545585193191], 
     Hue[0.6414345382241344, 1, 0.11185987015119851`], 
     Hue[0.6404868988168657, 1, 0.1131719862535706], 
     Hue[0.6044785360483764, 1, 0.16302971931763272`], 
     Hue[0.07049944238912087, 1, 0.9023853874612173], 
     Hue[0.0024391661414466803`, 1, 0.99662269303492], 
     Hue[0.020024885749810428`, 1, 0.9722732351156471], 
     Hue[0.23577760259562525`, 1, 0.673538704098365], 
     Hue[0.2420834410038361, 1, 0.6648075432254578], 
     Hue[0.24251364645452195`, 1, 0.6642118741398927], 
     Hue[0.23750407900351966`, 1, 0.6711481983028189], 
     Hue[0.005681080180083287, 1, 0.9921338889814231], 
     Hue[0.03389119525015072, 1, 0.9530737296536375], 
     Hue[0.5739368605688189, 1, 0.20531819305855853`], 
     Hue[0.6289515700277414, 1, 0.12914397996158888`], 
     Hue[0.6481714217172886, 1, 0.10253187762221586`], 
     Hue[0.6487097974449376, 1, 0.1017864343070095], 
     Hue[0.6314777186642292, 1, 0.12564623569568262`], 
     Hue[0.03457102577730864, 1, 0.9521324258468035], 
     Hue[0.0007451096657035139, 1, 0.9989683096936413], 
     Hue[0.23909763254801092`, 1, 0.6689417395489079], 
     Hue[0.24282742472391228`, 1, 0.6637774119207369], 
     Hue[0.24136350061985357`, 1, 0.6658043837571258], 
     Hue[0.02324890601426366, 1, 0.9678092070571734], 
     Hue[0.006061134744822838, 1, 0.9916076595840914], 
     Hue[0.6390121122182261, 1, 0.11521399846707162`], 
     Hue[0.6426565983672214, 1, 0.11016778687615497`], 
     Hue[0.0057915299601970505`, 1, 0.9919809585166501], 
     Hue[0.23432488000031443`, 1, 0.6755501661534108], 
     Hue[0.24167924721425632`, 1, 0.6653671961648758], 
     Hue[0.24273309456886033`, 1, 0.6639080229046549], 
     Hue[0.23850569159282636`, 1, 0.6697613501022404], 
     Hue[0.0076056138338941315`, 1, 0.9894691500761467], 
     Hue[0.025340553787472464`, 1, 0.964913079371192], 
     Hue[0.62447141087357, 1, 0.13534727725197998`], 
     Hue[0.6468615374737116, 1, 0.10434556349793787`], 
     Hue[0.017048738624436455`, 1, 0.9763940542123187], 
     Hue[0.0056281282467732785`, 1, 0.9922072070429293], 
     Hue[0.24293681630038833`, 1, 0.6636259466610007], 
     Hue[0.01399637405249432, 1, 0.9806204051580847], 
     Hue[0.0127790068636221, 1, 0.9823059904965232], 
     Hue[0.0005340421827835229, 1, 0.9992605569776845], 
     Hue[0.24240396455977337`, 1, 0.6643637413787754], 
     Hue[0.24221296293629857`, 1, 0.664628205165125], 
     Hue[0.004704974984887311, 1, 0.9934854192516945], 
     Hue[0.6492820329770811, 1, 0.10099410818558009`], 
     Hue[0.00022440864791439807`, 1, 0.9996892803336569], 
     Hue[0.24274942655253734`, 1, 0.6638854093887945], 
     Hue[0.0052464110044955214`, 1, 0.9927357386091601], 
     Hue[0.00802860453632126, 1, 0.9888834706420168], 
     Hue[0.24281318085907933`, 1, 0.6637971341951209], 
     Hue[0.008900173204143491, 1, 0.9876766832558014], 
     Hue[0.004010648438320885, 1, 0.9944467944700173], 
     Hue[0.24293918265887698`, 1, 0.6636226701646318], 
     Hue[0.01056567476351944, 1, 0.9853706041735885], 
     Hue[0.0013097546715873376`, 1, 0.9981864935316483], 
     Hue[0.2422538185750024, 1, 0.6645716358192274], 
     Hue[0.24237366540118938`, 1, 0.6644056940598917], 
     Hue[0.005069923141861388, 1, 0.9929801064189611], 
     Hue[0.001557312940686284, 1, 0.9978437205436651], 
     Hue[0.24288478246956158`, 1, 0.663697993503684], 
     Hue[0.007213858733613021, 1, 0.9900115802149974], 
     Hue[0.003930591712660081, 1, 0.9945576422440092], 
     Hue[0.24263333903574652`, 1, 0.6640461459505048], 
     Hue[0.0065294112199941745`, 1, 0.9909592767723157], 
     Hue[0.24291498931313066`, 1, 0.6636561686433575], 
     Hue[0.00010295154861172939`, 1, 0.9998574517019222], 
     Hue[0.004594979824449452, 1, 0.99363772024307], 
     Hue[0.64977086055894, 1, 0.1003172699953139], 
     Hue[0.6498267959460592, 1, 0.10023982099776421`], 
     Hue[0.6354689910457146, 1, 0.12011985855208748`], 
     Hue[0.5895653930160409, 1, 0.18367868659317405`], 
     Hue[0.4960796990600623, 1, 0.3131204166860676], 
     Hue[0.3517577479465543, 1, 0.5129508105355403], 
     Hue[0.17350218449302507`, 1, 0.7597662060865807], 
     Hue[0.04718868651621222, 1, 0.93466181866986], 
     Hue[0., 1, 1.], 
     Hue[0.03222225681951929, 1, 0.9553845674806656], 
     Hue[0.09262977370060799, 1, 0.8717433902606967], 
     Hue[0.1552079445627536, 1, 0.7850966921438796], 
     Hue[0.19781457918251122`, 1, 0.7261028903626768], 
     Hue[0.2238565485266671, 1, 0.6900447789630764], 
     Hue[0.23804995165578857`, 1, 0.6703923746304467], 
     Hue[0.24262212671540995`, 1, 0.66406167070174], 
     Hue[0.24188124646142117`, 1, 0.6650875048995707], 
     Hue[0.23527423423659388`, 1, 0.6742356756724085], 
     Hue[0.22057622401421495`, 1, 0.6945867667495486], 
     Hue[0.1914522297432143, 1, 0.7349122972786264], 
     Hue[0.1494403947884514, 1, 0.7930825302929134], 
     Hue[0.08924648820947689, 1, 0.8764279394022628], 
     Hue[0.029471631938418397`, 1, 0.9591931250083437], 
     Hue[0.0046895608291251945`, 1, 0.9935067619289036], 
     Hue[0.05391528936430667, 1, 0.9253480608801907], 
     Hue[0.1807688007404623, 1, 0.749704737436283], 
     Hue[0.3437728212740789, 1, 0.5240068628512755], 
     Hue[0.49912405492813827`, 1, 0.30890515471488544`], 
     Hue[0.5905018903532525, 1, 0.1823819979724196], 
     Hue[0.6358419158002138, 1, 0.11960350119970403`], 
     Hue[0.644747440517332, 1, 0.10727277466830956`], 
     Hue[0.6180295514869177, 1, 0.14426677486426775`], 
     Hue[0.5499667694887826, 1, 0.23850754993860868`], 
     Hue[0.26137128574962687`, 1, 0.6381012966543628], 
     Hue[0.10194496084760285`, 1, 0.8588454388263961], 
     Hue[0.011362483237401855`, 1, 0.9842673309020589], 
     Hue[0.009039133546419609, 1, 0.9874842766280343], 
     Hue[0.1256830595597057, 1, 0.8259773021480997], 
     Hue[0.17865541471287094`, 1, 0.7526309642437172], 
     Hue[0.21262000720841728`, 1, 0.7056030669421914], 
     Hue[0.23247723786311014`, 1, 0.6781084398818474], 
     Hue[0.2411170959309321, 1, 0.6661455594802478], 
     Hue[0.24288589868948646`, 1, 0.6636964479684034], 
     Hue[0.23948572873784468`, 1, 0.6684043755937535], 
     Hue[0.22920310046934272`, 1, 0.6826418608886023], 
     Hue[0.2079196133987707, 1, 0.7121113045247791], 
     Hue[0.17232342850117444`, 1, 0.7613983297676047], 
     Hue[0.057669974532247315`, 1, 0.920149266032273], 
     Hue[0.010810649245944437`, 1, 0.9850314087363846], 
     Hue[0.017536918417845326`, 1, 0.9757181129599064], 
     Hue[0.10904803192953882`, 1, 0.8490104173283308], 
     Hue[0.4277075621287773, 1, 0.40778952936015456`], 
     Hue[0.551723842248992, 1, 0.2360746799629343], 
     Hue[0.6186826716428605, 1, 0.14336245464834704`], 
     Hue[0.645113769213699, 1, 0.10676555031949365`], 
     Hue[0.647687522076236, 1, 0.10320189250982711`], 
     Hue[0.6279113551657355, 1, 0.13058427746282786`], 
     Hue[0.5714830279065303, 1, 0.20871580751403512`], 
     Hue[0.13596186728554227`, 1, 0.8117451068354029], 
     Hue[0.026128086020435926`, 1, 0.9638226501255502], 
     Hue[0.0023509801766903315`, 1, 0.9967447966784287], 
     Hue[0.20569179722591574`, 1, 0.715195973071809], 
     Hue[0.22858894585906647`, 1, 0.6834922288105234], 
     Hue[0.23980772147892598`, 1, 0.6679585394907179], 
     Hue[0.24291451281894372`, 1, 0.6636568284045394], 
     Hue[0.24088035873712038`, 1, 0.6664733494409103], 
     Hue[0.23252726943555174`, 1, 0.6780391653969283], 
     Hue[0.21470616589684538`, 1, 0.7027145395274449], 
     Hue[0.018889791545872336`, 1, 0.9738449040134075], 
     Hue[0.008305222644471644, 1, 0.9885004609538084], 
     Hue[0.0790920665848659, 1, 0.8904879078055703], 
     Hue[0.5272056445812282, 1, 0.270022953656761], 
     Hue[0.6061907030226347, 1, 0.1606590265840443], 
     Hue[0.6411506213987276, 1, 0.11225298575560806`], 
     Hue[0.6407753896662215, 1, 0.11277253738523188`], 
     Hue[0.6053721124676309, 1, 0.16179245966020342`], 
     Hue[0.07220232904566781, 1, 0.9000275443983061], 
     Hue[0.002777776285926681, 1, 0.9961538482194862], 
     Hue[0.019284844440944804`, 1, 0.9732979076971534], 
     Hue[0.23560538048941515`, 1, 0.6737771654761944], 
     Hue[0.2420376074539074, 1, 0.6648710050638205], 
     Hue[0.24254545650580367`, 1, 0.6641678294535026], 
     Hue[0.23763631682842334`, 1, 0.6709650997760293], 
     Hue[0.005871287397505864, 1, 0.991870525141915], 
     Hue[0.032738990832565484`, 1, 0.9546690896164478], 
     Hue[0.572736519619314, 1, 0.20698020360402675`], 
     Hue[0.6284237437465504, 1, 0.1298748163509302], 
     Hue[0.6480191484796949, 1, 0.10274271748965322`], 
     Hue[0.6488443750266125, 1, 0.10160009611699812`], 
     Hue[0.6319530704454684, 1, 0.12498805630627452`], 
     Hue[0.03587551882417872, 1, 0.9503262047049833], 
     Hue[0.0005871729658315505, 1, 0.9991869912780794], 
     Hue[0.23898887816282172`, 1, 0.6690923225437853], 
     Hue[0.24280987854795794`, 1, 0.6638017066259044], 
     Hue[0.24142664643346395`, 1, 0.6657169510921268], 
     Hue[0.02390761713946854, 1, 0.9668971454991975], 
     Hue[0.005826105477265697, 1, 0.9919330847237859], 
     Hue[0.6386840952669439, 1, 0.11566817578423153`], 
     Hue[0.6429064205873171, 1, 0.1098218791867918], 
     Hue[0.0063152970214653825`, 1, 0.9912557425856633], 
     Hue[0.23413099190537467`, 1, 0.6758186265925582], 
     Hue[0.2416225516959748, 1, 0.6654456976517272], 
     Hue[0.24275495153474191`, 1, 0.6638777594134343], 
     Hue[0.2386220547719618, 1, 0.6696002318542068], 
     Hue[0.007909158848099285, 1, 0.9890488569795548], 
     Hue[0.02437882899720245, 1, 0.9662446983115659], 
     Hue[0.6238686848140528, 1, 0.13618182102669624`], 
     Hue[0.6466823867975802, 1, 0.10459361828027368`], 
     Hue[0.01795898965920595, 1, 0.9751337066257147], 
     Hue[0.0052003720824900235`, 1, 0.99279948480886], 
     Hue[0.24293923732195827`, 1, 0.6636225944772886], 
     Hue[0.014497451754876156`, 1, 0.9799266052624791], 
     Hue[0.012191540059722783`, 1, 0.9831194060711531], 
     Hue[0.0006952944588031196, 1, 0.9990372845955033], 
     Hue[0.2423682897281612, 1, 0.6644131372994692], 
     Hue[0.24225510785718468`, 1, 0.6645698506592828], 
     Hue[0.004772646106838918, 1, 0.9933917207751461], 
     Hue[0.6491531882498848, 1, 0.10117250857708265`], 
     Hue[0.00014106661170887325`, 1, 0.9998046769991723], 
     Hue[0.2427266445725117, 1, 0.66391695366883], 
     Hue[0.005094503875524015, 1, 0.9929460715569668], 
     Hue[0.00864733488158842, 1, 0.9880267670870315], 
     Hue[0.24283015239495992`, 1, 0.6637736351454401], 
     Hue[0.009256798249721698, 1, 0.9871828947311546], 
     Hue[0.003645891348118213, 1, 0.9949518427487594], 
     Hue[0.24293671597499894`, 1, 0.6636260855730785], 
     Hue[0.010068920788690261`, 1, 0.9860584173695058], 
     Hue[0.0015586111017354964`, 1, 0.9978419230899046], 
     Hue[0.24221314641020653`, 1, 0.6646279511243295], 
     Hue[0.2424105850143647, 1, 0.6643545745954951], 
     Hue[0.00519997918695525, 1, 0.9928000288180621], 
     Hue[0.0013275443995891534`, 1, 0.998161861600569], 
     Hue[0.24287235354241565`, 1, 0.6637152027874245], 
     Hue[0.006893525527503774, 1, 0.9904551185003794], 
     Hue[0.00436091039463804, 1, 0.9939618163766549], 
     Hue[0.24266013511274842`, 1, 0.6640090436900407], 
     Hue[0.0067774675810381435`, 1, 0.9906158141185625], 
     Hue[0.24292226469216777`, 1, 0.6636460950416139], 
     Hue[0.00017893923430534198`, 1, 0.9997522379832695], 
     Hue[0.004598111188936382, 1, 0.9936333845076265], 
     Hue[0.6496525416343352, 1, 0.10048109619861283`], 
     Hue[0.000031751580881422825`, 1, 0.9999560362726257], 
     Hue[0.004851796307673739, 1, 0.9932821281893748], 
     Hue[0.2428604506785837, 1, 0.6637316836758073], 
     Hue[0.2429280897525657, 1, 0.6636380295733706], 
     Hue[0.002123185981432907, 1, 0.9970602040257084], 
     Hue[0.005505697464917247, 1, 0.9923767265870377], 
     Hue[0.0009212675345182664, 1, 0.9987243987983593], 
     Hue[0.24284368127478534`, 1, 0.6637549028502973], 
     Hue[0.0063172929391455135`, 1, 0.991252979007337], 
     Hue[0.2429331794163045, 1, 0.6636309823466553], 
     Hue[0.0003943322151029882, 1, 0.999454001548319], 
     Hue[0.00465324008891177, 1, 0.9935570521845837], 
     Hue[0.0003266523135074806, 1, 0.9995477121812972], 
     Hue[0.005418884459220674, 1, 0.9924969292103099], 
     Hue[0.24294042309726, 1, 0.6636209526345631], 
     Hue[0.0010830097739441547`, 1, 0.9985004480053081], 
     Hue[0.004955256828851562, 1, 0.9931388751600516], 
     Hue[0.24289594818863453`, 1, 0.6636825332772753], 
     Hue[0.2429065029932575, 1, 0.6636679189324127], 
     Hue[0.00004789491497536602, 1, 0.9999336839638802], 
     Hue[0.00460831361475178, 1, 0.9936192580718821], 
     Hue[0.6498866648577772, 1, 0.10015692558153926`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.614729195998557*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[310]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "IntensityFunction", 
    "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
   RowBox[{"OutputGraphics", "\[Rule]", 
    GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwlmXk01O/bx7XYisi+hVApIUtIdF98I1HKmi0KkSJbxdiZIfu+RrYsM2Pf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      "], {{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne811Mcx/Hb0t5LRYPSUmnvSUqiNGmS0UK0RKEd2mlQKNo7ZbVU0la0
p9XetCd5fh7+eN3P6/35nvv7ne/5nvO9N1+7Lo1eTZSQkNA5cUJC1M1+VMMm
3hX59MfJeVFFTpC78zt0FvLghNwSx/lIFDVmslwEz8iZ5SE8E5b//xEJW3h1
bObdcJ/meDkfqsqJ5B4xIcxW8uIkb4UTfBRaIItx7+llxgo5CX7iNbCFd0e1
+E7jeuolwpy4L5zirXGSj0ZLJMVWvZr4ifdA9ZgfkmGbfi1s5T1RA/fjtF4b
nOJj0Ap34We9h7GNv4GaMUdzeUMvMebK+XGGt8Vp/iFaI6tx7+tlwUo5OX7h
j+Bn3iu+25gJ8n0xr5i/3IsnwTy5rDybl0EB+az6LM7wWq59w8fyB/kUXhQN
+Nq4H/1s/APeQs2q1lVXqC+q37teSV0Qn6lWVBurG9SOagrXt/PaaCb/Emup
LpHbqW/GvasfxXNV71frq6tjzWK9YwxPGp/Bl6rz9cvxObwsHpDPqc/hLB+H
tshuzFC9bFglp8QO/ii287fwCAoiFXbq18EO3hu1UQjnY644x8fjWaTGrlgL
7OR98CgK4y+953GeT8BzSIPdeo9hF38bdWJ/mONbesmwQC6Cv/kL+It/hHZI
iz169bCbv4O6sR/8fm+9u7Awzh0uxLPB3/xjFDPmc/nBmJd8tzyMZ8dqOR32
8sexh7+LAsZ8LOePOcsp5D48ORbFXsFF/hIu8IkobswXcrGYv5xDHs7vjs/g
K9U1+pX5Ql4J6eV98cyxN86Sa1/xvvwBPjHOp1pAfUJdo7ZX68XzVN+O90vs
s3iu6rL4bvVL18urc+NMqeXURup6tYNazPVL8Vl4Wr4oP6x+K0/iJfhUXhwN
+Y+xpvo5+QieI55F7H/1B/0qfBGvjAzy/pgv9vF+scdcnxR7NdY59pv8Dk+J
xbF2uBxzwyX+CR4yZppcItZZziWP5DmxVs6IA/xJ7Of9UT/2pnHv6qXCkrgX
XInziMv8U7RHJhyMs44DfACeiL3q9/vqpcZXMQ9c5Z1whX+GDsiMQ7E+OMgH
4kmUxDW9zrjKJ6MjsuBXvadwiA9CA5SK9xx+i2eEX/lgNERpXNd7Gdf4FHSK
dxJ+j3cNfuND4qya9ydywfiOODNyP54GX8sV5Hm8PMrIN9RXcD3eA659xz+P
+fPp/KH4HL4u7kX/Hj6Kt1RzxXNUV8Wzif3hetXYd/EeUquoTdSNsW5qdtf/
iB6ay7/LNdWv40zG3694d6ifym3UQvFc1R9iTeKM8v48bbyj+HL1G/2KfD6v
gLLyTTX+mN/gX8Tauj5DLhlrKN8rj+b3YF28C/Anb4o/+PtojPTGDdBLh2/l
crjFu+Amn4pX4ozjsF4z/Mk/QJM4e3FWcCTuF4f5UDSN54Dbeq/hFp+GV2N/
42icRxzhw9AMGcxlYLwr8F3cM/7hr+M2n44uyG3cGL17sT6eF47F+wFH+XA0
j3Nj3KA4p1gqV8K/vCv+4TNi3xkzUy4V85TzyB/y3NgQ64jjvAWO8REoYsxn
cuG4hzhf8mCeEcvkyrjDu+FfPhNljJkll477kfPKY3kebJSryYt51XhGfFOi
//9Py+3af37HGZo=
         "],
         VertexColors->Automatic]}},
      VertexColors->{
        Hue[0.649938493065757, 1, 0.10008516344741332`], 
        Hue[0.6358741673773562, 1, 0.11955884516981446`], 
        Hue[0.5905873008762106, 1, 0.1822637372483239], 
        Hue[0.4979484307175077, 1, 0.3105329420834509], 
        Hue[0.35451602692890677`, 1, 0.5091316550215137], 
        Hue[0.17594571030521544`, 1, 0.7563828626543171], 
        Hue[0.04871156498928875, 1, 0.9325532177071387], 
        Hue[0.000013609696291161377`, 1, 0.9999811558051354], 
        Hue[0.0314036943625815, 1, 0.9565179616518102], 
        Hue[0.09156431400777065, 1, 0.8732186421430868], 
        Hue[0.15440729473713571`, 1, 0.7862052842101198], 
        Hue[0.19728975639734175`, 1, 0.7268295680652191], 
        Hue[0.22353088478615885`, 1, 0.6904956979883954], 
        Hue[0.2379237277953894, 1, 0.6705671461294608], 
        Hue[0.2425926025512165, 1, 0.6641025503137002], 
        Hue[0.24193191586286183`, 1, 0.6650173472668067], 
        Hue[0.23542808694625678`, 1, 0.6740226488436445], 
        Hue[0.2209138717928834, 1, 0.694119254440623], 
        Hue[0.19199095316047804`, 1, 0.7341663725470304], 
        Hue[0.15027256198639483`, 1, 0.7919302987880686], 
        Hue[0.09024026146077968, 1, 0.8750519456696897], 
        Hue[0.030201651163216492`, 1, 0.9581823291586233], 
        Hue[0.004638232614477711, 1, 0.9935778317645693], 
        Hue[0.052509982832162905`, 1, 0.9272938699246975], 
        Hue[0.1783815195657164, 1, 0.7530102036782388], 
        Hue[0.34101624848043155`, 1, 0.5278236559501718], 
        Hue[0.4972517255084437, 1, 0.3114976108344626], 
        Hue[0.5894055607044238, 1, 0.18389999287079783`], 
        Hue[0.6354581494053099, 1, 0.12013487005418634`], 
        Hue[0.65, 1, 0.1], 
        Hue[0.6449588292034519, 1, 0.10698008264137433`], 
        Hue[0.6187237577052757, 1, 0.14330556625423374`], 
        Hue[0.5514160646799522, 1, 0.23650083352006626`], 
        Hue[0.43176207292228613`, 1, 0.4021755913383731], 
        Hue[0.26421151941190163`, 1, 0.6341686654296746], 
        Hue[0.1039527542770432, 1, 0.8560654171548633], 
        Hue[0.012101677487688978`, 1, 0.9832438311708921], 
        Hue[0.00850856280765877, 1, 0.9882189130355494], 
        Hue[0.06019131412133816, 1, 0.9166581804473779], 
        Hue[0.12469346490218047`, 1, 0.8273475101354424], 
        Hue[0.17798752106493576`, 1, 0.7535557400639351], 
        Hue[0.2122139032390356, 1, 0.7061653647459507], 
        Hue[0.23225737272044306`, 1, 0.678412868540925], 
        Hue[0.24104723166655917`, 1, 0.6662422946155335], 
        Hue[0.24289680610768544`, 1, 0.6636813453893586], 
        Hue[0.2395855333102348, 1, 0.6682661846473672], 
        Hue[0.2294288501666213, 1, 0.6823292843846782], 
        Hue[0.20837155645829114`, 1, 0.7114855372115969], 
        Hue[0.1729771897632726, 1, 0.760493121866238], 
        Hue[0.12176466277218645`, 1, 0.8314027746231264], 
        Hue[0.058630755354584396`, 1, 0.9188189541244216], 
        Hue[0.011230179613809343`, 1, 0.9844505205347255], 
        Hue[0.016787527287653203`, 1, 0.9767557314478648], 
        Hue[0.10704567305450974`, 1, 0.8517829142322172], 
        Hue[0.2584223206823415, 1, 0.6421844790552195], 
        Hue[0.42524505184003053`, 1, 0.411199158990727], 
        Hue[0.5502953978065704, 1, 0.23805252611397937`], 
        Hue[0.6179872284458, 1, 0.14432537599812303`], 
        Hue[0.6448998313517809, 1, 0.10706177197445726`], 
        Hue[0.6478425042462428, 1, 0.10298730181289469`], 
        Hue[0.6284471834969069, 1, 0.12984236131197513`], 
        Hue[0.5727113716380293, 1, 0.20701502388580556`], 
        Hue[0.46645977421420126`, 1, 0.3541326203187982], 
        Hue[0.309714456936927, 1, 0.5711645980873319], 
        Hue[0.13821354400198216`, 1, 0.8086274006126402], 
        Hue[0.027260279179128544`, 1, 0.9622549980596681], 
        Hue[0.002069212291204714, 1, 0.9971349368275626], 
        Hue[0.045218768976820756`, 1, 0.937389396801325], 
        Hue[0.10843160848475886`, 1, 0.8498639267134108], 
        Hue[0.16672938513660746`, 1, 0.7691439282723896], 
        Hue[0.20522774408762623`, 1, 0.7158385081863637], 
        Hue[0.22831875753897807`, 1, 0.6838663357152611], 
        Hue[0.23971165280865592`, 1, 0.6680915576495534], 
        Hue[0.2429058564863416, 1, 0.6636688140958347], 
        Hue[0.24095387459151096`, 1, 0.6663715582579078], 
        Hue[0.23271526620601346`, 1, 0.677778862176289], 
        Hue[0.21509936709691735`, 1, 0.702170107096576], 
        Hue[0.18294451617238688`, 1, 0.7466922083766951], 
        Hue[0.1364862118626946, 1, 0.8110190912670383], 
        Hue[0.0743154558767265, 1, 0.8971016764783787], 
        Hue[0.019484451417796533`, 1, 0.9730215288061279], 
        Hue[0.007919586572809445, 1, 0.9890344185914945], 
        Hue[0.07737360557414119, 1, 0.8928673153588815], 
        Hue[0.21760732674709288`, 1, 0.6986975475809483], 
        Hue[0.38430159615894394`, 1, 0.4678900976260776], 
        Hue[0.5255548315465994, 1, 0.27230869478163156`], 
        Hue[0.6053083095286513, 1, 0.16188080219109816`], 
        Hue[0.6408614618092212, 1, 0.11265336057184766`], 
        Hue[0.641058804060438, 1, 0.11238011745477816`], 
        Hue[0.6062530894156665, 1, 0.16057264542446192`], 
        Hue[0.5265164802918042, 1, 0.270977181134425], 
        Hue[0.21920699381676656`, 1, 0.6964826239460156], 
        Hue[0.07392421199042642, 1, 0.8976433987824864], 
        Hue[0.0031391385562195007`, 1, 0.9956535004606192], 
        Hue[0.018555541470199777`, 1, 0.9743077118104926], 
        Hue[0.14007958618520522`, 1, 0.8060436498974081], 
        Hue[0.1881700337023799, 1, 0.7394568764120893], 
        Hue[0.21829677038255385`, 1, 0.6977429333164639], 
        Hue[0.23543052355545147`, 1, 0.6740192750770673], 
        Hue[0.24199045651332346`, 1, 0.6649362909815522], 
        Hue[0.2425760049028693, 1, 0.6641255316729502], 
        Hue[0.23776650936503085`, 1, 0.6707848331868804], 
        Hue[0.2255125268403259, 1, 0.6877518859133949], 
        Hue[0.20068248766214664`, 1, 0.7221319401601046], 
        Hue[0.16208264859084515`, 1, 0.7755778711819067], 
        Hue[0.04371614699044968, 1, 0.9394699503209158], 
        Hue[0.006076175184724919, 1, 0.9915868343596116], 
        Hue[0.031610607863258755`, 1, 0.9562314660354879], 
        Hue[0.1409633959215164, 1, 0.8048199133394389], 
        Hue[0.463077843340281, 1, 0.358815293836534], 
        Hue[0.5715231364312646, 1, 0.20866027263363357`], 
        Hue[0.6278869376704564, 1, 0.13061808630244504`], 
        Hue[0.6478637099087889, 1, 0.10295794012629222`], 
        Hue[0.6489762270491305, 1, 0.10141753177812704`], 
        Hue[0.6324202093044816, 1, 0.12434124865533322`], 
        Hue[0.5820613221864717, 1, 0.19406893851103924`], 
        Hue[0.4826238513839495, 1, 0.33175159039145463`], 
        Hue[0.33227410434763993`, 1, 0.5399281632109602], 
        Hue[0.15669914592620343`, 1, 0.7830319517944876], 
        Hue[0.03720450063175462, 1, 0.9484860760483398], 
        Hue[0.0004476301727304177, 1, 0.9993802043762193], 
        Hue[0.03813072504697368, 1, 0.947203611473421], 
        Hue[0.10005293944572924`, 1, 0.8614651607674517], 
        Hue[0.1606994254836548, 1, 0.777493103176478], 
        Hue[0.2013804731055241, 1, 0.7211654987769667], 
        Hue[0.2260360957880304, 1, 0.6870269442934964], 
        Hue[0.23887824876642644`, 1, 0.669245501708025], 
        Hue[0.2427910353345592, 1, 0.6638277972290718], 
        Hue[0.24148836081151637`, 1, 0.6656315004148236], 
        Hue[0.23413973704573654`, 1, 0.6758065179366725], 
        Hue[0.2181175332060996, 1, 0.6979911078684774], 
        Hue[0.1875819223195057, 1, 0.7402711844806844], 
        Hue[0.14350356859037128`, 1, 0.8013027511825628], 
        Hue[0.08227685123058825, 1, 0.8860782059884162], 
        Hue[0.024574860279835242`, 1, 0.9659732703817666], 
        Hue[0.00561206866708297, 1, 0.9922294433840391], 
        Hue[0.06431351135931318, 1, 0.9109505227332586], 
        Hue[0.19773673251696433`, 1, 0.726210678053434], 
        Hue[0.3628955549218317, 1, 0.4975292316466946], 
        Hue[0.5118463674385785, 1, 0.2912896450850453], 
        Hue[0.5977865571960401, 1, 0.17229553619009824`], 
        Hue[0.6383502117552429, 1, 0.11613047603120219`], 
        Hue[0.6431517151854681, 1, 0.10948224051242877`], 
        Hue[0.6128602541465582, 1, 0.15142426348938104`], 
        Hue[0.5394239938133354, 1, 0.25310523933538176`], 
        Hue[0.24156930349962946`, 1, 0.66551942592359], 
        Hue[0.0883684273530787, 1, 0.8776437159726603], 
        Hue[0.006862671766282191, 1, 0.9904978390928401], 
        Hue[0.013131414241654427`, 1, 0.9818180418192477], 
        Hue[0.1325092901431738, 1, 0.8165255982632977], 
        Hue[0.1832129128211965, 1, 0.7463205822475741], 
        Hue[0.21536496123231758`, 1, 0.7018023613706372], 
        Hue[0.23393430211034122`, 1, 0.6760909663087583], 
        Hue[0.2415644445110947, 1, 0.6655261537538689], 
        Hue[0.24277558294640866`, 1, 0.6638491928434341], 
        Hue[0.238736511159101, 1, 0.6694417537797064], 
        Hue[0.22755280483815737`, 1, 0.6849268856087052], 
        Hue[0.20464991989517733`, 1, 0.7166385724528314], 
        Hue[0.1676455927361552, 1, 0.7678753331345544], 
        Hue[0.051040025199387884`, 1, 0.9293291958777706], 
        Hue[0.008226201348992213, 1, 0.9886098750552414], 
        Hue[0.02344084860751061, 1, 0.9675434403896007], 
        Hue[0.1235165366848554, 1, 0.8289771030517387], 
        Hue[0.4445898743090676, 1, 0.38441402018744486`], 
        Hue[0.561340331093485, 1, 0.22275954156286684`], 
        Hue[0.6232561010513117, 1, 0.13703001392895314`], 
        Hue[0.6464996169089005, 1, 0.10484668427998399`], 
        Hue[0.6465124810522591, 1, 0.10482887238917975`], 
        Hue[0.6239004235147201, 1, 0.1361378751334646], 
        Hue[0.5625051715042461, 1, 0.2211466856095055], 
        Hue[0.12059793676902664`, 1, 0.8330182413967324], 
        Hue[0.018893835004392012`, 1, 0.9738393053785341], 
        Hue[0.0047880791116963195`, 1, 0.9933703519991898], 
        Hue[0.20883693238894285`, 1, 0.7108411705383868], 
        Hue[0.23038904986361058`, 1, 0.6809997771119238], 
        Hue[0.24043206695659142`, 1, 0.6670940611370273], 
        Hue[0.2429404403961949, 1, 0.6636209286821917], 
        Hue[0.24032201531881137`, 1, 0.6672464403277997], 
        Hue[0.23114735397537128`, 1, 0.6799498175725629], 
        Hue[0.2118527754603053, 1, 0.7066653878241927], 
        Hue[0.015009554352580334`, 1, 0.9792175401271964], 
        Hue[0.011626889497613702`, 1, 0.9839012299263811], 
        Hue[0.09163910013354026, 1, 0.8731150921227904], 
        Hue[0.5383704079854961, 1, 0.2545640504816208], 
        Hue[0.6120234756793664, 1, 0.15258287982856955`], 
        Hue[0.6430321108068267, 1, 0.10964784657516316`], 
        Hue[0.6386453224664642, 1, 0.1157218612002804], 
        Hue[0.598846580304952, 1, 0.1708278118854511], 
        Hue[0.06068719802985534, 1, 0.9159715719586617], 
        Hue[0.0008782352204227406, 1, 0.9987839820024916], 
        Hue[0.024679649691824457`, 1, 0.9658281773497815], 
        Hue[0.23675677058823957`, 1, 0.6721829330316683], 
        Hue[0.24233138026757767`, 1, 0.6644642427064309], 
        Hue[0.24229593452182274`, 1, 0.6645133214313224], 
        Hue[0.23666671620205776`, 1, 0.6723076237202278], 
        Hue[0.004856118727534553, 1, 0.9932761433003368], 
        Hue[0.041303831797003365`, 1, 0.942810079050303], 
        Hue[0.5808682231554523, 1, 0.19572092178475842`], 
        Hue[0.6319359910749897, 1, 0.1250117046653989], 
        Hue[0.6490215920645284, 1, 0.10135471867988384`], 
        Hue[0.6494773327055394, 1, 0.10072369317694538`], 
        Hue[0.6342087330231195, 1, 0.12186483119875761`], 
        Hue[0.5864250969640279, 1, 0.18802678881903834`], 
        Hue[0.49039283759310626`, 1, 0.3209945325633914], 
        Hue[0.3434432237934854, 1, 0.5244632285936357], 
        Hue[0.16623441922116738`, 1, 0.7698292656937683], 
        Hue[0.04276434577331989, 1, 0.9407878289292494], 
        Hue[0.00007679176017338918, 1, 0.9998936729474521], 
        Hue[0.03471739730175005, 1, 0.9519297575821922], 
        Hue[0.09581942617566908, 1, 0.8673269483721505], 
        Hue[0.1575857700781747, 1, 0.7818043183532966], 
        Hue[0.19936585815728924`, 1, 0.7239549656283688], 
        Hue[0.22481193449965298`, 1, 0.6887219368466344], 
        Hue[0.23841664749117847`, 1, 0.6698846419352913], 
        Hue[0.2427025327369567, 1, 0.6639503392872907], 
        Hue[0.24172113730854938`, 1, 0.6653091944958547], 
        Hue[0.23480046731546206`, 1, 0.6748916606401294], 
        Hue[0.21954300256722858`, 1, 0.6960173810607604], 
        Hue[0.18981483182634717`, 1, 0.7371794636250578], 
        Hue[0.1469198142750071, 1, 0.7965725648499901], 
        Hue[0.08626156846681077, 1, 0.8805609051998005], 
        Hue[0.0273260897853026, 1, 0.9621638756818888], 
        Hue[0.004963014184779402, 1, 0.99312813420569], 
        Hue[0.05825200866613822, 1, 0.9193433726161162], 
        Hue[0.18798748353570155`, 1, 0.7397096381813363], 
        Hue[0.35200740343737535`, 1, 0.5126051337020957], 
        Hue[0.5046590281883945, 1, 0.3012413455852999], 
        Hue[0.5937066226343508, 1, 0.17794467635243744`], 
        Hue[0.6369543886566887, 1, 0.11806315416766175`], 
        Hue[0.6440889167723793, 1, 0.10818457677670562`], 
        Hue[0.6158814261215018, 1, 0.14724110229330523`], 
        Hue[0.5455338694872526, 1, 0.24464541147918872`], 
        Hue[0.2528652141785069, 1, 0.6498789342143751], 
        Hue[0.09602275426955087, 1, 0.8670454171652372], 
        Hue[0.009290015362268256, 1, 0.98713690180609], 
        Hue[0.010713488270728377`, 1, 0.985165939317453], 
        Hue[0.12863061507223938`, 1, 0.8218960714384378], 
        Hue[0.18063384730919002`, 1, 0.7498915960334291], 
        Hue[0.21381726377169769`, 1, 0.7039453270853416], 
        Hue[0.23311909649528167`, 1, 0.6772197125449946], 
        Hue[0.24131764623154633`, 1, 0.6658678744486282], 
        Hue[0.24284590844423104`, 1, 0.6637518190772186], 
        Hue[0.23917560670778654`, 1, 0.6688337753276802], 
        Hue[0.2285109458103161, 1, 0.6836002288780239], 
        Hue[0.20654113455121414`, 1, 0.7140199675444727], 
        Hue[0.17034038401171164`, 1, 0.7641440836760915], 
        Hue[0.05480692141553578, 1, 0.9241134934246428], 
        Hue[0.009626310941832528, 1, 0.9866712617728473], 
        Hue[0.019925739857921787`, 1, 0.9724105140428776], 
        Hue[0.11515332965430136`, 1, 0.8405569281709673], 
        Hue[0.43502017112478353`, 1, 0.3976643784426075], 
        Hue[0.5559269137383687, 1, 0.2302550425161049], 
        Hue[0.6207049662420664, 1, 0.14056235443406198`], 
        Hue[0.6457311365595364, 1, 0.10591073399448812`], 
        Hue[0.6472036790882919, 1, 0.1038718289546728], 
        Hue[0.6262490055599088, 1, 0.13288599230166476`], 
        Hue[0.5677171136998695, 1, 0.21393015026171913`], 
        Hue[0.1292904969224421, 1, 0.8209823888766186], 
        Hue[0.02287962775689989, 1, 0.9683205154135233], 
        Hue[0.003297360104398517, 1, 0.9954344244708329], 
        Hue[0.20706174400905775`, 1, 0.7132991236797662], 
        Hue[0.22937980562046162`, 1, 0.6823971922178224], 
        Hue[0.24008549095091536`, 1, 0.6675739356064249], 
        Hue[0.24293301960059616`, 1, 0.6636312036299438], 
        Hue[0.24065055236164995`, 1, 0.6667915428838693], 
        Hue[0.23194969037143282`, 1, 0.6788388902549392], 
        Hue[0.2135050221085743, 1, 0.7043776616958202], 
        Hue[0.017165074748182296`, 1, 0.9762329734255938], 
        Hue[0.009594603545152736, 1, 0.9867151643220963], 
        Hue[0.08435939786654623, 1, 0.8831946798770898], 
        Hue[0.5320742886563394, 1, 0.26328175416814537`], 
        Hue[0.6087633130142094, 1, 0.15709695121109477`], 
        Hue[0.6419869437680921, 1, 0.11109500093648796`], 
        Hue[0.639894402724465, 1, 0.11399236545843314`], 
        Hue[0.6026531603603668, 1, 0.1655571625779538], 
        Hue[0.06715110997453766, 1, 0.9070215400352556], 
        Hue[0.0018297104640305761`, 1, 0.9974665547421115], 
        Hue[0.0215363966805433, 1, 0.97018037382694], 
        Hue[0.23611422526742082`, 1, 0.6730726111681866], 
        Hue[0.24217119975554213`, 1, 0.664686031107711], 
        Hue[0.24244621716265308`, 1, 0.6643052377747881], 
        Hue[0.23723339706884855`, 1, 0.671522988673902], 
        Hue[0.0053452853139202006`, 1, 0.9925988357191874], 
        Hue[0.036267025740151615`, 1, 0.949784118205944], 
        Hue[0.5762986393114093, 1, 0.20204803787651024`], 
        Hue[0.6299807161816376, 1, 0.1277190083638863], 
        Hue[0.6484666908473073, 1, 0.10212304344218984`], 
        Hue[0.6484322903213533, 1, 0.10217067493966464`], 
        Hue[0.6305019530049214, 1, 0.12699729583933958`], 
        Hue[0.0320356621989184, 1, 0.9556429292630361], 
        Hue[0.0011154721803823264`, 1, 0.9984555000579323], 
        Hue[0.2393095702974985, 1, 0.6686482872803867], 
        Hue[0.24285865529168527`, 1, 0.6637341695961281], 
        Hue[0.24123286620035844`, 1, 0.665985262184119], 
        Hue[0.021957695447173964`, 1, 0.9695970370731437], 
        Hue[0.006594711929210906, 1, 0.9908688604057079], 
        Hue[0.6396508698321707, 1, 0.1143295648477637], 
        Hue[0.642143102661376, 1, 0.11087878093040252`], 
        Hue[0.004814436689188906, 1, 0.9933338568918922], 
        Hue[0.23470433046146488`, 1, 0.6750247732072024], 
        Hue[0.2417884525642831, 1, 0.6652159887571465], 
        Hue[0.24268569021400233`, 1, 0.6639736597036892], 
        Hue[0.23826717656319502`, 1, 0.67009160168173], 
        Hue[0.007039619470834202, 1, 0.990252834578845], 
        Hue[0.027335329847204104`, 1, 0.9621510817500251], 
        Hue[0.6256477321184175, 1, 0.13371852475911425`], 
        Hue[0.647209217509856, 1, 0.10386416037096859`], 
        Hue[0.01530189122233161, 1, 0.9788127659998486], 
        Hue[0.006529258236329438, 1, 0.9909594885958515], 
        Hue[0.24292832841305323`, 1, 0.6636376991203878], 
        Hue[0.013027917563786517`, 1, 0.9819613449116802], 
        Hue[0.014022731969356772`, 1, 0.9805839095808907], 
        Hue[0.00027601563255674755`, 1, 0.9996178245087677], 
        Hue[0.24247164802389493`, 1, 0.6642700258130686], 
        Hue[0.24212468420495137`, 1, 0.6647504372546827], 
        Hue[0.004617574815177883, 1, 0.9936064348712922], 
        Hue[0.6495316619871018, 1, 0.10064846801785912`], 
        Hue[0.6497127318737437, 1, 0.10039775586712417`], 
        Hue[0.6350564277740989, 1, 0.12069110000509396`], 
        Hue[0.5885311054974225, 1, 0.18511077700356893`], 
        Hue[0.49419749404543645`, 1, 0.3157265467063187], 
        Hue[0.3489926849992745, 1, 0.5167793592317738], 
        Hue[0.17106897372176466`, 1, 0.7631352671544798], 
        Hue[0.04568980625769192, 1, 0.9367371913355035], 
        Hue[6.09978477783546*^-6, 1, 0.9999915541441537], 
        Hue[0.0330474952309282, 1, 0.9542419296802532], 
        Hue[0.09369417962716953, 1, 0.8702695974393038], 
        Hue[0.1560045839915159, 1, 0.7839936529348241], 
        Hue[0.19833552935589482`, 1, 0.7253815747379918], 
        Hue[0.22417859788538547`, 1, 0.6895988644663893], 
        Hue[0.23817416800661556`, 1, 0.6702203827600708], 
        Hue[0.24265028325262583`, 1, 0.6640226847271334], 
        Hue[0.24182923371526088`, 1, 0.6651595225481003], 
        Hue[0.23511835715024532`, 1, 0.6744515054842757], 
        Hue[0.22023520536433383`, 1, 0.6950589464186148], 
        Hue[0.19090997098705936`, 1, 0.7356631170948409], 
        Hue[0.1486042012792279, 1, 0.7942403366902998], 
        Hue[0.08825205226399624, 1, 0.8778048507113898], 
        Hue[0.028748931982809478`, 1, 0.9601937864853407], 
        Hue[0.004760696576692314, 1, 0.9934082662784259], 
        Hue[0.055340772600581234`, 1, 0.9233743148607337], 
        Hue[0.183165701609248, 1, 0.7463859516179643], 
        Hue[0.34652371010590977`, 1, 0.5201979398533557], 
        Hue[0.5009827401009612, 1, 0.3063315906294384], 
        Hue[0.5915841143633571, 1, 0.1808835339584286], 
        Hue[0.6362191549143262, 1, 0.1190811701186252], 
        Hue[0.6445320336833886, 1, 0.10757103028453881`], 
        Hue[0.6173245018682061, 1, 0.14524299741325317`], 
        Hue[0.5485033245222803, 1, 0.24053385835376578`], 
        Hue[0.2585332875126271, 1, 0.642030832674824], 
        Hue[0.09995392257689595, 1, 0.8616022610473748], 
        Hue[0.01064751818501719, 1, 0.9852572825130532], 
        Hue[0.009583609472613941, 1, 0.9867303868840731], 
        Hue[0.1266691499776148, 1, 0.824611946184841], 
        Hue[0.17931909965999165`, 1, 0.7517120158553962], 
        Hue[0.21302259351732472`, 1, 0.7050456397452427], 
        Hue[0.23269413314926196`, 1, 0.6778081233317912], 
        Hue[0.24118544409568593`, 1, 0.6660509235598195], 
        Hue[0.24287378042988478`, 1, 0.6637132270970826], 
        Hue[0.23938415028703458`, 1, 0.6685450226794906], 
        Hue[0.22897487463823663`, 1, 0.6829578658855185], 
        Hue[0.20746390315405155`, 1, 0.7127422879405441], 
        Hue[0.17166603997631985`, 1, 0.7623085600327879], 
        Hue[0.05671231197508109, 1, 0.9214752603421954], 
        Hue[0.010403391228921754`, 1, 0.9855953044522623], 
        Hue[0.01830971312023455, 1, 0.974648089525829], 
        Hue[0.11106687206369958`, 1, 0.8462151002194929], 
        Hue[0.4301576904613472, 1, 0.40439704397659615`], 
        Hue[0.5531385554966293, 1, 0.2341158462354365], 
        Hue[0.6193673682918347, 1, 0.1424144131343828], 
        Hue[0.6453235894943384, 1, 0.10647502993091609`], 
        Hue[0.6475294258467215, 1, 0.10342079498146263`], 
        Hue[0.6273664555249102, 1, 0.1313387538885859], 
        Hue[0.5702412407310771, 1, 0.21043520514158565`], 
        Hue[0.133723999532688, 1, 0.8148436929547397], 
        Hue[0.025020577955309653`, 1, 0.9653561228311096], 
        Hue[0.002649717550851971, 1, 0.996331160314205], 
        Hue[0.20615214077830568`, 1, 0.7145585743069613], 
        Hue[0.228855837231551, 1, 0.6831226869101602], 
        Hue[0.23990204047560543`, 1, 0.667827943956854], 
        Hue[0.24292192231072768`, 1, 0.6636465691082233], 
        Hue[0.2408053089310842, 1, 0.6665772645569603], 
        Hue[0.23233701789674444`, 1, 0.6783025906045077], 
        Hue[0.2143093849512548, 1, 0.7032639285290319], 
        Hue[0.018304909377876655`, 1, 0.9746547408614016], 
        Hue[0.008712862688169953, 1, 0.9879360362779186], 
        Hue[0.08082926427271286, 1, 0.888082557160859], 
        Hue[0.5288424918695671, 1, 0.26775654971906104`], 
        Hue[0.6070605966249363, 1, 0.1594545585193191], 
        Hue[0.6414345382241344, 1, 0.11185987015119851`], 
        Hue[0.6404868988168657, 1, 0.1131719862535706], 
        Hue[0.6044785360483764, 1, 0.16302971931763272`], 
        Hue[0.07049944238912087, 1, 0.9023853874612173], 
        Hue[0.0024391661414466803`, 1, 0.99662269303492], 
        Hue[0.020024885749810428`, 1, 0.9722732351156471], 
        Hue[0.23577760259562525`, 1, 0.673538704098365], 
        Hue[0.2420834410038361, 1, 0.6648075432254578], 
        Hue[0.24251364645452195`, 1, 0.6642118741398927], 
        Hue[0.23750407900351966`, 1, 0.6711481983028189], 
        Hue[0.005681080180083287, 1, 0.9921338889814231], 
        Hue[0.03389119525015072, 1, 0.9530737296536375], 
        Hue[0.5739368605688189, 1, 0.20531819305855853`], 
        Hue[0.6289515700277414, 1, 0.12914397996158888`], 
        Hue[0.6481714217172886, 1, 0.10253187762221586`], 
        Hue[0.6487097974449376, 1, 0.1017864343070095], 
        Hue[0.6314777186642292, 1, 0.12564623569568262`], 
        Hue[0.03457102577730864, 1, 0.9521324258468035], 
        Hue[0.0007451096657035139, 1, 0.9989683096936413], 
        Hue[0.23909763254801092`, 1, 0.6689417395489079], 
        Hue[0.24282742472391228`, 1, 0.6637774119207369], 
        Hue[0.24136350061985357`, 1, 0.6658043837571258], 
        Hue[0.02324890601426366, 1, 0.9678092070571734], 
        Hue[0.006061134744822838, 1, 0.9916076595840914], 
        Hue[0.6390121122182261, 1, 0.11521399846707162`], 
        Hue[0.6426565983672214, 1, 0.11016778687615497`], 
        Hue[0.0057915299601970505`, 1, 0.9919809585166501], 
        Hue[0.23432488000031443`, 1, 0.6755501661534108], 
        Hue[0.24167924721425632`, 1, 0.6653671961648758], 
        Hue[0.24273309456886033`, 1, 0.6639080229046549], 
        Hue[0.23850569159282636`, 1, 0.6697613501022404], 
        Hue[0.0076056138338941315`, 1, 0.9894691500761467], 
        Hue[0.025340553787472464`, 1, 0.964913079371192], 
        Hue[0.62447141087357, 1, 0.13534727725197998`], 
        Hue[0.6468615374737116, 1, 0.10434556349793787`], 
        Hue[0.017048738624436455`, 1, 0.9763940542123187], 
        Hue[0.0056281282467732785`, 1, 0.9922072070429293], 
        Hue[0.24293681630038833`, 1, 0.6636259466610007], 
        Hue[0.01399637405249432, 1, 0.9806204051580847], 
        Hue[0.0127790068636221, 1, 0.9823059904965232], 
        Hue[0.0005340421827835229, 1, 0.9992605569776845], 
        Hue[0.24240396455977337`, 1, 0.6643637413787754], 
        Hue[0.24221296293629857`, 1, 0.664628205165125], 
        Hue[0.004704974984887311, 1, 0.9934854192516945], 
        Hue[0.6492820329770811, 1, 0.10099410818558009`], 
        Hue[0.00022440864791439807`, 1, 0.9996892803336569], 
        Hue[0.24274942655253734`, 1, 0.6638854093887945], 
        Hue[0.0052464110044955214`, 1, 0.9927357386091601], 
        Hue[0.00802860453632126, 1, 0.9888834706420168], 
        Hue[0.24281318085907933`, 1, 0.6637971341951209], 
        Hue[0.008900173204143491, 1, 0.9876766832558014], 
        Hue[0.004010648438320885, 1, 0.9944467944700173], 
        Hue[0.24293918265887698`, 1, 0.6636226701646318], 
        Hue[0.01056567476351944, 1, 0.9853706041735885], 
        Hue[0.0013097546715873376`, 1, 0.9981864935316483], 
        Hue[0.2422538185750024, 1, 0.6645716358192274], 
        Hue[0.24237366540118938`, 1, 0.6644056940598917], 
        Hue[0.005069923141861388, 1, 0.9929801064189611], 
        Hue[0.001557312940686284, 1, 0.9978437205436651], 
        Hue[0.24288478246956158`, 1, 0.663697993503684], 
        Hue[0.007213858733613021, 1, 0.9900115802149974], 
        Hue[0.003930591712660081, 1, 0.9945576422440092], 
        Hue[0.24263333903574652`, 1, 0.6640461459505048], 
        Hue[0.0065294112199941745`, 1, 0.9909592767723157], 
        Hue[0.24291498931313066`, 1, 0.6636561686433575], 
        Hue[0.00010295154861172939`, 1, 0.9998574517019222], 
        Hue[0.004594979824449452, 1, 0.99363772024307], 
        Hue[0.64977086055894, 1, 0.1003172699953139], 
        Hue[0.6498267959460592, 1, 0.10023982099776421`], 
        Hue[0.6354689910457146, 1, 0.12011985855208748`], 
        Hue[0.5895653930160409, 1, 0.18367868659317405`], 
        Hue[0.4960796990600623, 1, 0.3131204166860676], 
        Hue[0.3517577479465543, 1, 0.5129508105355403], 
        Hue[0.17350218449302507`, 1, 0.7597662060865807], 
        Hue[0.04718868651621222, 1, 0.93466181866986], 
        Hue[0., 1, 1.], 
        Hue[0.03222225681951929, 1, 0.9553845674806656], 
        Hue[0.09262977370060799, 1, 0.8717433902606967], 
        Hue[0.1552079445627536, 1, 0.7850966921438796], 
        Hue[0.19781457918251122`, 1, 0.7261028903626768], 
        Hue[0.2238565485266671, 1, 0.6900447789630764], 
        Hue[0.23804995165578857`, 1, 0.6703923746304467], 
        Hue[0.24262212671540995`, 1, 0.66406167070174], 
        Hue[0.24188124646142117`, 1, 0.6650875048995707], 
        Hue[0.23527423423659388`, 1, 0.6742356756724085], 
        Hue[0.22057622401421495`, 1, 0.6945867667495486], 
        Hue[0.1914522297432143, 1, 0.7349122972786264], 
        Hue[0.1494403947884514, 1, 0.7930825302929134], 
        Hue[0.08924648820947689, 1, 0.8764279394022628], 
        Hue[0.029471631938418397`, 1, 0.9591931250083437], 
        Hue[0.0046895608291251945`, 1, 0.9935067619289036], 
        Hue[0.05391528936430667, 1, 0.9253480608801907], 
        Hue[0.1807688007404623, 1, 0.749704737436283], 
        Hue[0.3437728212740789, 1, 0.5240068628512755], 
        Hue[0.49912405492813827`, 1, 0.30890515471488544`], 
        Hue[0.5905018903532525, 1, 0.1823819979724196], 
        Hue[0.6358419158002138, 1, 0.11960350119970403`], 
        Hue[0.644747440517332, 1, 0.10727277466830956`], 
        Hue[0.6180295514869177, 1, 0.14426677486426775`], 
        Hue[0.5499667694887826, 1, 0.23850754993860868`], 
        Hue[0.26137128574962687`, 1, 0.6381012966543628], 
        Hue[0.10194496084760285`, 1, 0.8588454388263961], 
        Hue[0.011362483237401855`, 1, 0.9842673309020589], 
        Hue[0.009039133546419609, 1, 0.9874842766280343], 
        Hue[0.1256830595597057, 1, 0.8259773021480997], 
        Hue[0.17865541471287094`, 1, 0.7526309642437172], 
        Hue[0.21262000720841728`, 1, 0.7056030669421914], 
        Hue[0.23247723786311014`, 1, 0.6781084398818474], 
        Hue[0.2411170959309321, 1, 0.6661455594802478], 
        Hue[0.24288589868948646`, 1, 0.6636964479684034], 
        Hue[0.23948572873784468`, 1, 0.6684043755937535], 
        Hue[0.22920310046934272`, 1, 0.6826418608886023], 
        Hue[0.2079196133987707, 1, 0.7121113045247791], 
        Hue[0.17232342850117444`, 1, 0.7613983297676047], 
        Hue[0.057669974532247315`, 1, 0.920149266032273], 
        Hue[0.010810649245944437`, 1, 0.9850314087363846], 
        Hue[0.017536918417845326`, 1, 0.9757181129599064], 
        Hue[0.10904803192953882`, 1, 0.8490104173283308], 
        Hue[0.4277075621287773, 1, 0.40778952936015456`], 
        Hue[0.551723842248992, 1, 0.2360746799629343], 
        Hue[0.6186826716428605, 1, 0.14336245464834704`], 
        Hue[0.645113769213699, 1, 0.10676555031949365`], 
        Hue[0.647687522076236, 1, 0.10320189250982711`], 
        Hue[0.6279113551657355, 1, 0.13058427746282786`], 
        Hue[0.5714830279065303, 1, 0.20871580751403512`], 
        Hue[0.13596186728554227`, 1, 0.8117451068354029], 
        Hue[0.026128086020435926`, 1, 0.9638226501255502], 
        Hue[0.0023509801766903315`, 1, 0.9967447966784287], 
        Hue[0.20569179722591574`, 1, 0.715195973071809], 
        Hue[0.22858894585906647`, 1, 0.6834922288105234], 
        Hue[0.23980772147892598`, 1, 0.6679585394907179], 
        Hue[0.24291451281894372`, 1, 0.6636568284045394], 
        Hue[0.24088035873712038`, 1, 0.6664733494409103], 
        Hue[0.23252726943555174`, 1, 0.6780391653969283], 
        Hue[0.21470616589684538`, 1, 0.7027145395274449], 
        Hue[0.018889791545872336`, 1, 0.9738449040134075], 
        Hue[0.008305222644471644, 1, 0.9885004609538084], 
        Hue[0.0790920665848659, 1, 0.8904879078055703], 
        Hue[0.5272056445812282, 1, 0.270022953656761], 
        Hue[0.6061907030226347, 1, 0.1606590265840443], 
        Hue[0.6411506213987276, 1, 0.11225298575560806`], 
        Hue[0.6407753896662215, 1, 0.11277253738523188`], 
        Hue[0.6053721124676309, 1, 0.16179245966020342`], 
        Hue[0.07220232904566781, 1, 0.9000275443983061], 
        Hue[0.002777776285926681, 1, 0.9961538482194862], 
        Hue[0.019284844440944804`, 1, 0.9732979076971534], 
        Hue[0.23560538048941515`, 1, 0.6737771654761944], 
        Hue[0.2420376074539074, 1, 0.6648710050638205], 
        Hue[0.24254545650580367`, 1, 0.6641678294535026], 
        Hue[0.23763631682842334`, 1, 0.6709650997760293], 
        Hue[0.005871287397505864, 1, 0.991870525141915], 
        Hue[0.032738990832565484`, 1, 0.9546690896164478], 
        Hue[0.572736519619314, 1, 0.20698020360402675`], 
        Hue[0.6284237437465504, 1, 0.1298748163509302], 
        Hue[0.6480191484796949, 1, 0.10274271748965322`], 
        Hue[0.6488443750266125, 1, 0.10160009611699812`], 
        Hue[0.6319530704454684, 1, 0.12498805630627452`], 
        Hue[0.03587551882417872, 1, 0.9503262047049833], 
        Hue[0.0005871729658315505, 1, 0.9991869912780794], 
        Hue[0.23898887816282172`, 1, 0.6690923225437853], 
        Hue[0.24280987854795794`, 1, 0.6638017066259044], 
        Hue[0.24142664643346395`, 1, 0.6657169510921268], 
        Hue[0.02390761713946854, 1, 0.9668971454991975], 
        Hue[0.005826105477265697, 1, 0.9919330847237859], 
        Hue[0.6386840952669439, 1, 0.11566817578423153`], 
        Hue[0.6429064205873171, 1, 0.1098218791867918], 
        Hue[0.0063152970214653825`, 1, 0.9912557425856633], 
        Hue[0.23413099190537467`, 1, 0.6758186265925582], 
        Hue[0.2416225516959748, 1, 0.6654456976517272], 
        Hue[0.24275495153474191`, 1, 0.6638777594134343], 
        Hue[0.2386220547719618, 1, 0.6696002318542068], 
        Hue[0.007909158848099285, 1, 0.9890488569795548], 
        Hue[0.02437882899720245, 1, 0.9662446983115659], 
        Hue[0.6238686848140528, 1, 0.13618182102669624`], 
        Hue[0.6466823867975802, 1, 0.10459361828027368`], 
        Hue[0.01795898965920595, 1, 0.9751337066257147], 
        Hue[0.0052003720824900235`, 1, 0.99279948480886], 
        Hue[0.24293923732195827`, 1, 0.6636225944772886], 
        Hue[0.014497451754876156`, 1, 0.9799266052624791], 
        Hue[0.012191540059722783`, 1, 0.9831194060711531], 
        Hue[0.0006952944588031196, 1, 0.9990372845955033], 
        Hue[0.2423682897281612, 1, 0.6644131372994692], 
        Hue[0.24225510785718468`, 1, 0.6645698506592828], 
        Hue[0.004772646106838918, 1, 0.9933917207751461], 
        Hue[0.6491531882498848, 1, 0.10117250857708265`], 
        Hue[0.00014106661170887325`, 1, 0.9998046769991723], 
        Hue[0.2427266445725117, 1, 0.66391695366883], 
        Hue[0.005094503875524015, 1, 0.9929460715569668], 
        Hue[0.00864733488158842, 1, 0.9880267670870315], 
        Hue[0.24283015239495992`, 1, 0.6637736351454401], 
        Hue[0.009256798249721698, 1, 0.9871828947311546], 
        Hue[0.003645891348118213, 1, 0.9949518427487594], 
        Hue[0.24293671597499894`, 1, 0.6636260855730785], 
        Hue[0.010068920788690261`, 1, 0.9860584173695058], 
        Hue[0.0015586111017354964`, 1, 0.9978419230899046], 
        Hue[0.24221314641020653`, 1, 0.6646279511243295], 
        Hue[0.2424105850143647, 1, 0.6643545745954951], 
        Hue[0.00519997918695525, 1, 0.9928000288180621], 
        Hue[0.0013275443995891534`, 1, 0.998161861600569], 
        Hue[0.24287235354241565`, 1, 0.6637152027874245], 
        Hue[0.006893525527503774, 1, 0.9904551185003794], 
        Hue[0.00436091039463804, 1, 0.9939618163766549], 
        Hue[0.24266013511274842`, 1, 0.6640090436900407], 
        Hue[0.0067774675810381435`, 1, 0.9906158141185625], 
        Hue[0.24292226469216777`, 1, 0.6636460950416139], 
        Hue[0.00017893923430534198`, 1, 0.9997522379832695], 
        Hue[0.004598111188936382, 1, 0.9936333845076265], 
        Hue[0.6496525416343352, 1, 0.10048109619861283`], 
        Hue[0.000031751580881422825`, 1, 0.9999560362726257], 
        Hue[0.004851796307673739, 1, 0.9932821281893748], 
        Hue[0.2428604506785837, 1, 0.6637316836758073], 
        Hue[0.2429280897525657, 1, 0.6636380295733706], 
        Hue[0.002123185981432907, 1, 0.9970602040257084], 
        Hue[0.005505697464917247, 1, 0.9923767265870377], 
        Hue[0.0009212675345182664, 1, 0.9987243987983593], 
        Hue[0.24284368127478534`, 1, 0.6637549028502973], 
        Hue[0.0063172929391455135`, 1, 0.991252979007337], 
        Hue[0.2429331794163045, 1, 0.6636309823466553], 
        Hue[0.0003943322151029882, 1, 0.999454001548319], 
        Hue[0.00465324008891177, 1, 0.9935570521845837], 
        Hue[0.0003266523135074806, 1, 0.9995477121812972], 
        Hue[0.005418884459220674, 1, 0.9924969292103099], 
        Hue[0.24294042309726, 1, 0.6636209526345631], 
        Hue[0.0010830097739441547`, 1, 0.9985004480053081], 
        Hue[0.004955256828851562, 1, 0.9931388751600516], 
        Hue[0.24289594818863453`, 1, 0.6636825332772753], 
        Hue[0.2429065029932575, 1, 0.6636679189324127], 
        Hue[0.00004789491497536602, 1, 0.9999336839638802], 
        Hue[0.00460831361475178, 1, 0.9936192580718821], 
        Hue[0.6498866648577772, 1, 0.10015692558153926`]}],
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesLabel->{None, None},
     AxesOrigin->{0., 0.},
     DisplayFunction->((Print[#]; #)& ),
     FormatType->OutputForm,
     Method->{},
     PlotLabel->"Surface Intensity",
     PlotRange->All,
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}]}], ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "0.01754622278237448`"}], ",", 
   RowBox[{"RayBoundary", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.061148071639646494`"}], ",", "0.061148071639646084`"}], 
     "}"}]}], ",", 
   RowBox[{"NumberOfRays", "\[Rule]", "1716"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
   RowBox[{"Energy", "\[Rule]", "74.47916666666666`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5634043307746572`*^9, 3.563458229111472*^9, 
  3.564487681562495*^9, 3.566100825935779*^9, 3.601301572638955*^9, 
  3.614709341695486*^9, 3.614729196009015*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[310]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindIntensity[{
\tMove[GridOfRays[{45,45}, NumberOfRays -> 48, WaveLength->.633], -25],
\tMove[ApertureStop[{50,50},45],-20],
\tGrating[gratingfunction, {50, 50}, DiffractedOrders -> {{-1, 1},{0,0}}],
\tMove[Screen[{.25,.25}],83.3673]}, SequentialTrace->True, \
SmoothKernelSize->.01, KernelScale->Absolute, Full3D -> False, \
ReportedSurfaces -> Last]\
\>", "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"In[311]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1716"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.01`"}]}], "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 3., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 1716, Optica`Optica`SmoothKernelSize -> 
    0.01}],
  Editable->False]], "Print",
 CellChangeTimes->{3.614729201057088*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[311]:="],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwlmXk0VP//xxVKwseWpRRJyJLIvr1fQohKUUiypRTZ04ydscxkLypLdsIM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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne8l3MchvFztEubllSnKU2SNGhnlKStQgMN7b333ntLe9EgRRlJWmhS
NGQWhWigUHl/+OPqvu77+b1Oned8n+eU1LpL/c6JCQkJW25JSIj81R91sJ93
tn3Me/GH+XJeCJX0u/RRPCXW60/r23hF5NVv1dvz83w6Gugb9XvwlF5en82z
Y7v+nL6DVwNN+E0+jgO8Nx4xrtAL40G9qD6ap8IGPR/S2zroP/EZaIYKtjm2
HHhfT4aLvC4O8j54CElIjkv2J3CI90Vl3O1rjLGlxkY9PzLYXtR/5jPRHBVt
c205sUNPgcu8Hg7zfnjUZ1bqRVBFL6aP5WnQlx+Vr9mf4W/zJbKSHCfPygKu
ZeQd+Qz5i95DHtJXy1l6Q/mavkjeK0fJb+PryhauV5Lz9PkylxwkT8h18gPX
n4/UV8jqcrL8KX7Wrl2RT+II74/HXFul34WqenF9HE+L1/WCyGTrpF/gs+Os
IBV+t9XHp3wAqqEQMvt8HMpf+Zy4F0iNP2wN8BkfiOoojCw+38X+G5+LZ5EG
f9oa4igfhBoogqw+39V+kc9DS6TFVVsjHOODURMlfHa8LR02xbnHbbZu+iU+
H62QDtdsjfE5H4JacU5xu893t1/mC9A6ng/8ZWuCL/jQeMbirCGbz/ewX+EL
0QYP2ubb7sDOOOv4mzfFcT4MtX1mtV4Uj+gl9Qn8VvTjx+QbcX/4O/EcYTz/
QRazZ+c9+Uz5u95THtbXyJf0RvJ1/WVZRo6W38XPWT4Xz5FcoC+QueVgeTLe
D/JD11+QO/WVsoacIn+WGVz7J94LOMG72D/hw3kdvobfjUf1UvpEnh6b47wh
h62X/gdfFOc3nlvbQtud2BXPDK7zZjjJu7q+n4/gj/O1cQ/i7+Rfycfspfkk
PkdmkP3l53JLnBn+Ll8qH5IT5I9xf2UJ13PK3vos+afeSx7R18qX9cZyk75Y
3ifHyO/jjMkXXK8S91zPgyH8lNxtbxv3ktdEJv2GbI5TfGScAdzjM5NtGfFm
nAPksvXRr/LFaKK/oZdFW72qvojnxVD+pdxjb8d38VqYGu8bmdl+U7bA9Pis
3k0e0FfF7wW9rnxFXyiLx32WX8sNso7r98op+lyZSQ6QX8hX5FvxTMn39GWy
spwoz8lSrt3B+/JrvDf/NN6TvCnfzO9Hu3ifxL3m+bBXb6/v5g8jix6/aJ7m
p+noOAcoY5sa3yO2xhlAbls//S++NL5OvEOQaH/G/hUfE99z3Hvcae9v/5sv
Q4d4Z8RfZ3/W/jUfiyfiPiCPfYD9H74cL8Y7A8nsLe3f8HGoF/8+5LUPtF/n
K9Ax3hlIbm9l/5aPx5O4D/nsg+w3+Ep0imcdKeyt7d/xCaiPskiyD7bf5KvQ
OZ4xpLS3sX/PJ6JBfH3btLif2Kbfj/y2IYkJ//2HYrV4St/Cy6GLXl1fzJOw
L+6PvifeWcipp4r3CT/Du/ODfFLcL/4qfymeMTlSfiM3yobxb5fT9Xkyqxwo
j8tX5dvx3pXb9eWySnxNeT7eI7Kc6wXkUH22TJR95Gfx/nOtGX+TP4Cx/Izs
aq/Bl/D8+Ch+dvreeFchl55af56f5ZPjZ6iv00uiUdwvfQa/De/oD6CgbZh+
S7wv4tmKM4808W6w/cCnxDsE5VHIPtyeLJ6fuGdxZpHW3tb2I58a50FfH88Q
mujl9Jn8dryrV0Bh2wg9edw3vXk8j7w8eug19aW8AD6Os6fvi/dlvGv1dHo7
fo5PizOlb9BLo2l8f/osng3v6W3093lVVNSL6CN5CqzTW+hbeQX01Gvpy3hB
DOOn5SdxpvlHvDam8QuJ//+fNo9r/wLDWET2
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.6499398707454878, 1, 0.1000832558908631], 
     Hue[0.6203223046622468, 1, 0.14109219354458144`], 
     Hue[0.4954513949642436, 1, 0.31399037620335496`], 
     Hue[0.2641613627303298, 1, 0.6342381131426202], 
     Hue[0.054036889669744625`, 1, 0.9251796912265073], 
     Hue[0.006381705140027227, 1, 0.9911637928830391], 
     Hue[0.08274420775938995, 1, 0.885431096948537], 
     Hue[0.1691599937265455, 1, 0.7657784702247832], 
     Hue[0.22978761711841755`, 1, 0.6818325301437296], 
     Hue[0.27248639375582473`, 1, 0.6227111471073197], 
     Hue[0.3023344156621466, 1, 0.5813831167754894], 
     Hue[0.3195110194425703, 1, 0.557600126925672], 
     Hue[0.33175474086621765`, 1, 0.5406472818775448], 
     Hue[0.33504382680193695`, 1, 0.5360931628896258], 
     Hue[0.32715412408604966`, 1, 0.5470173666500852], 
     Hue[0.3262530974705614, 1, 0.548264941963838], 
     Hue[0.3342350794206079, 1, 0.5372129669560815], 
     Hue[0.3305891117004883, 1, 0.54226122995317], 
     Hue[0.3141334395656173, 1, 0.5650460067552991], 
     Hue[0.29427986323480065`, 1, 0.5925355739825837], 
     Hue[0.26517408101989304`, 1, 0.6328358878186097], 
     Hue[0.22343611589303858`, 1, 0.6906269164557928], 
     Hue[0.1718551257721982, 1, 0.7620467489308025], 
     Hue[0.09067339939355312, 1, 0.874452216224311], 
     Hue[0.01479619594798487, 1, 0.9795129594566363], 
     Hue[0.047801980587299675`, 1, 0.933812642263739], 
     Hue[0.2636825196117118, 1, 0.6349011266914759], 
     Hue[0.491908269799307, 1, 0.31889624181634413`], 
     Hue[0.6191293513231393, 1, 0.142743975091038], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6409706445006202, 1, 0.11250218453760277`], 
     Hue[0.5748185040222215, 1, 0.20409745596923193`], 
     Hue[0.38940282912090374`, 1, 0.460826851986441], 
     Hue[0.14504693191953288`, 1, 0.7991657865729545], 
     Hue[0.004813969032249177, 1, 0.9933345044168858], 
     Hue[0.03863511362192695, 1, 0.9465052272927165], 
     Hue[0.12949486748296057`, 1, 0.8206994142543622], 
     Hue[0.2016498244225462, 1, 0.7207925507995514], 
     Hue[0.2528497487881972, 1, 0.6499003478317269], 
     Hue[0.28946413554699113`, 1, 0.5992035046272431], 
     Hue[0.3116834646957291, 1, 0.5684382796520674], 
     Hue[0.32622906826429365`, 1, 0.5482982131725165], 
     Hue[0.33528873833163825`, 1, 0.5357540546177317], 
     Hue[0.3316032232690648, 1, 0.5408570754736027], 
     Hue[0.32456990305854594`, 1, 0.5505955188420134], 
     Hue[0.330649628006252, 1, 0.5421774381451896], 
     Hue[0.33429378279586097`, 1, 0.5371316853595772], 
     Hue[0.3233150617506798, 1, 0.5523329914221357], 
     Hue[0.30465505043965346`, 1, 0.5781699301604798], 
     Hue[0.2812268585024925, 1, 0.610608965150395], 
     Hue[0.24592679149288388`, 1, 0.6594859810098531], 
     Hue[0.19957877626747422`, 1, 0.7236601559373435], 
     Hue[0.13511110569575213`, 1, 0.8129230844212663], 
     Hue[0.04729291525291868, 1, 0.9345175019574973], 
     Hue[0.010537614885446578`, 1, 0.9854094563124586], 
     Hue[0.13803819663954786`, 1, 0.8088701892683183], 
     Hue[0.38664807043228827`, 1, 0.4646411332476009], 
     Hue[0.572517840783257, 1, 0.20728298968472111`], 
     Hue[0.6407686948022476, 1, 0.11278180719688793`], 
     Hue[0.6464658206809982, 1, 0.10489347905707942`], 
     Hue[0.6012675228755449, 1, 0.1674757375569379], 
     Hue[0.44587440064177586`, 1, 0.3826354452652335], 
     Hue[0.20253157701263635`, 1, 0.7195716625978882], 
     Hue[0.022549036652892762`, 1, 0.9687782569421486], 
     Hue[0.019977799667594165`, 1, 0.972338431229485], 
     Hue[0.10682930858951623`, 1, 0.8520824957991313], 
     Hue[0.18606496752374724`, 1, 0.7423715834286576], 
     Hue[0.2417114192389414, 1, 0.6653226502845427], 
     Hue[0.2815371939795814, 1, 0.6101792698744257], 
     Hue[0.30725723350357076`, 1, 0.5745669074565943], 
     Hue[0.32298429150716074`, 1, 0.5527909809900852], 
     Hue[0.3339314511549457, 1, 0.5376333753239213], 
     Hue[0.3336190037457293, 1, 0.5380659948136056], 
     Hue[0.3253820726215876, 1, 0.5494709763701096], 
     Hue[0.3283155895431935, 1, 0.5454091837094244], 
     Hue[0.33474369287669475`, 1, 0.5365087329399612], 
     Hue[0.32728007883768284`, 1, 0.5468429677632084], 
     Hue[0.3094865562309006, 1, 0.5714801529110608], 
     Hue[0.2880599324099877, 1, 0.6011477858938632], 
     Hue[0.2559814500813479, 1, 0.6455641460412106], 
     Hue[0.2118905865609913, 1, 0.7066130339924735], 
     Hue[0.15448935071928593`, 1, 0.7860916682348349], 
     Hue[0.06858485788872304, 1, 0.9050363506156142], 
     Hue[0.008186003705886957, 1, 0.9886655333303103], 
     Hue[0.08700071976256285, 1, 0.8795374649441436], 
     Hue[0.32614581561593925`, 1, 0.548413486070238], 
     Hue[0.5368235063061956, 1, 0.2567059143452677], 
     Hue[0.6320334342956301, 1, 0.12487678328297373`], 
     Hue[0.6325995916241606, 1, 0.12409287313577767`], 
     Hue[0.5397656252400832, 1, 0.25263221120603874`], 
     Hue[0.09473536221503298, 1, 0.8688279600099543], 
     Hue[0.00005919780871066482, 1, 0.9999180338033237], 
     Hue[0.06016780764545682, 1, 0.9166907278755213], 
     Hue[0.15027934067999238`, 1, 0.791920912904626], 
     Hue[0.2161717130893524, 1, 0.7006853203378197], 
     Hue[0.26313156540672294`, 1, 0.635663986359922], 
     Hue[0.29635014283688577`, 1, 0.5896690329950812], 
     Hue[0.31573740831934805`, 1, 0.5628251269424411], 
     Hue[0.32918795993560573`, 1, 0.5442012862430075], 
     Hue[0.33567615409473517`, 1, 0.5352176327919053], 
     Hue[0.3293193739370407, 1, 0.5440193283948668], 
     Hue[0.3248868441666835, 1, 0.550156677307669], 
     Hue[0.33276770985525966`, 1, 0.539244709431179], 
     Hue[0.3328799368200185, 1, 0.5390893182492053], 
     Hue[0.3188844203233972, 1, 0.5584677257060655], 
     Hue[0.2996101164906168, 1, 0.5851552233206845], 
     Hue[0.27363384188991374`, 1, 0.6211223727678117], 
     Hue[0.23506307656055053`, 1, 0.6745280478392377], 
     Hue[0.1863189468053772, 1, 0.7420199198079392], 
     Hue[0.1137015524984426, 1, 0.8425670811560025], 
     Hue[0.02862967643823866, 1, 0.9603589095470542], 
     Hue[0.023456655151453343`, 1, 0.96752155440568], 
     Hue[0.19815455689489242`, 1, 0.7256321519916874], 
     Hue[0.4425393159756371, 1, 0.387253254802964], 
     Hue[0.5995662703128419, 1, 0.1698313180283728], 
     Hue[0.6464495558531855, 1, 0.10491599958789694`], 
     Hue[0.6484096091211057, 1, 0.10220207967846909`], 
     Hue[0.61163067873746, 1, 0.15312675251736316`], 
     Hue[0.47160885258391366`, 1, 0.34700312719150417`], 
     Hue[0.23303055108340498`, 1, 0.6773423138845162], 
     Hue[0.03657845595909315, 1, 0.9493529071335632], 
     Hue[0.012402155807288429`, 1, 0.9828277842668315], 
     Hue[0.09491337207880335, 1, 0.8685814848139646], 
     Hue[0.17779611877653512`, 1, 0.7538207586171053], 
     Hue[0.2358442171198502, 1, 0.6734464686032844], 
     Hue[0.27715476393911903`, 1, 0.6162472499304505], 
     Hue[0.3048665225530447, 1, 0.5778771226188613], 
     Hue[0.32127469147938764`, 1, 0.5551581194900786], 
     Hue[0.3329338316513099, 1, 0.5390146946366479], 
     Hue[0.33442149292249734`, 1, 0.5369548559534653], 
     Hue[0.3261676010268356, 1, 0.5483833216551507], 
     Hue[0.32722052286489206`, 1, 0.5469254298793802], 
     Hue[0.33460443469652346`, 1, 0.5367015519586599], 
     Hue[0.3290295826634927, 1, 0.5444205778505486], 
     Hue[0.31183312031603905`, 1, 0.5682310641777921], 
     Hue[0.29123666246325547`, 1, 0.5967492365893386], 
     Hue[0.26068780456341173`, 1, 0.6390476552198915], 
     Hue[0.2177513369198073, 1, 0.6984981488802668], 
     Hue[0.16341072802124462`, 1, 0.7737389919705844], 
     Hue[0.07962562024089126, 1, 0.8897491412049198], 
     Hue[0.010492820181716378`, 1, 0.9854714797483927], 
     Hue[0.06579612290033754, 1, 0.9088976759841481], 
     Hue[0.2949704808019442, 1, 0.5915793342742312], 
     Hue[0.5155229281922142, 1, 0.28619902250308804`], 
     Hue[0.6261780336936377, 1, 0.13298426103957858`], 
     Hue[0.6372053438594732, 1, 0.1177156777330371], 
     Hue[0.5584253420189846, 1, 0.22679568028140584`], 
     Hue[0.1188242529752942, 1, 0.8354741112649773], 
     Hue[0.0009109200328174527, 1, 0.9987387261084066], 
     Hue[0.04916676973704581, 1, 0.9319229342102443], 
     Hue[0.14013175130167543`, 1, 0.8059714212746033], 
     Hue[0.20903110585880658`, 1, 0.7105723149647294], 
     Hue[0.258102536305375, 1, 0.6426272574233269], 
     Hue[0.29302961014398354`, 1, 0.5942666936467921], 
     Hue[0.31375030549625865`, 1, 0.5655765000821035], 
     Hue[0.3277498472207276, 1, 0.5461925192328387], 
     Hue[0.3356098249227038, 1, 0.5353094731839486], 
     Hue[0.3304714083695946, 1, 0.5424242037959459], 
     Hue[0.32458628776516363`, 1, 0.5505728323251581], 
     Hue[0.3317651172668576, 1, 0.5406329145535819], 
     Hue[0.3337036832393987, 1, 0.5379487462839095], 
     Hue[0.3211475804152873, 1, 0.5553341194249869], 
     Hue[0.30216283721260195`, 1, 0.5816206869363973], 
     Hue[0.2775332919300528, 1, 0.6157231342506961], 
     Hue[0.24059242963680538`, 1, 0.6668720205028849], 
     Hue[0.19308204150484287`, 1, 0.7326556348394484], 
     Hue[0.1246466212891979, 1, 0.827412370522649], 
     Hue[0.037501644340984464`, 1, 0.9480746462970985], 
     Hue[0.015602071504170256`, 1, 0.9783971317634566], 
     Hue[0.16717515195253113`, 1, 0.7685267126811107], 
     Hue[0.4153087040981639, 1, 0.42495717894100393`], 
     Hue[0.5870602218492309, 1, 0.1871473851318342], 
     Hue[0.6439282618242888, 1, 0.10840702208944636`], 
     Hue[0.6440198096780283, 1, 0.10828026352273015`], 
     Hue[0.589052082743309, 1, 0.1843894238938799], 
     Hue[0.17307223495784924`, 1, 0.7603615208275933], 
     Hue[0.011980079925591025`, 1, 0.9834121970261047], 
     Hue[0.028816558568524053`, 1, 0.9601001496743513], 
     Hue[0.2856375251362463, 1, 0.6045018882728898], 
     Hue[0.3347235875878059, 1, 0.5365365710322688], 
     Hue[0.33266698393630134`, 1, 0.5393841760881982], 
     Hue[0.3248398131726385, 1, 0.5502217971455775], 
     Hue[0.3294792758522947, 1, 0.5437979257429766], 
     Hue[0.33464143192589035`, 1, 0.5366503250256903], 
     Hue[0.3253668711221463, 1, 0.5494920246001052], 
     Hue[0.05773538493622021, 1, 0.9200586977806181], 
     Hue[0.008126846574058932, 1, 0.9887474432051491], 
     Hue[0.1111854670051261, 1, 0.8460508918390562], 
     Hue[0.5558048271013173, 1, 0.2304240855520223], 
     Hue[0.6368486096420622, 1, 0.11820961741868313`], 
     Hue[0.6270191945889607, 1, 0.13181957672297745`], 
     Hue[0.5187770108687072, 1, 0.28169336956640545`], 
     Hue[0.07306375471873172, 1, 0.8988348011586792], 
     Hue[0.001987947739783724, 1, 0.9972474569756842], 
     Hue[0.3305286151939994, 1, 0.5423449943467701], 
     Hue[0.33548516430382075`, 1, 0.5354820801947098], 
     Hue[0.32819706695808465`, 1, 0.5455732919041905], 
     Hue[0.3254534536828504, 1, 0.5493721410545148], 
     Hue[0.3336055561160216, 1, 0.5380846146085855], 
     Hue[0.33183606785855096`, 1, 0.5405346752727757], 
     Hue[0.020962709570144678`, 1, 0.9709747098259535], 
     Hue[0.034182954699799484`, 1, 0.9526697550310469], 
     Hue[0.6101967759197219, 1, 0.15511215641884663`], 
     Hue[0.6484416117226051, 1, 0.10215776838408537`], 
     Hue[0.6492213623096276, 1, 0.10107811372513105`], 
     Hue[0.6161737909121435, 1, 0.14683628950626287`], 
     Hue[0.4837740601941176, 1, 0.33015899357737566`], 
     Hue[0.24854263990939435`, 1, 0.6558640370485309], 
     Hue[0.0448846016761445, 1, 0.9378520899868767], 
     Hue[0.00917917496135412, 1, 0.9872903731304328], 
     Hue[0.08885188803374344, 1, 0.8769743088763552], 
     Hue[0.17352636486384077`, 1, 0.7597327255731435], 
     Hue[0.23283930785268553`, 1, 0.6776071122039738], 
     Hue[0.2748563794230438, 1, 0.6194296284911701], 
     Hue[0.303619266958334, 1, 0.5796040919038452], 
     Hue[0.32039960084331387`, 1, 0.5563697834477193], 
     Hue[0.3323654254318962, 1, 0.5398017186327592], 
     Hue[0.3347567883195255, 1, 0.5364906007883493], 
     Hue[0.3266388244145866, 1, 0.5477308585028802], 
     Hue[0.3267173703364143, 1, 0.5476221026111188], 
     Hue[0.33444749976212423`, 1, 0.5369188464832126], 
     Hue[0.3298347498279073, 1, 0.543305731007513], 
     Hue[0.31298923279655444`, 1, 0.5666302930509247], 
     Hue[0.29277372118194384`, 1, 0.5946210014403854], 
     Hue[0.26295857949549856`, 1, 0.6359035053139251], 
     Hue[0.22061506592681146`, 1, 0.6945329856397995], 
     Hue[0.1676902202094634, 1, 0.7678135412484354], 
     Hue[0.08515887525637544, 1, 0.8820877111834802], 
     Hue[0.012411486847196729`, 1, 0.98281486436542], 
     Hue[0.05638675028899531, 1, 0.9219260380613912], 
     Hue[0.2793154975759987, 1, 0.613255464894771], 
     Hue[0.5040021097040585, 1, 0.30215092502514984`], 
     Hue[0.6228126361300026, 1, 0.13764404228153487`], 
     Hue[0.6391850298032127, 1, 0.1149745741186287], 
     Hue[0.5668994856957502, 1, 0.21506225057511516`], 
     Hue[0.13168855901506138`, 1, 0.8176619952099151], 
     Hue[0.002466248795067072, 1, 0.9965851939760609], 
     Hue[0.04382763578919335, 1, 0.9393155812149631], 
     Hue[0.13487429280051377`, 1, 0.8132509791992887], 
     Hue[0.20537184381645618`, 1, 0.7156389854849069], 
     Hue[0.2555035275538204, 1, 0.6462258849254795], 
     Hue[0.29127858158940784`, 1, 0.5966911947223584], 
     Hue[0.31272760163675994`, 1, 0.5669925515798709], 
     Hue[0.32699897238597153`, 1, 0.5472321920809625], 
     Hue[0.3354806277120149, 1, 0.5354883616295179], 
     Hue[0.33104290562929684`, 1, 0.5416328998978966], 
     Hue[0.32454205947565706`, 1, 0.5506340714952441], 
     Hue[0.33121797222664306`, 1, 0.5413904999938789], 
     Hue[0.33402861333113804`, 1, 0.5374988430799628], 
     Hue[0.32224445702467436`, 1, 0.5538153671966047], 
     Hue[0.30341595428827034`, 1, 0.5798856017547026], 
     Hue[0.2794049264104001, 1, 0.6131316403548307], 
     Hue[0.24328440712081945`, 1, 0.6631446670634807], 
     Hue[0.1963616922920871, 1, 0.728114579903264], 
     Hue[0.12994176625431386`, 1, 0.8200806313401808], 
     Hue[0.04229961761085321, 1, 0.9414312986926648], 
     Hue[0.012728400092202885`, 1, 0.982376061410796], 
     Hue[0.15234757901065116`, 1, 0.7890571982929445], 
     Hue[0.4011417181064782, 1, 0.4445730056987225], 
     Hue[0.5800527037955925, 1, 0.1968501024368719], 
     Hue[0.6424356043514087, 1, 0.11047377859035727`], 
     Hue[0.6453116124082237, 1, 0.10649161358861339`], 
     Hue[0.5954021620672785, 1, 0.17559700636838366`], 
     Hue[0.18764684067256798`, 1, 0.7401812975302905], 
     Hue[0.016833577591917948`, 1, 0.9766919694881137], 
     Hue[0.02425730475565102, 1, 0.9664129626460217], 
     Hue[0.2836222020006889, 1, 0.6072923356913539], 
     Hue[0.3343546308001878, 1, 0.537047434276663], 
     Hue[0.33315948171631066`, 1, 0.5387022560851084], 
     Hue[0.3250783760444603, 1, 0.5498914793230549], 
     Hue[0.32889269621484973`, 1, 0.544610112933285], 
     Hue[0.3347231617990408, 1, 0.5365371605859435], 
     Hue[0.32634232786068007`, 1, 0.5481413921929046], 
     Hue[0.06312343835721435, 1, 0.9125983161207801], 
     Hue[0.007860784868159776, 1, 0.9891158363363942], 
     Hue[0.09873826572022548, 1, 0.863285478233534], 
     Hue[0.5466021002875459, 1, 0.24316632267878266`], 
     Hue[0.6345617576170044, 1, 0.121376027914917], 
     Hue[0.6299399426764263, 1, 0.12777546398648673`], 
     Hue[0.5295643150772825, 1, 0.2667571022006858], 
     Hue[0.08358178669239591, 1, 0.8842713722720672], 
     Hue[0.0006948616020030496, 1, 0.999037883935688], 
     Hue[0.32987149048101866`, 1, 0.5432548593339742], 
     Hue[0.33561262787545737`, 1, 0.5353055921724437], 
     Hue[0.3287513647100242, 1, 0.5448058027091973], 
     Hue[0.3251386306538745, 1, 0.5498080498638661], 
     Hue[0.3332101640661408, 1, 0.5386320805238051], 
     Hue[0.3323845206144772, 1, 0.5397752791491854], 
     Hue[0.024627226904205823`, 1, 0.9659007627480227], 
     Hue[0.028458056533724463`, 1, 0.9605965371071506], 
     Hue[0.6051051503176443, 1, 0.16216209956018487`], 
     Hue[0.647505450095836, 1, 0.10345399217499632`], 
     Hue[0.6474946629038302, 1, 0.10346892828700434`], 
     Hue[0.606669581491444, 1, 0.1599959640887698], 
     Hue[0.02913101051004907, 1, 0.9596647546783936], 
     Hue[0.01601393441544674, 1, 0.9778268600401506], 
     Hue[0.33345686617940323`, 1, 0.5382904929823648], 
     Hue[0.3340410323828972, 1, 0.5374816474698347], 
     Hue[0.3257467885681318, 1, 0.5489659850595099], 
     Hue[0.33470372347960525`, 1, 0.536564075182085], 
     Hue[0.009073590774205442, 1, 0.9874365666203309], 
     Hue[0.07600949537887958, 1, 0.8947560833215514], 
     Hue[0.5264642181843207, 1, 0.27104954405247916`], 
     Hue[0.6292451803493999, 1, 0.12873744259313857`], 
     Hue[0.6350157006696132, 1, 0.12074749138053564`], 
     Hue[0.00011934873054919581`, 1, 0.9998347479115473], 
     Hue[0.3356752028647411, 1, 0.5352189498795893], 
     Hue[0.32470180782608865`, 1, 0.5504128814715695], 
     Hue[0.33228393735172246`, 1, 0.5399145482822305], 
     Hue[0.3333202655209005, 1, 0.5384796323556763], 
     Hue[0.03293321773132141, 1, 0.9544001600643243], 
     Hue[0.01917413917628419, 1, 0.9734511919097603], 
     Hue[0.5935582415820833, 1, 0.1781501270401924], 
     Hue[0.6452615609407701, 1, 0.10656091562047221`], 
     Hue[0.6425774098256601, 1, 0.11027743254908597`], 
     Hue[0.007978588801169528, 1, 0.9889527231983807], 
     Hue[0.33503573084672467`, 1, 0.5361043726737659], 
     Hue[0.32466957013441244`, 1, 0.550457518275429], 
     Hue[0.33449824854084825`, 1, 0.536848578943441], 
     Hue[0.009010994546887585, 1, 0.987523238319694], 
     Hue[0.6389118545999911, 1, 0.1153528167077047], 
     Hue[0.623819399848832, 1, 0.13625006174777116`], 
     Hue[0.0038977396867962977`, 1, 0.9946031296644359], 
     Hue[0.33529494773343405`, 1, 0.535745456984476], 
     Hue[0.3258267413460907, 1, 0.5488552812131052], 
     Hue[0.3339487155861848, 1, 0.5376094707268212], 
     Hue[0.33123680931030586`, 1, 0.541364417878038], 
     Hue[0.01767329301286913, 1, 0.9755292865975659], 
     Hue[0.04063204365031803, 1, 0.9437402472534059], 
     Hue[0.6148637936080795, 1, 0.1486501319272746], 
     Hue[0.6492695641742171, 1, 0.10101137268185331`], 
     Hue[0.6495916780181005, 1, 0.10056536889801475`], 
     Hue[0.6182959051391586, 1, 0.14389797749962663`], 
     Hue[0.4896744530275468, 1, 0.32198921888493526`], 
     Hue[0.25634187146467047`, 1, 0.6450651010489178], 
     Hue[0.049355988579127597`, 1, 0.9316609388904388], 
     Hue[0.007724965093649172, 1, 0.9893038944857164], 
     Hue[0.08580260926393413, 1, 0.8811963871730142], 
     Hue[0.17135555150725118`, 1, 0.762738467143806], 
     Hue[0.23131928850756284`, 1, 0.6797117543741438], 
     Hue[0.273680328349185, 1, 0.6210580069011284], 
     Hue[0.3029816820274928, 1, 0.5804869018080869], 
     Hue[0.3199570100815457, 1, 0.5569826014255521], 
     Hue[0.3320651739423048, 1, 0.5402174514645011], 
     Hue[0.33490651251482917`, 1, 0.5362832903640827], 
     Hue[0.3268913832654378, 1, 0.5473811616324707], 
     Hue[0.32647996418420705`, 1, 0.5479508188218671], 
     Hue[0.33434807060374117`, 1, 0.5370565176255891], 
     Hue[0.33021848789038316`, 1, 0.5427744013825464], 
     Hue[0.31356285696744657`, 1, 0.5658360441989202], 
     Hue[0.2935305057752772, 1, 0.5935731458496163], 
     Hue[0.2640732445165298, 1, 0.6343601229771126], 
     Hue[0.2220308630998889, 1, 0.6925726510924615], 
     Hue[0.1697866768227707, 1, 0.7649107551684713], 
     Hue[0.08791964644359773, 1, 0.8782651049242493], 
     Hue[0.013547711713068011`, 1, 0.9812416299357519], 
     Hue[0.05199022269743436, 1, 0.9280135378035524], 
     Hue[0.2714930587133087, 1, 0.6240865340892648], 
     Hue[0.49802624794011685`, 1, 0.31042519515983824`], 
     Hue[0.6210119648366716, 1, 0.14013727945691618`], 
     Hue[0.640101128705527, 1, 0.11370612948465492`], 
     Hue[0.570927521437244, 1, 0.2094849703176622], 
     Hue[0.13830860264548506`, 1, 0.8084957809524054], 
     Hue[0.0035394270118999094`, 1, 0.9950992549066002], 
     Hue[0.041211130063402934`, 1, 0.9429384352968266], 
     Hue[0.13219972387620438`, 1, 0.8169542284791016], 
     Hue[0.2035188658482081, 1, 0.7182046472870964], 
     Hue[0.25418340786124116`, 1, 0.6480537429613584], 
     Hue[0.290379410130738, 1, 0.5979362013574397], 
     Hue[0.3122083138993048, 1, 0.5677115653701934], 
     Hue[0.32661630658749696`, 1, 0.5477620370326965], 
     Hue[0.335392428031152, 1, 0.5356104842645588], 
     Hue[0.33132483557919656`, 1, 0.5412425353518817], 
     Hue[0.32454696346566336`, 1, 0.5506272813552353], 
     Hue[0.33093599298037457`, 1, 0.5417809327964045], 
     Hue[0.3341687359719763, 1, 0.5373048271157251], 
     Hue[0.3227831996270217, 1, 0.553069415901047], 
     Hue[0.3040371954779231, 1, 0.5790254216459527], 
     Hue[0.28032198428557525`, 1, 0.6118618679122805], 
     Hue[0.24461185614624303`, 1, 0.6613066607205866], 
     Hue[0.19797782006951153`, 1, 0.7258768645191379], 
     Hue[0.1325424081678125, 1, 0.816479742536875], 
     Hue[0.04477394039940796, 1, 0.9380053132931274], 
     Hue[0.01154874408725759, 1, 0.9840094312637971], 
     Hue[0.14512467094471104`, 1, 0.7990581479227077], 
     Hue[0.3939336254099925, 1, 0.45455344174001044`], 
     Hue[0.5763522332858397, 1, 0.20197383083499112`], 
     Hue[0.641624895323608, 1, 0.11159629878269661`], 
     Hue[0.6459051348766875, 1, 0.10566981324766349`], 
     Hue[0.5983941187109063, 1, 0.17145429716951432`], 
     Hue[0.19505354386190887`, 1, 0.7299258623450492], 
     Hue[0.019583148898330016`, 1, 0.9728848707561585], 
     Hue[0.022080356356444786`, 1, 0.9694271988910764], 
     Hue[0.28258847224659916`, 1, 0.6087236538124011], 
     Hue[0.33414964712752826`, 1, 0.5373312578234224], 
     Hue[0.33339365557159106`, 1, 0.5383780153624124], 
     Hue[0.3252223251121785, 1, 0.5496921652292913], 
     Hue[0.3286024731680903, 1, 0.545011960228798], 
     Hue[0.3347410420414997, 1, 0.5365124033271543], 
     Hue[0.32681611456694415`, 1, 0.547485379830385], 
     Hue[0.06584665018155045, 1, 0.9088277151332379], 
     Hue[0.007951246223989572, 1, 0.9889905821513991], 
     Hue[0.09277837680301726, 1, 0.8715376321188991], 
     Hue[0.5417851666356307, 1, 0.24983592311989603`], 
     Hue[0.633328921010883, 1, 0.12308303244646976`], 
     Hue[0.6313012956629634, 1, 0.1258905136974352], 
     Hue[0.5347381198195321, 1, 0.2595933725575709], 
     Hue[0.08908094261355293, 1, 0.8766571563812343], 
     Hue[0.00029239163763428166`, 1, 0.9995951500401987], 
     Hue[0.32953289265835145`, 1, 0.5437236870884365], 
     Hue[0.335652429084862, 1, 0.5352504828055757], 
     Hue[0.3290340481762456, 1, 0.5444143948328908], 
     Hue[0.3250045977180489, 1, 0.5499936339288554], 
     Hue[0.3329944733088144, 1, 0.5389307292647186], 
     Hue[0.3326389909955199, 1, 0.5394229355446648], 
     Hue[0.026588523572469325`, 1, 0.9631851212073502], 
     Hue[0.025867117004829132`, 1, 0.9641839918394673], 
     Hue[0.6023930066815211, 1, 0.16591737536404771`], 
     Hue[0.6469932227388104, 1, 0.10416323005395475`], 
     Hue[0.647965685486715, 1, 0.10281674317224085`], 
     Hue[0.609203823679551, 1, 0.15648701336677567`], 
     Hue[0.03274683723398941, 1, 0.9546582253683223], 
     Hue[0.014161744246589891`, 1, 0.9803914310431833], 
     Hue[0.33320121492827814`, 1, 0.5386444716377687], 
     Hue[0.3342366947175282, 1, 0.5372107303911149], 
     Hue[0.3259505201170127, 1, 0.5486838952225979], 
     Hue[0.33466140090781377`, 1, 0.536622675666104], 
     Hue[0.009718733605175722, 1, 0.9865432919312951], 
     Hue[0.07080381638030953, 1, 0.9019639465503407], 
     Hue[0.5210662604931173, 1, 0.27852363931722224`], 
     Hue[0.6277476698741495, 1, 0.130810918635793], 
     Hue[0.6361377860765688, 1, 0.11919383466321243`], 
     Hue[0.0004216049701781799, 1, 0.999416239272061], 
     Hue[0.335650542853165, 1, 0.5352530945110023], 
     Hue[0.32463522203899425`, 1, 0.5505050771767772], 
     Hue[0.33202849951228747`, 1, 0.5402682314445251], 
     Hue[0.3335191942989343, 1, 0.538204192509168], 
     Hue[0.03518655271004201, 1, 0.9512801577860956], 
     Hue[0.017299972610341552`, 1, 0.9760461917702963], 
     Hue[0.590371734720975, 1, 0.1825622134632654], 
     Hue[0.6446139332449645, 1, 0.10745763089158757`], 
     Hue[0.6433182767202669, 1, 0.10925161684886134`], 
     Hue[0.00987366148418578, 1, 0.986328776406512], 
     Hue[0.3348869127964574, 1, 0.5363104284356744], 
     Hue[0.32474598770549984`, 1, 0.5503517093308464], 
     Hue[0.33457752203819097`, 1, 0.5367388156394279], 
     Hue[0.008490076611369468, 1, 0.9882445093073345], 
     Hue[0.6379070913204846, 1, 0.1167440274024059], 
     Hue[0.6254553133829989, 1, 0.13398495070046312`], 
     Hue[0.002868374824688935, 1, 0.9960284040888921], 
     Hue[0.3353978003724276, 1, 0.5356030456381772], 
     Hue[0.32563310951254737`, 1, 0.5491233868287806], 
     Hue[0.33378396545074795`, 1, 0.5378375862989644], 
     Hue[0.33154264664100086`, 1, 0.5409409508047681], 
     Hue[0.01926878548484945, 1, 0.9733201431748237], 
     Hue[0.03731708892554586, 1, 0.9483301845646288], 
     Hue[0.6125819241844626, 1, 0.1518096434368981], 
     Hue[0.6488684292235369, 1, 0.10156679030587196`], 
     Hue[0.6488277482223833, 1, 0.1016231178459308], 
     Hue[0.33459499136331816`, 1, 0.5367146273430979], 
     Hue[0.32639729097297837`, 1, 0.5480652894220299], 
     Hue[0.33453304829270514`, 1, 0.5368003946716391], 
     Hue[0.011391787087449257`, 1, 0.984226756340455], 
     Hue[0.0015912329838886352`, 1, 0.9977967543300003], 
     Hue[0.33555314402344943`, 1, 0.5353879544290701], 
     Hue[0.32455518966412056`, 1, 0.5506158912342947], 
     Hue[0.3338735480858331, 1, 0.5377135488042312], 
     Hue[0.014078827787691872`, 1, 0.9805062384478113], 
     Hue[0.014299579844360588`, 1, 0.9802005817539623], 
     Hue[0.33454605598084153`, 1, 0.5367823840265272], 
     Hue[0.32495073479369113`, 1, 0.5500682133625816], 
     Hue[0.3346899738502388, 1, 0.5365831131304386], 
     Hue[0.007918177173668717, 1, 0.9890363700672279], 
     Hue[0.0012617229160725163`, 1, 0.9982529990392841], 
     Hue[0.3355568273404401, 1, 0.5353828544516983], 
     Hue[0.3252884273808777, 1, 0.5496006390110925], 
     Hue[0.33341408048336163`, 1, 0.5383497347153455], 
     Hue[0.6479877568612755, 1, 0.10278618280746465`], 
     Hue[0.3255570927912058, 1, 0.5492286407506382], 
     Hue[0.33473120609069956`, 1, 0.5365260223359545], 
     Hue[0.008561382792005912, 1, 0.9881457776726071], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[0.3356837494603589, 1, 0.5352071161318108], 
     Hue[0.3247857871570331, 1, 0.5502966023979542], 
     Hue[0.021225976353827836`, 1, 0.9706101865870076], 
     Hue[0.006292804813375796, 1, 0.991286885643018], 
     Hue[0.3351697580035618, 1, 0.5359187966104529], 
     Hue[0.32461081577858436`, 1, 0.5505388704604217], 
     Hue[0.3344036480973234, 1, 0.5369795641729368], 
     Hue[0.00969257327032369, 1, 0.9865795139333979], 
     Hue[0.005070668093653419, 1, 0.9929790749472491], 
     Hue[0.33517686031922533`, 1, 0.5359089626349188], 
     Hue[0.3340992571809017, 1, 0.5374010285187515], 
     Hue[0.6496463339576016, 1, 0.10048969144332093`], 
     Hue[0.6497684680580302, 1, 0.10032058268888121`], 
     Hue[0.6193208847295075, 1, 0.14247877498991263`], 
     Hue[0.49257843653554423`, 1, 0.3179683186430926], 
     Hue[0.26024948237517376`, 1, 0.639654562865144], 
     Hue[0.051670395251691814`, 1, 0.9284563758053499], 
     Hue[0.0070391826570419536`, 1, 0.990253439397942], 
     Hue[0.08427438705708767, 1, 0.8833123871517248], 
     Hue[0.17026090201037192`, 1, 0.7642541356779466], 
     Hue[0.23055490705616738`, 1, 0.6807701286914606], 
     Hue[0.2730855944832182, 1, 0.6218814845616979], 
     Hue[0.3026592767458759, 1, 0.580933309121095], 
     Hue[0.31973444101755644`, 1, 0.5572907739756912], 
     Hue[0.33191120509487415`, 1, 0.540430639099405], 
     Hue[0.3349767418483453, 1, 0.536186049748445], 
     Hue[0.32702153526753214`, 1, 0.5472009511680325], 
     Hue[0.3263651629831069, 1, 0.5481097743310828], 
     Hue[0.3342932498385909, 1, 0.5371324233004127], 
     Hue[0.3304054658465757, 1, 0.5425155088278183], 
     Hue[0.3138485329848082, 1, 0.5654404927902656], 
     Hue[0.2939060942517848, 1, 0.5930531002667595], 
     Hue[0.2646253885628478, 1, 0.633595615836057], 
     Hue[0.22273480082632774`, 1, 0.6915979680866231], 
     Hue[0.1708243594881107, 1, 0.7634739637856929], 
     Hue[0.0892975390851537, 1, 0.8763572535744025], 
     Hue[0.014158191134944875`, 1, 0.9803963507362302], 
     Hue[0.049869951896149955`, 1, 0.9309492973745617], 
     Hue[0.2675858993029871, 1, 0.6294964471189409], 
     Hue[0.494984937556883, 1, 0.31463624030585435`], 
     Hue[0.620081053978362, 1, 0.1414262329530373], 
     Hue[0.6405415909495699, 1, 0.11309625868521107`], 
     Hue[0.5728900282134092, 1, 0.20676765324297192`], 
     Hue[0.14166332032602003`, 1, 0.8038507872408953], 
     Hue[0.0041513378275706, 1, 0.99425199377721], 
     Hue[0.039917814685470066`, 1, 0.9447291796662722], 
     Hue[0.13085106349636644`, 1, 0.8188216043896465], 
     Hue[0.2025863779748482, 1, 0.7194957843425179], 
     Hue[0.25351826110643244`, 1, 0.6489747153910935], 
     Hue[0.28992380125612444`, 1, 0.598567044414597], 
     Hue[0.3119465976525323, 1, 0.5680739417118784], 
     Hue[0.3264232480596073, 1, 0.5480293488405438], 
     Hue[0.3353425097950293, 1, 0.5356796018222671], 
     Hue[0.33146451839705826`, 1, 0.541049128373304], 
     Hue[0.3245561812160596, 1, 0.5506145183162252], 
     Hue[0.33079330023634135`, 1, 0.5419785073650659], 
     Hue[0.3342331509003749, 1, 0.5372156372148655], 
     Hue[0.32305001221443946`, 1, 0.5526999830876993], 
     Hue[0.30434653929241884`, 1, 0.5785970994412662], 
     Hue[0.28077592854423666`, 1, 0.6112333297079799], 
     Hue[0.24527089452727113`, 1, 0.660394146039163], 
     Hue[0.19878016205132032`, 1, 0.7247659294674027], 
     Hue[0.1338307745236833, 1, 0.8146958506595153], 
     Hue[0.04602810281028025, 1, 0.9362687807242274], 
     Hue[0.011022261653315546`, 1, 0.9847384069415631], 
     Hue[0.14156396120479042`, 1, 0.8039883614087516], 
     Hue[0.3903002573939068, 1, 0.4595842589930521], 
     Hue[0.5744519006069537, 1, 0.2046050606980641], 
     Hue[0.6412026002558503, 1, 0.11218101503036115`], 
     Hue[0.6461894868204925, 1, 0.10527609517162578`], 
     Hue[0.5998454717906373, 1, 0.16944473136680996`], 
     Hue[0.19878403577845316`, 1, 0.7247605658452186], 
     Hue[0.02103901989610024, 1, 0.9708690493746304], 
     Hue[0.02101949813706505, 1, 0.9708960795025253], 
     Hue[0.28206503367222346`, 1, 0.6094484149153829], 
     Hue[0.3340421785668186, 1, 0.5374800604459434], 
     Hue[0.33350746839442696`, 1, 0.5382204283769473], 
     Hue[0.3253002543992455, 1, 0.5495842631395063], 
     Hue[0.3284585511000331, 1, 0.5452112369384158], 
     Hue[0.33474426363362786`, 1, 0.5365079426611307], 
     Hue[0.32704935004966873`, 1, 0.5471624383927663], 
     Hue[0.06721408207686197, 1, 0.9069343478935757], 
     Hue[0.008050815803413491, 1, 0.988852716579889], 
     Hue[0.08986648497730176, 1, 0.8755694823391206], 
     Hue[0.5393224638287768, 1, 0.2532458193140015], 
     Hue[0.6326891542119384, 1, 0.1239688633988546], 
     Hue[0.6319581881715707, 1, 0.12498097022397914`], 
     Hue[0.5372701351820414, 1, 0.2560875051325581], 
     Hue[0.0918889834870038, 1, 0.8727690997872255], 
     Hue[0.00015433721505975218`, 1, 0.9997863023176097], 
     Hue[0.3293612016678818, 1, 0.5439614130752406], 
     Hue[0.33566630563909317`, 1, 0.5352312691151019], 
     Hue[0.3291764291155226, 1, 0.5442172519938918], 
     Hue[0.32494366159260896`, 1, 0.5500780070256184], 
     Hue[0.3328824303402503, 1, 0.5390858656827304], 
     Hue[0.33276117041455455`, 1, 0.539253764041386], 
     Hue[0.027599405850318504`, 1, 0.9617854380534052], 
     Hue[0.02463936251650689, 1, 0.9658839595925289], 
     Hue[0.6009941334043599, 1, 0.16785427682473247`], 
     Hue[0.6467254162291354, 1, 0.10453403906735113`], 
     Hue[0.6481909529523812, 1, 0.10250483437362612`], 
     Hue[0.6104304980619305, 1, 0.15478854114501933`], 
     Hue[0.03463572826352013, 1, 0.9520428377889721], 
     Hue[0.013270088216202569`, 1, 0.9816260317006426], 
     Hue[0.33306896758758087`, 1, 0.5388275833402727], 
     Hue[0.33433048027707757`, 1, 0.537080873462508], 
     Hue[0.32605743586255737`, 1, 0.5485358580364591], 
     Hue[0.334634734986847, 1, 0.5366595977105195], 
     Hue[0.01008991294318795, 1, 0.986029351309432], 
     Hue[0.06827502074472325, 1, 0.9054653558919217], 
     Hue[0.518312745112626, 1, 0.28233619907482554`], 
     Hue[0.6269720191913284, 1, 0.13188489650431456`], 
     Hue[0.6366782518371953, 1, 0.11844549745619123`], 
     Hue[0.000642628549405333, 1, 0.9991102066239003], 
     Hue[0.3356321857471822, 1, 0.5352785120423631], 
     Hue[0.3246085384883455, 1, 0.5505420236315217], 
     Hue[0.33189774821654194`, 1, 0.5404492717001728], 
     Hue[0.3336132556644899, 1, 0.5380739536953216], 
     Hue[0.03633665471083669, 1, 0.9496877088619184], 
     Hue[0.016429087474083892`, 1, 0.9772520327281916], 
     Hue[0.5887317559390493, 1, 0.18483295331516256`], 
     Hue[0.6442759632013874, 1, 0.1079255894134637], 
     Hue[0.6436738528004411, 1, 0.10875928073785078`], 
     Hue[0.01090033653309086, 1, 0.9849072263387972], 
     Hue[0.33480704542627854`, 1, 0.5364210140251529], 
     Hue[0.3247907425211815, 1, 0.550289741124518], 
     Hue[0.33461139756560154`, 1, 0.5366919110630133], 
     Hue[0.008288943377575908, 1, 0.9885230014772026], 
     Hue[0.637384700036486, 1, 0.11746733841101942`], 
     Hue[0.626246115484745, 1, 0.1328899939441994], 
     Hue[0.002409214436113638, 1, 0.9966641646269195], 
     Hue[0.3354434324469677, 1, 0.535539862765737], 
     Hue[0.3255414933906034, 1, 0.549250239920703], 
     Hue[0.3336964316687655, 1, 0.5379587869201709], 
     Hue[0.3316909289586658, 1, 0.5407356368264628], 
     Hue[0.020103735364840003`, 1, 0.9721640587256062], 
     Hue[0.03572739517140178, 1, 0.9505312989934438], 
     Hue[0.6114024420244684, 1, 0.15344277258150535`], 
     Hue[0.6486583116008349, 1, 0.10185772239884405`], 
     Hue[0.6490275428023855, 1, 0.10134647919669705`], 
     Hue[0.334677376463026, 1, 0.5366005556665795], 
     Hue[0.32651662712492796`, 1, 0.5479000547500998], 
     Hue[0.3344920287104155, 1, 0.5368571910163479], 
     Hue[0.011886806967454588`, 1, 0.983541344198909], 
     Hue[0.002004180904139563, 1, 0.997224980286576], 
     Hue[0.3355188563553291, 1, 0.5354354296618521], 
     Hue[0.32454637288074756`, 1, 0.5506280990881957], 
     Hue[0.33395294099355477`, 1, 0.5376036201627703], 
     Hue[0.0133821348889126, 1, 0.9814708901538134], 
     Hue[0.015539689671055013`, 1, 0.9784835066093084], 
     Hue[0.334452059334183, 1, 0.5369125332295929], 
     Hue[0.3250124928910314, 1, 0.5499827021508796], 
     Hue[0.3347084847683594, 1, 0.5365574826284255], 
     Hue[0.007870782139597132, 1, 0.9891019939605578], 
     Hue[0.0009580543666320995, 1, 0.9986734631846632], 
     Hue[0.33558672114397226`, 1, 0.535341463031423], 
     Hue[0.32521158929034105`, 1, 0.549707030213374], 
     Hue[0.3333136365119753, 1, 0.5384888109834188], 
     Hue[0.647750250673156, 1, 0.10311503752947641`], 
     Hue[0.32565014497083133`, 1, 0.5490997992711567], 
     Hue[0.33471932880154487`, 1, 0.5365424678132457], 
     Hue[0.008800624248977873, 1, 0.9878145202706461], 
     Hue[0.000037078988190830664`, 1, 0.999948659862505], 
     Hue[0.3356814925559579, 1, 0.5352102410763661], 
     Hue[0.3247416416135234, 1, 0.55035772699666], 
     Hue[0.02017777035014312, 1, 0.9720615487459557], 
     Hue[0.007109671751682978, 1, 0.9901558391130543], 
     Hue[0.3351046097773764, 1, 0.5360090018467096], 
     Hue[0.32463797497778235`, 1, 0.5505012654153782], 
     Hue[0.3344528613781988, 1, 0.5369114227071095], 
     Hue[0.009331522119800817, 1, 0.987079430911045], 
     Hue[0.004466597584717014, 1, 0.9938154802673148], 
     Hue[0.33523779010694477`, 1, 0.5358245983134611], 
     Hue[0.3340257953108546, 1, 0.5375027449542014], 
     Hue[0.6494609147020903, 1, 0.10074642579710572`], 
     Hue[0.3343995008120433, 1, 0.5369853065679401], 
     Hue[0.002977861325355491, 1, 0.9958768073956615], 
     Hue[0.33543847851623076`, 1, 0.5355467220544498], 
     Hue[0.3245422556128765, 1, 0.5506337999206325], 
     Hue[0.01211736119459983, 1, 0.9832221152690156], 
     Hue[0.3251483401994455, 1, 0.5497946058776909], 
     Hue[0.3347340114594461, 1, 0.5365221379792285], 
     Hue[0.007887753077295723, 1, 0.989078495739129], 
     Hue[0.0004727689357605369, 1, 0.9993453968581777], 
     Hue[0.3356345366564564, 1, 0.5352752569372142], 
     Hue[0.3346844054353854, 1, 0.5365908232433125], 
     Hue[0.009379792468023451, 1, 0.9870125950442752], 
     Hue[0.0002473480850635479, 1, 0.9996575180360658], 
     Hue[0.33566488369663094`, 1, 0.5352332379585111], 
     Hue[0.3246663233849915, 1, 0.5504620137746272], 
     Hue[0.008899827783288905, 1, 0.9876771615308307], 
     Hue[0.3247055858170693, 1, 0.5504076504071348], 
     Hue[0.3345398038290026, 1, 0.5367910408521502], 
     Hue[0.008730634809406945, 1, 0.9879114287254365], 
     Hue[0.0033647739882266547`, 1, 0.9953410821701476], 
     Hue[0.33534829554959855`, 1, 0.535671590777479], 
     Hue[0.334570528677979, 1, 0.5367484987535676], 
     Hue[0.0012269646143769908`, 1, 0.9983011259185549], 
     Hue[0.33558347312137793`, 1, 0.5353459602934767], 
     Hue[0.32456849967550333`, 1, 0.5505974619877647], 
     Hue[0.33466762325689947`, 1, 0.5366140601058316], 
     Hue[0.008003393694545946, 1, 0.9889183779613979], 
     Hue[0.0016052343667500857`, 1, 0.9977773677998845], 
     Hue[0.3355229681347435, 1, 0.5354297364288167], 
     Hue[0.33473933474146894`, 1, 0.5365147672810431], 
     Hue[0.008356350169331228, 1, 0.9884296689963107], 
     Hue[7.5606077661882765`*^-6, 1, 0.9999895314661699], 
     Hue[0.3356819695512098, 1, 0.5352095806214018], 
     Hue[0.3248342030613752, 1, 0.5502295649919421], 
     Hue[0.3245881167942455, 1, 0.5505702998233524], 
     Hue[0.010094492916357334`, 1, 0.9860230098081206], 
     Hue[0.6498259780521269, 1, 0.10024095346628585`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.614729201445924*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"During evaluation of In[311]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "IntensityFunction", 
    "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
   RowBox[{"OutputGraphics", "\[Rule]", 
    GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwlmXk0VP//xxVKwseWpRRJyJLIvr1fQohKUUiypRTZ04ydscxkLypLdsIM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      "], {{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne8l3MchvFztEubllSnKU2SNGhnlKStQgMN7b333ntLe9EgRRlJWmhS
NGQWhWigUHl/+OPqvu77+b1Oned8n+eU1LpL/c6JCQkJW25JSIj81R91sJ93
tn3Me/GH+XJeCJX0u/RRPCXW60/r23hF5NVv1dvz83w6Gugb9XvwlF5en82z
Y7v+nL6DVwNN+E0+jgO8Nx4xrtAL40G9qD6ap8IGPR/S2zroP/EZaIYKtjm2
HHhfT4aLvC4O8j54CElIjkv2J3CI90Vl3O1rjLGlxkY9PzLYXtR/5jPRHBVt
c205sUNPgcu8Hg7zfnjUZ1bqRVBFL6aP5WnQlx+Vr9mf4W/zJbKSHCfPygKu
ZeQd+Qz5i95DHtJXy1l6Q/mavkjeK0fJb+PryhauV5Lz9PkylxwkT8h18gPX
n4/UV8jqcrL8KX7Wrl2RT+II74/HXFul34WqenF9HE+L1/WCyGTrpF/gs+Os
IBV+t9XHp3wAqqEQMvt8HMpf+Zy4F0iNP2wN8BkfiOoojCw+38X+G5+LZ5EG
f9oa4igfhBoogqw+39V+kc9DS6TFVVsjHOODURMlfHa8LR02xbnHbbZu+iU+
H62QDtdsjfE5H4JacU5xu893t1/mC9A6ng/8ZWuCL/jQeMbirCGbz/ewX+EL
0QYP2ubb7sDOOOv4mzfFcT4MtX1mtV4Uj+gl9Qn8VvTjx+QbcX/4O/EcYTz/
QRazZ+c9+Uz5u95THtbXyJf0RvJ1/WVZRo6W38XPWT4Xz5FcoC+QueVgeTLe
D/JD11+QO/WVsoacIn+WGVz7J94LOMG72D/hw3kdvobfjUf1UvpEnh6b47wh
h62X/gdfFOc3nlvbQtud2BXPDK7zZjjJu7q+n4/gj/O1cQ/i7+Rfycfspfkk
PkdmkP3l53JLnBn+Ll8qH5IT5I9xf2UJ13PK3vos+afeSx7R18qX9cZyk75Y
3ifHyO/jjMkXXK8S91zPgyH8lNxtbxv3ktdEJv2GbI5TfGScAdzjM5NtGfFm
nAPksvXRr/LFaKK/oZdFW72qvojnxVD+pdxjb8d38VqYGu8bmdl+U7bA9Pis
3k0e0FfF7wW9rnxFXyiLx32WX8sNso7r98op+lyZSQ6QX8hX5FvxTMn39GWy
spwoz8lSrt3B+/JrvDf/NN6TvCnfzO9Hu3ifxL3m+bBXb6/v5g8jix6/aJ7m
p+noOAcoY5sa3yO2xhlAbls//S++NL5OvEOQaH/G/hUfE99z3Hvcae9v/5sv
Q4d4Z8RfZ3/W/jUfiyfiPiCPfYD9H74cL8Y7A8nsLe3f8HGoF/8+5LUPtF/n
K9Ax3hlIbm9l/5aPx5O4D/nsg+w3+Ep0imcdKeyt7d/xCaiPskiyD7bf5KvQ
OZ4xpLS3sX/PJ6JBfH3btLif2Kbfj/y2IYkJ//2HYrV4St/Cy6GLXl1fzJOw
L+6PvifeWcipp4r3CT/Du/ODfFLcL/4qfymeMTlSfiM3yobxb5fT9Xkyqxwo
j8tX5dvx3pXb9eWySnxNeT7eI7Kc6wXkUH22TJR95Gfx/nOtGX+TP4Cx/Izs
aq/Bl/D8+Ch+dvreeFchl55af56f5ZPjZ6iv00uiUdwvfQa/De/oD6CgbZh+
S7wv4tmKM4808W6w/cCnxDsE5VHIPtyeLJ6fuGdxZpHW3tb2I58a50FfH88Q
mujl9Jn8dryrV0Bh2wg9edw3vXk8j7w8eug19aW8AD6Os6fvi/dlvGv1dHo7
fo5PizOlb9BLo2l8f/osng3v6W3093lVVNSL6CN5CqzTW+hbeQX01Gvpy3hB
DOOn5SdxpvlHvDam8QuJ//+fNo9r/wLDWET2
         "],
         VertexColors->Automatic]}},
      VertexColors->{
        Hue[0.6499398707454878, 1, 0.1000832558908631], 
        Hue[0.6203223046622468, 1, 0.14109219354458144`], 
        Hue[0.4954513949642436, 1, 0.31399037620335496`], 
        Hue[0.2641613627303298, 1, 0.6342381131426202], 
        Hue[0.054036889669744625`, 1, 0.9251796912265073], 
        Hue[0.006381705140027227, 1, 0.9911637928830391], 
        Hue[0.08274420775938995, 1, 0.885431096948537], 
        Hue[0.1691599937265455, 1, 0.7657784702247832], 
        Hue[0.22978761711841755`, 1, 0.6818325301437296], 
        Hue[0.27248639375582473`, 1, 0.6227111471073197], 
        Hue[0.3023344156621466, 1, 0.5813831167754894], 
        Hue[0.3195110194425703, 1, 0.557600126925672], 
        Hue[0.33175474086621765`, 1, 0.5406472818775448], 
        Hue[0.33504382680193695`, 1, 0.5360931628896258], 
        Hue[0.32715412408604966`, 1, 0.5470173666500852], 
        Hue[0.3262530974705614, 1, 0.548264941963838], 
        Hue[0.3342350794206079, 1, 0.5372129669560815], 
        Hue[0.3305891117004883, 1, 0.54226122995317], 
        Hue[0.3141334395656173, 1, 0.5650460067552991], 
        Hue[0.29427986323480065`, 1, 0.5925355739825837], 
        Hue[0.26517408101989304`, 1, 0.6328358878186097], 
        Hue[0.22343611589303858`, 1, 0.6906269164557928], 
        Hue[0.1718551257721982, 1, 0.7620467489308025], 
        Hue[0.09067339939355312, 1, 0.874452216224311], 
        Hue[0.01479619594798487, 1, 0.9795129594566363], 
        Hue[0.047801980587299675`, 1, 0.933812642263739], 
        Hue[0.2636825196117118, 1, 0.6349011266914759], 
        Hue[0.491908269799307, 1, 0.31889624181634413`], 
        Hue[0.6191293513231393, 1, 0.142743975091038], 
        Hue[0.65, 1, 0.1], 
        Hue[0.6409706445006202, 1, 0.11250218453760277`], 
        Hue[0.5748185040222215, 1, 0.20409745596923193`], 
        Hue[0.38940282912090374`, 1, 0.460826851986441], 
        Hue[0.14504693191953288`, 1, 0.7991657865729545], 
        Hue[0.004813969032249177, 1, 0.9933345044168858], 
        Hue[0.03863511362192695, 1, 0.9465052272927165], 
        Hue[0.12949486748296057`, 1, 0.8206994142543622], 
        Hue[0.2016498244225462, 1, 0.7207925507995514], 
        Hue[0.2528497487881972, 1, 0.6499003478317269], 
        Hue[0.28946413554699113`, 1, 0.5992035046272431], 
        Hue[0.3116834646957291, 1, 0.5684382796520674], 
        Hue[0.32622906826429365`, 1, 0.5482982131725165], 
        Hue[0.33528873833163825`, 1, 0.5357540546177317], 
        Hue[0.3316032232690648, 1, 0.5408570754736027], 
        Hue[0.32456990305854594`, 1, 0.5505955188420134], 
        Hue[0.330649628006252, 1, 0.5421774381451896], 
        Hue[0.33429378279586097`, 1, 0.5371316853595772], 
        Hue[0.3233150617506798, 1, 0.5523329914221357], 
        Hue[0.30465505043965346`, 1, 0.5781699301604798], 
        Hue[0.2812268585024925, 1, 0.610608965150395], 
        Hue[0.24592679149288388`, 1, 0.6594859810098531], 
        Hue[0.19957877626747422`, 1, 0.7236601559373435], 
        Hue[0.13511110569575213`, 1, 0.8129230844212663], 
        Hue[0.04729291525291868, 1, 0.9345175019574973], 
        Hue[0.010537614885446578`, 1, 0.9854094563124586], 
        Hue[0.13803819663954786`, 1, 0.8088701892683183], 
        Hue[0.38664807043228827`, 1, 0.4646411332476009], 
        Hue[0.572517840783257, 1, 0.20728298968472111`], 
        Hue[0.6407686948022476, 1, 0.11278180719688793`], 
        Hue[0.6464658206809982, 1, 0.10489347905707942`], 
        Hue[0.6012675228755449, 1, 0.1674757375569379], 
        Hue[0.44587440064177586`, 1, 0.3826354452652335], 
        Hue[0.20253157701263635`, 1, 0.7195716625978882], 
        Hue[0.022549036652892762`, 1, 0.9687782569421486], 
        Hue[0.019977799667594165`, 1, 0.972338431229485], 
        Hue[0.10682930858951623`, 1, 0.8520824957991313], 
        Hue[0.18606496752374724`, 1, 0.7423715834286576], 
        Hue[0.2417114192389414, 1, 0.6653226502845427], 
        Hue[0.2815371939795814, 1, 0.6101792698744257], 
        Hue[0.30725723350357076`, 1, 0.5745669074565943], 
        Hue[0.32298429150716074`, 1, 0.5527909809900852], 
        Hue[0.3339314511549457, 1, 0.5376333753239213], 
        Hue[0.3336190037457293, 1, 0.5380659948136056], 
        Hue[0.3253820726215876, 1, 0.5494709763701096], 
        Hue[0.3283155895431935, 1, 0.5454091837094244], 
        Hue[0.33474369287669475`, 1, 0.5365087329399612], 
        Hue[0.32728007883768284`, 1, 0.5468429677632084], 
        Hue[0.3094865562309006, 1, 0.5714801529110608], 
        Hue[0.2880599324099877, 1, 0.6011477858938632], 
        Hue[0.2559814500813479, 1, 0.6455641460412106], 
        Hue[0.2118905865609913, 1, 0.7066130339924735], 
        Hue[0.15448935071928593`, 1, 0.7860916682348349], 
        Hue[0.06858485788872304, 1, 0.9050363506156142], 
        Hue[0.008186003705886957, 1, 0.9886655333303103], 
        Hue[0.08700071976256285, 1, 0.8795374649441436], 
        Hue[0.32614581561593925`, 1, 0.548413486070238], 
        Hue[0.5368235063061956, 1, 0.2567059143452677], 
        Hue[0.6320334342956301, 1, 0.12487678328297373`], 
        Hue[0.6325995916241606, 1, 0.12409287313577767`], 
        Hue[0.5397656252400832, 1, 0.25263221120603874`], 
        Hue[0.09473536221503298, 1, 0.8688279600099543], 
        Hue[0.00005919780871066482, 1, 0.9999180338033237], 
        Hue[0.06016780764545682, 1, 0.9166907278755213], 
        Hue[0.15027934067999238`, 1, 0.791920912904626], 
        Hue[0.2161717130893524, 1, 0.7006853203378197], 
        Hue[0.26313156540672294`, 1, 0.635663986359922], 
        Hue[0.29635014283688577`, 1, 0.5896690329950812], 
        Hue[0.31573740831934805`, 1, 0.5628251269424411], 
        Hue[0.32918795993560573`, 1, 0.5442012862430075], 
        Hue[0.33567615409473517`, 1, 0.5352176327919053], 
        Hue[0.3293193739370407, 1, 0.5440193283948668], 
        Hue[0.3248868441666835, 1, 0.550156677307669], 
        Hue[0.33276770985525966`, 1, 0.539244709431179], 
        Hue[0.3328799368200185, 1, 0.5390893182492053], 
        Hue[0.3188844203233972, 1, 0.5584677257060655], 
        Hue[0.2996101164906168, 1, 0.5851552233206845], 
        Hue[0.27363384188991374`, 1, 0.6211223727678117], 
        Hue[0.23506307656055053`, 1, 0.6745280478392377], 
        Hue[0.1863189468053772, 1, 0.7420199198079392], 
        Hue[0.1137015524984426, 1, 0.8425670811560025], 
        Hue[0.02862967643823866, 1, 0.9603589095470542], 
        Hue[0.023456655151453343`, 1, 0.96752155440568], 
        Hue[0.19815455689489242`, 1, 0.7256321519916874], 
        Hue[0.4425393159756371, 1, 0.387253254802964], 
        Hue[0.5995662703128419, 1, 0.1698313180283728], 
        Hue[0.6464495558531855, 1, 0.10491599958789694`], 
        Hue[0.6484096091211057, 1, 0.10220207967846909`], 
        Hue[0.61163067873746, 1, 0.15312675251736316`], 
        Hue[0.47160885258391366`, 1, 0.34700312719150417`], 
        Hue[0.23303055108340498`, 1, 0.6773423138845162], 
        Hue[0.03657845595909315, 1, 0.9493529071335632], 
        Hue[0.012402155807288429`, 1, 0.9828277842668315], 
        Hue[0.09491337207880335, 1, 0.8685814848139646], 
        Hue[0.17779611877653512`, 1, 0.7538207586171053], 
        Hue[0.2358442171198502, 1, 0.6734464686032844], 
        Hue[0.27715476393911903`, 1, 0.6162472499304505], 
        Hue[0.3048665225530447, 1, 0.5778771226188613], 
        Hue[0.32127469147938764`, 1, 0.5551581194900786], 
        Hue[0.3329338316513099, 1, 0.5390146946366479], 
        Hue[0.33442149292249734`, 1, 0.5369548559534653], 
        Hue[0.3261676010268356, 1, 0.5483833216551507], 
        Hue[0.32722052286489206`, 1, 0.5469254298793802], 
        Hue[0.33460443469652346`, 1, 0.5367015519586599], 
        Hue[0.3290295826634927, 1, 0.5444205778505486], 
        Hue[0.31183312031603905`, 1, 0.5682310641777921], 
        Hue[0.29123666246325547`, 1, 0.5967492365893386], 
        Hue[0.26068780456341173`, 1, 0.6390476552198915], 
        Hue[0.2177513369198073, 1, 0.6984981488802668], 
        Hue[0.16341072802124462`, 1, 0.7737389919705844], 
        Hue[0.07962562024089126, 1, 0.8897491412049198], 
        Hue[0.010492820181716378`, 1, 0.9854714797483927], 
        Hue[0.06579612290033754, 1, 0.9088976759841481], 
        Hue[0.2949704808019442, 1, 0.5915793342742312], 
        Hue[0.5155229281922142, 1, 0.28619902250308804`], 
        Hue[0.6261780336936377, 1, 0.13298426103957858`], 
        Hue[0.6372053438594732, 1, 0.1177156777330371], 
        Hue[0.5584253420189846, 1, 0.22679568028140584`], 
        Hue[0.1188242529752942, 1, 0.8354741112649773], 
        Hue[0.0009109200328174527, 1, 0.9987387261084066], 
        Hue[0.04916676973704581, 1, 0.9319229342102443], 
        Hue[0.14013175130167543`, 1, 0.8059714212746033], 
        Hue[0.20903110585880658`, 1, 0.7105723149647294], 
        Hue[0.258102536305375, 1, 0.6426272574233269], 
        Hue[0.29302961014398354`, 1, 0.5942666936467921], 
        Hue[0.31375030549625865`, 1, 0.5655765000821035], 
        Hue[0.3277498472207276, 1, 0.5461925192328387], 
        Hue[0.3356098249227038, 1, 0.5353094731839486], 
        Hue[0.3304714083695946, 1, 0.5424242037959459], 
        Hue[0.32458628776516363`, 1, 0.5505728323251581], 
        Hue[0.3317651172668576, 1, 0.5406329145535819], 
        Hue[0.3337036832393987, 1, 0.5379487462839095], 
        Hue[0.3211475804152873, 1, 0.5553341194249869], 
        Hue[0.30216283721260195`, 1, 0.5816206869363973], 
        Hue[0.2775332919300528, 1, 0.6157231342506961], 
        Hue[0.24059242963680538`, 1, 0.6668720205028849], 
        Hue[0.19308204150484287`, 1, 0.7326556348394484], 
        Hue[0.1246466212891979, 1, 0.827412370522649], 
        Hue[0.037501644340984464`, 1, 0.9480746462970985], 
        Hue[0.015602071504170256`, 1, 0.9783971317634566], 
        Hue[0.16717515195253113`, 1, 0.7685267126811107], 
        Hue[0.4153087040981639, 1, 0.42495717894100393`], 
        Hue[0.5870602218492309, 1, 0.1871473851318342], 
        Hue[0.6439282618242888, 1, 0.10840702208944636`], 
        Hue[0.6440198096780283, 1, 0.10828026352273015`], 
        Hue[0.589052082743309, 1, 0.1843894238938799], 
        Hue[0.17307223495784924`, 1, 0.7603615208275933], 
        Hue[0.011980079925591025`, 1, 0.9834121970261047], 
        Hue[0.028816558568524053`, 1, 0.9601001496743513], 
        Hue[0.2856375251362463, 1, 0.6045018882728898], 
        Hue[0.3347235875878059, 1, 0.5365365710322688], 
        Hue[0.33266698393630134`, 1, 0.5393841760881982], 
        Hue[0.3248398131726385, 1, 0.5502217971455775], 
        Hue[0.3294792758522947, 1, 0.5437979257429766], 
        Hue[0.33464143192589035`, 1, 0.5366503250256903], 
        Hue[0.3253668711221463, 1, 0.5494920246001052], 
        Hue[0.05773538493622021, 1, 0.9200586977806181], 
        Hue[0.008126846574058932, 1, 0.9887474432051491], 
        Hue[0.1111854670051261, 1, 0.8460508918390562], 
        Hue[0.5558048271013173, 1, 0.2304240855520223], 
        Hue[0.6368486096420622, 1, 0.11820961741868313`], 
        Hue[0.6270191945889607, 1, 0.13181957672297745`], 
        Hue[0.5187770108687072, 1, 0.28169336956640545`], 
        Hue[0.07306375471873172, 1, 0.8988348011586792], 
        Hue[0.001987947739783724, 1, 0.9972474569756842], 
        Hue[0.3305286151939994, 1, 0.5423449943467701], 
        Hue[0.33548516430382075`, 1, 0.5354820801947098], 
        Hue[0.32819706695808465`, 1, 0.5455732919041905], 
        Hue[0.3254534536828504, 1, 0.5493721410545148], 
        Hue[0.3336055561160216, 1, 0.5380846146085855], 
        Hue[0.33183606785855096`, 1, 0.5405346752727757], 
        Hue[0.020962709570144678`, 1, 0.9709747098259535], 
        Hue[0.034182954699799484`, 1, 0.9526697550310469], 
        Hue[0.6101967759197219, 1, 0.15511215641884663`], 
        Hue[0.6484416117226051, 1, 0.10215776838408537`], 
        Hue[0.6492213623096276, 1, 0.10107811372513105`], 
        Hue[0.6161737909121435, 1, 0.14683628950626287`], 
        Hue[0.4837740601941176, 1, 0.33015899357737566`], 
        Hue[0.24854263990939435`, 1, 0.6558640370485309], 
        Hue[0.0448846016761445, 1, 0.9378520899868767], 
        Hue[0.00917917496135412, 1, 0.9872903731304328], 
        Hue[0.08885188803374344, 1, 0.8769743088763552], 
        Hue[0.17352636486384077`, 1, 0.7597327255731435], 
        Hue[0.23283930785268553`, 1, 0.6776071122039738], 
        Hue[0.2748563794230438, 1, 0.6194296284911701], 
        Hue[0.303619266958334, 1, 0.5796040919038452], 
        Hue[0.32039960084331387`, 1, 0.5563697834477193], 
        Hue[0.3323654254318962, 1, 0.5398017186327592], 
        Hue[0.3347567883195255, 1, 0.5364906007883493], 
        Hue[0.3266388244145866, 1, 0.5477308585028802], 
        Hue[0.3267173703364143, 1, 0.5476221026111188], 
        Hue[0.33444749976212423`, 1, 0.5369188464832126], 
        Hue[0.3298347498279073, 1, 0.543305731007513], 
        Hue[0.31298923279655444`, 1, 0.5666302930509247], 
        Hue[0.29277372118194384`, 1, 0.5946210014403854], 
        Hue[0.26295857949549856`, 1, 0.6359035053139251], 
        Hue[0.22061506592681146`, 1, 0.6945329856397995], 
        Hue[0.1676902202094634, 1, 0.7678135412484354], 
        Hue[0.08515887525637544, 1, 0.8820877111834802], 
        Hue[0.012411486847196729`, 1, 0.98281486436542], 
        Hue[0.05638675028899531, 1, 0.9219260380613912], 
        Hue[0.2793154975759987, 1, 0.613255464894771], 
        Hue[0.5040021097040585, 1, 0.30215092502514984`], 
        Hue[0.6228126361300026, 1, 0.13764404228153487`], 
        Hue[0.6391850298032127, 1, 0.1149745741186287], 
        Hue[0.5668994856957502, 1, 0.21506225057511516`], 
        Hue[0.13168855901506138`, 1, 0.8176619952099151], 
        Hue[0.002466248795067072, 1, 0.9965851939760609], 
        Hue[0.04382763578919335, 1, 0.9393155812149631], 
        Hue[0.13487429280051377`, 1, 0.8132509791992887], 
        Hue[0.20537184381645618`, 1, 0.7156389854849069], 
        Hue[0.2555035275538204, 1, 0.6462258849254795], 
        Hue[0.29127858158940784`, 1, 0.5966911947223584], 
        Hue[0.31272760163675994`, 1, 0.5669925515798709], 
        Hue[0.32699897238597153`, 1, 0.5472321920809625], 
        Hue[0.3354806277120149, 1, 0.5354883616295179], 
        Hue[0.33104290562929684`, 1, 0.5416328998978966], 
        Hue[0.32454205947565706`, 1, 0.5506340714952441], 
        Hue[0.33121797222664306`, 1, 0.5413904999938789], 
        Hue[0.33402861333113804`, 1, 0.5374988430799628], 
        Hue[0.32224445702467436`, 1, 0.5538153671966047], 
        Hue[0.30341595428827034`, 1, 0.5798856017547026], 
        Hue[0.2794049264104001, 1, 0.6131316403548307], 
        Hue[0.24328440712081945`, 1, 0.6631446670634807], 
        Hue[0.1963616922920871, 1, 0.728114579903264], 
        Hue[0.12994176625431386`, 1, 0.8200806313401808], 
        Hue[0.04229961761085321, 1, 0.9414312986926648], 
        Hue[0.012728400092202885`, 1, 0.982376061410796], 
        Hue[0.15234757901065116`, 1, 0.7890571982929445], 
        Hue[0.4011417181064782, 1, 0.4445730056987225], 
        Hue[0.5800527037955925, 1, 0.1968501024368719], 
        Hue[0.6424356043514087, 1, 0.11047377859035727`], 
        Hue[0.6453116124082237, 1, 0.10649161358861339`], 
        Hue[0.5954021620672785, 1, 0.17559700636838366`], 
        Hue[0.18764684067256798`, 1, 0.7401812975302905], 
        Hue[0.016833577591917948`, 1, 0.9766919694881137], 
        Hue[0.02425730475565102, 1, 0.9664129626460217], 
        Hue[0.2836222020006889, 1, 0.6072923356913539], 
        Hue[0.3343546308001878, 1, 0.537047434276663], 
        Hue[0.33315948171631066`, 1, 0.5387022560851084], 
        Hue[0.3250783760444603, 1, 0.5498914793230549], 
        Hue[0.32889269621484973`, 1, 0.544610112933285], 
        Hue[0.3347231617990408, 1, 0.5365371605859435], 
        Hue[0.32634232786068007`, 1, 0.5481413921929046], 
        Hue[0.06312343835721435, 1, 0.9125983161207801], 
        Hue[0.007860784868159776, 1, 0.9891158363363942], 
        Hue[0.09873826572022548, 1, 0.863285478233534], 
        Hue[0.5466021002875459, 1, 0.24316632267878266`], 
        Hue[0.6345617576170044, 1, 0.121376027914917], 
        Hue[0.6299399426764263, 1, 0.12777546398648673`], 
        Hue[0.5295643150772825, 1, 0.2667571022006858], 
        Hue[0.08358178669239591, 1, 0.8842713722720672], 
        Hue[0.0006948616020030496, 1, 0.999037883935688], 
        Hue[0.32987149048101866`, 1, 0.5432548593339742], 
        Hue[0.33561262787545737`, 1, 0.5353055921724437], 
        Hue[0.3287513647100242, 1, 0.5448058027091973], 
        Hue[0.3251386306538745, 1, 0.5498080498638661], 
        Hue[0.3332101640661408, 1, 0.5386320805238051], 
        Hue[0.3323845206144772, 1, 0.5397752791491854], 
        Hue[0.024627226904205823`, 1, 0.9659007627480227], 
        Hue[0.028458056533724463`, 1, 0.9605965371071506], 
        Hue[0.6051051503176443, 1, 0.16216209956018487`], 
        Hue[0.647505450095836, 1, 0.10345399217499632`], 
        Hue[0.6474946629038302, 1, 0.10346892828700434`], 
        Hue[0.606669581491444, 1, 0.1599959640887698], 
        Hue[0.02913101051004907, 1, 0.9596647546783936], 
        Hue[0.01601393441544674, 1, 0.9778268600401506], 
        Hue[0.33345686617940323`, 1, 0.5382904929823648], 
        Hue[0.3340410323828972, 1, 0.5374816474698347], 
        Hue[0.3257467885681318, 1, 0.5489659850595099], 
        Hue[0.33470372347960525`, 1, 0.536564075182085], 
        Hue[0.009073590774205442, 1, 0.9874365666203309], 
        Hue[0.07600949537887958, 1, 0.8947560833215514], 
        Hue[0.5264642181843207, 1, 0.27104954405247916`], 
        Hue[0.6292451803493999, 1, 0.12873744259313857`], 
        Hue[0.6350157006696132, 1, 0.12074749138053564`], 
        Hue[0.00011934873054919581`, 1, 0.9998347479115473], 
        Hue[0.3356752028647411, 1, 0.5352189498795893], 
        Hue[0.32470180782608865`, 1, 0.5504128814715695], 
        Hue[0.33228393735172246`, 1, 0.5399145482822305], 
        Hue[0.3333202655209005, 1, 0.5384796323556763], 
        Hue[0.03293321773132141, 1, 0.9544001600643243], 
        Hue[0.01917413917628419, 1, 0.9734511919097603], 
        Hue[0.5935582415820833, 1, 0.1781501270401924], 
        Hue[0.6452615609407701, 1, 0.10656091562047221`], 
        Hue[0.6425774098256601, 1, 0.11027743254908597`], 
        Hue[0.007978588801169528, 1, 0.9889527231983807], 
        Hue[0.33503573084672467`, 1, 0.5361043726737659], 
        Hue[0.32466957013441244`, 1, 0.550457518275429], 
        Hue[0.33449824854084825`, 1, 0.536848578943441], 
        Hue[0.009010994546887585, 1, 0.987523238319694], 
        Hue[0.6389118545999911, 1, 0.1153528167077047], 
        Hue[0.623819399848832, 1, 0.13625006174777116`], 
        Hue[0.0038977396867962977`, 1, 0.9946031296644359], 
        Hue[0.33529494773343405`, 1, 0.535745456984476], 
        Hue[0.3258267413460907, 1, 0.5488552812131052], 
        Hue[0.3339487155861848, 1, 0.5376094707268212], 
        Hue[0.33123680931030586`, 1, 0.541364417878038], 
        Hue[0.01767329301286913, 1, 0.9755292865975659], 
        Hue[0.04063204365031803, 1, 0.9437402472534059], 
        Hue[0.6148637936080795, 1, 0.1486501319272746], 
        Hue[0.6492695641742171, 1, 0.10101137268185331`], 
        Hue[0.6495916780181005, 1, 0.10056536889801475`], 
        Hue[0.6182959051391586, 1, 0.14389797749962663`], 
        Hue[0.4896744530275468, 1, 0.32198921888493526`], 
        Hue[0.25634187146467047`, 1, 0.6450651010489178], 
        Hue[0.049355988579127597`, 1, 0.9316609388904388], 
        Hue[0.007724965093649172, 1, 0.9893038944857164], 
        Hue[0.08580260926393413, 1, 0.8811963871730142], 
        Hue[0.17135555150725118`, 1, 0.762738467143806], 
        Hue[0.23131928850756284`, 1, 0.6797117543741438], 
        Hue[0.273680328349185, 1, 0.6210580069011284], 
        Hue[0.3029816820274928, 1, 0.5804869018080869], 
        Hue[0.3199570100815457, 1, 0.5569826014255521], 
        Hue[0.3320651739423048, 1, 0.5402174514645011], 
        Hue[0.33490651251482917`, 1, 0.5362832903640827], 
        Hue[0.3268913832654378, 1, 0.5473811616324707], 
        Hue[0.32647996418420705`, 1, 0.5479508188218671], 
        Hue[0.33434807060374117`, 1, 0.5370565176255891], 
        Hue[0.33021848789038316`, 1, 0.5427744013825464], 
        Hue[0.31356285696744657`, 1, 0.5658360441989202], 
        Hue[0.2935305057752772, 1, 0.5935731458496163], 
        Hue[0.2640732445165298, 1, 0.6343601229771126], 
        Hue[0.2220308630998889, 1, 0.6925726510924615], 
        Hue[0.1697866768227707, 1, 0.7649107551684713], 
        Hue[0.08791964644359773, 1, 0.8782651049242493], 
        Hue[0.013547711713068011`, 1, 0.9812416299357519], 
        Hue[0.05199022269743436, 1, 0.9280135378035524], 
        Hue[0.2714930587133087, 1, 0.6240865340892648], 
        Hue[0.49802624794011685`, 1, 0.31042519515983824`], 
        Hue[0.6210119648366716, 1, 0.14013727945691618`], 
        Hue[0.640101128705527, 1, 0.11370612948465492`], 
        Hue[0.570927521437244, 1, 0.2094849703176622], 
        Hue[0.13830860264548506`, 1, 0.8084957809524054], 
        Hue[0.0035394270118999094`, 1, 0.9950992549066002], 
        Hue[0.041211130063402934`, 1, 0.9429384352968266], 
        Hue[0.13219972387620438`, 1, 0.8169542284791016], 
        Hue[0.2035188658482081, 1, 0.7182046472870964], 
        Hue[0.25418340786124116`, 1, 0.6480537429613584], 
        Hue[0.290379410130738, 1, 0.5979362013574397], 
        Hue[0.3122083138993048, 1, 0.5677115653701934], 
        Hue[0.32661630658749696`, 1, 0.5477620370326965], 
        Hue[0.335392428031152, 1, 0.5356104842645588], 
        Hue[0.33132483557919656`, 1, 0.5412425353518817], 
        Hue[0.32454696346566336`, 1, 0.5506272813552353], 
        Hue[0.33093599298037457`, 1, 0.5417809327964045], 
        Hue[0.3341687359719763, 1, 0.5373048271157251], 
        Hue[0.3227831996270217, 1, 0.553069415901047], 
        Hue[0.3040371954779231, 1, 0.5790254216459527], 
        Hue[0.28032198428557525`, 1, 0.6118618679122805], 
        Hue[0.24461185614624303`, 1, 0.6613066607205866], 
        Hue[0.19797782006951153`, 1, 0.7258768645191379], 
        Hue[0.1325424081678125, 1, 0.816479742536875], 
        Hue[0.04477394039940796, 1, 0.9380053132931274], 
        Hue[0.01154874408725759, 1, 0.9840094312637971], 
        Hue[0.14512467094471104`, 1, 0.7990581479227077], 
        Hue[0.3939336254099925, 1, 0.45455344174001044`], 
        Hue[0.5763522332858397, 1, 0.20197383083499112`], 
        Hue[0.641624895323608, 1, 0.11159629878269661`], 
        Hue[0.6459051348766875, 1, 0.10566981324766349`], 
        Hue[0.5983941187109063, 1, 0.17145429716951432`], 
        Hue[0.19505354386190887`, 1, 0.7299258623450492], 
        Hue[0.019583148898330016`, 1, 0.9728848707561585], 
        Hue[0.022080356356444786`, 1, 0.9694271988910764], 
        Hue[0.28258847224659916`, 1, 0.6087236538124011], 
        Hue[0.33414964712752826`, 1, 0.5373312578234224], 
        Hue[0.33339365557159106`, 1, 0.5383780153624124], 
        Hue[0.3252223251121785, 1, 0.5496921652292913], 
        Hue[0.3286024731680903, 1, 0.545011960228798], 
        Hue[0.3347410420414997, 1, 0.5365124033271543], 
        Hue[0.32681611456694415`, 1, 0.547485379830385], 
        Hue[0.06584665018155045, 1, 0.9088277151332379], 
        Hue[0.007951246223989572, 1, 0.9889905821513991], 
        Hue[0.09277837680301726, 1, 0.8715376321188991], 
        Hue[0.5417851666356307, 1, 0.24983592311989603`], 
        Hue[0.633328921010883, 1, 0.12308303244646976`], 
        Hue[0.6313012956629634, 1, 0.1258905136974352], 
        Hue[0.5347381198195321, 1, 0.2595933725575709], 
        Hue[0.08908094261355293, 1, 0.8766571563812343], 
        Hue[0.00029239163763428166`, 1, 0.9995951500401987], 
        Hue[0.32953289265835145`, 1, 0.5437236870884365], 
        Hue[0.335652429084862, 1, 0.5352504828055757], 
        Hue[0.3290340481762456, 1, 0.5444143948328908], 
        Hue[0.3250045977180489, 1, 0.5499936339288554], 
        Hue[0.3329944733088144, 1, 0.5389307292647186], 
        Hue[0.3326389909955199, 1, 0.5394229355446648], 
        Hue[0.026588523572469325`, 1, 0.9631851212073502], 
        Hue[0.025867117004829132`, 1, 0.9641839918394673], 
        Hue[0.6023930066815211, 1, 0.16591737536404771`], 
        Hue[0.6469932227388104, 1, 0.10416323005395475`], 
        Hue[0.647965685486715, 1, 0.10281674317224085`], 
        Hue[0.609203823679551, 1, 0.15648701336677567`], 
        Hue[0.03274683723398941, 1, 0.9546582253683223], 
        Hue[0.014161744246589891`, 1, 0.9803914310431833], 
        Hue[0.33320121492827814`, 1, 0.5386444716377687], 
        Hue[0.3342366947175282, 1, 0.5372107303911149], 
        Hue[0.3259505201170127, 1, 0.5486838952225979], 
        Hue[0.33466140090781377`, 1, 0.536622675666104], 
        Hue[0.009718733605175722, 1, 0.9865432919312951], 
        Hue[0.07080381638030953, 1, 0.9019639465503407], 
        Hue[0.5210662604931173, 1, 0.27852363931722224`], 
        Hue[0.6277476698741495, 1, 0.130810918635793], 
        Hue[0.6361377860765688, 1, 0.11919383466321243`], 
        Hue[0.0004216049701781799, 1, 0.999416239272061], 
        Hue[0.335650542853165, 1, 0.5352530945110023], 
        Hue[0.32463522203899425`, 1, 0.5505050771767772], 
        Hue[0.33202849951228747`, 1, 0.5402682314445251], 
        Hue[0.3335191942989343, 1, 0.538204192509168], 
        Hue[0.03518655271004201, 1, 0.9512801577860956], 
        Hue[0.017299972610341552`, 1, 0.9760461917702963], 
        Hue[0.590371734720975, 1, 0.1825622134632654], 
        Hue[0.6446139332449645, 1, 0.10745763089158757`], 
        Hue[0.6433182767202669, 1, 0.10925161684886134`], 
        Hue[0.00987366148418578, 1, 0.986328776406512], 
        Hue[0.3348869127964574, 1, 0.5363104284356744], 
        Hue[0.32474598770549984`, 1, 0.5503517093308464], 
        Hue[0.33457752203819097`, 1, 0.5367388156394279], 
        Hue[0.008490076611369468, 1, 0.9882445093073345], 
        Hue[0.6379070913204846, 1, 0.1167440274024059], 
        Hue[0.6254553133829989, 1, 0.13398495070046312`], 
        Hue[0.002868374824688935, 1, 0.9960284040888921], 
        Hue[0.3353978003724276, 1, 0.5356030456381772], 
        Hue[0.32563310951254737`, 1, 0.5491233868287806], 
        Hue[0.33378396545074795`, 1, 0.5378375862989644], 
        Hue[0.33154264664100086`, 1, 0.5409409508047681], 
        Hue[0.01926878548484945, 1, 0.9733201431748237], 
        Hue[0.03731708892554586, 1, 0.9483301845646288], 
        Hue[0.6125819241844626, 1, 0.1518096434368981], 
        Hue[0.6488684292235369, 1, 0.10156679030587196`], 
        Hue[0.6488277482223833, 1, 0.1016231178459308], 
        Hue[0.33459499136331816`, 1, 0.5367146273430979], 
        Hue[0.32639729097297837`, 1, 0.5480652894220299], 
        Hue[0.33453304829270514`, 1, 0.5368003946716391], 
        Hue[0.011391787087449257`, 1, 0.984226756340455], 
        Hue[0.0015912329838886352`, 1, 0.9977967543300003], 
        Hue[0.33555314402344943`, 1, 0.5353879544290701], 
        Hue[0.32455518966412056`, 1, 0.5506158912342947], 
        Hue[0.3338735480858331, 1, 0.5377135488042312], 
        Hue[0.014078827787691872`, 1, 0.9805062384478113], 
        Hue[0.014299579844360588`, 1, 0.9802005817539623], 
        Hue[0.33454605598084153`, 1, 0.5367823840265272], 
        Hue[0.32495073479369113`, 1, 0.5500682133625816], 
        Hue[0.3346899738502388, 1, 0.5365831131304386], 
        Hue[0.007918177173668717, 1, 0.9890363700672279], 
        Hue[0.0012617229160725163`, 1, 0.9982529990392841], 
        Hue[0.3355568273404401, 1, 0.5353828544516983], 
        Hue[0.3252884273808777, 1, 0.5496006390110925], 
        Hue[0.33341408048336163`, 1, 0.5383497347153455], 
        Hue[0.6479877568612755, 1, 0.10278618280746465`], 
        Hue[0.3255570927912058, 1, 0.5492286407506382], 
        Hue[0.33473120609069956`, 1, 0.5365260223359545], 
        Hue[0.008561382792005912, 1, 0.9881457776726071], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[0.3356837494603589, 1, 0.5352071161318108], 
        Hue[0.3247857871570331, 1, 0.5502966023979542], 
        Hue[0.021225976353827836`, 1, 0.9706101865870076], 
        Hue[0.006292804813375796, 1, 0.991286885643018], 
        Hue[0.3351697580035618, 1, 0.5359187966104529], 
        Hue[0.32461081577858436`, 1, 0.5505388704604217], 
        Hue[0.3344036480973234, 1, 0.5369795641729368], 
        Hue[0.00969257327032369, 1, 0.9865795139333979], 
        Hue[0.005070668093653419, 1, 0.9929790749472491], 
        Hue[0.33517686031922533`, 1, 0.5359089626349188], 
        Hue[0.3340992571809017, 1, 0.5374010285187515], 
        Hue[0.6496463339576016, 1, 0.10048969144332093`], 
        Hue[0.6497684680580302, 1, 0.10032058268888121`], 
        Hue[0.6193208847295075, 1, 0.14247877498991263`], 
        Hue[0.49257843653554423`, 1, 0.3179683186430926], 
        Hue[0.26024948237517376`, 1, 0.639654562865144], 
        Hue[0.051670395251691814`, 1, 0.9284563758053499], 
        Hue[0.0070391826570419536`, 1, 0.990253439397942], 
        Hue[0.08427438705708767, 1, 0.8833123871517248], 
        Hue[0.17026090201037192`, 1, 0.7642541356779466], 
        Hue[0.23055490705616738`, 1, 0.6807701286914606], 
        Hue[0.2730855944832182, 1, 0.6218814845616979], 
        Hue[0.3026592767458759, 1, 0.580933309121095], 
        Hue[0.31973444101755644`, 1, 0.5572907739756912], 
        Hue[0.33191120509487415`, 1, 0.540430639099405], 
        Hue[0.3349767418483453, 1, 0.536186049748445], 
        Hue[0.32702153526753214`, 1, 0.5472009511680325], 
        Hue[0.3263651629831069, 1, 0.5481097743310828], 
        Hue[0.3342932498385909, 1, 0.5371324233004127], 
        Hue[0.3304054658465757, 1, 0.5425155088278183], 
        Hue[0.3138485329848082, 1, 0.5654404927902656], 
        Hue[0.2939060942517848, 1, 0.5930531002667595], 
        Hue[0.2646253885628478, 1, 0.633595615836057], 
        Hue[0.22273480082632774`, 1, 0.6915979680866231], 
        Hue[0.1708243594881107, 1, 0.7634739637856929], 
        Hue[0.0892975390851537, 1, 0.8763572535744025], 
        Hue[0.014158191134944875`, 1, 0.9803963507362302], 
        Hue[0.049869951896149955`, 1, 0.9309492973745617], 
        Hue[0.2675858993029871, 1, 0.6294964471189409], 
        Hue[0.494984937556883, 1, 0.31463624030585435`], 
        Hue[0.620081053978362, 1, 0.1414262329530373], 
        Hue[0.6405415909495699, 1, 0.11309625868521107`], 
        Hue[0.5728900282134092, 1, 0.20676765324297192`], 
        Hue[0.14166332032602003`, 1, 0.8038507872408953], 
        Hue[0.0041513378275706, 1, 0.99425199377721], 
        Hue[0.039917814685470066`, 1, 0.9447291796662722], 
        Hue[0.13085106349636644`, 1, 0.8188216043896465], 
        Hue[0.2025863779748482, 1, 0.7194957843425179], 
        Hue[0.25351826110643244`, 1, 0.6489747153910935], 
        Hue[0.28992380125612444`, 1, 0.598567044414597], 
        Hue[0.3119465976525323, 1, 0.5680739417118784], 
        Hue[0.3264232480596073, 1, 0.5480293488405438], 
        Hue[0.3353425097950293, 1, 0.5356796018222671], 
        Hue[0.33146451839705826`, 1, 0.541049128373304], 
        Hue[0.3245561812160596, 1, 0.5506145183162252], 
        Hue[0.33079330023634135`, 1, 0.5419785073650659], 
        Hue[0.3342331509003749, 1, 0.5372156372148655], 
        Hue[0.32305001221443946`, 1, 0.5526999830876993], 
        Hue[0.30434653929241884`, 1, 0.5785970994412662], 
        Hue[0.28077592854423666`, 1, 0.6112333297079799], 
        Hue[0.24527089452727113`, 1, 0.660394146039163], 
        Hue[0.19878016205132032`, 1, 0.7247659294674027], 
        Hue[0.1338307745236833, 1, 0.8146958506595153], 
        Hue[0.04602810281028025, 1, 0.9362687807242274], 
        Hue[0.011022261653315546`, 1, 0.9847384069415631], 
        Hue[0.14156396120479042`, 1, 0.8039883614087516], 
        Hue[0.3903002573939068, 1, 0.4595842589930521], 
        Hue[0.5744519006069537, 1, 0.2046050606980641], 
        Hue[0.6412026002558503, 1, 0.11218101503036115`], 
        Hue[0.6461894868204925, 1, 0.10527609517162578`], 
        Hue[0.5998454717906373, 1, 0.16944473136680996`], 
        Hue[0.19878403577845316`, 1, 0.7247605658452186], 
        Hue[0.02103901989610024, 1, 0.9708690493746304], 
        Hue[0.02101949813706505, 1, 0.9708960795025253], 
        Hue[0.28206503367222346`, 1, 0.6094484149153829], 
        Hue[0.3340421785668186, 1, 0.5374800604459434], 
        Hue[0.33350746839442696`, 1, 0.5382204283769473], 
        Hue[0.3253002543992455, 1, 0.5495842631395063], 
        Hue[0.3284585511000331, 1, 0.5452112369384158], 
        Hue[0.33474426363362786`, 1, 0.5365079426611307], 
        Hue[0.32704935004966873`, 1, 0.5471624383927663], 
        Hue[0.06721408207686197, 1, 0.9069343478935757], 
        Hue[0.008050815803413491, 1, 0.988852716579889], 
        Hue[0.08986648497730176, 1, 0.8755694823391206], 
        Hue[0.5393224638287768, 1, 0.2532458193140015], 
        Hue[0.6326891542119384, 1, 0.1239688633988546], 
        Hue[0.6319581881715707, 1, 0.12498097022397914`], 
        Hue[0.5372701351820414, 1, 0.2560875051325581], 
        Hue[0.0918889834870038, 1, 0.8727690997872255], 
        Hue[0.00015433721505975218`, 1, 0.9997863023176097], 
        Hue[0.3293612016678818, 1, 0.5439614130752406], 
        Hue[0.33566630563909317`, 1, 0.5352312691151019], 
        Hue[0.3291764291155226, 1, 0.5442172519938918], 
        Hue[0.32494366159260896`, 1, 0.5500780070256184], 
        Hue[0.3328824303402503, 1, 0.5390858656827304], 
        Hue[0.33276117041455455`, 1, 0.539253764041386], 
        Hue[0.027599405850318504`, 1, 0.9617854380534052], 
        Hue[0.02463936251650689, 1, 0.9658839595925289], 
        Hue[0.6009941334043599, 1, 0.16785427682473247`], 
        Hue[0.6467254162291354, 1, 0.10453403906735113`], 
        Hue[0.6481909529523812, 1, 0.10250483437362612`], 
        Hue[0.6104304980619305, 1, 0.15478854114501933`], 
        Hue[0.03463572826352013, 1, 0.9520428377889721], 
        Hue[0.013270088216202569`, 1, 0.9816260317006426], 
        Hue[0.33306896758758087`, 1, 0.5388275833402727], 
        Hue[0.33433048027707757`, 1, 0.537080873462508], 
        Hue[0.32605743586255737`, 1, 0.5485358580364591], 
        Hue[0.334634734986847, 1, 0.5366595977105195], 
        Hue[0.01008991294318795, 1, 0.986029351309432], 
        Hue[0.06827502074472325, 1, 0.9054653558919217], 
        Hue[0.518312745112626, 1, 0.28233619907482554`], 
        Hue[0.6269720191913284, 1, 0.13188489650431456`], 
        Hue[0.6366782518371953, 1, 0.11844549745619123`], 
        Hue[0.000642628549405333, 1, 0.9991102066239003], 
        Hue[0.3356321857471822, 1, 0.5352785120423631], 
        Hue[0.3246085384883455, 1, 0.5505420236315217], 
        Hue[0.33189774821654194`, 1, 0.5404492717001728], 
        Hue[0.3336132556644899, 1, 0.5380739536953216], 
        Hue[0.03633665471083669, 1, 0.9496877088619184], 
        Hue[0.016429087474083892`, 1, 0.9772520327281916], 
        Hue[0.5887317559390493, 1, 0.18483295331516256`], 
        Hue[0.6442759632013874, 1, 0.1079255894134637], 
        Hue[0.6436738528004411, 1, 0.10875928073785078`], 
        Hue[0.01090033653309086, 1, 0.9849072263387972], 
        Hue[0.33480704542627854`, 1, 0.5364210140251529], 
        Hue[0.3247907425211815, 1, 0.550289741124518], 
        Hue[0.33461139756560154`, 1, 0.5366919110630133], 
        Hue[0.008288943377575908, 1, 0.9885230014772026], 
        Hue[0.637384700036486, 1, 0.11746733841101942`], 
        Hue[0.626246115484745, 1, 0.1328899939441994], 
        Hue[0.002409214436113638, 1, 0.9966641646269195], 
        Hue[0.3354434324469677, 1, 0.535539862765737], 
        Hue[0.3255414933906034, 1, 0.549250239920703], 
        Hue[0.3336964316687655, 1, 0.5379587869201709], 
        Hue[0.3316909289586658, 1, 0.5407356368264628], 
        Hue[0.020103735364840003`, 1, 0.9721640587256062], 
        Hue[0.03572739517140178, 1, 0.9505312989934438], 
        Hue[0.6114024420244684, 1, 0.15344277258150535`], 
        Hue[0.6486583116008349, 1, 0.10185772239884405`], 
        Hue[0.6490275428023855, 1, 0.10134647919669705`], 
        Hue[0.334677376463026, 1, 0.5366005556665795], 
        Hue[0.32651662712492796`, 1, 0.5479000547500998], 
        Hue[0.3344920287104155, 1, 0.5368571910163479], 
        Hue[0.011886806967454588`, 1, 0.983541344198909], 
        Hue[0.002004180904139563, 1, 0.997224980286576], 
        Hue[0.3355188563553291, 1, 0.5354354296618521], 
        Hue[0.32454637288074756`, 1, 0.5506280990881957], 
        Hue[0.33395294099355477`, 1, 0.5376036201627703], 
        Hue[0.0133821348889126, 1, 0.9814708901538134], 
        Hue[0.015539689671055013`, 1, 0.9784835066093084], 
        Hue[0.334452059334183, 1, 0.5369125332295929], 
        Hue[0.3250124928910314, 1, 0.5499827021508796], 
        Hue[0.3347084847683594, 1, 0.5365574826284255], 
        Hue[0.007870782139597132, 1, 0.9891019939605578], 
        Hue[0.0009580543666320995, 1, 0.9986734631846632], 
        Hue[0.33558672114397226`, 1, 0.535341463031423], 
        Hue[0.32521158929034105`, 1, 0.549707030213374], 
        Hue[0.3333136365119753, 1, 0.5384888109834188], 
        Hue[0.647750250673156, 1, 0.10311503752947641`], 
        Hue[0.32565014497083133`, 1, 0.5490997992711567], 
        Hue[0.33471932880154487`, 1, 0.5365424678132457], 
        Hue[0.008800624248977873, 1, 0.9878145202706461], 
        Hue[0.000037078988190830664`, 1, 0.999948659862505], 
        Hue[0.3356814925559579, 1, 0.5352102410763661], 
        Hue[0.3247416416135234, 1, 0.55035772699666], 
        Hue[0.02017777035014312, 1, 0.9720615487459557], 
        Hue[0.007109671751682978, 1, 0.9901558391130543], 
        Hue[0.3351046097773764, 1, 0.5360090018467096], 
        Hue[0.32463797497778235`, 1, 0.5505012654153782], 
        Hue[0.3344528613781988, 1, 0.5369114227071095], 
        Hue[0.009331522119800817, 1, 0.987079430911045], 
        Hue[0.004466597584717014, 1, 0.9938154802673148], 
        Hue[0.33523779010694477`, 1, 0.5358245983134611], 
        Hue[0.3340257953108546, 1, 0.5375027449542014], 
        Hue[0.6494609147020903, 1, 0.10074642579710572`], 
        Hue[0.3343995008120433, 1, 0.5369853065679401], 
        Hue[0.002977861325355491, 1, 0.9958768073956615], 
        Hue[0.33543847851623076`, 1, 0.5355467220544498], 
        Hue[0.3245422556128765, 1, 0.5506337999206325], 
        Hue[0.01211736119459983, 1, 0.9832221152690156], 
        Hue[0.3251483401994455, 1, 0.5497946058776909], 
        Hue[0.3347340114594461, 1, 0.5365221379792285], 
        Hue[0.007887753077295723, 1, 0.989078495739129], 
        Hue[0.0004727689357605369, 1, 0.9993453968581777], 
        Hue[0.3356345366564564, 1, 0.5352752569372142], 
        Hue[0.3346844054353854, 1, 0.5365908232433125], 
        Hue[0.009379792468023451, 1, 0.9870125950442752], 
        Hue[0.0002473480850635479, 1, 0.9996575180360658], 
        Hue[0.33566488369663094`, 1, 0.5352332379585111], 
        Hue[0.3246663233849915, 1, 0.5504620137746272], 
        Hue[0.008899827783288905, 1, 0.9876771615308307], 
        Hue[0.3247055858170693, 1, 0.5504076504071348], 
        Hue[0.3345398038290026, 1, 0.5367910408521502], 
        Hue[0.008730634809406945, 1, 0.9879114287254365], 
        Hue[0.0033647739882266547`, 1, 0.9953410821701476], 
        Hue[0.33534829554959855`, 1, 0.535671590777479], 
        Hue[0.334570528677979, 1, 0.5367484987535676], 
        Hue[0.0012269646143769908`, 1, 0.9983011259185549], 
        Hue[0.33558347312137793`, 1, 0.5353459602934767], 
        Hue[0.32456849967550333`, 1, 0.5505974619877647], 
        Hue[0.33466762325689947`, 1, 0.5366140601058316], 
        Hue[0.008003393694545946, 1, 0.9889183779613979], 
        Hue[0.0016052343667500857`, 1, 0.9977773677998845], 
        Hue[0.3355229681347435, 1, 0.5354297364288167], 
        Hue[0.33473933474146894`, 1, 0.5365147672810431], 
        Hue[0.008356350169331228, 1, 0.9884296689963107], 
        Hue[7.5606077661882765`*^-6, 1, 0.9999895314661699], 
        Hue[0.3356819695512098, 1, 0.5352095806214018], 
        Hue[0.3248342030613752, 1, 0.5502295649919421], 
        Hue[0.3245881167942455, 1, 0.5505702998233524], 
        Hue[0.010094492916357334`, 1, 0.9860230098081206], 
        Hue[0.6498259780521269, 1, 0.10024095346628585`]}],
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesLabel->{None, None},
     AxesOrigin->{0., 0.},
     DisplayFunction->((Print[#]; #)& ),
     FormatType->OutputForm,
     Method->{},
     PlotLabel->"Surface Intensity",
     PlotRange->All,
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}]}], ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"RayBoundary", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.061148071639646494`"}], ",", "0.061148071639646084`"}], 
     "}"}]}], ",", 
   RowBox[{"NumberOfRays", "\[Rule]", "1716"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
   RowBox[{"Energy", "\[Rule]", "74.47916666666666`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5634043328134327`*^9, 3.56345823436012*^9, 
  3.564487687149067*^9, 3.566100828747759*^9, 3.601301578308778*^9, 
  3.614709343506666*^9, 3.6147292014539223`*^9},
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"},
 CellLabel->"Out[311]="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Gratings", "PR4.4"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.5 Generic Building Blocks: The Language of Components", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"4.5", "Generic Building Blocks", "PR4.5"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " has its own special language called \"generic building blocks\" that are \
used by component functions to model different optical elements. Generic \
building blocks are a collection of functions that assign new behaviors and \
pass special attributes to the ",
 StyleBox["Component", "Input"],
 " object, which holds the information about one or more optical surfaces \
that make up an element. ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " presently has 30 principle generic building blocks. At any time that you \
wish while working with ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", you can access a listing of ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s positioning functions with the ",
 StyleBox["BuildingBlockFunctions", "Input"],
 " command:"
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["BuildingBlockFunctions", "Input"]], "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[312]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {
     ButtonBox[
      StyleBox["\<\"ABCDMatrix\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ABCDMatrix", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CombineSurfaces\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CombineSurfaces", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Diffraction \"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"Diffraction ", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LinearPolarization\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"LinearPolarization", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Resonate\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Resonate", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"Absorption\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Absorption", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ComponentFoundation\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ComponentFoundation", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DrillHole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"DrillHole", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MeldSurfaces\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"MeldSurfaces", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ScatterRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ScatterRays", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AddDeflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AddDeflection", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ComponentRendering\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ComponentRendering", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FocusRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"FocusRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PhaseRetardation\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PhaseRetardation", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"TransferTraits\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"TransferTraits", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AddRandomRayTilt\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AddRandomRayTilt", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Confine\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Confine", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Fresnel\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Fresnel", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Reflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Reflection", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Transmission\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"Transmission", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AddSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"AddSurface", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ConjugateReflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ConjugateReflection", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Hole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Hole", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Refraction\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Refraction", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Unconfine\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Unconfine", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AddSurfaceRoughness\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AddSurfaceRoughness", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ConjugateReflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ConjugateReflection", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"InsertDeflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"InsertDeflection", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RemoveDeflection\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RemoveDeflection", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BuildComponent\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BuildComponent", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomDeflections\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomDeflections", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"JonesMatrix\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"JonesMatrix", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RemoveSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RemoveSurface", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]}
   },
   AutoDelete->False,
   GridBoxBackground->{"Columns" -> {{
        GrayLevel[0.930022]}}},
   GridBoxDividers->{
    "Columns" -> {True, {False}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {1, 1, 1, {1.05}},
      "RowsIndexed" -> {}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.563404333898985*^9, 3.563458234534588*^9, 
  3.564487687411191*^9, 3.5661008289104347`*^9, 3.601301578565659*^9, 
  3.614709343575577*^9, 3.614729201643951*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[312]="]
}, Open  ]],

Cell["\<\
Hyperlinks to Rayica's most important generic building blocks functions. \
Clicking on any name will give you a description of its use in Mathematica.\
\>", "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[TextData[{
 "These various generic building blocks are called internally by each \
component function in order to construct a particular optical element. \
Normally, this activity happens transparently whenever you evaluate a \
component function, such as ",
 StyleBox["PlanoConvexLens", "Input"],
 ". However, you can also call these generic building blocks directly. For \
example, the ",
 StyleBox["Resonate", "Input"],
 " function is a generic building block that is frequently called by the user \
to invoke non-sequential ray-trace behavior within an optical system. Two \
other examples are ",
 StyleBox["Hole", "Input"],
 " that places a hole in the element and ",
 StyleBox["Fresnel", "Input"],
 " that creates a Fresnel lens (or mirror) out of an ordinary \"thick\" \
optic.  You can see how generic building blocks are used within a particular \
component function with the ",
 StyleBox["BuildComponent -> True", "Input"],
 " option. This option serves no purpose other than as a diagnostic tool that \
causes the created component to display its generic-building-block history. \
For example, here are the underlaying generic building blocks used by the ",
 StyleBox["PlanoConvexLens", "Input"],
 " function."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["PlanoConvexLens[100, 50, 10, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[313]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Resonate", "[", 
     RowBox[{"Refraction", "[", 
      RowBox[{"ComponentRendering", "[", 
       RowBox[{"ComponentFoundation", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"51.872033213443714`", ",", "\[Infinity]"}], "}"}], ",", 
         "50.`", ",", "10", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Labels", "\[Rule]", "\<\"L\"\>"}], ",", 
           RowBox[{"ComponentMedium", "\[Rule]", "BK7"}]}], "}"}]}], "]"}], 
       "]"}], "]"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5634043341991463`*^9, 3.563458234656954*^9, 
  3.564487687959585*^9, 3.566100829182581*^9, 3.601301578692429*^9, 
  3.614709343698782*^9, 3.614729201769039*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[313]="]
}, Open  ]],

Cell[TextData[{
 "From this, we can see that the ",
 StyleBox["PlanoConvexLens", "Input"],
 " function has internally called ",
 StyleBox["Resonate", "Input"],
 ", ",
 StyleBox["Refraction", "Input"],
 ", ",
 StyleBox["ComponentRendering", "Input"],
 ", and ",
 StyleBox["ComponentFoundation", "Input"],
 ". Each of these generic functions have a specific purpose in fashioning the \
final plano-convex lens ",
 StyleBox["Component", "Input"],
 " object. In particular, ",
 StyleBox["ComponentFoundation", "Input"],
 " creates the initial ",
 StyleBox["Component", "Input"],
 " object, while ",
 StyleBox["ComponentRendering", "Input"],
 " instructs the ",
 StyleBox["Component", "Input"],
 " object how it is graphically rendered. ",
 StyleBox["Refraction", "Input"],
 " passes the trait for optical refraction to the ",
 StyleBox["Component", "Input"],
 " object, and ",
 StyleBox["Resonate", "Input"],
 " informs the ",
 StyleBox["Component", "Input"],
 " to invoke nonsequential ray-tracing within its active surfaces. In \
general, generic building blocks completely define the behavior of a \
particular optical component. As a demonstration, to obtain the behavior of \
the ",
 StyleBox["PlanoConvexLens", "Input"],
 " function, you can explicitly use the same generic building blocks directly."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["\<\
lens = Resonate[Refraction[ComponentRendering[ComponentFoundation[{51.872,\
\[Infinity]},50.,10]]]];

AnalyzeSystem[{LineOfRays[45], Move[lens,50], Boundary[150,60]}, \
PlotType->TopView];\
\>", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[314]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.421979273932116`, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75045069399559, -16.666666666666668`}, {
      56.421979273932116`, -25.}}], 
     PolygonBox[{{52.75045069399559, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375843297393, -8.333333333333336}, {
      52.75045069399559, -16.666666666666668`}}], 
     PolygonBox[{{50.67375843297393, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375843297393, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375843297393, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375843297393, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75045069399559, 
      16.666666666666664`}, {50.67375843297393, 8.333333333333329}}], 
     PolygonBox[{{52.75045069399559, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197927393211, 
      24.999999999999993`}, {52.75045069399559, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.421979273932116`, -25.}, {
       52.75045069399559, -16.666666666666668`}, {
       50.67375843297393, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375843297393, 
       8.333333333333329}, {52.75045069399559, 16.666666666666657`}, {
       56.42197927393211, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.421979273932116`, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.421979273932116`, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75045069399559, 
        5.102694996447305*^-16}, {56.421979273932116`, 0.}}], 
       PolygonBox[{{52.75045069399559, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375843297393, 1.020538999289461*^-15}, {52.75045069399559, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375843297393, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375843297393, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375843297393, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375843297393, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75045069399559, 2.5513474982236525`*^-15}, {50.67375843297393, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75045069399559, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197927393211, 3.0616169978683826`*^-15}, {52.75045069399559, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.421979273932116`, 0.}, {52.75045069399559, 0.}, {
         50.67375843297393, 0.}, {50., 0.}, {50.67375843297393, 0.}, {
         52.75045069399559, 0.}, {56.42197927393211, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.421979273932116`, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.421979273932116`, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.421979273932116`, 24.148145657226706`}, {
       56.421979273932116`, 25.}}], 
      LineBox[{{56.421979273932116`, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.421979273932116`, 
       21.65063509461097}, {56.421979273932116`, 24.148145657226706`}}], 
      LineBox[{{56.421979273932116`, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.421979273932116`, 
       17.67766952966369}, {56.421979273932116`, 21.65063509461097}}], 
      LineBox[{{56.421979273932116`, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.421979273932116`, 
       12.500000000000004`}, {56.421979273932116`, 17.67766952966369}}], 
      LineBox[{{56.421979273932116`, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.421979273932116`, 
       6.470476127563024}, {56.421979273932116`, 12.500000000000004`}}], 
      LineBox[{{56.421979273932116`, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.421979273932116`, 7.0819236220599744`*^-15}, {56.421979273932116`, 
       6.470476127563024}}], 
      LineBox[{{56.421979273932116`, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.421979273932116`, -6.470476127563016}, {56.421979273932116`, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.421979273932116`, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.421979273932116`, -12.499999999999995`}, {
       56.421979273932116`, -6.470476127563016}}], 
      LineBox[{{56.421979273932116`, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.421979273932116`, -17.677669529663685`}, {
       56.421979273932116`, -12.499999999999995`}}], 
      LineBox[{{56.421979273932116`, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.421979273932116`, -21.65063509461097}, {
       56.421979273932116`, -17.677669529663685`}}], 
      LineBox[{{56.42197927393212, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.421979273932116`, -24.148145657226706`}, {
       56.42197927393212, -21.650635094610962`}}], 
      LineBox[{{56.421979273932116`, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.421979273932116`, -25.}, {
       56.421979273932116`, -24.148145657226706`}}], 
      LineBox[{{56.421979273932116`, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.421979273932116`, -24.148145657226706`}, {
       56.421979273932116`, -25.}}], 
      LineBox[{{56.421979273932116`, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.421979273932116`, -21.65063509461097}, {
       56.421979273932116`, -24.14814565722671}}], 
      LineBox[{{56.421979273932116`, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.421979273932116`, -17.677669529663692`}, {
       56.421979273932116`, -21.65063509461097}}], 
      LineBox[{{56.421979273932116`, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.421979273932116`, -12.50000000000001}, {
       56.421979273932116`, -17.677669529663696`}}], 
      LineBox[{{56.421979273932116`, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.421979273932116`, -6.470476127563038}, {
       56.421979273932116`, -12.50000000000001}}], 
      LineBox[{{56.421979273932116`, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.421979273932116`, -2.6796885989305705`*^-14}, {
       56.421979273932116`, -6.470476127563038}}], 
      LineBox[{{56.421979273932116`, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.421979273932116`, 6.470476127563007}, {
       56.421979273932116`, -4.592425496802574*^-15}}], 
      LineBox[{{56.421979273932116`, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.421979273932116`, 
       12.499999999999984`}, {56.421979273932116`, 6.470476127563007}}], 
      LineBox[{{56.421979273932116`, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.42197927393212, 
       17.67766952966367}, {56.421979273932116`, 12.499999999999984`}}], 
      LineBox[{{56.421979273932116`, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.421979273932116`, 
       21.65063509461096}, {56.421979273932116`, 17.677669529663685`}}], 
      LineBox[{{56.421979273932116`, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.421979273932116`, 
       24.148145657226703`}, {56.421979273932116`, 21.65063509461096}}], 
      LineBox[{{56.421979273932116`, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.421979273932116`, 25.}, {
       56.421979273932116`, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 30.}, {150., -30.}, {150., -30.}, {150., 30.}, {150., 
       30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -30.}, {0., -30.}, {0., -30.}, {150., -30.}, {
       150., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -30}, {0, 30}, {0, 30}, {0, -30}, {0, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 30.}, {150., 30.}, {150., 30.}, {0., 30.}, {0., 30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -30.}, {150., 30.}, {0., 30.}, {0., -30.}, {
       150., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 30.}, {150., -30.}, {0., -30.}, {0., 30.}, {150., 
       30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13385301062953, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13385301062953, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13385301062953, -22.5}, {60., -21.719260791554696`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13385301062953, 22.5}, {60., 21.719260791554696`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.719260791554696`}, {150., 0.5945571216141872}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {150., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.719260791554696`}, {150., -0.5945571216141872}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{55.13385301062953, -22.5}, {50., 0.}, {55.13385301062953, 
      22.5}, {60., -21.719260791554696`}, {60., 0.}, {60., 
      21.719260791554696`}, {150., 0.5945571216141872}, {150., 0.}, {
      150., -0.5945571216141872}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043376612453`*^9, 3.563458234992887*^9, 
  3.564487689266355*^9, 3.566100830199916*^9, 3.601301579063798*^9, 
  3.6147093440685577`*^9, 3.61472920215275*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"During evaluation of In[314]:="]
}, Open  ]],

Cell[TextData[StyleBox["A plano-convex lens built from scratch.",
 FontSlant->"Italic"]], "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[TextData[{
 "Now, we will examine the ",
 StyleBox["Mirror", "Input"],
 " function."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["Mirror[100, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[317]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Reflection", "[", 
     RowBox[{"ComponentRendering", "[", 
      RowBox[{"ComponentFoundation", "[", 
       RowBox[{"\[Infinity]", ",", "100.`", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Labels", "\[Rule]", "\<\"M\"\>"}], ",", 
          RowBox[{"ComponentMedium", "\[Rule]", "BK7"}]}], "}"}]}], "]"}], 
      "]"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404337997078*^9, 3.5634582350404797`*^9, 
  3.564487689613779*^9, 3.5661008307046537`*^9, 3.601301579117128*^9, 
  3.61470934412332*^9, 3.614729202204175*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[317]="]
}, Open  ]],

Cell[TextData[{
 "Here you can see that the two inner-most generic functions, ",
 StyleBox["ComponentFoundation", "Input"],
 " and ",
 StyleBox["ComponentRendering", "Input"],
 ", have been used with both ",
 StyleBox["Mirror", "Input"],
 " and ",
 StyleBox["PlanoConvexLens", "Input"],
 ". In fact, these two functions are used with every component function in \
some combination",
 StyleBox[" ",
  FontSlant->"Italic"],
 "(although non-rendered optical components would not require ",
 StyleBox["ComponentRendering", "Input"],
 "). Therefore, only the ",
 StyleBox["Reflection", "Input"],
 " function is new for ",
 StyleBox["Mirror", "Input"],
 ", which passes the trait for optical reflection. Note, however, ",
 StyleBox["Resonate", "Input"],
 " is not used with ",
 StyleBox["Mirror", "Input"],
 " because only a single flat surface is involved.  Next we examine the ",
 StyleBox["Screen", "Input"],
 " function."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["Screen[100, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[318]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Transmission", "[", 
     RowBox[{"ComponentRendering", "[", 
      RowBox[{"ComponentFoundation", "[", 
       RowBox[{"\[Infinity]", ",", "100.`", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Labels", "\[Rule]", "\<\"S\"\>"}], ",", 
          RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
       "]"}], "]"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404338059079*^9, 3.5634582350829973`*^9, 
  3.564487689981002*^9, 3.566100830836994*^9, 3.601301579165346*^9, 
  3.6147093441694183`*^9, 3.614729202253208*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[318]="]
}, Open  ]],

Cell[TextData[{
 "By comparing the results of ",
 StyleBox["Screen", "Input"],
 " with those of ",
 StyleBox["Mirror", "Input"],
 ", we can see that the ",
 StyleBox["Reflection", "Input"],
 " function in ",
 StyleBox["Mirror", "Input"],
 " has been exchanged by the ",
 StyleBox["Transmission", "Input"],
 " function in ",
 StyleBox["Screen", "Input"],
 ". Here of course, the ",
 StyleBox["Transmission", "Input"],
 " function passes the trait for the transmission of rays (otherwise the \
optic would be totally invisible to the rays). The next example shows the ",
 StyleBox["BeamSplitter", "Input"],
 " function, which uses both ",
 StyleBox["Reflection", "Input"],
 " and ",
 StyleBox["Transmission", "Input"],
 " generic traits."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["BeamSplitter[{50,50}, 100, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[319]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Reflection", "[", 
     RowBox[{
      RowBox[{"Transmission", "[", 
       RowBox[{
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"ComponentFoundation", "[", 
          RowBox[{"\[Infinity]", ",", "100.`", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Labels", "\[Rule]", "\<\"BS\"\>"}], ",", 
             RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
             RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
          "]"}], "]"}], ",", 
        RowBox[{"Transmittance", "\[Rule]", "50"}], ",", 
        RowBox[{"WaveFrontID", "\[Rule]", "NewRay"}]}], "]"}], ",", 
      RowBox[{"Reflectance", "\[Rule]", "50"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.56340433835979*^9, 3.563458235142218*^9, 
  3.564487690078388*^9, 3.56610083123604*^9, 3.6013015792228813`*^9, 
  3.614709344228429*^9, 3.61472920231176*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[319]="]
}, Open  ]],

Cell[TextData[{
 "For component functions that use more than two surfaces, the generic \
building block structure can get more complicated. Here is the ",
 StyleBox["Prism", "Input"],
 " function that contains five surfaces."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["Prism[{45, 50, 45}, 50, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[320]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Resonate", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Refraction", "[", 
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"ComponentFoundation", "[", 
            RowBox[{"\[Infinity]", ",", 
             RowBox[{"{", 
              RowBox[{"35.37301672885704`", ",", "50.025`"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"SymbolicValues", "\[Rule]", 
                RowBox[{"CleanUpRules", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"Sequence", "[", "]"}]}], "}"}], "]"}], "]"}]}], 
               ",", 
               RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
               RowBox[{"SurfaceBoundaryFactor", "\[Rule]", 
                FractionBox["2001", "2000"]}], ",", 
               RowBox[{"ActiveRegion", "\[Rule]", "1"}], ",", 
               RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "12.5`"}], ",", "12.5`"}], "}"}], ",", 
           RowBox[{"-", "45.`"}]}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"Refraction", "[", 
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"ComponentFoundation", "[", 
            RowBox[{"\[Infinity]", ",", 
             RowBox[{"{", 
              RowBox[{"35.37301672885704`", ",", "50.025`"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"SymbolicValues", "\[Rule]", 
                RowBox[{"CleanUpRules", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"Sequence", "[", "]"}]}], "}"}], "]"}], "]"}]}], 
               ",", 
               RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
               RowBox[{"SurfaceBoundaryFactor", "\[Rule]", 
                FractionBox["2001", "2000"]}], ",", 
               RowBox[{"ActiveRegion", "\[Rule]", "1"}], ",", 
               RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"12.5`", ",", "12.5`"}], "}"}], ",", "45.`"}], "]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"Refraction", "[", 
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"ComponentFoundation", "[", 
            RowBox[{"\[Infinity]", ",", 
             RowBox[{"{", 
              RowBox[{"50.025`", ",", "50.025`"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"SymbolicValues", "\[Rule]", 
                RowBox[{"CleanUpRules", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"Sequence", "[", "]"}]}], "}"}], "]"}], "]"}]}], 
               ",", 
               RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
               RowBox[{"SurfaceBoundaryFactor", "\[Rule]", 
                FractionBox["2001", "2000"]}], ",", 
               RowBox[{"ActiveRegion", "\[Rule]", "1"}], ",", 
               RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
            "]"}], ",", "0", ",", 
           RowBox[{"-", "90.`"}]}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"Refraction", "[", 
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"ComponentFoundation", "[", 
            RowBox[{"\[Infinity]", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "25.0125`"}], ",", 
                 RowBox[{"-", "0.00416666666666643`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "25.008333333333333`"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"25.0125`", ",", 
                 RowBox[{"-", "0.00416666666666643`"}]}], "}"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"SymbolicValues", "\[Rule]", 
                RowBox[{"CleanUpRules", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"Sequence", "[", "]"}]}], "}"}], "]"}], "]"}]}], 
               ",", 
               RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
               RowBox[{"SurfaceBoundaryFactor", "\[Rule]", 
                FractionBox["2001", "2000"]}], ",", 
               RowBox[{"ActiveRegion", "\[Rule]", "1"}], ",", 
               RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "25.`"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}], 
         "]"}], "]"}], ",", 
       RowBox[{"Refraction", "[", 
        RowBox[{"ComponentRendering", "[", 
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"ComponentFoundation", "[", 
            RowBox[{"\[Infinity]", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "25.0125`"}], ",", 
                 RowBox[{"-", "0.00416666666666643`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "25.008333333333333`"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"25.0125`", ",", 
                 RowBox[{"-", "0.00416666666666643`"}]}], "}"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"SymbolicValues", "\[Rule]", 
                RowBox[{"CleanUpRules", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"Sequence", "[", "]"}]}], "}"}], "]"}], "]"}]}], 
               ",", 
               RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
               RowBox[{"SurfaceBoundaryFactor", "\[Rule]", 
                FractionBox["2001", "2000"]}], ",", 
               RowBox[{"ActiveRegion", "\[Rule]", "1"}], ",", 
               RowBox[{"SurfaceLabel", "\[Rule]", "PlanarShape"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "25.`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "1.`"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1.`", ",", "0"}], "}"}]}], "}"}]}], "]"}], 
         "]"}], "]"}]}], "}"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404341452437*^9, 3.5634582355039597`*^9, 
  3.5644876905828457`*^9, 3.56610083214338*^9, 3.601301579609166*^9, 
  3.614709344604353*^9, 3.6147292026796713`*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[320]="]
}, Open  ]],

Cell[TextData[{
 "In the instance of ",
 StyleBox["Prism", "Input"],
 ", a new ",
 StyleBox["Refraction", "Input"],
 ", ",
 StyleBox["ComponentRendering", "Input"],
 ", and ",
 StyleBox["ComponentFoundation", "Input"],
 " function was used for every surface present. However, it also would have \
been possible to apply a single ",
 StyleBox["Refraction", "Input"],
 " and ",
 StyleBox["ComponentRendering", "Input"],
 " function to the list of surfaces (created by ",
 StyleBox["ComponentFoundation", "Input"],
 ") instead of repeating these at every surface. ",
 StyleBox["ComponentFoundation", "Input"],
 " function, on the other hand, can not create more than two surfaces at a \
time (and only if the two surfaces are in-line with each other). Otherwise, a \
separate ",
 StyleBox["ComponentFoundation", "Input"],
 " is required for every surface present. The following example illustrates \
this use of a single call to ",
 StyleBox["Refraction", "Input"],
 " and ",
 StyleBox["ComponentRendering", "Input"],
 "."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["\<\
strangeprism = 
\tResonate[Refraction[ComponentRendering[
\t\t{Move[ComponentFoundation[100,{50,50}],0,-45],
\t\tMove[ComponentFoundation[-100,{50,50}],{50,0},45],
\t\tMove[ComponentFoundation[100,{60,50}],{25,-35},90]}, 
\t\tGraphicDesign -> Wire, EdgeRendering -> Empty]]];

ShowSystem[strangeprism];\
\>", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[321]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-15.432311099154703`, -19.923027960172675`, 0.}, {
      65.4323110991547, -19.923027960172675`, 6.123233995736766*^-15}, {
      60.79610377896067, -12.774122260590914`, 
      5.102694996447306*^-15}, {-10.79610377896067, -12.774122260590914`, 
      0.}, {-15.432311099154703`, -19.923027960172675`, 0.}}], 
     Polygon3DBox[{{-10.79610377896067, -12.774122260590914`, 0.}, {
      60.79610377896067, -12.774122260590914`, 5.102694996447306*^-15}, {
      55.64660557993216, -6.138507439843636, 
      4.0821559971578446`*^-15}, {-5.646605579932157, -6.138507439843636, 
      0.}, {-10.79610377896067, -12.774122260590914`, 0.}}], 
     Polygon3DBox[{{-5.646605579932157, -6.138507439843636, 0.}, {
      55.64660557993216, -6.138507439843636, 4.0821559971578446`*^-15}, {50., 
      0., 3.061616997868384*^-15}, {0., 0., 
      0.}, {-5.646605579932157, -6.138507439843636, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {50., 0., 3.061616997868383*^-15}, {
      43.861492560156364`, 5.646605579932157, 2.0410779985789223`*^-15}, {
      6.138507439843636, 5.646605579932157, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{6.138507439843636, 5.646605579932157, 0.}, {
      43.861492560156364`, 5.646605579932157, 2.0410779985789223`*^-15}, {
      37.225877739409086`, 10.79610377896067, 1.0205389992894613`*^-15}, {
      12.774122260590914`, 10.79610377896067, 0.}, {6.138507439843636, 
      5.646605579932157, 0.}}], 
     Polygon3DBox[{{12.774122260590914`, 10.79610377896067, 0.}, {
      37.225877739409086`, 10.79610377896067, 1.0205389992894615`*^-15}, {
      30.076972039827325`, 15.432311099154703`, 5.098616525425841*^-31}, {
      19.92302796017266, 15.432311099154695`, 0.}, {12.774122260590914`, 
      10.79610377896067, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5QSnwYflfvgIVNWb/3G+MDDFAQsV321azpqgde
rD9wILJHEy7O8PDNUflpYgcc2j4+udIrgRDHAaDqHKD6HGDiDyDmOoRA7IGL
m0Dc4ZADcRdc/MThzoItwnYOBWjibFfO97+c4+QQgWaOxfnEZNd3rhj2QoAn
Gp+BQWHO3h+HL3k7oPvram77rmepfg4P0MLBT0Xnz6roAAcTtHDDFZ4ASvVp
uA==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.245358430508986, -2.245358430508986, -25.}, {
        47.754641569491014`, -2.245358430508986, -25.}, {
        49.01099075918488, -0.9890092408151219, -16.66666666666667}, {
        0.9890092408151219, -0.9890092408151219, -16.666666666666668`}, {
        2.245358430508986, -2.245358430508986, -25.}}], 
       Polygon3DBox[{{
        0.9890092408151219, -0.9890092408151219, -16.666666666666668`}, {
        49.01099075918488, -0.9890092408151219, -16.66666666666667}, {
        49.75404907004426, -0.24595092995573964`, -8.333333333333336}, {
        0.24595092995573964`, -0.24595092995573964`, -8.333333333333336}, {
        0.9890092408151219, -0.9890092408151219, -16.666666666666668`}}], 
       Polygon3DBox[{{
        0.24595092995573964`, -0.24595092995573964`, -8.333333333333336}, {
        49.75404907004426, -0.24595092995573964`, -8.333333333333336}, {50., 
        0., -7.105427357601002*^-15}, {0., 0., 0.}, {
        0.24595092995573964`, -0.24595092995573964`, -8.333333333333336}}], 
       Polygon3DBox[{{0., 0., 0.}, {50., 0., 0.}, {
        49.75404907004426, -0.24595092995573964`, 8.333333333333332}, {
        0.24595092995573964`, -0.24595092995573964`, 8.333333333333329}, {0., 
        0., 0.}}], 
       Polygon3DBox[{{0.24595092995573964`, -0.24595092995573964`, 
        8.333333333333329}, {49.75404907004426, -0.24595092995573964`, 
        8.333333333333332}, {49.01099075918488, -0.9890092408151219, 
        16.666666666666664`}, {0.9890092408151219, -0.9890092408151219, 
        16.666666666666664`}, {0.24595092995573964`, -0.24595092995573964`, 
        8.333333333333329}}], 
       Polygon3DBox[{{0.9890092408151219, -0.9890092408151219, 
        16.666666666666664`}, {49.01099075918488, -0.9890092408151219, 
        16.666666666666664`}, {47.754641569491014`, -2.245358430508986, 
        24.999999999999996`}, {2.245358430508986, -2.245358430508986, 
        24.999999999999993`}, {0.9890092408151219, -0.9890092408151219, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZYI1Zd943RAUofYAADywMNR8S3flv63h5K71+9
CgQMDjCEeH0IrD5vD6X3rwGLK0D1oYMPe9DVr4Cod0A3HyJu4IDunn//QcDC
wWGqn8SMB+7o7nR4t0BbNaPRwwHNnQ5rtvKva3ng4YDmTgeIPk8HNHfaoKuH
uvMAuvlQdx5Adw/UnQdwhScAIlSexg==
         "]], 
        {GrayLevel[0.5], EdgeForm[None], 
         Polygon3DBox[{{65.4323110991547, -19.923027960172675`, 0.}, {
          55., -30.393920141694565`, 7.34788079488412*^-15}, {
          45., -32.97958971132712, 6.123233995736766*^-15}, {
          60.79610377896067, -12.774122260590914`, 0.}, {
          65.4323110991547, -19.923027960172675`, 0.}}], 
         Polygon3DBox[{{60.79610377896067, -12.774122260590914`, 0.}, {
          45., -32.97958971132712, 6.123233995736766*^-15}, {
          35.00000000000001, -34.498743710662, 4.898587196589414*^-15}, {
          55.64660557993216, -6.138507439843636, 0.}, {
          60.79610377896067, -12.774122260590914`, 0.}}], 
         Polygon3DBox[{{55.64660557993216, -6.138507439843636, 0.}, {
          35.00000000000001, -34.498743710662, 4.898587196589414*^-15}, {
          25.000000000000007`, -35., 3.673940397442061*^-15}, {50., 0., 0.}, {
          55.64660557993216, -6.138507439843636, 0.}}], 
         Polygon3DBox[{{50., 0., 0.}, {25., -35., 3.67394039744206*^-15}, {
          15.000000000000004`, -34.498743710662, 2.449293598294707*^-15}, {
          43.861492560156364`, 5.646605579932157, 0.}, {50., 0., 0.}}], 
         Polygon3DBox[{{43.861492560156364`, 5.646605579932157, 0.}, {
          15.000000000000004`, -34.498743710662, 2.449293598294707*^-15}, {
          5.0000000000000036`, -32.97958971132712, 
          1.2246467991473537`*^-15}, {37.225877739409086`, 10.79610377896067, 
          0.}, {43.861492560156364`, 5.646605579932157, 0.}}], 
         Polygon3DBox[{{37.225877739409086`, 10.79610377896067, 0.}, {
          5.0000000000000036`, -32.97958971132712, 
          1.2246467991473537`*^-15}, {-4.9999999999999964`, \
-30.393920141694565`, 6.11833983051101*^-31}, {30.076972039827332`, 
          15.432311099154695`, 0.}, {37.225877739409086`, 10.79610377896067, 
          0.}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZT0fmzKjrAwcKmrN/7jfEBBii4ltu+61mqn8OL
9QcORPZowsUV5uz9cfiSt4ND28cnV3ol4OIQ4OnAgAYszicmu75zdWB4+Oao
/DQxuDz7lfP9L+c4OYRsl301a7oqXPzU4c6CLcJ2DjlKiQ/D7+qhmSdyIOKC
7+frKXZo9oo4fLkkZpRc64AmrufQZFB99Zq9I5q4JcTcBjTxBkfs6hvcsJvf
4O2A7h5c4QkAqExYxw==
           "]], 
          {GrayLevel[0.5], EdgeForm[None], 
           Polygon3DBox[{{47.754641569491014`, -2.245358430508986, -25.}, {
            24.999999999999996`, -31.82458365518542, -25.}, {
            24.999999999999996`, -33.60132971832694, -16.66666666666667}, {
            49.01099075918488, -0.9890092408151219, -16.666666666666668`}, {
            47.754641569491014`, -2.245358430508986, -25.}}], 
           Polygon3DBox[{{
            49.01099075918488, -0.9890092408151219, -16.666666666666668`}, {
            24.999999999999996`, -33.60132971832694, -16.66666666666667}, {
            24.999999999999996`, -34.65217285917831, -8.333333333333336}, {
            49.75404907004426, -0.24595092995573964`, -8.333333333333336}, {
            49.01099075918488, -0.9890092408151219, -16.666666666666668`}}], 
           Polygon3DBox[{{
            49.75404907004426, -0.24595092995573964`, -8.333333333333336}, {
            24.999999999999996`, -34.65217285917831, -8.333333333333336}, {
            25., -35., -7.105427357601002*^-15}, {50., 0., 0.}, {
            49.75404907004426, -0.24595092995573964`, -8.333333333333336}}], 
           Polygon3DBox[{{50., 0., 0.}, {25., -35., 0.}, {
            25., -34.65217285917831, 8.333333333333332}, {
            49.75404907004426, -0.24595092995573964`, 8.333333333333329}, {
            50., 0., 0.}}], 
           Polygon3DBox[{{49.75404907004426, -0.24595092995573964`, 
            8.333333333333329}, {25., -34.65217285917831, 
            8.333333333333332}, {25., -33.60132971832694, 
            16.666666666666664`}, {49.01099075918488, -0.9890092408151219, 
            16.666666666666664`}, {49.75404907004426, -0.24595092995573964`, 
            8.333333333333329}}], 
           Polygon3DBox[{{49.01099075918488, -0.9890092408151219, 
            16.666666666666664`}, {25., -33.60132971832694, 
            16.666666666666664`}, {25., -31.82458365518542, 
            24.999999999999996`}, {47.754641569491014`, -2.245358430508986, 
            24.999999999999993`}, {49.01099075918488, -0.9890092408151219, 
            16.666666666666664`}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaY6icx44G7A8Maseq6b4wHGMDA8sC7BdqqGY0e
Dg1HxLd+W/p+/+pVIGBwYM1W/nUtDzwcGEK8PgRWn9+/BiyuANXn6cCAAj7s
QVe/AqLeAd18iLiBA7p7/v0HAQuouZYOGdfEX4lftoe5Ey5+T9Mz/scZhwNQ
d8LFbQ6WpVUFOx6AutMBRV+DI9ScDzbo6leg+AthPtSdcHGYe6DuPIArPAFI
YYyW
             "]]}}}}}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-13.110774187623704`, -22.244564871703673`, -25.}, \
{-8.517826802115394, -15.052399237436191`, -25.}, {-9.79286199474872, \
-13.777364044802866`, -16.666666666666664`}, {-14.41038331200329, \
-20.944955747324087`, -16.666666666666664`}, {-13.110774187623704`, \
-22.244564871703673`, -25.}}], 
      Line3DBox[{{-14.41038331200329, -20.944955747324087`, \
-16.666666666666664`}, {-9.79286199474872, -13.777364044802866`, \
-16.666666666666664`}, {-10.54665157000882, -13.023574469542766`, \
-8.33333333333333}, {-15.178264509946032`, -20.177074549381345`, \
-8.33333333333333}, {-14.41038331200329, -20.944955747324087`, \
-16.666666666666664`}}], 
      Line3DBox[{{-15.178264509946032`, -20.177074549381345`, \
-8.333333333333332}, {-10.54665157000882, -13.023574469542766`, \
-8.333333333333332}, {-10.79610377896067, -12.774122260590914`, 
       1.7763568394002505`*^-15}, {-15.432311099154703`, -19.923027960172675`,
        1.7763568394002505`*^-15}, {-15.178264509946032`, \
-20.177074549381345`, -8.333333333333332}}], 
      Line3DBox[{{-15.432311099154703`, -19.923027960172675`, 
       0.}, {-10.79610377896067, -12.774122260590914`, 
       0.}, {-10.54665157000882, -13.023574469542766`, 
       8.333333333333334}, {-15.178264509946032`, -20.177074549381345`, 
       8.333333333333334}, {-15.432311099154703`, -19.923027960172675`, 0.}}],
       Line3DBox[{{-15.178264509946032`, -20.177074549381345`, 
       8.333333333333336}, {-10.54665157000882, -13.023574469542766`, 
       8.333333333333336}, {-9.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {-14.41038331200329, -20.944955747324087`, 
       16.66666666666667}, {-15.178264509946032`, -20.177074549381345`, 
       8.333333333333336}}], 
      Line3DBox[{{-14.41038331200329, -20.944955747324087`, 
       16.66666666666667}, {-9.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {-8.517826802115394, -15.052399237436191`, 
       25.000000000000007`}, {-13.110774187623704`, -22.244564871703673`, 
       25.000000000000007`}, {-14.41038331200329, -20.944955747324087`, 
       16.66666666666667}}], 
      Line3DBox[{{-8.517826802115394, -15.052399237436191`, -25.}, \
{-3.39315149017024, -8.391961529605553, -25.}, {-4.654095060120923, \
-7.131017959654869, -16.666666666666664`}, {-9.79286199474872, \
-13.777364044802866`, -16.666666666666664`}, {-8.517826802115394, \
-15.052399237436191`, -25.}}], 
      Line3DBox[{{-9.79286199474872, -13.777364044802866`, \
-16.666666666666664`}, {-4.654095060120923, -7.131017959654869, \
-16.666666666666664`}, {-5.399793167702796, -6.385319852072996, \
-8.33333333333333}, {-10.54665157000882, -13.023574469542766`, \
-8.33333333333333}, {-9.79286199474872, -13.777364044802866`, \
-16.666666666666664`}}], 
      Line3DBox[{{-10.54665157000882, -13.023574469542766`, \
-8.333333333333332}, {-5.399793167702796, -6.385319852072996, \
-8.333333333333332}, {-5.646605579932157, -6.138507439843636, 
       1.7763568394002505`*^-15}, {-10.79610377896067, -12.774122260590914`, 
       1.7763568394002505`*^-15}, {-10.54665157000882, -13.023574469542766`, \
-8.333333333333332}}], 
      Line3DBox[{{-10.79610377896067, -12.774122260590914`, 
       0.}, {-5.646605579932157, -6.138507439843636, 
       0.}, {-5.399793167702796, -6.385319852072996, 
       8.333333333333334}, {-10.54665157000882, -13.023574469542766`, 
       8.333333333333334}, {-10.79610377896067, -12.774122260590914`, 0.}}], 
      Line3DBox[{{-10.54665157000882, -13.023574469542766`, 
       8.333333333333336}, {-5.399793167702796, -6.385319852072996, 
       8.333333333333336}, {-4.654095060120923, -7.131017959654869, 
       16.66666666666667}, {-9.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {-10.54665157000882, -13.023574469542766`, 
       8.333333333333336}}], 
      Line3DBox[{{-9.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {-4.654095060120923, -7.131017959654869, 
       16.66666666666667}, {-3.39315149017024, -8.391961529605553, 
       25.000000000000007`}, {-8.517826802115394, -15.052399237436191`, 
       25.000000000000007`}, {-9.79286199474872, -13.777364044802866`, 
       16.66666666666667}}], 
      Line3DBox[{{-3.39315149017024, -8.391961529605553, -25.}, {
       2.245358430508986, -2.245358430508986, -25.}, {
       0.9890092408151219, -0.9890092408151219, -16.666666666666664`}, \
{-4.654095060120923, -7.131017959654869, -16.666666666666664`}, \
{-3.39315149017024, -8.391961529605553, -25.}}], 
      Line3DBox[{{-4.654095060120923, -7.131017959654869, \
-16.666666666666664`}, {
       0.9890092408151219, -0.9890092408151219, -16.666666666666664`}, {
       0.24595092995573964`, -0.24595092995573964`, -8.33333333333333}, \
{-5.399793167702796, -6.385319852072996, -8.33333333333333}, \
{-4.654095060120923, -7.131017959654869, -16.666666666666664`}}], 
      Line3DBox[{{-5.399793167702796, -6.385319852072996, \
-8.333333333333332}, {
       0.24595092995573964`, -0.24595092995573964`, -8.333333333333332}, {0., 
       0., 1.7763568394002505`*^-15}, {-5.646605579932157, -6.138507439843636,
        1.7763568394002505`*^-15}, {-5.399793167702796, -6.385319852072996, \
-8.333333333333332}}], 
      Line3DBox[{{-5.646605579932157, -6.138507439843636, 0.}, {0., 0., 0.}, {
       0.24595092995573964`, -0.24595092995573964`, 
       8.333333333333334}, {-5.399793167702796, -6.385319852072996, 
       8.333333333333334}, {-5.646605579932157, -6.138507439843636, 0.}}], 
      Line3DBox[{{-5.399793167702796, -6.385319852072996, 
       8.333333333333336}, {0.24595092995573964`, -0.24595092995573964`, 
       8.333333333333336}, {0.9890092408151219, -0.9890092408151219, 
       16.66666666666667}, {-4.654095060120923, -7.131017959654869, 
       16.66666666666667}, {-5.399793167702796, -6.385319852072996, 
       8.333333333333336}}], 
      Line3DBox[{{-4.654095060120923, -7.131017959654869, 
       16.66666666666667}, {0.9890092408151219, -0.9890092408151219, 
       16.66666666666667}, {2.245358430508986, -2.245358430508986, 
       25.000000000000007`}, {-3.39315149017024, -8.391961529605553, 
       25.000000000000007`}, {-4.654095060120923, -7.131017959654869, 
       16.66666666666667}}], 
      Line3DBox[{{2.245358430508986, -2.245358430508986, -25.}, {
       8.391961529605553, 3.39315149017024, -25.}, {7.131017959654869, 
       4.654095060120923, -16.666666666666664`}, {
       0.9890092408151219, -0.9890092408151219, -16.666666666666664`}, {
       2.245358430508986, -2.245358430508986, -25.}}], 
      Line3DBox[{{
       0.9890092408151219, -0.9890092408151219, -16.666666666666664`}, {
       7.131017959654869, 4.654095060120923, -16.666666666666664`}, {
       6.385319852072996, 5.399793167702796, -8.33333333333333}, {
       0.24595092995573964`, -0.24595092995573964`, -8.33333333333333}, {
       0.9890092408151219, -0.9890092408151219, -16.666666666666664`}}], 
      Line3DBox[{{
       0.24595092995573964`, -0.24595092995573964`, -8.333333333333332}, {
       6.385319852072996, 5.399793167702796, -8.333333333333332}, {
       6.138507439843636, 5.646605579932157, 1.7763568394002505`*^-15}, {0., 
       0., 1.7763568394002505`*^-15}, {
       0.24595092995573964`, -0.24595092995573964`, -8.333333333333332}}], 
      Line3DBox[{{0., 0., 0.}, {6.138507439843636, 5.646605579932157, 0.}, {
       6.385319852072996, 5.399793167702796, 8.333333333333334}, {
       0.24595092995573964`, -0.24595092995573964`, 8.333333333333334}, {0., 
       0., 0.}}], 
      Line3DBox[{{0.24595092995573964`, -0.24595092995573964`, 
       8.333333333333336}, {6.385319852072996, 5.399793167702796, 
       8.333333333333336}, {7.131017959654869, 4.654095060120923, 
       16.66666666666667}, {0.9890092408151219, -0.9890092408151219, 
       16.66666666666667}, {0.24595092995573964`, -0.24595092995573964`, 
       8.333333333333336}}], 
      Line3DBox[{{0.9890092408151219, -0.9890092408151219, 
       16.66666666666667}, {7.131017959654869, 4.654095060120923, 
       16.66666666666667}, {8.391961529605553, 3.39315149017024, 
       25.000000000000007`}, {2.245358430508986, -2.245358430508986, 
       25.000000000000007`}, {0.9890092408151219, -0.9890092408151219, 
       16.66666666666667}}], 
      Line3DBox[{{8.391961529605553, 3.39315149017024, -25.}, {
       15.052399237436191`, 8.517826802115394, -25.}, {13.777364044802866`, 
       9.79286199474872, -16.666666666666664`}, {7.131017959654869, 
       4.654095060120923, -16.666666666666664`}, {8.391961529605553, 
       3.39315149017024, -25.}}], 
      Line3DBox[{{7.131017959654869, 
       4.654095060120923, -16.666666666666664`}, {13.777364044802866`, 
       9.79286199474872, -16.666666666666664`}, {13.023574469542766`, 
       10.54665157000882, -8.33333333333333}, {6.385319852072996, 
       5.399793167702796, -8.33333333333333}, {7.131017959654869, 
       4.654095060120923, -16.666666666666664`}}], 
      Line3DBox[{{6.385319852072996, 5.399793167702796, -8.333333333333332}, {
       13.023574469542766`, 10.54665157000882, -8.333333333333332}, {
       12.774122260590914`, 10.79610377896067, 1.7763568394002505`*^-15}, {
       6.138507439843636, 5.646605579932157, 1.7763568394002505`*^-15}, {
       6.385319852072996, 5.399793167702796, -8.333333333333332}}], 
      Line3DBox[{{6.138507439843636, 5.646605579932157, 0.}, {
       12.774122260590914`, 10.79610377896067, 0.}, {13.023574469542766`, 
       10.54665157000882, 8.333333333333334}, {6.385319852072996, 
       5.399793167702796, 8.333333333333334}, {6.138507439843636, 
       5.646605579932157, 0.}}], 
      Line3DBox[{{6.385319852072996, 5.399793167702796, 8.333333333333336}, {
       13.023574469542766`, 10.54665157000882, 8.333333333333336}, {
       13.777364044802866`, 9.79286199474872, 16.66666666666667}, {
       7.131017959654869, 4.654095060120923, 16.66666666666667}, {
       6.385319852072996, 5.399793167702796, 8.333333333333336}}], 
      Line3DBox[{{7.131017959654869, 4.654095060120923, 16.66666666666667}, {
       13.777364044802866`, 9.79286199474872, 16.66666666666667}, {
       15.052399237436191`, 8.517826802115394, 25.000000000000007`}, {
       8.391961529605553, 3.39315149017024, 25.000000000000007`}, {
       7.131017959654869, 4.654095060120923, 16.66666666666667}}], 
      Line3DBox[{{15.052399237436191`, 8.517826802115394, -25.}, {
       22.244564871703673`, 13.110774187623704`, -25.}, {20.944955747324087`, 
       14.41038331200329, -16.666666666666664`}, {13.777364044802866`, 
       9.79286199474872, -16.666666666666664`}, {15.052399237436191`, 
       8.517826802115394, -25.}}], 
      Line3DBox[{{13.777364044802866`, 
       9.79286199474872, -16.666666666666664`}, {20.944955747324087`, 
       14.41038331200329, -16.666666666666664`}, {20.177074549381345`, 
       15.178264509946032`, -8.33333333333333}, {13.023574469542766`, 
       10.54665157000882, -8.33333333333333}, {13.777364044802866`, 
       9.79286199474872, -16.666666666666664`}}], 
      Line3DBox[{{13.023574469542766`, 
       10.54665157000882, -8.333333333333332}, {20.177074549381345`, 
       15.178264509946032`, -8.333333333333332}, {19.923027960172675`, 
       15.432311099154703`, 1.7763568394002505`*^-15}, {12.774122260590914`, 
       10.79610377896067, 1.7763568394002505`*^-15}, {13.023574469542766`, 
       10.54665157000882, -8.333333333333332}}], 
      Line3DBox[{{12.774122260590914`, 10.79610377896067, 0.}, {
       19.923027960172675`, 15.432311099154703`, 0.}, {20.177074549381345`, 
       15.178264509946032`, 8.333333333333334}, {13.023574469542766`, 
       10.54665157000882, 8.333333333333334}, {12.774122260590914`, 
       10.79610377896067, 0.}}], 
      Line3DBox[{{13.023574469542766`, 10.54665157000882, 
       8.333333333333336}, {20.177074549381345`, 15.178264509946032`, 
       8.333333333333336}, {20.944955747324087`, 14.41038331200329, 
       16.66666666666667}, {13.777364044802866`, 9.79286199474872, 
       16.66666666666667}, {13.023574469542766`, 10.54665157000882, 
       8.333333333333336}}], 
      Line3DBox[{{13.777364044802866`, 9.79286199474872, 16.66666666666667}, {
       20.944955747324087`, 14.41038331200329, 16.66666666666667}, {
       22.244564871703673`, 13.110774187623704`, 25.000000000000007`}, {
       15.052399237436191`, 8.517826802115394, 25.000000000000007`}, {
       13.777364044802866`, 9.79286199474872, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{63.110774187623704`, -22.244564871703673`, -25.}, {
       58.517826802115394`, -15.052399237436191`, -25.}, {
       59.79286199474872, -13.777364044802866`, -16.666666666666664`}, {
       64.41038331200329, -20.944955747324087`, -16.666666666666664`}, {
       63.110774187623704`, -22.244564871703673`, -25.}}], 
      Line3DBox[{{
       64.41038331200329, -20.944955747324087`, -16.666666666666664`}, {
       59.79286199474872, -13.777364044802866`, -16.666666666666664`}, {
       60.54665157000882, -13.023574469542766`, -8.33333333333333}, {
       65.17826450994603, -20.177074549381345`, -8.33333333333333}, {
       64.41038331200329, -20.944955747324087`, -16.666666666666664`}}], 
      Line3DBox[{{
       65.17826450994603, -20.177074549381345`, -8.333333333333332}, {
       60.54665157000882, -13.023574469542766`, -8.333333333333332}, {
       60.79610377896067, -12.774122260590914`, 1.7763568394002505`*^-15}, {
       65.4323110991547, -19.923027960172675`, 1.7763568394002505`*^-15}, {
       65.17826450994603, -20.177074549381345`, -8.333333333333332}}], 
      Line3DBox[{{65.4323110991547, -19.923027960172675`, 0.}, {
       60.79610377896067, -12.774122260590914`, 0.}, {
       60.54665157000882, -13.023574469542766`, 8.333333333333334}, {
       65.17826450994603, -20.177074549381345`, 8.333333333333334}, {
       65.4323110991547, -19.923027960172675`, 0.}}], 
      Line3DBox[{{65.17826450994603, -20.177074549381345`, 
       8.333333333333336}, {60.54665157000882, -13.023574469542766`, 
       8.333333333333336}, {59.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {64.41038331200329, -20.944955747324087`, 
       16.66666666666667}, {65.17826450994603, -20.177074549381345`, 
       8.333333333333336}}], 
      Line3DBox[{{64.41038331200329, -20.944955747324087`, 
       16.66666666666667}, {59.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {58.517826802115394`, -15.052399237436191`, 
       25.000000000000007`}, {63.110774187623704`, -22.244564871703673`, 
       25.000000000000007`}, {64.41038331200329, -20.944955747324087`, 
       16.66666666666667}}], 
      Line3DBox[{{58.517826802115394`, -15.052399237436191`, -25.}, {
       53.39315149017024, -8.391961529605553, -25.}, {
       54.65409506012092, -7.131017959654869, -16.666666666666664`}, {
       59.79286199474872, -13.777364044802866`, -16.666666666666664`}, {
       58.517826802115394`, -15.052399237436191`, -25.}}], 
      Line3DBox[{{
       59.79286199474872, -13.777364044802866`, -16.666666666666664`}, {
       54.65409506012092, -7.131017959654869, -16.666666666666664`}, {
       55.399793167702796`, -6.385319852072996, -8.33333333333333}, {
       60.54665157000882, -13.023574469542766`, -8.33333333333333}, {
       59.79286199474872, -13.777364044802866`, -16.666666666666664`}}], 
      Line3DBox[{{
       60.54665157000882, -13.023574469542766`, -8.333333333333332}, {
       55.399793167702796`, -6.385319852072996, -8.333333333333332}, {
       55.64660557993216, -6.138507439843636, 1.7763568394002505`*^-15}, {
       60.79610377896067, -12.774122260590914`, 1.7763568394002505`*^-15}, {
       60.54665157000882, -13.023574469542766`, -8.333333333333332}}], 
      Line3DBox[{{60.79610377896067, -12.774122260590914`, 0.}, {
       55.64660557993216, -6.138507439843636, 0.}, {
       55.399793167702796`, -6.385319852072996, 8.333333333333334}, {
       60.54665157000882, -13.023574469542766`, 8.333333333333334}, {
       60.79610377896067, -12.774122260590914`, 0.}}], 
      Line3DBox[{{60.54665157000882, -13.023574469542766`, 
       8.333333333333336}, {55.399793167702796`, -6.385319852072996, 
       8.333333333333336}, {54.65409506012092, -7.131017959654869, 
       16.66666666666667}, {59.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {60.54665157000882, -13.023574469542766`, 
       8.333333333333336}}], 
      Line3DBox[{{59.79286199474872, -13.777364044802866`, 
       16.66666666666667}, {54.65409506012092, -7.131017959654869, 
       16.66666666666667}, {53.39315149017024, -8.391961529605553, 
       25.000000000000007`}, {58.517826802115394`, -15.052399237436191`, 
       25.000000000000007`}, {59.79286199474872, -13.777364044802866`, 
       16.66666666666667}}], 
      Line3DBox[{{53.39315149017024, -8.391961529605553, -25.}, {
       47.754641569491014`, -2.245358430508986, -25.}, {
       49.01099075918488, -0.9890092408151219, -16.666666666666664`}, {
       54.65409506012092, -7.131017959654869, -16.666666666666664`}, {
       53.39315149017024, -8.391961529605553, -25.}}], 
      Line3DBox[{{
       54.65409506012092, -7.131017959654869, -16.666666666666664`}, {
       49.01099075918488, -0.9890092408151219, -16.666666666666664`}, {
       49.75404907004426, -0.24595092995573964`, -8.33333333333333}, {
       55.399793167702796`, -6.385319852072996, -8.33333333333333}, {
       54.65409506012092, -7.131017959654869, -16.666666666666664`}}], 
      Line3DBox[{{
       55.399793167702796`, -6.385319852072996, -8.333333333333332}, {
       49.75404907004426, -0.24595092995573964`, -8.333333333333332}, {50., 
       0., 1.7763568394002505`*^-15}, {55.64660557993216, -6.138507439843636, 
       1.7763568394002505`*^-15}, {
       55.399793167702796`, -6.385319852072996, -8.333333333333332}}], 
      Line3DBox[{{55.64660557993216, -6.138507439843636, 0.}, {50., 0., 0.}, {
       49.75404907004426, -0.24595092995573964`, 8.333333333333334}, {
       55.399793167702796`, -6.385319852072996, 8.333333333333334}, {
       55.64660557993216, -6.138507439843636, 0.}}], 
      Line3DBox[{{55.399793167702796`, -6.385319852072996, 
       8.333333333333336}, {49.75404907004426, -0.24595092995573964`, 
       8.333333333333336}, {49.01099075918488, -0.9890092408151219, 
       16.66666666666667}, {54.65409506012092, -7.131017959654869, 
       16.66666666666667}, {55.399793167702796`, -6.385319852072996, 
       8.333333333333336}}], 
      Line3DBox[{{54.65409506012092, -7.131017959654869, 16.66666666666667}, {
       49.01099075918488, -0.9890092408151219, 16.66666666666667}, {
       47.754641569491014`, -2.245358430508986, 25.000000000000007`}, {
       53.39315149017024, -8.391961529605553, 25.000000000000007`}, {
       54.65409506012092, -7.131017959654869, 16.66666666666667}}], 
      Line3DBox[{{47.754641569491014`, -2.245358430508986, -25.}, {
       41.60803847039445, 3.39315149017024, -25.}, {42.86898204034513, 
       4.654095060120923, -16.666666666666664`}, {
       49.01099075918488, -0.9890092408151219, -16.666666666666664`}, {
       47.754641569491014`, -2.245358430508986, -25.}}], 
      Line3DBox[{{
       49.01099075918488, -0.9890092408151219, -16.666666666666664`}, {
       42.86898204034513, 4.654095060120923, -16.666666666666664`}, {
       43.614680147927004`, 5.399793167702796, -8.33333333333333}, {
       49.75404907004426, -0.24595092995573964`, -8.33333333333333}, {
       49.01099075918488, -0.9890092408151219, -16.666666666666664`}}], 
      Line3DBox[{{
       49.75404907004426, -0.24595092995573964`, -8.333333333333332}, {
       43.614680147927004`, 5.399793167702796, -8.333333333333332}, {
       43.861492560156364`, 5.646605579932157, 1.7763568394002505`*^-15}, {
       50., 0., 1.7763568394002505`*^-15}, {
       49.75404907004426, -0.24595092995573964`, -8.333333333333332}}], 
      Line3DBox[{{50., 0., 0.}, {43.861492560156364`, 5.646605579932157, 
       0.}, {43.614680147927004`, 5.399793167702796, 8.333333333333334}, {
       49.75404907004426, -0.24595092995573964`, 8.333333333333334}, {50., 0.,
        0.}}], Line3DBox[{{49.75404907004426, -0.24595092995573964`, 
       8.333333333333336}, {43.614680147927004`, 5.399793167702796, 
       8.333333333333336}, {42.86898204034513, 4.654095060120923, 
       16.66666666666667}, {49.01099075918488, -0.9890092408151219, 
       16.66666666666667}, {49.75404907004426, -0.24595092995573964`, 
       8.333333333333336}}], 
      Line3DBox[{{49.01099075918488, -0.9890092408151219, 
       16.66666666666667}, {42.86898204034513, 4.654095060120923, 
       16.66666666666667}, {41.60803847039445, 3.39315149017024, 
       25.000000000000007`}, {47.754641569491014`, -2.245358430508986, 
       25.000000000000007`}, {49.01099075918488, -0.9890092408151219, 
       16.66666666666667}}], 
      Line3DBox[{{41.60803847039445, 3.39315149017024, -25.}, {
       34.94760076256381, 8.517826802115394, -25.}, {36.222635955197134`, 
       9.79286199474872, -16.666666666666664`}, {42.86898204034513, 
       4.654095060120923, -16.666666666666664`}, {41.60803847039445, 
       3.39315149017024, -25.}}], 
      Line3DBox[{{42.86898204034513, 
       4.654095060120923, -16.666666666666664`}, {36.222635955197134`, 
       9.79286199474872, -16.666666666666664`}, {36.976425530457234`, 
       10.54665157000882, -8.33333333333333}, {43.614680147927004`, 
       5.399793167702796, -8.33333333333333}, {42.86898204034513, 
       4.654095060120923, -16.666666666666664`}}], 
      Line3DBox[{{43.614680147927004`, 
       5.399793167702796, -8.333333333333332}, {36.976425530457234`, 
       10.54665157000882, -8.333333333333332}, {37.225877739409086`, 
       10.79610377896067, 1.7763568394002505`*^-15}, {43.861492560156364`, 
       5.646605579932157, 1.7763568394002505`*^-15}, {43.614680147927004`, 
       5.399793167702796, -8.333333333333332}}], 
      Line3DBox[{{43.861492560156364`, 5.646605579932157, 0.}, {
       37.225877739409086`, 10.79610377896067, 0.}, {36.976425530457234`, 
       10.54665157000882, 8.333333333333334}, {43.614680147927004`, 
       5.399793167702796, 8.333333333333334}, {43.861492560156364`, 
       5.646605579932157, 0.}}], 
      Line3DBox[{{43.614680147927004`, 5.399793167702796, 
       8.333333333333336}, {36.976425530457234`, 10.54665157000882, 
       8.333333333333336}, {36.222635955197134`, 9.79286199474872, 
       16.66666666666667}, {42.86898204034513, 4.654095060120923, 
       16.66666666666667}, {43.614680147927004`, 5.399793167702796, 
       8.333333333333336}}], 
      Line3DBox[{{42.86898204034513, 4.654095060120923, 16.66666666666667}, {
       36.222635955197134`, 9.79286199474872, 16.66666666666667}, {
       34.94760076256381, 8.517826802115394, 25.000000000000007`}, {
       41.60803847039445, 3.39315149017024, 25.000000000000007`}, {
       42.86898204034513, 4.654095060120923, 16.66666666666667}}], 
      Line3DBox[{{34.94760076256381, 8.517826802115394, -25.}, {
       27.755435128296327`, 13.110774187623704`, -25.}, {29.055044252675913`, 
       14.41038331200329, -16.666666666666664`}, {36.222635955197134`, 
       9.79286199474872, -16.666666666666664`}, {34.94760076256381, 
       8.517826802115394, -25.}}], 
      Line3DBox[{{36.222635955197134`, 
       9.79286199474872, -16.666666666666664`}, {29.055044252675913`, 
       14.41038331200329, -16.666666666666664`}, {29.822925450618655`, 
       15.178264509946032`, -8.33333333333333}, {36.976425530457234`, 
       10.54665157000882, -8.33333333333333}, {36.222635955197134`, 
       9.79286199474872, -16.666666666666664`}}], 
      Line3DBox[{{36.976425530457234`, 
       10.54665157000882, -8.333333333333332}, {29.822925450618655`, 
       15.178264509946032`, -8.333333333333332}, {30.076972039827325`, 
       15.432311099154703`, 1.7763568394002505`*^-15}, {37.225877739409086`, 
       10.79610377896067, 1.7763568394002505`*^-15}, {36.976425530457234`, 
       10.54665157000882, -8.333333333333332}}], 
      Line3DBox[{{37.225877739409086`, 10.79610377896067, 0.}, {
       30.076972039827325`, 15.432311099154703`, 0.}, {29.822925450618655`, 
       15.178264509946032`, 8.333333333333334}, {36.976425530457234`, 
       10.54665157000882, 8.333333333333334}, {37.225877739409086`, 
       10.79610377896067, 0.}}], 
      Line3DBox[{{36.976425530457234`, 10.54665157000882, 
       8.333333333333336}, {29.822925450618655`, 15.178264509946032`, 
       8.333333333333336}, {29.055044252675913`, 14.41038331200329, 
       16.66666666666667}, {36.222635955197134`, 9.79286199474872, 
       16.66666666666667}, {36.976425530457234`, 10.54665157000882, 
       8.333333333333336}}], 
      Line3DBox[{{36.222635955197134`, 9.79286199474872, 16.66666666666667}, {
       29.055044252675913`, 14.41038331200329, 16.66666666666667}, {
       27.755435128296327`, 13.110774187623704`, 25.000000000000007`}, {
       34.94760076256381, 8.517826802115394, 25.000000000000007`}, {
       36.222635955197134`, 9.79286199474872, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{54.85, -27.14234572117209, -24.875}, {
       44.900000000000006`, -29.790423435070693`, -24.875}, {
       44.900000000000006`, -31.586660857260995`, -16.583333333333336`}, {
       54.85, -28.989204462829434`, -16.583333333333336`}, {
       54.85, -27.14234572117209, -24.875}}], 
      Line3DBox[{{54.85, -28.989204462829434`, -16.583333333333336`}, {
       44.900000000000006`, -31.586660857260995`, -16.583333333333336`}, {
       44.900000000000006`, -32.64854460712094, -8.29166666666667}, {
       54.85, -30.08010182939904, -8.29166666666667}, {
       54.85, -28.989204462829434`, -16.583333333333336`}}], 
      Line3DBox[{{54.85, -30.08010182939904, -8.291666666666668}, {
       44.900000000000006`, -32.64854460712094, -8.291666666666668}, {
       44.900000000000006`, -32.99994897957855, -1.7763568394002505`*^-15}, {
       54.85, -30.44096342766035, -1.7763568394002505`*^-15}, {
       54.85, -30.08010182939904, -8.291666666666668}}], 
      Line3DBox[{{54.85, -30.44096342766035, 0.}, {
       44.900000000000006`, -32.99994897957855, 0.}, {
       44.900000000000006`, -32.64854460712094, 8.291666666666666}, {
       54.85, -30.08010182939904, 8.291666666666666}, {
       54.85, -30.44096342766035, 0.}}], 
      Line3DBox[{{54.85, -30.08010182939904, 8.291666666666664}, {
       44.900000000000006`, -32.64854460712094, 8.291666666666664}, {
       44.900000000000006`, -31.58666085726101, 16.58333333333333}, {
       54.85, -28.989204462829434`, 16.58333333333333}, {
       54.85, -30.08010182939904, 8.291666666666664}}], 
      Line3DBox[{{54.85, -28.989204462829434`, 16.58333333333333}, {
       44.900000000000006`, -31.58666085726101, 16.58333333333333}, {
       44.900000000000006`, -29.790423435070693`, 24.874999999999993`}, {
       54.85, -27.14234572117209, 24.874999999999993`}, {
       54.85, -28.989204462829434`, 16.58333333333333}}], 
      Line3DBox[{{44.900000000000006`, -29.790423435070693`, -24.875}, {
       34.95, -31.344340129558205`, -24.875}, {
       34.95, -33.11213256043085, -16.583333333333336`}, {
       44.900000000000006`, -31.586660857260995`, -16.583333333333336`}, {
       44.900000000000006`, -29.790423435070693`, -24.875}}], 
      Line3DBox[{{
       44.900000000000006`, -31.586660857260995`, -16.583333333333336`}, {
       34.95, -33.11213256043085, -16.583333333333336`}, {
       34.95, -34.15768131561411, -8.29166666666667}, {
       44.900000000000006`, -32.64854460712094, -8.29166666666667}, {
       44.900000000000006`, -31.586660857260995`, -16.583333333333336`}}], 
      Line3DBox[{{
       44.900000000000006`, -32.64854460712094, -8.291666666666668}, {
       34.95, -34.15768131561411, -8.291666666666668}, {
       34.95, -34.50375621050695, -1.7763568394002505`*^-15}, {
       44.900000000000006`, -32.99994897957855, -1.7763568394002505`*^-15}, {
       44.900000000000006`, -32.64854460712094, -8.291666666666668}}], 
      Line3DBox[{{44.900000000000006`, -32.99994897957855, 0.}, {
       34.95, -34.50375621050695, 0.}, {34.95, -34.15768131561411, 
       8.291666666666666}, {44.900000000000006`, -32.64854460712094, 
       8.291666666666666}, {44.900000000000006`, -32.99994897957855, 0.}}], 
      Line3DBox[{{44.900000000000006`, -32.64854460712094, 
       8.291666666666664}, {34.95, -34.15768131561411, 8.291666666666664}, {
       34.95, -33.11213256043085, 16.58333333333333}, {
       44.900000000000006`, -31.58666085726101, 16.58333333333333}, {
       44.900000000000006`, -32.64854460712094, 8.291666666666664}}], 
      Line3DBox[{{44.900000000000006`, -31.58666085726101, 
       16.58333333333333}, {34.95, -33.11213256043085, 16.58333333333333}, {
       34.95, -31.344340129558205`, 24.874999999999993`}, {
       44.900000000000006`, -29.790423435070693`, 24.874999999999993`}, {
       44.900000000000006`, -31.58666085726101, 16.58333333333333}}], 
      Line3DBox[{{34.95, -31.344340129558205`, -24.875}, {
       25.000000000000004`, -31.856772478748226`, -24.875}, {
       25.000000000000004`, -33.615379406842806`, -16.583333333333336`}, {
       34.95, -33.11213256043085, -16.583333333333336`}, {
       34.95, -31.344340129558205`, -24.875}}], 
      Line3DBox[{{34.95, -33.11213256043085, -16.583333333333336`}, {
       25.000000000000004`, -33.615379406842806`, -16.583333333333336`}, {
       25.000000000000004`, -34.65564842942365, -8.29166666666667}, {
       34.95, -34.15768131561411, -8.29166666666667}, {
       34.95, -33.11213256043085, -16.583333333333336`}}], 
      Line3DBox[{{34.95, -34.15768131561411, -8.291666666666668}, {
       25.000000000000004`, -34.65564842942365, -8.291666666666668}, {
       25.000000000000004`, -35., -1.7763568394002505`*^-15}, {
       34.95, -34.50375621050695, -1.7763568394002505`*^-15}, {
       34.95, -34.15768131561411, -8.291666666666668}}], 
      Line3DBox[{{34.95, -34.50375621050695, 0.}, {25.000000000000004`, -35., 
       0.}, {25.000000000000004`, -34.65564842942365, 8.291666666666666}, {
       34.95, -34.15768131561411, 8.291666666666666}, {
       34.95, -34.50375621050695, 0.}}], 
      Line3DBox[{{34.95, -34.15768131561411, 8.291666666666664}, {
       25.000000000000004`, -34.65564842942365, 8.291666666666664}, {
       25.000000000000004`, -33.615379406842806`, 16.58333333333333}, {
       34.95, -33.11213256043085, 16.58333333333333}, {
       34.95, -34.15768131561411, 8.291666666666664}}], 
      Line3DBox[{{34.95, -33.11213256043085, 16.58333333333333}, {
       25.000000000000004`, -33.615379406842806`, 16.58333333333333}, {
       25.000000000000004`, -31.856772478748226`, 24.874999999999993`}, {
       34.95, -31.344340129558205`, 24.874999999999993`}, {
       34.95, -33.11213256043085, 16.58333333333333}}], 
      Line3DBox[{{25.000000000000004`, -31.856772478748226`, -24.875}, {
       15.050000000000004`, -31.344340129558205`, -24.875}, {
       15.050000000000004`, -33.11213256043085, -16.583333333333336`}, {
       25.000000000000004`, -33.615379406842806`, -16.583333333333336`}, {
       25.000000000000004`, -31.856772478748226`, -24.875}}], 
      Line3DBox[{{
       25.000000000000004`, -33.615379406842806`, -16.583333333333336`}, {
       15.050000000000004`, -33.11213256043085, -16.583333333333336`}, {
       15.050000000000004`, -34.15768131561411, -8.29166666666667}, {
       25.000000000000004`, -34.65564842942365, -8.29166666666667}, {
       25.000000000000004`, -33.615379406842806`, -16.583333333333336`}}], 
      Line3DBox[{{
       25.000000000000004`, -34.65564842942365, -8.291666666666668}, {
       15.050000000000004`, -34.15768131561411, -8.291666666666668}, {
       15.050000000000004`, -34.50375621050695, -1.7763568394002505`*^-15}, {
       25.000000000000004`, -35., -1.7763568394002505`*^-15}, {
       25.000000000000004`, -34.65564842942365, -8.291666666666668}}], 
      Line3DBox[{{25.000000000000004`, -35., 0.}, {
       15.050000000000004`, -34.50375621050695, 0.}, {
       15.050000000000004`, -34.15768131561411, 8.291666666666666}, {
       25.000000000000004`, -34.65564842942365, 8.291666666666666}, {
       25.000000000000004`, -35., 0.}}], 
      Line3DBox[{{25.000000000000004`, -34.65564842942365, 
       8.291666666666664}, {15.050000000000004`, -34.15768131561411, 
       8.291666666666664}, {15.050000000000004`, -33.11213256043085, 
       16.58333333333333}, {25.000000000000004`, -33.615379406842806`, 
       16.58333333333333}, {25.000000000000004`, -34.65564842942365, 
       8.291666666666664}}], 
      Line3DBox[{{25.000000000000004`, -33.615379406842806`, 
       16.58333333333333}, {15.050000000000004`, -33.11213256043085, 
       16.58333333333333}, {15.050000000000004`, -31.344340129558205`, 
       24.874999999999993`}, {25.000000000000004`, -31.856772478748226`, 
       24.874999999999993`}, {25.000000000000004`, -33.615379406842806`, 
       16.58333333333333}}], 
      Line3DBox[{{15.050000000000004`, -31.344340129558205`, -24.875}, {
       5.100000000000005, -29.790423435070693`, -24.875}, {
       5.100000000000005, -31.586660857260995`, -16.583333333333336`}, {
       15.050000000000004`, -33.11213256043085, -16.583333333333336`}, {
       15.050000000000004`, -31.344340129558205`, -24.875}}], 
      Line3DBox[{{
       15.050000000000004`, -33.11213256043085, -16.583333333333336`}, {
       5.100000000000005, -31.586660857260995`, -16.583333333333336`}, {
       5.100000000000005, -32.64854460712094, -8.29166666666667}, {
       15.050000000000004`, -34.15768131561411, -8.29166666666667}, {
       15.050000000000004`, -33.11213256043085, -16.583333333333336`}}], 
      Line3DBox[{{
       15.050000000000004`, -34.15768131561411, -8.291666666666668}, {
       5.100000000000005, -32.64854460712094, -8.291666666666668}, {
       5.100000000000005, -32.99994897957855, -1.7763568394002505`*^-15}, {
       15.050000000000004`, -34.50375621050695, -1.7763568394002505`*^-15}, {
       15.050000000000004`, -34.15768131561411, -8.291666666666668}}], 
      Line3DBox[{{15.050000000000004`, -34.50375621050695, 0.}, {
       5.100000000000005, -32.99994897957855, 0.}, {
       5.100000000000005, -32.64854460712094, 8.291666666666666}, {
       15.050000000000004`, -34.15768131561411, 8.291666666666666}, {
       15.050000000000004`, -34.50375621050695, 0.}}], 
      Line3DBox[{{15.050000000000004`, -34.15768131561411, 
       8.291666666666664}, {5.100000000000005, -32.64854460712094, 
       8.291666666666664}, {5.100000000000005, -31.58666085726101, 
       16.58333333333333}, {15.050000000000004`, -33.11213256043085, 
       16.58333333333333}, {15.050000000000004`, -34.15768131561411, 
       8.291666666666664}}], 
      Line3DBox[{{15.050000000000004`, -33.11213256043085, 
       16.58333333333333}, {5.100000000000005, -31.58666085726101, 
       16.58333333333333}, {5.100000000000005, -29.790423435070693`, 
       24.874999999999993`}, {15.050000000000004`, -31.344340129558205`, 
       24.874999999999993`}, {15.050000000000004`, -33.11213256043085, 
       16.58333333333333}}], 
      Line3DBox[{{
       5.100000000000001, -29.790423435070693`, -24.875}, \
{-4.849999999999998, -27.14234572117209, -24.875}, {-4.849999999999998, \
-28.989204462829434`, -16.583333333333336`}, {
       5.100000000000001, -31.586660857260995`, -16.583333333333336`}, {
       5.100000000000001, -29.790423435070693`, -24.875}}], 
      Line3DBox[{{
       5.100000000000001, -31.586660857260995`, -16.583333333333336`}, \
{-4.849999999999998, -28.989204462829434`, -16.583333333333336`}, \
{-4.849999999999998, -30.08010182939904, -8.29166666666667}, {
       5.100000000000001, -32.64854460712094, -8.29166666666667}, {
       5.100000000000001, -31.586660857260995`, -16.583333333333336`}}], 
      Line3DBox[{{
       5.100000000000001, -32.64854460712094, -8.291666666666668}, \
{-4.849999999999998, -30.08010182939904, -8.291666666666668}, \
{-4.849999999999998, -30.44096342766035, -1.7763568394002505`*^-15}, {
       5.100000000000001, -32.99994897957855, -1.7763568394002505`*^-15}, {
       5.100000000000001, -32.64854460712094, -8.291666666666668}}], 
      Line3DBox[{{5.100000000000001, -32.99994897957855, 
       0.}, {-4.849999999999998, -30.44096342766035, 
       0.}, {-4.849999999999998, -30.08010182939904, 8.291666666666666}, {
       5.100000000000001, -32.64854460712094, 8.291666666666666}, {
       5.100000000000001, -32.99994897957855, 0.}}], 
      Line3DBox[{{5.100000000000001, -32.64854460712094, 
       8.291666666666664}, {-4.849999999999998, -30.08010182939904, 
       8.291666666666664}, {-4.849999999999998, -28.989204462829434`, 
       16.58333333333333}, {5.100000000000001, -31.58666085726101, 
       16.58333333333333}, {5.100000000000001, -32.64854460712094, 
       8.291666666666664}}], 
      Line3DBox[{{5.100000000000001, -31.58666085726101, 
       16.58333333333333}, {-4.849999999999998, -28.989204462829434`, 
       16.58333333333333}, {-4.849999999999998, -27.14234572117209, 
       24.874999999999993`}, {5.100000000000001, -29.790423435070693`, 
       24.874999999999993`}, {5.100000000000001, -31.58666085726101, 
       16.58333333333333}}], {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043429288597`*^9, 3.5634582359069147`*^9, 
  3.564487691315008*^9, 3.566100832669685*^9, 3.60130157994697*^9, 
  3.6147093449319477`*^9, 3.614729203069377*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"During evaluation of In[321]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Only a single ",
  FontSlant->"Italic"],
 StyleBox["Refraction", "Input",
  FontSlant->"Plain"],
 StyleBox[" and ",
  FontSlant->"Italic"],
 StyleBox["ComponentRendering", "Input",
  FontSlant->"Plain"],
 StyleBox[" is used to generate this element.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[TextData[{
 "Finally, we will examine how different surface shapes are handled by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s generic building blocks. For this, we evaluate the ",
 StyleBox["ParabolicMirror", "Input"],
 " function."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["ParabolicMirror[50, 100, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[324]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Reflection", "[", 
     RowBox[{"ComponentRendering", "[", 
      RowBox[{"ComponentFoundation", "[", 
       RowBox[{"50", ",", "100.`", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Labels", "\[Rule]", "\<\"M\"\>"}], ",", 
          RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
          RowBox[{"SurfaceLabel", "\[Rule]", "ParabolicShape"}]}], "}"}]}], 
       "]"}], "]"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404343106841*^9, 3.563458235977298*^9, 
  3.564487691415904*^9, 3.5661008328281507`*^9, 3.601301580009018*^9, 
  3.614709344994404*^9, 3.6147292031344013`*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[324]="]
}, Open  ]],

Cell[TextData[{
 "Here we can see that the ",
 StyleBox["ParabolicMirror", "Input"],
 " has passed the ",
 StyleBox["SurfaceLabel -> ParabolicShape", "Input"],
 " option to ",
 StyleBox["ComponentFoundation", "Input"],
 ". It is therefore evident that the ",
 StyleBox["ComponentFoundation", "Input"],
 " is responsible for establishing the component shape and the ",
 StyleBox["SurfaceLabel", "Input"],
 " option is used to specify this information. In order to gain further \
insight into this process, lets evaluate a ",
 StyleBox["CustomMirror", "Input"],
 " function."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[CellGroupData[{

Cell["CustomMirror[Function[10], 100, BuildComponent->True]", "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"In[325]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Reflection", "[", 
     RowBox[{"ComponentRendering", "[", 
      RowBox[{"ComponentFoundation", "[", 
       RowBox[{
        RowBox[{"10", "&"}], ",", "100.`", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Labels", "\[Rule]", "\<\"M\"\>"}], ",", 
          RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
          RowBox[{"SurfaceLabel", "\[Rule]", "OtherShape"}], ",", 
          RowBox[{"BoundaryFactor", "\[Rule]", "1"}]}], "}"}]}], "]"}], "]"}],
      "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404343389131*^9, 3.563458236218014*^9, 
  3.564487691852145*^9, 3.566100833314506*^9, 3.601301580290245*^9, 
  3.6147093452768593`*^9, 3.6147292034155083`*^9},
 CellTags->{"Generic Building Blocks", "PR4.5"},
 CellLabel->"Out[325]="]
}, Open  ]],

Cell[TextData[{
 "In this case, the custom surface function, ",
 StyleBox["10 &", "Input"],
 ", is the first parameter of ",
 StyleBox["ComponentFoundation", "Input"],
 " and ",
 StyleBox["SurfaceLabel -> OtherShape", "Input"],
 " indicates that an external surface function is being used."
}], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6 CustomDeflections", "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 "In this section, we will examine the use of ",
 StyleBox["CustomDeflections", "Input"],
 ". ",
 StyleBox["CustomDeflections", "Input"],
 " is one of 30 principle generic building blocks that were listed at the \
start of the previous section. Unlike most generic building blocks, ",
 StyleBox["CustomDeflections", "Input"],
 " is not used by any of the internal component functions. It is instead \
designed to give the user a way to create new ray-trace behaviors."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 StyleBox["CustomDeflections[", "Input"],
 StyleBox["component",
  FontSlant->"Italic"],
 ", ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 ", ",
 StyleBox["functionlabel",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " allows the user to create custom ray-tracing functions. The ",
 StyleBox["functionlabel",
  FontSlant->"Italic"],
 " is optional."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 StyleBox["CustomDeflections", "Input"],
 " works equally well with both ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 ". We will see shortly that the ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 " of ",
 StyleBox["CustomDeflections", "Input"],
 " operates on ray and surface parameters. When tracing with ",
 StyleBox["AnalyzeSystem", "Input"],
 ", you can work with any ray parameter that is listed in ",
 StyleBox["Options[Ray]", "Input"],
 ". However, ",
 StyleBox["TurboTrace", "Input"],
 " uses a limited set of the most important ray parameters, shown below. \
(These parameters are listed in ",
 StyleBox["$TurboRaysRuleNames", "Input"],
 ".)"
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[Cell[BoxData[
 TagBox[GridBox[{
    {"RayStart", "SurfaceNumber", "RayTilt"},
    {"RayEnd", "SurfaceCoordinates", ""},
    {"RotationMatrix", "SourceID", ""},
    {"WaveLength", "WaveFrontID", ""},
    {"Intensity", "RaySourceNumber", ""},
    {"RayLength", "RaySlot", ""},
    {"RefractiveIndex", "GenerationNumber", ""},
    {"OpticalLength", "IntersectionNumber", ""},
    {"ComponentNumber", "Polarization", ""}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]]]], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 StyleBox["Ray parameters used by ",
  FontSlant->"Italic"],
 StyleBox["TurboTrace", "Input",
  FontSlant->"Plain"],
 StyleBox[".",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 "Note that the ",
 StyleBox["RayTilt", "Input"],
 " parameter is in fact the same as the first three elements in ",
 StyleBox["RotationMatrix", "Input"],
 ". In addition to the ray-specific parameters, the following optical surface \
parameters may be used: ",
 StyleBox["SurfaceCoordinates", "Input"],
 " ( also given as a ray parameter), ",
 StyleBox["SurfaceNormalMatrix", "Input"],
 ", and ",
 StyleBox["ComponentTransformation", "Input"],
 ". When working exclusively with ",
 StyleBox["TurboTrace", "Input"],
 ", the following additional parameters can also be used: ",
 StyleBox["RayAmplitude", "Input"],
 ", ",
 StyleBox["RefractiveIndexBefore", "Input"],
 ", and ",
 StyleBox["RefractiveIndexAfter", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 "Here, we can see the standard behavior of the unmodified ",
 StyleBox["Screen", "Input"],
 " element."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{SingleRay[],Move[Screen[50],50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"},
 CellLabel->"In[326]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {100., 0.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043446103067`*^9, 3.563458236523398*^9, 
  3.564487692739365*^9, 3.5661008337671623`*^9, 3.601301580551695*^9, 
  3.6147093455348387`*^9, 3.6147292036657124`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"},
 CellLabel->"During evaluation of In[326]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Default ",
  FontSlant->"Italic"],
 StyleBox["Screen", "Input",
  FontSlant->"Plain"],
 StyleBox[" behavior.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[{
 "In the examples that follow, we will use ",
 StyleBox["CustomDeflections", "Input"],
 " with ",
 StyleBox["Screen", "Input"],
 " and see how to create different ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 " constructions that modify the ray-trace behavior in various ways."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}],

Cell[CellGroupData[{

Cell["4.6.1 Getting a Ray to Change Color", "Subsection",
 CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}],

Cell[TextData[{
 "The simplest ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 " simply changes a ray parameter by a constant amount.  In this first \
example, we will use ",
 StyleBox["CustomDeflections", "Input"],
 " on ",
 StyleBox["Screen", "Input"],
 " to alter the wavelength of any ray that passes through the screen surface. \
Here, the ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 " is given by ",
 StyleBox["Function[Ray[WaveLength->.45]]", "Input"],
 ". "
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],

Cell[CellGroupData[{

Cell["\<\
alterwavelength = 
\tCustomDeflections[
\t\tScreen[50],
\t\tFunction[Ray[WaveLength->.45]]
\t]\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"},
 CellLabel->"In[327]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomDeflections", "[", 
     RowBox[{
      RowBox[{"Screen", "[", "50", "]"}], ",", 
      RowBox[{
       RowBox[{"Ray", "[", 
        RowBox[{"WaveLength", "\[Rule]", "0.45`"}], "]"}], "&"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404346163356*^9, 3.563458236719672*^9, 
  3.5644876928023767`*^9, 3.5661008338920107`*^9, 3.60130158059437*^9, 
  3.6147093455766973`*^9, 3.614729203715622*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"},
 CellLabel->"Out[327]="]
}, Open  ]],

Cell["\<\
When we trace a ray through the surface, we get the desired effect.\
\>", "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{SingleRay[],Move[alterwavelength,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"},
 CellLabel->"In[328]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404346765575*^9, 3.5634582369598417`*^9, 
  3.564487693139727*^9, 3.5661008343081207`*^9, 3.601301580841629*^9, 
  3.614709345801791*^9, 3.6147292040574703`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"},
 CellLabel->"During evaluation of In[328]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["CustomDeflections", "Input",
  FontSlant->"Plain"],
 " is used to modify ",
 StyleBox["WaveLength", "Input",
  FontSlant->"Plain"],
 " parameter. This changes both the wavelength and the displayed color of a \
ray."
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6.2 Using Information from a Ray Parameter", "Subsection",
 CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[{
 "The previous example did not use any existing ray parameter information. \
Instead, it simply forced a parameter change without interaction. We will now \
see how to use previously existing ray information in order to invoke a \
wanted change in the propagated ray. Lets try an example that uses the ",
 StyleBox["RayLength", "Input"],
 " information to shift the transverse ray end position in space. We use ",
 StyleBox["ReplaceFor", "Input"],
 " (written as /.) to get at the ray information. Here, an optional ",
 StyleBox["\"shiftposition\"", "Input"],
 " label is used with ",
 StyleBox["CustomDeflections", "Input"],
 ". Such labels were once required with the original ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " package, but are no longer necessary."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[CellGroupData[{

Cell["\<\
shiftposition = 
\tCustomDeflections[Screen[50],
\t\tFunction[Ray[RayEnd->({50,.5*RayLength,0}/.#)]],
\t\t\"shiftposition\"
\t]\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[329]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox["\<\"shiftposition\"\>",
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5634043468339357`*^9, 3.563458236998678*^9, 
  3.5644876944996767`*^9, 3.566100834377595*^9, 3.601301580944707*^9, 
  3.614709345897499*^9, 3.614729204106494*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"Out[329]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{SingleRay[],Move[shiftposition,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[330]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 25.}, {100., 25.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 25.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404347200881*^9, 3.563458237212109*^9, 
  3.5644876949107924`*^9, 3.566100834792708*^9, 3.601301581458136*^9, 
  3.614709346122369*^9, 3.614729204346335*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"During evaluation of In[330]:="]
}, Open  ]],

Cell[TextData[StyleBox["The position of the ray has been shifted.",
 FontSlant->"Italic"]], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[{
 "You can also introduce intermediate variables inside our ",
 StyleBox["raydeflectfunction ",
  FontSlant->"Italic"],
 "with either ",
 StyleBox["Block", "Input"],
 " or ",
 StyleBox["Module", "Input"],
 ". Here is the same ",
 StyleBox["raydeflectfunction,",
  FontSlant->"Italic"],
 " used in the previous example, with ",
 StyleBox["Block", "Input"],
 " and two intermediate variables, ",
 StyleBox["rayend", "Input"],
 " and ",
 StyleBox["raylength", "Input"],
 ", included."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[CellGroupData[{

Cell["\<\
shiftscreen2 = 
\tCustomDeflections[Screen[50],
\t\tFunction[
\t\t\tBlock[{rayend,raylength},
\t\t\trayend = RayEnd/.#;
\t\t\traylength = RayLength/.#;
\t\t\tRay[RayEnd->rayend + {0,.5*raylength,0}]
\t\t\t]
\t\t]
\t];
AnalyzeSystem[{SingleRay[],Move[shiftscreen2,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[331]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 25.}, {100., 25.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 25.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56340434857572*^9, 3.56345823745621*^9, 
  3.564487695211089*^9, 3.566100835328393*^9, 3.601301581717173*^9, 
  3.614709346384138*^9, 3.614729204603716*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"During evaluation of In[331]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Block", "Input",
  FontSlant->"Plain"],
 StyleBox[" is used to create intermediate variables.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[{
 "You can also modify more than one ray parameter at a time in ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 ". In this example, we change the values of both ",
 StyleBox["RayEnd", "Input"],
 " and ",
 StyleBox["WaveLength", "Input"],
 "."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[CellGroupData[{

Cell["\<\
shiftscreen3 = 
\tCustomDeflections[Screen[50],
\t\tFunction[
\t\t\tBlock[{rayend,raylength},
\t\t\trayend = RayEnd/.#;
\t\t\traylength = RayLength/.#;
\t\t\tRay[RayEnd->rayend + {0,.5*raylength,0}, WaveLength->.65]
\t\t\t]
\t\t]
\t];
AnalyzeSystem[{SingleRay[],Move[shiftscreen3,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[333]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.9470219661360387, 0.0130229581892769, 0.009663572422132893], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 25.}, {100., 25.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 25.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043493716497`*^9, 3.563458237700699*^9, 
  3.564487695530568*^9, 3.566100835796308*^9, 3.6013015819789963`*^9, 
  3.614709346641573*^9, 3.6147292048670692`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"During evaluation of In[333]:="]
}, Open  ]],

Cell[TextData[StyleBox["Two ray parameters are modified at the same time.", \
"Text"]], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[{
 "Finally, you can to generate multiple rays in the output if you list \
several ",
 StyleBox["Ray", "Input"],
 " objects in ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 ". In the following example, we list three different ",
 StyleBox["Ray", "Input"],
 " objects to generate three new rays."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[CellGroupData[{

Cell["\<\
shiftscreen4 = 
\tCustomDeflections[Screen[50],
\t\tFunction[
\t\t\tBlock[{rayend,raylength},
\t\t\trayend = RayEnd/.#;
\t\t\traylength = RayLength/.#;
\t\t\t{Ray[RayEnd->rayend + {0,.5*raylength,0}, WaveLength->.45],
\t\t\tRay[RayEnd->{50,10,0}],
\t\t\tRay[WaveLength->.6]}
\t\t\t]
\t\t]
\t];
AnalyzeSystem[{SingleRay[],Move[shiftscreen4,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[335]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 25.}, {100., 25.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 10.}, {100., 10.}}]}, 
    {RGBColor[0.947342704361055, 0.47353532394041015`, 0.014823955533973587`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 25.}, {100., 10.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043497191563`*^9, 3.56345823803518*^9, 
  3.564487696742765*^9, 3.566100836338447*^9, 3.601301582329653*^9, 
  3.614709346908326*^9, 3.614729205214168*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"During evaluation of In[335]:="]
}, Open  ]],

Cell[TextData[StyleBox["Three new rays are generated.", "Text"]], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[{
 "Here is the same component traced with ",
 StyleBox["TurboPlot", "Input"],
 ". Even though ",
 StyleBox["TurboTrace", "Input"],
 " does not directly use ",
 StyleBox["Ray", "Input"],
 " objects, the ",
 StyleBox["Ray", "Input"],
 " notation of the ",
 StyleBox["raydeflectfunction",
  FontSlant->"Italic"],
 " is automatically converted by ",
 StyleBox["CustomDeflections", "Input"],
 " into the ",
 StyleBox["TurboTrace", "Input"],
 " format when ",
 StyleBox["TurboPlot", "Input"],
 " is called."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{SingleRay[],Move[shiftscreen4,50],Boundary[100]},PlotType->TopView]\
;\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"In[337]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}, {{50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFIBwjt6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AY+ki2A==
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[{{0., 0.}, {50., 0.}}]}, 
   {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
    AbsoluteThickness[0.5], LineBox[{{50., 25.}, {100., 25.}}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[{{50., 10.}, {100., 10.}}]}, 
   {RGBColor[0.947342704361055, 0.47353532394041015`, 0.014823955533973587`], 
    AbsoluteThickness[0.5], LineBox[{{50., 0.}, {100., 0.}}], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], 
     PointBox[{{50., 0.}, {100., 25.}, {100., 10.}, {100., 0.}}]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404350758471*^9, 3.563458238636795*^9, 
  3.564487697472775*^9, 3.5661008375295553`*^9, 3.601301583389701*^9, 
  3.614709347988413*^9, 3.614729206266818*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"},
 CellLabel->"During evaluation of In[337]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["TurboPlot", "Input",
  FontSlant->"Plain"],
 StyleBox[" can also be used with ", "Text"],
 StyleBox["CustomDeflections", "Input",
  FontSlant->"Plain"],
 StyleBox[" instead of ", "Text"],
 StyleBox["AnalyzeSystem", "Input",
  FontSlant->"Plain"],
 StyleBox[".", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.6.3 ",
 StyleBox["AddTo", "Input"],
 ", ",
 StyleBox["TakeFrom", "Input"],
 ", and ",
 StyleBox["ReplaceFor", "Input"]
}], "Subsection",
 CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 StyleBox["CustomDeflections", "Input"],
 " (and indeed all built-in deflection functions) use the options ",
 StyleBox["AddTo", "Input"],
 ", ",
 StyleBox["TakeFrom", "Input"],
 ", and sometimes ",
 StyleBox["ReplaceFor", "Input"],
 ". These options control the flow of information to and from the ray \
deflection process. "
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 StyleBox["AddTo ->", "Input"],
 " ",
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 " specifies the types of objects that receive the new parameter results. \n\
",
 StyleBox["TakeFrom -> ", "Input"],
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 " designates which types of objects are used as inputs to the ray-tracing \
function calculation.\n",
 StyleBox["ReplaceFor -> ", "Input"],
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 " indicates which types of objects are replaced by the new parameter results \
of the ray-tracing function calculation."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 StyleBox["Three important options used by ",
  FontSlant->"Italic"],
 StyleBox["CustomDeflections", "Input",
  FontSlant->"Plain"],
 StyleBox[" and other generic building blocks.",
  FontSlant->"Italic"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "Of these three options, ",
 StyleBox["AddTo", "Input"],
 " is the most important to consider. The remaining two options, ",
 StyleBox["TakeFrom", "Input"],
 " and ",
 StyleBox["ReplaceFor", "Input"],
 ", are rarely altered and will not be considered further at this time. There \
are seven possible ",
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 " that include: ",
 StyleBox["NewRay", "Input"],
 ", ",
 StyleBox["ChangedRay", "Input"],
 ", ",
 StyleBox["OriginalRay", "Input"],
 ", ",
 StyleBox["CreatedRay", "Input"],
 ", ",
 StyleBox["AllCreatedRays", "Input"],
 ", ",
 StyleBox["ChangedSurface", "Input"],
 ", and ",
 StyleBox["ChangedComponent", "Input"],
 ". Of these seven ",
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 ", only ",
 StyleBox["NewRay", "Input"],
 ", ",
 StyleBox["ChangedRay", "Input"],
 ", ",
 StyleBox["OriginalRay", "Input"],
 ", and ",
 StyleBox["CreatedRay", "Input"],
 " are commonly used by ",
 StyleBox["CustomDeflections", "Input"],
 ". For the remainder of this section, we will examine these four ",
 StyleBox["objecttypes",
  FontSlant->"Italic"],
 " in more detail."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "If we examine the options of ",
 StyleBox["CustomDeflections", "Input"],
 " that modified the ray color, we can immediately see the effect of changing \
the ",
 StyleBox["AddTo", "Input"],
 " value. By default, ",
 StyleBox["CustomDeflections", "Input"],
 " uses ",
 StyleBox["AddTo -> CreatedRay", "Input"],
 ":"
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AddTo", "Input"],
 "/.Options[",
 StyleBox["CustomDeflections", "Input"],
 "]"
}], "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[338]:="],

Cell[BoxData["CreatedRay"], "Output",
 CellChangeTimes->{3.563404358323966*^9, 3.5634582386668386`*^9, 
  3.564487697485293*^9, 3.5661008376199636`*^9, 3.601301583483283*^9, 
  3.614709348043324*^9, 3.6147292063509483`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"Out[338]="]
}, Open  ]],

Cell["\<\
In its default state, the new ray information is added to a newly created ray \
at the surface. \
\>", "Text",
 FontWeight->"Plain",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorscreen = 
\tCustomDeflections[Screen[50],
\t\tFunction[Ray[WaveLength->.45]]
\t];
AnalyzeSystem[{SingleRay[],Move[colorscreen,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[339]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404359213194*^9, 3.563458238912567*^9, 
  3.564487697739375*^9, 3.5661008381255493`*^9, 3.601301583739462*^9, 
  3.614709348301618*^9, 3.614729206638873*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[339]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Default ", "Text"],
 StyleBox["AddTo -> CreatedRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" condition.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "If we instead change this value to ",
 StyleBox["AddTo -> OriginalRay", "Input"],
 ", we can change information in the ray that is incident on the surface."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorscreen = 
\tCustomDeflections[Screen[50],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAddTo->OriginalRay
\t];
AnalyzeSystem[{SingleRay[],Move[colorscreen,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[341]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {100., 0.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043595627403`*^9, 3.563458239234209*^9, 
  3.564487697986071*^9, 3.566100838631318*^9, 3.6013015840004673`*^9, 
  3.6147093485601177`*^9, 3.61472920690948*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[341]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["AddTo -> OriginalRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" alters the ray before the surface.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "In this case, the color of the previous ray segment has been changed to \
blue and this attribute has then been passed on to the subsequent ray \
generations. On the other hand, if we use ",
 StyleBox["AddTo -> ChangedRay", "Input"],
 " we get something even more astounding:"
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorscreen = 
\tCustomDeflections[Screen[50],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAddTo->ChangedRay
\t];
AnalyzeSystem[{SingleRay[],Move[colorscreen,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[343]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404360048728*^9, 3.563458239477652*^9, 
  3.56448769834328*^9, 3.56610083919425*^9, 3.601301584276862*^9, 
  3.614709348835918*^9, 3.6147292071757717`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[343]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["AddTo -> ChangedRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" does not affect the ray after the surface.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell["\<\
This time, the newly created ray does not inherit the color change because \
the information gets passed to the previous ray segment after it has already \
passed its information onto the new ray generations.\
\>", "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "You can use ",
 StyleBox["AddTo -> NewRay", "Input"],
 " to create a new ray at the same surface. In the following case, two rays \
are generated at the screen surface that separately contain the new and the \
old wavelength information. Shown below, the ",
 StyleBox["Grating", "Input"],
 " element is used to visually separate the two rays from each other."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorscreen = 
\tCustomDeflections[Screen[50],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAddTo->NewRay
\t];
AnalyzeSystem[{
\tSingleRay[],
\tMove[colorscreen,50],
\tMove[Grating[1000,50,DiffractedOrders->{{1,1}}],75],
\tBoundary[100]},PlotType->TopView];
ReadRays[%, WaveLength, ComponentNumber -> 3]\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[345]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{75., -25.}, {75., -25.}, {75., -16.66666666666667}, {
      75., -16.666666666666668`}, {75., -25.}}], 
     PolygonBox[{{75., -16.666666666666668`}, {75., -16.66666666666667}, {
      75., -8.333333333333336}, {75., -8.333333333333336}, {
      75., -16.666666666666668`}}], 
     PolygonBox[{{75., -8.333333333333336}, {75., -8.333333333333336}, {
      75., -7.105427357601002*^-15}, {75., 0.}, {75., -8.333333333333336}}], 
     PolygonBox[{{75., 0.}, {75., 0.}, {75., 8.333333333333332}, {75., 
      8.333333333333329}, {75., 0.}}], 
     PolygonBox[{{75., 8.333333333333329}, {75., 8.333333333333332}, {75., 
      16.666666666666664`}, {75., 16.666666666666664`}, {75., 
      8.333333333333329}}], 
     PolygonBox[{{75., 16.666666666666664`}, {75., 16.666666666666664`}, {75.,
       24.999999999999996`}, {75., 24.999999999999993`}, {75., 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -25.}, {75., -16.666666666666668`}, {
       75., -8.333333333333336}, {75., -3.552713678800501*^-15}, {75., 
       8.333333333333329}, {75., 16.666666666666657`}, {75., 
       24.999999999999993`}, {75., 25.}, {75., 16.666666666666668`}, {75., 
       8.333333333333336}, {75., 3.552713678800501*^-15}, {
       75., -8.333333333333329}, {75., -16.666666666666657`}, {
       75., -24.999999999999993`}, {75., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{75., 0.}, {75., 3.061616997868383*^-15}, {75., 
        2.551347498223653*^-15}, {75., 5.102694996447305*^-16}, {75., 0.}}], 
       PolygonBox[{{75., 5.102694996447305*^-16}, {75., 
        2.551347498223653*^-15}, {75., 2.0410779985789223`*^-15}, {75., 
        1.020538999289461*^-15}, {75., 5.102694996447305*^-16}}], 
       PolygonBox[{{75., 1.020538999289461*^-15}, {75., 
        2.0410779985789223`*^-15}, {75., 1.530808498934192*^-15}, {75., 
        1.5308084989341915`*^-15}, {75., 1.020538999289461*^-15}}], 
       PolygonBox[{{75., 1.5308084989341915`*^-15}, {75., 
        1.5308084989341915`*^-15}, {75., 1.0205389992894611`*^-15}, {75., 
        2.041077998578922*^-15}, {75., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{75., 2.041077998578922*^-15}, {75., 
        1.0205389992894611`*^-15}, {75., 5.102694996447307*^-16}, {75., 
        2.5513474982236525`*^-15}, {75., 2.041077998578922*^-15}}], 
       PolygonBox[{{75., 2.5513474982236525`*^-15}, {75., 
        5.102694996447308*^-16}, {75., 2.5493082627129206`*^-31}, {75., 
        3.0616169978683826`*^-15}, {75., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 
         0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 
         0.}, {75., 0.}, {75., 0.}, {75., 0.}}]}}}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHghwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAFhNgg8=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {75., 0.}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {75., 0.}}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{75., 0.}, {100., 15.707220186036757`}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{75., 0.}, {100., 12.597581496506724`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {75., 0.}, {75., 0.}, {100., 15.707220186036757`}, {
      100., 12.597581496506724`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"G\"\>", {75., -27.314144403720736`}, {0., 0.}], 
    InsetBox["\<\"S\"\>", {50., -27.314144403720736`}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043608665733`*^9, 3.563458240111013*^9, 
  3.5644876990737057`*^9, 3.566100840232422*^9, 3.601301584861451*^9, 
  3.614709349479755*^9, 3.614729207784423*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[345]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.532`", ",", "0.45`"}], "}"}]], "Output",
 CellChangeTimes->{3.5634043608710318`*^9, 3.563458240115142*^9, 
  3.564487699076984*^9, 3.566100840239758*^9, 3.6013015848657084`*^9, 
  3.614709349483869*^9, 3.6147292077883587`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"Out[347]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["AddTo -> NewRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" creates a new ray and preserves the old ray.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "The ",
 StyleBox["AddTo -> CreatedRay", "Input"],
 " setting becomes important with components that already generate multiple \
rays at its surface. This setting causes the new information to be included \
the previously created rays."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorsplitter = 
\tCustomDeflections[BeamSplitter[{50,50},50],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAddTo->CreatedRay
\t];
AnalyzeSystem[{SingleRay[],Move[colorsplitter,50,45],Boundary[100]},PlotType->\
TopView];
ReadRays[%, WaveLength, ComponentNumber -> 2]\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[348]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{67.67766952966369, -17.677669529663685`}, {
      67.67766952966369, -17.677669529663685`}, {
      61.78511301977579, -11.785113019775794`}, {
      61.78511301977579, -11.785113019775793`}, {
      67.67766952966369, -17.677669529663685`}}], 
     PolygonBox[{{61.78511301977579, -11.785113019775793`}, {
      61.78511301977579, -11.785113019775794`}, {
      55.892556509887896`, -5.892556509887897}, {
      55.892556509887896`, -5.892556509887897}, {
      61.78511301977579, -11.785113019775793`}}], 
     PolygonBox[{{55.892556509887896`, -5.892556509887897}, {
      55.892556509887896`, -5.892556509887897}, {
      50.00000000000001, -5.02429586778808*^-15}, {50., 0.}, {
      55.892556509887896`, -5.892556509887897}}], 
     PolygonBox[{{50., 0.}, {50., 0.}, {44.107443490112104`, 
      5.8925565098878945`}, {44.10744349011211, 5.892556509887892}, {50., 
      0.}}], PolygonBox[{{44.10744349011211, 5.892556509887892}, {
      44.107443490112104`, 5.8925565098878945`}, {38.21488698022421, 
      11.785113019775789`}, {38.21488698022421, 11.785113019775789`}, {
      44.10744349011211, 5.892556509887892}}], 
     PolygonBox[{{38.21488698022421, 11.785113019775789`}, {38.21488698022421,
       11.785113019775789`}, {32.32233047033631, 17.677669529663685`}, {
      32.32233047033632, 17.67766952966368}, {38.21488698022421, 
      11.785113019775789`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{67.67766952966369, -17.677669529663685`}, {
       61.78511301977579, -11.785113019775793`}, {
       55.892556509887896`, -5.892556509887897}, {
       50., -2.51214793389404*^-15}, {44.10744349011211, 5.892556509887892}, {
       38.214886980224215`, 11.785113019775784`}, {32.32233047033632, 
       17.67766952966368}, {32.32233047033631, 17.677669529663685`}, {
       38.21488698022421, 11.785113019775793`}, {44.107443490112104`, 
       5.892556509887897}, {50., 2.51214793389404*^-15}, {
       55.89255650988789, -5.892556509887892}, {
       61.785113019775785`, -11.785113019775784`}, {
       67.67766952966369, -17.67766952966368}, {
       67.67766952966369, -17.677669529663685`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{50., 0.}, {50., 2.164890140588733*^-15}, {50., 
        1.804075117157278*^-15}, {50., 3.6081502343145547`*^-16}, {50., 0.}}],
        PolygonBox[{{50., 3.6081502343145547`*^-16}, {50., 
        1.804075117157278*^-15}, {50., 1.4432600937258223`*^-15}, {50., 
        7.216300468629109*^-16}, {50., 3.6081502343145547`*^-16}}], 
       PolygonBox[{{50., 7.216300468629109*^-16}, {50., 
        1.4432600937258223`*^-15}, {50., 1.0824450702943668`*^-15}, {50., 
        1.0824450702943666`*^-15}, {50., 7.216300468629109*^-16}}], 
       PolygonBox[{{50., 1.0824450702943666`*^-15}, {50., 
        1.0824450702943666`*^-15}, {50., 7.216300468629111*^-16}, {50., 
        1.4432600937258219`*^-15}, {50., 1.0824450702943666`*^-15}}], 
       PolygonBox[{{50., 1.4432600937258219`*^-15}, {50., 
        7.216300468629111*^-16}, {50., 3.608150234314556*^-16}, {50., 
        1.8040751171572774`*^-15}, {50., 1.4432600937258219`*^-15}}], 
       PolygonBox[{{50., 1.8040751171572774`*^-15}, {50., 
        3.608150234314557*^-16}, {50., 1.8026331598992026`*^-31}, {50., 
        2.1648901405887327`*^-15}, {50., 1.8040751171572774`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
         0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
         0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{50., 0.}, {44.107443490112104`, 5.8925565098878945`}, {
      44.30822748423151, 5.691772515768494}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{44.107443490112104`, 5.8925565098878945`}, {
      38.21488698022421, 11.785113019775789`}, {38.61645496846301, 
      11.383545031536988`}, {44.30822748423151, 5.691772515768494}, {
      44.107443490112104`, 5.8925565098878945`}}], 
     PolygonBox[{{38.21488698022421, 11.785113019775789`}, {32.32233047033631,
       17.677669529663685`}, {32.92468245269452, 17.07531754730548}, {
      38.61645496846301, 11.383545031536988`}, {38.21488698022421, 
      11.785113019775789`}}], 
     PolygonBox[{{50., 0.}, {44.30822748423151, 5.691772515768494}, {
      44.89689636920171, 5.103103630798287}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{44.30822748423151, 5.691772515768494}, {38.61645496846301, 
      11.383545031536988`}, {39.793792738403425`, 10.206207261596575`}, {
      44.89689636920171, 5.103103630798287}, {44.30822748423151, 
      5.691772515768494}}], 
     PolygonBox[{{38.61645496846301, 11.383545031536988`}, {32.92468245269452,
       17.07531754730548}, {34.69068910760514, 15.309310892394864`}, {
      39.793792738403425`, 10.206207261596575`}, {38.61645496846301, 
      11.383545031536988`}}], 
     PolygonBox[{{50., 0.}, {44.89689636920171, 5.103103630798287}, {
      45.833333333333336`, 4.166666666666666}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{44.89689636920171, 5.103103630798287}, {39.793792738403425`,
       10.206207261596575`}, {41.66666666666667, 8.333333333333332}, {
      45.833333333333336`, 4.166666666666666}, {44.89689636920171, 
      5.103103630798287}}], 
     PolygonBox[{{39.793792738403425`, 10.206207261596575`}, {
      34.69068910760514, 15.309310892394864`}, {37.5, 12.5}, {
      41.66666666666667, 8.333333333333332}, {39.793792738403425`, 
      10.206207261596575`}}], 
     PolygonBox[{{50., 0.}, {45.833333333333336`, 4.166666666666666}, {
      47.05372174505605, 2.9462782549439486`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{45.833333333333336`, 4.166666666666666}, {41.66666666666667,
       8.333333333333332}, {44.107443490112104`, 5.892556509887897}, {
      47.05372174505605, 2.9462782549439486`}, {45.833333333333336`, 
      4.166666666666666}}], 
     PolygonBox[{{41.66666666666667, 8.333333333333332}, {37.5, 12.5}, {
      41.161165235168156`, 8.838834764831846}, {44.107443490112104`, 
      5.892556509887897}, {41.66666666666667, 8.333333333333332}}], 
     PolygonBox[{{50., 0.}, {47.05372174505605, 2.9462782549439486`}, {
      48.47489415089817, 1.5251058491018286`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{47.05372174505605, 2.9462782549439486`}, {
      44.107443490112104`, 5.892556509887897}, {46.949788301796346`, 
      3.050211698203657}, {48.47489415089817, 1.5251058491018286`}, {
      47.05372174505605, 2.9462782549439486`}}], 
     PolygonBox[{{44.107443490112104`, 5.892556509887897}, {
      41.161165235168156`, 8.838834764831846}, {45.42468245269451, 
      4.575317547305486}, {46.949788301796346`, 3.050211698203657}, {
      44.107443490112104`, 5.892556509887897}}], 
     PolygonBox[{{50., 0.}, {48.47489415089817, 1.5251058491018286`}, {50., 
      1.6692254056679344`*^-15}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{48.47489415089817, 1.5251058491018286`}, {
      46.949788301796346`, 3.050211698203657}, {50., 
      3.3384508113358688`*^-15}, {50., 1.6692254056679344`*^-15}, {
      48.47489415089817, 1.5251058491018286`}}], 
     PolygonBox[{{46.949788301796346`, 3.050211698203657}, {45.42468245269451,
       4.575317547305486}, {49.99999999999999, 5.007676217003804*^-15}, {50., 
      3.3384508113358688`*^-15}, {46.949788301796346`, 3.050211698203657}}], 
     PolygonBox[{{50., 0.}, {50., 3.6081502343145547`*^-16}, {
      51.52510584910183, -1.5251058491018266`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50., 3.6081502343145547`*^-16}, {50., 
      7.216300468629109*^-16}, {53.050211698203654`, -3.050211698203653}, {
      51.52510584910183, -1.5251058491018266`}, {50., 
      3.6081502343145547`*^-16}}], 
     PolygonBox[{{50., 7.216300468629109*^-16}, {50., 
      1.0824450702943666`*^-15}, {54.57531754730548, -4.57531754730548}, {
      53.050211698203654`, -3.050211698203653}, {50., 
      7.216300468629109*^-16}}], 
     PolygonBox[{{50., 0.}, {51.52510584910183, -1.5251058491018266`}, {
      52.94627825494395, -2.946278254943946}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{51.52510584910183, -1.5251058491018266`}, {
      53.050211698203654`, -3.050211698203653}, {
      55.89255650988789, -5.892556509887892}, {
      52.94627825494395, -2.946278254943946}, {
      51.52510584910183, -1.5251058491018266`}}], 
     PolygonBox[{{53.050211698203654`, -3.050211698203653}, {
      54.57531754730548, -4.57531754730548}, {
      58.83883476483184, -8.838834764831839}, {
      55.89255650988789, -5.892556509887892}, {
      53.050211698203654`, -3.050211698203653}}], 
     PolygonBox[{{50., 0.}, {52.94627825494395, -2.946278254943946}, {
      54.166666666666664`, -4.166666666666665}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{52.94627825494395, -2.946278254943946}, {
      55.89255650988789, -5.892556509887892}, {
      58.33333333333333, -8.33333333333333}, {
      54.166666666666664`, -4.166666666666665}, {
      52.94627825494395, -2.946278254943946}}], 
     PolygonBox[{{55.89255650988789, -5.892556509887892}, {
      58.83883476483184, -8.838834764831839}, {62.5, -12.499999999999996`}, {
      58.33333333333333, -8.33333333333333}, {
      55.89255650988789, -5.892556509887892}}], 
     PolygonBox[{{50., 0.}, {54.166666666666664`, -4.166666666666665}, {
      55.10310363079829, -5.103103630798287}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{54.166666666666664`, -4.166666666666665}, {
      58.33333333333333, -8.33333333333333}, {
      60.206207261596575`, -10.206207261596575`}, {
      55.10310363079829, -5.103103630798287}, {
      54.166666666666664`, -4.166666666666665}}], 
     PolygonBox[{{58.33333333333333, -8.33333333333333}, {
      62.5, -12.499999999999996`}, {
      65.30931089239486, -15.309310892394864`}, {
      60.206207261596575`, -10.206207261596575`}, {
      58.33333333333333, -8.33333333333333}}], 
     PolygonBox[{{50., 0.}, {55.10310363079829, -5.1031036307982856`}, {
      55.69177251576849, -5.691772515768494}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{55.10310363079829, -5.1031036307982856`}, {
      60.206207261596575`, -10.206207261596571`}, {
      61.38354503153699, -11.383545031536988`}, {
      55.69177251576849, -5.691772515768494}, {
      55.10310363079829, -5.1031036307982856`}}], 
     PolygonBox[{{60.206207261596575`, -10.206207261596571`}, {
      65.30931089239486, -15.309310892394858`}, {
      67.07531754730547, -17.07531754730548}, {
      61.38354503153699, -11.383545031536988`}, {
      60.206207261596575`, -10.206207261596571`}}], 
     PolygonBox[{{50., 0.}, {55.69177251576849, -5.691772515768494}, {
      55.892556509887896`, -5.8925565098878945`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{55.69177251576849, -5.691772515768494}, {
      61.38354503153699, -11.383545031536988`}, {
      61.78511301977579, -11.785113019775789`}, {
      55.892556509887896`, -5.8925565098878945`}, {
      55.69177251576849, -5.691772515768494}}], 
     PolygonBox[{{61.38354503153699, -11.383545031536988`}, {
      67.07531754730547, -17.07531754730548}, {
      67.67766952966369, -17.677669529663685`}, {
      61.78511301977579, -11.785113019775789`}, {
      61.38354503153699, -11.383545031536988`}}], 
     PolygonBox[{{50., 0.}, {55.892556509887896`, -5.8925565098878945`}, {
      55.69177251576849, -5.691772515768494}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{55.892556509887896`, -5.8925565098878945`}, {
      61.78511301977579, -11.785113019775789`}, {
      61.38354503153699, -11.383545031536988`}, {
      55.69177251576849, -5.691772515768494}, {
      55.892556509887896`, -5.8925565098878945`}}], 
     PolygonBox[{{61.78511301977579, -11.785113019775789`}, {
      67.67766952966369, -17.677669529663685`}, {
      67.07531754730547, -17.07531754730548}, {
      61.38354503153699, -11.383545031536988`}, {
      61.78511301977579, -11.785113019775789`}}], 
     PolygonBox[{{50., 0.}, {55.69177251576849, -5.691772515768494}, {
      55.10310363079829, -5.103103630798287}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{55.69177251576849, -5.691772515768494}, {
      61.38354503153699, -11.383545031536988`}, {
      60.206207261596575`, -10.206207261596575`}, {
      55.10310363079829, -5.103103630798287}, {
      55.69177251576849, -5.691772515768494}}], 
     PolygonBox[{{61.38354503153699, -11.383545031536988`}, {
      67.07531754730549, -17.075317547305485`}, {
      65.30931089239486, -15.309310892394864`}, {
      60.206207261596575`, -10.206207261596575`}, {
      61.38354503153699, -11.383545031536988`}}], 
     PolygonBox[{{50., 0.}, {55.10310363079829, -5.103103630798287}, {
      54.166666666666664`, -4.166666666666667}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{55.10310363079829, -5.103103630798287}, {
      60.206207261596575`, -10.206207261596575`}, {
      58.333333333333336`, -8.333333333333334}, {
      54.166666666666664`, -4.166666666666667}, {
      55.10310363079829, -5.103103630798287}}], 
     PolygonBox[{{60.206207261596575`, -10.206207261596575`}, {
      65.30931089239486, -15.309310892394864`}, {
      62.5, -12.500000000000002`}, {
      58.333333333333336`, -8.333333333333334}, {
      60.206207261596575`, -10.206207261596575`}}], 
     PolygonBox[{{50., 0.}, {54.16666666666667, -4.166666666666668}, {
      52.94627825494395, -2.94627825494395}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{54.16666666666667, -4.166666666666668}, {
      58.333333333333336`, -8.333333333333336}, {
      55.892556509887896`, -5.8925565098879}, {
      52.94627825494395, -2.94627825494395}, {
      54.16666666666667, -4.166666666666668}}], 
     PolygonBox[{{58.333333333333336`, -8.333333333333336}, {
      62.5, -12.500000000000004`}, {58.83883476483185, -8.838834764831851}, {
      55.892556509887896`, -5.8925565098879}, {
      58.333333333333336`, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {52.94627825494395, -2.94627825494395}, {
      51.525105849101834`, -1.525105849101832}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{52.94627825494395, -2.94627825494395}, {
      55.892556509887896`, -5.8925565098879}, {
      53.05021169820366, -3.050211698203664}, {
      51.525105849101834`, -1.525105849101832}, {
      52.94627825494395, -2.94627825494395}}], 
     PolygonBox[{{55.892556509887896`, -5.8925565098879}, {
      58.83883476483185, -8.838834764831851}, {
      54.575317547305495`, -4.575317547305496}, {
      53.05021169820366, -3.050211698203664}, {
      55.892556509887896`, -5.8925565098879}}], 
     PolygonBox[{{50., 0.}, {51.525105849101834`, -1.525105849101832}, {
      50.00000000000001, -6.316086599240283*^-15}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{51.525105849101834`, -1.525105849101832}, {
      53.05021169820366, -3.050211698203664}, {
      50.000000000000014`, -1.2632173198480566`*^-14}, {
      50.00000000000001, -6.316086599240283*^-15}, {
      51.525105849101834`, -1.525105849101832}}], 
     PolygonBox[{{53.05021169820366, -3.050211698203664}, {
      54.575317547305495`, -4.575317547305496}, {
      50.00000000000002, -1.894825979772085*^-14}, {
      50.000000000000014`, -1.2632173198480566`*^-14}, {
      53.05021169820366, -3.050211698203664}}], 
     PolygonBox[{{50., 0.}, {50., -1.0824450702943664`*^-15}, {
      48.47489415089817, 1.5251058491018248`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50., -1.0824450702943664`*^-15}, {
      50., -2.1648901405887327`*^-15}, {46.94978830179635, 
      3.0502116982036496`}, {48.47489415089817, 1.5251058491018248`}, {
      50., -1.0824450702943664`*^-15}}], 
     PolygonBox[{{50., -2.1648901405887327`*^-15}, {
      50., -3.2473352108830995`*^-15}, {45.424682452694526`, 
      4.575317547305474}, {46.94978830179635, 3.0502116982036496`}, {
      50., -2.1648901405887327`*^-15}}], 
     PolygonBox[{{50., 0.}, {48.47489415089817, 1.5251058491018248`}, {
      47.05372174505606, 2.9462782549439437`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{48.47489415089817, 1.5251058491018248`}, {46.94978830179635,
       3.0502116982036496`}, {44.10744349011211, 5.892556509887887}, {
      47.05372174505606, 2.9462782549439437`}, {48.47489415089817, 
      1.5251058491018248`}}], 
     PolygonBox[{{46.94978830179635, 3.0502116982036496`}, {
      45.424682452694526`, 4.575317547305474}, {41.16116523516817, 
      8.838834764831832}, {44.10744349011211, 5.892556509887887}, {
      46.94978830179635, 3.0502116982036496`}}], 
     PolygonBox[{{50., 0.}, {47.05372174505606, 2.9462782549439437`}, {
      45.833333333333336`, 4.166666666666662}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{47.05372174505606, 2.9462782549439437`}, {44.10744349011211,
       5.892556509887887}, {41.66666666666668, 8.333333333333323}, {
      45.833333333333336`, 4.166666666666662}, {47.05372174505606, 
      2.9462782549439437`}}], 
     PolygonBox[{{44.10744349011211, 5.892556509887887}, {41.16116523516817, 
      8.838834764831832}, {37.500000000000014`, 12.499999999999988`}, {
      41.66666666666668, 8.333333333333323}, {44.10744349011211, 
      5.892556509887887}}], 
     PolygonBox[{{50., 0.}, {45.833333333333336`, 4.166666666666665}, {
      44.89689636920171, 5.1031036307982856`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{45.833333333333336`, 4.166666666666665}, {41.66666666666667,
       8.33333333333333}, {39.793792738403425`, 10.206207261596571`}, {
      44.89689636920171, 5.1031036307982856`}, {45.833333333333336`, 
      4.166666666666665}}], 
     PolygonBox[{{41.66666666666667, 8.33333333333333}, {37.5, 
      12.499999999999996`}, {34.690689107605145`, 15.309310892394857`}, {
      39.793792738403425`, 10.206207261596571`}, {41.66666666666667, 
      8.33333333333333}}], 
     PolygonBox[{{50., 0.}, {44.89689636920171, 5.1031036307982856`}, {
      44.30822748423151, 5.691772515768492}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{44.89689636920171, 5.1031036307982856`}, {
      39.793792738403425`, 10.206207261596571`}, {38.61645496846302, 
      11.383545031536984`}, {44.30822748423151, 5.691772515768492}, {
      44.89689636920171, 5.1031036307982856`}}], 
     PolygonBox[{{39.793792738403425`, 10.206207261596571`}, {
      34.690689107605145`, 15.309310892394857`}, {32.924682452694526`, 
      17.075317547305477`}, {38.61645496846302, 11.383545031536984`}, {
      39.793792738403425`, 10.206207261596571`}}], 
     PolygonBox[{{50., 0.}, {44.30822748423151, 5.691772515768492}, {
      44.107443490112104`, 5.8925565098878945`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{44.30822748423151, 5.691772515768492}, {38.61645496846302, 
      11.383545031536984`}, {38.21488698022421, 11.785113019775789`}, {
      44.107443490112104`, 5.8925565098878945`}, {44.30822748423151, 
      5.691772515768492}}], 
     PolygonBox[{{38.61645496846302, 11.383545031536984`}, {
      32.924682452694526`, 17.075317547305477`}, {32.32233047033631, 
      17.677669529663685`}, {38.21488698022421, 11.785113019775789`}, {
      38.61645496846302, 11.383545031536984`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvcTnm7yTpoPD9jThA9VrDR3YD877F13m4PCp9hCT
h7ChA1e+TkNGhKPDTWe//7Hz9BwYQOCAE4Rm0HQIUvvNv3CKi8NOsH5FBzaQ
/m1uDue+c3Ir+ApB1Xk6TD9eNOVp/WWbn3aJjEs8vR2OQ+QPrL3J8iEu29dh
K0T/AbByB3+Hf/9BQONA9YmX+08HBzhcg9h/oGb+BoZLRwJg7juwDqT/dQDM
/QdqofKfofIw/VD3w81ngrj/wHqo/Xug9v+Guu8m1H0w9ydpr4m7Yf92DwfU
fweg/guB+n8j1P+w8IG634EbGn5XoeHHAQ3fj9DwRQ9/AKJRpQU=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {50., -50.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 0.}, {50., -50.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043614073267`*^9, 3.563458240679139*^9, 
  3.5644876995076847`*^9, 3.566100840939961*^9, 3.601301585283011*^9, 
  3.614709349896215*^9, 3.6147292082276373`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[348]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.45`", ",", "0.45`"}], "}"}]], "Output",
 CellChangeTimes->{3.563404361411758*^9, 3.563458240683072*^9, 
  3.564487699511298*^9, 3.566100840946055*^9, 3.6013015852876787`*^9, 
  3.614709349901779*^9, 3.6147292082317333`*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"Out[350]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["AddTo -> CreatedRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" conserves the total number of rays.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[{
 "In contrast, the ",
 StyleBox["AddTo -> NewRay", "Input"],
 " setting causes an additional ray to be generated by ",
 StyleBox["CustomDeflections", "Input"],
 " for each ray already present. In this example, four rays are now created \
at the beamsplitter surface instead of two."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[CellGroupData[{

Cell["\<\
colorsplitter = 
\tCustomDeflections[BeamSplitter[{50,50},50],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAddTo->NewRay
\t];
TurboPlot[{SingleRay[],Move[colorsplitter,50,45],Boundary[100]},PlotType->\
TopView, ShowArrows->True];
ReadTurboRays[%, WaveLength, ComponentNumber -> 2]\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"In[351]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJyVWH9sU1UUfmzqpoC/AJ0aw0iQOTAGJDFRG3dHSdlWV+fYKmE4keBUjFlk
rpFM3DRxicoaf8AgIZaRdMDoyo9EMJCSVUTnMtREnKGJQSJO+aHEsWSKU2r3
ek5Dv9ubU1/SP07e/b7vfH33vXPPmbWqsfrZXMuyahK/axO/nMRvT+yaP+ov
VKlPGqZFW8ILohifPV636fWfPWr7wsbav98vSsVdFJvWd8F6xr/yS7ii5JKb
4tu1GPHS+knWxFWujj/S2hDoGotYFFt04Xq8j/GGO6oPRKe6VCC5XnVQvJVi
XI/3EV+wMLjmjbucFBdpMeKl9cHHxmYuKlb8f6tuig9SjOtNfjf3r9043HrG
wXHP+Mfj50pOp+Kmpy9+/kP8kMOEx/uIb7bvx4BvwMiP9xG/xc73RCreDDHi
8T7GzRnziQn8MSPeB352Zfw/Y8b7rwJ+1bze+pMlHQ9x3AnPC/H8ZHD/LVPv
xJuKXMr5bzh35bHblOl5mvC4n/a2TY//6nES3xyNX8Lj/s37NHClzqfUpfVH
c8qmLdD4pf2M+nu+ubHtq7Uu9d6bb8c/fGG66BfxqL9i293W1mEn8c3W+CU8
+ruh8b6255eVqpjTE38qcL/Gj3jMF/VDuxPXeZfabV83i34Rj/re2sQ1tJj4
CjV+CY/+bNHoItIv1vgRj/mi/hdTepafbl9C3/M80S/iUZ/3K9UHjV/Co7/q
OeM3bd+4WB2y9/csjT8j/qp8UT+86ceaAUeZeq5i6uqhhr9KJL+IR/3l8/p6
Pli3hPjyNX4Jj/6um9jfB13q6z+vn1xYeavGj3jM1+SvZfB8+8gtp4z1x4RH
/XS+i470+JRDwqO/uH2VqY8K5t/T3DHmQH6TPubP9W/pmsLQg5+Vq/qkfh+s
b5Pw6fGAY8d3yvtSewXx5UdN/FL95fp3+dFnJgXL3ao/6T+K/CY854/6D496
u2euq6DzTl4U10t41G+i8x2dn6LIL+HRX3jiPPtipTqQ3N8av8k/54v6E697
7Qy36kl+P0S/iEd9m2ZuJfEVavwSHv3ZqupxdcXe1/dq/IjHfFG/ev5I6wMd
bq4Pol/Eo35w5U/x1Xd6uD5o/BIe/bV8ea5vcGkV1yeNPyP+qnxZ30/6u/qa
rQ0n3Vz/Rb+IZ30/6T/ResEq2O/h+q/xS3j29z35e23bPuvbY1V8/tD4EY/5
oj73UwHDfpDwqM/9XgD6PeaX8OjP1I8yP+IxX0lf8ot4SV/6fxGP/qTni3jp
+fzf91d6PtL7K+HXk79R8ie9v9LzNX0/Qll+nxGP+iH6foTg+8z8Eh792aqJ
71dyzlGs8SMe8/WSfi/Uh2CW9RfxrN9L+rxfg1B/mV/Cs78c8reX6lOE6hPy
Z8RnqJ+sX0P135fd+UrDo/5Oqv8+qv/IL+HR3zidP2J0/kB+xGO+qM/zsLeG
3z08+vI/OA/T/CIe9XPS+KYcQX4Jj/5yCT/7t7ODvtoZR5Af8ab8k/OQExE+
v3uz6480fHp8JlJH53cv9EfIb8JznJzf/B7Jp/4hSv0D8pvwnDnq91N/1pll
/4t41Of5Yyf1Z8gv4dFfDfWH+6k/RH6Tf84X9bn/7qb+W/KLeNR/kvrvbuq/
kV/Coz97/yb6/8vJ86XGj3jMl/Xp/Jqar/iznF8hnucLdH5NzVf8ML/yw/zI
hLfIH52f1WSa7wzB/MoP86M0fIb5kx/mZ6VZzicRj/r7aH5WCvPJUpgPmvDo
L5/mdyM0v0N+xGO+qI/zUckv4lEf56Om+a8Jj/5wPov8iP8P4MWsTw==
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{67.67766952966369, -17.677669529663685`}, {
       61.78511301977579, -11.785113019775793`}, {
       55.892556509887896`, -5.892556509887897}, {
       50., -2.51214793389404*^-15}, {44.10744349011211, 5.892556509887892}, {
       38.214886980224215`, 11.785113019775784`}, {32.32233047033632, 
       17.67766952966368}, {32.32233047033631, 17.677669529663685`}, {
       38.21488698022421, 11.785113019775793`}, {44.107443490112104`, 
       5.892556509887897}, {50., 2.51214793389404*^-15}, {
       55.89255650988789, -5.892556509887892}, {
       61.785113019775785`, -11.785113019775784`}, {
       67.67766952966369, -17.67766952966368}, {
       67.67766952966369, -17.677669529663685`}}, {{50., 0.}, {50., 0.}, {50.,
        0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQvcTnm7yTpoPD9jThA9VrDR3YD877F13m4PCp9hCT
h7ChA1e+TkNGhKPDTWe//7Hz9BwYQOCAE4Rm0HQIUvvNv3CKi8NOsH5FBzaQ
/m1uDue+c3Ir+ApB1Xk6TD9eNOVp/WWbn3aJjEs8vR2OQ+QPrL3J8iEu29dh
K0T/AbByB3+Hf/9BQONA9YmX+08HBzhcg9h/oGb+BoZLRwJg7juwDqT/dQDM
/QdqofKfofIw/VD3w81ngrj/wHqo/Xug9v+Guu8m1H0w9ydpr4m7Yf92DwfU
fweg/guB+n8j1P+w8IG634EbGn5XoeHHAQ3fj9DwRQ9/AKJRpQU=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFIBwjt6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AY+ki2A==
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Arrowheads[Small], 
    ArrowBox[{{0., 0.}, {50., 0.}}], 
    {Arrowheads[Small], ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {Arrowheads[Small], ArrowBox[{{50., 0.}, {50., -50.}}]}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {50., -50.}}], 
      {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], 
       PointBox[{{50., 0.}, {100., 0.}, {50., -50.}, {100., 0.}, {
        50., -50.}}]}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404362407187*^9, 3.563458241481192*^9, 
  3.564487700265394*^9, 3.566100842791883*^9, 3.601301586516885*^9, 
  3.6147093511345873`*^9, 3.614729209385724*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"During evaluation of In[351]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.532`", ",", "0.532`", ",", "0.45`", ",", "0.45`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5634043624108953`*^9, 3.563458241484125*^9, 
  3.564487700268374*^9, 3.566100842797234*^9, 3.601301586521315*^9, 
  3.6147093511375437`*^9, 3.614729209388825*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"},
 CellLabel->"Out[353]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["AddTo -> NewRay", "Input",
  FontSlant->"Plain"],
 StyleBox[" produces four rays with the beamsplitter.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6.4 Redirecting RayTilt with CustomDeflections", "Subsection",
 CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[{
 "Of course, one of the most important actions in ray-tracing is the ability \
to change the direction of a ray at an optical surface. In ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", the direction of the ray is governed by the ",
 StyleBox["RayTilt", "Input"],
 " parameter. The ",
 StyleBox["RayTilt", "Input"],
 " parameter is a three-dimensional unit direction vector. In order to change \
the ray direction, you need to set the ",
 StyleBox["RayTilt", "Input"],
 " of the ray to the desired direction.  We can demonstrate this by creating \
a new type of optic that focusses the rays to a fixed point in space. First, \
let us consider the behavior of a normal mirror optic, illustrated below. In \
the case of a mirror, the rays continue to diverge after the mirror. In our \
new custom optic, we will cause the rays to focus after its surface."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tWedgeOfRays[10],
\tMove[Mirror[50],100,-45],
\tBoundary[200]},PlotType->TopView];\
\>", "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"In[354]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{82.32233047033631, -17.677669529663685`}, {
      82.32233047033631, -17.677669529663685`}, {
      88.21488698022421, -11.785113019775794`}, {
      88.21488698022421, -11.785113019775793`}, {
      82.32233047033631, -17.677669529663685`}}], 
     PolygonBox[{{88.21488698022421, -11.785113019775793`}, {
      88.21488698022421, -11.785113019775794`}, {
      94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {
      88.21488698022421, -11.785113019775793`}}], 
     PolygonBox[{{94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {100., -5.02429586778808*^-15}, {
      100., 0.}, {94.1074434901121, -5.892556509887897}}], 
     PolygonBox[{{100., 0.}, {100., 0.}, {105.8925565098879, 
      5.8925565098878945`}, {105.8925565098879, 5.892556509887892}, {100., 
      0.}}], PolygonBox[{{105.8925565098879, 5.892556509887892}, {
      105.8925565098879, 5.8925565098878945`}, {111.78511301977579`, 
      11.785113019775789`}, {111.78511301977579`, 11.785113019775789`}, {
      105.8925565098879, 5.892556509887892}}], 
     PolygonBox[{{111.78511301977579`, 11.785113019775789`}, {
      111.78511301977579`, 11.785113019775789`}, {117.67766952966369`, 
      17.677669529663685`}, {117.67766952966369`, 17.67766952966368}, {
      111.78511301977579`, 11.785113019775789`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{82.32233047033631, -17.677669529663685`}, {
       88.21488698022421, -11.785113019775793`}, {
       94.1074434901121, -5.892556509887897}, {
       100., -2.51214793389404*^-15}, {105.8925565098879, 
       5.892556509887892}, {111.78511301977578`, 11.785113019775784`}, {
       117.67766952966369`, 17.67766952966368}, {117.67766952966369`, 
       17.677669529663685`}, {111.78511301977579`, 11.785113019775793`}, {
       105.8925565098879, 5.892556509887897}, {100., 2.51214793389404*^-15}, {
       94.1074434901121, -5.892556509887892}, {
       88.21488698022422, -11.785113019775784`}, {
       82.32233047033631, -17.67766952966368}, {
       82.32233047033631, -17.677669529663685`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., 0.}, {100., 2.164890140588733*^-15}, {100., 
        1.804075117157278*^-15}, {100., 3.6081502343145547`*^-16}, {100., 
        0.}}], PolygonBox[{{100., 3.6081502343145547`*^-16}, {100., 
        1.804075117157278*^-15}, {100., 1.4432600937258223`*^-15}, {100., 
        7.216300468629109*^-16}, {100., 3.6081502343145547`*^-16}}], 
       PolygonBox[{{100., 7.216300468629109*^-16}, {100., 
        1.4432600937258223`*^-15}, {100., 1.0824450702943668`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629109*^-16}}], 
       PolygonBox[{{100., 1.0824450702943666`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629111*^-16}, {100., 
        1.4432600937258219`*^-15}, {100., 1.0824450702943666`*^-15}}], 
       PolygonBox[{{100., 1.4432600937258219`*^-15}, {100., 
        7.216300468629111*^-16}, {100., 3.608150234314556*^-16}, {100., 
        1.8040751171572774`*^-15}, {100., 1.4432600937258219`*^-15}}], 
       PolygonBox[{{100., 1.8040751171572774`*^-15}, {100., 
        3.608150234314557*^-16}, {100., 1.8026331598992026`*^-31}, {100., 
        2.1648901405887327`*^-15}, {100., 1.8040751171572774`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {
         100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 
         0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100., 0.}, {105.8925565098879, 5.8925565098878945`}, {
      105.69177251576849`, 5.691772515768494}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{105.8925565098879, 5.8925565098878945`}, {
      111.78511301977579`, 11.785113019775789`}, {111.38354503153698`, 
      11.383545031536988`}, {105.69177251576849`, 5.691772515768494}, {
      105.8925565098879, 5.8925565098878945`}}], 
     PolygonBox[{{111.78511301977579`, 11.785113019775789`}, {
      117.67766952966369`, 17.677669529663685`}, {117.07531754730547`, 
      17.07531754730548}, {111.38354503153698`, 11.383545031536988`}, {
      111.78511301977579`, 11.785113019775789`}}], 
     PolygonBox[{{100., 0.}, {105.69177251576849`, 5.691772515768494}, {
      105.10310363079829`, 5.103103630798287}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{105.69177251576849`, 5.691772515768494}, {
      111.38354503153698`, 11.383545031536988`}, {110.20620726159657`, 
      10.206207261596575`}, {105.10310363079829`, 5.103103630798287}, {
      105.69177251576849`, 5.691772515768494}}], 
     PolygonBox[{{111.38354503153698`, 11.383545031536988`}, {
      117.07531754730547`, 17.07531754730548}, {115.30931089239486`, 
      15.309310892394864`}, {110.20620726159657`, 10.206207261596575`}, {
      111.38354503153698`, 11.383545031536988`}}], 
     PolygonBox[{{100., 0.}, {105.10310363079829`, 5.103103630798287}, {
      104.16666666666667`, 4.166666666666666}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{105.10310363079829`, 5.103103630798287}, {
      110.20620726159657`, 10.206207261596575`}, {108.33333333333333`, 
      8.333333333333332}, {104.16666666666667`, 4.166666666666666}, {
      105.10310363079829`, 5.103103630798287}}], 
     PolygonBox[{{110.20620726159657`, 10.206207261596575`}, {
      115.30931089239486`, 15.309310892394864`}, {112.5, 12.5}, {
      108.33333333333333`, 8.333333333333332}, {110.20620726159657`, 
      10.206207261596575`}}], 
     PolygonBox[{{100., 0.}, {104.16666666666667`, 4.166666666666666}, {
      102.94627825494395`, 2.9462782549439486`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{104.16666666666667`, 4.166666666666666}, {
      108.33333333333333`, 8.333333333333332}, {105.8925565098879, 
      5.892556509887897}, {102.94627825494395`, 2.9462782549439486`}, {
      104.16666666666667`, 4.166666666666666}}], 
     PolygonBox[{{108.33333333333333`, 8.333333333333332}, {112.5, 12.5}, {
      108.83883476483184`, 8.838834764831846}, {105.8925565098879, 
      5.892556509887897}, {108.33333333333333`, 8.333333333333332}}], 
     PolygonBox[{{100., 0.}, {102.94627825494395`, 2.9462782549439486`}, {
      101.52510584910183`, 1.5251058491018286`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{102.94627825494395`, 2.9462782549439486`}, {
      105.8925565098879, 5.892556509887897}, {103.05021169820365`, 
      3.050211698203657}, {101.52510584910183`, 1.5251058491018286`}, {
      102.94627825494395`, 2.9462782549439486`}}], 
     PolygonBox[{{105.8925565098879, 5.892556509887897}, {108.83883476483184`,
       8.838834764831846}, {104.57531754730549`, 4.575317547305486}, {
      103.05021169820365`, 3.050211698203657}, {105.8925565098879, 
      5.892556509887897}}], 
     PolygonBox[{{100., 0.}, {101.52510584910183`, 1.5251058491018286`}, {
      100., 1.6692254056679344`*^-15}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{101.52510584910183`, 1.5251058491018286`}, {
      103.05021169820365`, 3.050211698203657}, {100., 
      3.3384508113358688`*^-15}, {100., 1.6692254056679344`*^-15}, {
      101.52510584910183`, 1.5251058491018286`}}], 
     PolygonBox[{{103.05021169820365`, 3.050211698203657}, {
      104.57531754730549`, 4.575317547305486}, {100., 
      5.007676217003804*^-15}, {100., 3.3384508113358688`*^-15}, {
      103.05021169820365`, 3.050211698203657}}], 
     PolygonBox[{{100., 0.}, {100., 3.6081502343145547`*^-16}, {
      98.47489415089818, -1.5251058491018266`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., 3.6081502343145547`*^-16}, {100., 
      7.216300468629109*^-16}, {96.94978830179635, -3.050211698203653}, {
      98.47489415089818, -1.5251058491018266`}, {100., 
      3.6081502343145547`*^-16}}], 
     PolygonBox[{{100., 7.216300468629109*^-16}, {100., 
      1.0824450702943666`*^-15}, {95.42468245269453, -4.57531754730548}, {
      96.94978830179635, -3.050211698203653}, {100., 
      7.216300468629109*^-16}}], 
     PolygonBox[{{100., 0.}, {98.47489415089818, -1.5251058491018266`}, {
      97.05372174505605, -2.946278254943946}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{98.47489415089818, -1.5251058491018266`}, {
      96.94978830179635, -3.050211698203653}, {
      94.1074434901121, -5.892556509887892}, {
      97.05372174505605, -2.946278254943946}, {
      98.47489415089818, -1.5251058491018266`}}], 
     PolygonBox[{{96.94978830179635, -3.050211698203653}, {
      95.42468245269453, -4.57531754730548}, {
      91.16116523516816, -8.838834764831839}, {
      94.1074434901121, -5.892556509887892}, {
      96.94978830179635, -3.050211698203653}}], 
     PolygonBox[{{100., 0.}, {97.05372174505605, -2.946278254943946}, {
      95.83333333333333, -4.166666666666665}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{97.05372174505605, -2.946278254943946}, {
      94.1074434901121, -5.892556509887892}, {
      91.66666666666667, -8.33333333333333}, {
      95.83333333333333, -4.166666666666665}, {
      97.05372174505605, -2.946278254943946}}], 
     PolygonBox[{{94.1074434901121, -5.892556509887892}, {
      91.16116523516816, -8.838834764831839}, {87.5, -12.499999999999996`}, {
      91.66666666666667, -8.33333333333333}, {
      94.1074434901121, -5.892556509887892}}], 
     PolygonBox[{{100., 0.}, {95.83333333333333, -4.166666666666665}, {
      94.89689636920171, -5.103103630798287}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{95.83333333333333, -4.166666666666665}, {
      91.66666666666667, -8.33333333333333}, {
      89.79379273840343, -10.206207261596575`}, {
      94.89689636920171, -5.103103630798287}, {
      95.83333333333333, -4.166666666666665}}], 
     PolygonBox[{{91.66666666666667, -8.33333333333333}, {
      87.5, -12.499999999999996`}, {
      84.69068910760514, -15.309310892394864`}, {
      89.79379273840343, -10.206207261596575`}, {
      91.66666666666667, -8.33333333333333}}], 
     PolygonBox[{{100., 0.}, {94.89689636920171, -5.1031036307982856`}, {
      94.30822748423151, -5.691772515768494}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{94.89689636920171, -5.1031036307982856`}, {
      89.79379273840343, -10.206207261596571`}, {
      88.61645496846302, -11.383545031536988`}, {
      94.30822748423151, -5.691772515768494}, {
      94.89689636920171, -5.1031036307982856`}}], 
     PolygonBox[{{89.79379273840343, -10.206207261596571`}, {
      84.69068910760514, -15.309310892394858`}, {
      82.92468245269453, -17.07531754730548}, {
      88.61645496846302, -11.383545031536988`}, {
      89.79379273840343, -10.206207261596571`}}], 
     PolygonBox[{{100., 0.}, {94.30822748423151, -5.691772515768494}, {
      94.1074434901121, -5.8925565098878945`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{94.30822748423151, -5.691772515768494}, {
      88.61645496846302, -11.383545031536988`}, {
      88.21488698022421, -11.785113019775789`}, {
      94.1074434901121, -5.8925565098878945`}, {
      94.30822748423151, -5.691772515768494}}], 
     PolygonBox[{{88.61645496846302, -11.383545031536988`}, {
      82.92468245269453, -17.07531754730548}, {
      82.32233047033631, -17.677669529663685`}, {
      88.21488698022421, -11.785113019775789`}, {
      88.61645496846302, -11.383545031536988`}}], 
     PolygonBox[{{100., 0.}, {94.1074434901121, -5.8925565098878945`}, {
      94.30822748423151, -5.691772515768494}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{94.1074434901121, -5.8925565098878945`}, {
      88.21488698022421, -11.785113019775789`}, {
      88.61645496846302, -11.383545031536988`}, {
      94.30822748423151, -5.691772515768494}, {
      94.1074434901121, -5.8925565098878945`}}], 
     PolygonBox[{{88.21488698022421, -11.785113019775789`}, {
      82.32233047033631, -17.677669529663685`}, {
      82.92468245269453, -17.07531754730548}, {
      88.61645496846302, -11.383545031536988`}, {
      88.21488698022421, -11.785113019775789`}}], 
     PolygonBox[{{100., 0.}, {94.30822748423151, -5.691772515768494}, {
      94.89689636920171, -5.103103630798287}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{94.30822748423151, -5.691772515768494}, {
      88.61645496846302, -11.383545031536988`}, {
      89.79379273840343, -10.206207261596575`}, {
      94.89689636920171, -5.103103630798287}, {
      94.30822748423151, -5.691772515768494}}], 
     PolygonBox[{{88.61645496846302, -11.383545031536988`}, {
      82.92468245269451, -17.075317547305485`}, {
      84.69068910760514, -15.309310892394864`}, {
      89.79379273840343, -10.206207261596575`}, {
      88.61645496846302, -11.383545031536988`}}], 
     PolygonBox[{{100., 0.}, {94.89689636920171, -5.103103630798287}, {
      95.83333333333333, -4.166666666666667}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{94.89689636920171, -5.103103630798287}, {
      89.79379273840343, -10.206207261596575`}, {
      91.66666666666667, -8.333333333333334}, {
      95.83333333333333, -4.166666666666667}, {
      94.89689636920171, -5.103103630798287}}], 
     PolygonBox[{{89.79379273840343, -10.206207261596575`}, {
      84.69068910760514, -15.309310892394864`}, {
      87.5, -12.500000000000002`}, {91.66666666666667, -8.333333333333334}, {
      89.79379273840343, -10.206207261596575`}}], 
     PolygonBox[{{100., 0.}, {95.83333333333333, -4.166666666666668}, {
      97.05372174505605, -2.94627825494395}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{95.83333333333333, -4.166666666666668}, {
      91.66666666666666, -8.333333333333336}, {
      94.1074434901121, -5.8925565098879}, {
      97.05372174505605, -2.94627825494395}, {
      95.83333333333333, -4.166666666666668}}], 
     PolygonBox[{{91.66666666666666, -8.333333333333336}, {
      87.5, -12.500000000000004`}, {91.16116523516814, -8.838834764831851}, {
      94.1074434901121, -5.8925565098879}, {
      91.66666666666666, -8.333333333333336}}], 
     PolygonBox[{{100., 0.}, {97.05372174505605, -2.94627825494395}, {
      98.47489415089817, -1.525105849101832}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{97.05372174505605, -2.94627825494395}, {
      94.1074434901121, -5.8925565098879}, {
      96.94978830179633, -3.050211698203664}, {
      98.47489415089817, -1.525105849101832}, {
      97.05372174505605, -2.94627825494395}}], 
     PolygonBox[{{94.1074434901121, -5.8925565098879}, {
      91.16116523516814, -8.838834764831851}, {
      95.4246824526945, -4.575317547305496}, {
      96.94978830179633, -3.050211698203664}, {
      94.1074434901121, -5.8925565098879}}], 
     PolygonBox[{{100., 0.}, {98.47489415089817, -1.525105849101832}, {
      100., -6.316086599240283*^-15}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{98.47489415089817, -1.525105849101832}, {
      96.94978830179633, -3.050211698203664}, {
      99.99999999999999, -1.2632173198480566`*^-14}, {
      100., -6.316086599240283*^-15}, {
      98.47489415089817, -1.525105849101832}}], 
     PolygonBox[{{96.94978830179633, -3.050211698203664}, {
      95.4246824526945, -4.575317547305496}, {
      99.99999999999999, -1.894825979772085*^-14}, {
      99.99999999999999, -1.2632173198480566`*^-14}, {
      96.94978830179633, -3.050211698203664}}], 
     PolygonBox[{{100., 0.}, {100., -1.0824450702943664`*^-15}, {
      101.52510584910182`, 1.5251058491018248`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{100., -1.0824450702943664`*^-15}, {
      100., -2.1648901405887327`*^-15}, {103.05021169820365`, 
      3.0502116982036496`}, {101.52510584910182`, 1.5251058491018248`}, {
      100., -1.0824450702943664`*^-15}}], 
     PolygonBox[{{100., -2.1648901405887327`*^-15}, {
      100., -3.2473352108830995`*^-15}, {104.57531754730547`, 
      4.575317547305474}, {103.05021169820365`, 3.0502116982036496`}, {
      100., -2.1648901405887327`*^-15}}], 
     PolygonBox[{{100., 0.}, {101.52510584910182`, 1.5251058491018248`}, {
      102.94627825494395`, 2.9462782549439437`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{101.52510584910182`, 1.5251058491018248`}, {
      103.05021169820365`, 3.0502116982036496`}, {105.89255650988788`, 
      5.892556509887887}, {102.94627825494395`, 2.9462782549439437`}, {
      101.52510584910182`, 1.5251058491018248`}}], 
     PolygonBox[{{103.05021169820365`, 3.0502116982036496`}, {
      104.57531754730547`, 4.575317547305474}, {108.83883476483183`, 
      8.838834764831832}, {105.89255650988788`, 5.892556509887887}, {
      103.05021169820365`, 3.0502116982036496`}}], 
     PolygonBox[{{100., 0.}, {102.94627825494395`, 2.9462782549439437`}, {
      104.16666666666666`, 4.166666666666662}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{102.94627825494395`, 2.9462782549439437`}, {
      105.89255650988788`, 5.892556509887887}, {108.33333333333333`, 
      8.333333333333323}, {104.16666666666666`, 4.166666666666662}, {
      102.94627825494395`, 2.9462782549439437`}}], 
     PolygonBox[{{105.89255650988788`, 5.892556509887887}, {
      108.83883476483183`, 8.838834764831832}, {112.49999999999999`, 
      12.499999999999988`}, {108.33333333333333`, 8.333333333333323}, {
      105.89255650988788`, 5.892556509887887}}], 
     PolygonBox[{{100., 0.}, {104.16666666666667`, 4.166666666666665}, {
      105.10310363079829`, 5.1031036307982856`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{104.16666666666667`, 4.166666666666665}, {
      108.33333333333333`, 8.33333333333333}, {110.20620726159657`, 
      10.206207261596571`}, {105.10310363079829`, 5.1031036307982856`}, {
      104.16666666666667`, 4.166666666666665}}], 
     PolygonBox[{{108.33333333333333`, 8.33333333333333}, {112.5, 
      12.499999999999996`}, {115.30931089239486`, 15.309310892394857`}, {
      110.20620726159657`, 10.206207261596571`}, {108.33333333333333`, 
      8.33333333333333}}], 
     PolygonBox[{{100., 0.}, {105.10310363079829`, 5.1031036307982856`}, {
      105.69177251576849`, 5.691772515768492}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{105.10310363079829`, 5.1031036307982856`}, {
      110.20620726159657`, 10.206207261596571`}, {111.38354503153698`, 
      11.383545031536984`}, {105.69177251576849`, 5.691772515768492}, {
      105.10310363079829`, 5.1031036307982856`}}], 
     PolygonBox[{{110.20620726159657`, 10.206207261596571`}, {
      115.30931089239486`, 15.309310892394857`}, {117.07531754730547`, 
      17.075317547305477`}, {111.38354503153698`, 11.383545031536984`}, {
      110.20620726159657`, 10.206207261596571`}}], 
     PolygonBox[{{100., 0.}, {105.69177251576849`, 5.691772515768492}, {
      105.8925565098879, 5.8925565098878945`}, {100., 0.}, {100., 0.}}], 
     PolygonBox[{{105.69177251576849`, 5.691772515768492}, {
      111.38354503153698`, 11.383545031536984`}, {111.78511301977579`, 
      11.785113019775789`}, {105.8925565098879, 5.8925565098878945`}, {
      105.69177251576849`, 5.691772515768492}}], 
     PolygonBox[{{111.38354503153698`, 11.383545031536984`}, {
      117.07531754730547`, 17.075317547305477`}, {117.67766952966369`, 
      17.677669529663685`}, {111.78511301977579`, 11.785113019775789`}, {
      111.38354503153698`, 11.383545031536984`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQve4my4e47FiH7WnCB6rXGjrUzN/AcMkl1uFT7SEm
D2FDh+oTL/efvhzjcNPZ73/sPD0HBhBQiIHQDJoO13OYKtabRjvsBOtXdKgF
6VeJcjj3nZNbwVcIqi7SYfrxoilP6y/btCT4/9e9He5wHCJ/QHPy3/aAU2EO
WyH6D4CVPwh1+PcfBDQOtJqLOZjohDpcg9h/AKx/dwjMfQeC1H7zL5wSAnP/
gWao/GeoPEw/1P1w85kg7j+gAbV/D9T+Jqj7bkLdB3N/kvaauBv2b/fUQP13
AOq/a1D/b4T6HxY+UPfDw+8qNPxg4fsRGr7o4Q8AgdmmGQ==
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {200., -100.}, {200., 100.}, {
       200., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {0., -100.}, {0., -100.}, {200., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -100}, {0, 100}, {0, 100}, {0, -100}, {0, -100}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 100.}, {200., 100.}, {200., 100.}, {0., 100.}, {0., 
       100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {200., 100.}, {0., 100.}, {0., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {0., -100.}, {0., 100.}, {200., 
       100.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {109.5876796297105, 9.587679629710493}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {100., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {91.954981558864, -8.045018441135994}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.5876796297105, 9.587679629710493}, {117.49773270518477`, 
       100.}}]}, 
     {Arrowheads[Small], ArrowBox[{{100., 0.}, {100., 100.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.954981558864, -8.045018441135994}, {82.50226729481521, 
       100.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{109.5876796297105, 9.587679629710493}, {100., 0.}, {
      91.954981558864, -8.045018441135994}, {117.49773270518477`, 100.}, {
      100., 100.}, {82.50226729481521, 100.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043628917923`*^9, 3.563458241896517*^9, 
  3.564487700697481*^9, 3.566100843806979*^9, 3.601301587065154*^9, 
  3.6147093515373383`*^9, 3.61472920981213*^9},
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"During evaluation of In[354]:="]
}, Open  ]],

Cell[TextData[StyleBox["A normal mirror optic.", "Text"]], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[{
 "In order to build this new optic, we first need to create a ",
 StyleBox["Component", "Input"],
 " \"base\" for our ",
 StyleBox["CustomFunction", "Input"],
 " to operate on. We can do this with the ",
 StyleBox["ComponentFoundation", "Input"],
 " and ",
 StyleBox["ComponentRendering", "Input"],
 " functions as shown."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[CellGroupData[{

Cell["\<\
basecomponent = ComponentRendering[ComponentFoundation[Infinity,50]]\
\>", "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"In[355]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"ComponentRendering", "[", 
     RowBox[{"ComponentFoundation", "[", 
      RowBox[{"\[Infinity]", ",", "50.`"}], "]"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563404363422277*^9, 3.563458241928845*^9, 
  3.564487700725604*^9, 3.5661008439003057`*^9, 3.601301587096326*^9, 
  3.614709351570775*^9, 3.6147292098413773`*^9},
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"Out[355]="]
}, Open  ]],

Cell[TextData[{
 "This new ",
 StyleBox["basecomponent", "Input"],
 " is not capable of interacting with rays until we give it a ray-trace \
deflection property with a generic function such as: ",
 StyleBox["Transmission", "Input"],
 ", ",
 StyleBox["Reflection", "Input"],
 ", ",
 StyleBox["Refraction", "Input"],
 ", ",
 StyleBox["Diffraction", "Input"],
 ", or, in this instance, ",
 StyleBox["CustomDeflection", "Input"],
 ". If we try to trace rays through ",
 StyleBox["basecomponent", "Input"],
 " without deflection property, the rays pass through the component without \
any interaction. The component is \"invisible\" to the rays."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tWedgeOfRays[10],
\tMove[basecomponent,100,-45],
\tBoundary[200]}, PlotType->TopView];\
\>", "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"In[356]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {200., -100.}, {200., 100.}, {
       200., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {0., -100.}, {0., -100.}, {200., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -100}, {0, 100}, {0, 100}, {0, -100}, {0, -100}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 100.}, {200., 100.}, {200., 100.}, {0., 100.}, {0., 
       100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {200., 100.}, {0., 100.}, {0., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {0., -100.}, {0., 100.}, {200., 
       100.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{82.32233047033631, -17.677669529663685`}, {
      82.32233047033631, -17.677669529663685`}, {
      88.21488698022421, -11.785113019775794`}, {
      88.21488698022421, -11.785113019775793`}, {
      82.32233047033631, -17.677669529663685`}}], 
     PolygonBox[{{88.21488698022421, -11.785113019775793`}, {
      88.21488698022421, -11.785113019775794`}, {
      94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {
      88.21488698022421, -11.785113019775793`}}], 
     PolygonBox[{{94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {100., -5.02429586778808*^-15}, {
      100., 0.}, {94.1074434901121, -5.892556509887897}}], 
     PolygonBox[{{100., 0.}, {100., 0.}, {105.8925565098879, 
      5.8925565098878945`}, {105.8925565098879, 5.892556509887892}, {100., 
      0.}}], PolygonBox[{{105.8925565098879, 5.892556509887892}, {
      105.8925565098879, 5.8925565098878945`}, {111.78511301977579`, 
      11.785113019775789`}, {111.78511301977579`, 11.785113019775789`}, {
      105.8925565098879, 5.892556509887892}}], 
     PolygonBox[{{111.78511301977579`, 11.785113019775789`}, {
      111.78511301977579`, 11.785113019775789`}, {117.67766952966369`, 
      17.677669529663685`}, {117.67766952966369`, 17.67766952966368}, {
      111.78511301977579`, 11.785113019775789`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{82.32233047033631, -17.677669529663685`}, {
       88.21488698022421, -11.785113019775793`}, {
       94.1074434901121, -5.892556509887897}, {
       100., -2.51214793389404*^-15}, {105.8925565098879, 
       5.892556509887892}, {111.78511301977578`, 11.785113019775784`}, {
       117.67766952966369`, 17.67766952966368}, {117.67766952966369`, 
       17.677669529663685`}, {111.78511301977579`, 11.785113019775793`}, {
       105.8925565098879, 5.892556509887897}, {100., 2.51214793389404*^-15}, {
       94.1074434901121, -5.892556509887892}, {
       88.21488698022422, -11.785113019775784`}, {
       82.32233047033631, -17.67766952966368}, {
       82.32233047033631, -17.677669529663685`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., 0.}, {100., 2.164890140588733*^-15}, {100., 
        1.804075117157278*^-15}, {100., 3.6081502343145547`*^-16}, {100., 
        0.}}], PolygonBox[{{100., 3.6081502343145547`*^-16}, {100., 
        1.804075117157278*^-15}, {100., 1.4432600937258223`*^-15}, {100., 
        7.216300468629109*^-16}, {100., 3.6081502343145547`*^-16}}], 
       PolygonBox[{{100., 7.216300468629109*^-16}, {100., 
        1.4432600937258223`*^-15}, {100., 1.0824450702943668`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629109*^-16}}], 
       PolygonBox[{{100., 1.0824450702943666`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629111*^-16}, {100., 
        1.4432600937258219`*^-15}, {100., 1.0824450702943666`*^-15}}], 
       PolygonBox[{{100., 1.4432600937258219`*^-15}, {100., 
        7.216300468629111*^-16}, {100., 3.608150234314556*^-16}, {100., 
        1.8040751171572774`*^-15}, {100., 1.4432600937258219`*^-15}}], 
       PolygonBox[{{100., 1.8040751171572774`*^-15}, {100., 
        3.608150234314557*^-16}, {100., 1.8026331598992026`*^-31}, {100., 
        2.1648901405887327`*^-15}, {100., 1.8040751171572774`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {
         100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 
         0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}}]}}}}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {200., 17.4977327051848}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {200., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {200., -17.4977327051848}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{200., 17.4977327051848}, {200., 0.}, {
      200., -17.4977327051848}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404363775815*^9, 3.563458242170457*^9, 
  3.564487700962592*^9, 3.566100844601404*^9, 3.601301587348609*^9, 
  3.614709351828088*^9, 3.614729210095565*^9},
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"During evaluation of In[356]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["The rays pass through ", "Text"],
 StyleBox["basecomponent", "Input",
  FontSlant->"Plain"],
 StyleBox[" without interaction.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[{
 "We are now ready to prepare our ",
 StyleBox["CustomDeflections", "Input"],
 " function and use it to create a new ",
 StyleBox["customcomponent", "Input"],
 " optic. For this, we will cause the rays to focus at the fixed point of ",
 StyleBox["{100,100,0}", "Input"],
 " in the ray-trace space. In order to create a new direction vector for the \
ray, we use the ",
 StyleBox["{100,100,0}-(RayEnd/.#)", "Input"],
 ", where the ",
 StyleBox["RayEnd", "Input"],
 " parameter gives us the three-dimensional ray positions along the optical \
surface. Finally, the direction vector is normalized with ",
 StyleBox["(#/Sqrt[Dot[#,#]])&", "Input"],
 ", where ",
 StyleBox["( )&", "Input"],
 " is a short-hand notation for ",
 StyleBox["Function[ ]", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[CellGroupData[{

Cell[TextData[{
 "customcomponent = CustomDeflections[basecomponent,\n\t\
Function[Ray[RayTilt->",
 StyleBox["(#/Sqrt[Dot[#,#]])&", "Input"],
 "[{100,100,0}-(RayEnd/.#)]]]];\n\nAnalyzeSystem[{\n\tWedgeOfRays[10], \n\t\
Move[customcomponent,100,-45], \n\tBoundary[200]}, PlotType->TopView];"
}], "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"In[357]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{82.32233047033631, -17.677669529663685`}, {
      82.32233047033631, -17.677669529663685`}, {
      88.21488698022421, -11.785113019775794`}, {
      88.21488698022421, -11.785113019775793`}, {
      82.32233047033631, -17.677669529663685`}}], 
     PolygonBox[{{88.21488698022421, -11.785113019775793`}, {
      88.21488698022421, -11.785113019775794`}, {
      94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {
      88.21488698022421, -11.785113019775793`}}], 
     PolygonBox[{{94.1074434901121, -5.892556509887897}, {
      94.1074434901121, -5.892556509887897}, {100., -5.02429586778808*^-15}, {
      100., 0.}, {94.1074434901121, -5.892556509887897}}], 
     PolygonBox[{{100., 0.}, {100., 0.}, {105.8925565098879, 
      5.8925565098878945`}, {105.8925565098879, 5.892556509887892}, {100., 
      0.}}], PolygonBox[{{105.8925565098879, 5.892556509887892}, {
      105.8925565098879, 5.8925565098878945`}, {111.78511301977579`, 
      11.785113019775789`}, {111.78511301977579`, 11.785113019775789`}, {
      105.8925565098879, 5.892556509887892}}], 
     PolygonBox[{{111.78511301977579`, 11.785113019775789`}, {
      111.78511301977579`, 11.785113019775789`}, {117.67766952966369`, 
      17.677669529663685`}, {117.67766952966369`, 17.67766952966368}, {
      111.78511301977579`, 11.785113019775789`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{82.32233047033631, -17.677669529663685`}, {
       88.21488698022421, -11.785113019775793`}, {
       94.1074434901121, -5.892556509887897}, {
       100., -2.51214793389404*^-15}, {105.8925565098879, 
       5.892556509887892}, {111.78511301977578`, 11.785113019775784`}, {
       117.67766952966369`, 17.67766952966368}, {117.67766952966369`, 
       17.677669529663685`}, {111.78511301977579`, 11.785113019775793`}, {
       105.8925565098879, 5.892556509887897}, {100., 2.51214793389404*^-15}, {
       94.1074434901121, -5.892556509887892}, {
       88.21488698022422, -11.785113019775784`}, {
       82.32233047033631, -17.67766952966368}, {
       82.32233047033631, -17.677669529663685`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., 0.}, {100., 2.164890140588733*^-15}, {100., 
        1.804075117157278*^-15}, {100., 3.6081502343145547`*^-16}, {100., 
        0.}}], PolygonBox[{{100., 3.6081502343145547`*^-16}, {100., 
        1.804075117157278*^-15}, {100., 1.4432600937258223`*^-15}, {100., 
        7.216300468629109*^-16}, {100., 3.6081502343145547`*^-16}}], 
       PolygonBox[{{100., 7.216300468629109*^-16}, {100., 
        1.4432600937258223`*^-15}, {100., 1.0824450702943668`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629109*^-16}}], 
       PolygonBox[{{100., 1.0824450702943666`*^-15}, {100., 
        1.0824450702943666`*^-15}, {100., 7.216300468629111*^-16}, {100., 
        1.4432600937258219`*^-15}, {100., 1.0824450702943666`*^-15}}], 
       PolygonBox[{{100., 1.4432600937258219`*^-15}, {100., 
        7.216300468629111*^-16}, {100., 3.608150234314556*^-16}, {100., 
        1.8040751171572774`*^-15}, {100., 1.4432600937258219`*^-15}}], 
       PolygonBox[{{100., 1.8040751171572774`*^-15}, {100., 
        3.608150234314557*^-16}, {100., 1.8026331598992026`*^-31}, {100., 
        2.1648901405887327`*^-15}, {100., 1.8040751171572774`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {
         100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 
         0.}, {100., 0.}, {100., 0.}, {100., 0.}, {100., 0.}}]}}}}, {}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {200., -100.}, {200., 100.}, {
       200., 100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {0., -100.}, {0., -100.}, {200., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -100}, {0, 100}, {0, 100}, {0, -100}, {0, -100}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 100.}, {200., 100.}, {200., 100.}, {0., 100.}, {0., 
       100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -100.}, {200., 100.}, {0., 100.}, {0., -100.}, {
       200., -100.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 100.}, {200., -100.}, {0., -100.}, {0., 100.}, {200., 
       100.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {109.5876796297105, 9.587679629710493}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {100., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {91.954981558864, -8.045018441135994}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{109.5876796297105, 9.587679629710493}, {100., 
       100.00000000000001`}}]}, 
     {Arrowheads[Small], ArrowBox[{{100., 0.}, {100., 100.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.954981558864, -8.045018441135994}, {100., 
       100.00000000000001`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{109.5876796297105, 9.587679629710493}, {100., 0.}, {
      91.954981558864, -8.045018441135994}, {100., 100.00000000000001`}, {
      100., 100.}, {100., 100.00000000000001`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404371746831*^9, 3.563458242433908*^9, 
  3.564487701213416*^9, 3.5661008452180023`*^9, 3.601301587602882*^9, 
  3.6147093521130123`*^9, 3.614729210363817*^9},
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"},
 
 CellLabel->"During evaluation of In[357]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["The ", "Text"],
 StyleBox["customcomponent", "Input",
  FontSlant->"Plain"],
 StyleBox[" optic focuses the rays to a fixed point in space.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[{
 "Note that our particular ",
 StyleBox["CustomDeflections", "Input"],
 " function causes the rays to focus through the same fixed point in space \
regardless of the ",
 StyleBox["customcomponent", "Input",
  FontSlant->"Plain"],
 " optic's position and orientation. This is shown below, with ",
 StyleBox["TurboPlot", "Input"],
 " this time."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tWedgeOfRays[10], 
\tMove[customcomponent,150], 
\tBoundary[200]}, 
\tPlotType->TopView, ShowArrows->True];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"},
 CellLabel->"In[360]:="],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGZigIIDSQ4QhuUBXPw1q0DAAM5fjcZHV48uj64f
wlfAyceuH7d6qE/2ovEZCKhnwMVfBVHvAOOvQOOjq0eXR9cP4Rvg5GPXj1v9
fzCwgPP/ofHR1aO79/T58+tnT35tA+Nr6eruZfz9DM5v7+o6lZ50yAaXfnR5
dP0dYPlHaOZdwmk+ujy6/rNg996G80+j8dH1o8uj8zuwuucRAfMf4dTfieYf
Tazh+QinfBea/hu3bx/esm6KJYx/Ci2+YPoB/Bs9vg==
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KA0GB5IcIAzLAzD+6lUgYADnrwHzFQ6gqv+wB8Zf
AZF3QOUbwPn//oOAhQOqfks4fzWa+jVo5kHts0Gz7wAqH+FeqH1o7rVE46P7
f/jxAYv9Yv8=
      "]],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFMBwgd6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AItYluA==
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Arrowheads[Small], 
    ArrowBox[{{0., 0.}, {150., 13.1232995288886}}], 
    {Arrowheads[Small], ArrowBox[{{0., 0.}, {150., 0.}}]}, 
    {Arrowheads[Small], ArrowBox[{{0., 0.}, {150., -13.1232995288886}}]}, 
    {Arrowheads[Small], ArrowBox[{{150., 13.1232995288886}, {100., 100.}}]}, 
    {Arrowheads[Small], ArrowBox[{{150., 0.}, {100., 100.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{150., -13.1232995288886}, {100., 100.00000000000001`}}], 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], 
      PointBox[{{150., 13.1232995288886}, {150., 0.}, {
       150., -13.1232995288886}, {100., 100.}, {100., 100.}, {100., 
       100.00000000000001`}}]}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404372945348*^9, 3.56345824304311*^9, 
  3.564487701825382*^9, 3.5661008466148863`*^9, 3.601301588775963*^9, 
  3.6147093544417677`*^9, 3.614729211376112*^9},
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"},
 CellLabel->"During evaluation of In[360]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["The rays focus to the same fixed point regardless of the ", "Text"],
 StyleBox["customcomponent", "Input",
  FontSlant->"Plain"],
 StyleBox[" position.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[{
 "In addition to using ",
 StyleBox["RayEnd", "Input"],
 ", more elaborate ",
 StyleBox["RayTilt", "Input"],
 " deflection functions may also use the ",
 StyleBox["SurfaceNormalMatrix", "Input"],
 " surface parameter. See the ",
 "Optica",
 " Software web-site (www.opticasoftware.com) and the on-line Library of \
Examples for further examples."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.6.5 Optimizing ",
 StyleBox["CustomDeflections", "Input"],
 " for TurboTrace"
}], "Subsection",
 CellTags->{
  "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "Because ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["PropagateSystem", "Input"],
 " have different internal structures, the structural implementation of ",
 StyleBox["CustomDeflections", "Input"],
 " is also different for ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["PropagateSystem", "Input"],
 ". Consequently, there are two possible deflection function formats for ",
 StyleBox["CustomDeflections", "Input"],
 ". Until now, the format that we have been using is actually the format for ",
 StyleBox["PropagateSystem", "Input"],
 ". The ",
 StyleBox["PropagateSystem", "Input"],
 " format is most convenient because it's structure can be automatically \
changed by ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " into the ",
 StyleBox["TurboTrace", "Input"],
 " format. However, it is also possible to directly specify the ",
 StyleBox["TurboTrace", "Input"],
 " format in ",
 StyleBox["CustomDeflections", "Input"],
 ". When only ",
 StyleBox["TurboTrace", "Input"],
 " is required or with very complicated deflection functions (that require \
the extensive use of local variables), it is generally best to directly \
specify the ",
 StyleBox["TurboTrace", "Input"],
 " format. Unfortunately, however, the ",
 StyleBox["TurboTrace", "Input"],
 " format cannot be automatically changed into the ",
 StyleBox["PropagateSystem", "Input"],
 " format. Consequently, it becomes necessary to directly specify both \
formats when working with both ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["PropagateSystem", "Input"],
 ". This accomplished with the additional ",
 StyleBox["PropagateSystemDeflection", "Input"],
 " option."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 StyleBox["PropagateSystemDeflection ", "Input"],
 "is an option of ",
 StyleBox["CustomDeflections", "Input"],
 " that specifies the deflection function to be used in ",
 StyleBox["PropagateSystem", "Input"],
 " calculations."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "When ",
 StyleBox["CustomDeflections", "Input"],
 " uses an input deflection function parameter that is compatible with ",
 StyleBox["PropagateSystem", "Input"],
 " calculations, then ",
 StyleBox["PropagateSystemDeflection", "Input"],
 " is not utilized. Otherwise, the input deflection function parameter is \
only used for ",
 StyleBox["TurboTrace", "Input"],
 " calculations and ",
 StyleBox["PropagateSystemDeflection", "Input"],
 " is used with ",
 StyleBox["PropagateSystem", "Input"],
 ". In the case where a separate deflection function is required with ",
 StyleBox["PropagateSystem", "Input"],
 ", then you are use one of the built-in deflection functions with ",
 StyleBox["PropagateSystem", "Input"],
 ". In particular, ",
 StyleBox["PropagateSystemDeflection -> Automatic/Transmission", "Input"],
 " uses a ",
 StyleBox["Transmission", "Input"],
 "-type deflection function and ",
 StyleBox["PropagateSystemDeflection -> Reflection", "Input"],
 " uses a ",
 StyleBox["Reflection", "Input"],
 "-type deflection function. In all other cases, the value of ",
 StyleBox["PropagateSystemDeflection", "Input"],
 " is directly passed as the ",
 StyleBox["DeflectionFunction", "Input"],
 " setting in ",
 StyleBox["PropagateSystem", "Input"],
 ". In the following example, we directly specify both formats for ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["PropagateSystem", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell["\<\
turboOptimized = 
\tCustomDeflections[Screen[50],
\t\t\t{
\t\t\tHold[{localrayend,_Real,1}, localraylength],
\t\t\tHold[localrayend = {1.}, localraylength=1.],
\t\t\tHold[
\t\t\t\tlocalrayend = RayEnd;
\t\t\t\tlocalraylength = RayLength;
\t\t\t\tAllCreatedRays = {
\t\t\t\t\tRayEnd = localrayend + {0,.5*localraylength,0}; Ray,
\t\t\t\t\tRayEnd = {50,10,0}; WaveLength =.45; Ray,
\t\t\t\t\tRayEnd = localrayend; WaveLength = .6; Ray}
\t\t\t]
\t\t\t},
\t\tMultipleCreatedRays -> 3,
\t\tPropagateSystemDeflection -> 
\t\t\tFunction[
\t\t\t\tBlock[{rayend,raylength},
\t\t\t\t\trayend = RayEnd/.#;
\t\t\t\t\traylength = RayLength/.#;
\t\t\t\t\t{Ray[RayEnd->rayend + {0,.5*raylength,0}],
\t\t\t\t\tRay[RayEnd->{50,10,0}, WaveLength->.45],
\t\t\t\t\tRay[WaveLength->.6]}
\t\t\t\t]
\t\t\t]
\t\t];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"},
 CellLabel->"In[361]:="],

Cell[TextData[{
 StyleBox["The ", "Text"],
 StyleBox["turboOptimized", "Input",
  FontSlant->"Plain"],
 StyleBox[" optic gives two separate formats for ", "Text"],
 StyleBox["TurboTrace", "Input",
  FontSlant->"Plain"],
 StyleBox[" and ", "Text"],
 StyleBox["PropagateSystem", "Input",
  FontSlant->"Plain"],
 StyleBox[".", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "As demonstrated here, the ",
 StyleBox["TurboTrace", "Input"],
 " format for ",
 StyleBox["CustomDeflections", "Input"],
 " uses a list of three parameters that are each held (with ",
 StyleBox["Hold", "Input"],
 "). Here, the first parameter declares the local variables (see ",
 StyleBox["Compile", "Input"],
 "), the second parameter initializes the local variables, and the third \
parameter holds the actual deflection-function source code. Finally the ",
 StyleBox["PropagateSystem", "Input"],
 "-formated deflection is passed in the ",
 StyleBox["PropagateSystemDeflection", "Input"],
 " option as explained previously. In the ",
 StyleBox["TurboTrace", "Input"],
 " format, the capitalized symbols denote placeholders in ",
 StyleBox["TurboTrace", "Input"],
 " for important parameters. Many of these parameters have already been \
listed at the start of Section 4.6 as ray and surface parameters for ",
 StyleBox["TurboTrace", "Input"],
 ". In addition, there are some other parameters that have not been \
discussed. In particular, ",
 StyleBox["AllCreatedRays", "Input"],
 " holds the list of rays that are returned by the deflection function. \
Furthermore, ",
 StyleBox["Ray", "Input"],
 " contains the entire ray parameter information."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "Also demonstrated, we have specified a ",
 StyleBox["MultipleCreatedRays", "Input"],
 " setting for the ",
 StyleBox["CustomDeflection", "Input"],
 " function. ",
 StyleBox["MultipleCreatedRays", "Input"],
 " is only used in ",
 StyleBox["TurboTrace", "Input"],
 " calculations and helps to construct the most optimal ray-trace code."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 StyleBox["MultipleCreatedRays -> True", "Input"],
 "/",
 StyleBox["False", "Input"],
 "/",
 StyleBox["numberofrays",
  FontSlant->"Italic"],
 " specifies how many rays are generated at an optical surface by a \
deflection function."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "However, ",
 StyleBox["MultipleCreatedRays", "Input"],
 " is not used for ",
 StyleBox["PropagateSystem", "Input"],
 " calculations. In this example, ",
 StyleBox["MultipleCreatedRays -> 3", "Input"],
 " has indicated that 3 rays will be generated by our deflection function. \
When ",
 StyleBox["MultipleCreatedRays", "Input"],
 " is not specified by the user, ",
 StyleBox["CustomDeflections", "Input"],
 " will attempt to automatically determine the number of rays that will be \
generated and pass this information onto ",
 StyleBox["TurboTrace", "Input"],
 ". However, it is always safest to provide ",
 StyleBox["MultipleCreatedRays", "Input"],
 " information explicitly whenever more than one ray is to be generated by ",
 StyleBox["CustomDeflections", "Input"],
 ". (Although we have been discussing ",
 StyleBox["MultipleCreatedRays", "Input"],
 " for ",
 StyleBox["CustomDeflections", "Input"],
 " in particular, it is worth noting that ",
 StyleBox["MultipleCreatedRays", "Input"],
 " is actually used by all built-in deflection functions with ",
 StyleBox["TurboTrace", "Input"],
 ". For most built-in deflection functions , however, this option is set \
automatically without further user involvement.)"
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[{
 "Finally, we trace through this ",
 StyleBox["turboOptimized", "Input"],
 " optic separately with ",
 StyleBox["TurboPlot", "Input"],
 " and ",
 StyleBox["AnalyzeSystem", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{SingleRay[],Move[turboOptimized,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"},
 CellLabel->"In[362]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}, {{50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFIBwjt6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AY+ki2A==
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], 
    LineBox[{{{0., 0.}, {50., 0.}}, {{50., 25.}, {100., 25.}}}]}, 
   {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
    AbsoluteThickness[0.5], LineBox[{{50., 10.}, {100., 10.}}]}, 
   {RGBColor[0.947342704361055, 0.47353532394041015`, 0.014823955533973587`], 
    AbsoluteThickness[0.5], LineBox[{{50., 0.}, {100., 0.}}], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], 
     PointBox[{{50., 0.}, {100., 25.}, {100., 10.}, {100., 0.}}]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404374520667*^9, 3.563458243762412*^9, 
  3.564487702603183*^9, 3.5661008481927137`*^9, 3.601301589995061*^9, 
  3.6147093556224546`*^9, 3.614729212527116*^9},
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"},
 CellLabel->"During evaluation of In[362]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["The ", "Text"],
 StyleBox["turboOptimized", "Input",
  FontSlant->"Plain"],
 StyleBox[" optic with ", "Text"],
 StyleBox["TurboTrace", "Input",
  FontSlant->"Plain"],
 StyleBox[".", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{SingleRay[],Move[turboOptimized,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"},
 CellLabel->"In[363]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., -25.}, {50., -16.666666666666668`}, {
       50., -8.333333333333336}, {50., -3.552713678800501*^-15}, {50., 
       8.333333333333329}, {50., 16.666666666666657`}, {50., 
       24.999999999999993`}, {50., 25.}, {50., 16.666666666666668`}, {50., 
       8.333333333333336}, {50., 3.552713678800501*^-15}, {
       50., -8.333333333333329}, {50., -16.666666666666657`}, {
       50., -24.999999999999993`}, {50., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 0.}, {50., 
       0.}, {50., 0.}, {50., 0.}, {50., 0.}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGeDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0Ax5Nubg==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {50., 0.}}], 
     {Arrowheads[Small], ArrowBox[{{50., 25.}, {100., 25.}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 10.}, {100., 10.}}]}, 
    {RGBColor[0.947342704361055, 0.47353532394041015`, 0.014823955533973587`],
      AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{50., 0.}, {100., 0.}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{50., 0.}, {100., 25.}, {100., 10.}, {100., 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404375056006*^9, 3.5634582440351553`*^9, 
  3.5644877028326397`*^9, 3.566100849505684*^9, 3.601301590305621*^9, 
  3.614709355936935*^9, 3.6147292128437357`*^9},
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"},
 CellLabel->"During evaluation of In[363]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["The ", "Text"],
 StyleBox["turboOptimized", "Input",
  FontSlant->"Plain"],
 StyleBox[" optic with ", "Text"],
 StyleBox["PropagateSystem", "Input",
  FontSlant->"Plain"],
 StyleBox[".", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4.6.6 ",
 StyleBox["AffectedSurfaces", "Input"]
}], "Subsection",
 CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "When an optical element contains more than one surface, you can use ",
 StyleBox["AffectedSurfaces -> {", "Input"],
 StyleBox["surface numbers",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " to specify which surfaces of the ",
 StyleBox["Component", "Input"],
 " object will be affected by ",
 StyleBox["CustomDeflections", "Input"],
 ". In particular, each surface element within the ",
 StyleBox["Component", "Input"],
 " object is stored as an element within an ordered list. In general, the ",
 StyleBox["surface numbers",
  FontSlant->"Italic"],
 " given by ",
 StyleBox["AffectedSurfaces", "Input"],
 " relate to the element positions in this list and identifies particular \
optical surfaces. These numbers also correspond with the ",
 StyleBox["SurfaceNumber", "Input"],
 " parameter. For example, ",
 StyleBox["AffectedSurfaces -> {2}", "Input"],
 " specifies that the second optical surface will inherit the new traits of \
",
 StyleBox["CustomDeflections", "Input"],
 ". In the following example, we will use ",
 StyleBox["AffectedSurfaces -> {2}", "Input"],
 " to modify the wavelength of the ray at the second surface of a ",
 StyleBox["PlanoConvexLens", "Input"],
 " component."
}], "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell["\<\
specialLens = 
\tCustomDeflections[
\t\tPlanoConvexLens[100,50,10],
\t\tFunction[Ray[WaveLength->.45]],
\t\tAffectedSurfaces -> {2}
\t];
AnalyzeSystem[{LineOfRays[45],Move[specialLens,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"In[364]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., -21.7192607925394}, {100., -11.802016093784832`}}], 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {100., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {100., 11.802016093784832`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{55.13384936237171, -22.5}, {50.00000000000001, 0.}, {
      55.13384936237171, 22.5}, {60., -21.7192607925394}, {60., 0.}, {60., 
      21.7192607925394}, {100., -11.802016093784832`}, {100., 0.}, {100., 
      11.802016093784832`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404375475939*^9, 3.563458244543803*^9, 
  3.564487703869689*^9, 3.5661008509181623`*^9, 3.601301590686154*^9, 
  3.614709356359885*^9, 3.614729213244835*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"During evaluation of In[364]:="]
}, Open  ]],

Cell[TextData[{
 "In this case, the wavelength of the rays are changed to blue at the \
right-most surface because this is internally recognized as the second \
surface element of the ",
 StyleBox["Component", "Input"],
 ". We will next send the rays through the lens from the reverse direction."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{Move[LineOfRays[45],100,180],Move[specialLens,50],Boundary[100]\
},PlotType->TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"In[366]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{100., 22.5}, {60., 22.5}}], 
     {Arrowheads[Small], ArrowBox[{{100., 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{100., -22.5}, {60., -22.5}}]}}, 
    {RGBColor[0.0007568495259124286, 0.09180997994403128, 0.901145431087504], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{60., 22.5}, {55.13384936237171, 22.5}}], 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -22.5}, {55.13384936237171, -22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {-7.105427357601002*^-15, 
       6.9988202440431575`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{
       55.13384936237171, -22.5}, {-7.105427357601002*^-15, \
-6.9988202440431575`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{60., 22.5}, {60., 0.}, {60., -22.5}, {55.13384936237171, 
      22.5}, {50., 0.}, {55.13384936237171, -22.5}, {-7.105427357601002*^-15, 
      6.9988202440431575`}, {0., 
      0.}, {-7.105427357601002*^-15, -6.9988202440431575`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404375895082*^9, 3.563458245294327*^9, 
  3.564487704422575*^9, 3.566100851570052*^9, 3.601301590990078*^9, 
  3.614709356673745*^9, 3.6147292135446*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"During evaluation of In[366]:="]
}, Open  ]],

Cell[TextData[{
 "Again the wavelength of the rays are changed to blue at the second surface, \
but this time the change happens as the ray enters the lens. This should not \
be surprising since the specified surface number is independent of the \
ray-trace order . If we had wished to make the wavelength change at the \
left-most surface, we would instead use ",
 StyleBox["AffectedSurfaces -> {1}", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["RemoveDeflection", "Input"]], "Subsubsection",
 CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "In addition to ",
 StyleBox["CustomDeflections", "Input"],
 ", ",
 StyleBox["AffectedSurfaces", "Input"],
 " is an option of many generic building blocks. In each case, you use ",
 StyleBox["AffectedSurfaces", "Input"],
 " to affect a change at specific surfaces while leaving the other surfaces \
unchanged. As a more complex example, we will use ",
 StyleBox["Reflection", "Input"],
 " to create mirror on the second surface of a plano-convex lens."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell["\<\
reflectedLens = 
\tResonate[
\t\tReflection[
\t\t\tRemoveDeflection[
\t\t\t\tPlanoConvexLens[100,50,10],
\t\t\t\tAffectedSurfaces -> {2}
\t\t\t],
\t\t\tAffectedSurfaces -> {2},
\t\t\tAddTo -> CreatedRay
\t\t],
\t\tAffectedSurfaces -> {2}
\t];
AnalyzeSystem[{LineOfRays[45],Move[reflectedLens,50],Boundary[100]},PlotType->\
TopView];\
\>", "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"In[367]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.7192607925394}, {
       54.35913041950905, -20.81422344913986}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {54.35913041950905, 
       20.81422344913986}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{
       54.35913041950905, -20.81422344913986}, {-7.105427357601002*^-15, 
       12.700025153137155`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.35913041950905, 
       20.81422344913986}, {-7.105427357601002*^-15, \
-12.700025153137155`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{55.13384936237171, -22.5}, {50.00000000000001, 0.}, {
      55.13384936237171, 22.5}, {60., -21.7192607925394}, {60., 0.}, {60., 
      21.7192607925394}, {54.35913041950905, -20.81422344913986}, {50., 0.}, {
      54.35913041950905, 20.81422344913986}, {-7.105427357601002*^-15, 
      12.700025153137155`}, {0., 
      0.}, {-7.105427357601002*^-15, -12.700025153137155`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404379153947*^9, 3.563458246230401*^9, 
  3.564487704905361*^9, 3.566100852434372*^9, 3.601301591455311*^9, 
  3.614709357201494*^9, 3.614729214089713*^9},
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"During evaluation of In[367]:="]
}, Open  ]],

Cell[TextData[{
 "In this case, we needed to first remove the effect of ",
 StyleBox["Refraction", "Input"],
 " at the second surface before we could add the ",
 StyleBox["Reflection", "Input"],
 " trait. This was accomplished with ",
 StyleBox["RemoveDeflection", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 StyleBox["RemoveDeflection[", "Input"],
 StyleBox["component",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 " ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is a generic building block that is used to remove deflections from \
existing component surfaces."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 StyleBox["RemoveDeflection", "Input"],
 " represents a special class of generic functions that modify existing \
traits of optical components. Other members of this class include: ",
 StyleBox["RemoveSurface", "Input"],
 ", ",
 StyleBox["InsertDeflection", "Input"],
 ", and ",
 StyleBox["AddDeflection", "Input"],
 ". (See the ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " Reference Guide for further information on these functions.)"
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "The previous example relied on several of the control mechanisms that we \
had examined earlier in this chapter. In particular, ",
 StyleBox["AffectedSurfaces -> {2}", "Input"],
 " indicated that only the second surface is to be affected. In addition, ",
 StyleBox["AddTo -> CreatedRay", "Input"],
 " was used with ",
 StyleBox["Reflection", "Input"],
 " to combine its result with the existing ray and not to create extra rays \
at the surface for the new information. As evidenced here, both ",
 StyleBox["AffectSurfaces", "Input"],
 " and ",
 StyleBox["AddTo", "Input"],
 " are frequently used with many generic building blocks. Finally, the ",
 StyleBox["Resonate", "Input"],
 " function was added to cause the component to trace rays non-sequentially \
between the first lens surface and the new reflective surface. It is \
interesting to note that the ",
 StyleBox["PlanoConvexLens", "Input"],
 " object originally already had the ",
 StyleBox["Resonate", "Input"],
 " attribute (see Section 4.5). Unfortunately, however, ",
 StyleBox["RemoveDeflection", "Input"],
 " has removed not only the ",
 StyleBox["Refraction", "Input"],
 " trait from the second surface, but also the ",
 StyleBox["Resonate", "Input"],
 " trait. This is why we have reapplied ",
 StyleBox["Resonate", "Input"],
 " to the second surface and not to the first surface (although a repeated \
application of ",
 StyleBox["Resonate", "Input"],
 " to the first surface would not have hurt anything, it would have been \
unnecessary.)"
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "In addition to ",
 StyleBox["AffectedSurfaces -> {", "Input"],
 StyleBox["surface numbers",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 ", there exist several other ways to specify ",
 StyleBox["AffectedSurfaces", "Input"],
 ". For example, ",
 StyleBox["AffectedSurfaces", "Input"],
 " can operate with any the following word settings: ",
 StyleBox["AllDeflections", "Input"],
 ", ",
 StyleBox["AllSurfaces", "Input"],
 ", ",
 StyleBox["FirstSlot", "Input"],
 ", ",
 StyleBox["NotFirstSlot", "Input"],
 ", ",
 StyleBox["LastSlot", "Input"],
 ", ",
 StyleBox["NotLastSlot", "Input"],
 ", and ",
 StyleBox["IndependentSurfaces", "Input"],
 ". Of these different forms, only ",
 StyleBox["AffectedSurfaces -> AllSurfaces", "Input"],
 " is commonly employed since it is the default setting for most generic \
building blocks. ",
 StyleBox["AllSurfaces", "Input"],
 " simply indicates that all surfaces within the ",
 StyleBox["Component", "Input"],
 " object will be affected by the new generic trait. For most part, however, \
the other possible setting of ",
 StyleBox["AffectedSurfaces", "Input"],
 " are rarely used and, in some instances, are not compatible with ",
 StyleBox["TurboTrace", "Input"],
 ". As such, we will not examine any of the other ",
 StyleBox["AffectedSurfaces", "Input"],
 " settings at this time. Please consult the ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " Reference Guide for further information about ",
 StyleBox["AffectedSurfaces", "Input"],
 "."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelSurfaces", "Subsubsection",
 CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "When working with optical systems that contain multiple surface elements, \
it is sometimes difficult to find out how the surfaces are internally \
numbered in order to apply options such as ",
 StyleBox["AffectedSurfaces", "Input"],
 ". You can use ",
 StyleBox["LabelSurfaces -> True", "Input"],
 " with ",
 StyleBox["ShowSystem", "Input"],
 " to determine this information."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 StyleBox["LabelSurfaces -> True/False", "Input"],
 " is an option of ",
 StyleBox["ShowSystem", "Input"],
 " that displays the ",
 StyleBox["ComponentNumber", "Input"],
 " and ",
 StyleBox["SurfaceNumber", "Input"],
 " information for each component surface in an optical system."
}], "Text",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{"SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "When a single component element is present, the corresponding ",
 StyleBox["SurfaceNumber", "Input"],
 " for each surface is displayed. In the ",
 StyleBox["PlanoConvexLens", "Input"],
 " examples used previously, there are only two surfaces present and we \
simply guessed to discover the correct ",
 StyleBox["SurfaceNumber", "Input"],
 " setting for ",
 StyleBox["AffectedSurfaces", "Input"],
 ". If instead, we wished to work with a ",
 StyleBox["Prism", "Input"],
 " that has five internal surfaces, we need to use the ",
 StyleBox["LabelSurfaces", "Input"],
 " option with ",
 StyleBox["ShowSystem", "Input"],
 " to easily determine the correct surface numbering:"
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[Prism[{45,50,45},50], LabelSurfaces -> True, \
DefaultFont\[Rule]{\"Times\",14}];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"In[369]:="],

Cell[BoxData[
 Graphics3DBox[
  {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[None],
    Line3DBox[{{-24.999999999999996`, 
    3.552713678800501*^-15, -25.}, {-3.552713678800501*^-15, 
    24.999999999999996`, -25.}, {-3.552713678800501*^-15, 24.999999999999996`,
     25.}, {-24.999999999999996`, 3.552713678800501*^-15, 
    25.}, {-24.999999999999996`, 3.552713678800501*^-15, -25.}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{24.999999999999996`, 3.552713678800501*^-15, -25.}, {
     3.552713678800501*^-15, 24.999999999999996`, -25.}, {
     3.552713678800501*^-15, 24.999999999999996`, 25.}, {24.999999999999996`, 
     3.552713678800501*^-15, 25.}, {24.999999999999996`, 
     3.552713678800501*^-15, -25.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{-25., 0., -25.}, {25., 0., -25.}, {25., 0., 25.}, {-25., 0., 
     25.}, {-25., 0., -25.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{-25.0125, -0.00416666666666643, -25.}, {0., 
     25.008333333333333`, -25.}, {
     25.0125, -0.00416666666666643, -25.}, {-25.0125, -0.00416666666666643, \
-25.}}]}, 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    Line3DBox[{{-25.0125, -0.00416666666666643, 25.}, {0., 
     25.008333333333333`, 25.}, {25.0125, -0.00416666666666643, 
     25.}, {-25.0125, -0.00416666666666643, 25.}}], 
    {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
     StyleBox[
      Text3DBox["\<\"1\"\>", {-12.499992928932189`, 12.500007071067811`, 
       0.00001}],
      StripOnInput->False,
      FontSize->48], 
     StyleBox[
      Text3DBox["\<\"2\"\>", {12.499992928932189`, 12.500007071067811`, 
       0.00001}],
      StripOnInput->False,
      FontSize->48], 
     StyleBox[Text3DBox["\<\"3\"\>", {0.00001, 0, 0.00001}],
      StripOnInput->False,
      FontSize->48], 
     StyleBox[Text3DBox["\<\"4\"\>", {0.00001, 8.333343333333332, -25.}],
      StripOnInput->False,
      FontSize->48], 
     StyleBox[Text3DBox["\<\"5\"\>", {0.00001, 8.333343333333332, 25.}],
      StripOnInput->False,
      FontSize->48]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634043797022963`*^9, 3.563458246867128*^9, 
  3.564487705919939*^9, 3.5661008531058826`*^9, 3.601301591853108*^9, 
  3.614709357570706*^9, 3.6147292144162893`*^9},
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"During evaluation of In[369]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["LabelSurfaces -> True", "Input",
  FontSlant->"Plain"],
 StyleBox[" shows the ", "Text"],
 StyleBox["SurfaceNumber", "Input",
  FontSlant->"Plain"],
 StyleBox[" of each surface present.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "For simple systems, you can immediately determine the corresponding ",
 StyleBox["ComponentNumber", "Input"],
 " for each optical component by simply inspecting its order position in the \
component listing. However, when system definitions are more complex, it can \
become difficult to keep track of the corresponding ",
 StyleBox["ComponentNumber", "Input"],
 " for every component of the system. In such cases, you can again use the ",
 StyleBox["LabelSurfaces", "Input"],
 " option. When several components are present, a pair of numbers that \
correspond with ",
 StyleBox["{ComponentNumber, SurfaceNumber}", "Input"],
 " is displayed by each component surface. As such, ",
 StyleBox["LabelSurfaces", "Input"],
 " will tell you the internal surface order as well as how the different \
components are ordered. To illustrate this, here is a simple example that \
shows two components."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{PlanoConvexLens[100,50,10],Move[Prism[{45,50,45},50],50]}, 
\tPlotType->TopView, LabelSurfaces->True, DefaultFont\[Rule]{\"Times\",14}];\
\>", "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"In[370]:="],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0.5], AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None],
    PolygonBox[{{6.421974580955592, -25.}, {10., -25.}, {
    10., -16.66666666666667}, {2.7504488342847893`, -16.666666666666668`}, {
    6.421974580955592, -25.}}], 
   PolygonBox[{{2.7504488342847893`, -16.666666666666668`}, {
    10., -16.66666666666667}, {10., -8.333333333333336}, {
    0.6737579958920605, -8.333333333333336}, {
    2.7504488342847893`, -16.666666666666668`}}], 
   PolygonBox[{{0.6737579958920605, -8.333333333333336}, {
    10., -8.333333333333336}, {10., -7.105427357601002*^-15}, {0., 0.}, {
    0.6737579958920605, -8.333333333333336}}], 
   PolygonBox[{{0., 0.}, {10., 0.}, {10., 8.333333333333332}, {
    0.6737579958920605, 8.333333333333329}, {0., 0.}}], 
   PolygonBox[{{0.6737579958920605, 8.333333333333329}, {10., 
    8.333333333333332}, {10., 16.666666666666664`}, {2.7504488342847893`, 
    16.666666666666664`}, {0.6737579958920605, 8.333333333333329}}], 
   PolygonBox[{{2.7504488342847893`, 16.666666666666664`}, {10., 
    16.666666666666664`}, {10., 24.999999999999996`}, {6.421974580955592, 
    24.999999999999993`}, {2.7504488342847893`, 16.666666666666664`}}], 
   {GrayLevel[0], AbsoluteThickness[0.5], 
    LineBox[{{6.421974580955592, -25.}, {
     2.7504488342847893`, -16.666666666666668`}, {
     0.6737579958920605, -8.333333333333336}, {0., -3.552713678800501*^-15}, {
     0.6737579958920605, 8.333333333333329}, {2.750448834284782, 
     16.666666666666657`}, {6.421974580955592, 24.999999999999993`}, {10., 
     25.}, {10., 16.666666666666668`}, {10., 8.333333333333336}, {10., 
     3.552713678800501*^-15}, {10., -8.333333333333329}, {
     10., -16.666666666666657`}, {10., -24.999999999999993`}, {
     6.421974580955592, -25.}}], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{6.421974580955592, 0.}, {10., 3.061616997868383*^-15}, {10.,
       2.551347498223653*^-15}, {2.7504488342847893`, 
      5.102694996447305*^-16}, {6.421974580955592, 0.}}], 
     PolygonBox[{{2.7504488342847893`, 5.102694996447305*^-16}, {10., 
      2.551347498223653*^-15}, {10., 2.0410779985789223`*^-15}, {
      0.6737579958920605, 1.020538999289461*^-15}, {2.7504488342847893`, 
      5.102694996447305*^-16}}], 
     PolygonBox[{{0.6737579958920605, 1.020538999289461*^-15}, {10., 
      2.0410779985789223`*^-15}, {10., 1.530808498934192*^-15}, {0., 
      1.5308084989341915`*^-15}, {0.6737579958920605, 
      1.020538999289461*^-15}}], 
     PolygonBox[{{0., 1.5308084989341915`*^-15}, {10., 
      1.5308084989341915`*^-15}, {10., 1.0205389992894611`*^-15}, {
      0.6737579958920605, 2.041077998578922*^-15}, {0., 
      1.5308084989341915`*^-15}}], 
     PolygonBox[{{0.6737579958920605, 2.041077998578922*^-15}, {10., 
      1.0205389992894611`*^-15}, {10., 5.102694996447307*^-16}, {
      2.7504488342847893`, 2.5513474982236525`*^-15}, {0.6737579958920605, 
      2.041077998578922*^-15}}], 
     PolygonBox[{{2.7504488342847893`, 2.5513474982236525`*^-15}, {10., 
      5.102694996447308*^-16}, {10., 2.5493082627129206`*^-31}, {
      6.421974580955592, 3.0616169978683826`*^-15}, {2.7504488342847893`, 
      2.5513474982236525`*^-15}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 0.}, {2.7504488342847893`, 0.}, {
       0.6737579958920605, 0.}, {0., 0.}, {0.6737579958920605, 0.}, {
       2.750448834284782, 0.}, {6.421974580955592, 0.}, {10., 0.}, {10., 
       0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {10., 0.}, {
       6.421974580955592, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.421974580955592, 25.}, {10., 25.}, {10., 
       24.148145657226706`}, {6.421974580955592, 24.148145657226706`}, {
       6.421974580955592, 25.}}], 
      LineBox[{{6.421974580955592, 24.148145657226706`}, {10., 
       24.148145657226706`}, {10., 21.65063509461097}, {6.421974580955592, 
       21.65063509461097}, {6.421974580955592, 24.148145657226706`}}], 
      LineBox[{{6.421974580955592, 21.65063509461097}, {10., 
       21.65063509461097}, {10., 17.67766952966369}, {6.421974580955592, 
       17.67766952966369}, {6.421974580955592, 21.65063509461097}}], 
      LineBox[{{6.421974580955592, 17.67766952966369}, {10., 
       17.67766952966369}, {10., 12.500000000000004`}, {6.421974580955592, 
       12.500000000000004`}, {6.421974580955592, 17.67766952966369}}], 
      LineBox[{{6.421974580955592, 12.500000000000004`}, {10., 
       12.500000000000004`}, {10., 6.470476127563024}, {6.421974580955592, 
       6.470476127563024}, {6.421974580955592, 12.500000000000004`}}], 
      LineBox[{{6.421974580955592, 6.470476127563024}, {10., 
       6.470476127563024}, {10., 7.0819236220599744`*^-15}, {
       6.421974580955592, 7.0819236220599744`*^-15}, {6.421974580955592, 
       6.470476127563024}}], 
      LineBox[{{6.421974580955592, 1.5308084989341915`*^-15}, {10., 
       1.5308084989341915`*^-15}, {10., -6.470476127563016}, {
       6.421974580955592, -6.470476127563016}, {6.421974580955592, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{6.421974580955592, -6.470476127563016}, {
       10., -6.470476127563016}, {10., -12.499999999999995`}, {
       6.421974580955592, -12.499999999999995`}, {
       6.421974580955592, -6.470476127563016}}], 
      LineBox[{{6.421974580955592, -12.499999999999995`}, {
       10., -12.499999999999995`}, {10., -17.677669529663685`}, {
       6.421974580955592, -17.677669529663685`}, {
       6.421974580955592, -12.499999999999995`}}], 
      LineBox[{{6.421974580955592, -17.677669529663685`}, {
       10., -17.677669529663685`}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -17.677669529663685`}}], 
      LineBox[{{6.421974580955599, -21.650635094610962`}, {
       10., -21.650635094610962`}, {10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {
       6.421974580955599, -21.650635094610962`}}], 
      LineBox[{{6.421974580955592, -24.148145657226706`}, {
       10., -24.148145657226706`}, {10., -25.}, {6.421974580955592, -25.}, {
       6.421974580955592, -24.148145657226706`}}], 
      LineBox[{{6.421974580955592, -25.}, {10., -25.}, {
       10., -24.148145657226706`}, {
       6.421974580955592, -24.148145657226706`}, {6.421974580955592, -25.}}], 
      LineBox[{{6.421974580955592, -24.14814565722671}, {
       10., -24.14814565722671}, {10., -21.65063509461097}, {
       6.421974580955592, -21.65063509461097}, {
       6.421974580955592, -24.14814565722671}}], 
      LineBox[{{6.421974580955592, -21.65063509461097}, {
       10., -21.65063509461097}, {10., -17.677669529663692`}, {
       6.421974580955592, -17.677669529663692`}, {
       6.421974580955592, -21.65063509461097}}], 
      LineBox[{{6.421974580955592, -17.677669529663696`}, {
       10., -17.677669529663696`}, {10., -12.50000000000001}, {
       6.421974580955592, -12.50000000000001}, {
       6.421974580955592, -17.677669529663696`}}], 
      LineBox[{{6.421974580955592, -12.50000000000001}, {
       10., -12.50000000000001}, {10., -6.470476127563038}, {
       6.421974580955592, -6.470476127563038}, {
       6.421974580955592, -12.50000000000001}}], 
      LineBox[{{6.421974580955592, -6.470476127563038}, {
       10., -6.470476127563038}, {10., -2.6796885989305705`*^-14}, {
       6.421974580955592, -2.6796885989305705`*^-14}, {
       6.421974580955592, -6.470476127563038}}], 
      LineBox[{{6.421974580955592, -4.592425496802574*^-15}, {
       10., -4.592425496802574*^-15}, {10., 6.470476127563007}, {
       6.421974580955592, 6.470476127563007}, {
       6.421974580955592, -4.592425496802574*^-15}}], 
      LineBox[{{6.421974580955592, 6.470476127563007}, {10., 
       6.470476127563007}, {10., 12.499999999999984`}, {6.421974580955592, 
       12.499999999999984`}, {6.421974580955592, 6.470476127563007}}], 
      LineBox[{{6.421974580955592, 12.499999999999984`}, {10., 
       12.499999999999984`}, {10., 17.67766952966367}, {6.421974580955599, 
       17.67766952966367}, {6.421974580955592, 12.499999999999984`}}], 
      LineBox[{{6.421974580955592, 17.677669529663685`}, {10., 
       17.677669529663685`}, {10., 21.65063509461096}, {6.421974580955592, 
       21.65063509461096}, {6.421974580955592, 17.677669529663685`}}], 
      LineBox[{{6.421974580955592, 21.65063509461096}, {10., 
       21.65063509461096}, {10., 24.148145657226703`}, {6.421974580955592, 
       24.148145657226703`}, {6.421974580955592, 21.65063509461096}}], 
      LineBox[{{6.421974580955592, 24.148145657226703`}, {10., 
       24.148145657226703`}, {10., 25.}, {6.421974580955592, 25.}, {
       6.421974580955592, 24.148145657226703`}}]}, 
     {GrayLevel[0], AbsolutePointSize[1], AbsoluteThickness[0.5], EdgeForm[
      None], LineBox[{{25.000000000000004`, 3.552713678800501*^-15}, {50., 
       24.999999999999996`}, {50., 24.999999999999996`}, {25.000000000000004`,
        3.552713678800501*^-15}, {25.000000000000004`, 
       3.552713678800501*^-15}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{75., 3.552713678800501*^-15}, {50., 24.999999999999996`}, {
        50., 24.999999999999996`}, {75., 3.552713678800501*^-15}, {75., 
        3.552713678800501*^-15}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{25., 0.}, {75., 0.}, {75., 0.}, {25., 0.}, {25., 0.}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{24.9875, -0.00416666666666643}, {50., 25.008333333333333`}, {
        75.0125, -0.00416666666666643}, {24.9875, -0.00416666666666643}}]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{24.9875, -0.00416666666666643}, {50., 25.008333333333333`}, {
        75.0125, -0.00416666666666643}, {24.9875, -0.00416666666666643}}], 
       {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
        InsetBox["\<\"L\"\>", {5., -26.}, {0., 0.}], 
        InsetBox["\<\"Prism\"\>", {24., -1.}, {0., 0.}]}, 
       {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
        StyleBox[InsetBox["\<\"{1, 1}\"\>", {0, 0.00001}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{1, 2}\"\>", {10., 0.00001}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{2, 1}\"\>", {37.50000707106781, 12.500007071067811`}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{2, 2}\"\>", {62.49999292893219, 12.500007071067811`}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{2, 3}\"\>", {50.00001, 0}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{2, 4}\"\>", {50.00001, 8.333343333333332}],
         StripOnInput->False,
         FontSize->48], 
        StyleBox[InsetBox["\<\"{2, 5}\"\>", {50.00001, 8.333343333333332}],
         StripOnInput->False,
         FontSize->48]}}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56340438035699*^9, 3.563458247366743*^9, 
  3.564487706664505*^9, 3.5661008540082817`*^9, 3.601301592324972*^9, 
  3.6147093580795927`*^9, 3.6147292149326887`*^9},
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"},
 CellLabel->"During evaluation of In[370]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["LabelSurfaces -> True", "Input",
  FontSlant->"Plain"],
 StyleBox[" shows ", "Text"],
 StyleBox["{ComponentNumber, SurfaceNumber}", "Input",
  FontSlant->"Plain"],
 StyleBox[" for multiple components.", "Text"]
}], "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[{
 "In the case of multiple component entries, ",
 StyleBox["LabelSurfaces", "Input"],
 " displays an ordered pair of numbers that show the ",
 StyleBox["{ComponentNumber, SurfaceNumber}", "Input"],
 " of each optical surface."
}], "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 4 topics"]], "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Brackets",
PrintingStyleEnvironment->"EnhancedPrintout",
WindowToolbars->"RulerBar",
WindowSize->{1218, 876},
WindowMargins->{{Automatic, 34}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->132,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{"Customization"}], "Header"]}, {
   Cell[
    TextData[{"Chapter 4"}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False},
ShowSelection->True,
DelimiterFlashTime->1,
AutoItalicWords->{
 "Mathematica", "MathLink", "MathSource", "MathReader", "MathScript", 
  "Optica", "Optica2"},
Magnification->1,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "chapter 4 topics"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}]},
 "Aperture Shapes"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[805, 30, 254, 6, 20, "Outline2",
   Evaluatable->False,
   CellTags->"Aperture Shapes"],
  Cell[1062, 38, 556, 20, 55, "Outline3",
   Evaluatable->False,
   CellTags->"Aperture Shapes"],
  Cell[6700, 245, 187, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[6890, 250, 883, 23, 33, "Text",
   Evaluatable->False,
   CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22434, 544, 100, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45670, 996, 124, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98812, 1912, 131, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98946, 1915, 244, 6, 20, "Text",
   Evaluatable->False,
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[99193, 1923, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}],
  Cell[99599, 1938, 761, 25, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100385, 1967, 240, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100628, 1976, 23320, 379, 438, "Print",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[123963, 2358, 97, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.2"}],
  Cell[124063, 2361, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}],
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[137971, 2616, 96, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[138070, 2619, 511, 18, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138606, 2641, 275, 12, 106, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138884, 2655, 23415, 395, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[162314, 3053, 101, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[162418, 3056, 145, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[162566, 3061, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[162759, 3069, 121, 1, 35, "Subsection",
   CellTags->{
    "4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[162883, 3072, 427, 10, 33, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163313, 3084, 460, 12, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163776, 3098, 4392, 137, 131, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168171, 3237, 141, 2, 24, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168315, 3241, 188, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168506, 3248, 426, 9, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168957, 3261, 1333, 38, 105, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[170293, 3301, 8200, 148, 397, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178508, 3452, 147, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178658, 3459, 323, 8, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179006, 3471, 426, 11, 25, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179435, 3484, 14097, 298, 365, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193547, 3785, 149, 3, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193699, 3790, 314, 7, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[194016, 3799, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}]},
 "Light Sources"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[1655, 63, 179, 4, 20, "Outline2",
   CellTags->"Light Sources"],
  Cell[1859, 71, 243, 4, 16, "Outline3",
   CellTags->"Light Sources"],
  Cell[2105, 77, 377, 10, 27, "Outline4",
   CellTags->"Light Sources"],
  Cell[2497, 90, 471, 14, 42, "Outline3",
   CellTags->"Light Sources"],
  Cell[194221, 3808, 93, 1, 60, "Section",
   CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[194317, 3811, 702, 13, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[195044, 3828, 176, 3, 35, "Subsection",
   CellTags->{
    "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
     "PR4.2", "PR4.2.1"}],
  Cell[195245, 3835, 160, 3, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[195408, 3840, 864, 14, 60, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196275, 3856, 576, 15, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196876, 3875, 1951, 52, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[198830, 3929, 55173, 887, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254018, 4819, 284, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254305, 4829, 448, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254756, 4839, 323, 11, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[255104, 4854, 1823, 49, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[256930, 4905, 54707, 879, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311652, 5787, 264, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311919, 5795, 347, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312269, 5804, 449, 11, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312721, 5817, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[312912, 5825, 152, 2, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with ReadRays", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[313067, 5829, 402, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313472, 5839, 350, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313847, 5853, 1983, 54, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[315833, 5909, 61833, 993, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377681, 6905, 287, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377971, 6914, 385, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378359, 6924, 470, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378832, 6935, 709, 15, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379566, 6954, 304, 7, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379873, 6963, 1496, 37, 48, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[381384, 7003, 1035, 28, 62, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[382422, 7033, 875, 23, 48, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383300, 7058, 574, 16, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383899, 7078, 661, 21, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[384563, 7101, 1813, 43, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386391, 7147, 175, 4, 20, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386569, 7153, 921, 25, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[387493, 7180, 1041, 32, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388537, 7214, 128, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388690, 7220, 927, 26, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[389620, 7248, 62670, 1006, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452305, 8257, 164, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452472, 8263, 370, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452845, 8274, 412, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453260, 8286, 354, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453617, 8297, 1675, 47, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455295, 8346, 191, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455489, 8352, 188, 5, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455702, 8361, 1481, 40, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[457186, 8403, 63822, 1027, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521023, 9433, 263, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521289, 9441, 336, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521628, 9450, 525, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[522156, 9465, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}],
  Cell[522548, 9479, 433, 13, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[522984, 9494, 376, 6, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[523363, 9502, 824, 14, 50, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[524190, 9518, 1462, 37, 76, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[525655, 9557, 542, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[526222, 9574, 1022, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[527247, 9605, 1615, 34, 99, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[528877, 9642, 252, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529132, 9650, 425, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529582, 9665, 1023, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[530608, 9696, 1640, 36, 163, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532263, 9735, 236, 5, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532502, 9742, 463, 12, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532968, 9756, 260, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[533253, 9768, 1700, 46, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[534956, 9816, 5321, 97, 303, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[540292, 9916, 308, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[540603, 9926, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[540794, 9934, 158, 3, 35, "Subsection",
   CellTags->{
    "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
     "PR4.2.3"}],
  Cell[540955, 9939, 347, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541305, 9950, 630, 17, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541938, 9969, 3693, 104, 229, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545634, 10075, 110, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545747, 10078, 322, 7, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[546094, 10089, 1189, 36, 131, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[547286, 10127, 2791, 86, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550092, 10216, 236, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550331, 10227, 313, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550669, 10240, 663, 18, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[551335, 10260, 101782, 1834, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653132, 12097, 112, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653247, 12100, 386, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653636, 12112, 697, 20, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654358, 12136, 601, 15, 87, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654962, 12153, 3040, 95, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[658039, 12253, 985, 24, 121, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[659027, 12279, 142085, 2384, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801127, 14666, 630, 21, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801760, 14689, 386, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[802149, 14700, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[802340, 14708, 128, 2, 35, "Subsection",
   CellTags->{
    "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802471, 14712, 473, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802947, 14723, 452, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803402, 14735, 403, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803830, 14748, 1027, 29, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[804860, 14779, 13596, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818471, 15011, 221, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818695, 15019, 457, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[819177, 15034, 1146, 33, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[820326, 15069, 13584, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[833925, 15301, 250, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834178, 15310, 359, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834540, 15320, 272, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834837, 15333, 1357, 34, 168, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[836197, 15369, 57972, 1085, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[894184, 16457, 172, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[894359, 16463, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}]},
 "Custom Surface Shapes"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[3005, 109, 195, 4, 20, "Outline2",
   CellTags->"Custom Surface Shapes"],
  Cell[3203, 115, 1238, 42, 133, "Outline3",
   CellTags->"Custom Surface Shapes"],
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}],
  Cell[894771, 16479, 703, 17, 34, "Text",
   Evaluatable->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[895477, 16498, 1265, 30, 148, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896745, 16530, 112, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896860, 16533, 749, 21, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[897612, 16556, 1688, 71, 102, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899303, 16629, 299, 9, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899605, 16640, 1451, 52, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901059, 16694, 237, 4, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901299, 16700, 1044, 22, 60, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[902346, 16724, 983, 19, 59, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903354, 16747, 384, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903741, 16762, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904280, 16776, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904819, 16790, 53569, 876, 372, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958403, 17669, 149, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958555, 17674, 596, 17, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[959154, 17693, 935, 34, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960092, 17729, 164, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960259, 17734, 570, 14, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960854, 17752, 112, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960969, 17756, 478, 12, 34, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[961462, 17771, 682, 14, 50, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962169, 17789, 370, 12, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962542, 17803, 224950, 3563, 330, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187507, 21369, 154, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187664, 21374, 271, 5, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187938, 21381, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195005, 21609, 120, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195128, 21613, 376, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195519, 21623, 474, 12, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196018, 21639, 142, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196163, 21643, 534, 12, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196712, 21658, 499, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197236, 21675, 154, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197393, 21679, 647, 17, 42, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198055, 21699, 172, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199582, 21753, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1216757, 22054, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220209, 22177, 205, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220417, 22184, 751, 21, 50, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221893, 22232, 322, 9, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222218, 22243, 182, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1236457, 22508, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1236656, 22516, 118, 1, 35, "Subsection",
   CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1236777, 22519, 815, 24, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1237595, 22545, 563, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1238161, 22565, 1709, 52, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1239873, 22619, 1448, 47, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1241324, 22668, 1642, 48, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1242969, 22718, 1524, 46, 67, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1244518, 22768, 177, 3, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1244698, 22773, 325, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245038, 22781, 295, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245358, 22791, 235, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245596, 22801, 372, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245983, 22810, 129, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246137, 22815, 148, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246288, 22819, 199460, 3241, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1445763, 26063, 461, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446249, 26078, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446528, 26088, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446906, 26096, 149930, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1596851, 28675, 1819, 42, 99, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598673, 28719, 117, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598815, 28725, 271, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599089, 28736, 373, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599499, 28747, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599633, 28751, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600022, 28760, 585, 12, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600632, 28776, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600911, 28786, 909, 16, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1601823, 28804, 709, 13, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602535, 28819, 405, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602943, 28828, 141021, 2427, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744001, 31260, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744135, 31264, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744527, 31273, 311, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744863, 31284, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745138, 31295, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745549, 31306, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745683, 31310, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746074, 31319, 299, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746398, 31332, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746677, 31342, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1747056, 31350, 149932, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897025, 33931, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897159, 33935, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897548, 33944, 258, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897831, 33955, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898106, 33966, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898518, 33977, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898652, 33981, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899041, 33990, 313, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899379, 34002, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899658, 34012, 368, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1900029, 34020, 149917, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2049983, 36601, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050117, 36605, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050509, 36614, 1341, 32, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2051853, 36648, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}],
  Cell[2052269, 36663, 384, 9, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052656, 36674, 200, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052859, 36681, 300, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053162, 36694, 216, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053381, 36701, 492, 15, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053876, 36718, 253, 7, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055679, 36778, 489, 21, 252, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056171, 36801, 652, 23, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056848, 36828, 222, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2057073, 36835, 25095, 403, 168, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082183, 37241, 286, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082494, 37256, 207, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082704, 37263, 16992, 296, 365, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2099711, 37562, 342, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100078, 37578, 338, 12, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100419, 37592, 13569, 279, 105, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2395143, 43255, 445, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2395613, 43271, 457, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2396073, 43284, 13212, 276, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2409300, 43563, 756, 19, 50, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410081, 43586, 454, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410538, 43599, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411264, 43617, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411990, 43635, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2412716, 43653, 731, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2413450, 43671, 13138, 274, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2426603, 43948, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[2426802, 43956, 201, 6, 35, "Subsection",
   CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2427006, 43964, 448, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.5"}],
  Cell[2427457, 43978, 781, 25, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2428241, 44005, 1836, 42, 93, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2430080, 44049, 2981, 77, 310, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433064, 44128, 254, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433321, 44136, 1556, 25, 96, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2434880, 44163, 1372, 37, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436277, 44204, 396, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436676, 44219, 57340, 927, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2494019, 45148, 23067, 419, 419, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517101, 45570, 219, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517323, 45578, 399, 7, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517747, 45589, 332, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2518082, 45598, 54722, 886, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2572819, 46487, 192, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573036, 46495, 424, 14, 171, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573463, 46511, 119021, 1853, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2692487, 48366, 26691, 458, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719193, 48827, 222, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719418, 48835, 277, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719720, 48845, 136, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719859, 48849, 311, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720185, 48857, 216, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720426, 48866, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720764, 48878, 44789, 712, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2765568, 49593, 467, 9, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766060, 49606, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766398, 49618, 41446, 724, 383, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2807859, 50345, 163, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2808025, 50351, 1194, 33, 447, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809244, 50388, 200, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809447, 50397, 422031, 6709, 271, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231493, 57109, 230, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231748, 57120, 244, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231995, 57129, 34846, 552, 233, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3266856, 57684, 236, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267117, 57694, 267, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267387, 57704, 396352, 6269, 248, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3663754, 63976, 885, 19, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664664, 63999, 262, 12, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664929, 64013, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3665466, 64027, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3666003, 64041, 289761, 5004, 152, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3955779, 69048, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[3955978, 69056, 252, 7, 35, "Subsection",
   CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3956233, 69065, 804, 14, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957062, 69083, 398, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957463, 69095, 517025, 8331, 205, 512665, 8256, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4474491, 77428, 440235, 7710, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914741, 85141, 223, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914967, 85149, 148, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915140, 85156, 239, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915382, 85166, 13808, 255, 136, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929205, 85424, 106, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929314, 85427, 154, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929493, 85434, 297, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929793, 85444, 440561, 7716, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370369, 93163, 101, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370473, 93166, 345, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370843, 93178, 625, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5371471, 93193, 513284, 8286, 208, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5884758, 101481, 445359, 7798, 320, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[6330132, 109282, 291, 7, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[6330426, 109291, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6330625, 109299, 169, 4, 35, "Subsection",
   CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6330797, 109305, 616, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331438, 109322, 414, 9, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331855, 109333, 687, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6332545, 109349, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333233, 109365, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333921, 109381, 679, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6334603, 109397, 34371, 579, 393, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6368989, 109979, 217, 4, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6369209, 109985, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6369408, 109993, 255, 7, 35, "Subsection",
   CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6369666, 110002, 667, 13, 47, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370358, 110019, 393, 13, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370754, 110034, 52388, 875, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6423145, 110911, 38731, 790, 366, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6461891, 111704, 155, 2, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462049, 111708, 251, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462325, 111717, 157, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462485, 111721, 565, 15, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463065, 111739, 207, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463297, 111747, 213, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463513, 111754, 741, 21, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464269, 111778, 483, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464777, 111793, 483, 14, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6465263, 111809, 73645, 1224, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6538911, 113035, 38451, 790, 361, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577377, 113828, 194, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577574, 113835, 714, 19, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6578291, 113856, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6578490, 113864, 125, 1, 35, "Subsection",
   CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6578618, 113867, 376, 12, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579019, 113883, 118, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579140, 113887, 1424, 24, 56, "Print",
   CellTags->{
    "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}],
  Cell[6580579, 113914, 393, 7, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6580997, 113925, 265, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581265, 113933, 636, 17, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581938, 113955, 222, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582163, 113963, 359, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582537, 113973, 240, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582780, 113983, 141, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582924, 113987, 543, 11, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583492, 114002, 183, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583678, 114008, 642, 19, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584335, 114030, 346, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584684, 114041, 227, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584914, 114049, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585071, 114054, 282, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585356, 114064, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585893, 114078, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586432, 114092, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586969, 114106, 711, 15, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6587683, 114123, 7673, 142, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595371, 114268, 170, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595544, 114275, 401, 5, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595948, 114282, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6596147, 114290, 164, 4, 35, "Subsection",
   CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6596314, 114296, 955, 27, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597294, 114327, 121, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597418, 114331, 5918, 152, 168, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603351, 114486, 214, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603590, 114497, 171, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603764, 114503, 1976, 33, 229, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6605755, 114539, 952, 21, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6606710, 114562, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}]},
 "Gratings"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[4478, 162, 195, 4, 20, "Outline2",
   CellTags->"Gratings"],
  Cell[4676, 168, 384, 12, 29, "Outline3",
   Evaluatable->False,
   CellTags->"Gratings"],
  Cell[6606921, 114571, 199, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
     "PR4.4.0"}],
  Cell[6607123, 114578, 385, 12, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6607511, 114592, 1621, 64, 84, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609135, 114658, 280, 9, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609440, 114671, 231, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609674, 114680, 23672, 400, 251, 9186, 160, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633361, 115083, 128, 2, 26, "Commentary",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633492, 115087, 739, 13, 46, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634234, 115102, 720, 19, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634957, 115123, 1366, 44, 63, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6636326, 115169, 706, 18, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6637035, 115189, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}],
  Cell[6637209, 115196, 121, 1, 35, "Subsection",
   CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637355, 115201, 106, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637464, 115205, 428, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637929, 115221, 115, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638047, 115225, 421, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638483, 115239, 289, 9, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638797, 115252, 303, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6639103, 115262, 8377, 165, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647517, 115432, 385, 10, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647905, 115444, 525, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6648433, 115458, 664, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649100, 115474, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649626, 115488, 687, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650316, 115504, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650842, 115518, 700, 15, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6651545, 115535, 9843, 215, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6661403, 115753, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}],
  Cell[6661589, 115761, 131, 1, 35, "Subsection",
   CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}],
  
  Cell[6661745, 115766, 254, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662002, 115775, 737, 22, 51, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662754, 115800, 113, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662892, 115806, 213, 5, 41, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6663108, 115813, 1103, 32, 59, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664248, 115850, 285, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664536, 115860, 3169, 61, 438, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667742, 115926, 128, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667873, 115930, 2782, 57, 337, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6670658, 115989, 450, 11, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671145, 116005, 299, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671447, 116015, 6645, 117, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678129, 116137, 137, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678269, 116141, 2777, 57, 325, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681049, 116200, 433, 10, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681519, 116215, 325, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681847, 116225, 6536, 115, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688420, 116345, 140, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688563, 116349, 2591, 46, 353, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691157, 116397, 428, 10, 23, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691622, 116412, 101, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691726, 116416, 2480, 33, 334, "Print",
   CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}],
  Cell[6694243, 116454, 363, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6694609, 116464, 905, 19, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6695517, 116485, 12459, 221, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6707979, 116708, 915, 20, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6708897, 116730, 47697, 850, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6756597, 117582, 65331, 1104, 240, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6821965, 118691, 370, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6822338, 118701, 241331, 3444, 365, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7063706, 122150, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064156, 122162, 771, 18, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064930, 122182, 49650, 880, 234, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7114583, 123064, 52432, 900, 112, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167052, 123969, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167502, 123981, 737, 17, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7168242, 124000, 55364, 984, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7223609, 124986, 58357, 1004, 126, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7281981, 125993, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}]},
 "CustomDeflections"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[5291, 191, 187, 4, 20, "Outline2",
   CellTags->"CustomDeflections"],
  Cell[5503, 199, 850, 28, 81, "Outline3",
   Evaluatable->False,
   CellTags->"CustomDeflections"],
  Cell[6356, 229, 295, 10, 27, "Outline4",
   CellTags->"CustomDeflections"],
  Cell[7379890, 128062, 147, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380040, 128067, 581, 12, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380624, 128081, 713, 26, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7381340, 128109, 818, 23, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7382161, 128134, 1143, 31, 180, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383307, 128167, 242, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383552, 128177, 806, 22, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384361, 128201, 217, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384603, 128211, 218, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384824, 128219, 2844, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387683, 128278, 232, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387918, 128288, 373, 10, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7388294, 128300, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7388477, 128307, 120, 1, 35, "Subsection",
   CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7388600, 128310, 590, 18, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389215, 128332, 229, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389447, 128343, 644, 18, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390106, 128364, 176, 4, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390307, 128372, 223, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390533, 128380, 2950, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7393498, 128441, 314, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7393815, 128452, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7394010, 128460, 129, 1, 35, "Subsection",
   CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7394142, 128463, 880, 18, 53, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395047, 128485, 262, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395312, 128496, 448, 12, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395797, 128513, 221, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7396021, 128521, 2841, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7398877, 128580, 159, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399039, 128584, 593, 20, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399657, 128608, 438, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7400098, 128626, 2837, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7402950, 128685, 217, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403170, 128693, 366, 11, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403561, 128708, 455, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7404019, 128726, 2952, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7406986, 128787, 155, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407144, 128791, 420, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407589, 128807, 514, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7408106, 128827, 3325, 65, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411446, 128895, 133, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411582, 128898, 582, 20, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412189, 128922, 216, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412408, 128930, 2344, 46, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7414767, 128979, 368, 11, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7415138, 128992, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7415333, 129000, 219, 8, 35, "Subsection",
   CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415555, 129010, 439, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415997, 129024, 857, 25, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7416857, 129051, 292, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7417152, 129061, 1227, 44, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418382, 129107, 428, 13, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418835, 129124, 228, 8, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419066, 129134, 333, 6, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419414, 129143, 196, 5, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419635, 129152, 306, 10, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419944, 129164, 2946, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7422905, 129225, 216, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423124, 129233, 271, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423420, 129243, 330, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423753, 129256, 2832, 55, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426600, 129314, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426813, 129321, 391, 8, 34, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427229, 129333, 329, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427561, 129346, 2944, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430520, 129407, 217, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430740, 129414, 317, 6, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431060, 129422, 474, 10, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431559, 129436, 433, 15, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431995, 129453, 6909, 123, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7438907, 129578, 378, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439300, 129589, 215, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439518, 129596, 350, 8, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439893, 129608, 396, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7440292, 129622, 21487, 368, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7461782, 129992, 375, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462172, 130003, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462385, 130010, 395, 9, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462805, 130023, 411, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7463219, 130037, 4676, 87, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7467898, 130126, 408, 9, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7468321, 130138, 212, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7468536, 130145, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7468731, 130153, 133, 1, 35, "Subsection",
   CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7468867, 130156, 938, 18, 64, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7469830, 130178, 243, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7470076, 130189, 22046, 377, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492137, 130569, 126, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492266, 130572, 404, 11, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492695, 130587, 212, 6, 24, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492910, 130595, 573, 16, 24, "Output",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7493498, 130614, 707, 19, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7494230, 130637, 247, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7494480, 130648, 5654, 101, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7500149, 130752, 234, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7500386, 130760, 842, 21, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7501253, 130785, 422, 10, 122, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7501678, 130797, 6106, 110, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7507799, 130910, 247, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508049, 130918, 425, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508499, 130933, 224, 8, 89, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508726, 130943, 2088, 44, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7510829, 130990, 260, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7511092, 130998, 428, 12, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7511523, 131012, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7511718, 131020, 204, 6, 35, "Subsection",
   CellTags->{
    "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  
  Cell[7511925, 131028, 1746, 46, 103, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7513674, 131076, 528, 16, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7514205, 131094, 1490, 38, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7515698, 131134, 894, 29, 431, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7516595, 131165, 403, 12, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7517001, 131179, 1334, 29, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518338, 131210, 418, 11, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518759, 131223, 534, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7519296, 131243, 1300, 30, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520599, 131275, 268, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520892, 131288, 187, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7521082, 131295, 2197, 43, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523294, 131341, 288, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523607, 131354, 191, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523801, 131361, 3182, 61, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7526998, 131425, 293, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7527294, 131436, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7527489, 131444, 157, 4, 35, "Subsection",
   CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7527649, 131450, 1313, 32, 70, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7528987, 131486, 359, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7529349, 131500, 11531, 198, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7540895, 131701, 362, 7, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541282, 131712, 236, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541521, 131720, 11509, 201, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553045, 131924, 482, 9, 37, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553530, 131935, 169, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553724, 131942, 144, 1, 31, "Subsubsection",
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553871, 131945, 535, 12, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554431, 131961, 467, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554901, 131981, 11963, 210, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7566879, 132194, 345, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567227, 132205, 580, 19, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567810, 132226, 522, 14, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7568335, 132242, 1593, 35, 99, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7569931, 132279, 1573, 45, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571507, 132326, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7571702, 132334, 109, 1, 31, "Subsubsection",
   CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571814, 132337, 461, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572278, 132350, 574, 17, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572855, 132369, 754, 18, 51, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573634, 132391, 196, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573833, 132398, 2517, 55, 402, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576365, 132456, 294, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576662, 132466, 974, 18, 67, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577661, 132488, 252, 5, 41, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577916, 132495, 11394, 197, 224, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589325, 132695, 309, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589637, 132705, 307, 7, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589947, 132714, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}]},
 "Generic Building Blocks"->{
  Cell[579, 22, 201, 4, 60, "Subtitle",
   CellTags->{
    "chapter 4 topics", "Aperture Shapes", "Light Sources", 
     "Custom Surface Shapes", "Gratings", "CustomDeflections", 
     "Generic Building Blocks"}],
  Cell[7282179, 126002, 176, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.5", "Generic Building Blocks", "PR4.5"}],
  Cell[7282358, 126007, 892, 23, 53, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7283275, 126034, 142, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7283420, 126038, 14522, 417, 162, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7297957, 126458, 229, 4, 26, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7298189, 126464, 1287, 25, 85, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7299501, 126493, 141, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7299645, 126497, 893, 24, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7300553, 126524, 1363, 37, 70, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7301941, 126565, 287, 8, 57, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7302231, 126575, 11532, 197, 159, "Print",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7313778, 126775, 152, 2, 26, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7313933, 126779, 150, 5, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314108, 126788, 124, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314235, 126792, 749, 20, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314999, 126815, 980, 27, 54, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316004, 126846, 124, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316131, 126850, 758, 20, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316904, 126873, 797, 24, 38, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7317726, 126901, 139, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7317868, 126905, 1091, 27, 40, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7318974, 126935, 286, 6, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7319285, 126945, 136, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7319424, 126949, 7830, 183, 399, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7327269, 127135, 1080, 29, 70, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7328374, 127168, 401, 11, 138, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7328778, 127181, 47160, 755, 327, "Print",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7375953, 127939, 368, 12, 27, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376324, 127953, 306, 8, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376655, 127965, 137, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376795, 127969, 813, 21, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7377623, 127993, 634, 16, 38, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7378282, 128013, 144, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7378429, 128017, 891, 23, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7379335, 128043, 351, 9, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7379689, 128054, 164, 3, 20, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}]},
 "4.1"->{
  Cell[6700, 245, 187, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}]},
 "aperture shapes"->{
  Cell[6700, 245, 187, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[6890, 250, 883, 23, 33, "Text",
   Evaluatable->False,
   CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}],
  Cell[99599, 1938, 761, 25, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100385, 1967, 240, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100628, 1976, 23320, 379, 438, "Print",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}],
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[138070, 2619, 511, 18, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138606, 2641, 275, 12, 106, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138884, 2655, 23415, 395, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}]},
 "PR4.1.1"->{
  Cell[6700, 245, 187, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[6890, 250, 883, 23, 33, "Text",
   Evaluatable->False,
   CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22434, 544, 100, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45670, 996, 124, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98812, 1912, 131, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98946, 1915, 244, 6, 20, "Text",
   Evaluatable->False,
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}]},
 "PR4.1"->{
  Cell[6700, 245, 187, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[6890, 250, 883, 23, 33, "Text",
   Evaluatable->False,
   CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22434, 544, 100, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45670, 996, 124, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98812, 1912, 131, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[98946, 1915, 244, 6, 20, "Text",
   Evaluatable->False,
   CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[99193, 1923, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}],
  Cell[99599, 1938, 761, 25, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100385, 1967, 240, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100628, 1976, 23320, 379, 438, "Print",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[123963, 2358, 97, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.2"}],
  Cell[124063, 2361, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}],
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[137971, 2616, 96, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[138070, 2619, 511, 18, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138606, 2641, 275, 12, 106, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138884, 2655, 23415, 395, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[162314, 3053, 101, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[162418, 3056, 145, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[162566, 3061, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}],
  Cell[162759, 3069, 121, 1, 35, "Subsection",
   CellTags->{
    "4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[162883, 3072, 427, 10, 33, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163313, 3084, 460, 12, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163776, 3098, 4392, 137, 131, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168171, 3237, 141, 2, 24, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168315, 3241, 188, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168506, 3248, 426, 9, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168957, 3261, 1333, 38, 105, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[170293, 3301, 8200, 148, 397, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178508, 3452, 147, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178658, 3459, 323, 8, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179006, 3471, 426, 11, 25, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179435, 3484, 14097, 298, 365, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193547, 3785, 149, 3, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193699, 3790, 314, 7, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[194016, 3799, 156, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1"}]},
 "4.1.1"->{
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}]},
 "circular apertures"->{
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}]},
 "elliptical apertures"->{
  Cell[7798, 277, 244, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8045, 284, 746, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[8816, 312, 263, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[9082, 321, 13337, 220, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[22537, 547, 1127, 37, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23689, 588, 242, 5, 24, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[23934, 595, 21721, 398, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[45797, 999, 1297, 45, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47119, 1048, 302, 9, 57, "Input",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}],
  Cell[47424, 1059, 51373, 850, 438, "Print",
   CellTags->{
    "aperture shapes", "circular apertures", "elliptical apertures", 
     "Aperture Shapes", "PR4.1.1", "PR4.1"}]},
 "4.1.2"->{
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}]},
 "rectangular apertures"->{
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}],
  Cell[99599, 1938, 761, 25, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100385, 1967, 240, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100628, 1976, 23320, 379, 438, "Print",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}]},
 "PR4.1.2"->{
  Cell[99386, 1931, 210, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.2"}],
  Cell[99599, 1938, 761, 25, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100385, 1967, 240, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[100628, 1976, 23320, 379, 438, "Print",
   CellTags->{
    "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.2"}],
  Cell[123963, 2358, 97, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.2"}]},
 "4.1.3"->{
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}]},
 "polygonal apertures"->{
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}],
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[138070, 2619, 511, 18, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138606, 2641, 275, 12, 106, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138884, 2655, 23415, 395, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}]},
 "PR4.1.3"->{
  Cell[124256, 2369, 206, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
     "PR4.1", "PR4.1.3"}],
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[137971, 2616, 96, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[138070, 2619, 511, 18, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138606, 2641, 275, 12, 106, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[138884, 2655, 23415, 395, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
     "PR4.1.3"}],
  Cell[162314, 3053, 101, 1, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[162418, 3056, 145, 3, 20, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}]},
 "triangular apertures"->{
  Cell[124465, 2376, 437, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[124927, 2391, 278, 7, 24, "Input",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}],
  Cell[125208, 2400, 12748, 213, 438, "Print",
   CellTags->{
    "aperture shapes", "polygonal apertures", "triangular apertures", 
     "Aperture Shapes", "PR4.1", "PR4.1.3"}]},
 "4.1.4"->{
  Cell[162759, 3069, 121, 1, 35, "Subsection",
   CellTags->{
    "4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}]},
 "Aperture Stops"->{
  Cell[162759, 3069, 121, 1, 35, "Subsection",
   CellTags->{
    "4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}]},
 "PR4.1.4"->{
  Cell[162759, 3069, 121, 1, 35, "Subsection",
   CellTags->{
    "4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[162883, 3072, 427, 10, 33, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163313, 3084, 460, 12, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[163776, 3098, 4392, 137, 131, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168171, 3237, 141, 2, 24, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168315, 3241, 188, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168506, 3248, 426, 9, 34, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[168957, 3261, 1333, 38, 105, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[170293, 3301, 8200, 148, 397, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178508, 3452, 147, 5, 27, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[178658, 3459, 323, 8, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179006, 3471, 426, 11, 25, "Input",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[179435, 3484, 14097, 298, 365, "Print",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193547, 3785, 149, 3, 26, "Commentary",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
  Cell[193699, 3790, 314, 7, 21, "Text",
   CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}]},
 "4.2"->{
  Cell[194221, 3808, 93, 1, 60, "Section",
   CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}]},
 "PR4.2"->{
  Cell[194221, 3808, 93, 1, 60, "Section",
   CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[194317, 3811, 702, 13, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[195044, 3828, 176, 3, 35, "Subsection",
   CellTags->{
    "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
     "PR4.2", "PR4.2.1"}],
  Cell[195245, 3835, 160, 3, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[195408, 3840, 864, 14, 60, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196275, 3856, 576, 15, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196876, 3875, 1951, 52, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[198830, 3929, 55173, 887, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254018, 4819, 284, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254305, 4829, 448, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254756, 4839, 323, 11, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[255104, 4854, 1823, 49, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[256930, 4905, 54707, 879, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311652, 5787, 264, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311919, 5795, 347, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312269, 5804, 449, 11, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312721, 5817, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[312912, 5825, 152, 2, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with ReadRays", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[313067, 5829, 402, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313472, 5839, 350, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313847, 5853, 1983, 54, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[315833, 5909, 61833, 993, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377681, 6905, 287, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377971, 6914, 385, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378359, 6924, 470, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378832, 6935, 709, 15, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379566, 6954, 304, 7, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379873, 6963, 1496, 37, 48, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[381384, 7003, 1035, 28, 62, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[382422, 7033, 875, 23, 48, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383300, 7058, 574, 16, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383899, 7078, 661, 21, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[384563, 7101, 1813, 43, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386391, 7147, 175, 4, 20, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386569, 7153, 921, 25, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[387493, 7180, 1041, 32, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388537, 7214, 128, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388690, 7220, 927, 26, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[389620, 7248, 62670, 1006, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452305, 8257, 164, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452472, 8263, 370, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452845, 8274, 412, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453260, 8286, 354, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453617, 8297, 1675, 47, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455295, 8346, 191, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455489, 8352, 188, 5, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455702, 8361, 1481, 40, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[457186, 8403, 63822, 1027, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521023, 9433, 263, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521289, 9441, 336, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521628, 9450, 525, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[522156, 9465, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}],
  Cell[522548, 9479, 433, 13, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[522984, 9494, 376, 6, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[523363, 9502, 824, 14, 50, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[524190, 9518, 1462, 37, 76, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[525655, 9557, 542, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[526222, 9574, 1022, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[527247, 9605, 1615, 34, 99, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[528877, 9642, 252, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529132, 9650, 425, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529582, 9665, 1023, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[530608, 9696, 1640, 36, 163, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532263, 9735, 236, 5, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532502, 9742, 463, 12, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532968, 9756, 260, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[533253, 9768, 1700, 46, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[534956, 9816, 5321, 97, 303, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[540292, 9916, 308, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[540603, 9926, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[540794, 9934, 158, 3, 35, "Subsection",
   CellTags->{
    "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
     "PR4.2.3"}],
  Cell[540955, 9939, 347, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541305, 9950, 630, 17, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541938, 9969, 3693, 104, 229, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545634, 10075, 110, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545747, 10078, 322, 7, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[546094, 10089, 1189, 36, 131, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[547286, 10127, 2791, 86, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550092, 10216, 236, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550331, 10227, 313, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550669, 10240, 663, 18, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[551335, 10260, 101782, 1834, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653132, 12097, 112, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653247, 12100, 386, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653636, 12112, 697, 20, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654358, 12136, 601, 15, 87, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654962, 12153, 3040, 95, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[658039, 12253, 985, 24, 121, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[659027, 12279, 142085, 2384, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801127, 14666, 630, 21, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801760, 14689, 386, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[802149, 14700, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}],
  Cell[802340, 14708, 128, 2, 35, "Subsection",
   CellTags->{
    "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802471, 14712, 473, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802947, 14723, 452, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803402, 14735, 403, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803830, 14748, 1027, 29, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[804860, 14779, 13596, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818471, 15011, 221, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818695, 15019, 457, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[819177, 15034, 1146, 33, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[820326, 15069, 13584, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[833925, 15301, 250, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834178, 15310, 359, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834540, 15320, 272, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834837, 15333, 1357, 34, 168, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[836197, 15369, 57972, 1085, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[894184, 16457, 172, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[894359, 16463, 154, 3, 20, "Text",
   CellTags->{"Light Sources", "PR4.2"}]},
 "PR4.2.1"->{
  Cell[194221, 3808, 93, 1, 60, "Section",
   CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[194317, 3811, 702, 13, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[195044, 3828, 176, 3, 35, "Subsection",
   CellTags->{
    "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
     "PR4.2", "PR4.2.1"}],
  Cell[195245, 3835, 160, 3, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[195408, 3840, 864, 14, 60, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196275, 3856, 576, 15, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[196876, 3875, 1951, 52, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[198830, 3929, 55173, 887, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254018, 4819, 284, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254305, 4829, 448, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[254756, 4839, 323, 11, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[255104, 4854, 1823, 49, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[256930, 4905, 54707, 879, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311652, 5787, 264, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[311919, 5795, 347, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312269, 5804, 449, 11, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[312912, 5825, 152, 2, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with ReadRays", "Light Sources", "PR4.2", 
     "PR4.2.1"}],
  Cell[313067, 5829, 402, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313472, 5839, 350, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[313847, 5853, 1983, 54, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[315833, 5909, 61833, 993, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377681, 6905, 287, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[377971, 6914, 385, 8, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378359, 6924, 470, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[378832, 6935, 709, 15, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379566, 6954, 304, 7, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[379873, 6963, 1496, 37, 48, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[381384, 7003, 1035, 28, 62, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[382422, 7033, 875, 23, 48, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383300, 7058, 574, 16, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[383899, 7078, 661, 21, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[384563, 7101, 1813, 43, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386391, 7147, 175, 4, 20, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[386569, 7153, 921, 25, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[387493, 7180, 1041, 32, 49, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388537, 7214, 128, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[388690, 7220, 927, 26, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[389620, 7248, 62670, 1006, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452305, 8257, 164, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452472, 8263, 370, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[452845, 8274, 412, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453260, 8286, 354, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[453617, 8297, 1675, 47, 73, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455295, 8346, 191, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455489, 8352, 188, 5, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[455702, 8361, 1481, 40, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[457186, 8403, 63822, 1027, 384, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521023, 9433, 263, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521289, 9441, 336, 7, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
  Cell[521628, 9450, 525, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]},
 "4.2.1"->{
  Cell[195044, 3828, 176, 3, 35, "Subsection",
   CellTags->{
    "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
     "PR4.2", "PR4.2.1"}]},
 "Maintaining Constant Pupil Illumination"->{
  Cell[195044, 3828, 176, 3, 35, "Subsection",
   CellTags->{
    "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
     "PR4.2", "PR4.2.1"}]},
 "Constant Illumination with BirthPoint"->{
  Cell[195245, 3835, 160, 3, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
     "PR4.2.1"}]},
 "Constant Illumination with ReadRays"->{
  Cell[312912, 5825, 152, 2, 31, "Subsubsection",
   CellTags->{
    "Constant Illumination with ReadRays", "Light Sources", "PR4.2", 
     "PR4.2.1"}]},
 "4.2.2"->{
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}]},
 "Distant Sources"->{
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}]},
 "Lasers"->{
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}]},
 "Beam Divergence"->{
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}]},
 "PR4.2.2"->{
  Cell[522359, 9474, 186, 3, 35, "Subsection",
   CellTags->{
    "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
     "PR4.2", "PR4.2.2"}],
  Cell[522548, 9479, 433, 13, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[522984, 9494, 376, 6, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[523363, 9502, 824, 14, 50, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[524190, 9518, 1462, 37, 76, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[525655, 9557, 542, 13, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[526222, 9574, 1022, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[527247, 9605, 1615, 34, 99, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[528877, 9642, 252, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529132, 9650, 425, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[529582, 9665, 1023, 29, 41, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[530608, 9696, 1640, 36, 163, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532263, 9735, 236, 5, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532502, 9742, 463, 12, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[532968, 9756, 260, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[533253, 9768, 1700, 46, 57, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[534956, 9816, 5321, 97, 303, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
  Cell[540292, 9916, 308, 8, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}]},
 "4.2.3"->{
  Cell[540794, 9934, 158, 3, 35, "Subsection",
   CellTags->{
    "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
     "PR4.2.3"}]},
 "Laser Cavities and MoveAligned"->{
  Cell[540794, 9934, 158, 3, 35, "Subsection",
   CellTags->{
    "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
     "PR4.2.3"}]},
 "PR4.2.3"->{
  Cell[540794, 9934, 158, 3, 35, "Subsection",
   CellTags->{
    "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
     "PR4.2.3"}],
  Cell[540955, 9939, 347, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541305, 9950, 630, 17, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[541938, 9969, 3693, 104, 229, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545634, 10075, 110, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[545747, 10078, 322, 7, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[546094, 10089, 1189, 36, 131, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[547286, 10127, 2791, 86, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550092, 10216, 236, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550331, 10227, 313, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[550669, 10240, 663, 18, 25, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[551335, 10260, 101782, 1834, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653132, 12097, 112, 1, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653247, 12100, 386, 10, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[653636, 12112, 697, 20, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654358, 12136, 601, 15, 87, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[654962, 12153, 3040, 95, 54, "Output",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[658039, 12253, 985, 24, 121, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[659027, 12279, 142085, 2384, 81, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801127, 14666, 630, 21, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
  Cell[801760, 14689, 386, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}]},
 "4.2.4"->{
  Cell[802340, 14708, 128, 2, 35, "Subsection",
   CellTags->{
    "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}]},
 "Chromatic Sources"->{
  Cell[802340, 14708, 128, 2, 35, "Subsection",
   CellTags->{
    "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}]},
 "PR4.2.4"->{
  Cell[802340, 14708, 128, 2, 35, "Subsection",
   CellTags->{
    "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802471, 14712, 473, 9, 33, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[802947, 14723, 452, 10, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803402, 14735, 403, 9, 34, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[803830, 14748, 1027, 29, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[804860, 14779, 13596, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818471, 15011, 221, 6, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[818695, 15019, 457, 11, 35, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[819177, 15034, 1146, 33, 89, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[820326, 15069, 13584, 229, 281, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[833925, 15301, 250, 7, 27, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834178, 15310, 359, 8, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834540, 15320, 272, 9, 21, "Text",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[834837, 15333, 1357, 34, 168, "Input",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[836197, 15369, 57972, 1085, 397, "Print",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
  Cell[894184, 16457, 172, 4, 26, "Commentary",
   CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}]},
 "user defined models"->{
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}],
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]},
 "ModelSurfaceShape"->{
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}],
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]},
 "4.3"->{
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}]},
 "PR4.3"->{
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}],
  Cell[894771, 16479, 703, 17, 34, "Text",
   Evaluatable->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[895477, 16498, 1265, 30, 148, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896745, 16530, 112, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896860, 16533, 749, 21, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[897612, 16556, 1688, 71, 102, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899303, 16629, 299, 9, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899605, 16640, 1451, 52, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901059, 16694, 237, 4, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901299, 16700, 1044, 22, 60, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[902346, 16724, 983, 19, 59, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903354, 16747, 384, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903741, 16762, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904280, 16776, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904819, 16790, 53569, 876, 372, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958403, 17669, 149, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958555, 17674, 596, 17, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[959154, 17693, 935, 34, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960092, 17729, 164, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960259, 17734, 570, 14, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960854, 17752, 112, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960969, 17756, 478, 12, 34, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[961462, 17771, 682, 14, 50, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962169, 17789, 370, 12, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962542, 17803, 224950, 3563, 330, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187507, 21369, 154, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187664, 21374, 271, 5, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187938, 21381, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195005, 21609, 120, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195128, 21613, 376, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195519, 21623, 474, 12, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196018, 21639, 142, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196163, 21643, 534, 12, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196712, 21658, 499, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197236, 21675, 154, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197393, 21679, 647, 17, 42, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198055, 21699, 172, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199582, 21753, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1216757, 22054, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220209, 22177, 205, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220417, 22184, 751, 21, 50, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221893, 22232, 322, 9, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222218, 22243, 182, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1236457, 22508, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[1236656, 22516, 118, 1, 35, "Subsection",
   CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1236777, 22519, 815, 24, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1237595, 22545, 563, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1238161, 22565, 1709, 52, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1239873, 22619, 1448, 47, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1241324, 22668, 1642, 48, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1242969, 22718, 1524, 46, 67, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1244518, 22768, 177, 3, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1244698, 22773, 325, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245038, 22781, 295, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245358, 22791, 235, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245596, 22801, 372, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245983, 22810, 129, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246137, 22815, 148, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246288, 22819, 199460, 3241, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1445763, 26063, 461, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446249, 26078, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446528, 26088, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446906, 26096, 149930, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1596851, 28675, 1819, 42, 99, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598673, 28719, 117, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598815, 28725, 271, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599089, 28736, 373, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599499, 28747, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599633, 28751, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600022, 28760, 585, 12, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600632, 28776, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600911, 28786, 909, 16, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1601823, 28804, 709, 13, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602535, 28819, 405, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602943, 28828, 141021, 2427, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744001, 31260, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744135, 31264, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744527, 31273, 311, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744863, 31284, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745138, 31295, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745549, 31306, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745683, 31310, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746074, 31319, 299, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746398, 31332, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746677, 31342, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1747056, 31350, 149932, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897025, 33931, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897159, 33935, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897548, 33944, 258, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897831, 33955, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898106, 33966, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898518, 33977, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898652, 33981, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899041, 33990, 313, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899379, 34002, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899658, 34012, 368, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1900029, 34020, 149917, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2049983, 36601, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050117, 36605, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050509, 36614, 1341, 32, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2051853, 36648, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}],
  Cell[2052269, 36663, 384, 9, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052656, 36674, 200, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052859, 36681, 300, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053162, 36694, 216, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053381, 36701, 492, 15, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053876, 36718, 253, 7, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055679, 36778, 489, 21, 252, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056171, 36801, 652, 23, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056848, 36828, 222, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2057073, 36835, 25095, 403, 168, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082183, 37241, 286, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082494, 37256, 207, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082704, 37263, 16992, 296, 365, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2099711, 37562, 342, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100078, 37578, 338, 12, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100419, 37592, 13569, 279, 105, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2395143, 43255, 445, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2395613, 43271, 457, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2396073, 43284, 13212, 276, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2409300, 43563, 756, 19, 50, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410081, 43586, 454, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410538, 43599, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411264, 43617, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411990, 43635, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2412716, 43653, 731, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2413450, 43671, 13138, 274, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2426603, 43948, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[2426802, 43956, 201, 6, 35, "Subsection",
   CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2427006, 43964, 448, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.5"}],
  Cell[2427457, 43978, 781, 25, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2428241, 44005, 1836, 42, 93, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2430080, 44049, 2981, 77, 310, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433064, 44128, 254, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433321, 44136, 1556, 25, 96, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2434880, 44163, 1372, 37, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436277, 44204, 396, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436676, 44219, 57340, 927, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2494019, 45148, 23067, 419, 419, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517101, 45570, 219, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517323, 45578, 399, 7, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517747, 45589, 332, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2518082, 45598, 54722, 886, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2572819, 46487, 192, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573036, 46495, 424, 14, 171, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573463, 46511, 119021, 1853, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2692487, 48366, 26691, 458, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719193, 48827, 222, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719418, 48835, 277, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719720, 48845, 136, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719859, 48849, 311, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720185, 48857, 216, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720426, 48866, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720764, 48878, 44789, 712, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2765568, 49593, 467, 9, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766060, 49606, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766398, 49618, 41446, 724, 383, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2807859, 50345, 163, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2808025, 50351, 1194, 33, 447, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809244, 50388, 200, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809447, 50397, 422031, 6709, 271, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231493, 57109, 230, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231748, 57120, 244, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231995, 57129, 34846, 552, 233, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3266856, 57684, 236, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267117, 57694, 267, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267387, 57704, 396352, 6269, 248, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3663754, 63976, 885, 19, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664664, 63999, 262, 12, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664929, 64013, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3665466, 64027, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3666003, 64041, 289761, 5004, 152, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3955779, 69048, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[3955978, 69056, 252, 7, 35, "Subsection",
   CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3956233, 69065, 804, 14, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957062, 69083, 398, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957463, 69095, 517025, 8331, 205, 512665, 8256, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4474491, 77428, 440235, 7710, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914741, 85141, 223, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914967, 85149, 148, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915140, 85156, 239, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915382, 85166, 13808, 255, 136, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929205, 85424, 106, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929314, 85427, 154, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929493, 85434, 297, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929793, 85444, 440561, 7716, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370369, 93163, 101, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370473, 93166, 345, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370843, 93178, 625, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5371471, 93193, 513284, 8286, 208, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5884758, 101481, 445359, 7798, 320, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[6330132, 109282, 291, 7, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[6330426, 109291, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6330625, 109299, 169, 4, 35, "Subsection",
   CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6330797, 109305, 616, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331438, 109322, 414, 9, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331855, 109333, 687, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6332545, 109349, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333233, 109365, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333921, 109381, 679, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6334603, 109397, 34371, 579, 393, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6368989, 109979, 217, 4, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6369209, 109985, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6369408, 109993, 255, 7, 35, "Subsection",
   CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6369666, 110002, 667, 13, 47, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370358, 110019, 393, 13, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370754, 110034, 52388, 875, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6423145, 110911, 38731, 790, 366, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6461891, 111704, 155, 2, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462049, 111708, 251, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462325, 111717, 157, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462485, 111721, 565, 15, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463065, 111739, 207, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463297, 111747, 213, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463513, 111754, 741, 21, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464269, 111778, 483, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464777, 111793, 483, 14, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6465263, 111809, 73645, 1224, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6538911, 113035, 38451, 790, 361, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577377, 113828, 194, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577574, 113835, 714, 19, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6578291, 113856, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6578490, 113864, 125, 1, 35, "Subsection",
   CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6578618, 113867, 376, 12, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579019, 113883, 118, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579140, 113887, 1424, 24, 56, "Print",
   CellTags->{
    "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}],
  Cell[6580579, 113914, 393, 7, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6580997, 113925, 265, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581265, 113933, 636, 17, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581938, 113955, 222, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582163, 113963, 359, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582537, 113973, 240, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582780, 113983, 141, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582924, 113987, 543, 11, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583492, 114002, 183, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583678, 114008, 642, 19, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584335, 114030, 346, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584684, 114041, 227, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584914, 114049, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585071, 114054, 282, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585356, 114064, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585893, 114078, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586432, 114092, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586969, 114106, 711, 15, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6587683, 114123, 7673, 142, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595371, 114268, 170, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595544, 114275, 401, 5, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595948, 114282, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}],
  Cell[6596147, 114290, 164, 4, 35, "Subsection",
   CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6596314, 114296, 955, 27, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597294, 114327, 121, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597418, 114331, 5918, 152, 168, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603351, 114486, 214, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603590, 114497, 171, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603764, 114503, 1976, 33, 229, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6605755, 114539, 952, 21, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6606710, 114562, 162, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3"}]},
 "PR4.3.0"->{
  Cell[894562, 16472, 206, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", 
     "4.3", "PR4.3", "PR4.3.0"}],
  Cell[894771, 16479, 703, 17, 34, "Text",
   Evaluatable->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[895477, 16498, 1265, 30, 148, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896745, 16530, 112, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[896860, 16533, 749, 21, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[897612, 16556, 1688, 71, 102, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899303, 16629, 299, 9, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[899605, 16640, 1451, 52, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901059, 16694, 237, 4, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[901299, 16700, 1044, 22, 60, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[902346, 16724, 983, 19, 59, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903354, 16747, 384, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[903741, 16762, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904280, 16776, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[904819, 16790, 53569, 876, 372, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958403, 17669, 149, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[958555, 17674, 596, 17, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[959154, 17693, 935, 34, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960092, 17729, 164, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960259, 17734, 570, 14, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960854, 17752, 112, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[960969, 17756, 478, 12, 34, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[961462, 17771, 682, 14, 50, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962169, 17789, 370, 12, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[962542, 17803, 224950, 3563, 330, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187507, 21369, 154, 3, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
  Cell[1187664, 21374, 271, 5, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}]},
 "4.3.1"->{
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]},
 "SurfaceLabel"->{
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]},
 "PR4.3.1"->{
  Cell[1188125, 21388, 256, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1188384, 21395, 737, 21, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189146, 21420, 246, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1189395, 21427, 1491, 44, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1190901, 21474, 962, 30, 35, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1191888, 21508, 239, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192130, 21515, 781, 22, 50, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1192926, 21540, 739, 28, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193668, 21570, 262, 7, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1193933, 21579, 1047, 26, 54, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195005, 21609, 120, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195128, 21613, 376, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1195519, 21623, 474, 12, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196018, 21639, 142, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196163, 21643, 534, 12, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1196712, 21658, 499, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197236, 21675, 154, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1197393, 21679, 647, 17, 42, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198055, 21699, 172, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198252, 21708, 310, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1198565, 21721, 1002, 29, 42, "Output",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199582, 21753, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1199739, 21758, 295, 11, 89, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
  Cell[1200037, 21771, 16705, 280, 298, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]},
 "4.3.2"->{
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]},
 "PR4.3.2"->{
  Cell[1216956, 22062, 225, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217184, 22069, 811, 22, 34, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1217998, 22093, 827, 32, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1218828, 22127, 1132, 39, 48, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1219963, 22168, 221, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220209, 22177, 205, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1220417, 22184, 751, 21, 50, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221183, 22208, 219, 5, 24, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221405, 22215, 485, 15, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1221893, 22232, 322, 9, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222218, 22243, 182, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222425, 22252, 350, 12, 106, "Input",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
  Cell[1222778, 22266, 13664, 239, 193, "Print",
   CellTags->{
    "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]},
 "4.3.3"->{
  Cell[1236656, 22516, 118, 1, 35, "Subsection",
   CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}]},
 "PR4.3.3"->{
  Cell[1236656, 22516, 118, 1, 35, "Subsection",
   CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1236777, 22519, 815, 24, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1237595, 22545, 563, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1238161, 22565, 1709, 52, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1239873, 22619, 1448, 47, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1241324, 22668, 1642, 48, 86, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1242969, 22718, 1524, 46, 67, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1244518, 22768, 177, 3, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1244698, 22773, 325, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245038, 22781, 295, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245358, 22791, 235, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245596, 22801, 372, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1245983, 22810, 129, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246137, 22815, 148, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1246288, 22819, 199460, 3241, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1445763, 26063, 461, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446249, 26078, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446528, 26088, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1446906, 26096, 149930, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1596851, 28675, 1819, 42, 99, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598673, 28719, 117, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1598815, 28725, 271, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599089, 28736, 373, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599499, 28747, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1599633, 28751, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600022, 28760, 585, 12, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600632, 28776, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1600911, 28786, 909, 16, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1601823, 28804, 709, 13, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602535, 28819, 405, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1602943, 28828, 141021, 2427, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744001, 31260, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744135, 31264, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744527, 31273, 311, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1744863, 31284, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745138, 31295, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745549, 31306, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1745683, 31310, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746074, 31319, 299, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746398, 31332, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1746677, 31342, 376, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1747056, 31350, 149932, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897025, 33931, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897159, 33935, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897548, 33944, 258, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1897831, 33955, 272, 9, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898106, 33966, 375, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898518, 33977, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1898652, 33981, 374, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899041, 33990, 313, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899379, 34002, 276, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1899658, 34012, 368, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[1900029, 34020, 149917, 2576, 193, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2049983, 36601, 131, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050117, 36605, 377, 6, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
  Cell[2050509, 36614, 1341, 32, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]},
 "creating new components"->{
  Cell[1236777, 22519, 815, 24, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1242969, 22718, 1524, 46, 67, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}],
  Cell[2052269, 36663, 384, 9, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052656, 36674, 200, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052859, 36681, 300, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053162, 36694, 216, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053381, 36701, 492, 15, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053876, 36718, 253, 7, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055679, 36778, 489, 21, 252, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056171, 36801, 652, 23, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056848, 36828, 222, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2057073, 36835, 25095, 403, 168, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082183, 37241, 286, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082494, 37256, 207, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082704, 37263, 16992, 296, 365, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2099711, 37562, 342, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100078, 37578, 338, 12, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100419, 37592, 13569, 279, 105, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2395143, 43255, 445, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2395613, 43271, 457, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2396073, 43284, 13212, 276, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2409300, 43563, 756, 19, 50, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410081, 43586, 454, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410538, 43599, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411264, 43617, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411990, 43635, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2412716, 43653, 731, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2413450, 43671, 13138, 274, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2427006, 43964, 448, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.5"}]},
 "black hole"->{
  Cell[1236777, 22519, 815, 24, 38, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[1242969, 22718, 1524, 46, 67, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.3"}],
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}],
  Cell[2052269, 36663, 384, 9, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052656, 36674, 200, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052859, 36681, 300, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053162, 36694, 216, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053381, 36701, 492, 15, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053876, 36718, 253, 7, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055679, 36778, 489, 21, 252, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056171, 36801, 652, 23, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056848, 36828, 222, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2057073, 36835, 25095, 403, 168, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082183, 37241, 286, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082494, 37256, 207, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082704, 37263, 16992, 296, 365, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2099711, 37562, 342, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100078, 37578, 338, 12, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100419, 37592, 13569, 279, 105, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2395143, 43255, 445, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2395613, 43271, 457, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2396073, 43284, 13212, 276, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2409300, 43563, 756, 19, 50, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410081, 43586, 454, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410538, 43599, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411264, 43617, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411990, 43635, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2412716, 43653, 731, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2413450, 43671, 13138, 274, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2427006, 43964, 448, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.5"}]},
 "SurfaceRayIntersections"->{
  Cell[1237595, 22545, 563, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", 
     "PR4.3.3"}]},
 "4.3.4"->{
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}]},
 "PR4.3.4"->{
  Cell[2052052, 36656, 214, 5, 35, "Subsection",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "4.3.4", "Custom Surface Shapes",
      "PR4.3", "PR4.3.4"}],
  Cell[2052269, 36663, 384, 9, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052656, 36674, 200, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2052859, 36681, 300, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053162, 36694, 216, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053381, 36701, 492, 15, 20, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2053876, 36718, 253, 7, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055679, 36778, 489, 21, 252, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056171, 36801, 652, 23, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2056848, 36828, 222, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2057073, 36835, 25095, 403, 168, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082183, 37241, 286, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082494, 37256, 207, 5, 24, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2082704, 37263, 16992, 296, 365, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2099711, 37562, 342, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100078, 37578, 338, 12, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2100419, 37592, 13569, 279, 105, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2395143, 43255, 445, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2395613, 43271, 457, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2396073, 43284, 13212, 276, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2409300, 43563, 756, 19, 50, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410081, 43586, 454, 11, 106, "Input",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2410538, 43599, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411264, 43617, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2411990, 43635, 723, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2412716, 43653, 731, 16, 22, "Message",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}],
  Cell[2413450, 43671, 13138, 274, 129, "Print",
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.4"}]},
 "FreezeIncrement"->{
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2055020, 36752, 656, 24, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}]},
 "FunctionCenter"->{
  Cell[2054132, 36727, 885, 23, 47, "Text",
   Evaluatable->False,
   CellTags->{
    "FreezeIncrement", "FunctionCenter", "creating new components", 
     "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}]},
 "animations"->{
  Cell[2114003, 37874, 755, 19, 33, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2114761, 37895, 345, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115131, 37910, 209, 5, 24, "Input",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115343, 37917, 378, 7, 23, "Output",
   CellTags->{
    "animations", "creating new components", "black hole", 
     "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}]},
 "RayChoice"->{
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}]},
 "IntersectionNumber"->{
  Cell[2115736, 37927, 390, 11, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116151, 37942, 361, 11, 89, "Input",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2116515, 37955, 3674, 69, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2120192, 38026, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2123910, 38098, 3720, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2127633, 38170, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2131353, 38242, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2135066, 38314, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2138780, 38386, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2142495, 38458, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2146215, 38530, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2239596, 40248, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2243315, 40320, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2253894, 40518, 3707, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2257604, 40590, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2261316, 40662, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2265038, 40734, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2268757, 40806, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2272475, 40878, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2276194, 40950, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2279910, 41022, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2283625, 41094, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2287345, 41166, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2291062, 41238, 3719, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2294784, 41310, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2298503, 41382, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2302219, 41454, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2305931, 41526, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2309651, 41598, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2313368, 41670, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2317082, 41742, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2320794, 41814, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2324510, 41886, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2328227, 41958, 3721, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2331951, 42030, 3722, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2335676, 42102, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2339402, 42174, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2343120, 42246, 3709, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2346832, 42318, 3710, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2350545, 42390, 3711, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2354259, 42462, 3714, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2357976, 42534, 3717, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2361696, 42606, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2365411, 42678, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2369127, 42750, 3718, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2372848, 42822, 3723, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2376574, 42894, 3712, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2380289, 42966, 3713, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2384005, 43038, 3716, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2387724, 43110, 3715, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}],
  Cell[2391442, 43182, 3686, 70, 99, "Print",
   CellTags->{
    "animations", "RayChoice", "IntersectionNumber", 
     "creating new components", "black hole", "Custom Surface Shapes", 
     "PR4.3", "PR4.3.4"}]},
 "4.3.5"->{
  Cell[2426802, 43956, 201, 6, 35, "Subsection",
   CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}]},
 "PR4.3.5"->{
  Cell[2426802, 43956, 201, 6, 35, "Subsection",
   CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2427006, 43964, 448, 12, 21, "Text",
   Evaluatable->False,
   CellTags->{
    "creating new components", "black hole", "Custom Surface Shapes", "PR4.3",
      "PR4.3.5"}],
  Cell[2427457, 43978, 781, 25, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2428241, 44005, 1836, 42, 93, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2430080, 44049, 2981, 77, 310, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433064, 44128, 254, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2433321, 44136, 1556, 25, 96, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2434880, 44163, 1372, 37, 83, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436277, 44204, 396, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2436676, 44219, 57340, 927, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2494019, 45148, 23067, 419, 419, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517101, 45570, 219, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517323, 45578, 399, 7, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2517747, 45589, 332, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2518082, 45598, 54722, 886, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2572819, 46487, 192, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573036, 46495, 424, 14, 171, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2573463, 46511, 119021, 1853, 438, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2692487, 48366, 26691, 458, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719193, 48827, 222, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719418, 48835, 277, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719720, 48845, 136, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2719859, 48849, 311, 5, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720185, 48857, 216, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720426, 48866, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2720764, 48878, 44789, 712, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2765568, 49593, 467, 9, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766060, 49606, 335, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2766398, 49618, 41446, 724, 383, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2807859, 50345, 163, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2808025, 50351, 1194, 33, 447, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809244, 50388, 200, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2809447, 50397, 422031, 6709, 271, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231493, 57109, 230, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231748, 57120, 244, 7, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3231995, 57129, 34846, 552, 233, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3266856, 57684, 236, 6, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267117, 57694, 267, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3267387, 57704, 396352, 6269, 248, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3663754, 63976, 885, 19, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664664, 63999, 262, 12, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3664929, 64013, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3665466, 64027, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[3666003, 64041, 289761, 5004, 152, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]},
 "SurfaceApproximation"->{
  Cell[2427457, 43978, 781, 25, 76, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[2430080, 44049, 2981, 77, 310, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
  Cell[7380624, 128081, 713, 26, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7415997, 129024, 857, 25, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7572278, 132350, 574, 17, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}]},
 "4.3.6"->{
  Cell[3955978, 69056, 252, 7, 35, "Subsection",
   CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}]},
 "PR4.3.6"->{
  Cell[3955978, 69056, 252, 7, 35, "Subsection",
   CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3956233, 69065, 804, 14, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957062, 69083, 398, 10, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[3957463, 69095, 517025, 8331, 205, 512665, 8256, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4474491, 77428, 440235, 7710, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914741, 85141, 223, 6, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4914967, 85149, 148, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915140, 85156, 239, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4915382, 85166, 13808, 255, 136, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929205, 85424, 106, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929314, 85427, 154, 3, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929493, 85434, 297, 8, 89, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[4929793, 85444, 440561, 7716, 365, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370369, 93163, 101, 1, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370473, 93166, 345, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5370843, 93178, 625, 13, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5371471, 93193, 513284, 8286, 208, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[5884758, 101481, 445359, 7798, 320, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
  Cell[6330132, 109282, 291, 7, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}]},
 "4.3.7"->{
  Cell[6330625, 109299, 169, 4, 35, "Subsection",
   CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}]},
 "PR4.3.7"->{
  Cell[6330625, 109299, 169, 4, 35, "Subsection",
   CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6330797, 109305, 616, 13, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331438, 109322, 414, 9, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6331855, 109333, 687, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6332545, 109349, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333233, 109365, 685, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6333921, 109381, 679, 14, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6334603, 109397, 34371, 579, 393, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
  Cell[6368989, 109979, 217, 4, 27, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}]},
 "4.3.8"->{
  Cell[6369408, 109993, 255, 7, 35, "Subsection",
   CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}]},
 "PR4.3.8"->{
  Cell[6369408, 109993, 255, 7, 35, "Subsection",
   CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6369666, 110002, 667, 13, 47, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370358, 110019, 393, 13, 138, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6370754, 110034, 52388, 875, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6423145, 110911, 38731, 790, 366, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6461891, 111704, 155, 2, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462049, 111708, 251, 5, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462325, 111717, 157, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6462485, 111721, 565, 15, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463065, 111739, 207, 4, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463297, 111747, 213, 5, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6463513, 111754, 741, 21, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464269, 111778, 483, 11, 34, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6464777, 111793, 483, 14, 154, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6465263, 111809, 73645, 1224, 251, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6538911, 113035, 38451, 790, 361, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577377, 113828, 194, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
  Cell[6577574, 113835, 714, 19, 51, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}]},
 "4.3.9"->{
  Cell[6578490, 113864, 125, 1, 35, "Subsection",
   CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}]},
 "PR4.3.9"->{
  Cell[6578490, 113864, 125, 1, 35, "Subsection",
   CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6578618, 113867, 376, 12, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579019, 113883, 118, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6579140, 113887, 1424, 24, 56, "Print",
   CellTags->{
    "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}],
  Cell[6580579, 113914, 393, 7, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6580997, 113925, 265, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581265, 113933, 636, 17, 38, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6581938, 113955, 222, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582163, 113963, 359, 7, 23, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582537, 113973, 240, 8, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582780, 113983, 141, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6582924, 113987, 543, 11, 38, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583492, 114002, 183, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6583678, 114008, 642, 19, 24, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584335, 114030, 346, 9, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584684, 114041, 227, 6, 41, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6584914, 114049, 132, 1, 20, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585071, 114054, 282, 8, 73, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585356, 114064, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6585893, 114078, 536, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586432, 114092, 534, 12, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6586969, 114106, 711, 15, 22, "Message",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6587683, 114123, 7673, 142, 298, "Print",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595371, 114268, 170, 5, 26, "Commentary",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
  Cell[6595544, 114275, 401, 5, 33, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}]},
 "Info3614711174-7377950"->{
  Cell[6579140, 113887, 1424, 24, 56, "Print",
   CellTags->{
    "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}]},
 "4.3.10"->{
  Cell[6596147, 114290, 164, 4, 35, "Subsection",
   CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}]},
 "PR4.3.10"->{
  Cell[6596147, 114290, 164, 4, 35, "Subsection",
   CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6596314, 114296, 955, 27, 54, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597294, 114327, 121, 2, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6597418, 114331, 5918, 152, 168, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603351, 114486, 214, 7, 21, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603590, 114497, 171, 4, 24, "Input",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6603764, 114503, 1976, 33, 229, "Output",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
  Cell[6605755, 114539, 952, 21, 70, "Text",
   CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}]},
 "4.4"->{
  Cell[6606921, 114571, 199, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
     "PR4.4.0"}]},
 "Holograms and Diffraction Gratings"->{
  Cell[6606921, 114571, 199, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
     "PR4.4.0"}]},
 "PR4.4"->{
  Cell[6606921, 114571, 199, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
     "PR4.4.0"}],
  Cell[6607123, 114578, 385, 12, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6607511, 114592, 1621, 64, 84, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609135, 114658, 280, 9, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609440, 114671, 231, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609674, 114680, 23672, 400, 251, 9186, 160, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633361, 115083, 128, 2, 26, "Commentary",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633492, 115087, 739, 13, 46, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634234, 115102, 720, 19, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634957, 115123, 1366, 44, 63, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6636326, 115169, 706, 18, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6637035, 115189, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}],
  Cell[6637209, 115196, 121, 1, 35, "Subsection",
   CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637355, 115201, 106, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637464, 115205, 428, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637929, 115221, 115, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638047, 115225, 421, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638483, 115239, 289, 9, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638797, 115252, 303, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6639103, 115262, 8377, 165, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647517, 115432, 385, 10, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647905, 115444, 525, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6648433, 115458, 664, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649100, 115474, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649626, 115488, 687, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650316, 115504, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650842, 115518, 700, 15, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6651545, 115535, 9843, 215, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6661403, 115753, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}],
  Cell[6661589, 115761, 131, 1, 35, "Subsection",
   CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}],
  
  Cell[6661745, 115766, 254, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662002, 115775, 737, 22, 51, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662754, 115800, 113, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662892, 115806, 213, 5, 41, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6663108, 115813, 1103, 32, 59, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664248, 115850, 285, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664536, 115860, 3169, 61, 438, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667742, 115926, 128, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667873, 115930, 2782, 57, 337, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6670658, 115989, 450, 11, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671145, 116005, 299, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671447, 116015, 6645, 117, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678129, 116137, 137, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678269, 116141, 2777, 57, 325, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681049, 116200, 433, 10, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681519, 116215, 325, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681847, 116225, 6536, 115, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688420, 116345, 140, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688563, 116349, 2591, 46, 353, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691157, 116397, 428, 10, 23, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691622, 116412, 101, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691726, 116416, 2480, 33, 334, "Print",
   CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}],
  Cell[6694243, 116454, 363, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6694609, 116464, 905, 19, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6695517, 116485, 12459, 221, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6707979, 116708, 915, 20, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6708897, 116730, 47697, 850, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6756597, 117582, 65331, 1104, 240, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6821965, 118691, 370, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6822338, 118701, 241331, 3444, 365, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7063706, 122150, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064156, 122162, 771, 18, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064930, 122182, 49650, 880, 234, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7114583, 123064, 52432, 900, 112, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167052, 123969, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167502, 123981, 737, 17, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7168242, 124000, 55364, 984, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7223609, 124986, 58357, 1004, 126, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7281981, 125993, 149, 3, 20, "Text",
   CellTags->{"Gratings", "PR4.4"}]},
 "PR4.4.0"->{
  Cell[6606921, 114571, 199, 5, 60, "Section",
   Evaluatable->False,
   CellTags->{
    "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
     "PR4.4.0"}],
  Cell[6607123, 114578, 385, 12, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6607511, 114592, 1621, 64, 84, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609135, 114658, 280, 9, 21, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609440, 114671, 231, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6609674, 114680, 23672, 400, 251, 9186, 160, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633361, 115083, 128, 2, 26, "Commentary",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6633492, 115087, 739, 13, 46, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634234, 115102, 720, 19, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6634957, 115123, 1366, 44, 63, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
  Cell[6636326, 115169, 706, 18, 51, "Text",
   CellTags->{"Gratings", "PR4.4", "PR4.4.0"}]},
 "Grating"->{
  Cell[6607511, 114592, 1621, 64, 84, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}]},
 "Variable Pitch Grating"->{
  Cell[6637209, 115196, 121, 1, 35, "Subsection",
   CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}]},
 "PR4.4.1"->{
  Cell[6637209, 115196, 121, 1, 35, "Subsection",
   CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637355, 115201, 106, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637464, 115205, 428, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6637929, 115221, 115, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638047, 115225, 421, 11, 41, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638483, 115239, 289, 9, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6638797, 115252, 303, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6639103, 115262, 8377, 165, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647517, 115432, 385, 10, 106, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6647905, 115444, 525, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6648433, 115458, 664, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649100, 115474, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6649626, 115488, 687, 14, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650316, 115504, 523, 12, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6650842, 115518, 700, 15, 22, "Message",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
  Cell[6651545, 115535, 9843, 215, 159, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.1"}]},
 "Holographic Optical Element"->{
  Cell[6661589, 115761, 131, 1, 35, "Subsection",
   CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}]},
 "PR4.4.2"->{
  Cell[6661589, 115761, 131, 1, 35, "Subsection",
   CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}],
  
  Cell[6661745, 115766, 254, 7, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662002, 115775, 737, 22, 51, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662754, 115800, 113, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6662892, 115806, 213, 5, 41, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6663108, 115813, 1103, 32, 59, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664248, 115850, 285, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6664536, 115860, 3169, 61, 438, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667742, 115926, 128, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6667873, 115930, 2782, 57, 337, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6670658, 115989, 450, 11, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671145, 116005, 299, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6671447, 116015, 6645, 117, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678129, 116137, 137, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6678269, 116141, 2777, 57, 325, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681049, 116200, 433, 10, 28, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681519, 116215, 325, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6681847, 116225, 6536, 115, 128, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688420, 116345, 140, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6688563, 116349, 2591, 46, 353, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691157, 116397, 428, 10, 23, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691622, 116412, 101, 2, 24, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6691726, 116416, 2480, 33, 334, "Print",
   CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}],
  Cell[6694243, 116454, 363, 8, 73, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6694609, 116464, 905, 19, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6695517, 116485, 12459, 221, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6707979, 116708, 915, 20, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6708897, 116730, 47697, 850, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6756597, 117582, 65331, 1104, 240, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6821965, 118691, 370, 8, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[6822338, 118701, 241331, 3444, 365, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7063706, 122150, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064156, 122162, 771, 18, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7064930, 122182, 49650, 880, 234, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7114583, 123064, 52432, 900, 112, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167052, 123969, 447, 10, 89, "Input",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7167502, 123981, 737, 17, 20, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7168242, 124000, 55364, 984, 249, "Print",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
  Cell[7223609, 124986, 58357, 1004, 126, "Output",
   CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]},
 "Info3614711184-7377950"->{
  Cell[6691726, 116416, 2480, 33, 334, "Print",
   CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}]},
 "4.5"->{
  Cell[7282179, 126002, 176, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.5", "Generic Building Blocks", "PR4.5"}]},
 "PR4.5"->{
  Cell[7282179, 126002, 176, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.5", "Generic Building Blocks", "PR4.5"}],
  Cell[7282358, 126007, 892, 23, 53, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7283275, 126034, 142, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7283420, 126038, 14522, 417, 162, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7297957, 126458, 229, 4, 26, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7298189, 126464, 1287, 25, 85, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7299501, 126493, 141, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7299645, 126497, 893, 24, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7300553, 126524, 1363, 37, 70, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7301941, 126565, 287, 8, 57, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7302231, 126575, 11532, 197, 159, "Print",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7313778, 126775, 152, 2, 26, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7313933, 126779, 150, 5, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314108, 126788, 124, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314235, 126792, 749, 20, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7314999, 126815, 980, 27, 54, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316004, 126846, 124, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316131, 126850, 758, 20, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7316904, 126873, 797, 24, 38, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7317726, 126901, 139, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7317868, 126905, 1091, 27, 40, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7318974, 126935, 286, 6, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7319285, 126945, 136, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7319424, 126949, 7830, 183, 399, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7327269, 127135, 1080, 29, 70, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7328374, 127168, 401, 11, 138, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7328778, 127181, 47160, 755, 327, "Print",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7375953, 127939, 368, 12, 27, "Commentary",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376324, 127953, 306, 8, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376655, 127965, 137, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7376795, 127969, 813, 21, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7377623, 127993, 634, 16, 38, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7378282, 128013, 144, 2, 24, "Input",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7378429, 128017, 891, 23, 24, "Output",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7379335, 128043, 351, 9, 21, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}],
  Cell[7379689, 128054, 164, 3, 20, "Text",
   CellTags->{"Generic Building Blocks", "PR4.5"}]},
 "4.6"->{
  Cell[7379890, 128062, 147, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}]},
 "PR4.6"->{
  Cell[7379890, 128062, 147, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380040, 128067, 581, 12, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380624, 128081, 713, 26, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7381340, 128109, 818, 23, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7382161, 128134, 1143, 31, 180, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383307, 128167, 242, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383552, 128177, 806, 22, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384361, 128201, 217, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384603, 128211, 218, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384824, 128219, 2844, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387683, 128278, 232, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387918, 128288, 373, 10, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7388294, 128300, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7388477, 128307, 120, 1, 35, "Subsection",
   CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7388600, 128310, 590, 18, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389215, 128332, 229, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389447, 128343, 644, 18, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390106, 128364, 176, 4, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390307, 128372, 223, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390533, 128380, 2950, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7393498, 128441, 314, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7393815, 128452, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7394010, 128460, 129, 1, 35, "Subsection",
   CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7394142, 128463, 880, 18, 53, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395047, 128485, 262, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395312, 128496, 448, 12, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395797, 128513, 221, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7396021, 128521, 2841, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7398877, 128580, 159, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399039, 128584, 593, 20, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399657, 128608, 438, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7400098, 128626, 2837, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7402950, 128685, 217, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403170, 128693, 366, 11, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403561, 128708, 455, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7404019, 128726, 2952, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7406986, 128787, 155, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407144, 128791, 420, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407589, 128807, 514, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7408106, 128827, 3325, 65, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411446, 128895, 133, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411582, 128898, 582, 20, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412189, 128922, 216, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412408, 128930, 2344, 46, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7414767, 128979, 368, 11, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7415138, 128992, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7415333, 129000, 219, 8, 35, "Subsection",
   CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415555, 129010, 439, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415997, 129024, 857, 25, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7416857, 129051, 292, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7417152, 129061, 1227, 44, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418382, 129107, 428, 13, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418835, 129124, 228, 8, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419066, 129134, 333, 6, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419414, 129143, 196, 5, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419635, 129152, 306, 10, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419944, 129164, 2946, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7422905, 129225, 216, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423124, 129233, 271, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423420, 129243, 330, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423753, 129256, 2832, 55, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426600, 129314, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426813, 129321, 391, 8, 34, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427229, 129333, 329, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427561, 129346, 2944, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430520, 129407, 217, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430740, 129414, 317, 6, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431060, 129422, 474, 10, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431559, 129436, 433, 15, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431995, 129453, 6909, 123, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7438907, 129578, 378, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439300, 129589, 215, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439518, 129596, 350, 8, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439893, 129608, 396, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7440292, 129622, 21487, 368, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7461782, 129992, 375, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462172, 130003, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462385, 130010, 395, 9, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462805, 130023, 411, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7463219, 130037, 4676, 87, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7467898, 130126, 408, 9, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7468321, 130138, 212, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7468536, 130145, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7468731, 130153, 133, 1, 35, "Subsection",
   CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7468867, 130156, 938, 18, 64, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7469830, 130178, 243, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7470076, 130189, 22046, 377, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492137, 130569, 126, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492266, 130572, 404, 11, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492695, 130587, 212, 6, 24, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492910, 130595, 573, 16, 24, "Output",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7493498, 130614, 707, 19, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7494230, 130637, 247, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7494480, 130648, 5654, 101, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7500149, 130752, 234, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7500386, 130760, 842, 21, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7501253, 130785, 422, 10, 122, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7501678, 130797, 6106, 110, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7507799, 130910, 247, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508049, 130918, 425, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508499, 130933, 224, 8, 89, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508726, 130943, 2088, 44, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7510829, 130990, 260, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7511092, 130998, 428, 12, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7511523, 131012, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7511718, 131020, 204, 6, 35, "Subsection",
   CellTags->{
    "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  
  Cell[7511925, 131028, 1746, 46, 103, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7513674, 131076, 528, 16, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7514205, 131094, 1490, 38, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7515698, 131134, 894, 29, 431, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7516595, 131165, 403, 12, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7517001, 131179, 1334, 29, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518338, 131210, 418, 11, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518759, 131223, 534, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7519296, 131243, 1300, 30, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520599, 131275, 268, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520892, 131288, 187, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7521082, 131295, 2197, 43, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523294, 131341, 288, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523607, 131354, 191, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523801, 131361, 3182, 61, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7526998, 131425, 293, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7527294, 131436, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7527489, 131444, 157, 4, 35, "Subsection",
   CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7527649, 131450, 1313, 32, 70, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7528987, 131486, 359, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7529349, 131500, 11531, 198, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7540895, 131701, 362, 7, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541282, 131712, 236, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541521, 131720, 11509, 201, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553045, 131924, 482, 9, 37, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553530, 131935, 169, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553724, 131942, 144, 1, 31, "Subsubsection",
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553871, 131945, 535, 12, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554431, 131961, 467, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554901, 131981, 11963, 210, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7566879, 132194, 345, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567227, 132205, 580, 19, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567810, 132226, 522, 14, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7568335, 132242, 1593, 35, 99, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7569931, 132279, 1573, 45, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571507, 132326, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}],
  Cell[7571702, 132334, 109, 1, 31, "Subsubsection",
   CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571814, 132337, 461, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572278, 132350, 574, 17, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572855, 132369, 754, 18, 51, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573634, 132391, 196, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573833, 132398, 2517, 55, 402, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576365, 132456, 294, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576662, 132466, 974, 18, 67, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577661, 132488, 252, 5, 41, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577916, 132495, 11394, 197, 224, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589325, 132695, 309, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589637, 132705, 307, 7, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589947, 132714, 158, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6"}]},
 "PR4.6.0"->{
  Cell[7379890, 128062, 147, 3, 60, "Section",
   Evaluatable->False,
   CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380040, 128067, 581, 12, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7380624, 128081, 713, 26, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7381340, 128109, 818, 23, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7382161, 128134, 1143, 31, 180, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383307, 128167, 242, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7383552, 128177, 806, 22, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384361, 128201, 217, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384603, 128211, 218, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384824, 128219, 2844, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387683, 128278, 232, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7387918, 128288, 373, 10, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}]},
 "Simple CustomDeflections"->{
  Cell[7380040, 128067, 581, 12, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7381340, 128109, 818, 23, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384361, 128201, 217, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384603, 128211, 218, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7384824, 128219, 2844, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
  Cell[7388600, 128310, 590, 18, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389215, 128332, 229, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389447, 128343, 644, 18, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390106, 128364, 176, 4, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390307, 128372, 223, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390533, 128380, 2950, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7394142, 128463, 880, 18, 53, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395047, 128485, 262, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395312, 128496, 448, 12, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395797, 128513, 221, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7396021, 128521, 2841, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399039, 128584, 593, 20, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399657, 128608, 438, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7400098, 128626, 2837, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403170, 128693, 366, 11, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403561, 128708, 455, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7404019, 128726, 2952, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407144, 128791, 420, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407589, 128807, 514, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7408106, 128827, 3325, 65, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412189, 128922, 216, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412408, 128930, 2344, 46, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7415555, 129010, 439, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7417152, 129061, 1227, 44, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418382, 129107, 428, 13, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418835, 129124, 228, 8, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419066, 129134, 333, 6, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419635, 129152, 306, 10, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419944, 129164, 2946, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423124, 129233, 271, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423420, 129243, 330, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423753, 129256, 2832, 55, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426813, 129321, 391, 8, 34, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427229, 129333, 329, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427561, 129346, 2944, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430740, 129414, 317, 6, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431060, 129422, 474, 10, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431559, 129436, 433, 15, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431995, 129453, 6909, 123, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7438907, 129578, 378, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439518, 129596, 350, 8, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439893, 129608, 396, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7440292, 129622, 21487, 368, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7461782, 129992, 375, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462385, 130010, 395, 9, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462805, 130023, 411, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7463219, 130037, 4676, 87, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7467898, 130126, 408, 9, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7527649, 131450, 1313, 32, 70, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7528987, 131486, 359, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7529349, 131500, 11531, 198, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541282, 131712, 236, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541521, 131720, 11509, 201, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554431, 131961, 467, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554901, 131981, 11963, 210, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}]},
 "4.6.1"->{
  Cell[7388477, 128307, 120, 1, 35, "Subsection",
   CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}]},
 "PR4.6.1"->{
  Cell[7388477, 128307, 120, 1, 35, "Subsection",
   CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7388600, 128310, 590, 18, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389215, 128332, 229, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7389447, 128343, 644, 18, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390106, 128364, 176, 4, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390307, 128372, 223, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7390533, 128380, 2950, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
  Cell[7393498, 128441, 314, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.1"}]},
 "4.6.2"->{
  Cell[7394010, 128460, 129, 1, 35, "Subsection",
   CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}]},
 "PR4.6.2"->{
  Cell[7394010, 128460, 129, 1, 35, "Subsection",
   CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7394142, 128463, 880, 18, 53, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395047, 128485, 262, 9, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395312, 128496, 448, 12, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7395797, 128513, 221, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7396021, 128521, 2841, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7398877, 128580, 159, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399039, 128584, 593, 20, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7399657, 128608, 438, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7400098, 128626, 2837, 56, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7402950, 128685, 217, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403170, 128693, 366, 11, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7403561, 128708, 455, 16, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7404019, 128726, 2952, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7406986, 128787, 155, 2, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407144, 128791, 420, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7407589, 128807, 514, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7408106, 128827, 3325, 65, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411446, 128895, 133, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7411582, 128898, 582, 20, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412189, 128922, 216, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7412408, 128930, 2344, 46, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
  Cell[7414767, 128979, 368, 11, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}]},
 "4.6.3"->{
  Cell[7415333, 129000, 219, 8, 35, "Subsection",
   CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}]},
 "PR4.6.3"->{
  Cell[7415333, 129000, 219, 8, 35, "Subsection",
   CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415555, 129010, 439, 12, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7415997, 129024, 857, 25, 100, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7416857, 129051, 292, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7417152, 129061, 1227, 44, 54, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418382, 129107, 428, 13, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7418835, 129124, 228, 8, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419066, 129134, 333, 6, 24, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419414, 129143, 196, 5, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419635, 129152, 306, 10, 89, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7419944, 129164, 2946, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7422905, 129225, 216, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423124, 129233, 271, 6, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423420, 129243, 330, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7423753, 129256, 2832, 55, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426600, 129314, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7426813, 129321, 391, 8, 34, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427229, 129333, 329, 11, 106, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7427561, 129346, 2944, 58, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430520, 129407, 217, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7430740, 129414, 317, 6, 20, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431060, 129422, 474, 10, 38, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431559, 129436, 433, 15, 187, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7431995, 129453, 6909, 123, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7438907, 129578, 378, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439300, 129589, 215, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439518, 129596, 350, 8, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7439893, 129608, 396, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7440292, 129622, 21487, 368, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7461782, 129992, 375, 8, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462172, 130003, 210, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462385, 130010, 395, 9, 21, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7462805, 130023, 411, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7463219, 130037, 4676, 87, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7467898, 130126, 408, 9, 23, "Output",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
  Cell[7468321, 130138, 212, 5, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}]},
 "4.6.4"->{
  Cell[7468731, 130153, 133, 1, 35, "Subsection",
   CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}]},
 "PR4.6.4"->{
  Cell[7468731, 130153, 133, 1, 35, "Subsection",
   CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7468867, 130156, 938, 18, 64, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7469830, 130178, 243, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7470076, 130189, 22046, 377, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492137, 130569, 126, 1, 26, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492266, 130572, 404, 11, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7492695, 130587, 212, 6, 24, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492910, 130595, 573, 16, 24, "Output",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7493498, 130614, 707, 19, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7494230, 130637, 247, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7494480, 130648, 5654, 101, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7500149, 130752, 234, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7500386, 130760, 842, 21, 54, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7501253, 130785, 422, 10, 122, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7501678, 130797, 6106, 110, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7507799, 130910, 247, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508049, 130918, 425, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508499, 130933, 224, 8, 89, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7508726, 130943, 2088, 44, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7510829, 130990, 260, 6, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
  Cell[7511092, 130998, 428, 12, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}]},
 "RayTilt using CustomDeflections"->{
  Cell[7469830, 130178, 243, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7470076, 130189, 22046, 377, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492695, 130587, 212, 6, 24, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7492910, 130595, 573, 16, 24, "Output",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7494230, 130637, 247, 9, 73, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7494480, 130648, 5654, 101, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7501253, 130785, 422, 10, 122, "Input",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}],
  Cell[7501678, 130797, 6106, 110, 365, "Print",
   CellTags->{
    "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
     "PR4.6.4"}]},
 "Optimizing CustomDeflections"->{
  Cell[7511718, 131020, 204, 6, 35, "Subsection",
   CellTags->{
    "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}]},
 "PR4.6.5"->{
  Cell[7511718, 131020, 204, 6, 35, "Subsection",
   CellTags->{
    "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  
  Cell[7511925, 131028, 1746, 46, 103, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7513674, 131076, 528, 16, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7514205, 131094, 1490, 38, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7515698, 131134, 894, 29, 431, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7516595, 131165, 403, 12, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7517001, 131179, 1334, 29, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518338, 131210, 418, 11, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518759, 131223, 534, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7519296, 131243, 1300, 30, 83, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520599, 131275, 268, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7520892, 131288, 187, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7521082, 131295, 2197, 43, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523294, 131341, 288, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523607, 131354, 191, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7523801, 131361, 3182, 61, 365, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7526998, 131425, 293, 9, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}]},
 "PropagateSystemDeflection"->{
  Cell[7513674, 131076, 528, 16, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
  Cell[7518759, 131223, 534, 18, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}]},
 "AffectedSurfaces"->{
  Cell[7527489, 131444, 157, 4, 35, "Subsection",
   CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}]},
 "PR4.6.6"->{
  Cell[7527489, 131444, 157, 4, 35, "Subsection",
   CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7527649, 131450, 1313, 32, 70, "Text",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7528987, 131486, 359, 12, 122, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7529349, 131500, 11531, 198, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7540895, 131701, 362, 7, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541282, 131712, 236, 6, 24, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7541521, 131720, 11509, 201, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553045, 131924, 482, 9, 37, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553530, 131935, 169, 3, 20, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553724, 131942, 144, 1, 31, "Subsubsection",
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7553871, 131945, 535, 12, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554431, 131961, 467, 18, 219, "Input",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7554901, 131981, 11963, 210, 365, "Print",
   CellTags->{
    "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7566879, 132194, 345, 9, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567227, 132205, 580, 19, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567810, 132226, 522, 14, 34, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7568335, 132242, 1593, 35, 99, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7569931, 132279, 1573, 45, 86, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571702, 132334, 109, 1, 31, "Subsubsection",
   CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7571814, 132337, 461, 11, 38, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572278, 132350, 574, 17, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{
    "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7572855, 132369, 754, 18, 51, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573634, 132391, 196, 5, 24, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7573833, 132398, 2517, 55, 402, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576365, 132456, 294, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7576662, 132466, 974, 18, 67, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577661, 132488, 252, 5, 41, "Input",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7577916, 132495, 11394, 197, 224, "Print",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589325, 132695, 309, 8, 27, "Commentary",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7589637, 132705, 307, 7, 21, "Text",
   CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}]},
 "RemoveDeflection"->{
  Cell[7553724, 131942, 144, 1, 31, "Subsubsection",
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
  Cell[7567227, 132205, 580, 19, 51, "Text",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}]},
 "LabelSurfaces"->{
  Cell[7571702, 132334, 109, 1, 31, "Subsubsection",
   CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"chapter 4 topics", 7591195, 132759},
 {"Aperture Shapes", 7591432, 132765},
 {"Light Sources", 7598545, 132933},
 {"Custom Surface Shapes", 7610057, 133179},
 {"Gratings", 7660458, 134271},
 {"CustomDeflections", 7667649, 134427},
 {"Generic Building Blocks", 7687190, 134848},
 {"4.1", 7690989, 134927},
 {"aperture shapes", 7691162, 134932},
 {"PR4.1.1", 7695182, 135033},
 {"PR4.1", 7697731, 135094},
 {"4.1.1", 7704428, 135251},
 {"circular apertures", 7704661, 135257},
 {"elliptical apertures", 7706520, 135302},
 {"4.1.2", 7708364, 135347},
 {"rectangular apertures", 7708581, 135353},
 {"PR4.1.2", 7709267, 135372},
 {"4.1.3", 7710052, 135393},
 {"polygonal apertures", 7710266, 135399},
 {"PR4.1.3", 7711498, 135431},
 {"triangular apertures", 7713042, 135469},
 {"4.1.4", 7713605, 135483},
 {"Aperture Stops", 7713761, 135487},
 {"PR4.1.4", 7713910, 135491},
 {"4.2", 7715442, 135523},
 {"PR4.2", 7715558, 135526},
 {"PR4.2.1", 7726552, 135759},
 {"4.2.1", 7731601, 135867},
 {"Maintaining Constant Pupil Illumination", 7731811, 135872},
 {"Constant Illumination with BirthPoint", 7732019, 135877},
 {"Constant Illumination with ReadRays", 7732217, 135882},
 {"4.2.2", 7732383, 135887},
 {"Distant Sources", 7732574, 135892},
 {"Lasers", 7732756, 135897},
 {"Beam Divergence", 7732947, 135902},
 {"PR4.2.2", 7733130, 135907},
 {"4.2.3", 7734954, 135946},
 {"Laser Cavities and MoveAligned", 7735146, 135951},
 {"PR4.2.3", 7735315, 135956},
 {"4.2.4", 7737433, 136001},
 {"Chromatic Sources", 7737594, 136005},
 {"PR4.2.4", 7737745, 136009},
 {"user defined models", 7739382, 136043},
 {"ModelSurfaceShape", 7743955, 136152},
 {"4.3", 7748514, 136261},
 {"PR4.3", 7748718, 136267},
 {"PR4.3.0", 7798739, 137350},
 {"4.3.1", 7801926, 137417},
 {"SurfaceLabel", 7802159, 137423},
 {"PR4.3.1", 7806531, 137527},
 {"4.3.2", 7810206, 137609},
 {"PR4.3.2", 7810434, 137615},
 {"4.3.3", 7812616, 137666},
 {"PR4.3.3", 7812750, 137669},
 {"creating new components", 7818963, 137791},
 {"black hole", 7839691, 138292},
 {"SurfaceRayIntersections", 7860432, 138793},
 {"4.3.4", 7860638, 138800},
 {"PR4.3.4", 7860847, 138806},
 {"FreezeIncrement", 7881039, 139292},
 {"FunctionCenter", 7881477, 139303},
 {"animations", 7881712, 139309},
 {"RayChoice", 7896978, 139668},
 {"IntersectionNumber", 7911522, 140009},
 {"4.3.5", 7926053, 140350},
 {"PR4.3.5", 7926187, 140353},
 {"SurfaceApproximation", 7931175, 140451},
 {"4.3.6", 7932102, 140477},
 {"PR4.3.6", 7932236, 140480},
 {"4.3.7", 7934365, 140520},
 {"PR4.3.7", 7934500, 140523},
 {"4.3.8", 7935503, 140542},
 {"PR4.3.8", 7935638, 140545},
 {"4.3.9", 7937610, 140582},
 {"PR4.3.9", 7937745, 140585},
 {"Info3614711174-7377950", 7940493, 140637},
 {"4.3.10", 7940646, 140641},
 {"PR4.3.10", 7940784, 140644},
 {"4.4", 7941674, 140661},
 {"Holograms and Diffraction Gratings", 7941890, 140667},
 {"PR4.4", 7942077, 140673},
 {"PR4.4.0", 7948884, 140819},
 {"Grating", 7950117, 140848},
 {"Variable Pitch Grating", 7950302, 140853},
 {"PR4.4.1", 7950441, 140856},
 {"Holographic Optical Element", 7952028, 140889},
 {"PR4.4.2", 7952172, 140892},
 {"Info3614711184-7377950", 7955981, 140972},
 {"4.5", 7956114, 140975},
 {"PR4.5", 7956256, 140979},
 {"4.6", 7959841, 141053},
 {"PR4.6", 7959988, 141057},
 {"PR4.6.0", 7979043, 141466},
 {"Simple CustomDeflections", 7980639, 141502},
 {"4.6.1", 7988833, 141683},
 {"PR4.6.1", 7988964, 141686},
 {"4.6.2", 7990014, 141709},
 {"PR4.6.2", 7990145, 141712},
 {"4.6.3", 7993095, 141775},
 {"PR4.6.3", 7993226, 141778},
 {"4.6.4", 7997929, 141880},
 {"PR4.6.4", 7998060, 141883},
 {"RayTilt using CustomDeflections", 8000663, 141942},
 {"Optimizing CustomDeflections", 8001900, 141975},
 {"PR4.6.5", 8002059, 141979},
 {"PropagateSystemDeflection", 8004067, 142022},
 {"AffectedSurfaces", 8004463, 142033},
 {"PR4.6.6", 8004605, 142036},
 {"RemoveDeflection", 8008182, 142109},
 {"LabelSurfaces", 8008505, 142116}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 201, 4, 60, "Subtitle",
 CellTags->{
  "chapter 4 topics", "Aperture Shapes", "Light Sources", 
   "Custom Surface Shapes", "Gratings", "CustomDeflections", 
   "Generic Building Blocks"}],
Cell[CellGroupData[{
Cell[805, 30, 254, 6, 20, "Outline2",
 Evaluatable->False,
 CellTags->"Aperture Shapes"],
Cell[1062, 38, 556, 20, 55, "Outline3",
 Evaluatable->False,
 CellTags->"Aperture Shapes"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1655, 63, 179, 4, 20, "Outline2",
 CellTags->"Light Sources"],
Cell[CellGroupData[{
Cell[1859, 71, 243, 4, 16, "Outline3",
 CellTags->"Light Sources"],
Cell[2105, 77, 377, 10, 27, "Outline4",
 CellTags->"Light Sources"]
}, Open  ]],
Cell[2497, 90, 471, 14, 42, "Outline3",
 CellTags->"Light Sources"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3005, 109, 195, 4, 20, "Outline2",
 CellTags->"Custom Surface Shapes"],
Cell[3203, 115, 1238, 42, 133, "Outline3",
 CellTags->"Custom Surface Shapes"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4478, 162, 195, 4, 20, "Outline2",
 CellTags->"Gratings"],
Cell[4676, 168, 384, 12, 29, "Outline3",
 Evaluatable->False,
 CellTags->"Gratings"]
}, Open  ]],
Cell[5075, 183, 191, 4, 20, "Outline2"],
Cell[CellGroupData[{
Cell[5291, 191, 187, 4, 20, "Outline2",
 CellTags->"CustomDeflections"],
Cell[CellGroupData[{
Cell[5503, 199, 850, 28, 81, "Outline3",
 Evaluatable->False,
 CellTags->"CustomDeflections"],
Cell[6356, 229, 295, 10, 27, "Outline4",
 CellTags->"CustomDeflections"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6700, 245, 187, 3, 60, "Section",
 Evaluatable->False,
 CellTags->{
  "4.1", "aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[6890, 250, 883, 23, 33, "Text",
 Evaluatable->False,
 CellTags->{"aperture shapes", "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[CellGroupData[{
Cell[7798, 277, 244, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "4.1.1", "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[8045, 284, 746, 24, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[CellGroupData[{
Cell[8816, 312, 263, 7, 24, "Input",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[9082, 321, 13337, 220, 438, "Print",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}]
}, Open  ]],
Cell[22434, 544, 100, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[22537, 547, 1127, 37, 38, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[CellGroupData[{
Cell[23689, 588, 242, 5, 24, "Input",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[23934, 595, 21721, 398, 438, "Print",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}]
}, Open  ]],
Cell[45670, 996, 124, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[45797, 999, 1297, 45, 38, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[CellGroupData[{
Cell[47119, 1048, 302, 9, 57, "Input",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[47424, 1059, 51373, 850, 438, "Print",
 CellTags->{
  "aperture shapes", "circular apertures", "elliptical apertures", 
   "Aperture Shapes", "PR4.1.1", "PR4.1"}]
}, Open  ]],
Cell[98812, 1912, 131, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[98946, 1915, 244, 6, 20, "Text",
 Evaluatable->False,
 CellTags->{"Aperture Shapes", "PR4.1.1", "PR4.1"}],
Cell[99193, 1923, 156, 3, 20, "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[99386, 1931, 210, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "4.1.2", "aperture shapes", "rectangular apertures", "Aperture Shapes", 
   "PR4.1", "PR4.1.2"}],
Cell[99599, 1938, 761, 25, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"}],
Cell[CellGroupData[{
Cell[100385, 1967, 240, 7, 24, "Input",
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"}],
Cell[100628, 1976, 23320, 379, 438, "Print",
 CellTags->{
  "aperture shapes", "rectangular apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.2"}]
}, Open  ]],
Cell[123963, 2358, 97, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.2"}],
Cell[124063, 2361, 156, 3, 20, "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[124256, 2369, 206, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "4.1.3", "aperture shapes", "polygonal apertures", "Aperture Shapes", 
   "PR4.1", "PR4.1.3"}],
Cell[124465, 2376, 437, 11, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"}],
Cell[CellGroupData[{
Cell[124927, 2391, 278, 7, 24, "Input",
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"}],
Cell[125208, 2400, 12748, 213, 438, "Print",
 CellTags->{
  "aperture shapes", "polygonal apertures", "triangular apertures", 
   "Aperture Shapes", "PR4.1", "PR4.1.3"}]
}, Open  ]],
Cell[137971, 2616, 96, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
Cell[138070, 2619, 511, 18, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"}],
Cell[CellGroupData[{
Cell[138606, 2641, 275, 12, 106, "Input",
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"}],
Cell[138884, 2655, 23415, 395, 438, "Print",
 CellTags->{
  "aperture shapes", "polygonal apertures", "Aperture Shapes", "PR4.1", 
   "PR4.1.3"}]
}, Open  ]],
Cell[162314, 3053, 101, 1, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
Cell[162418, 3056, 145, 3, 20, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.3"}],
Cell[162566, 3061, 156, 3, 20, "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[162759, 3069, 121, 1, 35, "Subsection",
 CellTags->{"4.1.4", "Aperture Stops", "Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[162883, 3072, 427, 10, 33, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[163313, 3084, 460, 12, 34, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[163776, 3098, 4392, 137, 131, "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[168171, 3237, 141, 2, 24, "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[168315, 3241, 188, 5, 27, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[168506, 3248, 426, 9, 34, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[CellGroupData[{
Cell[168957, 3261, 1333, 38, 105, "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[170293, 3301, 8200, 148, 397, "Print",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}]
}, Open  ]],
Cell[178508, 3452, 147, 5, 27, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[178658, 3459, 323, 8, 21, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[CellGroupData[{
Cell[179006, 3471, 426, 11, 25, "Input",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[179435, 3484, 14097, 298, 365, "Print",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}]
}, Open  ]],
Cell[193547, 3785, 149, 3, 26, "Commentary",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[193699, 3790, 314, 7, 21, "Text",
 CellTags->{"Aperture Shapes", "PR4.1", "PR4.1.4"}],
Cell[194016, 3799, 156, 3, 20, "Text",
 CellTags->{"Aperture Shapes", "PR4.1"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[194221, 3808, 93, 1, 60, "Section",
 CellTags->{"4.2", "Light Sources", "PR4.2", "PR4.2.1"}],
Cell[194317, 3811, 702, 13, 33, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[195044, 3828, 176, 3, 35, "Subsection",
 CellTags->{
  "4.2.1", "Maintaining Constant Pupil Illumination", "Light Sources", 
   "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[195245, 3835, 160, 3, 31, "Subsubsection",
 CellTags->{
  "Constant Illumination with BirthPoint", "Light Sources", "PR4.2", 
   "PR4.2.1"}],
Cell[195408, 3840, 864, 14, 60, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[196275, 3856, 576, 15, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[196876, 3875, 1951, 52, 73, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[198830, 3929, 55173, 887, 397, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[254018, 4819, 284, 8, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[254305, 4829, 448, 8, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[254756, 4839, 323, 11, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[255104, 4854, 1823, 49, 57, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[256930, 4905, 54707, 879, 397, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[311652, 5787, 264, 6, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[311919, 5795, 347, 7, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[312269, 5804, 449, 11, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[312721, 5817, 154, 3, 20, "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[312912, 5825, 152, 2, 31, "Subsubsection",
 CellTags->{
  "Constant Illumination with ReadRays", "Light Sources", "PR4.2", "PR4.2.1"}],
Cell[313067, 5829, 402, 8, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[313472, 5839, 350, 10, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[313847, 5853, 1983, 54, 73, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[315833, 5909, 61833, 993, 384, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[377681, 6905, 287, 7, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[377971, 6914, 385, 8, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[378359, 6924, 470, 9, 33, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[378832, 6935, 709, 15, 49, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[379566, 6954, 304, 7, 25, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[379873, 6963, 1496, 37, 48, "Output",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[381384, 7003, 1035, 28, 62, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[382422, 7033, 875, 23, 48, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[383300, 7058, 574, 16, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[383899, 7078, 661, 21, 41, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[384563, 7101, 1813, 43, 54, "Output",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[386391, 7147, 175, 4, 20, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[386569, 7153, 921, 25, 41, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[387493, 7180, 1041, 32, 49, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[388537, 7214, 128, 2, 20, "Text",
 PageBreakAbove->True,
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[388690, 7220, 927, 26, 41, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[389620, 7248, 62670, 1006, 384, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[452305, 8257, 164, 4, 26, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[452472, 8263, 370, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[452845, 8274, 412, 10, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[453260, 8286, 354, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[453617, 8297, 1675, 47, 73, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[455295, 8346, 191, 4, 26, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[455489, 8352, 188, 5, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[CellGroupData[{
Cell[455702, 8361, 1481, 40, 57, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[457186, 8403, 63822, 1027, 384, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}]
}, Open  ]],
Cell[521023, 9433, 263, 6, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[521289, 9441, 336, 7, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[521628, 9450, 525, 13, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.1"}],
Cell[522156, 9465, 154, 3, 20, "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[522359, 9474, 186, 3, 35, "Subsection",
 CellTags->{
  "4.2.2", "Distant Sources", "Lasers", "Beam Divergence", "Light Sources", 
   "PR4.2", "PR4.2.2"}],
Cell[522548, 9479, 433, 13, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[522984, 9494, 376, 6, 33, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[523363, 9502, 824, 14, 50, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[524190, 9518, 1462, 37, 76, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[525655, 9557, 542, 13, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[CellGroupData[{
Cell[526222, 9574, 1022, 29, 41, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[527247, 9605, 1615, 34, 99, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}]
}, Open  ]],
Cell[528877, 9642, 252, 6, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[529132, 9650, 425, 11, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[CellGroupData[{
Cell[529582, 9665, 1023, 29, 41, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[530608, 9696, 1640, 36, 163, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}]
}, Open  ]],
Cell[532263, 9735, 236, 5, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[532502, 9742, 463, 12, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[532968, 9756, 260, 8, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[CellGroupData[{
Cell[533253, 9768, 1700, 46, 57, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[534956, 9816, 5321, 97, 303, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}]
}, Open  ]],
Cell[540292, 9916, 308, 8, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.2"}],
Cell[540603, 9926, 154, 3, 20, "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[540794, 9934, 158, 3, 35, "Subsection",
 CellTags->{
  "4.2.3", "Laser Cavities and MoveAligned", "Light Sources", "PR4.2", 
   "PR4.2.3"}],
Cell[540955, 9939, 347, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[541305, 9950, 630, 17, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[541938, 9969, 3693, 104, 229, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[545634, 10075, 110, 1, 26, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[545747, 10078, 322, 7, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[CellGroupData[{
Cell[546094, 10089, 1189, 36, 131, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[547286, 10127, 2791, 86, 54, "Output",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}]
}, Open  ]],
Cell[550092, 10216, 236, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[550331, 10227, 313, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[CellGroupData[{
Cell[550669, 10240, 663, 18, 25, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[551335, 10260, 101782, 1834, 81, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}]
}, Open  ]],
Cell[653132, 12097, 112, 1, 26, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[653247, 12100, 386, 10, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[653636, 12112, 697, 20, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[CellGroupData[{
Cell[654358, 12136, 601, 15, 87, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[654962, 12153, 3040, 95, 54, "Output",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[658039, 12253, 985, 24, 121, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[659027, 12279, 142085, 2384, 81, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}]
}, Open  ]],
Cell[801127, 14666, 630, 21, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[801760, 14689, 386, 9, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.3"}],
Cell[802149, 14700, 154, 3, 20, "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[802340, 14708, 128, 2, 35, "Subsection",
 CellTags->{
  "4.2.4", "Chromatic Sources", "Light Sources", "PR4.2", "PR4.2.4"}],
Cell[802471, 14712, 473, 9, 33, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[802947, 14723, 452, 10, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[803402, 14735, 403, 9, 34, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[CellGroupData[{
Cell[803830, 14748, 1027, 29, 89, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[804860, 14779, 13596, 229, 281, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}]
}, Open  ]],
Cell[818471, 15011, 221, 6, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[818695, 15019, 457, 11, 35, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[CellGroupData[{
Cell[819177, 15034, 1146, 33, 89, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[820326, 15069, 13584, 229, 281, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}]
}, Open  ]],
Cell[833925, 15301, 250, 7, 27, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[834178, 15310, 359, 8, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[834540, 15320, 272, 9, 21, "Text",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[CellGroupData[{
Cell[834837, 15333, 1357, 34, 168, "Input",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[836197, 15369, 57972, 1085, 397, "Print",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}]
}, Open  ]],
Cell[894184, 16457, 172, 4, 26, "Commentary",
 CellTags->{"Light Sources", "PR4.2", "PR4.2.4"}],
Cell[894359, 16463, 154, 3, 20, "Text",
 CellTags->{"Light Sources", "PR4.2"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[894562, 16472, 206, 5, 60, "Section",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "Custom Surface Shapes", "4.3", 
   "PR4.3", "PR4.3.0"}],
Cell[894771, 16479, 703, 17, 34, "Text",
 Evaluatable->False,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[895477, 16498, 1265, 30, 148, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[896745, 16530, 112, 1, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[896860, 16533, 749, 21, 51, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[897612, 16556, 1688, 71, 102, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[899303, 16629, 299, 9, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[899605, 16640, 1451, 52, 100, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[901059, 16694, 237, 4, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[901299, 16700, 1044, 22, 60, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[902346, 16724, 983, 19, 59, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[CellGroupData[{
Cell[903354, 16747, 384, 13, 154, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[903741, 16762, 536, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[904280, 16776, 536, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[904819, 16790, 53569, 876, 372, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}]
}, Open  ]],
Cell[958403, 17669, 149, 3, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[958555, 17674, 596, 17, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[959154, 17693, 935, 34, 76, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[960092, 17729, 164, 3, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[960259, 17734, 570, 14, 38, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[CellGroupData[{
Cell[960854, 17752, 112, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[960969, 17756, 478, 12, 34, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}]
}, Open  ]],
Cell[961462, 17771, 682, 14, 50, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[CellGroupData[{
Cell[962169, 17789, 370, 12, 138, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[962542, 17803, 224950, 3563, 330, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}]
}, Open  ]],
Cell[1187507, 21369, 154, 3, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[1187664, 21374, 271, 5, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.0"}],
Cell[1187938, 21381, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}],
Cell[CellGroupData[{
Cell[1188125, 21388, 256, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "4.3.1", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1188384, 21395, 737, 21, 34, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1189146, 21420, 246, 5, 24, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1189395, 21427, 1491, 44, 50, "Output",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1190901, 21474, 962, 30, 35, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1191888, 21508, 239, 5, 24, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1192130, 21515, 781, 22, 50, "Output",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1192926, 21540, 739, 28, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1193668, 21570, 262, 7, 24, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1193933, 21579, 1047, 26, 54, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1195005, 21609, 120, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1195128, 21613, 376, 7, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1195519, 21623, 474, 12, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1196018, 21639, 142, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1196163, 21643, 534, 12, 24, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1196712, 21658, 499, 13, 38, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1197236, 21675, 154, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1197393, 21679, 647, 17, 42, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1198055, 21699, 172, 5, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1198252, 21708, 310, 11, 89, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1198565, 21721, 1002, 29, 42, "Output",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1199582, 21753, 132, 1, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[CellGroupData[{
Cell[1199739, 21758, 295, 11, 89, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}],
Cell[1200037, 21771, 16705, 280, 298, "Print",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.1"}]
}, Open  ]],
Cell[1216757, 22054, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1216956, 22062, 225, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "4.3.2", "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1217184, 22069, 811, 22, 34, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1217998, 22093, 827, 32, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1218828, 22127, 1132, 39, 48, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1219963, 22168, 221, 5, 24, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[CellGroupData[{
Cell[1220209, 22177, 205, 5, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1220417, 22184, 751, 21, 50, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}]
}, Open  ]],
Cell[1221183, 22208, 219, 5, 24, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1221405, 22215, 485, 15, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1221893, 22232, 322, 9, 41, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1222218, 22243, 182, 5, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[CellGroupData[{
Cell[1222425, 22252, 350, 12, 106, "Input",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}],
Cell[1222778, 22266, 13664, 239, 193, "Print",
 CellTags->{
  "user defined models", "ModelSurfaceShape", "SurfaceLabel", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.2"}]
}, Open  ]],
Cell[1236457, 22508, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1236656, 22516, 118, 1, 35, "Subsection",
 CellTags->{"4.3.3", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1236777, 22519, 815, 24, 38, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.3"}],
Cell[1237595, 22545, 563, 18, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceRayIntersections", "Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1238161, 22565, 1709, 52, 86, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1239873, 22619, 1448, 47, 70, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1241324, 22668, 1642, 48, 86, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1242969, 22718, 1524, 46, 67, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1244518, 22768, 177, 3, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1244698, 22773, 325, 5, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1245038, 22781, 295, 6, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1245358, 22791, 235, 8, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1245596, 22801, 372, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1245983, 22810, 129, 1, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1246137, 22815, 148, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1246288, 22819, 199460, 3241, 298, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1445763, 26063, 461, 11, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1446249, 26078, 276, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1446528, 26088, 375, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1446906, 26096, 149930, 2576, 193, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1596851, 28675, 1819, 42, 99, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1598673, 28719, 117, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1598815, 28725, 271, 9, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1599089, 28736, 373, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1599499, 28747, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1599633, 28751, 374, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1600022, 28760, 585, 12, 38, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1600632, 28776, 276, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1600911, 28786, 909, 16, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1601823, 28804, 709, 13, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1602535, 28819, 405, 7, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1602943, 28828, 141021, 2427, 193, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1744001, 31260, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1744135, 31264, 377, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1744527, 31273, 311, 7, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1744863, 31284, 272, 9, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1745138, 31295, 374, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1745549, 31306, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1745683, 31310, 376, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1746074, 31319, 299, 9, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1746398, 31332, 276, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1746677, 31342, 376, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1747056, 31350, 149932, 2576, 193, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1897025, 33931, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1897159, 33935, 374, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1897548, 33944, 258, 7, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1897831, 33955, 272, 9, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1898106, 33966, 375, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1898518, 33977, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1898652, 33981, 374, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[1899041, 33990, 313, 8, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[CellGroupData[{
Cell[1899379, 34002, 276, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1899658, 34012, 368, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[1900029, 34020, 149917, 2576, 193, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2049983, 36601, 131, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[2050117, 36605, 377, 6, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}]
}, Open  ]],
Cell[2050509, 36614, 1341, 32, 83, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.3"}],
Cell[2051853, 36648, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2052052, 36656, 214, 5, 35, "Subsection",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "4.3.4", "Custom Surface Shapes", 
   "PR4.3", "PR4.3.4"}],
Cell[2052269, 36663, 384, 9, 20, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2052656, 36674, 200, 5, 24, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2052859, 36681, 300, 11, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2053162, 36694, 216, 5, 24, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2053381, 36701, 492, 15, 20, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2053876, 36718, 253, 7, 24, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2054132, 36727, 885, 23, 47, "Text",
 Evaluatable->False,
 CellTags->{
  "FreezeIncrement", "FunctionCenter", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2055020, 36752, 656, 24, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "FreezeIncrement", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2055679, 36778, 489, 21, 252, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2056171, 36801, 652, 23, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2056848, 36828, 222, 5, 24, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2057073, 36835, 25095, 403, 168, "Print",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}]
}, Open  ]],
Cell[2082183, 37241, 286, 11, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2082494, 37256, 207, 5, 24, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2082704, 37263, 16992, 296, 365, "Print",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}]
}, Open  ]],
Cell[2099711, 37562, 342, 12, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2100078, 37578, 338, 12, 106, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2100419, 37592, 13569, 279, 105, "Print",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}]
}, Open  ]],
Cell[2114003, 37874, 755, 19, 33, "Text",
 Evaluatable->False,
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2114761, 37895, 345, 11, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2115131, 37910, 209, 5, 24, "Input",
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2115343, 37917, 378, 7, 23, "Output",
 CellTags->{
  "animations", "creating new components", "black hole", 
   "Custom Surface Shapes", "PR4.3", "PR4.3.4"}]
}, Open  ]],
Cell[2115736, 37927, 390, 11, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2116151, 37942, 361, 11, 89, "Input",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2116515, 37955, 3674, 69, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2120192, 38026, 3715, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2123910, 38098, 3720, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2127633, 38170, 3717, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2131353, 38242, 3710, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2135066, 38314, 3711, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2138780, 38386, 3712, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2142495, 38458, 3717, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2146215, 38530, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2149934, 38602, 6932, 125, 99, 3419, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2156869, 38729, 6911, 125, 99, 3420, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2163783, 38856, 6914, 125, 99, 3423, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2170700, 38983, 6935, 125, 99, 3422, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2177638, 39110, 6878, 124, 99, 3419, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2184519, 39236, 6889, 125, 99, 3416, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2191411, 39363, 6896, 125, 99, 3419, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2198310, 39490, 6881, 124, 99, 3421, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2205194, 39616, 6904, 125, 99, 3423, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2212101, 39743, 6872, 124, 99, 3422, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2218976, 39869, 6879, 124, 99, 3423, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2225858, 39995, 6891, 125, 99, 3422, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2232752, 40122, 6841, 124, 99, 3427, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2239596, 40248, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2243315, 40320, 3715, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2247033, 40392, 6858, 124, 99, 3418, 64, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2253894, 40518, 3707, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2257604, 40590, 3709, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2261316, 40662, 3719, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2265038, 40734, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2268757, 40806, 3715, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2272475, 40878, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2276194, 40950, 3713, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2279910, 41022, 3712, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2283625, 41094, 3717, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2287345, 41166, 3714, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2291062, 41238, 3719, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2294784, 41310, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2298503, 41382, 3713, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2302219, 41454, 3709, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2305931, 41526, 3717, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2309651, 41598, 3714, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2313368, 41670, 3711, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2317082, 41742, 3709, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2320794, 41814, 3713, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2324510, 41886, 3714, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2328227, 41958, 3721, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2331951, 42030, 3722, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2335676, 42102, 3723, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2339402, 42174, 3715, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2343120, 42246, 3709, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2346832, 42318, 3710, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2350545, 42390, 3711, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2354259, 42462, 3714, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2357976, 42534, 3717, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2361696, 42606, 3712, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2365411, 42678, 3713, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2369127, 42750, 3718, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2372848, 42822, 3723, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2376574, 42894, 3712, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2380289, 42966, 3713, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2384005, 43038, 3716, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2387724, 43110, 3715, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}],
Cell[2391442, 43182, 3686, 70, 99, "Print",
 CellTags->{
  "animations", "RayChoice", "IntersectionNumber", "creating new components", 
   "black hole", "Custom Surface Shapes", "PR4.3", "PR4.3.4"}]
}, Open  ]],
Cell[2395143, 43255, 445, 12, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2395613, 43271, 457, 11, 106, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2396073, 43284, 13212, 276, 129, "Print",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}]
}, Open  ]],
Cell[2409300, 43563, 756, 19, 50, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[CellGroupData[{
Cell[2410081, 43586, 454, 11, 106, "Input",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2410538, 43599, 723, 16, 22, "Message",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2411264, 43617, 723, 16, 22, "Message",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2411990, 43635, 723, 16, 22, "Message",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2412716, 43653, 731, 16, 22, "Message",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}],
Cell[2413450, 43671, 13138, 274, 129, "Print",
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.4"}]
}, Open  ]],
Cell[2426603, 43948, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2426802, 43956, 201, 6, 35, "Subsection",
 CellTags->{"4.3.5", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2427006, 43964, 448, 12, 21, "Text",
 Evaluatable->False,
 CellTags->{
  "creating new components", "black hole", "Custom Surface Shapes", "PR4.3", 
   "PR4.3.5"}],
Cell[2427457, 43978, 781, 25, 76, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2428241, 44005, 1836, 42, 93, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2430080, 44049, 2981, 77, 310, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceApproximation", "Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2433064, 44128, 254, 6, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2433321, 44136, 1556, 25, 96, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2434880, 44163, 1372, 37, 83, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2436277, 44204, 396, 13, 154, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2436676, 44219, 57340, 927, 438, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2494019, 45148, 23067, 419, 419, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2517101, 45570, 219, 6, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2517323, 45578, 399, 7, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2517747, 45589, 332, 7, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2518082, 45598, 54722, 886, 438, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2572819, 46487, 192, 4, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2573036, 46495, 424, 14, 171, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2573463, 46511, 119021, 1853, 438, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2692487, 48366, 26691, 458, 365, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2719193, 48827, 222, 6, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2719418, 48835, 277, 6, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2719720, 48845, 136, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2719859, 48849, 311, 5, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2720185, 48857, 216, 5, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2720426, 48866, 335, 10, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2720764, 48878, 44789, 712, 365, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2765568, 49593, 467, 9, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2766060, 49606, 335, 10, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2766398, 49618, 41446, 724, 383, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[2807859, 50345, 163, 4, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2808025, 50351, 1194, 33, 447, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[2809244, 50388, 200, 7, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[2809447, 50397, 422031, 6709, 271, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[3231493, 57109, 230, 7, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[3231748, 57120, 244, 7, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[3231995, 57129, 34846, 552, 233, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[3266856, 57684, 236, 6, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[3267117, 57694, 267, 8, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[3267387, 57704, 396352, 6269, 248, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[3663754, 63976, 885, 19, 54, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[CellGroupData[{
Cell[3664664, 63999, 262, 12, 154, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[3664929, 64013, 534, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[3665466, 64027, 534, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}],
Cell[3666003, 64041, 289761, 5004, 152, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.5"}]
}, Open  ]],
Cell[3955779, 69048, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[3955978, 69056, 252, 7, 35, "Subsection",
 CellTags->{"4.3.6", "Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[3956233, 69065, 804, 14, 51, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[CellGroupData[{
Cell[3957062, 69083, 398, 10, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[3957463, 69095, 517025, 8331, 205, 512665, 8256, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[4474491, 77428, 440235, 7710, 365, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}]
}, Open  ]],
Cell[4914741, 85141, 223, 6, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[4914967, 85149, 148, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[CellGroupData[{
Cell[4915140, 85156, 239, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[4915382, 85166, 13808, 255, 136, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}]
}, Open  ]],
Cell[4929205, 85424, 106, 1, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[4929314, 85427, 154, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[CellGroupData[{
Cell[4929493, 85434, 297, 8, 89, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[4929793, 85444, 440561, 7716, 365, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}]
}, Open  ]],
Cell[5370369, 93163, 101, 1, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[5370473, 93166, 345, 8, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[CellGroupData[{
Cell[5370843, 93178, 625, 13, 154, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[5371471, 93193, 513284, 8286, 208, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[5884758, 101481, 445359, 7798, 320, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}]
}, Open  ]],
Cell[6330132, 109282, 291, 7, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.6"}],
Cell[6330426, 109291, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6330625, 109299, 169, 4, 35, "Subsection",
 CellTags->{"4.3.7", "Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6330797, 109305, 616, 13, 38, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[CellGroupData[{
Cell[6331438, 109322, 414, 9, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6331855, 109333, 687, 14, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6332545, 109349, 685, 14, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6333233, 109365, 685, 14, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6333921, 109381, 679, 14, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6334603, 109397, 34371, 579, 393, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}]
}, Open  ]],
Cell[6368989, 109979, 217, 4, 27, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.7"}],
Cell[6369209, 109985, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6369408, 109993, 255, 7, 35, "Subsection",
 CellTags->{"4.3.8", "Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6369666, 110002, 667, 13, 47, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[CellGroupData[{
Cell[6370358, 110019, 393, 13, 138, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6370754, 110034, 52388, 875, 251, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6423145, 110911, 38731, 790, 366, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}]
}, Open  ]],
Cell[6461891, 111704, 155, 2, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6462049, 111708, 251, 5, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[CellGroupData[{
Cell[6462325, 111717, 157, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6462485, 111721, 565, 15, 38, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}]
}, Open  ]],
Cell[6463065, 111739, 207, 4, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[CellGroupData[{
Cell[6463297, 111747, 213, 5, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6463513, 111754, 741, 21, 38, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}]
}, Open  ]],
Cell[6464269, 111778, 483, 11, 34, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[CellGroupData[{
Cell[6464777, 111793, 483, 14, 154, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6465263, 111809, 73645, 1224, 251, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6538911, 113035, 38451, 790, 361, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}]
}, Open  ]],
Cell[6577377, 113828, 194, 5, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6577574, 113835, 714, 19, 51, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.8"}],
Cell[6578291, 113856, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6578490, 113864, 125, 1, 35, "Subsection",
 CellTags->{"4.3.9", "Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6578618, 113867, 376, 12, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[CellGroupData[{
Cell[6579019, 113883, 118, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6579140, 113887, 1424, 24, 56, "Print",
 CellTags->{
  "Custom Surface Shapes", "Info3614711174-7377950", "PR4.3", "PR4.3.9"}]
}, Open  ]],
Cell[6580579, 113914, 393, 7, 33, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[CellGroupData[{
Cell[6580997, 113925, 265, 6, 41, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6581265, 113933, 636, 17, 38, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6581938, 113955, 222, 6, 41, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6582163, 113963, 359, 7, 23, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}]
}, Open  ]],
Cell[6582537, 113973, 240, 8, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6582780, 113983, 141, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6582924, 113987, 543, 11, 38, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[CellGroupData[{
Cell[6583492, 114002, 183, 4, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6583678, 114008, 642, 19, 24, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}]
}, Open  ]],
Cell[6584335, 114030, 346, 9, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6584684, 114041, 227, 6, 41, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6584914, 114049, 132, 1, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[CellGroupData[{
Cell[6585071, 114054, 282, 8, 73, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6585356, 114064, 534, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6585893, 114078, 536, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6586432, 114092, 534, 12, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6586969, 114106, 711, 15, 22, "Message",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6587683, 114123, 7673, 142, 298, "Print",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}]
}, Open  ]],
Cell[6595371, 114268, 170, 5, 26, "Commentary",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6595544, 114275, 401, 5, 33, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.9"}],
Cell[6595948, 114282, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6596147, 114290, 164, 4, 35, "Subsection",
 CellTags->{"4.3.10", "Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[6596314, 114296, 955, 27, 54, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[CellGroupData[{
Cell[6597294, 114327, 121, 2, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[6597418, 114331, 5918, 152, 168, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}]
}, Open  ]],
Cell[6603351, 114486, 214, 7, 21, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[CellGroupData[{
Cell[6603590, 114497, 171, 4, 24, "Input",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[6603764, 114503, 1976, 33, 229, "Output",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}]
}, Open  ]],
Cell[6605755, 114539, 952, 21, 70, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3", "PR4.3.10"}],
Cell[6606710, 114562, 162, 3, 20, "Text",
 CellTags->{"Custom Surface Shapes", "PR4.3"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6606921, 114571, 199, 5, 60, "Section",
 Evaluatable->False,
 CellTags->{
  "4.4", "Holograms and Diffraction Gratings", "Gratings", "PR4.4", 
   "PR4.4.0"}],
Cell[6607123, 114578, 385, 12, 21, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6607511, 114592, 1621, 64, 84, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Grating", "Gratings", "PR4.4", "PR4.4.0"}],
Cell[6609135, 114658, 280, 9, 21, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[CellGroupData[{
Cell[6609440, 114671, 231, 7, 73, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6609674, 114680, 23672, 400, 251, 9186, 160, "CachedBoxData", "BoxData", \
"Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}]
}, Open  ]],
Cell[6633361, 115083, 128, 2, 26, "Commentary",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6633492, 115087, 739, 13, 46, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6634234, 115102, 720, 19, 51, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6634957, 115123, 1366, 44, 63, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6636326, 115169, 706, 18, 51, "Text",
 CellTags->{"Gratings", "PR4.4", "PR4.4.0"}],
Cell[6637035, 115189, 149, 3, 20, "Text",
 CellTags->{"Gratings", "PR4.4"}],
Cell[CellGroupData[{
Cell[6637209, 115196, 121, 1, 35, "Subsection",
 CellTags->{"Variable Pitch Grating", "Gratings", "PR4.4", "PR4.4.1"}],
Cell[CellGroupData[{
Cell[6637355, 115201, 106, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6637464, 115205, 428, 11, 41, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6637929, 115221, 115, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6638047, 115225, 421, 11, 41, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}]
}, Open  ]],
Cell[6638483, 115239, 289, 9, 106, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[CellGroupData[{
Cell[6638797, 115252, 303, 8, 73, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6639103, 115262, 8377, 165, 159, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6647517, 115432, 385, 10, 106, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6647905, 115444, 525, 12, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6648433, 115458, 664, 14, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6649100, 115474, 523, 12, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6649626, 115488, 687, 14, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6650316, 115504, 523, 12, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6650842, 115518, 700, 15, 22, "Message",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}],
Cell[6651545, 115535, 9843, 215, 159, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.1"}]
}, Open  ]],
Cell[6661403, 115753, 149, 3, 20, "Text",
 CellTags->{"Gratings", "PR4.4"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6661589, 115761, 131, 1, 35, "Subsection",
 CellTags->{"Holographic Optical Element", "Gratings", "PR4.4", "PR4.4.2"}],
Cell[CellGroupData[{
Cell[6661745, 115766, 254, 7, 73, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6662002, 115775, 737, 22, 51, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[6662754, 115800, 113, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[CellGroupData[{
Cell[6662892, 115806, 213, 5, 41, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6663108, 115813, 1103, 32, 59, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6664248, 115850, 285, 8, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6664536, 115860, 3169, 61, 438, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6667742, 115926, 128, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6667873, 115930, 2782, 57, 337, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6670658, 115989, 450, 11, 28, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6671145, 116005, 299, 8, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6671447, 116015, 6645, 117, 128, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6678129, 116137, 137, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6678269, 116141, 2777, 57, 325, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6681049, 116200, 433, 10, 28, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6681519, 116215, 325, 8, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6681847, 116225, 6536, 115, 128, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6688420, 116345, 140, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6688563, 116349, 2591, 46, 353, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6691157, 116397, 428, 10, 23, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6691622, 116412, 101, 2, 24, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6691726, 116416, 2480, 33, 334, "Print",
 CellTags->{"Gratings", "Info3614711184-7377950", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6694243, 116454, 363, 8, 73, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6694609, 116464, 905, 19, 20, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6695517, 116485, 12459, 221, 249, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6707979, 116708, 915, 20, 20, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6708897, 116730, 47697, 850, 249, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6756597, 117582, 65331, 1104, 240, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6821965, 118691, 370, 8, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[6822338, 118701, 241331, 3444, 365, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7063706, 122150, 447, 10, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7064156, 122162, 771, 18, 20, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7064930, 122182, 49650, 880, 234, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7114583, 123064, 52432, 900, 112, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7167052, 123969, 447, 10, 89, "Input",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7167502, 123981, 737, 17, 20, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7168242, 124000, 55364, 984, 249, "Print",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}],
Cell[7223609, 124986, 58357, 1004, 126, "Output",
 CellTags->{"Gratings", "PR4.4", "PR4.4.2"}]
}, Open  ]],
Cell[7281981, 125993, 149, 3, 20, "Text",
 CellTags->{"Gratings", "PR4.4"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7282179, 126002, 176, 3, 60, "Section",
 Evaluatable->False,
 CellTags->{"4.5", "Generic Building Blocks", "PR4.5"}],
Cell[7282358, 126007, 892, 23, 53, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7283275, 126034, 142, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7283420, 126038, 14522, 417, 162, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7297957, 126458, 229, 4, 26, "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7298189, 126464, 1287, 25, 85, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7299501, 126493, 141, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7299645, 126497, 893, 24, 24, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7300553, 126524, 1363, 37, 70, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7301941, 126565, 287, 8, 57, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7302231, 126575, 11532, 197, 159, "Print",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7313778, 126775, 152, 2, 26, "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7313933, 126779, 150, 5, 21, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7314108, 126788, 124, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7314235, 126792, 749, 20, 24, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7314999, 126815, 980, 27, 54, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7316004, 126846, 124, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7316131, 126850, 758, 20, 24, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7316904, 126873, 797, 24, 38, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7317726, 126901, 139, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7317868, 126905, 1091, 27, 40, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7318974, 126935, 286, 6, 21, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7319285, 126945, 136, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7319424, 126949, 7830, 183, 399, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7327269, 127135, 1080, 29, 70, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7328374, 127168, 401, 11, 138, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7328778, 127181, 47160, 755, 327, "Print",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7375953, 127939, 368, 12, 27, "Commentary",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7376324, 127953, 306, 8, 21, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7376655, 127965, 137, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7376795, 127969, 813, 21, 24, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7377623, 127993, 634, 16, 38, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[CellGroupData[{
Cell[7378282, 128013, 144, 2, 24, "Input",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7378429, 128017, 891, 23, 24, "Output",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[7379335, 128043, 351, 9, 21, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}],
Cell[7379689, 128054, 164, 3, 20, "Text",
 CellTags->{"Generic Building Blocks", "PR4.5"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7379890, 128062, 147, 3, 60, "Section",
 Evaluatable->False,
 CellTags->{"4.6", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7380040, 128067, 581, 12, 38, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7380624, 128081, 713, 26, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7381340, 128109, 818, 23, 54, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7382161, 128134, 1143, 31, 180, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7383307, 128167, 242, 8, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7383552, 128177, 806, 22, 54, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7384361, 128201, 217, 6, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[CellGroupData[{
Cell[7384603, 128211, 218, 6, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7384824, 128219, 2844, 56, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.0"}]
}, Open  ]],
Cell[7387683, 128278, 232, 8, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7387918, 128288, 373, 10, 21, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.0"}],
Cell[7388294, 128300, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}],
Cell[CellGroupData[{
Cell[7388477, 128307, 120, 1, 35, "Subsection",
 CellTags->{"4.6.1", "CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[7388600, 128310, 590, 18, 38, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[CellGroupData[{
Cell[7389215, 128332, 229, 9, 89, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[7389447, 128343, 644, 18, 24, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}]
}, Open  ]],
Cell[7390106, 128364, 176, 4, 20, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[CellGroupData[{
Cell[7390307, 128372, 223, 6, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[7390533, 128380, 2950, 58, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.1"}]
}, Open  ]],
Cell[7393498, 128441, 314, 9, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.1"}],
Cell[7393815, 128452, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7394010, 128460, 129, 1, 35, "Subsection",
 CellTags->{"4.6.2", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7394142, 128463, 880, 18, 53, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[CellGroupData[{
Cell[7395047, 128485, 262, 9, 89, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7395312, 128496, 448, 12, 24, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7395797, 128513, 221, 6, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7396021, 128521, 2841, 56, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[7398877, 128580, 159, 2, 26, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7399039, 128584, 593, 20, 38, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[CellGroupData[{
Cell[7399657, 128608, 438, 16, 187, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7400098, 128626, 2837, 56, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[7402950, 128685, 217, 6, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7403170, 128693, 366, 11, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[CellGroupData[{
Cell[7403561, 128708, 455, 16, 187, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7404019, 128726, 2952, 58, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[7406986, 128787, 155, 2, 26, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7407144, 128791, 420, 12, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[CellGroupData[{
Cell[7407589, 128807, 514, 18, 219, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7408106, 128827, 3325, 65, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[7411446, 128895, 133, 1, 26, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7411582, 128898, 582, 20, 38, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[CellGroupData[{
Cell[7412189, 128922, 216, 6, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7412408, 128930, 2344, 46, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.2"}]
}, Open  ]],
Cell[7414767, 128979, 368, 11, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.2"}],
Cell[7415138, 128992, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7415333, 129000, 219, 8, 35, "Subsection",
 CellTags->{"4.6.3", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7415555, 129010, 439, 12, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7415997, 129024, 857, 25, 100, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7416857, 129051, 292, 8, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7417152, 129061, 1227, 44, 54, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7418382, 129107, 428, 13, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7418835, 129124, 228, 8, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7419066, 129134, 333, 6, 24, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7419414, 129143, 196, 5, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7419635, 129152, 306, 10, 89, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7419944, 129164, 2946, 58, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7422905, 129225, 216, 6, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7423124, 129233, 271, 6, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7423420, 129243, 330, 11, 106, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7423753, 129256, 2832, 55, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7426600, 129314, 210, 5, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7426813, 129321, 391, 8, 34, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7427229, 129333, 329, 11, 106, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7427561, 129346, 2944, 58, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7430520, 129407, 217, 5, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7430740, 129414, 317, 6, 20, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7431060, 129422, 474, 10, 38, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7431559, 129436, 433, 15, 187, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7431995, 129453, 6909, 123, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7438907, 129578, 378, 8, 23, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7439300, 129589, 215, 5, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7439518, 129596, 350, 8, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7439893, 129608, 396, 12, 122, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7440292, 129622, 21487, 368, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7461782, 129992, 375, 8, 23, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7462172, 130003, 210, 5, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7462385, 130010, 395, 9, 21, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[CellGroupData[{
Cell[7462805, 130023, 411, 12, 122, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7463219, 130037, 4676, 87, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7467898, 130126, 408, 9, 23, "Output",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.3"}]
}, Open  ]],
Cell[7468321, 130138, 212, 5, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.3"}],
Cell[7468536, 130145, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7468731, 130153, 133, 1, 35, "Subsection",
 CellTags->{"4.6.4", "CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7468867, 130156, 938, 18, 64, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[CellGroupData[{
Cell[7469830, 130178, 243, 9, 73, "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7470076, 130189, 22046, 377, 365, "Print",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
   "PR4.6.4"}]
}, Open  ]],
Cell[7492137, 130569, 126, 1, 26, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7492266, 130572, 404, 11, 21, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[CellGroupData[{
Cell[7492695, 130587, 212, 6, 24, "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7492910, 130595, 573, 16, 24, "Output",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
   "PR4.6.4"}]
}, Open  ]],
Cell[7493498, 130614, 707, 19, 38, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[CellGroupData[{
Cell[7494230, 130637, 247, 9, 73, "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7494480, 130648, 5654, 101, 365, "Print",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
   "PR4.6.4"}]
}, Open  ]],
Cell[7500149, 130752, 234, 6, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7500386, 130760, 842, 21, 54, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[CellGroupData[{
Cell[7501253, 130785, 422, 10, 122, "Input",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7501678, 130797, 6106, 110, 365, "Print",
 CellTags->{
  "RayTilt using CustomDeflections", "CustomDeflections", "PR4.6", 
   "PR4.6.4"}]
}, Open  ]],
Cell[7507799, 130910, 247, 6, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7508049, 130918, 425, 11, 38, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[CellGroupData[{
Cell[7508499, 130933, 224, 8, 89, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7508726, 130943, 2088, 44, 365, "Print",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}]
}, Open  ]],
Cell[7510829, 130990, 260, 6, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7511092, 130998, 428, 12, 34, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.4"}],
Cell[7511523, 131012, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7511718, 131020, 204, 6, 35, "Subsection",
 CellTags->{
  "Optimizing CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7511925, 131028, 1746, 46, 103, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7513674, 131076, 528, 16, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7514205, 131094, 1490, 38, 86, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7515698, 131134, 894, 29, 431, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7516595, 131165, 403, 12, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7517001, 131179, 1334, 29, 83, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7518338, 131210, 418, 11, 34, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7518759, 131223, 534, 18, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "PropagateSystemDeflection", "CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7519296, 131243, 1300, 30, 83, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7520599, 131275, 268, 9, 21, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[CellGroupData[{
Cell[7520892, 131288, 187, 5, 24, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7521082, 131295, 2197, 43, 365, "Print",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}]
}, Open  ]],
Cell[7523294, 131341, 288, 9, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[CellGroupData[{
Cell[7523607, 131354, 191, 5, 24, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7523801, 131361, 3182, 61, 365, "Print",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}]
}, Open  ]],
Cell[7526998, 131425, 293, 9, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.5"}],
Cell[7527294, 131436, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7527489, 131444, 157, 4, 35, "Subsection",
 CellTags->{"AffectedSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7527649, 131450, 1313, 32, 70, "Text",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7528987, 131486, 359, 12, 122, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7529349, 131500, 11531, 198, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}]
}, Open  ]],
Cell[7540895, 131701, 362, 7, 34, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7541282, 131712, 236, 6, 24, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7541521, 131720, 11509, 201, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}]
}, Open  ]],
Cell[7553045, 131924, 482, 9, 37, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7553530, 131935, 169, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7553724, 131942, 144, 1, 31, "Subsubsection",
 CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7553871, 131945, 535, 12, 38, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7554431, 131961, 467, 18, 219, "Input",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7554901, 131981, 11963, 210, 365, "Print",
 CellTags->{
  "Simple CustomDeflections", "CustomDeflections", "PR4.6", "PR4.6.6"}]
}, Open  ]],
Cell[7566879, 132194, 345, 9, 21, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7567227, 132205, 580, 19, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"RemoveDeflection", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7567810, 132226, 522, 14, 34, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7568335, 132242, 1593, 35, 99, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7569931, 132279, 1573, 45, 86, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7571507, 132326, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7571702, 132334, 109, 1, 31, "Subsubsection",
 CellTags->{"LabelSurfaces", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7571814, 132337, 461, 11, 38, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7572278, 132350, 574, 17, 51, "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{
  "SurfaceApproximation", "CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7572855, 132369, 754, 18, 51, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7573634, 132391, 196, 5, 24, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7573833, 132398, 2517, 55, 402, "Print",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}]
}, Open  ]],
Cell[7576365, 132456, 294, 8, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7576662, 132466, 974, 18, 67, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[CellGroupData[{
Cell[7577661, 132488, 252, 5, 41, "Input",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7577916, 132495, 11394, 197, 224, "Print",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}]
}, Open  ]],
Cell[7589325, 132695, 309, 8, 27, "Commentary",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7589637, 132705, 307, 7, 21, "Text",
 CellTags->{"CustomDeflections", "PR4.6", "PR4.6.6"}],
Cell[7589947, 132714, 158, 3, 20, "Text",
 CellTags->{"CustomDeflections", "PR4.6"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
