(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1063827,      49322]
NotebookOptionsPosition[   1008012,      48086]
NotebookOutlinePosition[   1051755,      49039]
CellTagsIndexPosition[   1050540,      48998]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["2. Placement Directives", "Subtitle",
 CellTags->{
  "chapter 2 topics", "Overview", "Placing Components and Systems", 
   "Angular Orientation", "Advanced Placement"}],

Cell[TextData[ButtonBox["2.1 Overview",
 BaseStyle->"Hyperlink",
 ButtonData:>"2.1"]], "Outline2"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.2 Placing Components and Systems",
 BaseStyle->"Hyperlink",
 ButtonData:>"2.2"]], "Outline2",
 CellTags->{"Placing Components and Systems", "PR2.2"}],

Cell[TextData[{
 ButtonBox["2.2.1 Legacy Issues",
  BaseStyle->"Hyperlink",
  ButtonData:>"Legacy Issues"],
 "\n",
 ButtonBox["2.2.2 Translate",
  BaseStyle->"Hyperlink",
  ButtonData:>"Translate"],
 "\n",
 ButtonBox["2.2.3 Move",
  BaseStyle->"Hyperlink",
  ButtonData:>"Move"],
 "\n",
 ButtonBox["2.2.4 MoveLinear",
  BaseStyle->"Hyperlink",
  ButtonData:>"MoveLinear"],
 "\n",
 ButtonBox["2.2.5 MoveDirected",
  BaseStyle->"Hyperlink",
  ButtonData:>"MoveDirected"],
 "\n",
 ButtonBox["2.2.6 MoveReflected",
  BaseStyle->"Hyperlink",
  ButtonData:>"MoveReflected"]
}], "Outline3",
 CellTags->{"Placing Components and Systems", "PR2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.3 Angular Orientation",
 BaseStyle->"Hyperlink",
 ButtonData:>"2.3"]], "Outline2",
 CellTags->{"Angular Orientation", "PR2.3"}],

Cell[TextData[{
 ButtonBox["2.3.1 Move with Intrinsic Rotation",
  BaseStyle->"Hyperlink",
  ButtonData:>"Move with Intrinsic Rotation"],
 "\n",
 ButtonBox["2.3.2 Rotate",
  BaseStyle->"Hyperlink",
  ButtonData:>"Rotate"]
}], "Outline3",
 CellTags->{"Angular Orientation", "PR2.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["2.4 Advanced Placement with MoveAligned",
 BaseStyle->"Hyperlink",
 ButtonData:>"2.4"]], "Outline2"],

Cell[CellGroupData[{

Cell["2.1 Overview", "Section",
 PageBreakAbove->True,
 CellTags->{"2.1", "Overview"}],

Cell[TextData[{
 "Coordinate systems in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " fall into two categories, local and global.  Every component and light  \
source has a local coordinate system.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " defines the component geometry in this local system.  In turn, the  \
overall optical system has a global reference frame.  Component placement  \
happens in this context.  Such placement is achieved by the ",
 StyleBox["Move", "MB"],
 " function and its variants.  Refer to these functions as placement  \
directives."
}], "Text",
 CellTags->"Overview"],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " works with standard Euclidian coordinates.  However ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 "'s default optic axis is the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-axis.  This convention is not universal; many textbooks adopt ",
 StyleBox["z",
  FontSlant->"Italic"],
 " as the optic axis, with ",
 StyleBox["x-y",
  FontSlant->"Italic"],
 " as the focal plane.  The reason for this convention in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " is that it meshes better with various default settings in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics.  Of course, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " has full three-dimensional generality.  You are free to orient your  \
system in any manner whatsoever.  Saying that ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " has a default axis means that built-in components use ",
 StyleBox["x",
  FontSlant->"Italic"],
 " as their local optic axis.  Thus if you wanted ",
 StyleBox["z",
  FontSlant->"Italic"],
 " as your system's optic axis, you would have to rotate every component 90  \
degrees."
}], "Text",
 CellTags->"Overview"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " represents vectors as lists ",
 StyleBox["{x,y,z}", "MB"],
 ", and matrices as nested lists ",
 StyleBox["{{a,b},{c,d}}", "MB"],
 ".  Two-dimensional vectors have two elements ",
 StyleBox["{x,y},", "MB"],
 " and three-dimensional vectors have three.  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " makes no distinction between row and column vectors.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " maintains these conventions of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language.  For placement purposes, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " uses direction vector",
 StyleBox["s",
  FontSlant->"Italic"],
 " as well as position vectors.  Direction vectors specify orientation.  \
Scalar angles are also used."
}], "Text",
 CellTags->"Overview"],

Cell[TextData[{
 "When you invoke a component or light source, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " drops it into your system with the local coordinate axes coincident with  \
the global axes.  If a ",
 StyleBox["Move", "MB"],
 "-related function wraps the component invocation, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " performs the indicated maneuver.  Specifically, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " defines component position as the location of the component's local  \
coordinate origin relative to the global origin.  Component orientation,  \
meanwhile, is considered between the component's local coordinate axes and  \
the global coordinate axes.  So for purposes of placing components, you  \
should visualize placement directives manipulating local coordinate axes.   \
The physical component, with its surfaces and properties, just goes along for \
 the ride."
}], "Text",
 CellTags->"Overview"],

Cell[TextData[{
 "Placement directives are general across all types of objects.  These  \
functions work on components, light sources, and rays.  You can, for example, \
 apply ",
 StyleBox["MoveReflected", "MB"],
 " to a prism, even though it is not a mirror.  The geometry of any  \
placement directive is completely general.  However, some of them, like ",
 StyleBox["MoveReflected", "MB"],
 ", are designed with particular components in mind.  Placement directives  \
also work on ",
 StyleBox["optical systems",
  FontSlant->"Italic"],
 ", that is, lists of components and sources."
}], "Text",
 CellTags->"Overview"],

Cell["\<\
Placement directives may be nested.  There is no requirement to achieve a \
given placement with a single function call.  Use as many nested directives \
as seems reasonable.  While it is best to minimize the nesting of directives, \
in some situations this type of input is unavoidable.\
\>", "Text",
 CellTags->"Overview"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Placing Components and Systems", "Section",
 CellTags->{
  "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
   "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],

Cell[TextData[{
 "Placement refers to the positioning of a component or light source in  \
global system coordinates.  It may also involve an adjustment of the object's \
 orientation, depending on the function used.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " features several placement directives that affect orientation as well as  \
position; these functions offer convenient ways to set up optical systems."
}], "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],

Cell[TextData[{
 "There are usually several different ways to achieve the same placement.   \
Sometimes ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " echoes back a different function than was supplied as input.  This  \
behavior is not an error.  ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " uses the echo-back string to express an equivalent formulation which ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " stores internally."
}], "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " presents a small toolbox of placement directives.  The primary functions  \
are ",
 StyleBox["Translate", "MB"],
 ", ",
 StyleBox["Rotate", "MB"],
 ", ",
 StyleBox["Move", "MB"],
 ", ",
 StyleBox["MoveLinear", "MB"],
 ", ",
 StyleBox["MoveDirected", "MB"],
 ", ",
 StyleBox["MoveReflected", "MB"],
 ", and ",
 StyleBox["MoveAligned", "Input"],
 ".  By far the most commonly used function is ",
 StyleBox["Move", "MB"],
 ".  In fact, different calling conventions for ",
 StyleBox["Move", "MB"],
 " can essentially perform all the other functions.  Yet at its simplest  \
level, ",
 StyleBox["Move", "MB"],
 " simply translates components without changing orientation.  The other  \
functions have more specialized applications.  ",
 StyleBox["Translate", "MB"],
 " and ",
 StyleBox["Rotate", "MB"],
 " perform their eponymous functions in one, two, or three dimensions.  In  \
general, all positioning functions work in any dimension; the dimensionality  \
in a given case follows the supplied input parameters."
}], "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " supports a few directives that handle orientation automatically.  ",
 StyleBox["MoveLinear", "MB"],
 " and ",
 StyleBox["MoveDirected", "MB"],
 " both drive components along an optical rail and orient them with the rail  \
direction.  The difference between them lies in their parameter formats.  ",
 StyleBox["MoveLinear", "MB"],
 " uses a scalar distance along the rail to find absolute position, whereas  ",
 StyleBox["MoveDirected", "MB"],
 " accepts absolute position directly (the scalar distance being implicit).  ",
 StyleBox["MoveReflected", "MB"],
 " positions and orients a mirror by consideration of reflective geometry.  \
This function simplifies the redirection of light beams in your system.  \
Later on, in Section 2.4, we will examine the advanced ",
 StyleBox["MoveAligned", "Input"],
 " function that calculates optical element positions with a chief ray trace \
through the system."
}], "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2"}],

Cell[CellGroupData[{

Cell["2.2.1 Legacy Issues", "Subsection",
 CellTags->{
  "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
   "PR2.2.1"}],

Cell[TextData[{
 "Some of the functions discussed in this chapter may be called with a ",
 StyleBox["3D", "MB"],
 " appendage, for example ",
 StyleBox["Move3D", "MB"],
 " instead of ",
 StyleBox["Move", "MB"],
 ".  These ",
 StyleBox["3D", "MB"],
 " functions were more important in previous versions of ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ".  They are still available, but somewhat obsolete.  All positioning  \
directives now work in three dimensions without the ",
 StyleBox["3D", "MB"],
 " appendage."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],

Cell[TextData[{
 "Some of the directives worked a little differently in older versions of ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ".  For purposes of backward compatibility, ",
 StyleBox["Move", "MB"],
 " has an option that reverts its behavior to conform with previous  \
versions.  See the Help Browser for details.  This option should be used only \
 to support legacy ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " code."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.2 Translate", "Subsection",
 CellTags->{
  "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", "PR2.2.2"}],

Cell[TextData[{
 "This function is the simplest positioning command.  Invoke ",
 StyleBox["Translate", "MB"],
 " with a translation vector of one, two, or three dimensions.  For example,  \
here is a group of three lenses translated by vectors of different  \
dimensions."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"lens1", " ", "=", " ", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"100", ",", "50", ",", "10", ",", "\"\<1-D\>\""}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"lens2", " ", "=", " ", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"100", ",", "50", ",", "10", ",", "\"\<2-D\>\""}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"lens3", " ", "=", " ", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"100", ",", "50", ",", "10", ",", "\"\<3-D\>\""}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Translate", "[", 
        RowBox[{"lens1", ",", 
         RowBox[{"{", "50", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{"lens2", ",", 
         RowBox[{"{", 
          RowBox[{"75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{"lens3", ",", 
         RowBox[{"{", 
          RowBox[{"25", ",", "75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"125", ",", "125", ",", "125"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"PlotLabel", " ", "\[Rule]", " ", "\"\<Top View\>\""}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ShowSystem", "[", 
   RowBox[{"sys", ",", "\[IndentingNewLine]", 
    RowBox[{"PlotType", "\[Rule]", "SideView"}], ",", 
    RowBox[{"PlotLabel", " ", "\[Rule]", " ", "\"\<Side View\>\""}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"},
 CellLabel->"In[47]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{81.42197458095559, 50.}, {85., 50.}, {85., 
      58.33333333333333}, {77.75044883428478, 58.33333333333333}, {
      81.42197458095559, 50.}}], 
     PolygonBox[{{77.75044883428478, 58.33333333333333}, {85., 
      58.33333333333333}, {85., 66.66666666666666}, {75.67375799589206, 
      66.66666666666666}, {77.75044883428478, 58.33333333333333}}], 
     PolygonBox[{{75.67375799589206, 66.66666666666666}, {85., 
      66.66666666666666}, {85., 75.}, {75., 75.}, {75.67375799589206, 
      66.66666666666666}}], 
     PolygonBox[{{75., 75.}, {85., 75.}, {85., 83.33333333333333}, {
      75.67375799589206, 83.33333333333333}, {75., 75.}}], 
     PolygonBox[{{75.67375799589206, 83.33333333333333}, {85., 
      83.33333333333333}, {85., 91.66666666666666}, {77.75044883428478, 
      91.66666666666666}, {75.67375799589206, 83.33333333333333}}], 
     PolygonBox[{{77.75044883428478, 91.66666666666666}, {85., 
      91.66666666666666}, {85., 100.}, {81.42197458095559, 100.}, {
      77.75044883428478, 91.66666666666666}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 50.}, {77.75044883428478, 
       58.33333333333333}, {75.67375799589206, 66.66666666666666}, {75., 
       75.}, {75.67375799589206, 83.33333333333333}, {77.75044883428478, 
       91.66666666666666}, {81.42197458095559, 100.}, {85., 100.}, {85., 
       91.66666666666667}, {85., 83.33333333333334}, {85., 75.}, {85., 
       66.66666666666667}, {85., 58.33333333333334}, {85., 
       50.00000000000001}, {81.42197458095559, 50.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 75.}, {
        77.75044883428478, 75.}, {81.42197458095559, 75.}}], 
       PolygonBox[{{77.75044883428478, 75.}, {85., 75.}, {85., 75.}, {
        75.67375799589206, 75.}, {77.75044883428478, 75.}}], 
       PolygonBox[{{75.67375799589206, 75.}, {85., 75.}, {85., 75.}, {75., 
        75.}, {75.67375799589206, 75.}}], 
       PolygonBox[{{75., 75.}, {85., 75.}, {85., 75.}, {75.67375799589206, 
        75.}, {75., 75.}}], 
       PolygonBox[{{75.67375799589206, 75.}, {85., 75.}, {85., 75.}, {
        77.75044883428478, 75.}, {75.67375799589206, 75.}}], 
       PolygonBox[{{77.75044883428478, 75.}, {85., 75.}, {85., 75.}, {
        81.42197458095559, 75.}, {77.75044883428478, 75.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{81.42197458095559, 75.}, {77.75044883428478, 75.}, {
         75.67375799589206, 75.}, {75., 75.}, {75.67375799589206, 75.}, {
         77.75044883428478, 75.}, {81.42197458095559, 75.}, {85., 75.}, {85., 
         75.}, {85., 75.}, {85., 75.}, {85., 75.}, {85., 75.}, {85., 75.}, {
         81.42197458095559, 75.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 100.}, {85., 100.}, {85., 
       99.1481456572267}, {81.42197458095559, 99.1481456572267}, {
       81.42197458095559, 100.}}], 
      LineBox[{{81.42197458095559, 99.1481456572267}, {85., 
       99.1481456572267}, {85., 96.65063509461098}, {81.42197458095559, 
       96.65063509461098}, {81.42197458095559, 99.1481456572267}}], 
      LineBox[{{81.42197458095559, 96.65063509461098}, {85., 
       96.65063509461098}, {85., 92.67766952966369}, {81.42197458095559, 
       92.67766952966369}, {81.42197458095559, 96.65063509461098}}], 
      LineBox[{{81.42197458095559, 92.67766952966369}, {85., 
       92.67766952966369}, {85., 87.5}, {81.42197458095559, 87.5}, {
       81.42197458095559, 92.67766952966369}}], 
      LineBox[{{81.42197458095559, 87.5}, {85., 87.5}, {85., 
       81.47047612756302}, {81.42197458095559, 81.47047612756302}, {
       81.42197458095559, 87.5}}], 
      LineBox[{{81.42197458095559, 81.47047612756302}, {85., 
       81.47047612756302}, {85., 75.}, {81.42197458095559, 75.}, {
       81.42197458095559, 81.47047612756302}}], 
      LineBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 
       68.52952387243698}, {81.42197458095559, 68.52952387243698}, {
       81.42197458095559, 75.}}], 
      LineBox[{{81.42197458095559, 68.52952387243698}, {85., 
       68.52952387243698}, {85., 62.50000000000001}, {81.42197458095559, 
       62.50000000000001}, {81.42197458095559, 68.52952387243698}}], 
      LineBox[{{81.42197458095559, 62.50000000000001}, {85., 
       62.50000000000001}, {85., 57.32233047033631}, {81.42197458095559, 
       57.32233047033631}, {81.42197458095559, 62.50000000000001}}], 
      LineBox[{{81.42197458095559, 57.32233047033631}, {85., 
       57.32233047033631}, {85., 53.34936490538903}, {81.42197458095559, 
       53.34936490538903}, {81.42197458095559, 57.32233047033631}}], 
      LineBox[{{81.4219745809556, 53.34936490538904}, {85., 
       53.34936490538904}, {85., 50.851854342773294`}, {81.42197458095559, 
       50.851854342773294`}, {81.4219745809556, 53.34936490538904}}], 
      LineBox[{{81.42197458095559, 50.851854342773294`}, {85., 
       50.851854342773294`}, {85., 50.}, {81.42197458095559, 50.}, {
       81.42197458095559, 50.851854342773294`}}], 
      LineBox[{{81.42197458095559, 50.}, {85., 50.}, {85., 
       50.851854342773294`}, {81.42197458095559, 50.851854342773294`}, {
       81.42197458095559, 50.}}], 
      LineBox[{{81.42197458095559, 50.851854342773294`}, {85., 
       50.851854342773294`}, {85., 53.34936490538903}, {81.42197458095559, 
       53.34936490538903}, {81.42197458095559, 50.851854342773294`}}], 
      LineBox[{{81.42197458095559, 53.34936490538903}, {85., 
       53.34936490538903}, {85., 57.32233047033631}, {81.42197458095559, 
       57.32233047033631}, {81.42197458095559, 53.34936490538903}}], 
      LineBox[{{81.42197458095559, 57.322330470336304`}, {85., 
       57.322330470336304`}, {85., 62.499999999999986`}, {81.42197458095559, 
       62.499999999999986`}, {81.42197458095559, 57.322330470336304`}}], 
      LineBox[{{81.42197458095559, 62.499999999999986`}, {85., 
       62.499999999999986`}, {85., 68.52952387243697}, {81.42197458095559, 
       68.52952387243697}, {81.42197458095559, 62.499999999999986`}}], 
      LineBox[{{81.42197458095559, 68.52952387243697}, {85., 
       68.52952387243697}, {85., 74.99999999999997}, {81.42197458095559, 
       74.99999999999997}, {81.42197458095559, 68.52952387243697}}], 
      LineBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 81.470476127563}, {
       81.42197458095559, 81.470476127563}, {81.42197458095559, 75.}}], 
      LineBox[{{81.42197458095559, 81.470476127563}, {85., 81.470476127563}, {
       85., 87.49999999999999}, {81.42197458095559, 87.49999999999999}, {
       81.42197458095559, 81.470476127563}}], 
      LineBox[{{81.42197458095559, 87.49999999999999}, {85., 
       87.49999999999999}, {85., 92.67766952966367}, {81.4219745809556, 
       92.67766952966367}, {81.42197458095559, 87.49999999999999}}], 
      LineBox[{{81.42197458095559, 92.67766952966369}, {85., 
       92.67766952966369}, {85., 96.65063509461096}, {81.42197458095559, 
       96.65063509461096}, {81.42197458095559, 92.67766952966369}}], 
      LineBox[{{81.42197458095559, 96.65063509461096}, {85., 
       96.65063509461096}, {85., 99.1481456572267}, {81.42197458095559, 
       99.1481456572267}, {81.42197458095559, 96.65063509461096}}], 
      LineBox[{{81.42197458095559, 99.1481456572267}, {85., 
       99.1481456572267}, {85., 100.}, {81.42197458095559, 100.}, {
       81.42197458095559, 99.1481456572267}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
      58.33333333333333}, {27.75044883428479, 58.33333333333333}, {
      31.42197458095559, 50.}}], 
     PolygonBox[{{27.75044883428479, 58.33333333333333}, {35., 
      58.33333333333333}, {35., 66.66666666666666}, {25.67375799589206, 
      66.66666666666666}, {27.75044883428479, 58.33333333333333}}], 
     PolygonBox[{{25.67375799589206, 66.66666666666666}, {35., 
      66.66666666666666}, {35., 75.}, {25., 75.}, {25.67375799589206, 
      66.66666666666666}}], 
     PolygonBox[{{25., 75.}, {35., 75.}, {35., 83.33333333333333}, {
      25.67375799589206, 83.33333333333333}, {25., 75.}}], 
     PolygonBox[{{25.67375799589206, 83.33333333333333}, {35., 
      83.33333333333333}, {35., 91.66666666666666}, {27.75044883428479, 
      91.66666666666666}, {25.67375799589206, 83.33333333333333}}], 
     PolygonBox[{{27.75044883428479, 91.66666666666666}, {35., 
      91.66666666666666}, {35., 100.}, {31.42197458095559, 100.}, {
      27.75044883428479, 91.66666666666666}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 50.}, {27.75044883428479, 
       58.33333333333333}, {25.67375799589206, 66.66666666666666}, {25., 
       75.}, {25.67375799589206, 83.33333333333333}, {27.750448834284782`, 
       91.66666666666666}, {31.42197458095559, 100.}, {35., 100.}, {35., 
       91.66666666666667}, {35., 83.33333333333334}, {35., 75.}, {35., 
       66.66666666666667}, {35., 58.33333333333334}, {35., 
       50.00000000000001}, {31.42197458095559, 50.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 75.}, {
        27.75044883428479, 75.}, {31.42197458095559, 75.}}], 
       PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
        25.67375799589206, 75.}, {27.75044883428479, 75.}}], 
       PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {25., 
        75.}, {25.67375799589206, 75.}}], 
       PolygonBox[{{25., 75.}, {35., 75.}, {35., 75.}, {25.67375799589206, 
        75.}, {25., 75.}}], 
       PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {
        27.75044883428479, 75.}, {25.67375799589206, 75.}}], 
       PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
        31.42197458095559, 75.}, {27.75044883428479, 75.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{31.42197458095559, 75.}, {27.75044883428479, 75.}, {
         25.67375799589206, 75.}, {25., 75.}, {25.67375799589206, 75.}, {
         27.750448834284782`, 75.}, {31.42197458095559, 75.}, {35., 75.}, {
         35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 
         75.}, {31.42197458095559, 75.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 100.}, {35., 100.}, {35., 
       99.1481456572267}, {31.42197458095559, 99.1481456572267}, {
       31.42197458095559, 100.}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 96.65063509461098}, {31.42197458095559, 
       96.65063509461098}, {31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 96.65063509461098}, {35., 
       96.65063509461098}, {35., 92.67766952966369}, {31.42197458095559, 
       92.67766952966369}, {31.42197458095559, 96.65063509461098}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 87.5}, {35., 87.5}, {35., 
       81.47047612756302}, {31.42197458095559, 81.47047612756302}, {
       31.42197458095559, 87.5}}], 
      LineBox[{{31.42197458095559, 81.47047612756302}, {35., 
       81.47047612756302}, {35., 75.}, {31.42197458095559, 75.}, {
       31.42197458095559, 81.47047612756302}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       68.52952387243698}, {31.42197458095559, 68.52952387243698}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 68.52952387243698}, {35., 
       68.52952387243698}, {35., 62.50000000000001}, {31.42197458095559, 
       62.50000000000001}, {31.42197458095559, 68.52952387243698}}], 
      LineBox[{{31.42197458095559, 62.50000000000001}, {35., 
       62.50000000000001}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 62.50000000000001}}], 
      LineBox[{{31.42197458095559, 57.32233047033631}, {35., 
       57.32233047033631}, {35., 53.34936490538903}, {31.42197458095559, 
       53.34936490538903}, {31.42197458095559, 57.32233047033631}}], 
      LineBox[{{31.4219745809556, 53.34936490538904}, {35., 
       53.34936490538904}, {35., 50.851854342773294`}, {31.42197458095559, 
       50.851854342773294`}, {31.4219745809556, 53.34936490538904}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 50.}, {31.42197458095559, 50.}, {
       31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
       50.851854342773294`}, {31.42197458095559, 50.851854342773294`}, {
       31.42197458095559, 50.}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 53.34936490538903}, {31.42197458095559, 
       53.34936490538903}, {31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 53.34936490538903}, {35., 
       53.34936490538903}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 53.34936490538903}}], 
      LineBox[{{31.42197458095559, 57.322330470336304`}, {35., 
       57.322330470336304`}, {35., 62.499999999999986`}, {31.42197458095559, 
       62.499999999999986`}, {31.42197458095559, 57.322330470336304`}}], 
      LineBox[{{31.42197458095559, 62.499999999999986`}, {35., 
       62.499999999999986`}, {35., 68.52952387243697}, {31.42197458095559, 
       68.52952387243697}, {31.42197458095559, 62.499999999999986`}}], 
      LineBox[{{31.42197458095559, 68.52952387243697}, {35., 
       68.52952387243697}, {35., 74.99999999999997}, {31.42197458095559, 
       74.99999999999997}, {31.42197458095559, 68.52952387243697}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 81.470476127563}, {
       31.42197458095559, 81.470476127563}, {31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 81.470476127563}, {35., 81.470476127563}, {
       35., 87.49999999999999}, {31.42197458095559, 87.49999999999999}, {
       31.42197458095559, 81.470476127563}}], 
      LineBox[{{31.42197458095559, 87.49999999999999}, {35., 
       87.49999999999999}, {35., 92.67766952966367}, {31.4219745809556, 
       92.67766952966367}, {31.42197458095559, 87.49999999999999}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 96.65063509461096}, {31.42197458095559, 
       96.65063509461096}, {31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 96.65063509461096}, {35., 
       96.65063509461096}, {35., 99.1481456572267}, {31.42197458095559, 
       99.1481456572267}, {31.42197458095559, 96.65063509461096}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 100.}, {31.42197458095559, 100.}, {
       31.42197458095559, 99.1481456572267}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., -50.}, {125., -50.}, {125., 125.}, {125., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {-50., -50.}, {-50., -50.}, {125., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., 125.}, {-50., 
       125.}, {-50., -50.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 125.}, {125., 125.}, {125., 125.}, {-50., 125.}, {-50., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., 125.}, {-50., 125.}, {-50., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., -50.}, {-50., -50.}, {-50., 125.}, {125., 
       125.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"2-D\"\>", {80., 49.}, {0., 0.}], 
    InsetBox["\<\"3-D\"\>", {30., 49.}, {0., 0.}], 
    InsetBox["\<\"1-D\"\>", {55., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotLabel:>FormBox["\"Top View\"", TraditionalForm],
  PlotRange:>All]], "Print",
 CellChangeTimes->{
  3.563366702787591*^9, 3.566086353752675*^9, 3.567272842174737*^9, {
   3.6012868616397448`*^9, 3.601286882493368*^9}, 3.614727105485227*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"},
 CellLabel->"During evaluation of In[47]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, 0.}, {60., 6.123233995736766*^-15}, {60.,
       5.102694996447306*^-15}, {52.75044883428479, 0.}, {56.42197458095559, 
      0.}}], PolygonBox[{{52.75044883428479, 0.}, {60., 
      5.102694996447306*^-15}, {60., 4.0821559971578446`*^-15}, {
      50.67375799589206, 0.}, {52.75044883428479, 0.}}], 
     PolygonBox[{{50.67375799589206, 0.}, {60., 4.0821559971578446`*^-15}, {
      60., 3.061616997868384*^-15}, {50., 0.}, {50.67375799589206, 0.}}], 
     PolygonBox[{{50., 0.}, {60., 3.061616997868383*^-15}, {60., 
      2.0410779985789223`*^-15}, {50.67375799589206, 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 0.}, {60., 2.0410779985789223`*^-15}, {
      60., 1.0205389992894613`*^-15}, {52.75044883428479, 0.}, {
      50.67375799589206, 0.}}], 
     PolygonBox[{{52.75044883428479, 0.}, {60., 1.0205389992894615`*^-15}, {
      60., 5.098616525425841*^-31}, {56.42197458095559, 0.}, {
      52.75044883428479, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
       50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
       52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
       0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       56.42197458095559, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
        60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
        56.42197458095559, -25.}}], 
       PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
        60., -16.66666666666667}, {60., -8.333333333333336}, {
        50.67375799589206, -8.333333333333336}, {
        52.75044883428479, -16.666666666666668`}}], 
       PolygonBox[{{50.67375799589206, -8.333333333333336}, {
        60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
        50.67375799589206, -8.333333333333336}}], 
       PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
        50.67375799589206, 8.333333333333329}, {50., 0.}}], 
       PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
        8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
        16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
       PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
        16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
        24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, -25.}, {
         52.75044883428479, -16.666666666666668`}, {
         50.67375799589206, -8.333333333333336}, {
         50., -3.552713678800501*^-15}, {50.67375799589206, 
         8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
         56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
         16.666666666666668`}, {60., 8.333333333333336}, {60., 
         3.552713678800501*^-15}, {60., -8.333333333333329}, {
         60., -16.666666666666657`}, {60., -24.999999999999993`}, {
         56.42197458095559, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 0.}, {60., 0.}, {60., 
       6.4704761275630185`}, {56.42197458095559, 6.4704761275630185`}, {
       56.42197458095559, 0.}}], 
      LineBox[{{56.42197458095559, 6.4704761275630185`}, {60., 
       6.4704761275630185`}, {60., 12.499999999999998`}, {56.42197458095559, 
       12.499999999999998`}, {56.42197458095559, 6.4704761275630185`}}], 
      LineBox[{{56.42197458095559, 12.499999999999998`}, {60., 
       12.499999999999998`}, {60., 17.677669529663685`}, {56.42197458095559, 
       17.677669529663685`}, {56.42197458095559, 12.499999999999998`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.650635094610966`}, {56.42197458095559, 
       21.650635094610966`}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.650635094610966`}, {60., 
       21.650635094610966`}, {60., 24.148145657226706`}, {56.42197458095559, 
       24.148145657226706`}, {56.42197458095559, 21.650635094610966`}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.499999999999998`}, {56.42197458095559, 
       12.499999999999998`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.4219745809556, 12.500000000000009`}, {60., 
       12.500000000000009`}, {60., 6.470476127563026}, {56.42197458095559, 
       6.470476127563026}, {56.4219745809556, 12.500000000000009`}}], 
      LineBox[{{56.42197458095559, 6.470476127563026}, {60., 
       6.470476127563026}, {60., 3.061616997868383*^-15}, {56.42197458095559, 
       3.061616997868383*^-15}, {56.42197458095559, 6.470476127563026}}], 
      LineBox[{{56.42197458095559, 3.061616997868383*^-15}, {60., 
       3.061616997868383*^-15}, {60., -6.47047612756302}, {
       56.42197458095559, -6.47047612756302}, {56.42197458095559, 
       3.061616997868383*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563009}, {
       60., -6.470476127563009}, {60., -12.499999999999993`}, {
       56.42197458095559, -12.499999999999993`}, {
       56.42197458095559, -6.470476127563009}}], 
      LineBox[{{56.42197458095559, -12.499999999999993`}, {
       60., -12.499999999999993`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999993`}}], 
      LineBox[{{56.42197458095559, -17.677669529663678`}, {
       60., -17.677669529663678`}, {60., -21.65063509461096}, {
       56.42197458095559, -21.65063509461096}, {
       56.42197458095559, -17.677669529663678`}}], 
      LineBox[{{56.42197458095559, -21.65063509461096}, {
       60., -21.65063509461096}, {60., -24.148145657226703`}, {
       56.42197458095559, -24.148145657226703`}, {
       56.42197458095559, -21.65063509461096}}], 
      LineBox[{{56.42197458095559, -24.148145657226703`}, {
       60., -24.148145657226703`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226703`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.14814565722671}, {56.42197458095559, -24.14814565722671}, {
       56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.650635094610976`}, {
       56.42197458095559, -21.650635094610976`}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.650635094610976`}, {
       60., -21.650635094610976`}, {60., -17.67766952966371}, {
       56.4219745809556, -17.67766952966371}, {
       56.42197458095559, -21.650635094610976`}}], 
      LineBox[{{56.42197458095559, -17.677669529663692`}, {
       60., -17.677669529663692`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663692`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563039}, {
       56.42197458095559, -6.470476127563039}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563039}, {
       60., -6.470476127563039}, {60., -2.8327694488239898`*^-14}, {
       56.42197458095559, -2.8327694488239898`*^-14}, {
       56.42197458095559, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{81.42197458095559, 0.}, {85., 6.123233995736766*^-15}, {85.,
       5.102694996447306*^-15}, {77.75044883428478, 0.}, {81.42197458095559, 
      0.}}], PolygonBox[{{77.75044883428478, 0.}, {85., 
      5.102694996447306*^-15}, {85., 4.0821559971578446`*^-15}, {
      75.67375799589206, 0.}, {77.75044883428478, 0.}}], 
     PolygonBox[{{75.67375799589206, 0.}, {85., 4.0821559971578446`*^-15}, {
      85., 3.061616997868384*^-15}, {75., 0.}, {75.67375799589206, 0.}}], 
     PolygonBox[{{75., 0.}, {85., 3.061616997868383*^-15}, {85., 
      2.0410779985789223`*^-15}, {75.67375799589206, 0.}, {75., 0.}}], 
     PolygonBox[{{75.67375799589206, 0.}, {85., 2.0410779985789223`*^-15}, {
      85., 1.0205389992894613`*^-15}, {77.75044883428478, 0.}, {
      75.67375799589206, 0.}}], 
     PolygonBox[{{77.75044883428478, 0.}, {85., 1.0205389992894615`*^-15}, {
      85., 5.098616525425841*^-31}, {81.42197458095559, 0.}, {
      77.75044883428478, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 0.}, {77.75044883428478, 0.}, {
       75.67375799589206, 0.}, {75., 0.}, {75.67375799589206, 0.}, {
       77.75044883428478, 0.}, {81.42197458095559, 0.}, {85., 0.}, {85., 
       0.}, {85., 0.}, {85., 0.}, {85., 0.}, {85., 0.}, {85., 0.}, {
       81.42197458095559, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{81.42197458095559, -25.}, {85., -25.}, {
        85., -16.66666666666667}, {77.75044883428478, -16.666666666666668`}, {
        81.42197458095559, -25.}}], 
       PolygonBox[{{77.75044883428478, -16.666666666666668`}, {
        85., -16.66666666666667}, {85., -8.333333333333336}, {
        75.67375799589206, -8.333333333333336}, {
        77.75044883428478, -16.666666666666668`}}], 
       PolygonBox[{{75.67375799589206, -8.333333333333336}, {
        85., -8.333333333333336}, {85., -7.105427357601002*^-15}, {75., 0.}, {
        75.67375799589206, -8.333333333333336}}], 
       PolygonBox[{{75., 0.}, {85., 0.}, {85., 8.333333333333332}, {
        75.67375799589206, 8.333333333333329}, {75., 0.}}], 
       PolygonBox[{{75.67375799589206, 8.333333333333329}, {85., 
        8.333333333333332}, {85., 16.666666666666664`}, {77.75044883428478, 
        16.666666666666664`}, {75.67375799589206, 8.333333333333329}}], 
       PolygonBox[{{77.75044883428478, 16.666666666666664`}, {85., 
        16.666666666666664`}, {85., 24.999999999999996`}, {81.42197458095559, 
        24.999999999999993`}, {77.75044883428478, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{81.42197458095559, -25.}, {
         77.75044883428478, -16.666666666666668`}, {
         75.67375799589206, -8.333333333333336}, {
         75., -3.552713678800501*^-15}, {75.67375799589206, 
         8.333333333333329}, {77.75044883428478, 16.666666666666657`}, {
         81.42197458095559, 24.999999999999993`}, {85., 25.}, {85., 
         16.666666666666668`}, {85., 8.333333333333336}, {85., 
         3.552713678800501*^-15}, {85., -8.333333333333329}, {
         85., -16.666666666666657`}, {85., -24.999999999999993`}, {
         81.42197458095559, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 0.}, {85., 0.}, {85., 
       6.4704761275630185`}, {81.42197458095559, 6.4704761275630185`}, {
       81.42197458095559, 0.}}], 
      LineBox[{{81.42197458095559, 6.4704761275630185`}, {85., 
       6.4704761275630185`}, {85., 12.499999999999998`}, {81.42197458095559, 
       12.499999999999998`}, {81.42197458095559, 6.4704761275630185`}}], 
      LineBox[{{81.42197458095559, 12.499999999999998`}, {85., 
       12.499999999999998`}, {85., 17.677669529663685`}, {81.42197458095559, 
       17.677669529663685`}, {81.42197458095559, 12.499999999999998`}}], 
      LineBox[{{81.42197458095559, 17.677669529663685`}, {85., 
       17.677669529663685`}, {85., 21.650635094610966`}, {81.42197458095559, 
       21.650635094610966`}, {81.42197458095559, 17.677669529663685`}}], 
      LineBox[{{81.42197458095559, 21.650635094610966`}, {85., 
       21.650635094610966`}, {85., 24.148145657226706`}, {81.42197458095559, 
       24.148145657226706`}, {81.42197458095559, 21.650635094610966`}}], 
      LineBox[{{81.42197458095559, 24.148145657226706`}, {85., 
       24.148145657226706`}, {85., 25.}, {81.42197458095559, 25.}, {
       81.42197458095559, 24.148145657226706`}}], 
      LineBox[{{81.42197458095559, 25.}, {85., 25.}, {85., 
       24.148145657226706`}, {81.42197458095559, 24.148145657226706`}, {
       81.42197458095559, 25.}}], 
      LineBox[{{81.42197458095559, 24.148145657226706`}, {85., 
       24.148145657226706`}, {85., 21.65063509461097}, {81.42197458095559, 
       21.65063509461097}, {81.42197458095559, 24.148145657226706`}}], 
      LineBox[{{81.42197458095559, 21.65063509461097}, {85., 
       21.65063509461097}, {85., 17.67766952966369}, {81.42197458095559, 
       17.67766952966369}, {81.42197458095559, 21.65063509461097}}], 
      LineBox[{{81.42197458095559, 17.67766952966369}, {85., 
       17.67766952966369}, {85., 12.499999999999998`}, {81.42197458095559, 
       12.499999999999998`}, {81.42197458095559, 17.67766952966369}}], 
      LineBox[{{81.4219745809556, 12.500000000000009`}, {85., 
       12.500000000000009`}, {85., 6.470476127563026}, {81.42197458095559, 
       6.470476127563026}, {81.4219745809556, 12.500000000000009`}}], 
      LineBox[{{81.42197458095559, 6.470476127563026}, {85., 
       6.470476127563026}, {85., 3.061616997868383*^-15}, {81.42197458095559, 
       3.061616997868383*^-15}, {81.42197458095559, 6.470476127563026}}], 
      LineBox[{{81.42197458095559, 3.061616997868383*^-15}, {85., 
       3.061616997868383*^-15}, {85., -6.47047612756302}, {
       81.42197458095559, -6.47047612756302}, {81.42197458095559, 
       3.061616997868383*^-15}}], 
      LineBox[{{81.42197458095559, -6.470476127563009}, {
       85., -6.470476127563009}, {85., -12.499999999999993`}, {
       81.42197458095559, -12.499999999999993`}, {
       81.42197458095559, -6.470476127563009}}], 
      LineBox[{{81.42197458095559, -12.499999999999993`}, {
       85., -12.499999999999993`}, {85., -17.677669529663685`}, {
       81.42197458095559, -17.677669529663685`}, {
       81.42197458095559, -12.499999999999993`}}], 
      LineBox[{{81.42197458095559, -17.677669529663678`}, {
       85., -17.677669529663678`}, {85., -21.65063509461096}, {
       81.42197458095559, -21.65063509461096}, {
       81.42197458095559, -17.677669529663678`}}], 
      LineBox[{{81.42197458095559, -21.65063509461096}, {
       85., -21.65063509461096}, {85., -24.148145657226703`}, {
       81.42197458095559, -24.148145657226703`}, {
       81.42197458095559, -21.65063509461096}}], 
      LineBox[{{81.42197458095559, -24.148145657226703`}, {
       85., -24.148145657226703`}, {85., -25.}, {81.42197458095559, -25.}, {
       81.42197458095559, -24.148145657226703`}}], 
      LineBox[{{81.42197458095559, -25.}, {85., -25.}, {
       85., -24.14814565722671}, {81.42197458095559, -24.14814565722671}, {
       81.42197458095559, -25.}}], 
      LineBox[{{81.42197458095559, -24.14814565722671}, {
       85., -24.14814565722671}, {85., -21.650635094610976`}, {
       81.42197458095559, -21.650635094610976`}, {
       81.42197458095559, -24.14814565722671}}], 
      LineBox[{{81.42197458095559, -21.650635094610976`}, {
       85., -21.650635094610976`}, {85., -17.67766952966371}, {
       81.4219745809556, -17.67766952966371}, {
       81.42197458095559, -21.650635094610976`}}], 
      LineBox[{{81.42197458095559, -17.677669529663692`}, {
       85., -17.677669529663692`}, {85., -12.50000000000001}, {
       81.42197458095559, -12.50000000000001}, {
       81.42197458095559, -17.677669529663692`}}], 
      LineBox[{{81.42197458095559, -12.50000000000001}, {
       85., -12.50000000000001}, {85., -6.470476127563039}, {
       81.42197458095559, -6.470476127563039}, {
       81.42197458095559, -12.50000000000001}}], 
      LineBox[{{81.42197458095559, -6.470476127563039}, {
       85., -6.470476127563039}, {85., -2.8327694488239898`*^-14}, {
       81.42197458095559, -2.8327694488239898`*^-14}, {
       81.42197458095559, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 75.}, {
      27.75044883428479, 75.}, {31.42197458095559, 75.}}], 
     PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
      25.67375799589206, 75.}, {27.75044883428479, 75.}}], 
     PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {25., 
      75.}, {25.67375799589206, 75.}}], 
     PolygonBox[{{25., 75.}, {35., 75.}, {35., 75.}, {25.67375799589206, 
      75.}, {25., 75.}}], 
     PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {
      27.75044883428479, 75.}, {25.67375799589206, 75.}}], 
     PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
      31.42197458095559, 75.}, {27.75044883428479, 75.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 75.}, {27.75044883428479, 75.}, {
       25.67375799589206, 75.}, {25., 75.}, {25.67375799589206, 75.}, {
       27.750448834284782`, 75.}, {31.42197458095559, 75.}, {35., 75.}, {35., 
       75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {
       31.42197458095559, 75.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
        58.33333333333333}, {27.75044883428479, 58.33333333333333}, {
        31.42197458095559, 50.}}], 
       PolygonBox[{{27.75044883428479, 58.33333333333333}, {35., 
        58.33333333333333}, {35., 66.66666666666666}, {25.67375799589206, 
        66.66666666666666}, {27.75044883428479, 58.33333333333333}}], 
       PolygonBox[{{25.67375799589206, 66.66666666666666}, {35., 
        66.66666666666666}, {35., 75.}, {25., 75.}, {25.67375799589206, 
        66.66666666666666}}], 
       PolygonBox[{{25., 75.}, {35., 75.}, {35., 83.33333333333333}, {
        25.67375799589206, 83.33333333333333}, {25., 75.}}], 
       PolygonBox[{{25.67375799589206, 83.33333333333333}, {35., 
        83.33333333333333}, {35., 91.66666666666666}, {27.75044883428479, 
        91.66666666666666}, {25.67375799589206, 83.33333333333333}}], 
       PolygonBox[{{27.75044883428479, 91.66666666666666}, {35., 
        91.66666666666666}, {35., 100.}, {31.42197458095559, 100.}, {
        27.75044883428479, 91.66666666666666}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{31.42197458095559, 50.}, {27.75044883428479, 
         58.33333333333333}, {25.67375799589206, 66.66666666666666}, {25., 
         75.}, {25.67375799589206, 83.33333333333333}, {27.750448834284782`, 
         91.66666666666666}, {31.42197458095559, 100.}, {35., 100.}, {35., 
         91.66666666666667}, {35., 83.33333333333334}, {35., 75.}, {35., 
         66.66666666666667}, {35., 58.33333333333334}, {35., 
         50.00000000000001}, {31.42197458095559, 50.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       81.47047612756302}, {31.42197458095559, 81.47047612756302}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 81.47047612756302}, {35., 
       81.47047612756302}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 81.47047612756302}}], 
      LineBox[{{31.42197458095559, 87.5}, {35., 87.5}, {35., 
       92.67766952966369}, {31.42197458095559, 92.67766952966369}, {
       31.42197458095559, 87.5}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 96.65063509461096}, {31.42197458095559, 
       96.65063509461096}, {31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 96.65063509461096}, {35., 
       96.65063509461096}, {35., 99.1481456572267}, {31.42197458095559, 
       99.1481456572267}, {31.42197458095559, 96.65063509461096}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 100.}, {31.42197458095559, 100.}, {
       31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 100.}, {35., 100.}, {35., 
       99.1481456572267}, {31.42197458095559, 99.1481456572267}, {
       31.42197458095559, 100.}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 96.65063509461098}, {31.42197458095559, 
       96.65063509461098}, {31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 96.65063509461098}, {35., 
       96.65063509461098}, {35., 92.67766952966369}, {31.42197458095559, 
       92.67766952966369}, {31.42197458095559, 96.65063509461098}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.4219745809556, 87.50000000000001}, {35., 
       87.50000000000001}, {35., 81.47047612756303}, {31.42197458095559, 
       81.47047612756303}, {31.4219745809556, 87.50000000000001}}], 
      LineBox[{{31.42197458095559, 81.47047612756303}, {35., 
       81.47047612756303}, {35., 75.}, {31.42197458095559, 75.}, {
       31.42197458095559, 81.47047612756303}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       68.52952387243698}, {31.42197458095559, 68.52952387243698}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 68.529523872437}, {35., 68.529523872437}, {
       35., 62.50000000000001}, {31.42197458095559, 62.50000000000001}, {
       31.42197458095559, 68.529523872437}}], 
      LineBox[{{31.42197458095559, 62.50000000000001}, {35., 
       62.50000000000001}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 62.50000000000001}}], 
      LineBox[{{31.42197458095559, 57.322330470336325`}, {35., 
       57.322330470336325`}, {35., 53.34936490538904}, {31.42197458095559, 
       53.34936490538904}, {31.42197458095559, 57.322330470336325`}}], 
      LineBox[{{31.42197458095559, 53.34936490538904}, {35., 
       53.34936490538904}, {35., 50.851854342773294`}, {31.42197458095559, 
       50.851854342773294`}, {31.42197458095559, 53.34936490538904}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 50.}, {31.42197458095559, 50.}, {
       31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
       50.851854342773294`}, {31.42197458095559, 50.851854342773294`}, {
       31.42197458095559, 50.}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 53.349364905389024`}, {31.42197458095559, 
       53.349364905389024`}, {31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 53.349364905389024`}, {35., 
       53.349364905389024`}, {35., 57.32233047033629}, {31.4219745809556, 
       57.32233047033629}, {31.42197458095559, 53.349364905389024`}}], 
      LineBox[{{31.42197458095559, 57.32233047033631}, {35., 
       57.32233047033631}, {35., 62.499999999999986`}, {31.42197458095559, 
       62.499999999999986`}, {31.42197458095559, 57.32233047033631}}], 
      LineBox[{{31.42197458095559, 62.499999999999986`}, {35., 
       62.499999999999986`}, {35., 68.52952387243695}, {31.42197458095559, 
       68.52952387243695}, {31.42197458095559, 62.499999999999986`}}], 
      LineBox[{{31.42197458095559, 68.52952387243695}, {35., 
       68.52952387243695}, {35., 74.99999999999997}, {31.42197458095559, 
       74.99999999999997}, {31.42197458095559, 68.52952387243695}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., -50.}, {125., 125.}, {125., 125.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {-50., -50.}, {-50., 125.}, {125., 125.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., -50.}, {-50., 125.}, {-50., 
       125.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {125., -50.}, {125., 125.}, {-50., 
       125.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., -50.}, {-50., -50.}, {-50., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., 125.}, {-50., 125.}, {-50., 125.}, {125., 
       125.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"2-D\"\>", {80., -26.}, {0., 0.}], 
    InsetBox["\<\"3-D\"\>", {30., 49.}, {0., 0.}], 
    InsetBox["\<\"1-D\"\>", {55., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotLabel:>FormBox["\"Side View\"", TraditionalForm],
  PlotRange:>All]], "Print",
 CellChangeTimes->{
  3.563366702787591*^9, 3.566086353752675*^9, 3.567272842174737*^9, {
   3.6012868616397448`*^9, 3.601286882493368*^9}, 3.6147271055647*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"},
 CellLabel->"During evaluation of In[47]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Translate", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 " works in one, two, and three dimensions."
}], "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],

Cell[TextData[{
 "The one-dimensional version works equally well sans vector notation.  So  \
instead of ",
 StyleBox["Translate[lens1,{50}]", "MB"],
 ", you could enter ",
 StyleBox["Translate[lens1,50]", "MB"],
 " without the curly braces.  The two- and three-dimensional versions do  \
require vector notation."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],

Cell[TextData[{
 StyleBox["Translate", "MB"],
 " does not affect orientation.  If you need to place a component with a  \
certain orientation, it is possible to combine ",
 StyleBox["Translate", "MB"],
 " with ",
 StyleBox["Rotate", "MB"],
 ", but you may wish to employ a different function having unified  \
capability.  Rarely in ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " will you need to perform manually computed rotations."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.3 Move", "Subsection",
 CellTags->{
  "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}],

Cell[TextData[{
 StyleBox["Move", "MB"],
 " is the most general component placement function.  It may be called in  \
many different ways to accomplish different placements.  A primary purpose of \
 ",
 StyleBox["Move", "MB"],
 " is simple translational motion.  The translation can be one-, two-, or  \
three-dimensional.  All three cases are illustrated below in both plan and  \
elevation views."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{"lens1", ",", "50"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Move", "[", 
        RowBox[{"lens2", ",", 
         RowBox[{"{", 
          RowBox[{"75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Move", "[", 
        RowBox[{"lens3", ",", 
         RowBox[{"{", 
          RowBox[{"25", ",", "75", ",", "75"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}], ",", 
           RowBox[{"-", "50"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"125", ",", "125", ",", "125"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"PlotLabel", " ", "\[Rule]", " ", "\"\<Top View\>\""}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ShowSystem", "[", 
   RowBox[{"sys", ",", "\[IndentingNewLine]", 
    RowBox[{"PlotType", "\[Rule]", "SideView"}], ",", 
    RowBox[{"PlotLabel", " ", "\[Rule]", " ", "\"\<Side View\>\""}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"},
 CellLabel->"In[52]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{81.42197458095559, 50.}, {85., 50.}, {85., 
      58.33333333333333}, {77.75044883428478, 58.33333333333333}, {
      81.42197458095559, 50.}}], 
     PolygonBox[{{77.75044883428478, 58.33333333333333}, {85., 
      58.33333333333333}, {85., 66.66666666666666}, {75.67375799589206, 
      66.66666666666666}, {77.75044883428478, 58.33333333333333}}], 
     PolygonBox[{{75.67375799589206, 66.66666666666666}, {85., 
      66.66666666666666}, {85., 75.}, {75., 75.}, {75.67375799589206, 
      66.66666666666666}}], 
     PolygonBox[{{75., 75.}, {85., 75.}, {85., 83.33333333333333}, {
      75.67375799589206, 83.33333333333333}, {75., 75.}}], 
     PolygonBox[{{75.67375799589206, 83.33333333333333}, {85., 
      83.33333333333333}, {85., 91.66666666666666}, {77.75044883428478, 
      91.66666666666666}, {75.67375799589206, 83.33333333333333}}], 
     PolygonBox[{{77.75044883428478, 91.66666666666666}, {85., 
      91.66666666666666}, {85., 100.}, {81.42197458095559, 100.}, {
      77.75044883428478, 91.66666666666666}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 50.}, {77.75044883428478, 
       58.33333333333333}, {75.67375799589206, 66.66666666666666}, {75., 
       75.}, {75.67375799589206, 83.33333333333333}, {77.75044883428478, 
       91.66666666666666}, {81.42197458095559, 100.}, {85., 100.}, {85., 
       91.66666666666667}, {85., 83.33333333333334}, {85., 75.}, {85., 
       66.66666666666667}, {85., 58.33333333333334}, {85., 
       50.00000000000001}, {81.42197458095559, 50.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 75.}, {
        77.75044883428478, 75.}, {81.42197458095559, 75.}}], 
       PolygonBox[{{77.75044883428478, 75.}, {85., 75.}, {85., 75.}, {
        75.67375799589206, 75.}, {77.75044883428478, 75.}}], 
       PolygonBox[{{75.67375799589206, 75.}, {85., 75.}, {85., 75.}, {75., 
        75.}, {75.67375799589206, 75.}}], 
       PolygonBox[{{75., 75.}, {85., 75.}, {85., 75.}, {75.67375799589206, 
        75.}, {75., 75.}}], 
       PolygonBox[{{75.67375799589206, 75.}, {85., 75.}, {85., 75.}, {
        77.75044883428478, 75.}, {75.67375799589206, 75.}}], 
       PolygonBox[{{77.75044883428478, 75.}, {85., 75.}, {85., 75.}, {
        81.42197458095559, 75.}, {77.75044883428478, 75.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{81.42197458095559, 75.}, {77.75044883428478, 75.}, {
         75.67375799589206, 75.}, {75., 75.}, {75.67375799589206, 75.}, {
         77.75044883428478, 75.}, {81.42197458095559, 75.}, {85., 75.}, {85., 
         75.}, {85., 75.}, {85., 75.}, {85., 75.}, {85., 75.}, {85., 75.}, {
         81.42197458095559, 75.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 100.}, {85., 100.}, {85., 
       99.1481456572267}, {81.42197458095559, 99.1481456572267}, {
       81.42197458095559, 100.}}], 
      LineBox[{{81.42197458095559, 99.1481456572267}, {85., 
       99.1481456572267}, {85., 96.65063509461098}, {81.42197458095559, 
       96.65063509461098}, {81.42197458095559, 99.1481456572267}}], 
      LineBox[{{81.42197458095559, 96.65063509461098}, {85., 
       96.65063509461098}, {85., 92.67766952966369}, {81.42197458095559, 
       92.67766952966369}, {81.42197458095559, 96.65063509461098}}], 
      LineBox[{{81.42197458095559, 92.67766952966369}, {85., 
       92.67766952966369}, {85., 87.5}, {81.42197458095559, 87.5}, {
       81.42197458095559, 92.67766952966369}}], 
      LineBox[{{81.42197458095559, 87.5}, {85., 87.5}, {85., 
       81.47047612756302}, {81.42197458095559, 81.47047612756302}, {
       81.42197458095559, 87.5}}], 
      LineBox[{{81.42197458095559, 81.47047612756302}, {85., 
       81.47047612756302}, {85., 75.}, {81.42197458095559, 75.}, {
       81.42197458095559, 81.47047612756302}}], 
      LineBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 
       68.52952387243698}, {81.42197458095559, 68.52952387243698}, {
       81.42197458095559, 75.}}], 
      LineBox[{{81.42197458095559, 68.52952387243698}, {85., 
       68.52952387243698}, {85., 62.50000000000001}, {81.42197458095559, 
       62.50000000000001}, {81.42197458095559, 68.52952387243698}}], 
      LineBox[{{81.42197458095559, 62.50000000000001}, {85., 
       62.50000000000001}, {85., 57.32233047033631}, {81.42197458095559, 
       57.32233047033631}, {81.42197458095559, 62.50000000000001}}], 
      LineBox[{{81.42197458095559, 57.32233047033631}, {85., 
       57.32233047033631}, {85., 53.34936490538903}, {81.42197458095559, 
       53.34936490538903}, {81.42197458095559, 57.32233047033631}}], 
      LineBox[{{81.4219745809556, 53.34936490538904}, {85., 
       53.34936490538904}, {85., 50.851854342773294`}, {81.42197458095559, 
       50.851854342773294`}, {81.4219745809556, 53.34936490538904}}], 
      LineBox[{{81.42197458095559, 50.851854342773294`}, {85., 
       50.851854342773294`}, {85., 50.}, {81.42197458095559, 50.}, {
       81.42197458095559, 50.851854342773294`}}], 
      LineBox[{{81.42197458095559, 50.}, {85., 50.}, {85., 
       50.851854342773294`}, {81.42197458095559, 50.851854342773294`}, {
       81.42197458095559, 50.}}], 
      LineBox[{{81.42197458095559, 50.851854342773294`}, {85., 
       50.851854342773294`}, {85., 53.34936490538903}, {81.42197458095559, 
       53.34936490538903}, {81.42197458095559, 50.851854342773294`}}], 
      LineBox[{{81.42197458095559, 53.34936490538903}, {85., 
       53.34936490538903}, {85., 57.32233047033631}, {81.42197458095559, 
       57.32233047033631}, {81.42197458095559, 53.34936490538903}}], 
      LineBox[{{81.42197458095559, 57.322330470336304`}, {85., 
       57.322330470336304`}, {85., 62.499999999999986`}, {81.42197458095559, 
       62.499999999999986`}, {81.42197458095559, 57.322330470336304`}}], 
      LineBox[{{81.42197458095559, 62.499999999999986`}, {85., 
       62.499999999999986`}, {85., 68.52952387243697}, {81.42197458095559, 
       68.52952387243697}, {81.42197458095559, 62.499999999999986`}}], 
      LineBox[{{81.42197458095559, 68.52952387243697}, {85., 
       68.52952387243697}, {85., 74.99999999999997}, {81.42197458095559, 
       74.99999999999997}, {81.42197458095559, 68.52952387243697}}], 
      LineBox[{{81.42197458095559, 75.}, {85., 75.}, {85., 81.470476127563}, {
       81.42197458095559, 81.470476127563}, {81.42197458095559, 75.}}], 
      LineBox[{{81.42197458095559, 81.470476127563}, {85., 81.470476127563}, {
       85., 87.49999999999999}, {81.42197458095559, 87.49999999999999}, {
       81.42197458095559, 81.470476127563}}], 
      LineBox[{{81.42197458095559, 87.49999999999999}, {85., 
       87.49999999999999}, {85., 92.67766952966367}, {81.4219745809556, 
       92.67766952966367}, {81.42197458095559, 87.49999999999999}}], 
      LineBox[{{81.42197458095559, 92.67766952966369}, {85., 
       92.67766952966369}, {85., 96.65063509461096}, {81.42197458095559, 
       96.65063509461096}, {81.42197458095559, 92.67766952966369}}], 
      LineBox[{{81.42197458095559, 96.65063509461096}, {85., 
       96.65063509461096}, {85., 99.1481456572267}, {81.42197458095559, 
       99.1481456572267}, {81.42197458095559, 96.65063509461096}}], 
      LineBox[{{81.42197458095559, 99.1481456572267}, {85., 
       99.1481456572267}, {85., 100.}, {81.42197458095559, 100.}, {
       81.42197458095559, 99.1481456572267}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
      58.33333333333333}, {27.75044883428479, 58.33333333333333}, {
      31.42197458095559, 50.}}], 
     PolygonBox[{{27.75044883428479, 58.33333333333333}, {35., 
      58.33333333333333}, {35., 66.66666666666666}, {25.67375799589206, 
      66.66666666666666}, {27.75044883428479, 58.33333333333333}}], 
     PolygonBox[{{25.67375799589206, 66.66666666666666}, {35., 
      66.66666666666666}, {35., 75.}, {25., 75.}, {25.67375799589206, 
      66.66666666666666}}], 
     PolygonBox[{{25., 75.}, {35., 75.}, {35., 83.33333333333333}, {
      25.67375799589206, 83.33333333333333}, {25., 75.}}], 
     PolygonBox[{{25.67375799589206, 83.33333333333333}, {35., 
      83.33333333333333}, {35., 91.66666666666666}, {27.75044883428479, 
      91.66666666666666}, {25.67375799589206, 83.33333333333333}}], 
     PolygonBox[{{27.75044883428479, 91.66666666666666}, {35., 
      91.66666666666666}, {35., 100.}, {31.42197458095559, 100.}, {
      27.75044883428479, 91.66666666666666}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 50.}, {27.75044883428479, 
       58.33333333333333}, {25.67375799589206, 66.66666666666666}, {25., 
       75.}, {25.67375799589206, 83.33333333333333}, {27.750448834284782`, 
       91.66666666666666}, {31.42197458095559, 100.}, {35., 100.}, {35., 
       91.66666666666667}, {35., 83.33333333333334}, {35., 75.}, {35., 
       66.66666666666667}, {35., 58.33333333333334}, {35., 
       50.00000000000001}, {31.42197458095559, 50.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 75.}, {
        27.75044883428479, 75.}, {31.42197458095559, 75.}}], 
       PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
        25.67375799589206, 75.}, {27.75044883428479, 75.}}], 
       PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {25., 
        75.}, {25.67375799589206, 75.}}], 
       PolygonBox[{{25., 75.}, {35., 75.}, {35., 75.}, {25.67375799589206, 
        75.}, {25., 75.}}], 
       PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {
        27.75044883428479, 75.}, {25.67375799589206, 75.}}], 
       PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
        31.42197458095559, 75.}, {27.75044883428479, 75.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{31.42197458095559, 75.}, {27.75044883428479, 75.}, {
         25.67375799589206, 75.}, {25., 75.}, {25.67375799589206, 75.}, {
         27.750448834284782`, 75.}, {31.42197458095559, 75.}, {35., 75.}, {
         35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 
         75.}, {31.42197458095559, 75.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 100.}, {35., 100.}, {35., 
       99.1481456572267}, {31.42197458095559, 99.1481456572267}, {
       31.42197458095559, 100.}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 96.65063509461098}, {31.42197458095559, 
       96.65063509461098}, {31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 96.65063509461098}, {35., 
       96.65063509461098}, {35., 92.67766952966369}, {31.42197458095559, 
       92.67766952966369}, {31.42197458095559, 96.65063509461098}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 87.5}, {35., 87.5}, {35., 
       81.47047612756302}, {31.42197458095559, 81.47047612756302}, {
       31.42197458095559, 87.5}}], 
      LineBox[{{31.42197458095559, 81.47047612756302}, {35., 
       81.47047612756302}, {35., 75.}, {31.42197458095559, 75.}, {
       31.42197458095559, 81.47047612756302}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       68.52952387243698}, {31.42197458095559, 68.52952387243698}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 68.52952387243698}, {35., 
       68.52952387243698}, {35., 62.50000000000001}, {31.42197458095559, 
       62.50000000000001}, {31.42197458095559, 68.52952387243698}}], 
      LineBox[{{31.42197458095559, 62.50000000000001}, {35., 
       62.50000000000001}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 62.50000000000001}}], 
      LineBox[{{31.42197458095559, 57.32233047033631}, {35., 
       57.32233047033631}, {35., 53.34936490538903}, {31.42197458095559, 
       53.34936490538903}, {31.42197458095559, 57.32233047033631}}], 
      LineBox[{{31.4219745809556, 53.34936490538904}, {35., 
       53.34936490538904}, {35., 50.851854342773294`}, {31.42197458095559, 
       50.851854342773294`}, {31.4219745809556, 53.34936490538904}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 50.}, {31.42197458095559, 50.}, {
       31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
       50.851854342773294`}, {31.42197458095559, 50.851854342773294`}, {
       31.42197458095559, 50.}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 53.34936490538903}, {31.42197458095559, 
       53.34936490538903}, {31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 53.34936490538903}, {35., 
       53.34936490538903}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 53.34936490538903}}], 
      LineBox[{{31.42197458095559, 57.322330470336304`}, {35., 
       57.322330470336304`}, {35., 62.499999999999986`}, {31.42197458095559, 
       62.499999999999986`}, {31.42197458095559, 57.322330470336304`}}], 
      LineBox[{{31.42197458095559, 62.499999999999986`}, {35., 
       62.499999999999986`}, {35., 68.52952387243697}, {31.42197458095559, 
       68.52952387243697}, {31.42197458095559, 62.499999999999986`}}], 
      LineBox[{{31.42197458095559, 68.52952387243697}, {35., 
       68.52952387243697}, {35., 74.99999999999997}, {31.42197458095559, 
       74.99999999999997}, {31.42197458095559, 68.52952387243697}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 81.470476127563}, {
       31.42197458095559, 81.470476127563}, {31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 81.470476127563}, {35., 81.470476127563}, {
       35., 87.49999999999999}, {31.42197458095559, 87.49999999999999}, {
       31.42197458095559, 81.470476127563}}], 
      LineBox[{{31.42197458095559, 87.49999999999999}, {35., 
       87.49999999999999}, {35., 92.67766952966367}, {31.4219745809556, 
       92.67766952966367}, {31.42197458095559, 87.49999999999999}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 96.65063509461096}, {31.42197458095559, 
       96.65063509461096}, {31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 96.65063509461096}, {35., 
       96.65063509461096}, {35., 99.1481456572267}, {31.42197458095559, 
       99.1481456572267}, {31.42197458095559, 96.65063509461096}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 100.}, {31.42197458095559, 100.}, {
       31.42197458095559, 99.1481456572267}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., -50.}, {125., -50.}, {125., 125.}, {125., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {-50., -50.}, {-50., -50.}, {125., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., 125.}, {-50., 
       125.}, {-50., -50.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 125.}, {125., 125.}, {125., 125.}, {-50., 125.}, {-50., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., 125.}, {-50., 125.}, {-50., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., -50.}, {-50., -50.}, {-50., 125.}, {125., 
       125.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"2-D\"\>", {80., 49.}, {0., 0.}], 
    InsetBox["\<\"3-D\"\>", {30., 49.}, {0., 0.}], 
    InsetBox["\<\"1-D\"\>", {55., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotLabel:>FormBox["\"Top View\"", TraditionalForm],
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563366716162716*^9, 3.566086362294907*^9, 
  3.567272843112973*^9, 3.601286891146948*^9, 3.61472710592572*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"},
 CellLabel->"During evaluation of In[52]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, 0.}, {60., 6.123233995736766*^-15}, {60.,
       5.102694996447306*^-15}, {52.75044883428479, 0.}, {56.42197458095559, 
      0.}}], PolygonBox[{{52.75044883428479, 0.}, {60., 
      5.102694996447306*^-15}, {60., 4.0821559971578446`*^-15}, {
      50.67375799589206, 0.}, {52.75044883428479, 0.}}], 
     PolygonBox[{{50.67375799589206, 0.}, {60., 4.0821559971578446`*^-15}, {
      60., 3.061616997868384*^-15}, {50., 0.}, {50.67375799589206, 0.}}], 
     PolygonBox[{{50., 0.}, {60., 3.061616997868383*^-15}, {60., 
      2.0410779985789223`*^-15}, {50.67375799589206, 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 0.}, {60., 2.0410779985789223`*^-15}, {
      60., 1.0205389992894613`*^-15}, {52.75044883428479, 0.}, {
      50.67375799589206, 0.}}], 
     PolygonBox[{{52.75044883428479, 0.}, {60., 1.0205389992894615`*^-15}, {
      60., 5.098616525425841*^-31}, {56.42197458095559, 0.}, {
      52.75044883428479, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
       50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
       52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
       0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       56.42197458095559, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
        60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
        56.42197458095559, -25.}}], 
       PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
        60., -16.66666666666667}, {60., -8.333333333333336}, {
        50.67375799589206, -8.333333333333336}, {
        52.75044883428479, -16.666666666666668`}}], 
       PolygonBox[{{50.67375799589206, -8.333333333333336}, {
        60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
        50.67375799589206, -8.333333333333336}}], 
       PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
        50.67375799589206, 8.333333333333329}, {50., 0.}}], 
       PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
        8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
        16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
       PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
        16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
        24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, -25.}, {
         52.75044883428479, -16.666666666666668`}, {
         50.67375799589206, -8.333333333333336}, {
         50., -3.552713678800501*^-15}, {50.67375799589206, 
         8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
         56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
         16.666666666666668`}, {60., 8.333333333333336}, {60., 
         3.552713678800501*^-15}, {60., -8.333333333333329}, {
         60., -16.666666666666657`}, {60., -24.999999999999993`}, {
         56.42197458095559, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 0.}, {60., 0.}, {60., 
       6.4704761275630185`}, {56.42197458095559, 6.4704761275630185`}, {
       56.42197458095559, 0.}}], 
      LineBox[{{56.42197458095559, 6.4704761275630185`}, {60., 
       6.4704761275630185`}, {60., 12.499999999999998`}, {56.42197458095559, 
       12.499999999999998`}, {56.42197458095559, 6.4704761275630185`}}], 
      LineBox[{{56.42197458095559, 12.499999999999998`}, {60., 
       12.499999999999998`}, {60., 17.677669529663685`}, {56.42197458095559, 
       17.677669529663685`}, {56.42197458095559, 12.499999999999998`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.650635094610966`}, {56.42197458095559, 
       21.650635094610966`}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.650635094610966`}, {60., 
       21.650635094610966`}, {60., 24.148145657226706`}, {56.42197458095559, 
       24.148145657226706`}, {56.42197458095559, 21.650635094610966`}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.499999999999998`}, {56.42197458095559, 
       12.499999999999998`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.4219745809556, 12.500000000000009`}, {60., 
       12.500000000000009`}, {60., 6.470476127563026}, {56.42197458095559, 
       6.470476127563026}, {56.4219745809556, 12.500000000000009`}}], 
      LineBox[{{56.42197458095559, 6.470476127563026}, {60., 
       6.470476127563026}, {60., 3.061616997868383*^-15}, {56.42197458095559, 
       3.061616997868383*^-15}, {56.42197458095559, 6.470476127563026}}], 
      LineBox[{{56.42197458095559, 3.061616997868383*^-15}, {60., 
       3.061616997868383*^-15}, {60., -6.47047612756302}, {
       56.42197458095559, -6.47047612756302}, {56.42197458095559, 
       3.061616997868383*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563009}, {
       60., -6.470476127563009}, {60., -12.499999999999993`}, {
       56.42197458095559, -12.499999999999993`}, {
       56.42197458095559, -6.470476127563009}}], 
      LineBox[{{56.42197458095559, -12.499999999999993`}, {
       60., -12.499999999999993`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999993`}}], 
      LineBox[{{56.42197458095559, -17.677669529663678`}, {
       60., -17.677669529663678`}, {60., -21.65063509461096}, {
       56.42197458095559, -21.65063509461096}, {
       56.42197458095559, -17.677669529663678`}}], 
      LineBox[{{56.42197458095559, -21.65063509461096}, {
       60., -21.65063509461096}, {60., -24.148145657226703`}, {
       56.42197458095559, -24.148145657226703`}, {
       56.42197458095559, -21.65063509461096}}], 
      LineBox[{{56.42197458095559, -24.148145657226703`}, {
       60., -24.148145657226703`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226703`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.14814565722671}, {56.42197458095559, -24.14814565722671}, {
       56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.650635094610976`}, {
       56.42197458095559, -21.650635094610976`}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.650635094610976`}, {
       60., -21.650635094610976`}, {60., -17.67766952966371}, {
       56.4219745809556, -17.67766952966371}, {
       56.42197458095559, -21.650635094610976`}}], 
      LineBox[{{56.42197458095559, -17.677669529663692`}, {
       60., -17.677669529663692`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663692`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563039}, {
       56.42197458095559, -6.470476127563039}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563039}, {
       60., -6.470476127563039}, {60., -2.8327694488239898`*^-14}, {
       56.42197458095559, -2.8327694488239898`*^-14}, {
       56.42197458095559, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{81.42197458095559, 0.}, {85., 6.123233995736766*^-15}, {85.,
       5.102694996447306*^-15}, {77.75044883428478, 0.}, {81.42197458095559, 
      0.}}], PolygonBox[{{77.75044883428478, 0.}, {85., 
      5.102694996447306*^-15}, {85., 4.0821559971578446`*^-15}, {
      75.67375799589206, 0.}, {77.75044883428478, 0.}}], 
     PolygonBox[{{75.67375799589206, 0.}, {85., 4.0821559971578446`*^-15}, {
      85., 3.061616997868384*^-15}, {75., 0.}, {75.67375799589206, 0.}}], 
     PolygonBox[{{75., 0.}, {85., 3.061616997868383*^-15}, {85., 
      2.0410779985789223`*^-15}, {75.67375799589206, 0.}, {75., 0.}}], 
     PolygonBox[{{75.67375799589206, 0.}, {85., 2.0410779985789223`*^-15}, {
      85., 1.0205389992894613`*^-15}, {77.75044883428478, 0.}, {
      75.67375799589206, 0.}}], 
     PolygonBox[{{77.75044883428478, 0.}, {85., 1.0205389992894615`*^-15}, {
      85., 5.098616525425841*^-31}, {81.42197458095559, 0.}, {
      77.75044883428478, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 0.}, {77.75044883428478, 0.}, {
       75.67375799589206, 0.}, {75., 0.}, {75.67375799589206, 0.}, {
       77.75044883428478, 0.}, {81.42197458095559, 0.}, {85., 0.}, {85., 
       0.}, {85., 0.}, {85., 0.}, {85., 0.}, {85., 0.}, {85., 0.}, {
       81.42197458095559, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{81.42197458095559, -25.}, {85., -25.}, {
        85., -16.66666666666667}, {77.75044883428478, -16.666666666666668`}, {
        81.42197458095559, -25.}}], 
       PolygonBox[{{77.75044883428478, -16.666666666666668`}, {
        85., -16.66666666666667}, {85., -8.333333333333336}, {
        75.67375799589206, -8.333333333333336}, {
        77.75044883428478, -16.666666666666668`}}], 
       PolygonBox[{{75.67375799589206, -8.333333333333336}, {
        85., -8.333333333333336}, {85., -7.105427357601002*^-15}, {75., 0.}, {
        75.67375799589206, -8.333333333333336}}], 
       PolygonBox[{{75., 0.}, {85., 0.}, {85., 8.333333333333332}, {
        75.67375799589206, 8.333333333333329}, {75., 0.}}], 
       PolygonBox[{{75.67375799589206, 8.333333333333329}, {85., 
        8.333333333333332}, {85., 16.666666666666664`}, {77.75044883428478, 
        16.666666666666664`}, {75.67375799589206, 8.333333333333329}}], 
       PolygonBox[{{77.75044883428478, 16.666666666666664`}, {85., 
        16.666666666666664`}, {85., 24.999999999999996`}, {81.42197458095559, 
        24.999999999999993`}, {77.75044883428478, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{81.42197458095559, -25.}, {
         77.75044883428478, -16.666666666666668`}, {
         75.67375799589206, -8.333333333333336}, {
         75., -3.552713678800501*^-15}, {75.67375799589206, 
         8.333333333333329}, {77.75044883428478, 16.666666666666657`}, {
         81.42197458095559, 24.999999999999993`}, {85., 25.}, {85., 
         16.666666666666668`}, {85., 8.333333333333336}, {85., 
         3.552713678800501*^-15}, {85., -8.333333333333329}, {
         85., -16.666666666666657`}, {85., -24.999999999999993`}, {
         81.42197458095559, -25.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{81.42197458095559, 0.}, {85., 0.}, {85., 
       6.4704761275630185`}, {81.42197458095559, 6.4704761275630185`}, {
       81.42197458095559, 0.}}], 
      LineBox[{{81.42197458095559, 6.4704761275630185`}, {85., 
       6.4704761275630185`}, {85., 12.499999999999998`}, {81.42197458095559, 
       12.499999999999998`}, {81.42197458095559, 6.4704761275630185`}}], 
      LineBox[{{81.42197458095559, 12.499999999999998`}, {85., 
       12.499999999999998`}, {85., 17.677669529663685`}, {81.42197458095559, 
       17.677669529663685`}, {81.42197458095559, 12.499999999999998`}}], 
      LineBox[{{81.42197458095559, 17.677669529663685`}, {85., 
       17.677669529663685`}, {85., 21.650635094610966`}, {81.42197458095559, 
       21.650635094610966`}, {81.42197458095559, 17.677669529663685`}}], 
      LineBox[{{81.42197458095559, 21.650635094610966`}, {85., 
       21.650635094610966`}, {85., 24.148145657226706`}, {81.42197458095559, 
       24.148145657226706`}, {81.42197458095559, 21.650635094610966`}}], 
      LineBox[{{81.42197458095559, 24.148145657226706`}, {85., 
       24.148145657226706`}, {85., 25.}, {81.42197458095559, 25.}, {
       81.42197458095559, 24.148145657226706`}}], 
      LineBox[{{81.42197458095559, 25.}, {85., 25.}, {85., 
       24.148145657226706`}, {81.42197458095559, 24.148145657226706`}, {
       81.42197458095559, 25.}}], 
      LineBox[{{81.42197458095559, 24.148145657226706`}, {85., 
       24.148145657226706`}, {85., 21.65063509461097}, {81.42197458095559, 
       21.65063509461097}, {81.42197458095559, 24.148145657226706`}}], 
      LineBox[{{81.42197458095559, 21.65063509461097}, {85., 
       21.65063509461097}, {85., 17.67766952966369}, {81.42197458095559, 
       17.67766952966369}, {81.42197458095559, 21.65063509461097}}], 
      LineBox[{{81.42197458095559, 17.67766952966369}, {85., 
       17.67766952966369}, {85., 12.499999999999998`}, {81.42197458095559, 
       12.499999999999998`}, {81.42197458095559, 17.67766952966369}}], 
      LineBox[{{81.4219745809556, 12.500000000000009`}, {85., 
       12.500000000000009`}, {85., 6.470476127563026}, {81.42197458095559, 
       6.470476127563026}, {81.4219745809556, 12.500000000000009`}}], 
      LineBox[{{81.42197458095559, 6.470476127563026}, {85., 
       6.470476127563026}, {85., 3.061616997868383*^-15}, {81.42197458095559, 
       3.061616997868383*^-15}, {81.42197458095559, 6.470476127563026}}], 
      LineBox[{{81.42197458095559, 3.061616997868383*^-15}, {85., 
       3.061616997868383*^-15}, {85., -6.47047612756302}, {
       81.42197458095559, -6.47047612756302}, {81.42197458095559, 
       3.061616997868383*^-15}}], 
      LineBox[{{81.42197458095559, -6.470476127563009}, {
       85., -6.470476127563009}, {85., -12.499999999999993`}, {
       81.42197458095559, -12.499999999999993`}, {
       81.42197458095559, -6.470476127563009}}], 
      LineBox[{{81.42197458095559, -12.499999999999993`}, {
       85., -12.499999999999993`}, {85., -17.677669529663685`}, {
       81.42197458095559, -17.677669529663685`}, {
       81.42197458095559, -12.499999999999993`}}], 
      LineBox[{{81.42197458095559, -17.677669529663678`}, {
       85., -17.677669529663678`}, {85., -21.65063509461096}, {
       81.42197458095559, -21.65063509461096}, {
       81.42197458095559, -17.677669529663678`}}], 
      LineBox[{{81.42197458095559, -21.65063509461096}, {
       85., -21.65063509461096}, {85., -24.148145657226703`}, {
       81.42197458095559, -24.148145657226703`}, {
       81.42197458095559, -21.65063509461096}}], 
      LineBox[{{81.42197458095559, -24.148145657226703`}, {
       85., -24.148145657226703`}, {85., -25.}, {81.42197458095559, -25.}, {
       81.42197458095559, -24.148145657226703`}}], 
      LineBox[{{81.42197458095559, -25.}, {85., -25.}, {
       85., -24.14814565722671}, {81.42197458095559, -24.14814565722671}, {
       81.42197458095559, -25.}}], 
      LineBox[{{81.42197458095559, -24.14814565722671}, {
       85., -24.14814565722671}, {85., -21.650635094610976`}, {
       81.42197458095559, -21.650635094610976`}, {
       81.42197458095559, -24.14814565722671}}], 
      LineBox[{{81.42197458095559, -21.650635094610976`}, {
       85., -21.650635094610976`}, {85., -17.67766952966371}, {
       81.4219745809556, -17.67766952966371}, {
       81.42197458095559, -21.650635094610976`}}], 
      LineBox[{{81.42197458095559, -17.677669529663692`}, {
       85., -17.677669529663692`}, {85., -12.50000000000001}, {
       81.42197458095559, -12.50000000000001}, {
       81.42197458095559, -17.677669529663692`}}], 
      LineBox[{{81.42197458095559, -12.50000000000001}, {
       85., -12.50000000000001}, {85., -6.470476127563039}, {
       81.42197458095559, -6.470476127563039}, {
       81.42197458095559, -12.50000000000001}}], 
      LineBox[{{81.42197458095559, -6.470476127563039}, {
       85., -6.470476127563039}, {85., -2.8327694488239898`*^-14}, {
       81.42197458095559, -2.8327694488239898`*^-14}, {
       81.42197458095559, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 75.}, {
      27.75044883428479, 75.}, {31.42197458095559, 75.}}], 
     PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
      25.67375799589206, 75.}, {27.75044883428479, 75.}}], 
     PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {25., 
      75.}, {25.67375799589206, 75.}}], 
     PolygonBox[{{25., 75.}, {35., 75.}, {35., 75.}, {25.67375799589206, 
      75.}, {25., 75.}}], 
     PolygonBox[{{25.67375799589206, 75.}, {35., 75.}, {35., 75.}, {
      27.75044883428479, 75.}, {25.67375799589206, 75.}}], 
     PolygonBox[{{27.75044883428479, 75.}, {35., 75.}, {35., 75.}, {
      31.42197458095559, 75.}, {27.75044883428479, 75.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 75.}, {27.75044883428479, 75.}, {
       25.67375799589206, 75.}, {25., 75.}, {25.67375799589206, 75.}, {
       27.750448834284782`, 75.}, {31.42197458095559, 75.}, {35., 75.}, {35., 
       75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {35., 75.}, {
       31.42197458095559, 75.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
        58.33333333333333}, {27.75044883428479, 58.33333333333333}, {
        31.42197458095559, 50.}}], 
       PolygonBox[{{27.75044883428479, 58.33333333333333}, {35., 
        58.33333333333333}, {35., 66.66666666666666}, {25.67375799589206, 
        66.66666666666666}, {27.75044883428479, 58.33333333333333}}], 
       PolygonBox[{{25.67375799589206, 66.66666666666666}, {35., 
        66.66666666666666}, {35., 75.}, {25., 75.}, {25.67375799589206, 
        66.66666666666666}}], 
       PolygonBox[{{25., 75.}, {35., 75.}, {35., 83.33333333333333}, {
        25.67375799589206, 83.33333333333333}, {25., 75.}}], 
       PolygonBox[{{25.67375799589206, 83.33333333333333}, {35., 
        83.33333333333333}, {35., 91.66666666666666}, {27.75044883428479, 
        91.66666666666666}, {25.67375799589206, 83.33333333333333}}], 
       PolygonBox[{{27.75044883428479, 91.66666666666666}, {35., 
        91.66666666666666}, {35., 100.}, {31.42197458095559, 100.}, {
        27.75044883428479, 91.66666666666666}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{31.42197458095559, 50.}, {27.75044883428479, 
         58.33333333333333}, {25.67375799589206, 66.66666666666666}, {25., 
         75.}, {25.67375799589206, 83.33333333333333}, {27.750448834284782`, 
         91.66666666666666}, {31.42197458095559, 100.}, {35., 100.}, {35., 
         91.66666666666667}, {35., 83.33333333333334}, {35., 75.}, {35., 
         66.66666666666667}, {35., 58.33333333333334}, {35., 
         50.00000000000001}, {31.42197458095559, 50.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       81.47047612756302}, {31.42197458095559, 81.47047612756302}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 81.47047612756302}, {35., 
       81.47047612756302}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 81.47047612756302}}], 
      LineBox[{{31.42197458095559, 87.5}, {35., 87.5}, {35., 
       92.67766952966369}, {31.42197458095559, 92.67766952966369}, {
       31.42197458095559, 87.5}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 96.65063509461096}, {31.42197458095559, 
       96.65063509461096}, {31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.42197458095559, 96.65063509461096}, {35., 
       96.65063509461096}, {35., 99.1481456572267}, {31.42197458095559, 
       99.1481456572267}, {31.42197458095559, 96.65063509461096}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 100.}, {31.42197458095559, 100.}, {
       31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 100.}, {35., 100.}, {35., 
       99.1481456572267}, {31.42197458095559, 99.1481456572267}, {
       31.42197458095559, 100.}}], 
      LineBox[{{31.42197458095559, 99.1481456572267}, {35., 
       99.1481456572267}, {35., 96.65063509461098}, {31.42197458095559, 
       96.65063509461098}, {31.42197458095559, 99.1481456572267}}], 
      LineBox[{{31.42197458095559, 96.65063509461098}, {35., 
       96.65063509461098}, {35., 92.67766952966369}, {31.42197458095559, 
       92.67766952966369}, {31.42197458095559, 96.65063509461098}}], 
      LineBox[{{31.42197458095559, 92.67766952966369}, {35., 
       92.67766952966369}, {35., 87.5}, {31.42197458095559, 87.5}, {
       31.42197458095559, 92.67766952966369}}], 
      LineBox[{{31.4219745809556, 87.50000000000001}, {35., 
       87.50000000000001}, {35., 81.47047612756303}, {31.42197458095559, 
       81.47047612756303}, {31.4219745809556, 87.50000000000001}}], 
      LineBox[{{31.42197458095559, 81.47047612756303}, {35., 
       81.47047612756303}, {35., 75.}, {31.42197458095559, 75.}, {
       31.42197458095559, 81.47047612756303}}], 
      LineBox[{{31.42197458095559, 75.}, {35., 75.}, {35., 
       68.52952387243698}, {31.42197458095559, 68.52952387243698}, {
       31.42197458095559, 75.}}], 
      LineBox[{{31.42197458095559, 68.529523872437}, {35., 68.529523872437}, {
       35., 62.50000000000001}, {31.42197458095559, 62.50000000000001}, {
       31.42197458095559, 68.529523872437}}], 
      LineBox[{{31.42197458095559, 62.50000000000001}, {35., 
       62.50000000000001}, {35., 57.32233047033631}, {31.42197458095559, 
       57.32233047033631}, {31.42197458095559, 62.50000000000001}}], 
      LineBox[{{31.42197458095559, 57.322330470336325`}, {35., 
       57.322330470336325`}, {35., 53.34936490538904}, {31.42197458095559, 
       53.34936490538904}, {31.42197458095559, 57.322330470336325`}}], 
      LineBox[{{31.42197458095559, 53.34936490538904}, {35., 
       53.34936490538904}, {35., 50.851854342773294`}, {31.42197458095559, 
       50.851854342773294`}, {31.42197458095559, 53.34936490538904}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 50.}, {31.42197458095559, 50.}, {
       31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 50.}, {35., 50.}, {35., 
       50.851854342773294`}, {31.42197458095559, 50.851854342773294`}, {
       31.42197458095559, 50.}}], 
      LineBox[{{31.42197458095559, 50.851854342773294`}, {35., 
       50.851854342773294`}, {35., 53.349364905389024`}, {31.42197458095559, 
       53.349364905389024`}, {31.42197458095559, 50.851854342773294`}}], 
      LineBox[{{31.42197458095559, 53.349364905389024`}, {35., 
       53.349364905389024`}, {35., 57.32233047033629}, {31.4219745809556, 
       57.32233047033629}, {31.42197458095559, 53.349364905389024`}}], 
      LineBox[{{31.42197458095559, 57.32233047033631}, {35., 
       57.32233047033631}, {35., 62.499999999999986`}, {31.42197458095559, 
       62.499999999999986`}, {31.42197458095559, 57.32233047033631}}], 
      LineBox[{{31.42197458095559, 62.499999999999986`}, {35., 
       62.499999999999986`}, {35., 68.52952387243695}, {31.42197458095559, 
       68.52952387243695}, {31.42197458095559, 62.499999999999986`}}], 
      LineBox[{{31.42197458095559, 68.52952387243695}, {35., 
       68.52952387243695}, {35., 74.99999999999997}, {31.42197458095559, 
       74.99999999999997}, {31.42197458095559, 68.52952387243695}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., -50.}, {125., 125.}, {125., 125.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {-50., -50.}, {-50., 125.}, {125., 125.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., -50.}, {-50., 125.}, {-50., 
       125.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {125., -50.}, {125., 125.}, {-50., 
       125.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -50.}, {125., -50.}, {-50., -50.}, {-50., -50.}, {
       125., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., 125.}, {125., 125.}, {-50., 125.}, {-50., 125.}, {125., 
       125.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"2-D\"\>", {80., -26.}, {0., 0.}], 
    InsetBox["\<\"3-D\"\>", {30., 49.}, {0., 0.}], 
    InsetBox["\<\"1-D\"\>", {55., -26.}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotLabel:>FormBox["\"Side View\"", TraditionalForm],
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563366716162716*^9, 3.566086362294907*^9, 
  3.567272843112973*^9, 3.601286891146948*^9, 3.614727106005163*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"},
 CellLabel->"During evaluation of In[52]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Move", "MB"],
 " can perform the same operations as ",
 StyleBox["Translate", "Input",
  FontFamily->"Courier",
  FontSlant->"Plain"],
 "."
}], "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],

Cell[TextData[{
 "As with ",
 StyleBox["Translate", "MB"],
 ", the one-dimensional case works with or without vector notation (curly  \
braces); higher dimensions require vector notation."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],

Cell[TextData[{
 StyleBox["Move", "MB"],
 " is more general than ",
 StyleBox["Translate", "MB"],
 " in that it can also change orientation.  This capability of ",
 StyleBox["Move", "MB"],
 " is described later.  You might employ ",
 StyleBox["Translate", "MB"],
 " instead of ",
 StyleBox["Move", "MB"],
 " for purely translational cases; such a convention might improve code  \
readability."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.4 MoveLinear", "Subsection",
 CellTags->{
  "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", "PR2.2.4"}
  ],

Cell[TextData[{
 "The ",
 StyleBox["MoveLinear", "MB"],
 " function simulates a notched optical rail.  The function parameters  \
include two points defining the rail's axis, plus a scalar value giving the  \
component's distance along this axis.  The function automatically aligns the  \
component with the axis."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", "75"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"source", " ", "=", " ", 
   RowBox[{"WedgeOfRays", "[", 
    RowBox[{"10", ",", 
     RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "6"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lens", " ", "=", " ", 
   RowBox[{"PlanoConvexLens", "[", 
    RowBox[{"100", ",", "50", ",", "10"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sys", " ", "=", " ", 
   RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"MoveLinear", "[", 
        RowBox[{"source", ",", "a", ",", "0", ",", "b"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"MoveLinear", "[", 
        RowBox[{"lens", ",", "a", ",", "50", ",", "b"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"MoveLinear", "[", 
        RowBox[{"lens", ",", "a", ",", "100", ",", "b"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "15"}], ",", 
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "50"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"150", ",", "125", ",", "100"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", 
         RowBox[{"{", "0.015", "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<a\>\"", ",", 
          RowBox[{"a", "+", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7"}], ",", "5"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<b\>\"", ",", 
          RowBox[{"b", "+", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"},
 CellLabel->"In[54]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{60.13757966476447, 13.853184748573355`}, {63., 16.}, {58., 
      22.666666666666664`}, {52.20035906742783, 18.316935967237537`}, {
      60.13757966476447, 13.853184748573355`}}], 
     PolygonBox[{{52.20035906742783, 18.316935967237537`}, {58., 
      22.666666666666664`}, {53., 29.333333333333332`}, {45.539006396713646`, 
      23.737588130868566`}, {52.20035906742783, 18.316935967237537`}}], 
     PolygonBox[{{45.539006396713646`, 23.737588130868566`}, {53., 
      29.333333333333332`}, {48.00000000000001, 35.99999999999999}, {40., 
      30.}, {45.539006396713646`, 23.737588130868566`}}], 
     PolygonBox[{{40., 30.}, {48., 36.}, {43., 42.666666666666664`}, {
      35.539006396713646`, 37.0709214642019}, {40., 30.}}], 
     PolygonBox[{{35.539006396713646`, 37.0709214642019}, {43., 
      42.666666666666664`}, {38., 49.33333333333333}, {32.20035906742783, 
      44.98360263390421}, {35.539006396713646`, 37.0709214642019}}], 
     PolygonBox[{{32.20035906742783, 44.98360263390421}, {38., 
      49.33333333333333}, {33., 56.}, {30.137579664764473`, 
      53.85318474857335}, {32.20035906742783, 44.98360263390421}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{60.13757966476447, 13.853184748573355`}, {52.20035906742783, 
       18.316935967237537`}, {45.539006396713646`, 23.737588130868566`}, {40.,
        30.}, {35.539006396713646`, 37.0709214642019}, {32.200359067427826`, 
       44.98360263390419}, {30.137579664764473`, 53.85318474857335}, {33., 
       56.}, {38., 49.333333333333336`}, {43., 42.66666666666667}, {48., 
       36.}, {53., 29.333333333333336`}, {57.99999999999999, 
       22.66666666666667}, {62.99999999999999, 16.000000000000004`}, {
       60.13757966476447, 13.853184748573355`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{45.13757966476447, 33.853184748573355`}, {48., 36.}, {48.,
         36.}, {42.20035906742783, 31.650269300570873`}, {45.13757966476447, 
        33.853184748573355`}}], 
       PolygonBox[{{42.20035906742783, 31.650269300570873`}, {48., 36.}, {48.,
         36.}, {40.539006396713646`, 30.404254797535238`}, {42.20035906742783,
         31.650269300570873`}}], 
       PolygonBox[{{40.539006396713646`, 30.404254797535238`}, {48., 36.}, {
        48., 36.}, {40., 30.}, {40.539006396713646`, 30.404254797535238`}}], 
       PolygonBox[{{40., 30.}, {48., 36.}, {48., 36.}, {40.539006396713646`, 
        30.404254797535238`}, {40., 30.}}], 
       PolygonBox[{{40.539006396713646`, 30.404254797535238`}, {48., 36.}, {
        48., 36.}, {42.20035906742783, 31.650269300570873`}, {
        40.539006396713646`, 30.404254797535238`}}], 
       PolygonBox[{{42.20035906742783, 31.650269300570873`}, {48., 36.}, {48.,
         36.}, {45.13757966476447, 33.853184748573355`}, {42.20035906742783, 
        31.650269300570873`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{45.13757966476447, 33.853184748573355`}, {42.20035906742783,
          31.650269300570873`}, {40.539006396713646`, 30.404254797535238`}, {
         40., 30.}, {40.539006396713646`, 30.404254797535238`}, {
         42.200359067427826`, 31.65026930057087}, {45.13757966476447, 
         33.853184748573355`}, {48., 36.}, {48., 36.}, {48., 36.}, {48., 
         36.}, {48., 36.}, {48., 36.}, {48., 36.}, {45.13757966476447, 
         33.853184748573355`}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{30.137579664764473`, 53.85318474857335}, {33., 56.}, {
       33.511112605663975`, 55.31851652578136}, {30.648692270428455`, 
       53.171701274354724`}, {30.137579664764473`, 53.85318474857335}}], 
      LineBox[{{30.648692270428455`, 53.171701274354724`}, {
       33.511112605663975`, 55.31851652578136}, {35.00961894323342, 
       53.32050807568878}, {32.14719860799789, 51.173692824262126`}, {
       30.648692270428455`, 53.171701274354724`}}], 
      LineBox[{{32.14719860799789, 51.173692824262126`}, {35.00961894323342, 
       53.32050807568878}, {37.39339828220179, 50.14213562373095}, {
       34.53097794696626, 47.9953203723043}, {32.14719860799789, 
       51.173692824262126`}}], 
      LineBox[{{34.53097794696626, 47.9953203723043}, {37.39339828220179, 
       50.14213562373095}, {40.5, 46.}, {37.63757966476447, 
       43.85318474857336}, {34.53097794696626, 47.9953203723043}}], 
      LineBox[{{37.63757966476447, 43.85318474857336}, {40.5, 46.}, {
       44.11771432346219, 41.17638090205042}, {41.255293988226654`, 
       39.02956565062377}, {37.63757966476447, 43.85318474857336}}], 
      LineBox[{{41.255293988226654`, 39.02956565062377}, {44.11771432346219, 
       41.17638090205042}, {47.99999999999999, 36.00000000000001}, {
       45.13757966476447, 33.85318474857336}, {41.255293988226654`, 
       39.02956565062377}}], 
      LineBox[{{45.13757966476447, 33.853184748573355`}, {48., 36.}, {
       51.88228567653781, 30.82361909794959}, {49.01986534130228, 
       28.676803846522944`}, {45.13757966476447, 33.853184748573355`}}], 
      LineBox[{{49.01986534130228, 28.676803846522944`}, {51.88228567653781, 
       30.82361909794959}, {55.5, 26.000000000000004`}, {52.63757966476447, 
       23.853184748573362`}, {49.01986534130228, 28.676803846522944`}}], 
      LineBox[{{52.63757966476447, 23.853184748573362`}, {55.5, 
       26.000000000000004`}, {58.60660171779821, 21.85786437626905}, {
       55.74418138256269, 19.711049124842404`}, {52.63757966476447, 
       23.853184748573362`}}], 
      LineBox[{{55.74418138256269, 19.711049124842404`}, {58.60660171779821, 
       21.85786437626905}, {60.99038105676658, 18.679491924311225`}, {
       58.12796072153105, 16.532676672884584`}, {55.74418138256269, 
       19.711049124842404`}}], 
      LineBox[{{58.12796072153106, 16.532676672884588`}, {60.99038105676658, 
       18.67949192431123}, {62.488887394336025`, 16.681483474218634`}, {
       59.62646705910049, 14.534668222791986`}, {58.12796072153106, 
       16.532676672884588`}}], 
      LineBox[{{59.62646705910049, 14.534668222791986`}, {62.488887394336025`,
        16.681483474218634`}, {63., 16.}, {60.13757966476447, 
       13.853184748573355`}, {59.62646705910049, 14.534668222791986`}}], 
      LineBox[{{60.13757966476447, 13.853184748573355`}, {63., 16.}, {
       62.488887394336025`, 16.681483474218634`}, {59.62646705910049, 
       14.534668222791986`}, {60.13757966476447, 13.853184748573355`}}], 
      LineBox[{{59.626467059100506`, 14.534668222791986`}, {
       62.488887394336025`, 16.68148347421863}, {60.99038105676658, 
       18.679491924311225`}, {58.12796072153105, 16.532676672884584`}, {
       59.626467059100506`, 14.534668222791986`}}], 
      LineBox[{{58.12796072153105, 16.532676672884584`}, {60.99038105676658, 
       18.679491924311225`}, {58.60660171779821, 21.857864376269045`}, {
       55.74418138256269, 19.711049124842397`}, {58.12796072153105, 
       16.532676672884584`}}], 
      LineBox[{{55.74418138256269, 19.711049124842397`}, {58.60660171779821, 
       21.857864376269042`}, {55.50000000000001, 25.999999999999993`}, {
       52.63757966476447, 23.853184748573348`}, {55.74418138256269, 
       19.711049124842397`}}], 
      LineBox[{{52.63757966476447, 23.853184748573348`}, {55.50000000000001, 
       25.999999999999993`}, {51.88228567653782, 30.823619097949567`}, {
       49.01986534130229, 28.676803846522922`}, {52.63757966476447, 
       23.853184748573348`}}], 
      LineBox[{{49.01986534130229, 28.676803846522922`}, {51.88228567653782, 
       30.823619097949567`}, {48.000000000000014`, 35.99999999999998}, {
       45.13757966476449, 33.853184748573334`}, {49.01986534130229, 
       28.676803846522922`}}], 
      LineBox[{{45.13757966476447, 33.85318474857335}, {48., 
       35.99999999999999}, {44.117714323462195`, 41.176380902050404`}, {
       41.25529398822667, 39.02956565062376}, {45.13757966476447, 
       33.85318474857335}}], 
      LineBox[{{41.25529398822667, 39.02956565062376}, {44.117714323462195`, 
       41.176380902050404`}, {40.50000000000001, 45.999999999999986`}, {
       37.63757966476449, 43.85318474857335}, {41.25529398822667, 
       39.02956565062376}}], 
      LineBox[{{37.63757966476449, 43.85318474857335}, {40.50000000000001, 
       45.999999999999986`}, {37.3933982822018, 50.14213562373094}, {
       34.53097794696628, 47.995320372304306`}, {37.63757966476449, 
       43.85318474857335}}], 
      LineBox[{{34.53097794696626, 47.9953203723043}, {37.39339828220179, 
       50.14213562373095}, {35.00961894323343, 53.320508075688764`}, {
       32.14719860799789, 51.173692824262126`}, {34.53097794696626, 
       47.9953203723043}}], 
      LineBox[{{32.14719860799789, 51.173692824262126`}, {35.00961894323343, 
       53.320508075688764`}, {33.51111260566398, 55.31851652578136}, {
       30.648692270428455`, 53.171701274354724`}, {32.14719860799789, 
       51.173692824262126`}}], 
      LineBox[{{30.648692270428455`, 53.171701274354724`}, {33.51111260566398,
        55.31851652578136}, {33., 56.}, {30.137579664764473`, 
       53.85318474857335}, {30.648692270428455`, 53.171701274354724`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100.13757966476446`, 43.85318474857335}, {103., 46.}, {98., 
      52.666666666666664`}, {92.20035906742783, 48.31693596723753}, {
      100.13757966476446`, 43.85318474857335}}], 
     PolygonBox[{{92.20035906742783, 48.31693596723753}, {98., 
      52.666666666666664`}, {93., 59.33333333333333}, {85.53900639671365, 
      53.73758813086856}, {92.20035906742783, 48.31693596723753}}], 
     PolygonBox[{{85.53900639671365, 53.73758813086856}, {93., 
      59.33333333333333}, {88., 66.}, {80., 59.99999999999999}, {
      85.53900639671365, 53.73758813086856}}], 
     PolygonBox[{{80., 59.99999999999999}, {88., 66.}, {83., 
      72.66666666666667}, {75.53900639671365, 67.07092146420189}, {80., 
      59.99999999999999}}], 
     PolygonBox[{{75.53900639671365, 67.07092146420189}, {83., 
      72.66666666666667}, {78., 79.33333333333333}, {72.20035906742783, 
      74.9836026339042}, {75.53900639671365, 67.07092146420189}}], 
     PolygonBox[{{72.20035906742783, 74.9836026339042}, {78., 
      79.33333333333333}, {73., 86.}, {70.13757966476447, 
      83.85318474857334}, {72.20035906742783, 74.9836026339042}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100.13757966476446`, 43.85318474857335}, {92.20035906742783, 
       48.31693596723753}, {85.53900639671365, 53.73758813086856}, {80., 
       59.99999999999999}, {75.53900639671365, 67.07092146420189}, {
       72.20035906742783, 74.98360263390418}, {70.13757966476447, 
       83.85318474857334}, {73., 86.}, {78., 79.33333333333334}, {83., 
       72.66666666666667}, {88., 66.}, {93., 59.333333333333336`}, {98., 
       52.66666666666667}, {103., 46.}, {100.13757966476446`, 
       43.85318474857335}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{85.13757966476447, 63.85318474857335}, {88., 66.}, {88., 
        66.}, {82.20035906742783, 61.65026930057087}, {85.13757966476447, 
        63.85318474857335}}], 
       PolygonBox[{{82.20035906742783, 61.65026930057087}, {88., 66.}, {88., 
        66.}, {80.53900639671365, 60.40425479753523}, {82.20035906742783, 
        61.65026930057087}}], 
       PolygonBox[{{80.53900639671365, 60.40425479753523}, {88., 66.}, {88., 
        66.}, {80., 59.99999999999999}, {80.53900639671365, 
        60.40425479753523}}], 
       PolygonBox[{{80., 59.99999999999999}, {88., 66.}, {88., 66.}, {
        80.53900639671365, 60.40425479753523}, {80., 59.99999999999999}}], 
       PolygonBox[{{80.53900639671365, 60.40425479753523}, {88., 66.}, {88., 
        66.}, {82.20035906742783, 61.65026930057087}, {80.53900639671365, 
        60.40425479753523}}], 
       PolygonBox[{{82.20035906742783, 61.65026930057087}, {88., 66.}, {88., 
        66.}, {85.13757966476447, 63.85318474857335}, {82.20035906742783, 
        61.65026930057087}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{85.13757966476447, 63.85318474857335}, {82.20035906742783, 
         61.65026930057087}, {80.53900639671365, 60.40425479753523}, {80., 
         59.99999999999999}, {80.53900639671365, 60.40425479753523}, {
         82.20035906742783, 61.65026930057086}, {85.13757966476447, 
         63.85318474857335}, {88., 66.}, {88., 66.}, {88., 66.}, {88., 66.}, {
         88., 66.}, {88., 66.}, {88., 66.}, {85.13757966476447, 
         63.85318474857335}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{70.13757966476447, 83.85318474857334}, {73., 86.}, {
       73.51111260566398, 85.31851652578136}, {70.64869227042846, 
       83.17170127435472}, {70.13757966476447, 83.85318474857334}}], 
      LineBox[{{70.64869227042846, 83.17170127435472}, {73.51111260566398, 
       85.31851652578136}, {75.00961894323342, 83.32050807568878}, {
       72.1471986079979, 81.17369282426213}, {70.64869227042846, 
       83.17170127435472}}], 
      LineBox[{{72.1471986079979, 81.17369282426213}, {75.00961894323342, 
       83.32050807568878}, {77.39339828220179, 80.14213562373095}, {
       74.53097794696626, 77.99532037230429}, {72.1471986079979, 
       81.17369282426213}}], 
      LineBox[{{74.53097794696626, 77.99532037230429}, {77.39339828220179, 
       80.14213562373095}, {80.5, 76.}, {77.63757966476447, 
       73.85318474857334}, {74.53097794696626, 77.99532037230429}}], 
      LineBox[{{77.63757966476447, 73.85318474857334}, {80.5, 76.}, {
       84.11771432346218, 71.17638090205043}, {81.25529398822665, 
       69.02956565062377}, {77.63757966476447, 73.85318474857334}}], 
      LineBox[{{81.25529398822665, 69.02956565062377}, {84.11771432346218, 
       71.17638090205043}, {88., 66.}, {85.13757966476447, 
       63.85318474857335}, {81.25529398822665, 69.02956565062377}}], 
      LineBox[{{85.13757966476447, 63.85318474857335}, {88., 66.}, {
       91.8822856765378, 60.82361909794959}, {89.01986534130228, 
       58.67680384652294}, {85.13757966476447, 63.85318474857335}}], 
      LineBox[{{89.01986534130228, 58.67680384652294}, {91.8822856765378, 
       60.82361909794959}, {95.5, 56.}, {92.63757966476446, 
       53.85318474857335}, {89.01986534130228, 58.67680384652294}}], 
      LineBox[{{92.63757966476446, 53.85318474857335}, {95.5, 56.}, {
       98.60660171779821, 51.85786437626905}, {95.74418138256267, 
       49.7110491248424}, {92.63757966476446, 53.85318474857335}}], 
      LineBox[{{95.74418138256267, 49.7110491248424}, {98.60660171779821, 
       51.85786437626905}, {100.99038105676658`, 48.67949192431122}, {
       98.12796072153107, 46.53267667288457}, {95.74418138256267, 
       49.7110491248424}}], 
      LineBox[{{98.12796072153105, 46.53267667288459}, {100.99038105676658`, 
       48.67949192431123}, {102.48888739433602`, 46.68148347421864}, {
       99.6264670591005, 44.534668222791986`}, {98.12796072153105, 
       46.53267667288459}}], 
      LineBox[{{99.6264670591005, 44.534668222791986`}, {102.48888739433602`, 
       46.68148347421864}, {103., 46.}, {100.13757966476446`, 
       43.85318474857335}, {99.6264670591005, 44.534668222791986`}}], 
      LineBox[{{100.13757966476446`, 43.85318474857335}, {103., 46.}, {
       102.48888739433602`, 46.68148347421864}, {99.6264670591005, 
       44.534668222791986`}, {100.13757966476446`, 43.85318474857335}}], 
      LineBox[{{99.6264670591005, 44.53466822279197}, {102.48888739433602`, 
       46.68148347421863}, {100.99038105676658`, 48.67949192431122}, {
       98.12796072153107, 46.53267667288457}, {99.6264670591005, 
       44.53466822279197}}], 
      LineBox[{{98.12796072153107, 46.53267667288457}, {100.99038105676658`, 
       48.67949192431122}, {98.60660171779821, 51.85786437626905}, {
       95.7441813825627, 49.7110491248424}, {98.12796072153107, 
       46.53267667288457}}], 
      LineBox[{{95.7441813825627, 49.7110491248424}, {98.60660171779821, 
       51.85786437626904}, {95.5, 55.99999999999999}, {92.63757966476449, 
       53.853184748573334`}, {95.7441813825627, 49.7110491248424}}], 
      LineBox[{{92.63757966476449, 53.853184748573334`}, {95.5, 
       55.99999999999999}, {91.88228567653782, 60.82361909794957}, {
       89.01986534130229, 58.67680384652292}, {92.63757966476449, 
       53.853184748573334`}}], 
      LineBox[{{89.01986534130229, 58.67680384652292}, {91.88228567653782, 
       60.82361909794957}, {88.00000000000001, 65.99999999999997}, {
       85.13757966476449, 63.85318474857332}, {89.01986534130229, 
       58.67680384652292}}], 
      LineBox[{{85.13757966476447, 63.85318474857335}, {88., 66.}, {
       84.1177143234622, 71.17638090205041}, {81.25529398822667, 
       69.02956565062377}, {85.13757966476447, 63.85318474857335}}], 
      LineBox[{{81.25529398822667, 69.02956565062377}, {84.1177143234622, 
       71.17638090205041}, {80.50000000000001, 75.99999999999999}, {
       77.63757966476449, 73.85318474857334}, {81.25529398822667, 
       69.02956565062377}}], 
      LineBox[{{77.63757966476449, 73.85318474857334}, {80.50000000000001, 
       75.99999999999999}, {77.3933982822018, 80.14213562373094}, {
       74.53097794696629, 77.99532037230429}, {77.63757966476449, 
       73.85318474857334}}], 
      LineBox[{{74.53097794696626, 77.99532037230429}, {77.39339828220179, 
       80.14213562373095}, {75.00961894323342, 83.32050807568876}, {
       72.1471986079979, 81.1736928242621}, {74.53097794696626, 
       77.99532037230429}}], 
      LineBox[{{72.1471986079979, 81.1736928242621}, {75.00961894323342, 
       83.32050807568876}, {73.51111260566398, 85.31851652578136}, {
       70.64869227042846, 83.17170127435472}, {72.1471986079979, 
       81.1736928242621}}], 
      LineBox[{{70.64869227042846, 83.17170127435472}, {73.51111260566398, 
       85.31851652578136}, {73., 86.}, {70.13757966476447, 
       83.85318474857334}, {70.64869227042846, 83.17170127435472}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 125.}, {150., -10.}, {150., -10.}, {150., 125.}, {150., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -10.}, {-15., -10.}, {-15., -10.}, {150., -10.}, {
       150., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-15., -10.}, {-15., 125.}, {-15., 
       125.}, {-15., -10.}, {-15., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-15., 125.}, {150., 125.}, {150., 125.}, {-15., 125.}, {-15., 
       125.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -10.}, {150., 125.}, {-15., 125.}, {-15., -10.}, {
       150., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 125.}, {150., -10.}, {-15., -10.}, {-15., 125.}, {150., 
       125.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {37.514496563958815`, 33.62427259363403}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {38.47880234469748, 32.13893812043509}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {39.48214694353572, 30.702712019891308`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {40.529604683285655`, 29.306101700224723`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {41.62744525213299, 27.940747577187754`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {42.78336072779714, 26.599120375182935`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{37.514496563958815`, 33.62427259363403}, {45.19963936640227, 
       39.7338141781303}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{38.47880234469748, 32.13893812043509}, {46.323697302338296`, 
       38.23507026354894}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{39.48214694353572, 30.702712019891308`}, {
       47.441875507884006`, 36.74416598948799}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{40.529604683285655`, 29.306101700224723`}, {
       48.558124492115994`, 35.25583401051201}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{41.62744525213299, 27.940747577187754`}, {49.67630269766171, 
       33.76492973645105}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{42.78336072779714, 26.599120375182935`}, {50.80036063359773, 
       32.2661858218697}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{45.19963936640227, 39.7338141781303}, {76.47838401057052, 
       65.35549536799135}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{46.323697302338296`, 38.23507026354894}, {77.81126454323962, 
       63.15520958593653}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.441875507884006`, 36.74416598948799}, {79.24525354214234, 
       61.03261004478909}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{48.558124492115994`, 35.25583401051201}, {80.77997663479738, 
       58.98631258791569}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.67630269766171, 33.76492973645105}, {82.4161552746062, 
       57.015355277447796`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.80036063359773, 32.2661858218697}, {84.15522307623144, 
       55.11970994711013}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{76.47838401057052, 65.35549536799135}, {84.24433626129738, 
       71.00755165160349}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{77.81126454323962, 63.15520958593653}, {85.7463752387105, 
       69.00483301505267}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{79.24525354214234, 61.03261004478909}, {87.24876007784879, 
       67.00165322953497}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{80.77997663479738, 58.98631258791569}, {88.75123992215123, 
       64.99834677046503}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.4161552746062, 57.015355277447796`}, {90.25362476128952, 
       62.99516698494732}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{84.15522307623144, 55.11970994711013}, {91.75566373870262, 
       60.99244834839651}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{84.24433626129738, 71.00755165160349}, {150., 
       118.11866522731435`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{85.7463752387105, 69.00483301505267}, {150., 
       115.94790695478287`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{87.24876007784879, 67.00165322953497}, {150., 
       113.66547570909674`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.75123992215123, 64.99834677046503}, {150., 
       111.32735545069698`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.25362476128952, 62.99516698494732}, {150., 
       108.98662721885947`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.75566373870262, 60.99244834839651}, {150., 
       106.6943872903635}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQfYj3H+vtg04ODjuFtF6cd3BYekc31dPW2eHu9tyd
JwQdHMR1t/7dttfZoeRD+Psnm+0cZjmJip1ydnEQ2x6+LsbP1qHzh5NCwAUX
B84LvlevfLB2YM4T1HJNcXXQOP7xc/xMK4eJN5JO9M50c5hiUjP/7V1nh/A1
x1/mabo7mEt5nxCTc3b4tDA7oX+Hu8PeS0evOMQ7OfDFTZlf4O7h4Kxrpb1/
gaPDqmALsYnXPBxOPN1i/vKhg0O++lzzojRPh5zTzQlCSg4OUqI/rs+VC3Y4
cHNJ/oGwAIdp6XKHXhcHOxw6H//i7mR/hw3rXlpvOh/s8Pnjwwk6LX4OIW1y
yq8NQxwmxa6qta/zdSidv9tz0awQh1NW6ZrfG30cXvw/ovOeM9SB9c3F5UH9
3g6f7veZLOYPddir9WZn9YFAh0nGy+YcyQ91eJGqpO/vEOjguyt5/evzoQ6u
m1TFpA8EOGxxnRMgYhDmsNv31ssn9gEO+Wcik60nhDnomexemFjv78CnUHg6
5kOYQ9sq9R6Oej8HBhA4kORgMp/TbEZ7LJyfMOdd46o/MXD+tG256tOzEHyf
XW4pn69Ew/lC02qfqdgj+Iu2J18vWBPlAACMJM5N
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L2\"\>", {102.21742398272777`, 38.71010135636297}, \
{0., 0.}], 
    InsetBox["\<\"L1\"\>", {62.21742398272777, 8.71010135636297}, {0., 0.}]}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  Epilog:>{
    Dashing[{0.015}], 
    Thickness[0.01], 
    LineBox[{{0, 0}, {100, 75}}], 
    InsetBox[
     FormBox["\"a\"", TraditionalForm], {-7, 5}], 
    InsetBox[
     FormBox["\"b\"", TraditionalForm], {95, 80}]},
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601286910886118*^9, 3.614727106541127*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"},
 CellLabel->"During evaluation of In[54]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["MoveLinear", "MB"],
 " simulates an optical rail having an axis ",
 StyleBox["ab", "MB"],
 "."
}], "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],

Cell[TextData[{
 "The first lens is 50 units distant from point ",
 StyleBox["a", "MB"],
 ".  The second lens is 100 units distant from ",
 StyleBox["a", "MB"],
 ".  The orientation of each lens is colinear with axis ",
 StyleBox["ab", "MB"],
 "."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],

Cell[TextData[{
 "Note the use of ",
 StyleBox["Epilog", "MB"],
 " to add custom graphics to the ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " output.  ",
 StyleBox["Epilog", "MB"],
 " is a standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphics option.  Sometimes the production of pleasing graphics requires  \
a certain amount of experimentation when dealing with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s graphics primitives.  Do not recompute your optical system with each  \
experimental iteration.  Instead, compute the system once, assigning the  \
result into a variable (like ",
 StyleBox["sys", "MB"],
 " above). Then use ",
 StyleBox["ShowSystem", "MB"],
 " with the variable and different settings of ",
 StyleBox["Epilog", "MB"],
 " until you have a satisfactory display."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.5 MoveDirected", "Subsection",
 CellTags->{
  "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
   "PR2.2.5"}],

Cell[TextData[{
 StyleBox["MoveDirected", "MB"],
 " is a close cousin of ",
 StyleBox["MoveLinear", "MB"],
 ".  ",
 StyleBox["MoveDirected", "MB"],
 " performs the same task with different inputs.  It also accepts two  \
points, but the second point directly assigns the component position.  With  \
this function, there is no need to specify scalar distance along the rail.   \
The two points suffice because one of them establishes absolute position, not \
 merely linear direction."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"{", 
    RowBox[{"100", ",", "75"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "50"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sys", " ", "=", " ", 
   RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"MoveDirected", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"WedgeOfRays", "[", 
          RowBox[{"10", ",", 
           RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "6"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "c", ",", "a", ",", 
         RowBox[{"SideOfObject", " ", "\[Rule]", " ", "After"}]}], "]"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"MoveDirected", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"PlanoConvexLens", "[", 
          RowBox[{"100", ",", "50", ",", "10", ",", "\"\<\>\""}], "]"}], ",", 
         "\[IndentingNewLine]", "a", ",", "b", ",", 
         RowBox[{"SideOfObject", "\[Rule]", "Before"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Boundary", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "15"}], ",", 
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "50"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"150", ",", "110", ",", "100"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", 
         RowBox[{"{", "0.015", "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"c", ",", "a"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<a\>\"", ",", 
          RowBox[{"a", "+", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7"}], ",", "5"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<b\>\"", ",", 
          RowBox[{"b", "+", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<c\>\"", ",", 
          RowBox[{"c", "+", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"},
 CellLabel->"In[59]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{120.13757966476446`, 58.85318474857335}, {123., 61.}, {118.,
       67.66666666666666}, {112.20035906742783`, 63.31693596723753}, {
      120.13757966476446`, 58.85318474857335}}], 
     PolygonBox[{{112.20035906742783`, 63.31693596723753}, {118., 
      67.66666666666666}, {113., 74.33333333333333}, {105.53900639671363`, 
      68.73758813086856}, {112.20035906742783`, 63.31693596723753}}], 
     PolygonBox[{{105.53900639671363`, 68.73758813086856}, {113., 
      74.33333333333333}, {108., 81.}, {99.99999999999999, 75.}, {
      105.53900639671363`, 68.73758813086856}}], 
     PolygonBox[{{99.99999999999999, 75.}, {108., 81.}, {103., 
      87.66666666666667}, {95.53900639671363, 82.07092146420189}, {
      99.99999999999999, 75.}}], 
     PolygonBox[{{95.53900639671363, 82.07092146420189}, {103., 
      87.66666666666667}, {98., 94.33333333333333}, {92.20035906742783, 
      89.9836026339042}, {95.53900639671363, 82.07092146420189}}], 
     PolygonBox[{{92.20035906742783, 89.9836026339042}, {98., 
      94.33333333333333}, {93., 101.}, {90.13757966476446, 
      98.85318474857334}, {92.20035906742783, 89.9836026339042}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{120.13757966476446`, 58.85318474857335}, {112.20035906742783`,
        63.31693596723753}, {105.53900639671363`, 68.73758813086856}, {
       99.99999999999999, 75.}, {95.53900639671363, 82.07092146420189}, {
       92.20035906742781, 89.98360263390418}, {90.13757966476446, 
       98.85318474857334}, {93., 101.}, {98., 94.33333333333334}, {103., 
       87.66666666666667}, {108., 81.}, {113., 74.33333333333334}, {118., 
       67.66666666666667}, {123., 61.}, {120.13757966476446`, 
       58.85318474857335}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{105.13757966476446`, 78.85318474857334}, {108., 81.}, {
        108., 81.}, {102.20035906742783`, 76.65026930057087}, {
        105.13757966476446`, 78.85318474857334}}], 
       PolygonBox[{{102.20035906742783`, 76.65026930057087}, {108., 81.}, {
        108., 81.}, {100.53900639671363`, 75.40425479753523}, {
        102.20035906742783`, 76.65026930057087}}], 
       PolygonBox[{{100.53900639671363`, 75.40425479753523}, {108., 81.}, {
        108., 81.}, {99.99999999999999, 75.}, {100.53900639671363`, 
        75.40425479753523}}], 
       PolygonBox[{{99.99999999999999, 75.}, {108., 81.}, {108., 81.}, {
        100.53900639671363`, 75.40425479753523}, {99.99999999999999, 75.}}], 
       PolygonBox[{{100.53900639671363`, 75.40425479753523}, {108., 81.}, {
        108., 81.}, {102.20035906742783`, 76.65026930057087}, {
        100.53900639671363`, 75.40425479753523}}], 
       PolygonBox[{{102.20035906742783`, 76.65026930057087}, {108., 81.}, {
        108., 81.}, {105.13757966476446`, 78.85318474857334}, {
        102.20035906742783`, 76.65026930057087}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{105.13757966476446`, 78.85318474857334}, {
         102.20035906742783`, 76.65026930057087}, {100.53900639671363`, 
         75.40425479753523}, {99.99999999999999, 75.}, {100.53900639671363`, 
         75.40425479753523}, {102.20035906742781`, 76.65026930057087}, {
         105.13757966476446`, 78.85318474857334}, {108., 81.}, {108., 81.}, {
         108., 81.}, {108., 81.}, {108., 81.}, {108., 81.}, {108., 81.}, {
         105.13757966476446`, 78.85318474857334}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{90.13757966476446, 98.85318474857334}, {93., 101.}, {
       93.51111260566398, 100.31851652578136`}, {90.64869227042844, 
       98.17170127435472}, {90.13757966476446, 98.85318474857334}}], 
      LineBox[{{90.64869227042844, 98.17170127435472}, {93.51111260566398, 
       100.31851652578136`}, {95.00961894323342, 98.32050807568878}, {
       92.14719860799788, 96.17369282426213}, {90.64869227042844, 
       98.17170127435472}}], 
      LineBox[{{92.14719860799788, 96.17369282426213}, {95.00961894323342, 
       98.32050807568878}, {97.39339828220179, 95.14213562373095}, {
       94.53097794696625, 92.99532037230429}, {92.14719860799788, 
       96.17369282426213}}], 
      LineBox[{{94.53097794696625, 92.99532037230429}, {97.39339828220179, 
       95.14213562373095}, {100.5, 91.}, {97.63757966476446, 
       88.85318474857334}, {94.53097794696625, 92.99532037230429}}], 
      LineBox[{{97.63757966476446, 88.85318474857334}, {100.5, 91.}, {
       104.11771432346218`, 86.17638090205043}, {101.25529398822665`, 
       84.02956565062377}, {97.63757966476446, 88.85318474857334}}], 
      LineBox[{{101.25529398822665`, 84.02956565062377}, {104.11771432346218`,
        86.17638090205043}, {108., 81.}, {105.13757966476446`, 
       78.85318474857334}, {101.25529398822665`, 84.02956565062377}}], 
      LineBox[{{105.13757966476446`, 78.85318474857334}, {108., 81.}, {
       111.8822856765378, 75.82361909794959}, {109.01986534130226`, 
       73.67680384652294}, {105.13757966476446`, 78.85318474857334}}], 
      LineBox[{{109.01986534130226`, 73.67680384652294}, {111.8822856765378, 
       75.82361909794959}, {115.5, 71.}, {112.63757966476446`, 
       68.85318474857334}, {109.01986534130226`, 73.67680384652294}}], 
      LineBox[{{112.63757966476446`, 68.85318474857334}, {115.5, 71.}, {
       118.60660171779821`, 66.85786437626905}, {115.74418138256267`, 
       64.71104912484239}, {112.63757966476446`, 68.85318474857334}}], 
      LineBox[{{115.74418138256267`, 64.71104912484239}, {118.60660171779821`,
        66.85786437626905}, {120.99038105676658`, 63.67949192431122}, {
       118.12796072153104`, 61.53267667288457}, {115.74418138256267`, 
       64.71104912484239}}], 
      LineBox[{{118.12796072153105`, 61.53267667288459}, {120.99038105676658`,
        63.67949192431123}, {122.48888739433602`, 61.68148347421864}, {
       119.62646705910048`, 59.534668222791986`}, {118.12796072153105`, 
       61.53267667288459}}], 
      LineBox[{{119.62646705910048`, 59.534668222791986`}, {
       122.48888739433602`, 61.68148347421864}, {123., 61.}, {
       120.13757966476446`, 58.85318474857335}, {119.62646705910048`, 
       59.534668222791986`}}], 
      LineBox[{{120.13757966476446`, 58.85318474857335}, {123., 61.}, {
       122.48888739433602`, 61.68148347421864}, {119.62646705910048`, 
       59.534668222791986`}, {120.13757966476446`, 58.85318474857335}}], 
      LineBox[{{119.62646705910048`, 59.53466822279197}, {122.48888739433602`,
        61.68148347421863}, {120.99038105676658`, 63.67949192431122}, {
       118.12796072153104`, 61.53267667288457}, {119.62646705910048`, 
       59.53466822279197}}], 
      LineBox[{{118.12796072153104`, 61.53267667288457}, {120.99038105676658`,
        63.67949192431122}, {118.60660171779821`, 66.85786437626905}, {
       115.74418138256267`, 64.71104912484239}, {118.12796072153104`, 
       61.53267667288457}}], 
      LineBox[{{115.74418138256267`, 64.71104912484239}, {118.60660171779821`,
        66.85786437626905}, {115.5, 70.99999999999999}, {112.63757966476446`, 
       68.85318474857334}, {115.74418138256267`, 64.71104912484239}}], 
      LineBox[{{112.63757966476446`, 68.85318474857334}, {115.5, 
       70.99999999999999}, {111.88228567653782`, 75.82361909794957}, {
       109.01986534130229`, 73.67680384652292}, {112.63757966476446`, 
       68.85318474857334}}], 
      LineBox[{{109.01986534130229`, 73.67680384652292}, {111.88228567653782`,
        75.82361909794957}, {108.00000000000001`, 80.99999999999997}, {
       105.13757966476449`, 78.85318474857331}, {109.01986534130229`, 
       73.67680384652292}}], 
      LineBox[{{105.13757966476446`, 78.85318474857334}, {108., 81.}, {
       104.1177143234622, 86.17638090205041}, {101.25529398822665`, 
       84.02956565062377}, {105.13757966476446`, 78.85318474857334}}], 
      LineBox[{{101.25529398822665`, 84.02956565062377}, {104.1177143234622, 
       86.17638090205041}, {100.50000000000001`, 90.99999999999999}, {
       97.63757966476446, 88.85318474857334}, {101.25529398822665`, 
       84.02956565062377}}], 
      LineBox[{{97.63757966476446, 88.85318474857334}, {100.50000000000001`, 
       90.99999999999999}, {97.3933982822018, 95.14213562373094}, {
       94.53097794696626, 92.99532037230429}, {97.63757966476446, 
       88.85318474857334}}], 
      LineBox[{{94.53097794696625, 92.99532037230429}, {97.39339828220179, 
       95.14213562373095}, {95.00961894323342, 98.32050807568876}, {
       92.14719860799788, 96.1736928242621}, {94.53097794696625, 
       92.99532037230429}}], 
      LineBox[{{92.14719860799788, 96.1736928242621}, {95.00961894323342, 
       98.32050807568876}, {93.51111260566398, 100.31851652578136`}, {
       90.64869227042844, 98.17170127435472}, {92.14719860799788, 
       96.1736928242621}}], 
      LineBox[{{90.64869227042844, 98.17170127435472}, {93.51111260566398, 
       100.31851652578136`}, {93., 101.}, {90.13757966476446, 
       98.85318474857334}, {90.64869227042844, 98.17170127435472}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 110.}, {150., -10.}, {150., -10.}, {150., 110.}, {150., 
       110.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -10.}, {-15., -10.}, {-15., -10.}, {150., -10.}, {
       150., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-15., -10.}, {-15., 110.}, {-15., 
       110.}, {-15., -10.}, {-15., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-15., 110.}, {150., 110.}, {150., 110.}, {-15., 110.}, {-15., 
       110.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -10.}, {150., 110.}, {-15., 110.}, {-15., -10.}, {
       150., -10.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 110.}, {150., -10.}, {-15., -10.}, {-15., 110.}, {150., 
       110.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 50.}, {95.14966476331746, 82.82999632134049}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 50.}, {96.86994877561456, 79.68313285729919}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 50.}, {98.87434230852155, 76.56034678627806}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 50.}, {101.22040059909278`, 73.43602216312671}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 50.}, {103.99804223447563`, 70.28345145360639}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 50.}, {107.35416047877739`, 67.07284793339015}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.14966476331746, 82.82999632134049}, {103.99361394419383`, 
       86.34184807440823}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.86994877561456, 79.68313285729919}, {106.19854730487351`, 
       83.40193692683532}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{98.87434230852155, 76.56034678627806}, {108.44237151172086`, 
       80.41017131770552}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{101.22040059909278`, 73.43602216312671}, {
       110.74668055592599`, 77.33775925876535}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.99804223447563`, 70.28345145360639}, {
       113.14190362725307`, 74.14412849699592}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{107.35416047877739`, 67.07284793339015}, {
       115.67732333940853`, 70.76356888078863}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.99361394419383`, 86.34184807440823}, {150., 
       97.28462815425999}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{106.19854730487351`, 83.40193692683532}, {150., 
       93.91956578547612}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{108.44237151172086`, 80.41017131770552}, {150., 
       90.6140915225931}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110.74668055592599`, 77.33775925876535}, {150., 
       87.38750770061468}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{113.14190362725307`, 74.14412849699592}, {150., 
       84.25564693730398}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{115.67732333940853`, 70.76356888078863}, {150., 
       81.22935189407438}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{95.14966476331746, 82.82999632134049}, {96.86994877561456, 
      79.68313285729919}, {98.87434230852155, 76.56034678627806}, {
      101.22040059909278`, 73.43602216312671}, {103.99804223447563`, 
      70.28345145360639}, {107.35416047877739`, 67.07284793339015}, {
      103.99361394419383`, 86.34184807440823}, {106.19854730487351`, 
      83.40193692683532}, {108.44237151172086`, 80.41017131770552}, {
      110.74668055592599`, 77.33775925876535}, {113.14190362725307`, 
      74.14412849699592}, {115.67732333940853`, 70.76356888078863}, {150., 
      97.28462815425999}, {150., 93.91956578547612}, {150., 
      90.6140915225931}, {150., 87.38750770061468}, {150., 
      84.25564693730398}, {150., 81.22935189407438}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  Epilog:>{
    Dashing[{0.015}], 
    Thickness[0.01], 
    LineBox[{{100, 75}, {0, 0}}], 
    LineBox[{{0, 50}, {100, 75}}], 
    InsetBox[
     FormBox["\"a\"", TraditionalForm], {93, 80}], 
    InsetBox[
     FormBox["\"b\"", TraditionalForm], {-5, 5}], 
    InsetBox[
     FormBox["\"c\"", TraditionalForm], {-5, 50}]},
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.601286917904685*^9, 3.614727107002133*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"},
 CellLabel->"During evaluation of In[59]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["MoveDirected", "MB"],
 " puts components and sources at a point and orients them toward a second  \
point."
}], "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],

Cell[TextData[{
 "The light source position is ",
 StyleBox["c", "MB"],
 ", oriented toward ",
 StyleBox["a", "MB"],
 ".  The lens position is ",
 StyleBox["a", "MB"],
 ", oriented toward ",
 StyleBox["b", "MB"],
 "."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],

Cell[TextData[{
 "The ",
 StyleBox["SideOfObject", "MB"],
 " option applies ",
 "only",
 " to ",
 StyleBox["MoveDirected", "MB"],
 ".  This option specifies which side of the component or light source is  \
taken by the first input point, and this assigns the orientation of the  \
component or light source.  In the case of light sources, the first input  \
point is usually located on the positive side of the source's local optical  \
axis, and ",
 StyleBox["After", "MB"],
 " is specified for ",
 StyleBox["SideOfObject", "MB"],
 ".  In the case of optical components, the first input point is usually  \
located on the negative side of the component's local optical axis so that ",
 StyleBox["Before", "MB"],
 " is used. The net effect of ",
 StyleBox["SideOfObject", "MB"],
 " is a 180 degree flip in the orientation of the object."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2.6 MoveReflected", "Subsection",
 CellTags->{
  "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
   "PR2.2.6"}],

Cell[TextData[{
 "The idea of ",
 StyleBox["MoveReflected", "MB"],
 " is to angle a mirror according to incident and reflected beams.  The  \
function accepts three distinct points ",
 StyleBox["a", "MB"],
 ", ",
 StyleBox["b", "MB"],
 ", and ",
 StyleBox["c", "MB"],
 ".  Point ",
 StyleBox["b", "MB"],
 " gives the absolute position of the mirror.  This position is independent  \
of the mirror's orientation.  The orientation arises from consideration of  \
all three points.  The following diagram clarifies the geometry involved.   \
This is a two-dimensional example and therefore the points are defined in two \
 dimensions.  The function also works in three dimensions."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "define", " ", "points", " ", "of", " ", "triangle", " ", "and", " ", 
    "bisection", " ", "intercept", " ", "\"\<d\>\""}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"{", 
      RowBox[{"100", ",", "75"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"{", 
      RowBox[{"100", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "0"}], "}"}], "/.", 
       RowBox[{"First", "[", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"100", "-", "x"}], ")"}], "/", "75"}], "\[Equal]", 
           RowBox[{"Tan", "[", 
            RowBox[{
             RowBox[{"ArcTan", "[", 
              RowBox[{"100", "/", "75"}], "]"}], "/", "2"}], "]"}]}], ",", 
          "x"}], "]"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AnalyzeSystem", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MoveDirected", "[", 
         RowBox[{
          RowBox[{"WedgeOfRays", "[", 
           RowBox[{"10", ",", 
            RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", "a", ",", 
          "b", ",", 
          RowBox[{"SideOfObject", "\[Rule]", "After"}]}], "]"}], ",", 
        RowBox[{"MoveReflected", "[", 
         RowBox[{
          RowBox[{"Mirror", "[", 
           RowBox[{"50", ",", "\"\<mirror\>\""}], "]"}], ",", "a", ",", "b", 
          ",", "c"}], "]"}], ",", 
        RowBox[{"MoveDirected", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10", ",", "\"\<\>\""}], "]"}], ",",
           "c", ",", "b", ",", 
          RowBox[{"SideOfObject", "\[Rule]", "Before"}]}], "]"}], ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "50"}], ",", 
            RowBox[{"-", "50"}], ",", 
            RowBox[{"-", "50"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"150", ",", "150", ",", "100"}], "}"}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Dashing", "[", 
          RowBox[{"{", "0.015", "}"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}], ",", 
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"b", ",", "d"}], "}"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<a\>\"", ",", 
           RowBox[{"a", "+", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5"}], ",", 
              RowBox[{"-", "5"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<b\>\"", ",", 
           RowBox[{"b", "+", 
            RowBox[{"{", 
             RowBox[{"0", ",", "5"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<c\>\"", ",", 
           RowBox[{"c", "+", 
            RowBox[{"{", 
             RowBox[{"5", ",", "5"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<d\>\"", ",", 
           RowBox[{"d", "+", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
     "]"}], ";"}]}]}]], "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"},
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ivar"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(5\\)\[NoBreak] is not a valid variable. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/ivar\\\", \
ButtonNote -> \\\"Solve::ivar\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727107139105*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"},
 CellLabel->"During evaluation of In[63]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({False}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727107180169*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"},
 CellLabel->"During evaluation of In[63]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({False}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6147271072121964`*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"},
 CellLabel->"During evaluation of In[63]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{122.36067977499789`, 63.819660112501055`}, {
      122.36067977499789`, 63.819660112501055`}, {114.90711984999861`, 
      67.5464400750007}, {114.9071198499986, 67.5464400750007}, {
      122.36067977499789`, 63.819660112501055`}}], 
     PolygonBox[{{114.9071198499986, 67.5464400750007}, {114.90711984999861`, 
      67.5464400750007}, {107.4535599249993, 71.27322003750035}, {
      107.4535599249993, 71.27322003750035}, {114.9071198499986, 
      67.5464400750007}}], 
     PolygonBox[{{107.4535599249993, 71.27322003750035}, {107.4535599249993, 
      71.27322003750035}, {100., 75.}, {100., 75.}, {107.4535599249993, 
      71.27322003750035}}], 
     PolygonBox[{{100., 75.}, {100., 75.}, {92.5464400750007, 
      78.72677996249965}, {92.5464400750007, 78.72677996249965}, {100., 
      75.}}], PolygonBox[{{92.5464400750007, 78.72677996249965}, {
      92.5464400750007, 78.72677996249965}, {85.0928801500014, 
      82.4535599249993}, {85.0928801500014, 82.4535599249993}, {
      92.5464400750007, 78.72677996249965}}], 
     PolygonBox[{{85.0928801500014, 82.4535599249993}, {85.0928801500014, 
      82.4535599249993}, {77.63932022500211, 86.18033988749895}, {
      77.63932022500211, 86.18033988749895}, {85.0928801500014, 
      82.4535599249993}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{122.36067977499789`, 63.819660112501055`}, {114.9071198499986,
        67.5464400750007}, {107.4535599249993, 71.27322003750035}, {100., 
       75.}, {92.5464400750007, 78.72677996249965}, {85.0928801500014, 
       82.4535599249993}, {77.63932022500211, 86.18033988749895}, {
       77.63932022500211, 86.18033988749895}, {85.0928801500014, 
       82.4535599249993}, {92.5464400750007, 78.72677996249965}, {100., 
       75.}, {107.4535599249993, 71.27322003750035}, {114.9071198499986, 
       67.5464400750007}, {122.36067977499789`, 63.819660112501055`}, {
       122.36067977499789`, 63.819660112501055`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}}], PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}, {100., 75.}}], 
       PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}}], PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}, {100., 75.}}], 
       PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}}], PolygonBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 
        75.}, {100., 75.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
         75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
         75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 75.}, {100., 
         75.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{100., 75.}, {92.5464400750007, 78.72677996249965}, {
      92.80041397064997, 78.59979301467502}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{92.5464400750007, 78.72677996249965}, {85.0928801500014, 
      82.4535599249993}, {85.60082794129993, 82.19958602935003}, {
      92.80041397064997, 78.59979301467502}, {92.5464400750007, 
      78.72677996249965}}], 
     PolygonBox[{{85.0928801500014, 82.4535599249993}, {77.63932022500211, 
      86.18033988749895}, {78.4012419119499, 85.79937904402505}, {
      85.60082794129993, 82.19958602935003}, {85.0928801500014, 
      82.4535599249993}}], 
     PolygonBox[{{100., 75.}, {92.80041397064997, 78.59979301467502}, {
      93.54502775632098, 78.22748612183952}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{92.80041397064997, 78.59979301467502}, {85.60082794129993, 
      82.19958602935003}, {87.09005551264194, 81.45497224367902}, {
      93.54502775632098, 78.22748612183952}, {92.80041397064997, 
      78.59979301467502}}], 
     PolygonBox[{{85.60082794129993, 82.19958602935003}, {78.4012419119499, 
      85.79937904402505}, {80.63508326896292, 84.68245836551854}, {
      87.09005551264194, 81.45497224367902}, {85.60082794129993, 
      82.19958602935003}}], 
     PolygonBox[{{100., 75.}, {93.54502775632098, 78.22748612183952}, {
      94.7295372330527, 77.63523138347365}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{93.54502775632098, 78.22748612183952}, {87.09005551264194, 
      81.45497224367902}, {89.4590744661054, 80.2704627669473}, {
      94.7295372330527, 77.63523138347365}, {93.54502775632098, 
      78.22748612183952}}], 
     PolygonBox[{{87.09005551264194, 81.45497224367902}, {80.63508326896292, 
      84.68245836551854}, {84.1886116991581, 82.90569415042094}, {
      89.4590744661054, 80.2704627669473}, {87.09005551264194, 
      81.45497224367902}}], 
     PolygonBox[{{100., 75.}, {94.7295372330527, 77.63523138347365}, {
      96.27322003750035, 76.86338998124982}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{94.7295372330527, 77.63523138347365}, {89.4590744661054, 
      80.2704627669473}, {92.5464400750007, 78.72677996249965}, {
      96.27322003750035, 76.86338998124982}, {94.7295372330527, 
      77.63523138347365}}], 
     PolygonBox[{{89.4590744661054, 80.2704627669473}, {84.1886116991581, 
      82.90569415042094}, {88.81966011250105, 80.59016994374947}, {
      92.5464400750007, 78.72677996249965}, {89.4590744661054, 
      80.2704627669473}}], 
     PolygonBox[{{100., 75.}, {96.27322003750035, 76.86338998124982}, {
      98.07087673759726, 75.96456163120136}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{96.27322003750035, 76.86338998124982}, {92.5464400750007, 
      78.72677996249965}, {96.14175347519453, 76.92912326240274}, {
      98.07087673759726, 75.96456163120136}, {96.27322003750035, 
      76.86338998124982}}], 
     PolygonBox[{{92.5464400750007, 78.72677996249965}, {88.81966011250105, 
      80.59016994374947}, {94.2126302127918, 77.8936848936041}, {
      96.14175347519453, 76.92912326240274}, {92.5464400750007, 
      78.72677996249965}}], 
     PolygonBox[{{100., 75.}, {98.07087673759726, 75.96456163120136}, {100., 
      75.}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{98.07087673759726, 75.96456163120136}, {96.14175347519453, 
      76.92912326240274}, {100., 75.}, {100., 75.}, {98.07087673759726, 
      75.96456163120136}}], 
     PolygonBox[{{96.14175347519453, 76.92912326240274}, {94.2126302127918, 
      77.8936848936041}, {100., 75.}, {100., 75.}, {96.14175347519453, 
      76.92912326240274}}], 
     PolygonBox[{{100., 75.}, {100., 75.}, {101.92912326240274`, 
      74.03543836879864}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{100., 75.}, {100., 75.}, {103.85824652480547`, 
      73.07087673759726}, {101.92912326240274`, 74.03543836879864}, {100., 
      75.}}], PolygonBox[{{100., 75.}, {100., 75.}, {105.7873697872082, 
      72.1063151063959}, {103.85824652480547`, 73.07087673759726}, {100., 
      75.}}], PolygonBox[{{100., 75.}, {101.92912326240274`, 
      74.03543836879864}, {103.72677996249965`, 73.13661001875018}, {100., 
      75.}, {100., 75.}}], 
     PolygonBox[{{101.92912326240274`, 74.03543836879864}, {
      103.85824652480547`, 73.07087673759726}, {107.4535599249993, 
      71.27322003750035}, {103.72677996249965`, 73.13661001875018}, {
      101.92912326240274`, 74.03543836879864}}], 
     PolygonBox[{{103.85824652480547`, 73.07087673759726}, {105.7873697872082,
       72.1063151063959}, {111.18033988749895`, 69.40983005625053}, {
      107.4535599249993, 71.27322003750035}, {103.85824652480547`, 
      73.07087673759726}}], 
     PolygonBox[{{100., 75.}, {103.72677996249965`, 73.13661001875018}, {
      105.2704627669473, 72.36476861652635}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{103.72677996249965`, 73.13661001875018}, {107.4535599249993,
       71.27322003750035}, {110.5409255338946, 69.7295372330527}, {
      105.2704627669473, 72.36476861652635}, {103.72677996249965`, 
      73.13661001875018}}], 
     PolygonBox[{{107.4535599249993, 71.27322003750035}, {111.18033988749895`,
       69.40983005625053}, {115.8113883008419, 67.09430584957906}, {
      110.5409255338946, 69.7295372330527}, {107.4535599249993, 
      71.27322003750035}}], 
     PolygonBox[{{100., 75.}, {105.2704627669473, 72.36476861652635}, {
      106.45497224367902`, 71.77251387816048}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{105.2704627669473, 72.36476861652635}, {110.5409255338946, 
      69.7295372330527}, {112.90994448735806`, 68.54502775632098}, {
      106.45497224367902`, 71.77251387816048}, {105.2704627669473, 
      72.36476861652635}}], 
     PolygonBox[{{110.5409255338946, 69.7295372330527}, {115.8113883008419, 
      67.09430584957906}, {119.36491673103708`, 65.31754163448146}, {
      112.90994448735806`, 68.54502775632098}, {110.5409255338946, 
      69.7295372330527}}], 
     PolygonBox[{{100., 75.}, {106.45497224367902`, 71.77251387816048}, {
      107.19958602935003`, 71.40020698532498}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{106.45497224367902`, 71.77251387816048}, {
      112.90994448735805`, 68.54502775632098}, {114.39917205870007`, 
      67.80041397064997}, {107.19958602935003`, 71.40020698532498}, {
      106.45497224367902`, 71.77251387816048}}], 
     PolygonBox[{{112.90994448735805`, 68.54502775632098}, {
      119.36491673103708`, 65.31754163448146}, {121.5987580880501, 
      64.20062095597495}, {114.39917205870007`, 67.80041397064997}, {
      112.90994448735805`, 68.54502775632098}}], 
     PolygonBox[{{100., 75.}, {107.19958602935003`, 71.40020698532498}, {
      107.4535599249993, 71.27322003750035}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{107.19958602935003`, 71.40020698532498}, {
      114.39917205870007`, 67.80041397064997}, {114.9071198499986, 
      67.5464400750007}, {107.4535599249993, 71.27322003750035}, {
      107.19958602935003`, 71.40020698532498}}], 
     PolygonBox[{{114.39917205870007`, 67.80041397064997}, {121.5987580880501,
       64.20062095597495}, {122.36067977499789`, 63.819660112501055`}, {
      114.9071198499986, 67.5464400750007}, {114.39917205870007`, 
      67.80041397064997}}], 
     PolygonBox[{{100., 75.}, {107.4535599249993, 71.27322003750035}, {
      107.19958602935003`, 71.40020698532498}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{107.4535599249993, 71.27322003750035}, {114.9071198499986, 
      67.5464400750007}, {114.39917205870007`, 67.80041397064997}, {
      107.19958602935003`, 71.40020698532498}, {107.4535599249993, 
      71.27322003750035}}], 
     PolygonBox[{{114.9071198499986, 67.5464400750007}, {122.36067977499789`, 
      63.819660112501055`}, {121.5987580880501, 64.20062095597495}, {
      114.39917205870007`, 67.80041397064997}, {114.9071198499986, 
      67.5464400750007}}], 
     PolygonBox[{{100., 75.}, {107.19958602935003`, 71.40020698532498}, {
      106.45497224367902`, 71.77251387816048}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{107.19958602935003`, 71.40020698532498}, {
      114.39917205870007`, 67.80041397064997}, {112.90994448735806`, 
      68.54502775632098}, {106.45497224367902`, 71.77251387816048}, {
      107.19958602935003`, 71.40020698532498}}], 
     PolygonBox[{{114.39917205870007`, 67.80041397064997}, {121.5987580880501,
       64.20062095597495}, {119.36491673103708`, 65.31754163448146}, {
      112.90994448735806`, 68.54502775632098}, {114.39917205870007`, 
      67.80041397064997}}], 
     PolygonBox[{{100., 75.}, {106.45497224367902`, 71.77251387816048}, {
      105.2704627669473, 72.36476861652635}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{106.45497224367902`, 71.77251387816048}, {
      112.90994448735806`, 68.54502775632098}, {110.54092553389461`, 
      69.7295372330527}, {105.2704627669473, 72.36476861652635}, {
      106.45497224367902`, 71.77251387816048}}], 
     PolygonBox[{{112.90994448735806`, 68.54502775632098}, {
      119.36491673103708`, 65.31754163448146}, {115.8113883008419, 
      67.09430584957906}, {110.54092553389461`, 69.7295372330527}, {
      112.90994448735806`, 68.54502775632098}}], 
     PolygonBox[{{100., 75.}, {105.2704627669473, 72.36476861652635}, {
      103.72677996249965`, 73.13661001875018}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{105.2704627669473, 72.36476861652635}, {110.54092553389461`,
       69.7295372330527}, {107.45355992499931`, 71.27322003750035}, {
      103.72677996249965`, 73.13661001875018}, {105.2704627669473, 
      72.36476861652635}}], 
     PolygonBox[{{110.54092553389461`, 69.7295372330527}, {
      115.81138830084191`, 67.09430584957904}, {111.18033988749896`, 
      69.40983005625053}, {107.45355992499931`, 71.27322003750035}, {
      110.54092553389461`, 69.7295372330527}}], 
     PolygonBox[{{100., 75.}, {103.72677996249965`, 73.13661001875018}, {
      101.92912326240274`, 74.03543836879862}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{103.72677996249965`, 73.13661001875018}, {
      107.45355992499931`, 71.27322003750035}, {103.85824652480548`, 
      73.07087673759726}, {101.92912326240274`, 74.03543836879862}, {
      103.72677996249965`, 73.13661001875018}}], 
     PolygonBox[{{107.45355992499931`, 71.27322003750035}, {
      111.18033988749896`, 69.40983005625053}, {105.78736978720822`, 
      72.1063151063959}, {103.85824652480548`, 73.07087673759726}, {
      107.45355992499931`, 71.27322003750035}}], 
     PolygonBox[{{100., 75.}, {101.92912326240274`, 74.03543836879862}, {
      100.00000000000001`, 75.}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{101.92912326240274`, 74.03543836879862}, {
      103.85824652480548`, 73.07087673759726}, {100.00000000000001`, 
      74.99999999999999}, {100.00000000000001`, 75.}, {101.92912326240274`, 
      74.03543836879862}}], 
     PolygonBox[{{103.85824652480548`, 73.07087673759726}, {
      105.78736978720822`, 72.1063151063959}, {100.00000000000003`, 
      74.99999999999999}, {100.00000000000001`, 74.99999999999999}, {
      103.85824652480548`, 73.07087673759726}}], 
     PolygonBox[{{100., 75.}, {100., 75.}, {98.07087673759727, 
      75.96456163120136}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{100., 75.}, {100., 75.}, {96.14175347519453, 
      76.92912326240273}, {98.07087673759727, 75.96456163120136}, {100., 
      75.}}], PolygonBox[{{100., 75.}, {100., 75.}, {94.21263021279181, 
      77.8936848936041}, {96.14175347519453, 76.92912326240273}, {100., 
      75.}}], PolygonBox[{{100., 75.}, {98.07087673759727, 
      75.96456163120136}, {96.27322003750035, 76.86338998124982}, {100., 
      75.}, {100., 75.}}], 
     PolygonBox[{{98.07087673759727, 75.96456163120136}, {96.14175347519453, 
      76.92912326240273}, {92.54644007500072, 78.72677996249965}, {
      96.27322003750035, 76.86338998124982}, {98.07087673759727, 
      75.96456163120136}}], 
     PolygonBox[{{96.14175347519453, 76.92912326240273}, {94.21263021279181, 
      77.8936848936041}, {88.81966011250107, 80.59016994374947}, {
      92.54644007500072, 78.72677996249965}, {96.14175347519453, 
      76.92912326240273}}], 
     PolygonBox[{{100., 75.}, {96.27322003750035, 76.86338998124982}, {
      94.72953723305271, 77.63523138347365}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{96.27322003750035, 76.86338998124982}, {92.54644007500072, 
      78.72677996249965}, {89.4590744661054, 80.27046276694729}, {
      94.72953723305271, 77.63523138347365}, {96.27322003750035, 
      76.86338998124982}}], 
     PolygonBox[{{92.54644007500072, 78.72677996249965}, {88.81966011250107, 
      80.59016994374947}, {84.18861169915812, 82.90569415042094}, {
      89.4590744661054, 80.27046276694729}, {92.54644007500072, 
      78.72677996249965}}], 
     PolygonBox[{{100., 75.}, {94.7295372330527, 77.63523138347365}, {
      93.54502775632098, 78.22748612183952}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{94.7295372330527, 77.63523138347365}, {89.4590744661054, 
      80.2704627669473}, {87.09005551264195, 81.45497224367902}, {
      93.54502775632098, 78.22748612183952}, {94.7295372330527, 
      77.63523138347365}}], 
     PolygonBox[{{89.4590744661054, 80.2704627669473}, {84.1886116991581, 
      82.90569415042094}, {80.63508326896292, 84.68245836551854}, {
      87.09005551264195, 81.45497224367902}, {89.4590744661054, 
      80.2704627669473}}], 
     PolygonBox[{{100., 75.}, {93.54502775632098, 78.22748612183952}, {
      92.80041397064997, 78.59979301467502}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{93.54502775632098, 78.22748612183952}, {87.09005551264195, 
      81.45497224367902}, {85.60082794129994, 82.19958602935003}, {
      92.80041397064997, 78.59979301467502}, {93.54502775632098, 
      78.22748612183952}}], 
     PolygonBox[{{87.09005551264195, 81.45497224367902}, {80.63508326896292, 
      84.68245836551854}, {78.4012419119499, 85.79937904402505}, {
      85.60082794129994, 82.19958602935003}, {87.09005551264195, 
      81.45497224367902}}], 
     PolygonBox[{{100., 75.}, {92.80041397064997, 78.59979301467502}, {
      92.5464400750007, 78.72677996249965}, {100., 75.}, {100., 75.}}], 
     PolygonBox[{{92.80041397064997, 78.59979301467502}, {85.60082794129994, 
      82.19958602935003}, {85.0928801500014, 82.4535599249993}, {
      92.5464400750007, 78.72677996249965}, {92.80041397064997, 
      78.59979301467502}}], 
     PolygonBox[{{85.60082794129994, 82.19958602935003}, {78.4012419119499, 
      85.79937904402505}, {77.63932022500211, 86.18033988749895}, {
      85.0928801500014, 82.4535599249993}, {85.60082794129994, 
      82.19958602935003}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3dOcMP9VRrCD1T7/DV3doQ7/0/o+rZ0Z7NBwZgeb
ZnGow7rZ3iZLNUIcNI1upa7VDnXY/fCsmRBPqIMS/8wn33aGOBxz3OBfahLm
IHtfPeKoaoiDS+uB3bN7wx3i9sorGVUGOzCAQSSEPhDksKfK3iWlKMphkdOD
u2fZgiD2no52eKxwY7lVVKCDq5zRybefYxzufUiT5jwW4BCUsuV01PVYh+tn
VWcFhQQ4MM4s5A1Ki3NoMHb/eY0nwKGkZn6C6PQ4B7A/XvhjyKPrd4Oafxdq
vjWa/XvR3Ifuflc0/x1H8z96+KCHH3r4ooc/AKGKqGc=
       "]]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{75., -6.421974580955592}, {75., -10.}, {
      83.33333333333333, -10.}, {83.33333333333333, -2.7504488342847893`}, {
      75., -6.421974580955592}}], 
     PolygonBox[{{83.33333333333333, -2.7504488342847893`}, {
      83.33333333333333, -10.}, {91.66666666666666, -10.}, {
      91.66666666666666, -0.6737579958920605}, {
      83.33333333333333, -2.7504488342847893`}}], 
     PolygonBox[{{91.66666666666666, -0.6737579958920605}, {
      91.66666666666666, -10.}, {100., -10.}, {100., 0.}, {
      91.66666666666666, -0.6737579958920605}}], 
     PolygonBox[{{100., 0.}, {100., -10.}, {108.33333333333333`, -10.}, {
      108.33333333333333`, -0.6737579958920605}, {100., 0.}}], 
     PolygonBox[{{108.33333333333333`, -0.6737579958920605}, {
      108.33333333333333`, -10.}, {116.66666666666666`, -10.}, {
      116.66666666666666`, -2.7504488342847893`}, {
      108.33333333333333`, -0.6737579958920605}}], 
     PolygonBox[{{116.66666666666666`, -2.7504488342847893`}, {
      116.66666666666666`, -10.}, {125., -10.}, {125., -6.421974580955592}, {
      116.66666666666666`, -2.7504488342847893`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -6.421974580955592}, {
       83.33333333333333, -2.7504488342847893`}, {
       91.66666666666666, -0.6737579958920605}, {100., 0.}, {
       108.33333333333333`, -0.6737579958920605}, {
       116.66666666666666`, -2.750448834284782}, {125., -6.421974580955592}, {
       125., -10.}, {116.66666666666667`, -10.}, {
       108.33333333333334`, -10.}, {100., -10.}, {91.66666666666667, -10.}, {
       83.33333333333334, -10.}, {75., -10.}, {75., -6.421974580955592}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{100., -6.421974580955592}, {100., -10.}, {100., -10.}, {
        100., -2.7504488342847893`}, {100., -6.421974580955592}}], 
       PolygonBox[{{100., -2.7504488342847893`}, {100., -10.}, {100., -10.}, {
        100., -0.6737579958920605}, {100., -2.7504488342847893`}}], 
       PolygonBox[{{100., -0.6737579958920605}, {100., -10.}, {100., -10.}, {
        100., 0.}, {100., -0.6737579958920605}}], 
       PolygonBox[{{100., 0.}, {100., -10.}, {100., -10.}, {
        100., -0.6737579958920605}, {100., 0.}}], 
       PolygonBox[{{100., -0.6737579958920605}, {100., -10.}, {100., -10.}, {
        100., -2.7504488342847893`}, {100., -0.6737579958920605}}], 
       PolygonBox[{{100., -2.7504488342847893`}, {100., -10.}, {100., -10.}, {
        100., -6.421974580955592}, {100., -2.7504488342847893`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{100., -6.421974580955592}, {100., -2.7504488342847893`}, {
         100., -0.6737579958920605}, {100., 0.}, {
         100., -0.6737579958920605}, {100., -2.750448834284782}, {
         100., -6.421974580955592}, {100., -10.}, {100., -10.}, {
         100., -10.}, {100., -10.}, {100., -10.}, {100., -10.}, {
         100., -10.}, {100., -6.421974580955592}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{125., -6.421974580955592}, {125., -10.}, {
       124.1481456572267, -10.}, {124.1481456572267, -6.421974580955592}, {
       125., -6.421974580955592}}], 
      LineBox[{{124.1481456572267, -6.421974580955592}, {
       124.1481456572267, -10.}, {121.65063509461098`, -10.}, {
       121.65063509461098`, -6.421974580955592}, {
       124.1481456572267, -6.421974580955592}}], 
      LineBox[{{121.65063509461098`, -6.421974580955592}, {
       121.65063509461098`, -10.}, {117.67766952966369`, -10.}, {
       117.67766952966369`, -6.421974580955592}, {
       121.65063509461098`, -6.421974580955592}}], 
      LineBox[{{117.67766952966369`, -6.421974580955592}, {
       117.67766952966369`, -10.}, {112.5, -10.}, {
       112.5, -6.421974580955592}, {
       117.67766952966369`, -6.421974580955592}}], 
      LineBox[{{112.5, -6.421974580955592}, {112.5, -10.}, {
       106.47047612756302`, -10.}, {
       106.47047612756302`, -6.421974580955592}, {
       112.5, -6.421974580955592}}], 
      LineBox[{{106.47047612756302`, -6.421974580955592}, {
       106.47047612756302`, -10.}, {100., -10.}, {100., -6.421974580955592}, {
       106.47047612756302`, -6.421974580955592}}], 
      LineBox[{{100., -6.421974580955592}, {100., -10.}, {
       93.52952387243698, -10.}, {93.52952387243698, -6.421974580955592}, {
       100., -6.421974580955592}}], 
      LineBox[{{93.52952387243698, -6.421974580955592}, {
       93.52952387243698, -10.}, {87.5, -10.}, {87.5, -6.421974580955592}, {
       93.52952387243698, -6.421974580955592}}], 
      LineBox[{{87.5, -6.421974580955592}, {87.5, -10.}, {
       82.32233047033631, -10.}, {82.32233047033631, -6.421974580955592}, {
       87.5, -6.421974580955592}}], 
      LineBox[{{82.32233047033631, -6.421974580955592}, {
       82.32233047033631, -10.}, {78.34936490538902, -10.}, {
       78.34936490538902, -6.421974580955592}, {
       82.32233047033631, -6.421974580955592}}], 
      LineBox[{{78.34936490538904, -6.421974580955599}, {
       78.34936490538904, -10.}, {75.8518543427733, -10.}, {
       75.8518543427733, -6.421974580955592}, {
       78.34936490538904, -6.421974580955599}}], 
      LineBox[{{75.8518543427733, -6.421974580955592}, {
       75.8518543427733, -10.}, {75., -10.}, {75., -6.421974580955592}, {
       75.8518543427733, -6.421974580955592}}], 
      LineBox[{{75., -6.421974580955592}, {75., -10.}, {
       75.8518543427733, -10.}, {75.8518543427733, -6.421974580955592}, {
       75., -6.421974580955592}}], 
      LineBox[{{75.8518543427733, -6.421974580955592}, {
       75.8518543427733, -10.}, {78.34936490538902, -10.}, {
       78.34936490538902, -6.421974580955592}, {
       75.8518543427733, -6.421974580955592}}], 
      LineBox[{{78.34936490538902, -6.421974580955592}, {
       78.34936490538902, -10.}, {82.32233047033631, -10.}, {
       82.32233047033631, -6.421974580955592}, {
       78.34936490538902, -6.421974580955592}}], 
      LineBox[{{82.32233047033631, -6.421974580955592}, {
       82.32233047033631, -10.}, {87.49999999999999, -10.}, {
       87.49999999999999, -6.421974580955592}, {
       82.32233047033631, -6.421974580955592}}], 
      LineBox[{{87.49999999999999, -6.421974580955592}, {
       87.49999999999999, -10.}, {93.52952387243697, -10.}, {
       93.52952387243697, -6.421974580955592}, {
       87.49999999999999, -6.421974580955592}}], 
      LineBox[{{93.52952387243697, -6.421974580955592}, {
       93.52952387243697, -10.}, {99.99999999999997, -10.}, {
       99.99999999999997, -6.421974580955592}, {
       93.52952387243697, -6.421974580955592}}], 
      LineBox[{{100., -6.421974580955592}, {100., -10.}, {
       106.470476127563, -10.}, {106.470476127563, -6.421974580955592}, {
       100., -6.421974580955592}}], 
      LineBox[{{106.470476127563, -6.421974580955592}, {
       106.470476127563, -10.}, {112.49999999999999`, -10.}, {
       112.49999999999999`, -6.421974580955592}, {
       106.470476127563, -6.421974580955592}}], 
      LineBox[{{112.49999999999999`, -6.421974580955592}, {
       112.49999999999999`, -10.}, {117.67766952966367`, -10.}, {
       117.67766952966367`, -6.421974580955599}, {
       112.49999999999999`, -6.421974580955592}}], 
      LineBox[{{117.67766952966369`, -6.421974580955592}, {
       117.67766952966369`, -10.}, {121.65063509461096`, -10.}, {
       121.65063509461096`, -6.421974580955592}, {
       117.67766952966369`, -6.421974580955592}}], 
      LineBox[{{121.65063509461096`, -6.421974580955592}, {
       121.65063509461096`, -10.}, {124.1481456572267, -10.}, {
       124.1481456572267, -6.421974580955592}, {
       121.65063509461096`, -6.421974580955592}}], 
      LineBox[{{124.1481456572267, -6.421974580955592}, {
       124.1481456572267, -10.}, {125., -10.}, {125., -6.421974580955592}, {
       124.1481456572267, -6.421974580955592}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 150.}, {150., -50.}, {150., -50.}, {150., 150.}, {150., 
       150.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -50.}, {-50., -50.}, {-50., -50.}, {150., -50.}, {
       150., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., -50.}, {-50., 150.}, {-50., 
       150.}, {-50., -50.}, {-50., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-50., 150.}, {150., 150.}, {150., 150.}, {-50., 150.}, {-50., 
       150.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -50.}, {150., 150.}, {-50., 150.}, {-50., -50.}, {
       150., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 150.}, {150., -50.}, {-50., -50.}, {-50., 150.}, {150., 
       150.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {89.52225884449247, 80.23887057775376}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {93.61630522305994, 78.19184738847002}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {97.83699458396134, 76.08150270801933}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {102.20109322863667`, 73.89945338568167}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {106.72725259496941`, 71.63637370251533}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {111.43635881489975`, 69.2818205925501}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.52225884449247, 80.23887057775376}, {
       82.22758709910394, -3.1396090035127315`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.61630522305994, 78.19184738847002}, {
       89.46175217966456, -1.0817471089748096`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.83699458396134, 76.08150270801933}, {
       96.50693176023043, -0.1177454300250389}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{102.20109322863667`, 73.89945338568167}, {
       103.49306823976963`, -0.11774543002501048`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{106.72725259496941`, 71.63637370251533}, {
       110.53824782033554`, -1.0817471089748523`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{111.43635881489975`, 69.2818205925501}, {
       117.7724129008961, -3.139609003512703}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.22758709910394, -3.1396090035127315`}, {
       82.69052767037532, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.46175217966456, -1.0817471089748096`}, {
       89.78743081301188, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.50693176023043, -0.1177454300250389}, {
       96.62133391615386, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.49306823976963`, -0.11774543002501048`}, {
       103.3786660838462, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110.53824782033554`, -1.0817471089748523`}, {
       110.21256918698822`, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{117.7724129008961, -3.139609003512703}, {
       117.30947232962473`, -10.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{82.69052767037532, -10.}, {
       86.8030564890394, -50.00000000000001}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.78743081301188, -10.}, {92.00830660585885, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.62133391615386, -10.}, {
       97.32481437352297, -49.99999999999999}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.3786660838462, -10.}, {
       102.67518562647709`, -49.99999999999999}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110.21256918698822`, -10.}, {107.99169339414124`, -50.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{117.30947232962473`, -10.}, {
       113.19694351096064`, -50.00000000000001}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQLeoZsyEnMcyh9PbF5Z78IQ7xkWXdhenhDgGXXazc
e4IdDjntDpxYGuEwP04p3Jw12MFJRmnbvZ5Ih/sf3y2ZUBnkcPJKuV/3uiiH
eaJHIna9CHQwvdLq+/Z2tMMTUdtIzqBAB7WXVScn9IU4HGh2Cn4ty3mAbSFz
ZG9smANDXiXfNb+P+6fcfzGxUCHCgYHFrHmCyr79BQrieX33Ix0Y/piC+Yzx
f5YVLYp2OABVf1es1Sy/MNahAWreev8fswzXhDgwgIHKgdf5pi6pRWFw/sbC
kPeH1SPg/OC+1QI2NyLhfJkJp3bP6o2G80M2sKeeC46F8z8HcLunbg51YATz
PQ94KeRJdDCEQ+U9DwQ9tjx0MiTC4T8YeBzYJHPM1mx1JJy/5/7E5+X/o+Dq
BdZ/2THLJwZuHgBS4pj+
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  Epilog:>{
    Dashing[{0.015}], 
    Thickness[0.01], 
    LineBox[{{0, 0}, {100, 75}, {100, 0}}], 
    Thickness[0.005], 
    LineBox[{{100, 75}, 
      ReplaceAll[{5., 0.}, False]}], 
    InsetBox[
     FormBox["\"a\"", TraditionalForm], {-5, -5}], 
    InsetBox[
     FormBox["\"b\"", TraditionalForm], {100, 80}], 
    InsetBox[
     FormBox["\"c\"", TraditionalForm], {105, 5}], 
    InsetBox[
     FormBox[
     "\"d\"", TraditionalForm], {-5 + ReplaceAll[{5., 0.}, False], 5 + 
      ReplaceAll[{5., 0.}, False]}]},
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>True,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563366746492565*^9, 3.566086337711321*^9, 
  3.5660863755108213`*^9, 3.567272846258988*^9, 3.6147271077153873`*^9},
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"},
 CellLabel->"During evaluation of In[63]:="]
}, Open  ]],

Cell[TextData[{
 "The geometry of ",
 StyleBox["MoveReflected", "MB"],
 " in two dimensions."
}], "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],

Cell[TextData[{
 "The line ",
 StyleBox["bd", "MB"],
 " bisects angle ",
 StyleBox["abc", "MB"],
 ".  ",
 StyleBox["MoveReflected[mirror, a, b, c]", "MB"],
 " positions the ",
 StyleBox["mirror", "MB"],
 " at ",
 StyleBox["b", "MB"],
 ", and orients its normal vector along ",
 StyleBox["bd", "MB"],
 ".  Effectively this function orients the mirror to receive light from the  \
direction of ",
 StyleBox["a", "MB"],
 " and reflect it in the direction of ",
 StyleBox["c", "MB"],
 " from the vantage of position ",
 StyleBox["b", "MB"],
 ".  ",
 StyleBox["MoveReflected", "MB"],
 " assumes that bisection of the angle ",
 StyleBox["abc", "MB"],
 " will produce a reasonable orientation angle for this purpose.  The  \
mirror's normal vector will always bisect angle ",
 StyleBox["abc", "MB"],
 "."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],

Cell[TextData[{
 "In three dimensions, lines ",
 StyleBox["ab", "MB"],
 " and ",
 StyleBox["bc", "MB"],
 " determine a plane.  The mirror's normal vector will lie in the same plane  \
such that it bisects the angle ",
 StyleBox["abc", "MB"],
 " that is formed in this plane."
}], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 Angular Orientation", "Section",
 CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],

Cell[TextData[{
 "Some of the ",
 StyleBox["Move", "MB"],
 "-related functions that have been presented incorporate their own angular  \
effects.  If none of these satisfies your requirements, you can orient  \
components directly."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],

Cell[TextData[{
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " uses three basic mechanisms to implement rotations:  direction vectors,  \
rotation angles, and twist angles.  There exist other means as well; these  \
are only the most common.  You may also define angular orientations by means  \
of fully general 3-by-3 rotation matrices, for example."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Angular Orientation", "PR2.3"}],

Cell[CellGroupData[{

Cell["2.3.1 Move with Intrinsic Rotation", "Subsection",
 CellTags->{
  "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
   "PR2.3.1"}],

Cell[TextData[{
 "The ",
 StyleBox["Move", "MB"],
 " function not only performs translation, but it can also change component  \
orientation at your option.  ",
 StyleBox["Move", "MB"],
 " offers several ways to define orientation."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[{
 "In three dimensions, you will typically define a ",
 StyleBox["tilt vector",
  FontSlant->"Italic"],
 " and a ",
 StyleBox["twist angle",
  FontSlant->"Italic"],
 ". The twist angle is optional. The tilt vector specifies the direction in  \
which the component faces. The following visualization shows how this method  \
works.  Each display shows two lenses: one lens occupies the default  \
placement at the origin; the other lens some specific placement indicated by  \
input parameters shown above the graphic."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1.01883 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.0242577 0.47619 [

[ 0 0 0 0 ]

[ 1 1.01883 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 1.01883 L

0 1.01883 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.0242577 0.477324 0.48631 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.0184128 1.11086 1.11022e-16 1.11086 [

[.5 1.03133 -55.2 0 ]

[.5 1.03133 55.2 7.2 ]

[.07999 .18147 -4.33011 -7.2 ]

[.07999 .18147 .46989 0 ]

[.28509 .12212 -8.07061 -7.2 ]

[.28509 .12212 1.52939 0 ]

[.50279 .05919 -11.2215 -7.2 ]

[.50279 .05919 3.17851 0 ]

[.73427 -0.0076 -10.3371 -7.2 ]

[.73427 -0.0076 4.06293 0 ]

[.77653 .00912 0 -4.62791 ]

[.77653 .00912 14.4 2.57209 ]

[.84438 .16831 0 -4.54413 ]

[.84438 .16831 4.8 2.65587 ]

[.90296 .30575 0 -4.47298 ]

[.90296 .30575 9.6 2.72702 ]

[.95404 .42562 0 -4.4118 ]

[.95404 .42562 14.4 2.7882 ]

[.05897 .21099 -14.4 -2.57051 ]

[.05897 .21099 0 4.62949 ]

[.03311 .39048 -4.8 -2.6608 ]

[.03311 .39048 0 4.5392 ]

[.00422 .59105 -9.6 -2.76251 ]

[.00422 .59105 0 4.43749 ]

[ 0 0 0 0 ]

[ 1 1.01883 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[({100,50,50},{0,0,-1},45)] .5 1.03133 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

.25 Mabswid

.75767 0 m

.94405 .43703 L

s

.76318 .01294 m

.75651 .01484 L

s

[(-50)] .77653 .00912 -1 .28553 Mshowa

.83095 .17183 m

.82423 .17359 L

s

[(0)] .84438 .16831 -1 .26226 Mshowa

.88946 .30902 m

.88271 .31066 L

s

[(50)] .90296 .30575 -1 .24249 Mshowa

.94049 .42867 m

.93372 .4302 L

s

[(100)] .95404 .42562 -1 .2255 Mshowa

.125 Mabswid

.77758 .0467 m

.77357 .04782 L

s

.79154 .07942 m

.78752 .08053 L

s

.80507 .11115 m

.80105 .11224 L

s

.8182 .14194 m

.81418 .14302 L

s

.84333 .20086 m

.83929 .2019 L

s

.85535 .22905 m

.85132 .23008 L

s

.86704 .25646 m

.863 .25747 L

s

.87841 .2831 m

.87436 .2841 L

s

.90022 .33424 m

.89616 .33521 L

s

.91069 .35879 m

.90663 .35974 L

s

.92088 .3827 m

.91682 .38364 L

s

.93081 .40598 m

.92675 .40691 L

s

.25 Mabswid

.07384 .19656 m

0 .71164 L

s

.07232 .20717 m

.079 .20526 L

s

[(-50)] .05897 .21099 1 -0.28597 Mshowa

.04654 .38698 m

.05326 .38522 L

s

[(0)] .03311 .39048 1 -0.26089 Mshowa

.01774 .5879 m

.0245 .58633 L

s

[(50)] .00422 .59105 1 -0.23264 Mshowa

.125 Mabswid

.06738 .24161 m

.07139 .24048 L

s

.06234 .27678 m

.06636 .27567 L

s

.05719 .31271 m

.06121 .31162 L

s

.05193 .34944 m

.05595 .34837 L

s

.04104 .42536 m

.04508 .42433 L

s

.03541 .46461 m

.03946 .4636 L

s

.02966 .50476 m

.0337 .50377 L

s

.02377 .54585 m

.02782 .54488 L

s

.01157 .63095 m

.01563 .63003 L

s

.00525 .67503 m

.00932 .67414 L

s

0 0 m

1 0 L

1 1.01883 L

0 1.01883 L

closepath

clip

newpath

.5 Mabswid

.92692 .44201 m

.37994 .56463 L

s

.36101 .99851 m

.37994 .56463 L

s

.74617 .02894 m

.92692 .44201 L

s

.92692 .44201 m

.97796 .89707 L

s

.36101 .99851 m

.97796 .89707 L

s

.02943 .70308 m

.36101 .99851 L

s

.28245 .48062 m .26661 .46133 L .24399 .46681 L .659 .748 .916 r

F

.28245 .48062 m .28253 .4806 L .26661 .46133 L F

.24399 .46681 m .28245 .48062 L .28037 .50935 L .822 .574 .564 r

F

0 g

.22503 .37321 m

.37994 .56463 L

s

.28037 .50935 m .28253 .4806 L .28245 .48062 L .59 .37 .55 r

F

0 g

.28245 .48062 m

.28245 .48062 L

s

.28037 .50935 m .28045 .50933 L .28253 .4806 L .59 .37 .55 r

F

.24399 .46681 m .25032 .44162 L .21573 .45012 L .659 .748 .916 r

F

.24399 .46681 m .26661 .46133 L .25032 .44162 L F

.24399 .46681 m .28037 .50935 L .24157 .49567 L .822 .574 .564 r

F

.21573 .45012 m .24399 .46681 L .24157 .49567 L .881 .631 .555 r

F

.27825 .53856 m .28045 .50933 L .28037 .50935 L .59 .37 .55 r

F

.24157 .49567 m .28037 .50935 L .27825 .53856 L .822 .574 .564 r

F

.27825 .53856 m .27834 .53854 L .28045 .50933 L .59 .37 .55 r

F

.24157 .49567 m .27825 .53856 L .23912 .525 L .822 .574 .564 r

F

.21305 .47912 m .24157 .49567 L .23912 .525 L .881 .631 .555 r

F

.21573 .45012 m .24157 .49567 L .21305 .47912 L F

.2761 .56825 m .27834 .53854 L .27825 .53856 L .59 .37 .55 r

F

.23912 .525 m .27825 .53856 L .2761 .56825 L .822 .574 .564 r

F

.2761 .56825 m .27619 .56823 L .27834 .53854 L .59 .37 .55 r

F

.21573 .45012 m .23365 .42145 L .19501 .43108 L .659 .748 .916 r

F

.21573 .45012 m .25032 .44162 L .23365 .42145 L F

.19501 .43108 m .21573 .45012 L .21305 .47912 L .939 .691 .535 r

F

.23912 .525 m .2761 .56825 L .23662 .55483 L .822 .574 .564 r

F

.21033 .5086 m .23912 .525 L .23662 .55483 L .881 .631 .555 r

F

.21305 .47912 m .23912 .525 L .21033 .5086 L F

.23662 .55483 m .2761 .56825 L .27391 .59844 L .822 .574 .564 r

F

.27391 .59844 m .27619 .56823 L .2761 .56825 L .59 .37 .55 r

F

.27391 .59844 m .274 .59842 L .27619 .56823 L F

.19501 .43108 m .21659 .40081 L .18136 .40971 L .659 .748 .916 r

F

.19501 .43108 m .23365 .42145 L .21659 .40081 L F

.23662 .55483 m .27391 .59844 L .23408 .58516 L .822 .574 .564 r

F

.23408 .58516 m .27391 .59844 L .27169 .62914 L F

.27169 .62914 m .274 .59842 L .27391 .59844 L .59 .37 .55 r

F

.27169 .62914 m .27178 .62912 L .274 .59842 L F

.18136 .40971 m .19912 .37968 L .17566 .3857 L .659 .748 .916 r

F

.18136 .40971 m .21659 .40081 L .19912 .37968 L F

.23408 .58516 m .27169 .62914 L .2315 .616 L .822 .574 .564 r

F

.2315 .616 m .27169 .62914 L .26943 .66037 L F

.26943 .66037 m .27178 .62912 L .27169 .62914 L .59 .37 .55 r

F

.26943 .66037 m .26952 .66035 L .27178 .62912 L F

.17566 .3857 m .19912 .37968 L .18123 .35805 L .659 .748 .916 r

F

.18123 .35805 m .28253 .4806 L .26952 .66035 L .97 .724 .507 r

F

.19214 .46024 m .21305 .47912 L .21033 .5086 L .939 .691 .535 r

F

.19501 .43108 m .21305 .47912 L .19214 .46024 L F

.18136 .40971 m .19501 .43108 L .19214 .46024 L .989 .755 .486 r

F

0 g

.19501 .43108 m

.20533 .44057 L

s

.75102 .75197 m .73419 .76816 L .7342 .76825 L .232 .117 .51 r

F

.75102 .75197 m .75102 .75188 L .73419 .76816 L F

.7342 .76825 m .73419 .76816 L .70183 .76115 L .788 .538 .559 r

F

.8413 .66448 m .53505 .72502 L .73419 .76816 L .636 .771 .945 r

F

.7342 .76825 m .70183 .76115 L .70282 .78405 L .788 .538 .559 r

F

.75102 .75197 m .70282 .78405 L .7342 .76825 L .681 .979 .857 r

F

.20757 .53859 m .23662 .55483 L .23408 .58516 L .881 .631 .555 r

F

.21033 .5086 m .23662 .55483 L .20757 .53859 L F

.18921 .48989 m .21033 .5086 L .20757 .53859 L .939 .691 .535 r

F

.19214 .46024 m .21033 .5086 L .18921 .48989 L F

.70282 .78405 m .70183 .76115 L .66914 .75407 L .788 .538 .559 r

F

.17833 .43905 m .19214 .46024 L .18921 .48989 L .989 .755 .486 r

F

.18136 .40971 m .19214 .46024 L .17833 .43905 L F

.67036 .78905 m .66914 .75407 L .63612 .74692 L .788 .538 .559 r

F

.70282 .78405 m .66914 .75407 L .67036 .78905 L F

.17566 .3857 m .18136 .40971 L .17833 .43905 L .966 .782 .346 r

F

0 g

.18136 .40971 m

.19501 .43108 L

s

.20476 .56909 m .23408 .58516 L .2315 .616 L .881 .631 .555 r

F

.20757 .53859 m .23408 .58516 L .20476 .56909 L F

.71946 .76777 m .67036 .78905 L .70282 .78405 L .698 .921 .968 r

F

.75102 .75197 m .71946 .76777 L .70282 .78405 L .681 .979 .857 r

F

0 g

.70282 .78405 m

.7342 .76825 L

s

.76823 .73531 m .75102 .75188 L .75102 .75197 L .232 .117 .51 r

F

.76823 .73531 m .76823 .73522 L .75102 .75188 L F

.76823 .73531 m .71946 .76777 L .75102 .75197 L .681 .979 .857 r

F

0 g

.7342 .76825 m

.75102 .75197 L

s

.18623 .52006 m .20757 .53859 L .20476 .56909 L .939 .691 .535 r

F

.18921 .48989 m .20757 .53859 L .18623 .52006 L F

.63714 .78581 m .63612 .74692 L .60277 .73969 L .788 .538 .559 r

F

.67036 .78905 m .63612 .74692 L .63714 .78581 L F

.17525 .46889 m .18921 .48989 L .18623 .52006 L .989 .755 .486 r

F

.17833 .43905 m .18921 .48989 L .17525 .46889 L F

.17254 .41523 m .17833 .43905 L .17525 .46889 L .966 .782 .346 r

F

.17566 .3857 m .17833 .43905 L .17254 .41523 L F

.68676 .77269 m .63714 .78581 L .67036 .78905 L .656 .822 .963 r

F

.71946 .76777 m .68676 .77269 L .67036 .78905 L .698 .921 .968 r

F

0 g

.67036 .78905 m

.70282 .78405 L

s

.2315 .616 m .26943 .66037 L .22888 .64738 L .822 .574 .564 r

F

.2019 .60011 m .2315 .616 L .22888 .64738 L .881 .631 .555 r

F

.20476 .56909 m .2315 .616 L .2019 .60011 L F

.22888 .64738 m .26952 .66035 L .26943 .66037 L .643 .765 .937 r

F

0 g

.26943 .66037 m

.26943 .66037 L

s

.26943 .66032 m

.26945 .6601 L

s

.18623 .52006 m .20476 .56909 L .1832 .55074 L .939 .691 .535 r

F

.1832 .55074 m .20476 .56909 L .2019 .60011 L F

.17211 .49925 m .18623 .52006 L .1832 .55074 L .989 .755 .486 r

F

.17525 .46889 m .18623 .52006 L .17211 .49925 L F

.16936 .44528 m .17525 .46889 L .17211 .49925 L .966 .782 .346 r

F

.17254 .41523 m .17525 .46889 L .16936 .44528 L F

.1832 .55074 m .2019 .60011 L .18012 .58196 L .939 .691 .535 r

F

.17211 .49925 m .1832 .55074 L .16892 .53014 L .989 .755 .486 r

F

.16892 .53014 m .1832 .55074 L .18012 .58196 L F

.16613 .47585 m .17211 .49925 L .16892 .53014 L .966 .782 .346 r

F

.16936 .44528 m .17211 .49925 L .16613 .47585 L F

.16892 .53014 m .18012 .58196 L .16567 .56158 L .989 .755 .486 r

F

.16613 .47585 m .16892 .53014 L .16284 .50697 L .966 .782 .346 r

F

.16284 .50697 m .16892 .53014 L .16567 .56158 L F

.16284 .50697 m .16567 .56158 L .1595 .53864 L F

.18123 .35805 m .26952 .66035 L .16166 .54472 L .97 .724 .507 r

F

.22888 .64738 m .25261 .64222 L .26952 .66035 L .643 .765 .937 r

F

0 g

.26952 .66035 m

.28253 .4806 L

s

.60338 .77489 m .60277 .73969 L .56908 .73239 L .788 .538 .559 r

F

.63714 .78581 m .60277 .73969 L .60338 .77489 L F

.7365 .7511 m .68676 .77269 L .71946 .76777 L .698 .921 .968 r

F

0 g

.7218 .76548 m

.72263 .76566 L

s

.76823 .73531 m .7365 .7511 L .71946 .76777 L .681 .979 .857 r

F

.78585 .71825 m .76823 .73522 L .76823 .73531 L .232 .117 .51 r

F

.78585 .71825 m .78585 .71816 L .76823 .73522 L F

.78585 .71825 m .7365 .7511 L .76823 .73531 L .681 .979 .857 r

F

0 g

.75102 .75197 m

.76823 .73531 L

s

.17566 .3857 m .18123 .35805 L .18114 .35807 L .659 .748 .916 r

F

.18114 .35807 m .17566 .3857 L .17254 .41523 L 0 0 .013 r

F

0 g

.17647 .38912 m

.17751 .39352 L

s

.0959 .21365 m

.18105 .31887 L

s

.18105 .31887 m

.22503 .37321 L

s

.56928 .75558 m .56908 .73239 L .53505 .72502 L .788 .538 .559 r

F

.60338 .77489 m .56908 .73239 L .56928 .75558 L F

.65324 .76931 m .60338 .77489 L .63714 .78581 L .607 .73 .932 r

F

.68676 .77269 m .65324 .76931 L .63714 .78581 L .656 .822 .963 r

F

0 g

.63714 .78581 m

.67036 .78905 L

s

.2019 .60011 m .22888 .64738 L .19899 .63167 L .881 .631 .555 r

F

.19899 .63167 m .25261 .64222 L .22888 .64738 L .643 .765 .937 r

F

0 g

.22888 .64738 m

.26943 .66037 L

s

.61915 .7582 m .56928 .75558 L .60338 .77489 L .555 .642 .891 r

F

.65324 .76931 m .61915 .7582 L .60338 .77489 L .607 .73 .932 r

F

0 g

.60338 .77489 m

.63714 .78581 L

s

.18012 .58196 m .2019 .60011 L .19899 .63167 L .939 .691 .535 r

F

.56928 .75558 m .53505 .72502 L .53505 .72511 L .788 .538 .559 r

F

.8413 .66448 m .63057 .61466 L .53505 .72502 L .636 .771 .945 r

F

.53505 .72511 m .53505 .72502 L .55002 .70772 L .124 .016 .449 r

F

0 g

.53511 .72503 m

.70951 .76282 L

s

.58467 .73862 m .53505 .72511 L .56928 .75558 L .494 .546 .838 r

F

.58467 .73862 m .55002 .70781 L .53505 .72511 L F

.53505 .72511 m .55002 .70772 L .55002 .70781 L .124 .016 .449 r

F

0 g

.53505 .72511 m

.53505 .72511 L

s

.70355 .75595 m .65324 .76931 L .68676 .77269 L .656 .822 .963 r

F

.7365 .7511 m .70355 .75595 L .68676 .77269 L .698 .921 .968 r

F

.61915 .7582 m .58467 .73862 L .56928 .75558 L .555 .642 .891 r

F

0 g

.53505 .72511 m

.56928 .75558 L

s

.56928 .75558 m

.60338 .77489 L

s

.19899 .63167 m .2353 .62367 L .25261 .64222 L .643 .765 .937 r

F

.17802 .38782 m .17254 .41523 L .16936 .44528 L 0 0 .013 r

F

.18114 .35807 m .17254 .41523 L .17802 .38782 L F

.75394 .73404 m .70355 .75595 L .7365 .7511 L .698 .921 .968 r

F

.78585 .71825 m .75394 .73404 L .7365 .7511 L .681 .979 .857 r

F

.8039 .70079 m .78585 .71816 L .78585 .71825 L .232 .117 .51 r

F

.8039 .70079 m .80389 .70069 L .78585 .71816 L F

.8039 .70079 m .75394 .73404 L .78585 .71825 L .681 .979 .857 r

F

0 g

.76823 .73531 m

.78585 .71825 L

s

.66974 .75242 m .61915 .7582 L .65324 .76931 L .607 .73 .932 r

F

.70355 .75595 m .66974 .75242 L .65324 .76931 L .656 .822 .963 r

F

.18012 .58196 m .19899 .63167 L .17699 .61373 L .939 .691 .535 r

F

.17699 .61373 m .2353 .62367 L .19899 .63167 L .643 .765 .937 r

F

0 g

.19899 .63167 m

.22888 .64738 L

s

.18114 .35807 m .17812 .3878 L .17802 .38782 L .572 .341 .527 r

F

.18114 .35807 m .18123 .35805 L .17812 .3878 L F

0 g

.17566 .3857 m

.18114 .35807 L

s

.18123 .35805 m

.28253 .4806 L

s

.18114 .35807 m

.18114 .35807 L

s

.16567 .56158 m .18012 .58196 L .17699 .61373 L .989 .755 .486 r

F

.63531 .7411 m .58467 .73862 L .61915 .7582 L .555 .642 .891 r

F

.66974 .75242 m .63531 .7411 L .61915 .7582 L .607 .73 .932 r

F

.17485 .41809 m .16936 .44528 L .16613 .47585 L 0 0 .013 r

F

.17802 .38782 m .16936 .44528 L .17485 .41809 L F

.55002 .70781 m .55002 .70772 L .56536 .69 L .124 .016 .449 r

F

.60044 .72126 m .55002 .70781 L .58467 .73862 L .494 .546 .838 r

F

.60044 .72126 m .56536 .69009 L .55002 .70781 L F

.55002 .70781 m .56536 .69 L .56536 .69009 L .124 .016 .449 r

F

0 g

.53505 .72511 m

.55002 .70781 L

s

.72074 .7388 m .66974 .75242 L .70355 .75595 L .656 .822 .963 r

F

.75394 .73404 m .72074 .7388 L .70355 .75595 L .698 .921 .968 r

F

.63531 .7411 m .60044 .72126 L .58467 .73862 L .555 .642 .891 r

F

0 g

.78114 .54113 m

.80686 .58765 L

s

.17699 .61373 m .21756 .60465 L .2353 .62367 L .643 .765 .937 r

F

0 g

.0959 .21365 m

.74617 .02894 L

s

.02943 .70308 m

.0959 .21365 L

s

.77181 .71657 m .72074 .7388 L .75394 .73404 L .698 .921 .968 r

F

.8039 .70079 m .77181 .71657 L .75394 .73404 L .681 .979 .857 r

F

.82237 .6829 m .80389 .70069 L .8039 .70079 L .232 .117 .51 r

F

0 g

.9047 .76458 m

.97796 .89707 L

s

.82237 .6829 m .82237 .68281 L .80389 .70069 L .232 .117 .51 r

F

.82237 .6829 m .77181 .71657 L .8039 .70079 L .681 .979 .857 r

F

0 g

.78585 .71825 m

.8039 .70079 L

s

.17802 .38782 m .17494 .41807 L .17485 .41809 L .572 .341 .527 r

F

.17802 .38782 m .17812 .3878 L .17494 .41807 L F

0 g

.17802 .38782 m

.18114 .35807 L

s

.68663 .73513 m .63531 .7411 L .66974 .75242 L .607 .73 .932 r

F

.72074 .7388 m .68663 .73513 L .66974 .75242 L .656 .822 .963 r

F

.16567 .56158 m .17699 .61373 L .16237 .59357 L .989 .755 .486 r

F

.16237 .59357 m .21756 .60465 L .17699 .61373 L .643 .765 .937 r

F

0 g

.17699 .61373 m

.19899 .63167 L

s

.17161 .44891 m .16613 .47585 L .16284 .50697 L 0 0 .013 r

F

.17485 .41809 m .16613 .47585 L .17161 .44891 L F

.65185 .72359 m .60044 .72126 L .63531 .7411 L .555 .642 .891 r

F

.68663 .73513 m .65185 .72359 L .63531 .7411 L .607 .73 .932 r

F

.1595 .53864 m .16567 .56158 L .16237 .59357 L .966 .782 .346 r

F

.56536 .69009 m .56536 .69 L .58106 .67186 L .124 .016 .449 r

F

.61659 .70347 m .56536 .69009 L .60044 .72126 L .494 .546 .838 r

F

.61659 .70347 m .58106 .67195 L .56536 .69009 L F

.56536 .69009 m .58106 .67186 L .58106 .67195 L .124 .016 .449 r

F

0 g

.55002 .70781 m

.56536 .69009 L

s

.73835 .72123 m .68663 .73513 L .72074 .7388 L .656 .822 .963 r

F

.77181 .71657 m .73835 .72123 L .72074 .7388 L .698 .921 .968 r

F

.65185 .72359 m .61659 .70347 L .60044 .72126 L .555 .642 .891 r

F

.16237 .59357 m .19939 .58517 L .21756 .60465 L .643 .765 .937 r

F

.17485 .41809 m .17171 .44889 L .17161 .44891 L .572 .341 .527 r

F

.17485 .41809 m .17494 .41807 L .17171 .44889 L F

0 g

.17485 .41809 m

.17802 .38782 L

s

.79011 .69867 m .73835 .72123 L .77181 .71657 L .698 .921 .968 r

F

.82237 .6829 m .79011 .69867 L .77181 .71657 L .681 .979 .857 r

F

.8413 .66458 m .82237 .68281 L .82237 .6829 L .232 .117 .51 r

F

.8413 .66458 m .8413 .66448 L .82237 .68281 L F

.8413 .66458 m .79011 .69867 L .82237 .6829 L .681 .979 .857 r

F

0 g

.8039 .70079 m

.82237 .6829 L

s

.16832 .48028 m .16284 .50697 L .1595 .53864 L 0 0 .013 r

F

.17161 .44891 m .16284 .50697 L .16832 .48028 L F

.70394 .7174 m .65185 .72359 L .68663 .73513 L .607 .73 .932 r

F

.73835 .72123 m .70394 .7174 L .68663 .73513 L .656 .822 .963 r

F

.1595 .53864 m .16237 .59357 L .15609 .57088 L .966 .782 .346 r

F

.15609 .57088 m .19939 .58517 L .16237 .59357 L .643 .765 .937 r

F

0 g

.16237 .59357 m

.17699 .61373 L

s

.6688 .70565 m .61659 .70347 L .65185 .72359 L .555 .642 .891 r

F

.70394 .7174 m .6688 .70565 L .65185 .72359 L .607 .73 .932 r

F

.17161 .44891 m .16842 .48026 L .16832 .48028 L .572 .341 .527 r

F

.17161 .44891 m .17171 .44889 L .16842 .48026 L F

0 g

.17161 .44891 m

.17485 .41809 L

s

.58106 .67195 m .58106 .67186 L .59716 .65326 L .124 .016 .449 r

F

.63315 .68525 m .58106 .67195 L .61659 .70347 L .494 .546 .838 r

F

.63315 .68525 m .59716 .65335 L .58106 .67195 L F

.58106 .67195 m .59716 .65326 L .59716 .65335 L .124 .016 .449 r

F

0 g

.56536 .69009 m

.58106 .67195 L

s

.7564 .70323 m .70394 .7174 L .73835 .72123 L .656 .822 .963 r

F

.79011 .69867 m .7564 .70323 L .73835 .72123 L .698 .921 .968 r

F

.6688 .70565 m .63315 .68525 L .61659 .70347 L .555 .642 .891 r

F

.16497 .51222 m .1595 .53864 L .15609 .57088 L 0 0 .013 r

F

.16832 .48028 m .1595 .53864 L .16497 .51222 L F

.15609 .57088 m .18076 .5652 L .19939 .58517 L .643 .765 .937 r

F

.80886 .68032 m .7564 .70323 L .79011 .69867 L .698 .921 .968 r

F

.8413 .66458 m .80886 .68032 L .79011 .69867 L .681 .979 .857 r

F

.80886 .68032 m .8413 .66448 L .8413 .66458 L .795 .531 .538 r

F

.80886 .68032 m .80711 .6564 L .8413 .66448 L F

0 g

.82237 .6829 m

.8413 .66458 L

s

.8413 .66458 m

.8413 .66458 L

s

.72167 .69924 m .6688 .70565 L .70394 .7174 L .607 .73 .932 r

F

.7564 .70323 m .72167 .69924 L .70394 .7174 L .656 .822 .963 r

F

.16832 .48028 m .16507 .5122 L .16497 .51222 L .572 .341 .527 r

F

.16832 .48028 m .16842 .48026 L .16507 .5122 L F

0 g

.16832 .48028 m

.17161 .44891 L

s

.7749 .68478 m .80711 .6564 L .80886 .68032 L .795 .531 .538 r

F

.7749 .68478 m .77256 .64823 L .80711 .6564 L F

.16156 .54475 m .18076 .5652 L .15609 .57088 L .643 .765 .937 r

F

.16497 .51222 m .15609 .57088 L .16156 .54475 L 0 0 .013 r

F

0 g

.15609 .57088 m

.16237 .59357 L

s

.68618 .68726 m .63315 .68525 L .6688 .70565 L .555 .642 .891 r

F

.72167 .69924 m .68618 .68726 L .6688 .70565 L .607 .73 .932 r

F

.59716 .65335 m .59716 .65326 L .61365 .6342 L .124 .016 .449 r

F

.65011 .66657 m .59716 .65335 L .63315 .68525 L .494 .546 .838 r

F

.65011 .66657 m .61366 .63429 L .59716 .65335 L F

.59716 .65335 m .61365 .6342 L .61366 .63429 L .124 .016 .449 r

F

0 g

.58106 .67195 m

.59716 .65335 L

s

.7749 .68478 m .72167 .69924 L .7564 .70323 L .656 .822 .963 r

F

.80886 .68032 m .7749 .68478 L .7564 .70323 L .698 .921 .968 r

F

0 g

.80686 .58765 m

.9047 .76458 L

s

.80886 .68032 m

.8413 .66458 L

s

.68618 .68726 m .65011 .66657 L .63315 .68525 L .555 .642 .891 r

F

.16156 .54475 m .16166 .54472 L .18076 .5652 L .643 .765 .937 r

F

.73985 .68062 m .77256 .64823 L .7749 .68478 L .795 .531 .538 r

F

.73985 .68062 m .73763 .63998 L .77256 .64823 L F

.16497 .51222 m .16166 .54472 L .16156 .54475 L .572 .341 .527 r

F

0 g

.15609 .57088 m

.16156 .54475 L

s

.16497 .51222 m .16507 .5122 L .16166 .54472 L .572 .341 .527 r

F

0 g

.16497 .51222 m

.16832 .48028 L

s

.16166 .54472 m

.18123 .35805 L

s

.16166 .54472 m

.26952 .66035 L

s

.16156 .54475 m

.16497 .51222 L

s

.73985 .68062 m .68618 .68726 L .72167 .69924 L .607 .73 .932 r

F

.7749 .68478 m .73985 .68062 L .72167 .69924 L .656 .822 .963 r

F

0 g

.7749 .68478 m

.80886 .68032 L

s

.70399 .66841 m .73763 .63998 L .73985 .68062 L .795 .531 .538 r

F

.70399 .66841 m .70233 .63163 L .73763 .63998 L F

.70399 .66841 m .65011 .66657 L .68618 .68726 L .555 .642 .891 r

F

.73985 .68062 m .70399 .66841 L .68618 .68726 L .607 .73 .932 r

F

.61366 .63429 m .61365 .6342 L .63057 .61466 L .124 .016 .449 r

F

.6675 .64741 m .61366 .63429 L .65011 .66657 L .494 .546 .838 r

F

.6675 .64741 m .63057 .61475 L .61366 .63429 L F

.61366 .63429 m .63057 .61466 L .63057 .61475 L .124 .016 .449 r

F

0 g

.59716 .65335 m

.61366 .63429 L

s

.73985 .68062 m

.7749 .68478 L

s

.70399 .66841 m .6675 .64741 L .65011 .66657 L .555 .642 .891 r

F

.6675 .64741 m .70233 .63163 L .70399 .66841 L .795 .531 .538 r

F

.6675 .64741 m .66665 .62319 L .70233 .63163 L F

.63057 .61475 m .66665 .62319 L .6675 .64741 L F

.63057 .61475 m .63057 .61466 L .66665 .62319 L F

0 g

.61366 .63429 m

.63057 .61475 L

s

.63057 .61466 m

.8413 .66448 L

s

.53505 .72502 m

.63057 .61466 L

s

.70399 .66841 m

.73985 .68062 L

s

.6675 .64741 m

.70399 .66841 L

s

.63057 .61475 m

.6675 .64741 L

s

.63057 .61475 m

.63057 .61475 L

s

.78114 .54113 m

.74617 .02894 L

s

.78114 .54113 m

.02943 .70308 L

s

.25 Mabswid

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.0242577 0.97619 0.48631 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.0184128 1.11086 1.11022e-16 1.11086 [

[.5 1.03133 -55.2 0 ]

[.5 1.03133 55.2 7.2 ]

[.07999 .18147 -4.33011 -7.2 ]

[.07999 .18147 .46989 0 ]

[.28509 .12212 -8.07061 -7.2 ]

[.28509 .12212 1.52939 0 ]

[.50279 .05919 -11.2215 -7.2 ]

[.50279 .05919 3.17851 0 ]

[.73427 -0.0076 -10.3371 -7.2 ]

[.73427 -0.0076 4.06293 0 ]

[.77653 .00912 0 -4.62791 ]

[.77653 .00912 14.4 2.57209 ]

[.84438 .16831 0 -4.54413 ]

[.84438 .16831 4.8 2.65587 ]

[.90296 .30575 0 -4.47298 ]

[.90296 .30575 9.6 2.72702 ]

[.95404 .42562 0 -4.4118 ]

[.95404 .42562 14.4 2.7882 ]

[.05897 .21099 -14.4 -2.57051 ]

[.05897 .21099 0 4.62949 ]

[.03311 .39048 -4.8 -2.6608 ]

[.03311 .39048 0 4.5392 ]

[.00422 .59105 -9.6 -2.76251 ]

[.00422 .59105 0 4.43749 ]

[ 0 0 0 0 ]

[ 1 1.01883 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[({100,50,50},{1,1,-1},45)] .5 1.03133 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m


.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

.25 Mabswid

.75767 0 m

.94405 .43703 L

s

.76318 .01294 m

.75651 .01484 L

s

[(-50)] .77653 .00912 -1 .28553 Mshowa

.83095 .17183 m

.82423 .17359 L

s

[(0)] .84438 .16831 -1 .26226 Mshowa

.88946 .30902 m

.88271 .31066 L

s

[(50)] .90296 .30575 -1 .24249 Mshowa

.94049 .42867 m

.93372 .4302 L

s

[(100)] .95404 .42562 -1 .2255 Mshowa

.125 Mabswid

.77758 .0467 m

.77357 .04782 L

s

.79154 .07942 m

.78752 .08053 L

s

.80507 .11115 m

.80105 .11224 L

s

.8182 .14194 m

.81418 .14302 L

s

.84333 .20086 m

.83929 .2019 L

s

.85535 .22905 m

.85132 .23008 L

s

.86704 .25646 m

.863 .25747 L

s

.87841 .2831 m

.87436 .2841 L

s

.90022 .33424 m

.89616 .33521 L

s

.91069 .35879 m

.90663 .35974 L

s

.92088 .3827 m

.91682 .38364 L

s

.93081 .40598 m

.92675 .40691 L

s

.25 Mabswid

.07384 .19656 m

0 .71164 L

s

.07232 .20717 m

.079 .20526 L

s

[(-50)] .05897 .21099 1 -0.28597 Mshowa

.04654 .38698 m

.05326 .38522 L

s

[(0)] .03311 .39048 1 -0.26089 Mshowa

.01774 .5879 m

.0245 .58633 L

s

[(50)] .00422 .59105 1 -0.23264 Mshowa

.125 Mabswid

.06738 .24161 m

.07139 .24048 L

s

.06234 .27678 m

.06636 .27567 L

s

.05719 .31271 m

.06121 .31162 L

s

.05193 .34944 m

.05595 .34837 L

s

.04104 .42536 m

.04508 .42433 L

s

.03541 .46461 m

.03946 .4636 L

s

.02966 .50476 m

.0337 .50377 L

s

.02377 .54585 m

.02782 .54488 L

s

.01157 .63095 m

.01563 .63003 L

s

.00525 .67503 m

.00932 .67414 L

s

0 0 m

1 0 L

1 1.01883 L

0 1.01883 L

closepath

clip

newpath

.5 Mabswid

.92692 .44201 m

.37994 .56463 L

s

.36101 .99851 m

.37994 .56463 L

s

.74617 .02894 m

.92692 .44201 L

s

.92692 .44201 m

.97796 .89707 L

s

.36101 .99851 m

.97796 .89707 L

s

.02943 .70308 m

.36101 .99851 L

s

.28245 .48062 m .26661 .46133 L .24399 .46681 L .659 .748 .916 r

F

.28245 .48062 m .28253 .4806 L .26661 .46133 L F

.24399 .46681 m .28245 .48062 L .28037 .50935 L .822 .574 .564 r

F

0 g

.22503 .37321 m

.37994 .56463 L

s

.28037 .50935 m .28253 .4806 L .28245 .48062 L .59 .37 .55 r

F

0 g

.28245 .48062 m

.28245 .48062 L

s

.28037 .50935 m .28045 .50933 L .28253 .4806 L .59 .37 .55 r

F

.24399 .46681 m .25032 .44162 L .21573 .45012 L .659 .748 .916 r

F

.24399 .46681 m .26661 .46133 L .25032 .44162 L F

.24399 .46681 m .28037 .50935 L .24157 .49567 L .822 .574 .564 r

F

.21573 .45012 m .24399 .46681 L .24157 .49567 L .881 .631 .555 r

F

.27825 .53856 m .28045 .50933 L .28037 .50935 L .59 .37 .55 r

F

.24157 .49567 m .28037 .50935 L .27825 .53856 L .822 .574 .564 r

F

.27825 .53856 m .27834 .53854 L .28045 .50933 L .59 .37 .55 r

F

.24157 .49567 m .27825 .53856 L .23912 .525 L .822 .574 .564 r

F

.21305 .47912 m .24157 .49567 L .23912 .525 L .881 .631 .555 r

F

.21573 .45012 m .24157 .49567 L .21305 .47912 L F

.2761 .56825 m .27834 .53854 L .27825 .53856 L .59 .37 .55 r

F

.23912 .525 m .27825 .53856 L .2761 .56825 L .822 .574 .564 r

F

.2761 .56825 m .27619 .56823 L .27834 .53854 L .59 .37 .55 r

F

.21573 .45012 m .23365 .42145 L .19501 .43108 L .659 .748 .916 r

F

.21573 .45012 m .25032 .44162 L .23365 .42145 L F

.19501 .43108 m .21573 .45012 L .21305 .47912 L .939 .691 .535 r

F

.23912 .525 m .2761 .56825 L .23662 .55483 L .822 .574 .564 r

F

.21033 .5086 m .23912 .525 L .23662 .55483 L .881 .631 .555 r

F

.21305 .47912 m .23912 .525 L .21033 .5086 L F

.23662 .55483 m .2761 .56825 L .27391 .59844 L .822 .574 .564 r

F

.27391 .59844 m .27619 .56823 L .2761 .56825 L .59 .37 .55 r

F

.27391 .59844 m .274 .59842 L .27619 .56823 L F

.19501 .43108 m .21659 .40081 L .18136 .40971 L .659 .748 .916 r

F

.19501 .43108 m .23365 .42145 L .21659 .40081 L F

.23662 .55483 m .27391 .59844 L .23408 .58516 L .822 .574 .564 r

F

.23408 .58516 m .27391 .59844 L .27169 .62914 L F

.27169 .62914 m .274 .59842 L .27391 .59844 L .59 .37 .55 r

F

.27169 .62914 m .27178 .62912 L .274 .59842 L F

.18136 .40971 m .19912 .37968 L .17566 .3857 L .659 .748 .916 r

F

.18136 .40971 m .21659 .40081 L .19912 .37968 L F

.23408 .58516 m .27169 .62914 L .2315 .616 L .822 .574 .564 r

F

.2315 .616 m .27169 .62914 L .26943 .66037 L F

.26943 .66037 m .27178 .62912 L .27169 .62914 L .59 .37 .55 r

F

.26943 .66037 m .26952 .66035 L .27178 .62912 L F

.17566 .3857 m .19912 .37968 L .18123 .35805 L .659 .748 .916 r

F

.18123 .35805 m .28253 .4806 L .26952 .66035 L .97 .724 .507 r

F

.19214 .46024 m .21305 .47912 L .21033 .5086 L .939 .691 .535 r

F

.19501 .43108 m .21305 .47912 L .19214 .46024 L F

.18136 .40971 m .19501 .43108 L .19214 .46024 L .989 .755 .486 r

F

0 g

.19501 .43108 m

.20533 .44057 L

s

.64922 .79023 m .6493 .79019 L .64649 .75755 L .866 .755 .739 r

F

.67443 .8004 m .6493 .79019 L .64922 .79023 L .572 .173 .248 r

F

.67443 .8004 m .67451 .80036 L .6493 .79019 L F

.63203 .58905 m .6493 .79019 L .80936 .85473 L .426 .424 .754 r

F

.64922 .79023 m .64649 .75755 L .62763 .76663 L .866 .755 .739 r

F

.62763 .76663 m .64922 .79023 L .67443 .8004 L .142 .476 .896 r

F

0 g

.64922 .79023 m

.64922 .79023 L

s

.20757 .53859 m .23662 .55483 L .23408 .58516 L .881 .631 .555 r

F

.21033 .5086 m .23662 .55483 L .20757 .53859 L F

.18921 .48989 m .21033 .5086 L .20757 .53859 L .939 .691 .535 r

F

.19214 .46024 m .21033 .5086 L .18921 .48989 L F

.62763 .76663 m .64649 .75755 L .64366 .72457 L .866 .755 .739 r

F

.17833 .43905 m .19214 .46024 L .18921 .48989 L .989 .755 .486 r

F

.18136 .40971 m .19214 .46024 L .17833 .43905 L F

.17566 .3857 m .18136 .40971 L .17833 .43905 L .966 .782 .346 r

F

0 g

.18136 .40971 m

.19501 .43108 L

s

.61474 .73814 m .64366 .72457 L .6408 .69123 L .866 .755 .739 r

F

.62763 .76663 m .64366 .72457 L .61474 .73814 L F

.20476 .56909 m .23408 .58516 L .2315 .616 L .881 .631 .555 r

F

.20757 .53859 m .23408 .58516 L .20476 .56909 L F

.70021 .81079 m .67451 .80036 L .67443 .8004 L .572 .173 .248 r

F

.70021 .81079 m .70028 .81075 L .67451 .80036 L F

.65289 .77665 m .67443 .8004 L .70021 .81079 L .142 .476 .896 r

F

0 g

.67423 .80025 m

.67434 .80029 L

s

.62763 .76663 m .67443 .8004 L .65289 .77665 L .142 .476 .896 r

F

0 g

.64922 .79023 m

.67443 .8004 L

s

.61474 .73814 m .62763 .76663 L .65289 .77665 L .314 .464 .85 r

F

0 g

.62763 .76663 m

.64922 .79023 L

s

.18623 .52006 m .20757 .53859 L .20476 .56909 L .939 .691 .535 r

F

.18921 .48989 m .20757 .53859 L .18623 .52006 L F

.17525 .46889 m .18921 .48989 L .18623 .52006 L .989 .755 .486 r

F

.17833 .43905 m .18921 .48989 L .17525 .46889 L F

.60854 .70599 m .6408 .69123 L .63791 .65754 L .866 .755 .739 r

F

.61474 .73814 m .6408 .69123 L .60854 .70599 L F

.17254 .41523 m .17833 .43905 L .17525 .46889 L .966 .782 .346 r

F

.17566 .3857 m .17833 .43905 L .17254 .41523 L F

.2315 .616 m .26943 .66037 L .22888 .64738 L .822 .574 .564 r

F

.2019 .60011 m .2315 .616 L .22888 .64738 L .881 .631 .555 r

F

.20476 .56909 m .2315 .616 L .2019 .60011 L F

.22888 .64738 m .26952 .66035 L .26943 .66037 L .643 .765 .937 r

F

0 g

.26943 .66037 m

.26943 .66037 L

s

.26943 .66032 m

.26945 .6601 L

s

.18623 .52006 m .20476 .56909 L .1832 .55074 L .939 .691 .535 r

F

.1832 .55074 m .20476 .56909 L .2019 .60011 L F

.17211 .49925 m .18623 .52006 L .1832 .55074 L .989 .755 .486 r

F

.17525 .46889 m .18623 .52006 L .17211 .49925 L F

.16936 .44528 m .17525 .46889 L .17211 .49925 L .966 .782 .346 r

F

.17254 .41523 m .17525 .46889 L .16936 .44528 L F

.1832 .55074 m .2019 .60011 L .18012 .58196 L .939 .691 .535 r

F

.17211 .49925 m .1832 .55074 L .16892 .53014 L .989 .755 .486 r

F

.16892 .53014 m .1832 .55074 L .18012 .58196 L F

.16613 .47585 m .17211 .49925 L .16892 .53014 L .966 .782 .346 r

F

.16936 .44528 m .17211 .49925 L .16613 .47585 L F

.16892 .53014 m .18012 .58196 L .16567 .56158 L .989 .755 .486 r

F

.16613 .47585 m .16892 .53014 L .16284 .50697 L .966 .782 .346 r

F

.16284 .50697 m .16892 .53014 L .16567 .56158 L F

.16284 .50697 m .16567 .56158 L .1595 .53864 L F

.18123 .35805 m .26952 .66035 L .16166 .54472 L .97 .724 .507 r

F

.22888 .64738 m .25261 .64222 L .26952 .66035 L .643 .765 .937 r

F

0 g

.26952 .66035 m

.28253 .4806 L

s

.60854 .70599 m .61474 .73814 L .64009 .74793 L .392 .434 .785 r

F

.61474 .73814 m .65289 .77665 L .64009 .74793 L .314 .464 .85 r

F

0 g

.61474 .73814 m

.62763 .76663 L

s

.60862 .67059 m .63791 .65754 L .63498 .62348 L .866 .755 .739 r

F

.60854 .70599 m .63791 .65754 L .60862 .67059 L F

.72656 .82141 m .70028 .81075 L .70021 .81079 L .572 .173 .248 r

F

.72656 .82141 m .72663 .82138 L .70028 .81075 L F

.67873 .7869 m .70021 .81079 L .72656 .82141 L .142 .476 .896 r

F

0 g

.7 .81064 m

.70011 .81068 L

s

.65289 .77665 m .70021 .81079 L .67873 .7869 L .142 .476 .896 r

F

0 g

.67443 .8004 m

.70021 .81079 L

s

.64009 .74793 m .65289 .77665 L .67873 .7869 L .314 .464 .85 r

F

.17566 .3857 m .18123 .35805 L .18114 .35807 L .659 .748 .916 r

F

.18114 .35807 m .17566 .3857 L .17254 .41523 L 0 0 .013 r

F

0 g

.17647 .38912 m

.17751 .39352 L

s

.0959 .21365 m

.18105 .31887 L

s

.18105 .31887 m

.22503 .37321 L

s

.61563 .63187 m .63498 .62348 L .63203 .58905 L .866 .755 .739 r

F

.60862 .67059 m .63498 .62348 L .61563 .63187 L F

.60854 .70599 m .64009 .74793 L .63398 .71548 L .392 .434 .785 r

F

.60862 .67059 m .60854 .70599 L .63398 .71548 L .438 .404 .724 r

F

0 g

.60854 .70599 m

.61474 .73814 L

s

.2019 .60011 m .22888 .64738 L .19899 .63167 L .881 .631 .555 r

F

.19899 .63167 m .25261 .64222 L .22888 .64738 L .643 .765 .937 r

F

0 g

.22888 .64738 m

.26943 .66037 L

s

.18012 .58196 m .2019 .60011 L .19899 .63167 L .939 .691 .535 r

F

.60862 .67059 m .63398 .71548 L .63417 .67972 L .438 .404 .724 r

F

.61563 .63187 m .60862 .67059 L .63417 .67972 L .469 .373 .664 r

F

0 g

.60854 .70599 m

.60862 .67059 L

s

.19899 .63167 m .2353 .62367 L .25261 .64222 L .643 .765 .937 r

F

.63398 .71548 m .64009 .74793 L .66601 .75794 L .392 .434 .785 r

F

0 g

.64586 .75016 m

.6462 .75409 L

s

.64009 .74793 m .67873 .7869 L .66601 .75794 L .314 .464 .85 r

F

.61563 .63187 m .63203 .58905 L .63195 .58908 L .866 .755 .739 r

F

.63203 .58905 m .80936 .85473 L .79643 .64132 L .426 .424 .754 r

F

.63195 .58908 m .63203 .58905 L .65787 .59727 L .525 .085 .147 r

F

0 g

.63203 .58911 m

.64402 .72879 L

s

.63195 .58908 m .65787 .59727 L .6578 .5973 L .525 .085 .147 r

F

.63195 .58908 m .64132 .64058 L .6578 .5973 L .494 .336 .595 r

F

.63195 .58908 m .61563 .63187 L .64132 .64058 L F

0 g

.63195 .58908 m

.63195 .58908 L

s

.17802 .38782 m .17254 .41523 L .16936 .44528 L 0 0 .013 r

F

.18114 .35807 m .17254 .41523 L .17802 .38782 L F

.61563 .63187 m .63417 .67972 L .64132 .64058 L .469 .373 .664 r

F

0 g

.60862 .67059 m

.61563 .63187 L

s

.61563 .63187 m

.63195 .58908 L

s

.75351 .83228 m .72663 .82138 L .72656 .82141 L .572 .173 .248 r

F

.75351 .83228 m .75358 .83224 L .72663 .82138 L F

.70516 .79738 m .72656 .82141 L .75351 .83228 L .142 .476 .896 r

F

0 g

.72635 .82126 m

.72646 .82131 L

s

.67873 .7869 m .72656 .82141 L .70516 .79738 L .142 .476 .896 r

F

0 g

.70021 .81079 m

.72656 .82141 L

s

.66601 .75794 m .67873 .7869 L .70516 .79738 L .314 .464 .85 r

F

.63398 .71548 m .66601 .75794 L .66 .72519 L .392 .434 .785 r

F

.63417 .67972 m .63398 .71548 L .66 .72519 L .438 .404 .724 r

F

.18012 .58196 m .19899 .63167 L .17699 .61373 L .939 .691 .535 r

F

.17699 .61373 m .2353 .62367 L .19899 .63167 L .643 .765 .937 r

F

0 g

.19899 .63167 m

.22888 .64738 L

s

.18114 .35807 m .17812 .3878 L .17802 .38782 L .572 .341 .527 r

F

.18114 .35807 m .18123 .35805 L .17812 .3878 L F

0 g

.17566 .3857 m

.18114 .35807 L

s

.18123 .35805 m

.28253 .4806 L

s

.18114 .35807 m

.18114 .35807 L

s

.16567 .56158 m .18012 .58196 L .17699 .61373 L .989 .755 .486 r

F

.17485 .41809 m .16936 .44528 L .16613 .47585 L 0 0 .013 r

F

.17802 .38782 m .16936 .44528 L .17485 .41809 L F

.63417 .67972 m .66 .72519 L .66031 .68906 L .438 .404 .724 r

F

.64132 .64058 m .63417 .67972 L .66031 .68906 L .469 .373 .664 r

F

.66 .72519 m .66601 .75794 L .69253 .76819 L .392 .434 .785 r

F

.66601 .75794 m .70516 .79738 L .69253 .76819 L .314 .464 .85 r

F

0 g

.91331 .78016 m

.97796 .89707 L

s

.17699 .61373 m .21756 .60465 L .2353 .62367 L .643 .765 .937 r

F

.6578 .5973 m .65787 .59727 L .68431 .60567 L .525 .085 .147 r

F

.6578 .5973 m .68431 .60567 L .68424 .6057 L F

.6578 .5973 m .6676 .64949 L .68424 .6057 L .494 .336 .595 r

F

.6578 .5973 m .64132 .64058 L .6676 .64949 L F

0 g

.63195 .58908 m

.6578 .5973 L

s

.0959 .21365 m

.74617 .02894 L

s

.02943 .70308 m

.0959 .21365 L

s

.64132 .64058 m .66031 .68906 L .6676 .64949 L .469 .373 .664 r

F

.78108 .8434 m .75358 .83224 L .75351 .83228 L .572 .173 .248 r

F

.78108 .8434 m .78115 .84336 L .75358 .83224 L F

.73219 .80811 m .75351 .83228 L .78108 .8434 L .142 .476 .896 r

F

0 g

.7533 .83213 m

.75341 .83218 L

s

.70516 .79738 m .75351 .83228 L .73219 .80811 L .142 .476 .896 r

F

0 g

.72656 .82141 m

.75351 .83228 L

s

.69253 .76819 m .70516 .79738 L .73219 .80811 L .314 .464 .85 r

F

.17802 .38782 m .17494 .41807 L .17485 .41809 L .572 .341 .527 r

F

.17802 .38782 m .17812 .3878 L .17494 .41807 L F

0 g

.17802 .38782 m

.18114 .35807 L

s

.66 .72519 m .69253 .76819 L .68663 .73513 L .392 .434 .785 r

F

.66031 .68906 m .66 .72519 L .68663 .73513 L .438 .404 .724 r

F

.16567 .56158 m .17699 .61373 L .16237 .59357 L .989 .755 .486 r

F

.16237 .59357 m .21756 .60465 L .17699 .61373 L .643 .765 .937 r

F

0 g

.17699 .61373 m

.19899 .63167 L

s

.17161 .44891 m .16613 .47585 L .16284 .50697 L 0 0 .013 r

F

.17485 .41809 m .16613 .47585 L .17161 .44891 L F

.1595 .53864 m .16567 .56158 L .16237 .59357 L .966 .782 .346 r

F

.66031 .68906 m .68663 .73513 L .68706 .69862 L .438 .404 .724 r

F

.6676 .64949 m .66031 .68906 L .68706 .69862 L .469 .373 .664 r

F

.68663 .73513 m .69253 .76819 L .71966 .77867 L .392 .434 .785 r

F

.69253 .76819 m .73219 .80811 L .71966 .77867 L .314 .464 .85 r

F

.68424 .6057 m .68431 .60567 L .71136 .61427 L .525 .085 .147 r

F

.68424 .6057 m .71136 .61427 L .71129 .61431 L F

.68424 .6057 m .69449 .65862 L .71129 .61431 L .494 .336 .595 r

F

.68424 .6057 m .6676 .64949 L .69449 .65862 L F

0 g

.6578 .5973 m

.68424 .6057 L

s

.16237 .59357 m .19939 .58517 L .21756 .60465 L .643 .765 .937 r

F

.6676 .64949 m .68706 .69862 L .69449 .65862 L .469 .373 .664 r

F

.80929 .85477 m .78115 .84336 L .78108 .8434 L .572 .173 .248 r

F

.80929 .85477 m .80936 .85473 L .78115 .84336 L F

.75985 .81908 m .78108 .8434 L .80929 .85477 L .142 .476 .896 r

F

0 g

.78086 .84324 m

.78098 .84329 L

s

.73219 .80811 m .78108 .8434 L .75985 .81908 L .142 .476 .896 r

F

0 g

.75351 .83228 m

.78108 .8434 L

s

.71966 .77867 m .73219 .80811 L .75985 .81908 L .314 .464 .85 r

F

.17485 .41809 m .17171 .44889 L .17161 .44891 L .572 .341 .527 r

F

.17485 .41809 m .17494 .41807 L .17171 .44889 L F

0 g

.17485 .41809 m


.17802 .38782 L

s

.16832 .48028 m .16284 .50697 L .1595 .53864 L 0 0 .013 r

F

.17161 .44891 m .16284 .50697 L .16832 .48028 L F

.68663 .73513 m .71966 .77867 L .71388 .74529 L .392 .434 .785 r

F

.68706 .69862 m .68663 .73513 L .71388 .74529 L .438 .404 .724 r

F

.1595 .53864 m .16237 .59357 L .15609 .57088 L .966 .782 .346 r

F

.15609 .57088 m .19939 .58517 L .16237 .59357 L .643 .765 .937 r

F

0 g

.16237 .59357 m

.17699 .61373 L

s

.68706 .69862 m .71388 .74529 L .71444 .70841 L .438 .404 .724 r

F

.69449 .65862 m .68706 .69862 L .71444 .70841 L .469 .373 .664 r

F

.17161 .44891 m .16842 .48026 L .16832 .48028 L .572 .341 .527 r

F

.17161 .44891 m .17171 .44889 L .16842 .48026 L F

0 g

.17161 .44891 m

.17485 .41809 L

s

.71388 .74529 m .71966 .77867 L .74743 .7894 L .392 .434 .785 r

F

.71966 .77867 m .75985 .81908 L .74743 .7894 L .314 .464 .85 r

F

.71129 .61431 m .71136 .61427 L .73905 .62308 L .525 .085 .147 r

F

.71129 .61431 m .73905 .62308 L .73898 .62311 L F

.71129 .61431 m .72201 .66795 L .73898 .62311 L .494 .336 .595 r

F

.71129 .61431 m .69449 .65862 L .72201 .66795 L F

0 g

.68424 .6057 m

.71129 .61431 L

s

.69449 .65862 m .71444 .70841 L .72201 .66795 L .469 .373 .664 r

F

.78817 .83031 m .80936 .85473 L .80929 .85477 L .884 .776 .738 r

F

0 g

.80907 .85462 m

.8092 .85467 L

s

.78817 .83031 m .80727 .82017 L .80936 .85473 L .884 .776 .738 r

F

.75985 .81908 m .80929 .85477 L .78817 .83031 L .142 .476 .896 r

F

0 g

.80929 .85477 m

.80929 .85477 L

s

.78108 .8434 m

.80929 .85477 L

s

.16497 .51222 m .1595 .53864 L .15609 .57088 L 0 0 .013 r

F

.16832 .48028 m .1595 .53864 L .16497 .51222 L F

.15609 .57088 m .18076 .5652 L .19939 .58517 L .643 .765 .937 r

F

.74743 .7894 m .75985 .81908 L .78817 .83031 L .314 .464 .85 r

F

.71388 .74529 m .74743 .7894 L .74177 .7557 L .392 .434 .785 r

F

.71444 .70841 m .71388 .74529 L .74177 .7557 L .438 .404 .724 r

F

.77586 .80038 m .80727 .82017 L .78817 .83031 L .884 .776 .738 r

F

.77586 .80038 m .80515 .78521 L .80727 .82017 L F

.16832 .48028 m .16507 .5122 L .16497 .51222 L .572 .341 .527 r

F

.16832 .48028 m .16842 .48026 L .16507 .5122 L F

0 g

.16832 .48028 m

.17161 .44891 L

s

.16156 .54475 m .18076 .5652 L .15609 .57088 L .643 .765 .937 r

F

.16497 .51222 m .15609 .57088 L .16156 .54475 L 0 0 .013 r

F

0 g

.15609 .57088 m

.16237 .59357 L

s

.71444 .70841 m .74177 .7557 L .74247 .71843 L .438 .404 .724 r

F

.72201 .66795 m .71444 .70841 L .74247 .71843 L .469 .373 .664 r

F

.74177 .7557 m .74743 .7894 L .77586 .80038 L .392 .434 .785 r

F

.74743 .7894 m .78817 .83031 L .77586 .80038 L .314 .464 .85 r

F

0 g

.78817 .83031 m

.80929 .85477 L

s

.73898 .62311 m .73905 .62308 L .7674 .63209 L .525 .085 .147 r

F

.73898 .62311 m .7674 .63209 L .76732 .63212 L F

.73898 .62311 m .75019 .67751 L .76732 .63212 L .494 .336 .595 r

F

.73898 .62311 m .72201 .66795 L .75019 .67751 L F

0 g

.71129 .61431 m

.73898 .62311 L

s

.77033 .76636 m .80515 .78521 L .77586 .80038 L .884 .776 .738 r

F

.77033 .76636 m .803 .74986 L .80515 .78521 L F

.72201 .66795 m .74247 .71843 L .75019 .67751 L .469 .373 .664 r

F

.16156 .54475 m .16166 .54472 L .18076 .5652 L .643 .765 .937 r

F

.16497 .51222 m .16166 .54472 L .16156 .54475 L .572 .341 .527 r

F

0 g

.15609 .57088 m

.16156 .54475 L

s

.16497 .51222 m .16507 .5122 L .16166 .54472 L .572 .341 .527 r

F

0 g

.16497 .51222 m

.16832 .48028 L

s

.16166 .54472 m

.18123 .35805 L

s

.16166 .54472 m

.26952 .66035 L

s

.16156 .54475 m

.16497 .51222 L

s

.74177 .7557 m .77586 .80038 L .77033 .76636 L .392 .434 .785 r

F

0 g

.77586 .80038 m

.78817 .83031 L

s

.74247 .71843 m .74177 .7557 L .77033 .76636 L .438 .404 .724 r

F

.77117 .72868 m .803 .74986 L .77033 .76636 L .884 .776 .738 r

F

.77117 .72868 m .80084 .71409 L .803 .74986 L F

.74247 .71843 m .77033 .76636 L .77117 .72868 L .438 .404 .724 r

F

.75019 .67751 m .74247 .71843 L .77117 .72868 L .469 .373 .664 r

F

0 g

.77033 .76636 m

.77586 .80038 L

s

.76732 .63212 m .7674 .63209 L .79643 .64132 L .525 .085 .147 r

F

0 g

.87625 .71313 m

.91331 .78016 L

s

.76732 .63212 m .79643 .64132 L .79635 .64135 L .525 .085 .147 r

F

.76732 .63212 m .77904 .6873 L .79635 .64135 L .494 .336 .595 r

F

.76732 .63212 m .75019 .67751 L .77904 .6873 L F

0 g

.73898 .62311 m

.76732 .63212 L

s

.77904 .6873 m .80084 .71409 L .77117 .72868 L .884 .776 .738 r

F

.77904 .6873 m .79865 .67792 L .80084 .71409 L F

.75019 .67751 m .77117 .72868 L .77904 .6873 L .469 .373 .664 r

F

.79635 .64135 m .79865 .67792 L .77904 .6873 L .884 .776 .738 r

F

.79635 .64135 m .79643 .64132 L .79865 .67792 L F

0 g

.76732 .63212 m

.79635 .64135 L

s

.79643 .64132 m

.80936 .85473 L

s

.78114 .54113 m

.87625 .71313 L

s

.63203 .58905 m

.79643 .64132 L

s

.77033 .76636 m

.77117 .72868 L

s

.77117 .72868 m

.77904 .6873 L

s

.77904 .6873 m

.79635 .64135 L

s

.78114 .54113 m

.74617 .02894 L

s

.78114 .54113 m

.02943 .70308 L

s

.25 Mabswid

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.532515 0.477324 0.994568 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.0184128 1.11086 1.11022e-16 1.11086 [

[.5 1.03133 -26.4 0 ]

[.5 1.03133 26.4 7.2 ]

[.07999 .18147 -4.33011 -7.2 ]

[.07999 .18147 .46989 0 ]

[.28509 .12212 -8.07061 -7.2 ]

[.28509 .12212 1.52939 0 ]

[.50279 .05919 -11.2215 -7.2 ]

[.50279 .05919 3.17851 0 ]

[.73427 -0.0076 -10.3371 -7.2 ]

[.73427 -0.0076 4.06293 0 ]

[.77653 .00912 0 -4.62791 ]

[.77653 .00912 14.4 2.57209 ]

[.84438 .16831 0 -4.54413 ]

[.84438 .16831 4.8 2.65587 ]

[.90296 .30575 0 -4.47298 ]

[.90296 .30575 9.6 2.72702 ]

[.95404 .42562 0 -4.4118 ]

[.95404 .42562 14.4 2.7882 ]

[.05897 .21099 -14.4 -2.57051 ]

[.05897 .21099 0 4.62949 ]

[.03311 .39048 -4.8 -2.6608 ]

[.03311 .39048 0 4.5392 ]

[.00422 .59105 -9.6 -2.76251 ]

[.00422 .59105 0 4.43749 ]

[ 0 0 0 0 ]

[ 1 1.01883 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[({100,50,50})] .5 1.03133 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

.25 Mabswid

.75767 0 m

.94405 .43703 L

s

.76318 .01294 m

.75651 .01484 L

s

[(-50)] .77653 .00912 -1 .28553 Mshowa

.83095 .17183 m

.82423 .17359 L

s

[(0)] .84438 .16831 -1 .26226 Mshowa

.88946 .30902 m

.88271 .31066 L

s

[(50)] .90296 .30575 -1 .24249 Mshowa

.94049 .42867 m

.93372 .4302 L

s

[(100)] .95404 .42562 -1 .2255 Mshowa

.125 Mabswid

.77758 .0467 m

.77357 .04782 L

s

.79154 .07942 m

.78752 .08053 L

s

.80507 .11115 m

.80105 .11224 L

s

.8182 .14194 m

.81418 .14302 L

s

.84333 .20086 m

.83929 .2019 L

s

.85535 .22905 m

.85132 .23008 L

s

.86704 .25646 m

.863 .25747 L

s

.87841 .2831 m

.87436 .2841 L

s

.90022 .33424 m

.89616 .33521 L

s

.91069 .35879 m

.90663 .35974 L

s

.92088 .3827 m

.91682 .38364 L

s

.93081 .40598 m

.92675 .40691 L

s

.25 Mabswid

.07384 .19656 m

0 .71164 L

s

.07232 .20717 m

.079 .20526 L

s

[(-50)] .05897 .21099 1 -0.28597 Mshowa

.04654 .38698 m

.05326 .38522 L

s

[(0)] .03311 .39048 1 -0.26089 Mshowa

.01774 .5879 m

.0245 .58633 L

s

[(50)] .00422 .59105 1 -0.23264 Mshowa

.125 Mabswid

.06738 .24161 m

.07139 .24048 L

s

.06234 .27678 m

.06636 .27567 L

s

.05719 .31271 m

.06121 .31162 L

s

.05193 .34944 m

.05595 .34837 L

s

.04104 .42536 m

.04508 .42433 L

s

.03541 .46461 m

.03946 .4636 L

s

.02966 .50476 m

.0337 .50377 L

s

.02377 .54585 m

.02782 .54488 L

s

.01157 .63095 m

.01563 .63003 L

s

.00525 .67503 m

.00932 .67414 L

s

0 0 m

1 0 L

1 1.01883 L

0 1.01883 L

closepath

clip

newpath

.5 Mabswid

.92692 .44201 m

.37994 .56463 L

s

.36101 .99851 m

.37994 .56463 L

s

.74617 .02894 m

.92692 .44201 L

s

.92692 .44201 m

.97796 .89707 L

s

.36101 .99851 m

.97796 .89707 L

s

.02943 .70308 m

.36101 .99851 L

s

.28245 .48062 m .26661 .46133 L .24399 .46681 L .659 .748 .916 r

F

.28245 .48062 m .28253 .4806 L .26661 .46133 L F

.24399 .46681 m .28245 .48062 L .28037 .50935 L .822 .574 .564 r

F

0 g

.22503 .37321 m

.37994 .56463 L

s

.28037 .50935 m .28253 .4806 L .28245 .48062 L .59 .37 .55 r

F

0 g

.28245 .48062 m

.28245 .48062 L

s

.28037 .50935 m .28045 .50933 L .28253 .4806 L .59 .37 .55 r

F

.24399 .46681 m .25032 .44162 L .21573 .45012 L .659 .748 .916 r

F

.24399 .46681 m .26661 .46133 L .25032 .44162 L F

.24399 .46681 m .28037 .50935 L .24157 .49567 L .822 .574 .564 r

F

.21573 .45012 m .24399 .46681 L .24157 .49567 L .881 .631 .555 r

F

.27825 .53856 m .28045 .50933 L .28037 .50935 L .59 .37 .55 r

F

.24157 .49567 m .28037 .50935 L .27825 .53856 L .822 .574 .564 r

F

.27825 .53856 m .27834 .53854 L .28045 .50933 L .59 .37 .55 r

F

.24157 .49567 m .27825 .53856 L .23912 .525 L .822 .574 .564 r

F

.21305 .47912 m .24157 .49567 L .23912 .525 L .881 .631 .555 r

F

.21573 .45012 m .24157 .49567 L .21305 .47912 L F

.2761 .56825 m .27834 .53854 L .27825 .53856 L .59 .37 .55 r

F

.23912 .525 m .27825 .53856 L .2761 .56825 L .822 .574 .564 r

F

.2761 .56825 m .27619 .56823 L .27834 .53854 L .59 .37 .55 r

F

.21573 .45012 m .23365 .42145 L .19501 .43108 L .659 .748 .916 r

F

.21573 .45012 m .25032 .44162 L .23365 .42145 L F

.19501 .43108 m .21573 .45012 L .21305 .47912 L .939 .691 .535 r

F

.23912 .525 m .2761 .56825 L .23662 .55483 L .822 .574 .564 r

F

.21033 .5086 m .23912 .525 L .23662 .55483 L .881 .631 .555 r

F

.21305 .47912 m .23912 .525 L .21033 .5086 L F

.23662 .55483 m .2761 .56825 L .27391 .59844 L .822 .574 .564 r

F

.27391 .59844 m .27619 .56823 L .2761 .56825 L .59 .37 .55 r

F

.27391 .59844 m .274 .59842 L .27619 .56823 L F

.19501 .43108 m .21659 .40081 L .18136 .40971 L .659 .748 .916 r

F

.19501 .43108 m .23365 .42145 L .21659 .40081 L F

.23662 .55483 m .27391 .59844 L .23408 .58516 L .822 .574 .564 r

F

.23408 .58516 m .27391 .59844 L .27169 .62914 L F

.27169 .62914 m .274 .59842 L .27391 .59844 L .59 .37 .55 r

F

.27169 .62914 m .27178 .62912 L .274 .59842 L F

.18136 .40971 m .19912 .37968 L .17566 .3857 L .659 .748 .916 r

F

.18136 .40971 m .21659 .40081 L .19912 .37968 L F

.23408 .58516 m .27169 .62914 L .2315 .616 L .822 .574 .564 r

F

.2315 .616 m .27169 .62914 L .26943 .66037 L F

.26943 .66037 m .27178 .62912 L .27169 .62914 L .59 .37 .55 r

F

.26943 .66037 m .26952 .66035 L .27178 .62912 L F

.17566 .3857 m .19912 .37968 L .18123 .35805 L .659 .748 .916 r

F

.18123 .35805 m .28253 .4806 L .26952 .66035 L .97 .724 .507 r

F

.19214 .46024 m .21305 .47912 L .21033 .5086 L .939 .691 .535 r

F

.19501 .43108 m .21305 .47912 L .19214 .46024 L F

.18136 .40971 m .19501 .43108 L .19214 .46024 L .989 .755 .486 r

F

0 g

.19501 .43108 m

.20533 .44057 L

s

.20757 .53859 m .23662 .55483 L .23408 .58516 L .881 .631 .555 r

F

.21033 .5086 m .23662 .55483 L .20757 .53859 L F

.18921 .48989 m .21033 .5086 L .20757 .53859 L .939 .691 .535 r

F

.19214 .46024 m .21033 .5086 L .18921 .48989 L F

.759 .68255 m .74819 .66494 L .72317 .66994 L .643 .765 .937 r

F

.759 .68255 m .7591 .68253 L .74819 .66494 L F

.72317 .66994 m .759 .68255 L .76088 .71403 L .833 .57 .542 r

F

.76088 .71403 m .7591 .68253 L .759 .68255 L .604 .393 .568 r

F

0 g

.759 .68255 m

.759 .68255 L

s

.76088 .71403 m .76098 .71401 L .7591 .68253 L .604 .393 .568 r

F

.72317 .66994 m .73703 .64692 L .69871 .65469 L .643 .765 .937 r

F

.72317 .66994 m .74819 .66494 L .73703 .64692 L F

.72317 .66994 m .76088 .71403 L .72476 .70158 L .833 .57 .542 r

F

.69871 .65469 m .72317 .66994 L .72476 .70158 L .908 .632 .508 r

F

.76279 .74605 m .76098 .71401 L .76088 .71403 L .604 .393 .568 r

F

.72476 .70158 m .76088 .71403 L .76279 .74605 L .833 .57 .542 r

F

.76279 .74605 m .76289 .74603 L .76098 .71401 L .604 .393 .568 r

F

.72476 .70158 m .76279 .74605 L .72637 .73377 L .833 .57 .542 r

F

.70011 .68652 m .72476 .70158 L .72637 .73377 L .908 .632 .508 r

F

.69871 .65469 m .72476 .70158 L .70011 .68652 L F

.76474 .77862 m .76289 .74603 L .76279 .74605 L .604 .393 .568 r

F

.72637 .73377 m .76279 .74605 L .76474 .77862 L .833 .57 .542 r

F

.76474 .77862 m .76484 .7786 L .76289 .74603 L .604 .393 .568 r

F

.69871 .65469 m .72559 .62848 L .68275 .63728 L .643 .765 .937 r

F

.69871 .65469 m .73703 .64692 L .72559 .62848 L F

.72637 .73377 m .76474 .77862 L .72802 .76651 L .833 .57 .542 r

F

.76672 .81175 m .76484 .7786 L .76474 .77862 L .604 .393 .568 r

F

.72802 .76651 m .76474 .77862 L .76672 .81175 L .833 .57 .542 r

F

.76672 .81175 m .76682 .81174 L .76484 .7786 L .604 .393 .568 r

F

.68275 .63728 m .71388 .60958 L .67476 .61773 L .643 .765 .937 r

F

.68275 .63728 m .72559 .62848 L .71388 .60958 L F

.72802 .76651 m .76672 .81175 L .72969 .79983 L .833 .57 .542 r

F

.76873 .84547 m .76682 .81174 L .76672 .81175 L .604 .393 .568 r

F

.72969 .79983 m .76672 .81175 L .76873 .84547 L .833 .57 .542 r

F

.76873 .84547 m .76883 .84545 L .76682 .81174 L .604 .393 .568 r

F

.67476 .61773 m .70188 .59022 L .67579 .59573 L .643 .765 .937 r

F

.67476 .61773 m .71388 .60958 L .70188 .59022 L F

.72969 .79983 m .76873 .84547 L .7314 .83374 L .833 .57 .542 r

F

.77078 .87979 m .76883 .84545 L .76873 .84547 L .604 .393 .568 r

F

.7314 .83374 m .76873 .84547 L .77078 .87979 L .833 .57 .542 r

F

.77078 .87979 m .77088 .87977 L .76883 .84545 L .604 .393 .568 r

F

.67579 .59573 m .70188 .59022 L .68958 .57038 L .643 .765 .937 r

F

.68958 .57038 m .7591 .68253 L .77088 .87977 L .984 .709 .342 r

F

.17833 .43905 m .19214 .46024 L .18921 .48989 L .989 .755 .486 r

F

.18136 .40971 m .19214 .46024 L .17833 .43905 L F

.17566 .3857 m .18136 .40971 L .17833 .43905 L .966 .782 .346 r

F

0 g

.18136 .40971 m

.19501 .43108 L

s

.20476 .56909 m .23408 .58516 L .2315 .616 L .881 .631 .555 r

F

.20757 .53859 m .23408 .58516 L .20476 .56909 L F

.18623 .52006 m .20757 .53859 L .20476 .56909 L .939 .691 .535 r

F

.18921 .48989 m .20757 .53859 L .18623 .52006 L F

.17525 .46889 m .18921 .48989 L .18623 .52006 L .989 .755 .486 r

F

.17833 .43905 m .18921 .48989 L .17525 .46889 L F

.17254 .41523 m .17833 .43905 L .17525 .46889 L .966 .782 .346 r

F

.17566 .3857 m .17833 .43905 L .17254 .41523 L F

.2315 .616 m .26943 .66037 L .22888 .64738 L .822 .574 .564 r

F

.2019 .60011 m .2315 .616 L .22888 .64738 L .881 .631 .555 r

F

.20476 .56909 m .2315 .616 L .2019 .60011 L F

.22888 .64738 m .26952 .66035 L .26943 .66037 L .643 .765 .937 r

F

0 g

.26943 .66037 m

.26943 .66037 L

s

.26943 .66032 m

.26945 .6601 L

s

.18623 .52006 m .20476 .56909 L .1832 .55074 L .939 .691 .535 r

F

.1832 .55074 m .20476 .56909 L .2019 .60011 L F

.17211 .49925 m .18623 .52006 L .1832 .55074 L .989 .755 .486 r

F

.17525 .46889 m .18623 .52006 L .17211 .49925 L F

.16936 .44528 m .17525 .46889 L .17211 .49925 L .966 .782 .346 r

F

.17254 .41523 m .17525 .46889 L .16936 .44528 L F

.1832 .55074 m .2019 .60011 L .18012 .58196 L .939 .691 .535 r

F

.17211 .49925 m .1832 .55074 L .16892 .53014 L .989 .755 .486 r

F

.16892 .53014 m .1832 .55074 L .18012 .58196 L F

.16613 .47585 m .17211 .49925 L .16892 .53014 L .966 .782 .346 r

F

.16936 .44528 m .17211 .49925 L .16613 .47585 L F

.16892 .53014 m .18012 .58196 L .16567 .56158 L .989 .755 .486 r

F

.16613 .47585 m .16892 .53014 L .16284 .50697 L .966 .782 .346 r

F

.16284 .50697 m .16892 .53014 L .16567 .56158 L F

.16284 .50697 m .16567 .56158 L .1595 .53864 L F

.18123 .35805 m .26952 .66035 L .16166 .54472 L .97 .724 .507 r

F

.22888 .64738 m .25261 .64222 L .26952 .66035 L .643 .765 .937 r

F

0 g

.26952 .66035 m

.28253 .4806 L

s

.68275 .63728 m .69871 .65469 L .70011 .68652 L .974 .694 .435 r

F

0 g

.69871 .65469 m

.71429 .66441 L

s

.17566 .3857 m .18123 .35805 L .18114 .35807 L .659 .748 .916 r

F

.18114 .35807 m .17566 .3857 L .17254 .41523 L 0 0 .013 r

F

0 g

.17647 .38912 m

.17751 .39352 L

s

.0959 .21365 m

.18105 .31887 L

s

.18105 .31887 m

.22503 .37321 L

s

.2019 .60011 m .22888 .64738 L .19899 .63167 L .881 .631 .555 r

F

.19899 .63167 m .25261 .64222 L .22888 .64738 L .643 .765 .937 r

F

0 g

.22888 .64738 m

.26943 .66037 L

s

.18012 .58196 m .2019 .60011 L .19899 .63167 L .939 .691 .535 r

F

.70153 .71891 m .72637 .73377 L .72802 .76651 L .908 .632 .508 r

F

.70011 .68652 m .72637 .73377 L .70153 .71891 L F

.19899 .63167 m .2353 .62367 L .25261 .64222 L .643 .765 .937 r

F

.68402 .66933 m .70011 .68652 L .70153 .71891 L .974 .694 .435 r

F

.68275 .63728 m .70011 .68652 L .68402 .66933 L F

.17802 .38782 m .17254 .41523 L .16936 .44528 L 0 0 .013 r

F

.18114 .35807 m .17254 .41523 L .17802 .38782 L F

.67476 .61773 m .68275 .63728 L .68402 .66933 L .956 .706 .255 r

F

0 g

.68275 .63728 m

.69871 .65469 L

s

.18012 .58196 m .19899 .63167 L .17699 .61373 L .939 .691 .535 r

F

.17699 .61373 m .2353 .62367 L .19899 .63167 L .643 .765 .937 r

F

0 g

.19899 .63167 m

.22888 .64738 L

s

.70297 .75186 m .72802 .76651 L .72969 .79983 L .908 .632 .508 r

F

.70153 .71891 m .72802 .76651 L .70297 .75186 L F

.18114 .35807 m .17812 .3878 L .17802 .38782 L .572 .341 .527 r

F

.18114 .35807 m .18123 .35805 L .17812 .3878 L F

0 g

.17566 .3857 m

.18114 .35807 L

s

.18123 .35805 m

.28253 .4806 L

s

.18114 .35807 m

.18114 .35807 L

s

.68531 .70194 m .70153 .71891 L .70297 .75186 L .974 .694 .435 r

F

.68402 .66933 m .70153 .71891 L .68531 .70194 L F

.16567 .56158 m .18012 .58196 L .17699 .61373 L .989 .755 .486 r

F

.17485 .41809 m .16936 .44528 L .16613 .47585 L 0 0 .013 r

F

.17802 .38782 m .16936 .44528 L .17485 .41809 L F

0 g

.97796 .89707 m

.78114 .54113 L

s

.67597 .65001 m .68402 .66933 L .68531 .70194 L .956 .706 .255 r

F

.67476 .61773 m .68402 .66933 L .67597 .65001 L F

.17699 .61373 m .21756 .60465 L .2353 .62367 L .643 .765 .937 r

F

0 g

.0959 .21365 m

.74617 .02894 L

s

.02943 .70308 m

.0959 .21365 L

s

.67579 .59573 m .67476 .61773 L .67597 .65001 L 0 0 .099 r

F

0 g

.67587 .62046 m

.68275 .63728 L

s

.70444 .7854 m .72969 .79983 L .7314 .83374 L .908 .632 .508 r

F

.70297 .75186 m .72969 .79983 L .70444 .7854 L F

.17802 .38782 m .17494 .41807 L .17485 .41809 L .572 .341 .527 r

F

.17802 .38782 m .17812 .3878 L .17494 .41807 L F

0 g

.17802 .38782 m

.18114 .35807 L

s

.68663 .73513 m .70297 .75186 L .70444 .7854 L .974 .694 .435 r

F

.68531 .70194 m .70297 .75186 L .68663 .73513 L F

.16567 .56158 m .17699 .61373 L .16237 .59357 L .989 .755 .486 r

F

.16237 .59357 m .21756 .60465 L .17699 .61373 L .643 .765 .937 r

F

0 g

.17699 .61373 m

.19899 .63167 L

s

.17161 .44891 m .16613 .47585 L .16284 .50697 L 0 0 .013 r

F

.17485 .41809 m .16613 .47585 L .17161 .44891 L F

.67721 .68287 m .68531 .70194 L .68663 .73513 L .956 .706 .255 r

F

.67597 .65001 m .68531 .70194 L .67721 .68287 L F

.1595 .53864 m .16567 .56158 L .16237 .59357 L .966 .782 .346 r

F

.16237 .59357 m .19939 .58517 L .21756 .60465 L .643 .765 .937 r

F

.67703 .62828 m .67597 .65001 L .67721 .68287 L 0 0 .099 r

F

.67579 .59573 m .67597 .65001 L .67703 .62828 L F

.7314 .83374 m .77078 .87979 L .73313 .86825 L .833 .57 .542 r

F

.70594 .81954 m .7314 .83374 L .73313 .86825 L .908 .632 .508 r

F

.70444 .7854 m .7314 .83374 L .70594 .81954 L F

.73313 .86825 m .77088 .87977 L .77078 .87979 L .618 .785 .962 r

F

0 g

.77075 .87927 m

.77078 .87974 L

s

.77078 .87979 m

.77078 .87979 L

s

.73313 .86825 m .75954 .86367 L .77088 .87977 L .618 .785 .962 r

F

.68797 .76891 m .70444 .7854 L .70594 .81954 L .974 .694 .435 r

F

.68663 .73513 m .70444 .7854 L .68797 .76891 L F

.68958 .57038 m .77088 .87977 L .69832 .77681 L .984 .709 .342 r

F

0 g

.7591 .68253 m

.77088 .87977 L

s

.17485 .41809 m .17171 .44889 L .17161 .44891 L .572 .341 .527 r

F

.17485 .41809 m .17494 .41807 L .17171 .44889 L F

0 g

.17485 .41809 m

.17802 .38782 L

s

.16832 .48028 m .16284 .50697 L .1595 .53864 L 0 0 .013 r

F

.17161 .44891 m .16284 .50697 L .16832 .48028 L F

.67848 .71632 m .68663 .73513 L .68797 .76891 L .956 .706 .255 r

F

.67721 .68287 m .68663 .73513 L .67848 .71632 L F

.67579 .59573 m .68958 .57038 L .68948 .5704 L .643 .765 .937 r

F

.68948 .5704 m .67579 .59573 L .67703 .62828 L 0 0 .392 r

F

0 g

.67476 .61773 m

.67579 .59573 L

s

.1595 .53864 m .16237 .59357 L .15609 .57088 L .966 .782 .346 r

F

.15609 .57088 m .19939 .58517 L .16237 .59357 L .643 .765 .937 r

F

0 g

.16237 .59357 m

.17699 .61373 L

s

.6783 .66141 m .67721 .68287 L .67848 .71632 L 0 0 .099 r

F

.67703 .62828 m .67721 .68287 L .6783 .66141 L F

.70594 .81954 m .73313 .86825 L .70746 .85429 L .908 .632 .508 r

F

.70746 .85429 m .75954 .86367 L .73313 .86825 L .618 .785 .962 r

F

0 g

.73313 .86825 m

.77078 .87979 L

s

.17161 .44891 m .16842 .48026 L .16832 .48028 L .572 .341 .527 r

F

.17161 .44891 m .17171 .44889 L .16842 .48026 L F

0 g

.17161 .44891 m

.17485 .41809 L

s

.68934 .8033 m .70594 .81954 L .70746 .85429 L .974 .694 .435 r

F

.68797 .76891 m .70594 .81954 L .68934 .8033 L F

.16497 .51222 m .1595 .53864 L .15609 .57088 L 0 0 .013 r

F

.16832 .48028 m .1595 .53864 L .16497 .51222 L F

.15609 .57088 m .18076 .5652 L .19939 .58517 L .643 .765 .937 r

F

.70746 .85429 m .74791 .84717 L .75954 .86367 L .618 .785 .962 r

F

.67976 .75038 m .68797 .76891 L .68934 .8033 L .956 .706 .255 r

F

.67848 .71632 m .68797 .76891 L .67976 .75038 L F

.69087 .60324 m .67703 .62828 L .6783 .66141 L 0 0 .392 r

F

.68948 .5704 m .67703 .62828 L .69087 .60324 L F

.67959 .69515 m .67848 .71632 L .67976 .75038 L 0 0 .099 r

F

.6783 .66141 m .67848 .71632 L .67959 .69515 L F

.16832 .48028 m .16507 .5122 L .16497 .51222 L .572 .341 .527 r

F

.16832 .48028 m .16842 .48026 L .16507 .5122 L F

0 g

.16832 .48028 m

.17161 .44891 L

s

.68934 .8033 m .70746 .85429 L .69073 .83833 L .974 .694 .435 r

F

.69073 .83833 m .74791 .84717 L .70746 .85429 L .618 .785 .962 r

F

0 g

.70746 .85429 m

.73313 .86825 L

s

.16156 .54475 m .18076 .5652 L .15609 .57088 L .643 .765 .937 r

F

.16497 .51222 m .15609 .57088 L .16156 .54475 L 0 0 .013 r

F

0 g

.15609 .57088 m

.16237 .59357 L

s

.68948 .5704 m .69097 .60322 L .69087 .60324 L .59 .37 .55 r

F

.68948 .5704 m .68958 .57038 L .69097 .60322 L F

0 g

.68958 .57038 m

.7591 .68253 L

s

.67579 .59573 m

.68948 .5704 L

s

.68948 .5704 m

.68948 .5704 L

s

.68107 .78506 m .68934 .8033 L .69073 .83833 L .956 .706 .255 r

F

.67976 .75038 m .68934 .8033 L .68107 .78506 L F

.69228 .63668 m .6783 .66141 L .67959 .69515 L 0 0 .392 r

F

.69087 .60324 m .6783 .66141 L .69228 .63668 L F

.16156 .54475 m .16166 .54472 L .18076 .5652 L .643 .765 .937 r

F

.69073 .83833 m .73598 .83025 L .74791 .84717 L .618 .785 .962 r

F

.6809 .72951 m .67976 .75038 L .68107 .78506 L 0 0 .099 r

F

.67959 .69515 m .67976 .75038 L .6809 .72951 L F

.16497 .51222 m .16166 .54472 L .16156 .54475 L .572 .341 .527 r

F

0 g

.15609 .57088 m

.16156 .54475 L

s

.16497 .51222 m .16507 .5122 L .16166 .54472 L .572 .341 .527 r

F

0 g

.16497 .51222 m

.16832 .48028 L

s

.16166 .54472 m

.18123 .35805 L

s

.16166 .54472 m

.26952 .66035 L

s

.16156 .54475 m

.16497 .51222 L

s

.69087 .60324 m .69239 .63666 L .69228 .63668 L .59 .37 .55 r

F

.69087 .60324 m .69097 .60322 L .69239 .63666 L F

0 g

.68948 .5704 m

.69087 .60324 L

s

.68107 .78506 m .69073 .83833 L .6824 .82038 L .956 .706 .255 r

F

.6824 .82038 m .73598 .83025 L .69073 .83833 L .618 .785 .962 r

F

0 g

.69073 .83833 m

.70746 .85429 L

s

.69372 .67074 m .67959 .69515 L .6809 .72951 L 0 0 .392 r

F

.69228 .63668 m .67959 .69515 L .69372 .67074 L F

.68224 .7645 m .68107 .78506 L .6824 .82038 L 0 0 .099 r

F

.6809 .72951 m .68107 .78506 L .68224 .7645 L F

.6824 .82038 m .72375 .81289 L .73598 .83025 L .618 .785 .962 r

F

.69228 .63668 m .69383 .67072 L .69372 .67074 L .59 .37 .55 r

F

.69228 .63668 m .69239 .63666 L .69383 .67072 L F

0 g

.69087 .60324 m

.69228 .63668 L

s

.69519 .70544 m .6809 .72951 L .68224 .7645 L 0 0 .392 r

F

.69372 .67074 m .6809 .72951 L .69519 .70544 L F

.68224 .7645 m .6824 .82038 L .6836 .80016 L 0 0 .099 r

F

.6836 .80016 m .72375 .81289 L .6824 .82038 L .618 .785 .962 r

F

0 g

.6824 .82038 m

.69073 .83833 L

s

.69372 .67074 m .6953 .70542 L .69519 .70544 L .59 .37 .55 r

F

.69372 .67074 m .69383 .67072 L .6953 .70542 L F

0 g

.69228 .63668 m

.69372 .67074 L

s

.69669 .7408 m .68224 .7645 L .6836 .80016 L 0 0 .392 r

F

.69519 .70544 m .68224 .7645 L .69669 .7408 L F

.6836 .80016 m .7112 .79509 L .72375 .81289 L .618 .785 .962 r

F

.69519 .70544 m .69679 .74078 L .69669 .7408 L .59 .37 .55 r

F

.69519 .70544 m .6953 .70542 L .69679 .74078 L F

0 g

.69372 .67074 m

.69519 .70544 L

s

.69669 .7408 m .6836 .80016 L .69821 .77683 L 0 0 .392 r

F

.69821 .77683 m .7112 .79509 L .6836 .80016 L .618 .785 .962 r

F

0 g


.6824 .82038 m

.6836 .80016 L

s

.69821 .77683 m .69832 .77681 L .7112 .79509 L .618 .785 .962 r

F

.69669 .7408 m .69832 .77681 L .69821 .77683 L .59 .37 .55 r

F

0 g

.6836 .80016 m

.69821 .77683 L

s

.69669 .7408 m .69679 .74078 L .69832 .77681 L .59 .37 .55 r

F

0 g

.69519 .70544 m

.69669 .7408 L

s

.69832 .77681 m

.77088 .87977 L

s

.68958 .57038 m

.69832 .77681 L

s

.69669 .7408 m

.69821 .77683 L

s

.78114 .54113 m

.74617 .02894 L

s

.78114 .54113 m

.02943 .70308 L

s

.25 Mabswid

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.532515 0.97619 0.994568 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.0184128 1.11086 1.11022e-16 1.11086 [

[.5 1.03133 -45.6 0 ]

[.5 1.03133 45.6 7.2 ]

[.07999 .18147 -4.33011 -7.2 ]

[.07999 .18147 .46989 0 ]

[.28509 .12212 -8.07061 -7.2 ]

[.28509 .12212 1.52939 0 ]

[.50279 .05919 -11.2215 -7.2 ]

[.50279 .05919 3.17851 0 ]

[.73427 -0.0076 -10.3371 -7.2 ]

[.73427 -0.0076 4.06293 0 ]

[.77653 .00912 0 -4.62791 ]

[.77653 .00912 14.4 2.57209 ]

[.84438 .16831 0 -4.54413 ]

[.84438 .16831 4.8 2.65587 ]

[.90296 .30575 0 -4.47298 ]

[.90296 .30575 9.6 2.72702 ]

[.95404 .42562 0 -4.4118 ]

[.95404 .42562 14.4 2.7882 ]

[.05897 .21099 -14.4 -2.57051 ]

[.05897 .21099 0 4.62949 ]

[.03311 .39048 -4.8 -2.6608 ]

[.03311 .39048 0 4.5392 ]

[.00422 .59105 -9.6 -2.76251 ]

[.00422 .59105 0 4.43749 ]

[ 0 0 0 0 ]

[ 1 1.01883 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[({100,50,50},{0,0,1})] .5 1.03133 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

.25 Mabswid

.75767 0 m

.94405 .43703 L

s

.76318 .01294 m

.75651 .01484 L

s

[(-50)] .77653 .00912 -1 .28553 Mshowa

.83095 .17183 m

.82423 .17359 L

s

[(0)] .84438 .16831 -1 .26226 Mshowa

.88946 .30902 m

.88271 .31066 L

s

[(50)] .90296 .30575 -1 .24249 Mshowa

.94049 .42867 m

.93372 .4302 L

s

[(100)] .95404 .42562 -1 .2255 Mshowa

.125 Mabswid

.77758 .0467 m

.77357 .04782 L

s

.79154 .07942 m

.78752 .08053 L

s

.80507 .11115 m

.80105 .11224 L

s

.8182 .14194 m

.81418 .14302 L

s

.84333 .20086 m

.83929 .2019 L

s

.85535 .22905 m

.85132 .23008 L

s

.86704 .25646 m

.863 .25747 L

s

.87841 .2831 m

.87436 .2841 L

s

.90022 .33424 m

.89616 .33521 L

s

.91069 .35879 m

.90663 .35974 L

s

.92088 .3827 m

.91682 .38364 L

s

.93081 .40598 m

.92675 .40691 L

s

.25 Mabswid

.07384 .19656 m

0 .71164 L

s

.07232 .20717 m

.079 .20526 L

s

[(-50)] .05897 .21099 1 -0.28597 Mshowa

.04654 .38698 m

.05326 .38522 L

s

[(0)] .03311 .39048 1 -0.26089 Mshowa

.01774 .5879 m

.0245 .58633 L

s

[(50)] .00422 .59105 1 -0.23264 Mshowa

.125 Mabswid

.06738 .24161 m

.07139 .24048 L

s

.06234 .27678 m

.06636 .27567 L

s

.05719 .31271 m

.06121 .31162 L

s

.05193 .34944 m

.05595 .34837 L

s

.04104 .42536 m

.04508 .42433 L

s

.03541 .46461 m

.03946 .4636 L

s

.02966 .50476 m

.0337 .50377 L

s

.02377 .54585 m

.02782 .54488 L

s

.01157 .63095 m

.01563 .63003 L

s

.00525 .67503 m

.00932 .67414 L

s

0 0 m

1 0 L

1 1.01883 L

0 1.01883 L

closepath

clip

newpath

.5 Mabswid

.92692 .44201 m

.37994 .56463 L

s

.36101 .99851 m

.37994 .56463 L

s

.74617 .02894 m

.92692 .44201 L

s

.92692 .44201 m

.97796 .89707 L

s

.36101 .99851 m

.97796 .89707 L

s

.02943 .70308 m

.36101 .99851 L

s

.28245 .48062 m .26661 .46133 L .24399 .46681 L .659 .748 .916 r

F

.28245 .48062 m .28253 .4806 L .26661 .46133 L F

.24399 .46681 m .28245 .48062 L .28037 .50935 L .822 .574 .564 r

F

0 g

.22503 .37321 m

.37994 .56463 L

s

.28037 .50935 m .28253 .4806 L .28245 .48062 L .59 .37 .55 r

F

0 g

.28245 .48062 m

.28245 .48062 L

s

.28037 .50935 m .28045 .50933 L .28253 .4806 L .59 .37 .55 r

F

.24399 .46681 m .25032 .44162 L .21573 .45012 L .659 .748 .916 r

F

.24399 .46681 m .26661 .46133 L .25032 .44162 L F

.24399 .46681 m .28037 .50935 L .24157 .49567 L .822 .574 .564 r

F

.21573 .45012 m .24399 .46681 L .24157 .49567 L .881 .631 .555 r

F

.27825 .53856 m .28045 .50933 L .28037 .50935 L .59 .37 .55 r

F

.24157 .49567 m .28037 .50935 L .27825 .53856 L .822 .574 .564 r

F

.27825 .53856 m .27834 .53854 L .28045 .50933 L .59 .37 .55 r

F

.24157 .49567 m .27825 .53856 L .23912 .525 L .822 .574 .564 r

F

.21305 .47912 m .24157 .49567 L .23912 .525 L .881 .631 .555 r

F

.21573 .45012 m .24157 .49567 L .21305 .47912 L F

.2761 .56825 m .27834 .53854 L .27825 .53856 L .59 .37 .55 r

F

.23912 .525 m .27825 .53856 L .2761 .56825 L .822 .574 .564 r

F

.2761 .56825 m .27619 .56823 L .27834 .53854 L .59 .37 .55 r

F

.21573 .45012 m .23365 .42145 L .19501 .43108 L .659 .748 .916 r

F

.21573 .45012 m .25032 .44162 L .23365 .42145 L F

.19501 .43108 m .21573 .45012 L .21305 .47912 L .939 .691 .535 r

F

.23912 .525 m .2761 .56825 L .23662 .55483 L .822 .574 .564 r

F

.21033 .5086 m .23912 .525 L .23662 .55483 L .881 .631 .555 r

F

.21305 .47912 m .23912 .525 L .21033 .5086 L F

.23662 .55483 m .2761 .56825 L .27391 .59844 L .822 .574 .564 r

F

.27391 .59844 m .27619 .56823 L .2761 .56825 L .59 .37 .55 r

F

.27391 .59844 m .274 .59842 L .27619 .56823 L F

.19501 .43108 m .21659 .40081 L .18136 .40971 L .659 .748 .916 r

F

.19501 .43108 m .23365 .42145 L .21659 .40081 L F

.23662 .55483 m .27391 .59844 L .23408 .58516 L .822 .574 .564 r

F

.23408 .58516 m .27391 .59844 L .27169 .62914 L F

.27169 .62914 m .274 .59842 L .27391 .59844 L .59 .37 .55 r

F

.27169 .62914 m .27178 .62912 L .274 .59842 L F

.18136 .40971 m .19912 .37968 L .17566 .3857 L .659 .748 .916 r

F

.18136 .40971 m .21659 .40081 L .19912 .37968 L F

.23408 .58516 m .27169 .62914 L .2315 .616 L .822 .574 .564 r

F

.2315 .616 m .27169 .62914 L .26943 .66037 L F

.26943 .66037 m .27178 .62912 L .27169 .62914 L .59 .37 .55 r

F

.26943 .66037 m .26952 .66035 L .27178 .62912 L F

.17566 .3857 m .19912 .37968 L .18123 .35805 L .659 .748 .916 r

F

.18123 .35805 m .28253 .4806 L .26952 .66035 L .97 .724 .507 r

F

.19214 .46024 m .21305 .47912 L .21033 .5086 L .939 .691 .535 r

F

.19501 .43108 m .21305 .47912 L .19214 .46024 L F

.18136 .40971 m .19501 .43108 L .19214 .46024 L .989 .755 .486 r

F

0 g

.19501 .43108 m

.20533 .44057 L

s

.20757 .53859 m .23662 .55483 L .23408 .58516 L .881 .631 .555 r

F

.21033 .5086 m .23662 .55483 L .20757 .53859 L F

.18921 .48989 m .21033 .5086 L .20757 .53859 L .939 .691 .535 r

F

.19214 .46024 m .21033 .5086 L .18921 .48989 L F

.17833 .43905 m .19214 .46024 L .18921 .48989 L .989 .755 .486 r

F

.18136 .40971 m .19214 .46024 L .17833 .43905 L F

.17566 .3857 m .18136 .40971 L .17833 .43905 L .966 .782 .346 r

F

0 g

.18136 .40971 m

.19501 .43108 L

s

.20476 .56909 m .23408 .58516 L .2315 .616 L .881 .631 .555 r

F

.20757 .53859 m .23408 .58516 L .20476 .56909 L F

.18623 .52006 m .20757 .53859 L .20476 .56909 L .939 .691 .535 r

F

.18921 .48989 m .20757 .53859 L .18623 .52006 L F

.17525 .46889 m .18921 .48989 L .18623 .52006 L .989 .755 .486 r

F

.17833 .43905 m .18921 .48989 L .17525 .46889 L F

.17254 .41523 m .17833 .43905 L .17525 .46889 L .966 .782 .346 r

F

.17566 .3857 m .17833 .43905 L .17254 .41523 L F

.2315 .616 m .26943 .66037 L .22888 .64738 L .822 .574 .564 r

F

.2019 .60011 m .2315 .616 L .22888 .64738 L .881 .631 .555 r

F

.20476 .56909 m .2315 .616 L .2019 .60011 L F

.22888 .64738 m .26952 .66035 L .26943 .66037 L .643 .765 .937 r

F

0 g

.26943 .66037 m

.26943 .66037 L

s

.26943 .66032 m

.26945 .6601 L

s

.18623 .52006 m .20476 .56909 L .1832 .55074 L .939 .691 .535 r

F

.1832 .55074 m .20476 .56909 L .2019 .60011 L F

.17211 .49925 m .18623 .52006 L .1832 .55074 L .989 .755 .486 r

F

.17525 .46889 m .18623 .52006 L .17211 .49925 L F

.16936 .44528 m .17525 .46889 L .17211 .49925 L .966 .782 .346 r

F

.17254 .41523 m .17525 .46889 L .16936 .44528 L F

.1832 .55074 m .2019 .60011 L .18012 .58196 L .939 .691 .535 r

F

.17211 .49925 m .1832 .55074 L .16892 .53014 L .989 .755 .486 r

F

.16892 .53014 m .1832 .55074 L .18012 .58196 L F

.16613 .47585 m .17211 .49925 L .16892 .53014 L .966 .782 .346 r

F

.16936 .44528 m .17211 .49925 L .16613 .47585 L F

.16892 .53014 m .18012 .58196 L .16567 .56158 L .989 .755 .486 r

F

.16613 .47585 m .16892 .53014 L .16284 .50697 L .966 .782 .346 r

F

.16284 .50697 m .16892 .53014 L .16567 .56158 L F

.16284 .50697 m .16567 .56158 L .1595 .53864 L F

.18123 .35805 m .26952 .66035 L .16166 .54472 L .97 .724 .507 r

F

.22888 .64738 m .25261 .64222 L .26952 .66035 L .643 .765 .937 r

F

0 g

.26952 .66035 m

.28253 .4806 L

s

.60528 .80549 m .61847 .84511 L .61846 .84502 L .988 .722 .416 r

F

.61846 .84502 m .65335 .83885 L .65335 .83876 L .604 .393 .568 r

F

.61846 .84502 m .61847 .84511 L .65335 .83885 L F

.64031 .79901 m .61846 .84502 L .60528 .80549 L .65 .602 .788 r

F

.64031 .79901 m .65335 .83876 L .61846 .84502 L F

0 g

.61846 .84502 m

.61846 .84502 L

s

.60528 .80549 m .6057 .82917 L .61847 .84511 L .988 .722 .416 r

F

.67566 .79247 m .65335 .83876 L .64031 .79901 L .65 .602 .788 r

F

.62738 .77006 m .60528 .80549 L .59211 .77674 L .652 .666 .85 r

F

.62738 .77006 m .64031 .79901 L .60528 .80549 L F

.59211 .77674 m .6057 .82917 L .60528 .80549 L .988 .722 .416 r

F

.66299 .76333 m .64031 .79901 L .62738 .77006 L .652 .666 .85 r

F

.66299 .76333 m .67566 .79247 L .64031 .79901 L F

.59211 .77674 m .59263 .81284 L .6057 .82917 L .988 .722 .416 r

F

.61439 .74902 m .59211 .77674 L .57879 .75587 L .644 .736 .915 r

F

.61439 .74902 m .62738 .77006 L .59211 .77674 L F

.57879 .75587 m .59263 .81284 L .59211 .77674 L .988 .722 .416 r

F


.69894 .75653 m .67566 .79247 L .66299 .76333 L .652 .666 .85 r

F

.69894 .75653 m .71136 .78587 L .67566 .79247 L F

.65034 .74211 m .62738 .77006 L .61439 .74902 L .644 .736 .915 r

F

.65034 .74211 m .66299 .76333 L .62738 .77006 L F

.73523 .74966 m .71136 .78587 L .69894 .75653 L .652 .666 .85 r

F

.57879 .75587 m .57924 .79611 L .59263 .81284 L .988 .722 .416 r

F

.68663 .73513 m .66299 .76333 L .65034 .74211 L .644 .736 .915 r

F

.68663 .73513 m .69894 .75653 L .66299 .76333 L F

.56524 .74231 m .57924 .79611 L .57879 .75587 L .988 .722 .416 r

F

.60125 .7353 m .57879 .75587 L .56524 .74231 L .606 .816 .981 r

F

.60125 .7353 m .61439 .74902 L .57879 .75587 L F

.72328 .72808 m .69894 .75653 L .68663 .73513 L .644 .736 .915 r

F

.72328 .72808 m .73523 .74966 L .69894 .75653 L F

.63761 .72823 m .61439 .74902 L .60125 .7353 L .606 .816 .981 r

F

.63761 .72823 m .65034 .74211 L .61439 .74902 L F

.76028 .72096 m .73523 .74966 L .72328 .72808 L .644 .736 .915 r

F

.67433 .72109 m .65034 .74211 L .63761 .72823 L .606 .816 .981 r

F

.67433 .72109 m .68663 .73513 L .65034 .74211 L F

.56524 .74231 m .56551 .77897 L .57924 .79611 L .988 .722 .416 r

F

.58786 .72984 m .56524 .74231 L .55135 .73698 L .452 .855 .968 r

F

.58786 .72984 m .60125 .7353 L .56524 .74231 L F

.55135 .73698 m .56551 .77897 L .56524 .74231 L .988 .722 .416 r

F

.71141 .71387 m .68663 .73513 L .67433 .72109 L .606 .816 .981 r

F

.71141 .71387 m .72328 .72808 L .68663 .73513 L F

.62474 .72262 m .60125 .7353 L .58786 .72984 L .452 .855 .968 r

F

.62474 .72262 m .63761 .72823 L .60125 .7353 L F

.74886 .70659 m .72328 .72808 L .71141 .71387 L .606 .816 .981 r

F

.74886 .70659 m .76028 .72096 L .72328 .72808 L F

.55135 .73698 m .55144 .7614 L .56551 .77897 L .988 .722 .416 r

F

.66198 .71534 m .63761 .72823 L .62474 .72262 L .452 .855 .968 r

F

.66198 .71534 m .67433 .72109 L .63761 .72823 L F

.78669 .69923 m .76028 .72096 L .74886 .70659 L .606 .816 .981 r

F

.6996 .70798 m .67433 .72109 L .66198 .71534 L .452 .855 .968 r

F

.6996 .70798 m .71141 .71387 L .67433 .72109 L F

.53702 .74329 m .55144 .7614 L .55135 .73698 L .988 .722 .416 r

F

.7376 .70055 m .71141 .71387 L .6996 .70798 L .452 .855 .968 r

F

.7376 .70055 m .74886 .70659 L .71141 .71387 L F

.53702 .74329 m .53702 .74338 L .55144 .7614 L .988 .722 .416 r

F

.77598 .69304 m .74886 .70659 L .7376 .70055 L .452 .855 .968 r

F

.77598 .69304 m .78669 .69923 L .74886 .70659 L F

.76566 .69877 m .61847 .84511 L .53702 .74338 L .627 .779 .954 r

F

.65335 .83876 m .68857 .83254 L .68856 .83245 L .604 .393 .568 r

F

.65335 .83876 m .65335 .83885 L .68857 .83254 L F

.67566 .79247 m .68856 .83245 L .65335 .83876 L .65 .602 .788 r

F

.68856 .83245 m .72411 .82616 L .72411 .82607 L .604 .393 .568 r

F

.68856 .83245 m .68857 .83254 L .72411 .82616 L F

.71136 .78587 m .68856 .83245 L .67566 .79247 L .65 .602 .788 r

F

.71136 .78587 m .72411 .82607 L .68856 .83245 L F

.72411 .82607 m .76 .81973 L .75999 .81964 L .604 .393 .568 r

F

.72411 .82607 m .72411 .82616 L .76 .81973 L F

.74739 .7792 m .72411 .82607 L .71136 .78587 L .65 .602 .788 r

F

.74739 .7792 m .75999 .81964 L .72411 .82607 L F

.75999 .81964 m .79623 .81323 L .79622 .81314 L .604 .393 .568 r

F

.75999 .81964 m .76 .81973 L .79623 .81323 L F

.78377 .77247 m .75999 .81964 L .74739 .7792 L .65 .602 .788 r

F

.78377 .77247 m .79622 .81314 L .75999 .81964 L F

.73523 .74966 m .74739 .7792 L .71136 .78587 L .652 .666 .85 r

F

.79622 .81314 m .8328 .80667 L .8328 .80658 L .604 .393 .568 r

F

.79622 .81314 m .79623 .81323 L .8328 .80667 L F

.8205 .76568 m .79622 .81314 L .78377 .77247 L .65 .602 .788 r

F

.8205 .76568 m .8328 .80658 L .79622 .81314 L F

.77188 .74273 m .74739 .7792 L .73523 .74966 L .652 .666 .85 r

F

.77188 .74273 m .78377 .77247 L .74739 .7792 L F

.80889 .73573 m .78377 .77247 L .77188 .74273 L F

.80889 .73573 m .8205 .76568 L .78377 .77247 L F

.76028 .72096 m .77188 .74273 L .73523 .74966 L .644 .736 .915 r

F

.79765 .71377 m .77188 .74273 L .76028 .72096 L F

.79765 .71377 m .80889 .73573 L .77188 .74273 L F

.78669 .69923 m .79765 .71377 L .76028 .72096 L .606 .816 .981 r

F

.76566 .69877 m .8328 .80667 L .61847 .84511 L .627 .779 .954 r

F

.17566 .3857 m .18123 .35805 L .18114 .35807 L .659 .748 .916 r

F

.18114 .35807 m .17566 .3857 L .17254 .41523 L 0 0 .013 r

F

0 g

.17647 .38912 m

.17751 .39352 L

s

.0959 .21365 m

.18105 .31887 L

s

.18105 .31887 m

.22503 .37321 L

s

.2019 .60011 m .22888 .64738 L .19899 .63167 L .881 .631 .555 r

F

.19899 .63167 m .25261 .64222 L .22888 .64738 L .643 .765 .937 r

F

0 g

.22888 .64738 m

.26943 .66037 L

s

.18012 .58196 m .2019 .60011 L .19899 .63167 L .939 .691 .535 r

F

.19899 .63167 m .2353 .62367 L .25261 .64222 L .643 .765 .937 r

F

.17802 .38782 m .17254 .41523 L .16936 .44528 L 0 0 .013 r

F

.18114 .35807 m .17254 .41523 L .17802 .38782 L F

.18012 .58196 m .19899 .63167 L .17699 .61373 L .939 .691 .535 r

F

.17699 .61373 m .2353 .62367 L .19899 .63167 L .643 .765 .937 r

F

0 g

.19899 .63167 m

.22888 .64738 L

s

.18114 .35807 m .17812 .3878 L .17802 .38782 L .572 .341 .527 r

F

.18114 .35807 m .18123 .35805 L .17812 .3878 L F

0 g

.17566 .3857 m

.18114 .35807 L

s

.18123 .35805 m

.28253 .4806 L

s

.18114 .35807 m

.18114 .35807 L

s

.16567 .56158 m .18012 .58196 L .17699 .61373 L .989 .755 .486 r

F

.17485 .41809 m .16936 .44528 L .16613 .47585 L 0 0 .013 r

F

.17802 .38782 m .16936 .44528 L .17485 .41809 L F

0 g

.95131 .84888 m

.97796 .89707 L

s

.78114 .54113 m

.82376 .61822 L

s

.17699 .61373 m .21756 .60465 L .2353 .62367 L .643 .765 .937 r

F

0 g

.0959 .21365 m

.74617 .02894 L

s

.02943 .70308 m

.0959 .21365 L

s

.17802 .38782 m .17494 .41807 L .17485 .41809 L .572 .341 .527 r

F

.17802 .38782 m .17812 .3878 L .17494 .41807 L F

0 g

.17802 .38782 m

.18114 .35807 L

s

.8328 .80658 m .8223 .78979 L .8205 .76568 L .977 .698 .303 r

F

.8328 .80658 m .8328 .80667 L .8223 .78979 L F

0 g

.82376 .61822 m

.95131 .84888 L

s

.61847 .84511 m

.8328 .80667 L

s

.8328 .80658 m

.8328 .80658 L

s

.16567 .56158 m .17699 .61373 L .16237 .59357 L .989 .755 .486 r

F

.16237 .59357 m .21756 .60465 L .17699 .61373 L .643 .765 .937 r

F

0 g

.17699 .61373 m

.19899 .63167 L

s

.17161 .44891 m .16613 .47585 L .16284 .50697 L 0 0 .013 r

F

.17485 .41809 m .16613 .47585 L .17161 .44891 L F

.1595 .53864 m .16567 .56158 L .16237 .59357 L .966 .782 .346 r

F

.8205 .76568 m .81154 .77249 L .80889 .73573 L .977 .698 .303 r

F

.8205 .76568 m .8223 .78979 L .81154 .77249 L F

0 g

.8205 .76568 m

.8328 .80658 L

s

.16237 .59357 m .19939 .58517 L .21756 .60465 L .643 .765 .937 r

F

.17485 .41809 m .17171 .44889 L .17161 .44891 L .572 .341 .527 r

F

.17485 .41809 m .17494 .41807 L .17171 .44889 L F

0 g

.17485 .41809 m

.17802 .38782 L

s

.16832 .48028 m .16284 .50697 L .1595 .53864 L 0 0 .013 r

F

.17161 .44891 m .16284 .50697 L .16832 .48028 L F

.1595 .53864 m .16237 .59357 L .15609 .57088 L .966 .782 .346 r

F

.15609 .57088 m .19939 .58517 L .16237 .59357 L .643 .765 .937 r

F

0 g

.16237 .59357 m

.17699 .61373 L

s

.80889 .73573 m .8005 .75476 L .79765 .71377 L .977 .698 .303 r

F

.80889 .73573 m .81154 .77249 L .8005 .75476 L F

0 g

.80889 .73573 m

.8205 .76568 L

s

.17161 .44891 m .16842 .48026 L .16832 .48028 L .572 .341 .527 r

F

.17161 .44891 m .17171 .44889 L .16842 .48026 L F

0 g

.17161 .44891 m

.17485 .41809 L

s

.16497 .51222 m .1595 .53864 L .15609 .57088 L 0 0 .013 r

F

.16832 .48028 m .1595 .53864 L .16497 .51222 L F

.15609 .57088 m .18076 .5652 L .19939 .58517 L .643 .765 .937 r

F

.16832 .48028 m .16507 .5122 L .16497 .51222 L .572 .341 .527 r

F

.16832 .48028 m .16842 .48026 L .16507 .5122 L F

0 g

.16832 .48028 m

.17161 .44891 L

s

.57416 .73604 m .55135 .73698 L .53702 .74329 L .004 0 0 r

F

0 g

.55741 .73931 m

.55758 .73937 L

s

.57416 .73604 m .58786 .72984 L .55135 .73698 L .004 0 0 r

F

.79765 .71377 m .78919 .73657 L .78669 .69923 L .977 .698 .303 r

F

.79765 .71377 m .8005 .75476 L .78919 .73657 L F

0 g

.79765 .71377 m

.80889 .73573 L

s

.16156 .54475 m .18076 .5652 L .15609 .57088 L .643 .765 .937 r

F

.16497 .51222 m .15609 .57088 L .16156 .54475 L 0 0 .013 r

F

0 g

.15609 .57088 m

.16237 .59357 L

s

.16156 .54475 m .16166 .54472 L .18076 .5652 L .643 .765 .937 r

F

.61169 .72872 m .58786 .72984 L .57416 .73604 L .004 0 0 r

F

.61169 .72872 m .62474 .72262 L .58786 .72984 L F

.16497 .51222 m .16166 .54472 L .16156 .54475 L .572 .341 .527 r

F

0 g

.15609 .57088 m

.16156 .54475 L

s

.16497 .51222 m .16507 .5122 L .16166 .54472 L .572 .341 .527 r

F

0 g

.16497 .51222 m

.16832 .48028 L

s

.16166 .54472 m

.18123 .35805 L

s

.16166 .54472 m

.26952 .66035 L

s

.16156 .54475 m

.16497 .51222 L

s

.64959 .72132 m .62474 .72262 L .61169 .72872 L .004 0 0 r

F

.64959 .72132 m .66198 .71534 L .62474 .72262 L F

.78669 .69923 m .77758 .71791 L .77598 .69304 L .977 .698 .303 r

F

.78669 .69923 m .78919 .73657 L .77758 .71791 L F

0 g

.78669 .69923 m

.79765 .71377 L

s

.68788 .71385 m .66198 .71534 L .64959 .72132 L .004 0 0 r

F

.68788 .71385 m .6996 .70798 L .66198 .71534 L F

.57416 .73604 m .53702 .74338 L .53702 .74329 L .59 .37 .55 r

F

0 g

.53702 .74329 m

.55135 .73698 L

s

.57416 .73604 m .57417 .73613 L .53702 .74338 L .59 .37 .55 r

F

0 g

.53702 .74338 m

.61847 .84511 L

s

.72657 .7063 m .6996 .70798 L .68788 .71385 L .004 0 0 r

F

.72657 .7063 m .7376 .70055 L .6996 .70798 L F

.61169 .72872 m .57417 .73613 L .57416 .73604 L .59 .37 .55 r

F

0 g

.53702 .74329 m

.57416 .73604 L

s

.61169 .72872 m .61169 .72881 L .57417 .73613 L .59 .37 .55 r

F

.76566 .69867 m .7376 .70055 L .72657 .7063 L .004 0 0 r

F

.76566 .69867 m .77598 .69304 L .7376 .70055 L F

.64959 .72132 m .61169 .72881 L .61169 .72872 L .59 .37 .55 r

F

0 g

.57416 .73604 m

.61169 .72872 L

s

.64959 .72132 m .64959 .72142 L .61169 .72881 L .59 .37 .55 r

F

.77598 .69304 m .76566 .69877 L .76566 .69867 L .977 .698 .303 r

F

.77598 .69304 m .77758 .71791 L .76566 .69877 L F

0 g

.77598 .69304 m

.78669 .69923 L

s

.68788 .71385 m .64959 .72142 L .64959 .72132 L .59 .37 .55 r

F

0 g

.61169 .72872 m

.64959 .72132 L

s

.68788 .71385 m .68789 .71394 L .64959 .72142 L .59 .37 .55 r

F

.72657 .7063 m .68789 .71394 L .68788 .71385 L F

0 g

.64959 .72132 m

.68788 .71385 L

s

.72657 .7063 m .72658 .70639 L .68789 .71394 L .59 .37 .55 r

F

.76566 .69867 m .72658 .70639 L .72657 .7063 L F

0 g

.68788 .71385 m

.72657 .7063 L

s

.76566 .69867 m .76566 .69877 L .72658 .70639 L .59 .37 .55 r

F

0 g

.72657 .7063 m

.76566 .69867 L

s

.76566 .69867 m

.77598 .69304 L

s

.53702 .74338 m

.76566 .69877 L

s

.76566 .69877 m

.8328 .80667 L

s

.76566 .69867 m

.76566 .69867 L

s

.78114 .54113 m

.74617 .02894 L

s

.78114 .54113 m

.02943 .70308 L

s

.25 Mabswid

.07384 .19656 m

.75767 0 L

s

.08869 .19229 m

.09304 .1977 L

s

[(0)] .07999 .18147 .80421 1 Mshowa

.29291 .13359 m

.29682 .13933 L

s

[(50)] .28509 .12212 .68138 1 Mshowa

.50956 .07132 m

.51295 .07738 L

s

[(100)] .50279 .05919 .55854 1 Mshowa

.73981 .00513 m

.74259 .0115 L

s

[(150)] .73427 -0.0076 .4357 1 Mshowa

.125 Mabswid

.12859 .18082 m

.13115 .18411 L

s

.16896 .16922 m

.17147 .17255 L

s

.20979 .15748 m

.21225 .16085 L

s

.25111 .14561 m

.25351 .14901 L

s

.33521 .12143 m

.3375 .12491 L

s

.37802 .10913 m

.38025 .11265 L

s

.42134 .09667 m

.4235 .10023 L

s

.46519 .08407 m

.46728 .08767 L

s

.55449 .0584 m

.55645 .06208 L

s

.59996 .04533 m

.60185 .04904 L

s

.646 .0321 m

.64782 .03585 L

s

.69261 .0187 m

.69436 .02248 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
 ImageSize->{380.25, 387.312},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->{
  "Angular Orientation", "PR2.3", 
   "PR2.3.1"},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 379.25}, {386.312, 0}} -> {-0.0502246, \
-0.0509519, 0.00553843, 0.00553843}, {{9.0625, 181}, {377.062, 201.875}} -> \
{-0.0909214, -0.102531, 0.00581673, 0.00581673}, {{198.188, 370.125}, \
{377.062, 201.875}} -> {-1.19101, -0.102531, 0.00581673, 0.00581673}, \
{{9.0625, 181}, {184.375, 9.1875}} -> {-0.0909214, -1.22334, 0.00581673, \
0.00581673}, {{198.188, 370.125}, {184.375, 9.1875}} -> {-1.19101, -1.22334, \
0.00581673, 0.00581673}}],

Cell[TextData[{
 "How the tilt vector and twist angle work in three dimensions.  Plot labels  \
show what input to ",
 StyleBox["Move", "MB"],
 " generated the graphic."
}], "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[{
 "In all four cases, the second lens sits at position ",
 StyleBox["{100,50,50}", "MB"],
 ".  The graphic at top-left shows simple translation to this position.   \
There is no tilt vector, so there is no change in orientation.  At the  \
top-right, the extra tilt vector parameter causes orientation to align in its \
 direction.  The lower two graphics show how twist angles work.  At the  \
bottom-left, the tilt vector points in the opposite direction, and the lens  \
twists about the line of its direction vector by 45 degrees.  The tilt  \
vectors are different in all four cases.  At the bottom-right, a completely  \
general tilt vector shows the flexibility of this type of input."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[{
 "In two dimensions, you will less often use a direction vector although you  \
still can, using zero for its ",
 StyleBox["z",
  FontSlant->"Italic"],
 " component.  The reason is that two-dimensional attitude finds simpler  \
expression as a rotation in the plane.  Therefore, ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " lets you input a ",
 StyleBox["rotation angle",
  FontSlant->"Italic"],
 " to express rotation about the ",
 StyleBox["z",
  FontSlant->"Italic"],
 "-axis.  This angle is distinguished from the twist angle, which is about  \
the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-axis (the optic axis).  The following visualization demonstrates how  \
these parameters work."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .93555 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.0222751 0.47619 [

[ 0 0 0 0 ]

[ 1 .93555 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .93555 L

0 .93555 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.0222751 0.477324 0.446563 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

1.63888e-16 1.07296 -0.0200146 1.07296 [

[.5 .94805 -60 0 ]

[.5 .94805 60 7.2 ]

[.06656 .18332 -4.38263 -7.2 ]

[.06656 .18332 .41737 0 ]

[.27748 .1236 -8.15353 -7.2 ]

[.27748 .1236 1.44647 0 ]

[.50155 .06024 -11.3127 -7.2 ]

[.50155 .06024 3.08728 0 ]

[.74001 -0.00708 -10.3951 -7.2 ]

[.74001 -0.00708 4.00487 0 ]

[.78244 .00944 0 -4.60542 ]

[.78244 .00944 14.4 2.59458 ]

[.852 .16975 0 -4.52236 ]

[.852 .16975 4.8 2.67764 ]

[.91193 .30788 0 -4.45197 ]

[.91193 .30788 9.6 2.74803 ]

[.9641 .42813 0 -4.39157 ]

[.9641 .42813 14.4 2.80843 ]

[.04565 .21043 -14.4 -2.59212 ]

[.04565 .21043 0 4.60788 ]

[.03254 .30147 -14.4 -2.63724 ]

[.03254 .30147 0 4.56276 ]

[.01869 .39763 -4.8 -2.68508 ]

[.01869 .39763 0 4.51492 ]

[.00404 .49935 -9.6 -2.7359 ]

[.00404 .49935 0 4.4641 ]

[-0.01149 .60714 -9.6 -2.78998 ]

[-0.01149 .60714 0 4.41002 ]

[ 0 0 0 0 ]

[ 1 .93555 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Move[object, {100,50},45])] .5 .94805 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

.25 Mabswid

.76386 0 m

.95464 .43939 L

s

.76952 .01305 m

.76306 .01485 L

s

[(-50)] .78244 .00944 -1 .27928 Mshowa

.83901 .17308 m

.83251 .17475 L

s

[(0)] .852 .16975 -1 .25621 Mshowa

.89888 .31097 m

.89236 .31251 L

s

[(50)] .91193 .30788 -1 .23666 Mshowa

.95101 .43101 m

.94446 .43245 L

s

[(100)] .9641 .42813 -1 .21988 Mshowa

.125 Mabswid

.7843 .04708 m

.78042 .04814 L

s

.79861 .08005 m

.79473 .0811 L

s

.81249 .11201 m

.8086 .11304 L

s

.82595 .14301 m

.82206 .14402 L

s

.85169 .20228 m

.84778 .20326 L

s

.864 .23063 m

.86009 .23159 L

s

.87596 .25817 m

.87205 .25912 L

s

.88758 .28494 m

.88367 .28588 L

s

.90988 .33629 m

.90596 .3372 L

s

.92057 .36093 m

.91665 .36183 L

s

.93099 .38491 m

.92706 .3858 L

s

.94113 .40826 m

.9372 .40914 L

s

.25 Mabswid

.05984 .19796 m

0 .61535 L

s

.05857 .20681 m

.06503 .205 L

s

[(-50)] .04565 .21043 1 -0.27997 Mshowa

.04549 .298 m

.05197 .29627 L

s

[(-25)] .03254 .30147 1 -0.26743 Mshowa

.03169 .39433 m

.03818 .39267 L

s

[(0)] .01869 .39763 1 -0.25414 Mshowa

.01708 .49622 m

.0236 .49466 L

s

[(25)] .00404 .49935 1 -0.24003 Mshowa

.0016 .6042 m

.00814 .60272 L

s

[(50)] -0.01149 .60714 1 -0.22501 Mshowa

.125 Mabswid

.05601 .22466 m

.05989 .22358 L

s

.05342 .2427 m

.0573 .24163 L

s

.05081 .26093 m

.05469 .25988 L

s

.04817 .27937 m

.05205 .27832 L

s

.04279 .31684 m

.04668 .31581 L

s

.04006 .33589 m

.04395 .33487 L

s

.0373 .35515 m

.0412 .35414 L

s

.03451 .37463 m

.03841 .37363 L

s

.02883 .41424 m

.03273 .41326 L

s

.02594 .43439 m

.02985 .43342 L

s

.02302 .45477 m

.02693 .45381 L

s

.02007 .47538 m

.02398 .47443 L

s

.01405 .51732 m

.01797 .51639 L

s

.01099 .53865 m

.01491 .53774 L

s

.0079 .56024 m

.01182 .55934 L

s

.00477 .58209 m

.00869 .58119 L

s

0 0 m

1 0 L

1 .93555 L

0 .93555 L

closepath

clip

newpath

.5 Mabswid

.93683 .44267 m

.37533 .56553 L

s

.35997 .9174 m

.37533 .56553 L

s

.93683 .44267 m

.97822 .81165 L

s

.35997 .9174 m

.97822 .81165 L

s

.67004 .52544 m .67013 .52546 L .68575 .50735 L .655 .752 .921 r

F

.76929 .41045 m .67013 .52546 L .67688 .7098 L .203 .09 .494 r

F

0 g

.75184 .0273 m

.84084 .22714 L

s

.84084 .22714 m

.93683 .44267 L

s

.67112 .55492 m .67013 .52546 L .67004 .52544 L .788 .538 .559 r

F

.67112 .55492 m .67121 .55494 L .67013 .52546 L F

.67004 .52544 m .68575 .50735 L .66289 .50166 L .655 .752 .921 r

F

.66289 .50166 m .67004 .52544 L .67112 .55492 L .93 .697 .213 r

F

0 g

.67004 .52544 m

.67004 .52544 L

s

.67222 .58489 m .67121 .55494 L .67112 .55492 L .788 .538 .559 r

F

.67222 .58489 m .67231 .58491 L .67121 .55494 L F

.66393 .53138 m .67112 .55492 L .67222 .58489 L .93 .697 .213 r

F

.66289 .50166 m .67112 .55492 L .66393 .53138 L F

0 g

.67004 .52544 m

.67112 .55492 L

s

.66289 .50166 m .68575 .50735 L .70171 .48883 L .655 .752 .921 r

F

.66289 .50166 m .70171 .48883 L .66665 .47999 L F

.66665 .47999 m .66289 .50166 L .66393 .53138 L 0 0 .214 r

F

0 g

.66511 .50904 m

.67004 .52544 L

s

.67333 .61534 m .67231 .58491 L .67222 .58489 L .788 .538 .559 r

F

.67333 .61534 m .67342 .61536 L .67231 .58491 L F

.66498 .5616 m .67222 .58489 L .67333 .61534 L .93 .697 .213 r

F

.66393 .53138 m .67222 .58489 L .66498 .5616 L F

0 g

.67112 .55492 m

.67222 .58489 L

s

.66665 .47999 m .70171 .48883 L .71803 .4699 L .655 .752 .921 r

F

.66773 .50993 m .66393 .53138 L .66498 .5616 L 0 0 .214 r

F

.66665 .47999 m .66393 .53138 L .66773 .50993 L F

.67446 .6463 m .67342 .61536 L .67333 .61534 L .788 .538 .559 r

F

.67446 .6463 m .67455 .64632 L .67342 .61536 L F

.66605 .59231 m .67333 .61534 L .67446 .6463 L .93 .697 .213 r

F

.66498 .5616 m .67333 .61534 L .66605 .59231 L F

0 g

.67222 .58489 m

.67333 .61534 L

s

.23539 .47063 m .27493 .48446 L .27276 .51435 L .822 .574 .564 r

F

0 g

.21598 .37365 m

.37533 .56553 L

s

.27493 .48446 m .25862 .46514 L .23539 .47063 L .655 .752 .921 r

F

.27493 .48446 m .27502 .48444 L .25862 .46514 L F

.27276 .51435 m .27502 .48444 L .27493 .48446 L .59 .37 .55 r

F

0 g

.27493 .48446 m

.27493 .48446 L

s

.27276 .51435 m .27285 .51433 L .27502 .48444 L .59 .37 .55 r

F

.23539 .47063 m .24183 .4454 L .2063 .45391 L .655 .752 .921 r

F

.23539 .47063 m .25862 .46514 L .24183 .4454 L F

.23539 .47063 m .27276 .51435 L .23287 .50065 L .822 .574 .564 r

F

.2063 .45391 m .23539 .47063 L .23287 .50065 L .881 .631 .555 r

F

.23287 .50065 m .27276 .51435 L .27056 .54473 L .822 .574 .564 r

F

.27056 .54473 m .27285 .51433 L .27276 .51435 L .59 .37 .55 r

F

.27056 .54473 m .27065 .54471 L .27285 .51433 L F

.23287 .50065 m .27056 .54473 L .23032 .53118 L .822 .574 .564 r

F

.20352 .48409 m .23287 .50065 L .23032 .53118 L .881 .631 .555 r

F

.2063 .45391 m .23287 .50065 L .20352 .48409 L F

.23032 .53118 m .27056 .54473 L .26832 .57563 L .822 .574 .564 r

F

.26832 .57563 m .27065 .54471 L .27056 .54473 L .59 .37 .55 r

F

.26832 .57563 m .26842 .57561 L .27065 .54471 L F

.2063 .45391 m .22466 .4252 L .18497 .43484 L .655 .752 .921 r

F

.2063 .45391 m .24183 .4454 L .22466 .4252 L F

.18497 .43484 m .2063 .45391 L .20352 .48409 L .939 .691 .535 r

F

.23032 .53118 m .26832 .57563 L .22772 .56222 L .822 .574 .564 r

F

.20069 .51478 m .23032 .53118 L .22772 .56222 L .881 .631 .555 r

F

.20352 .48409 m .23032 .53118 L .20069 .51478 L F

.22772 .56222 m .26832 .57563 L .26605 .60705 L .822 .574 .564 r

F

.26605 .60705 m .26842 .57561 L .26832 .57563 L .59 .37 .55 r

F

.26605 .60705 m .26614 .60703 L .26842 .57561 L F

.18497 .43484 m .20707 .40451 L .17088 .41343 L .655 .752 .921 r

F

.18497 .43484 m .22466 .4252 L .20707 .40451 L F

.22772 .56222 m .26605 .60705 L .22508 .5938 L .822 .574 .564 r

F

.22508 .5938 m .26605 .60705 L .26373 .63901 L F

.26373 .63901 m .26614 .60703 L .26605 .60705 L .59 .37 .55 r

F

.26373 .63901 m .26383 .63899 L .26614 .60703 L F

.17088 .41343 m .18906 .38332 L .16495 .38935 L .655 .752 .921 r

F

.17088 .41343 m .20707 .40451 L .18906 .38332 L F

.22508 .5938 m .26373 .63901 L .22239 .62592 L .822 .574 .564 r

F

.22239 .62592 m .26373 .63901 L .26138 .67153 L F

.26138 .67153 m .26383 .63899 L .26373 .63901 L .59 .37 .55 r

F

.26138 .67153 m .26147 .67151 L .26383 .63899 L F

.16495 .38935 m .18906 .38332 L .17062 .36162 L .655 .752 .921 r

F

.17062 .36162 m .27502 .48444 L .26147 .67151 L .97 .724 .507 r

F

0 g

.18138 .75155 m

.35997 .9174 L

s

.66665 .47999 m .71803 .4699 L .67884 .45988 L .655 .752 .921 r

F

.67884 .45988 m .66665 .47999 L .66773 .50993 L .038 0 .435 r

F

0 g

.66289 .50166 m

.66665 .47999 L

s

.66882 .54036 m .66498 .5616 L .66605 .59231 L 0 0 .214 r

F

.66773 .50993 m .66498 .5616 L .66882 .54036 L F

.67561 .67778 m .67455 .64632 L .67446 .6463 L .788 .538 .559 r

F

.67561 .67778 m .67571 .6778 L .67455 .64632 L F

.66714 .62354 m .67446 .6463 L .67561 .67778 L .93 .697 .213 r

F

.66605 .59231 m .67446 .6463 L .66714 .62354 L F

0 g

.67333 .61534 m

.67446 .6463 L

s

.67884 .45988 m .71803 .4699 L .73473 .45054 L .655 .752 .921 r

F

.68003 .49001 m .66773 .50993 L .66882 .54036 L .038 0 .435 r

F

.67884 .45988 m .66773 .50993 L .68003 .49001 L F

.66994 .5713 m .66605 .59231 L .66714 .62354 L 0 0 .214 r

F

.66882 .54036 m .66605 .59231 L .66994 .5713 L F

.67884 .45988 m .73473 .45054 L .69904 .44129 L .655 .752 .921 r

F

.69904 .44129 m .67884 .45988 L .68003 .49001 L .29 .15 .511 r

F

0 g

.66665 .47999 m

.67884 .45988 L

s

.67679 .70978 m .67571 .6778 L .67561 .67778 L .788 .538 .559 r

F

.67679 .70978 m .67688 .7098 L .67571 .6778 L F

.66824 .6553 m .67561 .67778 L .67679 .70978 L .93 .697 .213 r

F

.66714 .62354 m .67561 .67778 L .66824 .6553 L F

0 g

.67446 .6463 m

.67561 .67778 L

s

.68125 .52064 m .66882 .54036 L .66994 .5713 L .038 0 .435 r

F

0 g

.67041 .53321 m

.67057 .53758 L

s

.68003 .49001 m .66882 .54036 L .68125 .52064 L .038 0 .435 r

F

.69904 .44129 m .73473 .45054 L .75181 .43072 L .655 .752 .921 r

F

.66994 .5713 m .66714 .62354 L .67108 .60277 L 0 0 .214 r

F

.67108 .60277 m .66714 .62354 L .66824 .6553 L F

.70042 .47158 m .68003 .49001 L .68125 .52064 L .29 .15 .511 r

F

.69904 .44129 m .68003 .49001 L .70042 .47158 L F

.66824 .6553 m .67679 .70978 L .66937 .6876 L .93 .697 .213 r

F

.66937 .6876 m .67688 .7098 L .67679 .70978 L .638 .77 .943 r

F

0 g

.67561 .67778 m

.67677 .7095 L

s

.76929 .41045 m .67688 .7098 L .78191 .60218 L .203 .09 .494 r

F

.66937 .6876 m .69337 .69291 L .67688 .7098 L .638 .77 .943 r

F

0 g

.67155 .56411 m

.67612 .68909 L

s

.67679 .70978 m

.67679 .70978 L

s

.69904 .44129 m .75181 .43072 L .72813 .4245 L .655 .752 .921 r

F

.72813 .4245 m .69904 .44129 L .70042 .47158 L .437 .26 .541 r

F

0 g

.67884 .45988 m

.69904 .44129 L

s

.18198 .46519 m .20352 .48409 L .20069 .51478 L .939 .691 .535 r

F

.18497 .43484 m .20352 .48409 L .18198 .46519 L F

.68249 .55179 m .66994 .5713 L .67108 .60277 L .038 0 .435 r

F

.68125 .52064 m .66994 .5713 L .68249 .55179 L F

.17088 .41343 m .18497 .43484 L .18198 .46519 L .989 .755 .486 r

F

0 g

.18497 .43484 m

.19461 .44346 L

s

.67223 .63479 m .66824 .6553 L .66937 .6876 L 0 0 .214 r

F

.67108 .60277 m .66824 .6553 L .67223 .63479 L F

.70182 .5024 m .68125 .52064 L .68249 .55179 L .29 .15 .511 r

F

.70042 .47158 m .68125 .52064 L .70182 .5024 L F

.72813 .4245 m .75181 .43072 L .76929 .41045 L .655 .752 .921 r


F

.19781 .546 m .22772 .56222 L .22508 .5938 L .881 .631 .555 r

F

.20069 .51478 m .22772 .56222 L .19781 .546 L F

.72978 .45495 m .70042 .47158 L .70182 .5024 L .437 .26 .541 r

F

.72813 .4245 m .70042 .47158 L .72978 .45495 L F

.17893 .49607 m .20069 .51478 L .19781 .546 L .939 .691 .535 r

F

.18198 .46519 m .20069 .51478 L .17893 .49607 L F

.72813 .4245 m .76929 .41045 L .7692 .41042 L .655 .752 .921 r

F

.7692 .41042 m .72813 .4245 L .72978 .45495 L .543 .339 .554 r

F

0 g

.69904 .44129 m

.72813 .4245 L

s

.67341 .66735 m .69337 .69291 L .66937 .6876 L .638 .77 .943 r

F

.67341 .66735 m .71024 .67562 L .69337 .69291 L F

.68249 .55179 m .67108 .60277 L .68375 .58349 L .038 0 .435 r

F

.68375 .58349 m .67108 .60277 L .67223 .63479 L F

.16772 .44398 m .18198 .46519 L .17893 .49607 L .989 .755 .486 r

F

.17088 .41343 m .18198 .46519 L .16772 .44398 L F

.67223 .63479 m .66937 .6876 L .67341 .66735 L 0 0 .214 r

F

0 g

.66937 .6876 m

.67679 .70978 L

s

.70325 .53374 m .68249 .55179 L .68375 .58349 L .29 .15 .511 r

F

.70182 .5024 m .68249 .55179 L .70325 .53374 L F

.16495 .38935 m .17088 .41343 L .16772 .44398 L .966 .782 .346 r

F

0 g

.17088 .41343 m

.18497 .43484 L

s

.19781 .546 m .22508 .5938 L .19489 .57776 L .881 .631 .555 r

F

.19489 .57776 m .22508 .5938 L .22239 .62592 L F

.73145 .48592 m .70182 .5024 L .70325 .53374 L .437 .26 .541 r

F

.72978 .45495 m .70182 .5024 L .73145 .48592 L F

.7692 .41042 m .76929 .41045 L .7713 .44102 L .795 .531 .538 r

F

0 g

.72984 .4562 m

.76921 .41054 L

s

.7692 .41042 m .7713 .44102 L .77121 .441 L .795 .531 .538 r

F

.7692 .41042 m .72978 .45495 L .77121 .441 L .543 .339 .554 r

F

0 g

.7692 .41042 m

.7692 .41042 L

s

.72813 .4245 m

.7692 .41042 L

s

.17583 .52748 m .19781 .546 L .19489 .57776 L .939 .691 .535 r

F

.17893 .49607 m .19781 .546 L .17583 .52748 L F

.77121 .441 m .72978 .45495 L .73145 .48592 L .543 .339 .554 r

F

.68502 .61573 m .67223 .63479 L .67341 .66735 L .038 0 .435 r

F

.68375 .58349 m .67223 .63479 L .68502 .61573 L F

.16451 .47506 m .17893 .49607 L .17583 .52748 L .989 .755 .486 r

F

.16772 .44398 m .17893 .49607 L .16451 .47506 L F

.68633 .64854 m .71024 .67562 L .67341 .66735 L .638 .77 .943 r

F

.68633 .64854 m .72752 .65791 L .71024 .67562 L F

0 g

.8767 .62231 m

.97822 .81165 L

s

.70325 .53374 m .68375 .58349 L .7047 .56563 L .29 .15 .511 r

F

.7047 .56563 m .68375 .58349 L .68502 .61573 L F

.1617 .42011 m .16772 .44398 L .16451 .47506 L .966 .782 .346 r

F

.16495 .38935 m .16772 .44398 L .1617 .42011 L F

.22239 .62592 m .26138 .67153 L .21965 .6586 L .822 .574 .564 r

F

.19191 .61007 m .22239 .62592 L .21965 .6586 L .881 .631 .555 r

F

.19489 .57776 m .22239 .62592 L .19191 .61007 L F

.21965 .6586 m .26147 .67151 L .26138 .67153 L .638 .77 .943 r

F

0 g

.26138 .67153 m

.26138 .67153 L

s

.26138 .67148 m

.2614 .67126 L

s

.17583 .52748 m .19489 .57776 L .17267 .55944 L .939 .691 .535 r

F

.17267 .55944 m .19489 .57776 L .19191 .61007 L F

.16125 .50668 m .17583 .52748 L .17267 .55944 L .989 .755 .486 r

F

.16451 .47506 m .17583 .52748 L .16125 .50668 L F

.1584 .45142 m .16451 .47506 L .16125 .50668 L .966 .782 .346 r

F

.1617 .42011 m .16451 .47506 L .1584 .45142 L F

.17267 .55944 m .19191 .61007 L .16946 .59197 L .939 .691 .535 r

F

.16125 .50668 m .17267 .55944 L .15792 .53887 L .989 .755 .486 r

F

.15792 .53887 m .17267 .55944 L .16946 .59197 L F

.15503 .48328 m .16125 .50668 L .15792 .53887 L .966 .782 .346 r

F

.1584 .45142 m .16125 .50668 L .15503 .48328 L F

.15792 .53887 m .16946 .59197 L .15454 .57163 L .989 .755 .486 r

F

.15503 .48328 m .15792 .53887 L .1516 .51571 L .966 .782 .346 r

F

.1516 .51571 m .15792 .53887 L .15454 .57163 L F

.14811 .54873 m .15454 .57163 L .1511 .60498 L F

.1516 .51571 m .15454 .57163 L .14811 .54873 L F

.17062 .36162 m .26147 .67151 L .1502 .55627 L .97 .724 .507 r

F

.21965 .6586 m .24405 .65346 L .26147 .67151 L .638 .77 .943 r

F

0 g

.26147 .67151 m

.27502 .48444 L

s

.73315 .51744 m .70325 .53374 L .7047 .56563 L .437 .26 .541 r

F

.73145 .48592 m .70325 .53374 L .73315 .51744 L F

.77121 .441 m .7713 .44102 L .77335 .47213 L .795 .531 .538 r

F

.77121 .441 m .77335 .47213 L .77326 .47211 L F

.77121 .441 m .73145 .48592 L .77326 .47211 L .543 .339 .554 r

F

0 g

.7692 .41042 m

.77121 .441 L

s

.77326 .47211 m .73145 .48592 L .73315 .51744 L .543 .339 .554 r

F

.68502 .61573 m .67341 .66735 L .68633 .64854 L .038 0 .435 r

F

0 g

.66937 .6876 m

.67341 .66735 L

s

.16495 .38935 m .17062 .36162 L .17052 .36165 L .655 .752 .921 r

F

.17052 .36165 m .16495 .38935 L .1617 .42011 L 0 0 .013 r

F

0 g

.16582 .39285 m

.16689 .3972 L

s

.08284 .21333 m

.17066 .31908 L

s

.17066 .31908 m

.21598 .37365 L

s

.70618 .59809 m .68502 .61573 L .68633 .64854 L .29 .15 .511 r

F

.7047 .56563 m .68502 .61573 L .70618 .59809 L F

.19191 .61007 m .21965 .6586 L .18887 .64295 L .881 .631 .555 r

F

.18887 .64295 m .24405 .65346 L .21965 .6586 L .638 .77 .943 r

F

0 g

.21965 .6586 m

.26138 .67153 L

s

.70769 .63112 m .72752 .65791 L .68633 .64854 L .638 .77 .943 r

F

.70769 .63112 m .74522 .63978 L .72752 .65791 L F

.73315 .51744 m .7047 .56563 L .73488 .54951 L .437 .26 .541 r

F

.73488 .54951 m .7047 .56563 L .70618 .59809 L F

.77326 .47211 m .77335 .47213 L .77544 .50379 L .795 .531 .538 r

F

.77326 .47211 m .77544 .50379 L .77534 .50376 L F

.77326 .47211 m .73315 .51744 L .77534 .50376 L .543 .339 .554 r

F

0 g

.77121 .441 m

.77326 .47211 L

s

.16946 .59197 m .19191 .61007 L .18887 .64295 L .939 .691 .535 r

F

0 g

.15604 .72802 m

.18138 .75155 L

s

.77534 .50376 m .73315 .51744 L .73488 .54951 L .543 .339 .554 r

F

.18887 .64295 m .2262 .63497 L .24405 .65346 L .638 .77 .943 r

F

.16727 .39265 m .1617 .42011 L .1584 .45142 L 0 0 .013 r

F

.17052 .36165 m .1617 .42011 L .16727 .39265 L F

.70618 .59809 m .68633 .64854 L .70769 .63112 L .29 .15 .511 r

F

0 g

.67341 .66735 m

.68633 .64854 L

s

.73664 .58215 m .70618 .59809 L .70769 .63112 L .437 .26 .541 r

F

.73488 .54951 m .70618 .59809 L .73664 .58215 L F

.77534 .50376 m .77544 .50379 L .77756 .536 L .795 .531 .538 r

F

.77534 .50376 m .77756 .536 L .77746 .53598 L F

.77534 .50376 m .73488 .54951 L .77746 .53598 L .543 .339 .554 r

F

0 g

.77326 .47211 m

.77534 .50376 L

s

.16946 .59197 m .18887 .64295 L .1662 .62507 L .939 .691 .535 r

F

.1662 .62507 m .2262 .63497 L .18887 .64295 L .638 .77 .943 r

F

0 g

.18887 .64295 m

.21965 .6586 L

s

.77746 .53598 m .73488 .54951 L .73664 .58215 L .543 .339 .554 r

F

.17052 .36165 m .16737 .39262 L .16727 .39265 L .572 .341 .527 r

F

.17052 .36165 m .17062 .36162 L .16737 .39262 L F

0 g

.16495 .38935 m

.17052 .36165 L

s

.17062 .36162 m

.27502 .48444 L

s

.17052 .36165 m

.17052 .36165 L

s

.73843 .61537 m .74522 .63978 L .70769 .63112 L .638 .77 .943 r

F

.73843 .61537 m .76334 .62121 L .74522 .63978 L F

.15454 .57163 m .16946 .59197 L .1662 .62507 L .989 .755 .486 r

F

.16396 .4242 m .1584 .45142 L .15503 .48328 L 0 0 .013 r

F

.16727 .39265 m .1584 .45142 L .16396 .4242 L F

.1662 .62507 m .2079 .61603 L .2262 .63497 L .638 .77 .943 r

F

0 g

.08284 .21333 m

.75184 .0273 L

s

.02897 .61001 m

.08284 .21333 L

s

.73664 .58215 m .70769 .63112 L .73843 .61537 L .437 .26 .541 r

F

0 g

.68633 .64854 m

.70769 .63112 L

s

.77746 .53598 m .77756 .536 L .77971 .5688 L .795 .531 .538 r

F

.77746 .53598 m .77971 .5688 L .77962 .56877 L F

.77746 .53598 m .73664 .58215 L .77962 .56877 L .543 .339 .554 r

F

0 g

.77534 .50376 m

.77746 .53598 L

s

.77962 .56877 m .73664 .58215 L .73843 .61537 L .543 .339 .554 r

F

.16727 .39265 m .16406 .42418 L .16396 .4242 L .572 .341 .527 r

F

.16727 .39265 m .16737 .39262 L .16406 .42418 L F

0 g

.16727 .39265 m

.17052 .36165 L

s

.15454 .57163 m .1662 .62507 L .1511 .60498 L .989 .755 .486 r

F

.1511 .60498 m .2079 .61603 L .1662 .62507 L .638 .77 .943 r

F

0 g

.1662 .62507 m

.18887 .64295 L

s

.16059 .45633 m .15503 .48328 L .1516 .51571 L 0 0 .013 r

F

.16396 .4242 m .15503 .48328 L .16059 .45633 L F

.78182 .60216 m .76334 .62121 L .73843 .61537 L .638 .77 .943 r

F

.78182 .60216 m .78191 .60218 L .76334 .62121 L F

.77962 .56877 m .77971 .5688 L .78191 .60218 L .795 .531 .538 r

F

.77962 .56877 m .78191 .60218 L .78182 .60216 L F

.77962 .56877 m .73843 .61537 L .78182 .60216 L .543 .339 .554 r

F

0 g

.77962 .56877 m

.78182 .60216 L

s

.67688 .7098 m

.78191 .60218 L

s

.76929 .41045 m

.78191 .60218 L

s

.78017 .44227 m

.8767 .62231 L

s

.77746 .53598 m

.77962 .56877 L

s

.70769 .63112 m

.73843 .61537 L

s

.1511 .60498 m .18915 .59661 L .2079 .61603 L .638 .77 .943 r

F

0 g

.02897 .61001 m

.15604 .72802 L

s

.73843 .61537 m

.78182 .60216 L

s

.16396 .4242 m .16069 .4563 L .16059 .45633 L .572 .341 .527 r

F

.16396 .4242 m .16406 .42418 L .16069 .4563 L F

0 g

.16396 .4242 m

.16727 .39265 L

s

.15716 .48904 m .1516 .51571 L .14811 .54873 L 0 0 .013 r

F

.16059 .45633 m .1516 .51571 L .15716 .48904 L F

.14811 .54873 m .1511 .60498 L .14456 .58236 L .966 .782 .346 r

F

.14456 .58236 m .18915 .59661 L .1511 .60498 L .638 .77 .943 r

F

0 g

.1511 .60498 m

.1662 .62507 L

s

.16059 .45633 m .15726 .48902 L .15716 .48904 L .572 .341 .527 r

F

.16059 .45633 m .16069 .4563 L .15726 .48902 L F

0 g

.16059 .45633 m

.16396 .4242 L

s

.15366 .52235 m .14811 .54873 L .14456 .58236 L 0 0 .013 r

F

.15716 .48904 m .14811 .54873 L .15366 .52235 L F

.14456 .58236 m .16992 .57669 L .18915 .59661 L .638 .77 .943 r

F

.15716 .48904 m .15376 .52233 L .15366 .52235 L .572 .341 .527 r

F

.15716 .48904 m .15726 .48902 L .15376 .52233 L F

0 g

.15716 .48904 m

.16059 .45633 L

s

.1501 .55629 m .16992 .57669 L .14456 .58236 L .638 .77 .943 r

F

.15366 .52235 m .14456 .58236 L .1501 .55629 L 0 0 .013 r

F

0 g

.14456 .58236 m

.1511 .60498 L

s

.1501 .55629 m .1502 .55627 L .16992 .57669 L .638 .77 .943 r

F

.15366 .52235 m .1502 .55627 L .1501 .55629 L .572 .341 .527 r

F

0 g

.14456 .58236 m

.1501 .55629 L

s

.15366 .52235 m .15376 .52233 L .1502 .55627 L .572 .341 .527 r

F

0 g

.15366 .52235 m

.15716 .48904 L

s

.1502 .55627 m

.17062 .36162 L

s

.1502 .55627 m

.26147 .67151 L

s

.1501 .55629 m

.15366 .52235 L

s

.78017 .44227 m

.75184 .0273 L

s

.78017 .44227 m

.02897 .61001 L

s

.25 Mabswid

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.0222751 0.97619 0.446563 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

1.63888e-16 1.07296 -0.0200146 1.07296 [

[.5 .94805 -67.2 0 ]

[.5 .94805 67.2 7.2 ]

[.06656 .18332 -4.38263 -7.2 ]

[.06656 .18332 .41737 0 ]

[.27748 .1236 -8.15353 -7.2 ]

[.27748 .1236 1.44647 0 ]

[.50155 .06024 -11.3127 -7.2 ]

[.50155 .06024 3.08728 0 ]

[.74001 -0.00708 -10.3951 -7.2 ]

[.74001 -0.00708 4.00487 0 ]

[.78244 .00944 0 -4.60542 ]

[.78244 .00944 14.4 2.59458 ]

[.852 .16975 0 -4.52236 ]

[.852 .16975 4.8 2.67764 ]

[.91193 .30788 0 -4.45197 ]

[.91193 .30788 9.6 2.74803 ]

[.9641 .42813 0 -4.39157 ]

[.9641 .42813 14.4 2.80843 ]

[.04565 .21043 -14.4 -2.59212 ]

[.04565 .21043 0 4.60788 ]

[.03254 .30147 -14.4 -2.63724 ]

[.03254 .30147 0 4.56276 ]

[.01869 .39763 -4.8 -2.68508 ]

[.01869 .39763 0 4.51492 ]

[.00404 .49935 -9.6 -2.7359 ]

[.00404 .49935 0 4.4641 ]

[-0.01149 .60714 -9.6 -2.78998 ]

[-0.01149 .60714 0 4.41002 ]

[ 0 0 0 0 ]

[ 1 .93555 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Move[object, {100,50},45,45])] .5 .94805 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

.25 Mabswid

.76386 0 m

.95464 .43939 L

s

.76952 .01305 m

.76306 .01485 L

s

[(-50)] .78244 .00944 -1 .27928 Mshowa

.83901 .17308 m

.83251 .17475 L

s

[(0)] .852 .16975 -1 .25621 Mshowa

.89888 .31097 m

.89236 .31251 L

s

[(50)] .91193 .30788 -1 .23666 Mshowa

.95101 .43101 m

.94446 .43245 L

s

[(100)] .9641 .42813 -1 .21988 Mshowa

.125 Mabswid

.7843 .04708 m

.78042 .04814 L

s

.79861 .08005 m

.79473 .0811 L

s

.81249 .11201 m

.8086 .11304 L

s

.82595 .14301 m

.82206 .14402 L

s

.85169 .20228 m

.84778 .20326 L

s

.864 .23063 m

.86009 .23159 L

s

.87596 .25817 m

.87205 .25912 L

s

.88758 .28494 m

.88367 .28588 L

s

.90988 .33629 m

.90596 .3372 L

s

.92057 .36093 m

.91665 .36183 L

s

.93099 .38491 m

.92706 .3858 L

s

.94113 .40826 m

.9372 .40914 L

s

.25 Mabswid

.05984 .19796 m

0 .61535 L

s

.05857 .20681 m

.06503 .205 L

s

[(-50)] .04565 .21043 1 -0.27997 Mshowa

.04549 .298 m

.05197 .29627 L

s

[(-25)] .03254 .30147 1 -0.26743 Mshowa

.03169 .39433 m

.03818 .39267 L

s

[(0)] .01869 .39763 1 -0.25414 Mshowa

.01708 .49622 m

.0236 .49466 L

s

[(25)] .00404 .49935 1 -0.24003 Mshowa

.0016 .6042 m

.00814 .60272 L

s

[(50)] -0.01149 .60714 1 -0.22501 Mshowa

.125 Mabswid

.05601 .22466 m

.05989 .22358 L

s

.05342 .2427 m

.0573 .24163 L

s

.05081 .26093 m

.05469 .25988 L

s

.04817 .27937 m

.05205 .27832 L

s

.04279 .31684 m

.04668 .31581 L

s

.04006 .33589 m

.04395 .33487 L

s

.0373 .35515 m

.0412 .35414 L

s

.03451 .37463 m

.03841 .37363 L

s

.02883 .41424 m

.03273 .41326 L

s

.02594 .43439 m

.02985 .43342 L

s

.02302 .45477 m

.02693 .45381 L

s

.02007 .47538 m

.02398 .47443 L

s

.01405 .51732 m

.01797 .51639 L

s

.01099 .53865 m

.01491 .53774 L

s

.0079 .56024 m

.01182 .55934 L

s

.00477 .58209 m

.00869 .58119 L

s

0 0 m

1 0 L

1 .93555 L

0 .93555 L

closepath

clip

newpath

.5 Mabswid

.93683 .44267 m

.37533 .56553 L

s

.35997 .9174 m

.37533 .56553 L

s

.93683 .44267 m

.97822 .81165 L

s

.35997 .9174 m

.97822 .81165 L

s

.65389 .63661 m .65398 .63663 L .66424 .60309 L .763 .662 .751 r

F

.71618 .43327 m .65398 .63663 L .72961 .69933 L .203 .09 .494 r

F

.66563 .64634 m .65398 .63663 L .65389 .63661 L .554 0 0 r

F

.66563 .64634 m .66572 .64636 L .65398 .63663 L F

.65389 .63661 m .66424 .60309 L .64127 .59772 L .763 .662 .751 r

F

.64127 .59772 m .65389 .63661 L .66563 .64634 L 0 .106 .645 r

F

0 g

.65389 .63661 m

.65389 .63661 L

s

.64127 .59772 m .66424 .60309 L .67454 .56941 L .763 .662 .751 r

F

.6396 .56106 m .67454 .56941 L .68489 .53559 L F

.64127 .59772 m .67454 .56941 L .6396 .56106 L F

.64127 .59772 m .66563 .64634 L .65291 .60697 L 0 .106 .645 r

F

.6396 .56106 m .64127 .59772 L .65291 .60697 L .058 .096 .585 r

F

0 g

.64127 .59772 m

.65389 .63661 L

s

.64615 .52612 m .68489 .53559 L .69528 .50163 L .763 .662 .751 r

F

.6396 .56106 m .68489 .53559 L .64615 .52612 L F

.66029 .49288 m .69528 .50163 L .70571 .46752 L F

.64615 .52612 m .69528 .50163 L .66029 .49288 L F

.6396 .56106 m .65291 .60697 L .65125 .56984 L .058 .096 .585 r

F

.64615 .52612 m .6396 .56106 L .65125 .56984 L .148 .08 .518 r

F

0 g

.6396 .56106 m

.64127 .59772 L

s

.68269 .46164 m .70571 .46752 L .71618 .43327 L .763 .662 .751 r

F

.66029 .49288 m .70571 .46752 L .68269 .46164 L F

.64615 .52612 m .65125 .56984 L .65792 .53444 L .148 .08 .518 r

F

.66029 .49288 m .64615 .52612 L .65792 .53444 L .215 .062 .446 r

F

0 g

.6396 .56106 m

.64615 .52612 L

s

.68269 .46164 m .71618 .43327 L .71609 .43325 L .763 .662 .751 r

F

.71618 .43327 m .72961 .69933 L .79843 .47864 L .203 .09 .494 r

F

.71609 .43325 m .71618 .43327 L .72894 .44031 L .413 0 0 r

F

0 g

.65812 .6231 m

.71618 .4333 L

s

.75184 .0273 m

.84084 .22714 L

s

.84084 .22714 m

.93683 .44267 L

s

.71609 .43325 m .72894 .44031 L .72885 .44029 L .413 0 0 r

F

.71609 .43325 m .695 .46908 L .72885 .44029 L .325 .007 .262 r

F

.71609 .43325 m .68269 .46164 L .695 .46908 L F

0 g

.71609 .43325 m

.71609 .43325 L

s

.66029 .49288 m .65792 .53444 L .67228 .50075 L .215 .062 .446 r

F

.68269 .46164 m .66029 .49288 L .67228 .50075 L .272 .039 .366 r

F

0 g

.64615 .52612 m

.66029 .49288 L

s

.6777 .65635 m .66572 .64636 L .66563 .64634 L .554 0 0 r

F

.6777 .65635 m .67779 .65637 L .66572 .64636 L F

.65291 .60697 m .66563 .64634 L .6777 .65635 L 0 .106 .645 r

F

0 g

.65389 .63661 m

.66563 .64634 L

s

.68269 .46164 m .67228 .50075 L .695 .46908 L .272 .039 .366 r

F

0 g

.68269 .46164 m

.71609 .43325 L

s

.66029 .49288 m

.68269 .46164 L

s

.23539 .47063 m .27493 .48446 L .27276 .51435 L .822 .574 .564 r

F

0 g

.21598 .37365 m

.37533 .56553 L

s

.27493 .48446 m .25862 .46514 L .23539 .47063 L .655 .752 .921 r

F

.27493 .48446 m .27502 .48444 L .25862 .46514 L F

.27276 .51435 m .27502 .48444 L .27493 .48446 L .59 .37 .55 r

F

0 g

.27493 .48446 m

.27493 .48446 L

s

.27276 .51435 m .27285 .51433 L .27502 .48444 L .59 .37 .55 r

F

.23539 .47063 m .24183 .4454 L .2063 .45391 L .655 .752 .921 r

F

.23539 .47063 m .25862 .46514 L .24183 .4454 L F

.23539 .47063 m .27276 .51435 L .23287 .50065 L .822 .574 .564 r

F

.2063 .45391 m .23539 .47063 L .23287 .50065 L .881 .631 .555 r

F

.23287 .50065 m .27276 .51435 L .27056 .54473 L .822 .574 .564 r

F

.27056 .54473 m .27285 .51433 L .27276 .51435 L .59 .37 .55 r

F

.27056 .54473 m .27065 .54471 L .27285 .51433 L F

.23287 .50065 m .27056 .54473 L .23032 .53118 L .822 .574 .564 r

F

.20352 .48409 m .23287 .50065 L .23032 .53118 L .881 .631 .555 r

F

.2063 .45391 m .23287 .50065 L .20352 .48409 L F

.23032 .53118 m .27056 .54473 L .26832 .57563 L .822 .574 .564 r

F

.26832 .57563 m .27065 .54471 L .27056 .54473 L .59 .37 .55 r

F

.26832 .57563 m .26842 .57561 L .27065 .54471 L F

.2063 .45391 m .22466 .4252 L .18497 .43484 L .655 .752 .921 r

F

.2063 .45391 m .24183 .4454 L .22466 .4252 L F

.18497 .43484 m .2063 .45391 L .20352 .48409 L .939 .691 .535 r

F

.23032 .53118 m .26832 .57563 L .22772 .56222 L .822 .574 .564 r

F

.20069 .51478 m .23032 .53118 L .22772 .56222 L .881 .631 .555 r

F

.20352 .48409 m .23032 .53118 L .20069 .51478 L F

.22772 .56222 m .26832 .57563 L .26605 .60705 L .822 .574 .564 r

F

.26605 .60705 m .26842 .57561 L .26832 .57563 L .59 .37 .55 r

F

.26605 .60705 m .26614 .60703 L .26842 .57561 L F

.18497 .43484 m .20707 .40451 L .17088 .41343 L .655 .752 .921 r

F

.18497 .43484 m .22466 .4252 L .20707 .40451 L F

.22772 .56222 m .26605 .60705 L .22508 .5938 L .822 .574 .564 r

F

.22508 .5938 m .26605 .60705 L .26373 .63901 L F

.26373 .63901 m .26614 .60703 L .26605 .60705 L .59 .37 .55 r

F

.26373 .63901 m .26383 .63899 L .26614 .60703 L F

.17088 .41343 m .18906 .38332 L .16495 .38935 L .655 .752 .921 r

F

.17088 .41343 m .20707 .40451 L .18906 .38332 L F

.22508 .5938 m .26373 .63901 L .22239 .62592 L .822 .574 .564 r

F

.22239 .62592 m .26373 .63901 L .26138 .67153 L F

.26138 .67153 m .26383 .63899 L .26373 .63901 L .59 .37 .55 r

F

.26138 .67153 m .26147 .67151 L .26383 .63899 L F

.16495 .38935 m .18906 .38332 L .17062 .36162 L .655 .752 .921 r

F

.17062 .36162 m .27502 .48444 L .26147 .67151 L .97 .724 .507 r

F

0 g

.18138 .75155 m

.35997 .9174 L

s

.65291 .60697 m .6777 .65635 L .66486 .61649 L 0 .106 .645 r

F

.65125 .56984 m .65291 .60697 L .66486 .61649 L .058 .096 .585 r

F

.65125 .56984 m .66486 .61649 L .66323 .57887 L F

.65792 .53444 m .65125 .56984 L .66323 .57887 L .148 .08 .518 r

F

.65792 .53444 m .66323 .57887 L .67003 .54299 L F

.67228 .50075 m .65792 .53444 L .67003 .54299 L .215 .062 .446 r

F

.72885 .44029 m .72894 .44031 L .74205 .44754 L .413 0 0 r

F

.72885 .44029 m .74205 .44754 L .74196 .44752 L F

.72885 .44029 m .70765 .47673 L .74196 .44752 L .325 .007 .262 r

F

.72885 .44029 m .695 .46908 L .70765 .47673 L F

0 g

.71609 .43325 m

.72885 .44029 L

s

.67228 .50075 m .67003 .54299 L .68461 .50885 L .215 .062 .446 r

F

.695 .46908 m .67228 .50075 L .68461 .50885 L .272 .039 .366 r

F

.69011 .66663 m .67779 .65637 L .6777 .65635 L .554 0 0 r

F

.69011 .66663 m .6902 .66665 L .67779 .65637 L F

.66486 .61649 m .6777 .65635 L .69011 .66663 L 0 .106 .645 r

F

0 g

.66563 .64634 m

.6777 .65635 L

s

.695 .46908 m .68461 .50885 L .70765 .47673 L .272 .039 .366 r

F

.66486 .61649 m .69011 .66663 L .67716 .62627 L 0 .106 .645 r

F

.66323 .57887 m .66486 .61649 L .67716 .62627 L .058 .096 .585 r

F

.67003 .54299 m .66323 .57887 L .67556 .58815 L .148 .08 .518 r

F

.66323 .57887 m .67716 .62627 L .67556 .58815 L .058 .096 .585 r

F

.67003 .54299 m .67556 .58815 L .68249 .55179 L .148 .08 .518 r

F

.68461 .50885 m .67003 .54299 L .68249 .55179 L .215 .062 .446 r

F

.74196 .44752 m .74205 .44754 L .75554 .45498 L .413 0 0 r

F

.74196 .44752 m .75554 .45498 L .75545 .45496 L F

.74196 .44752 m .72067 .4846 L .75545 .45496 L .325 .007 .262 r

F

.74196 .44752 m .70765 .47673 L .72067 .4846 L F

0 g

.72885 .44029 m

.74196 .44752 L

s

.18198 .46519 m .20352 .48409 L .20069 .51478 L .939 .691 .535 r

F

.18497 .43484 m .20352 .48409 L .18198 .46519 L F

.68461 .50885 m .68249 .55179 L .6973 .51717 L .215 .062 .446 r

F

.70765 .47673 m .68461 .50885 L .6973 .51717 L .272 .039 .366 r

F

.70287 .67721 m .6902 .66665 L .69011 .66663 L .554 0 0 r

F

.70287 .67721 m .70296 .67724 L .6902 .66665 L F

.67716 .62627 m .69011 .66663 L .70287 .67721 L 0 .106 .645 r

F

0 g

.6777 .65635 m

.69011 .66663 L

s

.70765 .47673 m .6973 .51717 L .72067 .4846 L .272 .039 .366 r

F

.17088 .41343 m .18497 .43484 L .18198 .46519 L .989 .755 .486 r

F

0 g

.18497 .43484 m

.19461 .44346 L

s

.67716 .62627 m .70287 .67721 L .68981 .63633 L 0 .106 .645 r

F

.67556 .58815 m .67716 .62627 L .68981 .63633 L .058 .096 .585 r

F

.19781 .546 m .22772 .56222 L .22508 .5938 L .881 .631 .555 r

F

.20069 .51478 m .22772 .56222 L .19781 .546 L F

.17893 .49607 m .20069 .51478 L .19781 .546 L .939 .691 .535 r

F

.18198 .46519 m .20069 .51478 L .17893 .49607 L F

.67556 .58815 m .68981 .63633 L .68823 .5977 L .058 .096 .585 r

F

.68249 .55179 m .67556 .58815 L .68823 .5977 L .148 .08 .518 r

F

.16772 .44398 m .18198 .46519 L .17893 .49607 L .989 .755 .486 r

F

.17088 .41343 m .18198 .46519 L .16772 .44398 L F

.68249 .55179 m .68823 .5977 L .6953 .56085 L .148 .08 .518 r

F

.6973 .51717 m .68249 .55179 L .6953 .56085 L .215 .062 .446 r

F

.75545 .45496 m .75554 .45498 L .76942 .46264 L .413 0 0 r

F

.75545 .45496 m .76942 .46264 L .76933 .46262 L F

.75545 .45496 m .73406 .4927 L .76933 .46262 L .325 .007 .262 r

F

.75545 .45496 m .72067 .4846 L .73406 .4927 L F

0 g

.74196 .44752 m

.75545 .45496 L

s

.16495 .38935 m .17088 .41343 L .16772 .44398 L .966 .782 .346 r

F

0 g

.17088 .41343 m

.18497 .43484 L

s

.6973 .51717 m .6953 .56085 L .71035 .52574 L .215 .062 .446 r

F

.72067 .4846 m .6973 .51717 L .71035 .52574 L .272 .039 .366 r

F

.716 .6881 m .70296 .67724 L .70287 .67721 L .554 0 0 r

F

.716 .6881 m .71609 .68812 L .70296 .67724 L F

.68981 .63633 m .70287 .67721 L .716 .6881 L 0 .106 .645 r

F

0 g

.69011 .66663 m

.70287 .67721 L

s

.72067 .4846 m .71035 .52574 L .73406 .4927 L .272 .039 .366 r

F

.19781 .546 m .22508 .5938 L .19489 .57776 L .881 .631 .555 r

F

.19489 .57776 m .22508 .5938 L .22239 .62592 L F

.17583 .52748 m .19781 .546 L .19489 .57776 L .939 .691 .535 r

F

.17893 .49607 m .19781 .546 L .17583 .52748 L F

.16451 .47506 m .17893 .49607 L .17583 .52748 L .989 .755 .486 r

F

.16772 .44398 m .17893 .49607 L .16451 .47506 L F

.68981 .63633 m .716 .6881 L .70283 .64669 L 0 .106 .645 r

F

.68823 .5977 m .68981 .63633 L .70283 .64669 L .058 .096 .585 r

F

0 g

.8767 .62231 m

.97822 .81165 L

s

.1617 .42011 m .16772 .44398 L .16451 .47506 L .966 .782 .346 r

F

.16495 .38935 m .16772 .44398 L .1617 .42011 L F

.22239 .62592 m .26138 .67153 L .21965 .6586 L .822 .574 .564 r

F

.19191 .61007 m .22239 .62592 L .21965 .6586 L .881 .631 .555 r

F

.19489 .57776 m .22239 .62592 L .19191 .61007 L F

.21965 .6586 m .26147 .67151 L .26138 .67153 L .638 .77 .943 r

F

0 g

.26138 .67153 m

.26138 .67153 L

s

.26138 .67148 m

.2614 .67126 L

s

.17583 .52748 m .19489 .57776 L .17267 .55944 L .939 .691 .535 r

F

.17267 .55944 m .19489 .57776 L .19191 .61007 L F

.16125 .50668 m .17583 .52748 L .17267 .55944 L .989 .755 .486 r

F

.16451 .47506 m .17583 .52748 L .16125 .50668 L F

.1584 .45142 m .16451 .47506 L .16125 .50668 L .966 .782 .346 r

F

.1617 .42011 m .16451 .47506 L .1584 .45142 L F

.17267 .55944 m .19191 .61007 L .16946 .59197 L .939 .691 .535 r

F

.16125 .50668 m .17267 .55944 L .15792 .53887 L .989 .755 .486 r

F

.15792 .53887 m .17267 .55944 L .16946 .59197 L F

.15503 .48328 m .16125 .50668 L .15792 .53887 L .966 .782 .346 r

F

.1584 .45142 m .16125 .50668 L .15503 .48328 L F

.15792 .53887 m .16946 .59197 L .15454 .57163 L .989 .755 .486 r

F

.15503 .48328 m .15792 .53887 L .1516 .51571 L .966 .782 .346 r

F

.1516 .51571 m .15792 .53887 L .15454 .57163 L F

.14811 .54873 m .15454 .57163 L .1511 .60498 L F

.1516 .51571 m .15454 .57163 L .14811 .54873 L F

.17062 .36162 m .26147 .67151 L .1502 .55627 L .97 .724 .507 r

F

.21965 .6586 m .24405 .65346 L .26147 .67151 L .638 .77 .943 r

F

0 g

.26147 .67151 m

.27502 .48444 L

s

.6953 .56085 m .68823 .5977 L .70128 .60754 L .148 .08 .518 r

F

.68823 .5977 m .70283 .64669 L .70128 .60754 L .058 .096 .585 r

F

.6953 .56085 m .70128 .60754 L .70849 .57017 L .148 .08 .518 r

F

.71035 .52574 m .6953 .56085 L .70849 .57017 L .215 .062 .446 r

F

.76933 .46262 m .76942 .46264 L .78371 .47052 L .413 0 0 r

F

0 g

.8269 .52943 m

.8767 .62231 L

s

.76933 .46262 m .78371 .47052 L .78362 .4705 L .413 0 0 r

F

.76933 .46262 m .74785 .50103 L .78362 .4705 L .325 .007 .262 r

F

.76933 .46262 m .73406 .4927 L .74785 .50103 L F

0 g

.75545 .45496 m

.76933 .46262 L

s

.16495 .38935 m .17062 .36162 L .17052 .36165 L .655 .752 .921 r

F

.17052 .36165 m .16495 .38935 L .1617 .42011 L 0 0 .013 r

F

0 g

.16582 .39285 m

.16689 .3972 L

s

.08284 .21333 m

.17066 .31908 L

s

.17066 .31908 m

.21598 .37365 L

s

.71035 .52574 m .70849 .57017 L .72378 .53456 L .215 .062 .446 r

F

.73406 .4927 m .71035 .52574 L .72378 .53456 L .272 .039 .366 r

F

.72952 .69931 m .71609 .68812 L .716 .6881 L .554 0 0 r

F

.72952 .69931 m .72961 .69933 L .71609 .68812 L F

.70283 .64669 m .716 .6881 L .72952 .69931 L 0 .106 .645 r

F

0 g

.70287 .67721 m

.716 .6881 L

s

.73406 .4927 m .72378 .53456 L .74785 .50103 L .272 .039 .366 r

F

.19191 .61007 m .21965 .6586 L .18887 .64295 L .881 .631 .555 r

F

.18887 .64295 m .24405 .65346 L .21965 .6586 L .638 .77 .943 r

F

0 g

.21965 .6586 m

.26138 .67153 L

s

.16946 .59197 m .19191 .61007 L .18887 .64295 L .939 .691 .535 r

F

0 g

.15604 .72802 m

.18138 .75155 L

s

.70283 .64669 m .72952 .69931 L .71623 .65735 L 0 .106 .645 r

F

.70128 .60754 m .70283 .64669 L .71623 .65735 L .058 .096 .585 r

F

.18887 .64295 m .2262 .63497 L .24405 .65346 L .638 .77 .943 r

F

.16727 .39265 m .1617 .42011 L .1584 .45142 L 0 0 .013 r

F

.17052 .36165 m .1617 .42011 L .16727 .39265 L F

.70128 .60754 m .71623 .65735 L .71472 .61766 L .058 .096 .585 r

F

.70849 .57017 m .70128 .60754 L .71472 .61766 L .148 .08 .518 r

F

.70849 .57017 m .71472 .61766 L .72208 .57977 L F

.72378 .53456 m .70849 .57017 L .72208 .57977 L .215 .062 .446 r

F

.78362 .4705 m .78371 .47052 L .79843 .47864 L .413 0 0 r

F

.78362 .4705 m .79843 .47864 L .79833 .47861 L F

.78362 .4705 m .76205 .50962 L .79833 .47861 L .325 .007 .262 r

F

.78362 .4705 m .74785 .50103 L .76205 .50962 L F

0 g

.76933 .46262 m

.78362 .4705 L

s

.16946 .59197 m .18887 .64295 L .1662 .62507 L .939 .691 .535 r

F

.1662 .62507 m .2262 .63497 L .18887 .64295 L .638 .77 .943 r

F

0 g

.18887 .64295 m

.21965 .6586 L

s

.72378 .53456 m .72208 .57977 L .73762 .54364 L .215 .062 .446 r

F

.74785 .50103 m .72378 .53456 L .73762 .54364 L .272 .039 .366 r

F

.71623 .65735 m .72961 .69933 L .72952 .69931 L .768 .67 .755 r

F

.71623 .65735 m .74095 .66297 L .72961 .69933 L F

0 g

.716 .6881 m

.72952 .69931 L

s

.72952 .69931 m

.72952 .69931 L

s

.17052 .36165 m .16737 .39262 L .16727 .39265 L .572 .341 .527 r

F

.17052 .36165 m .17062 .36162 L .16737 .39262 L F

0 g

.16495 .38935 m

.17052 .36165 L

s

.17062 .36162 m

.27502 .48444 L

s

.17052 .36165 m

.17052 .36165 L

s

.74785 .50103 m .73762 .54364 L .76205 .50962 L .272 .039 .366 r

F

.15454 .57163 m .16946 .59197 L .1662 .62507 L .989 .755 .486 r

F

.16396 .4242 m .1584 .45142 L .15503 .48328 L 0 0 .013 r

F

.16727 .39265 m .1584 .45142 L .16396 .4242 L F

.71472 .61766 m .74095 .66297 L .71623 .65735 L .768 .67 .755 r

F

.71472 .61766 m .75234 .62644 L .74095 .66297 L F

0 g

.71623 .65735 m

.72952 .69931 L

s

.1662 .62507 m .2079 .61603 L .2262 .63497 L .638 .77 .943 r

F

0 g

.08284 .21333 m

.75184 .0273 L

s

.02897 .61001 m

.08284 .21333 L

s

.72208 .57977 m .75234 .62644 L .71472 .61766 L .768 .67 .755 r

F

.72208 .57977 m .76378 .58974 L .75234 .62644 L F

0 g

.71472 .61766 m

.71623 .65735 L

s

.73762 .54364 m .76378 .58974 L .72208 .57977 L .768 .67 .755 r

F

.73762 .54364 m .77528 .55288 L .76378 .58974 L F

.16727 .39265 m .16406 .42418 L .16396 .4242 L .572 .341 .527 r

F

.16727 .39265 m .16737 .39262 L .16406 .42418 L F

0 g

.16727 .39265 m

.17052 .36165 L

s

.76205 .50962 m .77528 .55288 L .73762 .54364 L .768 .67 .755 r

F

.76205 .50962 m .78683 .51584 L .77528 .55288 L F

0 g

.71472 .61766 m

.72208 .57977 L

s

.15454 .57163 m .1662 .62507 L .1511 .60498 L .989 .755 .486 r

F

.1511 .60498 m .2079 .61603 L .1662 .62507 L .638 .77 .943 r

F

0 g

.1662 .62507 m

.18887 .64295 L

s

.16059 .45633 m .15503 .48328 L .1516 .51571 L 0 0 .013 r

F

.16396 .4242 m .15503 .48328 L .16059 .45633 L F

.79833 .47861 m .78683 .51584 L .76205 .50962 L .768 .67 .755 r

F

.79833 .47861 m .79843 .47864 L .78683 .51584 L F

0 g

.71618 .43327 m

.79843 .47864 L

s

.78362 .4705 m

.79833 .47861 L

s

.72961 .69933 m

.79843 .47864 L

s

.78017 .44227 m

.8269 .52943 L

s

.72208 .57977 m

.73762 .54364 L

s

.76205 .50962 m

.79833 .47861 L

s

.73762 .54364 m

.76205 .50962 L

s

.1511 .60498 m .18915 .59661 L .2079 .61603 L .638 .77 .943 r

F

0 g

.02897 .61001 m

.15604 .72802 L

s

.16396 .4242 m .16069 .4563 L .16059 .45633 L .572 .341 .527 r

F

.16396 .4242 m .16406 .42418 L .16069 .4563 L F

0 g

.16396 .4242 m

.16727 .39265 L

s

.15716 .48904 m .1516 .51571 L .14811 .54873 L 0 0 .013 r

F

.16059 .45633 m .1516 .51571 L .15716 .48904 L F

.14811 .54873 m .1511 .60498 L .14456 .58236 L .966 .782 .346 r

F

.14456 .58236 m .18915 .59661 L .1511 .60498 L .638 .77 .943 r

F

0 g

.1511 .60498 m

.1662 .62507 L

s

.16059 .45633 m .15726 .48902 L .15716 .48904 L .572 .341 .527 r

F

.16059 .45633 m .16069 .4563 L .15726 .48902 L F

0 g

.16059 .45633 m

.16396 .4242 L

s

.15366 .52235 m .14811 .54873 L .14456 .58236 L 0 0 .013 r

F

.15716 .48904 m .14811 .54873 L .15366 .52235 L F

.14456 .58236 m .16992 .57669 L .18915 .59661 L .638 .77 .943 r

F

.15716 .48904 m .15376 .52233 L .15366 .52235 L .572 .341 .527 r

F

.15716 .48904 m .15726 .48902 L .15376 .52233 L F

0 g

.15716 .48904 m

.16059 .45633 L

s

.1501 .55629 m .16992 .57669 L .14456 .58236 L .638 .77 .943 r

F

.15366 .52235 m .14456 .58236 L .1501 .55629 L 0 0 .013 r

F

0 g

.14456 .58236 m

.1511 .60498 L

s

.1501 .55629 m .1502 .55627 L .16992 .57669 L .638 .77 .943 r

F

.15366 .52235 m .1502 .55627 L .1501 .55629 L .572 .341 .527 r

F

0 g

.14456 .58236 m

.1501 .55629 L

s

.15366 .52235 m .15376 .52233 L .1502 .55627 L .572 .341 .527 r

F

0 g

.15366 .52235 m

.15716 .48904 L

s

.1502 .55627 m

.17062 .36162 L

s

.1502 .55627 m

.26147 .67151 L

s

.1501 .55629 m

.15366 .52235 L

s

.78017 .44227 m

.75184 .0273 L

s

.78017 .44227 m

.02897 .61001 L

s

.25 Mabswid

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.488992 0.477324 0.913279 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

1.63888e-16 1.07296 -0.0200146 1.07296 [

[.5 .94805 -40.8 0 ]

[.5 .94805 40.8 7.2 ]

[.06656 .18332 -4.38263 -7.2 ]

[.06656 .18332 .41737 0 ]

[.27748 .1236 -8.15353 -7.2 ]

[.27748 .1236 1.44647 0 ]

[.50155 .06024 -11.3127 -7.2 ]

[.50155 .06024 3.08728 0 ]

[.74001 -0.00708 -10.3951 -7.2 ]

[.74001 -0.00708 4.00487 0 ]

[.78244 .00944 0 -4.60542 ]

[.78244 .00944 14.4 2.59458 ]

[.852 .16975 0 -4.52236 ]

[.852 .16975 4.8 2.67764 ]

[.91193 .30788 0 -4.45197 ]

[.91193 .30788 9.6 2.74803 ]

[.9641 .42813 0 -4.39157 ]

[.9641 .42813 14.4 2.80843 ]

[.04565 .21043 -14.4 -2.59212 ]

[.04565 .21043 0 4.60788 ]

[.03254 .30147 -14.4 -2.63724 ]

[.03254 .30147 0 4.56276 ]

[.01869 .39763 -4.8 -2.68508 ]

[.01869 .39763 0 4.51492 ]

[.00404 .49935 -9.6 -2.7359 ]

[.00404 .49935 0 4.4641 ]

[-0.01149 .60714 -9.6 -2.78998 ]

[-0.01149 .60714 0 4.41002 ]

[ 0 0 0 0 ]

[ 1 .93555 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Move[object, 100])] .5 .94805 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

.25 Mabswid

.76386 0 m

.95464 .43939 L

s

.76952 .01305 m

.76306 .01485 L

s

[(-50)] .78244 .00944 -1 .27928 Mshowa

.83901 .17308 m

.83251 .17475 L

s

[(0)] .852 .16975 -1 .25621 Mshowa

.89888 .31097 m

.89236 .31251 L

s

[(50)] .91193 .30788 -1 .23666 Mshowa

.95101 .43101 m

.94446 .43245 L

s

[(100)] .9641 .42813 -1 .21988 Mshowa

.125 Mabswid

.7843 .04708 m

.78042 .04814 L

s

.79861 .08005 m

.79473 .0811 L

s

.81249 .11201 m

.8086 .11304 L

s

.82595 .14301 m

.82206 .14402 L

s

.85169 .20228 m

.84778 .20326 L

s

.864 .23063 m

.86009 .23159 L

s

.87596 .25817 m

.87205 .25912 L

s

.88758 .28494 m

.88367 .28588 L

s

.90988 .33629 m

.90596 .3372 L

s

.92057 .36093 m

.91665 .36183 L

s

.93099 .38491 m

.92706 .3858 L

s

.94113 .40826 m

.9372 .40914 L

s

.25 Mabswid

.05984 .19796 m

0 .61535 L

s

.05857 .20681 m

.06503 .205 L

s

[(-50)] .04565 .21043 1 -0.27997 Mshowa

.04549 .298 m

.05197 .29627 L

s

[(-25)] .03254 .30147 1 -0.26743 Mshowa

.03169 .39433 m

.03818 .39267 L

s

[(0)] .01869 .39763 1 -0.25414 Mshowa

.01708 .49622 m

.0236 .49466 L

s

[(25)] .00404 .49935 1 -0.24003 Mshowa

.0016 .6042 m

.00814 .60272 L

s

[(50)] -0.01149 .60714 1 -0.22501 Mshowa

.125 Mabswid

.05601 .22466 m

.05989 .22358 L

s

.05342 .2427 m

.0573 .24163 L

s

.05081 .26093 m

.05469 .25988 L

s

.04817 .27937 m

.05205 .27832 L

s

.04279 .31684 m

.04668 .31581 L

s

.04006 .33589 m

.04395 .33487 L

s

.0373 .35515 m

.0412 .35414 L

s

.03451 .37463 m

.03841 .37363 L

s

.02883 .41424 m

.03273 .41326 L

s

.02594 .43439 m

.02985 .43342 L

s

.02302 .45477 m

.02693 .45381 L

s

.02007 .47538 m

.02398 .47443 L

s

.01405 .51732 m

.01797 .51639 L

s

.01099 .53865 m

.01491 .53774 L

s

.0079 .56024 m

.01182 .55934 L

s

.00477 .58209 m

.00869 .58119 L

s

0 0 m

1 0 L

1 .93555 L

0 .93555 L

closepath

clip

newpath

.5 Mabswid

.93683 .44267 m

.37533 .56553 L

s

.35997 .9174 m

.37533 .56553 L

s

.75184 .0273 m

.93683 .44267 L

s

.93683 .44267 m

.97822 .81165 L

s

.35997 .9174 m

.97822 .81165 L

s

.23539 .47063 m .27493 .48446 L .27276 .51435 L .822 .574 .564 r

F

0 g

.21598 .37365 m

.37533 .56553 L

s

.27493 .48446 m .25862 .46514 L .23539 .47063 L .655 .752 .921 r

F

.27493 .48446 m .27502 .48444 L .25862 .46514 L F

.27276 .51435 m .27502 .48444 L .27493 .48446 L .59 .37 .55 r

F

0 g

.27493 .48446 m

.27493 .48446 L

s

.27276 .51435 m .27285 .51433 L .27502 .48444 L .59 .37 .55 r

F

.23539 .47063 m .24183 .4454 L .2063 .45391 L .655 .752 .921 r

F

.23539 .47063 m .25862 .46514 L .24183 .4454 L F

.23539 .47063 m .27276 .51435 L .23287 .50065 L .822 .574 .564 r

F

.2063 .45391 m .23539 .47063 L .23287 .50065 L .881 .631 .555 r

F

.23287 .50065 m .27276 .51435 L .27056 .54473 L .822 .574 .564 r

F

.27056 .54473 m .27285 .51433 L .27276 .51435 L .59 .37 .55 r

F

.27056 .54473 m .27065 .54471 L .27285 .51433 L F

.23287 .50065 m .27056 .54473 L .23032 .53118 L .822 .574 .564 r

F

.20352 .48409 m .23287 .50065 L .23032 .53118 L .881 .631 .555 r

F

.2063 .45391 m .23287 .50065 L .20352 .48409 L F

.23032 .53118 m .27056 .54473 L .26832 .57563 L .822 .574 .564 r

F

.26832 .57563 m .27065 .54471 L .27056 .54473 L .59 .37 .55 r

F

.26832 .57563 m .26842 .57561 L .27065 .54471 L F

.2063 .45391 m .22466 .4252 L .18497 .43484 L .655 .752 .921 r

F

.2063 .45391 m .24183 .4454 L .22466 .4252 L F

.18497 .43484 m .2063 .45391 L .20352 .48409 L .939 .691 .535 r

F

.23032 .53118 m .26832 .57563 L .22772 .56222 L .822 .574 .564 r

F

.20069 .51478 m .23032 .53118 L .22772 .56222 L .881 .631 .555 r

F

.20352 .48409 m .23032 .53118 L .20069 .51478 L F

.22772 .56222 m .26832 .57563 L .26605 .60705 L .822 .574 .564 r

F

.26605 .60705 m .26842 .57561 L .26832 .57563 L .59 .37 .55 r

F

.26605 .60705 m .26614 .60703 L .26842 .57561 L F

.18497 .43484 m .20707 .40451 L .17088 .41343 L .655 .752 .921 r

F

.18497 .43484 m .22466 .4252 L .20707 .40451 L F

.22772 .56222 m .26605 .60705 L .22508 .5938 L .822 .574 .564 r

F

.22508 .5938 m .26605 .60705 L .26373 .63901 L F

.26373 .63901 m .26614 .60703 L .26605 .60705 L .59 .37 .55 r

F

.26373 .63901 m .26383 .63899 L .26614 .60703 L F

.17088 .41343 m .18906 .38332 L .16495 .38935 L .655 .752 .921 r

F

.17088 .41343 m .20707 .40451 L .18906 .38332 L F

.22508 .5938 m .26373 .63901 L .22239 .62592 L .822 .574 .564 r

F

.22239 .62592 m .26373 .63901 L .26138 .67153 L F

.26138 .67153 m .26383 .63899 L .26373 .63901 L .59 .37 .55 r

F

.26138 .67153 m .26147 .67151 L .26383 .63899 L F

.16495 .38935 m .18906 .38332 L .17062 .36162 L .655 .752 .921 r

F

.17062 .36162 m .27502 .48444 L .26147 .67151 L .97 .724 .507 r

F

0 g

.18138 .75155 m

.35997 .9174 L

s

.18198 .46519 m .20352 .48409 L .20069 .51478 L .939 .691 .535 r

F

.18497 .43484 m .20352 .48409 L .18198 .46519 L F

.17088 .41343 m .18497 .43484 L .18198 .46519 L .989 .755 .486 r

F

0 g

.18497 .43484 m

.19461 .44346 L

s

.19781 .546 m .22772 .56222 L .22508 .5938 L .881 .631 .555 r

F

.20069 .51478 m .22772 .56222 L .19781 .546 L F

.17893 .49607 m .20069 .51478 L .19781 .546 L .939 .691 .535 r

F

.18198 .46519 m .20069 .51478 L .17893 .49607 L F

.16772 .44398 m .18198 .46519 L .17893 .49607 L .989 .755 .486 r

F

.17088 .41343 m .18198 .46519 L .16772 .44398 L F


.16495 .38935 m .17088 .41343 L .16772 .44398 L .966 .782 .346 r

F

0 g

.17088 .41343 m

.18497 .43484 L

s

.19781 .546 m .22508 .5938 L .19489 .57776 L .881 .631 .555 r

F

.19489 .57776 m .22508 .5938 L .22239 .62592 L F

.17583 .52748 m .19781 .546 L .19489 .57776 L .939 .691 .535 r

F

.17893 .49607 m .19781 .546 L .17583 .52748 L F

.16451 .47506 m .17893 .49607 L .17583 .52748 L .989 .755 .486 r

F

.16772 .44398 m .17893 .49607 L .16451 .47506 L F

0 g

.97822 .81165 m

.78017 .44227 L

s

.1617 .42011 m .16772 .44398 L .16451 .47506 L .966 .782 .346 r

F

.16495 .38935 m .16772 .44398 L .1617 .42011 L F

.22239 .62592 m .26138 .67153 L .21965 .6586 L .822 .574 .564 r

F

.19191 .61007 m .22239 .62592 L .21965 .6586 L .881 .631 .555 r

F

.19489 .57776 m .22239 .62592 L .19191 .61007 L F

.21965 .6586 m .26147 .67151 L .26138 .67153 L .638 .77 .943 r

F

0 g

.26138 .67153 m

.26138 .67153 L

s

.26138 .67148 m

.2614 .67126 L

s

.17583 .52748 m .19489 .57776 L .17267 .55944 L .939 .691 .535 r

F

.17267 .55944 m .19489 .57776 L .19191 .61007 L F

.16125 .50668 m .17583 .52748 L .17267 .55944 L .989 .755 .486 r

F

.16451 .47506 m .17583 .52748 L .16125 .50668 L F

.1584 .45142 m .16451 .47506 L .16125 .50668 L .966 .782 .346 r

F

.1617 .42011 m .16451 .47506 L .1584 .45142 L F

.17267 .55944 m .19191 .61007 L .16946 .59197 L .939 .691 .535 r

F

.16125 .50668 m .17267 .55944 L .15792 .53887 L .989 .755 .486 r

F

.15792 .53887 m .17267 .55944 L .16946 .59197 L F

.15503 .48328 m .16125 .50668 L .15792 .53887 L .966 .782 .346 r

F

.1584 .45142 m .16125 .50668 L .15503 .48328 L F

.15792 .53887 m .16946 .59197 L .15454 .57163 L .989 .755 .486 r

F

.15503 .48328 m .15792 .53887 L .1516 .51571 L .966 .782 .346 r

F

.1516 .51571 m .15792 .53887 L .15454 .57163 L F

.14811 .54873 m .15454 .57163 L .1511 .60498 L F

.1516 .51571 m .15454 .57163 L .14811 .54873 L F

.17062 .36162 m .26147 .67151 L .1502 .55627 L .97 .724 .507 r

F

.21965 .6586 m .24405 .65346 L .26147 .67151 L .638 .77 .943 r

F

0 g

.26147 .67151 m

.27502 .48444 L

s

.16495 .38935 m .17062 .36162 L .17052 .36165 L .655 .752 .921 r

F

.17052 .36165 m .16495 .38935 L .1617 .42011 L 0 0 .013 r

F

0 g

.16582 .39285 m

.16689 .3972 L

s

.08284 .21333 m

.17066 .31908 L

s

.17066 .31908 m

.21598 .37365 L

s

.64693 .37339 m .68518 .38884 L .68648 .41961 L .84 .568 .527 r

F

.68518 .38884 m .67291 .36725 L .64693 .37339 L .655 .752 .921 r

F

.68518 .38884 m .68527 .38882 L .67291 .36725 L F

.68648 .41961 m .68527 .38882 L .68518 .38884 L .59 .37 .55 r

F

0 g

.68518 .38884 m

.68518 .38884 L

s

.68648 .41961 m .68658 .41958 L .68527 .38882 L .59 .37 .55 r

F

.64693 .37339 m .68648 .41961 L .64791 .40429 L .84 .568 .527 r

F

.62046 .35469 m .64693 .37339 L .64791 .40429 L .914 .632 .493 r

F

.64693 .37339 m .66024 .34515 L .62046 .35469 L .655 .752 .921 r

F

.64693 .37339 m .67291 .36725 L .66024 .34515 L F

.64791 .40429 m .68648 .41961 L .6878 .45091 L .84 .568 .527 r

F

.6878 .45091 m .68658 .41958 L .68648 .41961 L .59 .37 .55 r

F

.6878 .45091 m .6879 .45089 L .68658 .41958 L F

.64791 .40429 m .6878 .45091 L .6489 .43574 L .84 .568 .527 r

F

.62121 .38574 m .64791 .40429 L .6489 .43574 L .914 .632 .493 r

F

.62046 .35469 m .64791 .40429 L .62121 .38574 L F

.6489 .43574 m .6878 .45091 L .68915 .48278 L .84 .568 .527 r

F

.68915 .48278 m .6879 .45089 L .6878 .45091 L .59 .37 .55 r

F

.68915 .48278 m .68925 .48276 L .6879 .45089 L F

.62046 .35469 m .64725 .32251 L .60276 .33332 L .655 .752 .921 r

F

.62046 .35469 m .66024 .34515 L .64725 .32251 L F

.6489 .43574 m .68915 .48278 L .64991 .46775 L .84 .568 .527 r

F

.64991 .46775 m .68915 .48278 L .69052 .51522 L F

.69052 .51522 m .68925 .48276 L .68915 .48278 L .59 .37 .55 r

F

.69052 .51522 m .69062 .5152 L .68925 .48276 L F

.60276 .33332 m .63394 .29929 L .59331 .30931 L .655 .752 .921 r

F

.60276 .33332 m .64725 .32251 L .63394 .29929 L F

.64991 .46775 m .69052 .51522 L .65094 .50035 L .84 .568 .527 r

F

.65094 .50035 m .69052 .51522 L .69192 .54825 L F

.69192 .54825 m .69062 .5152 L .69052 .51522 L .59 .37 .55 r

F

.69192 .54825 m .69202 .54822 L .69062 .5152 L F

.59331 .30931 m .62029 .27548 L .59318 .28226 L .655 .752 .921 r

F

.59331 .30931 m .63394 .29929 L .62029 .27548 L F

.65094 .50035 m .69192 .54825 L .65199 .53354 L .84 .568 .527 r

F

.65199 .53354 m .69192 .54825 L .69334 .58188 L F

.69334 .58188 m .69202 .54822 L .69192 .54825 L .59 .37 .55 r

F

.69334 .58188 m .69344 .58186 L .69202 .54822 L F

.59318 .28226 m .62029 .27548 L .60628 .25106 L .655 .752 .921 r

F

.60628 .25106 m .68527 .38882 L .69344 .58186 L .984 .709 .342 r

F

.19191 .61007 m .21965 .6586 L .18887 .64295 L .881 .631 .555 r

F

.18887 .64295 m .24405 .65346 L .21965 .6586 L .638 .77 .943 r

F

0 g

.21965 .6586 m

.26138 .67153 L

s

.16946 .59197 m .19191 .61007 L .18887 .64295 L .939 .691 .535 r

F

0 g

.15604 .72802 m

.18138 .75155 L

s

.18887 .64295 m .2262 .63497 L .24405 .65346 L .638 .77 .943 r

F

.16727 .39265 m .1617 .42011 L .1584 .45142 L 0 0 .013 r

F

.17052 .36165 m .1617 .42011 L .16727 .39265 L F

.16946 .59197 m .18887 .64295 L .1662 .62507 L .939 .691 .535 r

F

.1662 .62507 m .2262 .63497 L .18887 .64295 L .638 .77 .943 r

F

0 g

.18887 .64295 m

.21965 .6586 L

s

.17052 .36165 m .16737 .39262 L .16727 .39265 L .572 .341 .527 r

F

.17052 .36165 m .17062 .36162 L .16737 .39262 L F

0 g

.16495 .38935 m

.17052 .36165 L

s

.17062 .36162 m

.27502 .48444 L

s

.17052 .36165 m

.17052 .36165 L

s

.15454 .57163 m .16946 .59197 L .1662 .62507 L .989 .755 .486 r

F

.16396 .4242 m .1584 .45142 L .15503 .48328 L 0 0 .013 r

F

.16727 .39265 m .1584 .45142 L .16396 .4242 L F

.60276 .33332 m .62046 .35469 L .62121 .38574 L .975 .693 .426 r

F

0 g

.62046 .35469 m

.63659 .36608 L

s

.1662 .62507 m .2079 .61603 L .2262 .63497 L .638 .77 .943 r

F

0 g

.08284 .21333 m

.75184 .0273 L

s

.02897 .61001 m

.08284 .21333 L

s

.16727 .39265 m .16406 .42418 L .16396 .4242 L .572 .341 .527 r

F

.16727 .39265 m .16737 .39262 L .16406 .42418 L F

0 g

.16727 .39265 m

.17052 .36165 L

s

.15454 .57163 m .1662 .62507 L .1511 .60498 L .989 .755 .486 r

F

.1511 .60498 m .2079 .61603 L .1662 .62507 L .638 .77 .943 r

F

0 g

.1662 .62507 m

.18887 .64295 L

s

.16059 .45633 m .15503 .48328 L .1516 .51571 L 0 0 .013 r

F

.16396 .4242 m .15503 .48328 L .16059 .45633 L F

.62197 .41736 m .6489 .43574 L .64991 .46775 L .914 .632 .493 r

F

.62121 .38574 m .6489 .43574 L .62197 .41736 L F

.60336 .36455 m .62121 .38574 L .62197 .41736 L .975 .693 .426 r

F

.60276 .33332 m .62121 .38574 L .60336 .36455 L F

.59331 .30931 m .60276 .33332 L .60336 .36455 L .963 .713 .274 r

F

0 g

.60276 .33332 m

.62046 .35469 L

s

.1511 .60498 m .18915 .59661 L .2079 .61603 L .638 .77 .943 r

F

0 g

.02897 .61001 m

.15604 .72802 L

s

.16396 .4242 m .16069 .4563 L .16059 .45633 L .572 .341 .527 r

F

.16396 .4242 m .16406 .42418 L .16069 .4563 L F

0 g

.16396 .4242 m

.16727 .39265 L

s

.15716 .48904 m .1516 .51571 L .14811 .54873 L 0 0 .013 r

F

.16059 .45633 m .1516 .51571 L .15716 .48904 L F

.62275 .44955 m .64991 .46775 L .65094 .50035 L .914 .632 .493 r

F

.62197 .41736 m .64991 .46775 L .62275 .44955 L F

.60397 .39636 m .62197 .41736 L .62275 .44955 L .975 .693 .426 r

F

.60336 .36455 m .62197 .41736 L .60397 .39636 L F

.14811 .54873 m .1511 .60498 L .14456 .58236 L .966 .782 .346 r

F

.14456 .58236 m .18915 .59661 L .1511 .60498 L .638 .77 .943 r

F

0 g

.1511 .60498 m

.1662 .62507 L

s

.59382 .34074 m .60336 .36455 L .60397 .39636 L .963 .713 .274 r

F

.59331 .30931 m .60336 .36455 L .59382 .34074 L F

.16059 .45633 m .15726 .48902 L .15716 .48904 L .572 .341 .527 r

F

.16059 .45633 m .16069 .4563 L .15726 .48902 L F

0 g

.16059 .45633 m

.16396 .4242 L

s

.59318 .28226 m .59331 .30931 L .59382 .34074 L 0 0 .022 r

F

0 g

.59348 .30976 m

.60276 .33332 L

s

.15366 .52235 m .14811 .54873 L .14456 .58236 L 0 0 .013 r

F

.15716 .48904 m .14811 .54873 L .15366 .52235 L F

.14456 .58236 m .16992 .57669 L .18915 .59661 L .638 .77 .943 r

F

.62275 .44955 m .65094 .50035 L .62354 .48233 L .914 .632 .493 r

F

.62354 .48233 m .65094 .50035 L .65199 .53354 L F

.60459 .42875 m .62275 .44955 L .62354 .48233 L .975 .693 .426 r

F

.60397 .39636 m .62275 .44955 L .60459 .42875 L F

.59435 .37274 m .60397 .39636 L .60459 .42875 L .963 .713 .274 r

F

.59382 .34074 m .60397 .39636 L .59435 .37274 L F

.15716 .48904 m .15376 .52233 L .15366 .52235 L .572 .341 .527 r

F

.15716 .48904 m .15726 .48902 L .15376 .52233 L F

0 g

.15716 .48904 m

.16059 .45633 L

s

.5937 .3139 m .59382 .34074 L .59435 .37274 L 0 0 .022 r

F

.59318 .28226 m .59382 .34074 L .5937 .3139 L F

.1501 .55629 m .16992 .57669 L .14456 .58236 L .638 .77 .943 r

F

.15366 .52235 m .14456 .58236 L .1501 .55629 L 0 0 .013 r

F

0 g

.14456 .58236 m

.1511 .60498 L

s

.65199 .53354 m .69334 .58188 L .65305 .56734 L .84 .568 .527 r

F

.62434 .51572 m .65199 .53354 L .65305 .56734 L .914 .632 .493 r

F

.62354 .48233 m .65199 .53354 L .62434 .51572 L F

.65305 .56734 m .69344 .58186 L .69334 .58188 L .638 .77 .943 r

F

0 g

.69334 .58188 m

.69334 .58188 L

s

.69332 .58138 m

.69334 .58182 L

s

.60459 .42875 m .62354 .48233 L .60522 .46173 L .975 .693 .426 r

F

.60628 .25106 m .69344 .58186 L .61043 .45177 L .984 .709 .342 r

F

.65305 .56734 m .6805 .56156 L .69344 .58186 L .638 .77 .943 r

F

0 g

.68527 .38882 m

.69344 .58186 L

s

.60522 .46173 m .62354 .48233 L .62434 .51572 L .975 .693 .426 r

F

.1501 .55629 m .1502 .55627 L .16992 .57669 L .638 .77 .943 r

F

.59489 .40535 m .60459 .42875 L .60522 .46173 L .963 .713 .274 r

F

.59435 .37274 m .60459 .42875 L .59489 .40535 L F

.59318 .28226 m .60628 .25106 L .60617 .25109 L .655 .752 .921 r

F

.60617 .25109 m .59318 .28226 L .5937 .3139 L 0 0 .319 r

F

0 g

.59318 .28226 m

.59331 .30931 L

s

.15366 .52235 m .1502 .55627 L .1501 .55629 L .572 .341 .527 r

F

0 g

.14456 .58236 m

.1501 .55629 L

s

.15366 .52235 m .15376 .52233 L .1502 .55627 L .572 .341 .527 r

F

0 g

.15366 .52235 m

.15716 .48904 L

s

.1502 .55627 m

.17062 .36162 L

s

.1502 .55627 m

.26147 .67151 L

s

.1501 .55629 m

.15366 .52235 L

s

.59424 .34613 m .59435 .37274 L .59489 .40535 L 0 0 .022 r

F

.5937 .3139 m .59435 .37274 L .59424 .34613 L F

.62434 .51572 m .65305 .56734 L .62516 .54973 L .914 .632 .493 r

F

.62516 .54973 m .6805 .56156 L .65305 .56734 L .638 .77 .943 r

F

0 g

.65305 .56734 m

.69334 .58188 L

s

.60586 .49534 m .62434 .51572 L .62516 .54973 L .975 .693 .426 r

F

.60522 .46173 m .62434 .51572 L .60586 .49534 L F

.62516 .54973 m .66721 .54075 L .6805 .56156 L .638 .77 .943 r

F

.59489 .40535 m .60522 .46173 L .59544 .43857 L .963 .713 .274 r

F

.59544 .43857 m .60522 .46173 L .60586 .49534 L F

.60683 .28296 m .5937 .3139 L .59424 .34613 L 0 0 .319 r

F

.60617 .25109 m .5937 .3139 L .60683 .28296 L F

.59479 .37898 m .59489 .40535 L .59544 .43857 L 0 0 .022 r

F

.59424 .34613 m .59489 .40535 L .59479 .37898 L F

.60586 .49534 m .62516 .54973 L .60652 .52958 L .975 .693 .426 r

F

.60652 .52958 m .66721 .54075 L .62516 .54973 L .638 .77 .943 r

F

0 g

.62516 .54973 m

.65305 .56734 L

s

.60617 .25109 m .60694 .28293 L .60683 .28296 L .572 .341 .527 r

F

.60617 .25109 m .60628 .25106 L .60694 .28293 L F

0 g

.60628 .25106 m

.68527 .38882 L

s

.59318 .28226 m

.60617 .25109 L

s

.60617 .25109 m

.60617 .25109 L

s

.596 .47241 m .60586 .49534 L .60652 .52958 L .963 .713 .274 r

F

.59544 .43857 m .60586 .49534 L .596 .47241 L F

.6075 .31544 m .59424 .34613 L .59479 .37898 L 0 0 .319 r

F

.60683 .28296 m .59424 .34613 L .6075 .31544 L F

.60652 .52958 m .65357 .51938 L .66721 .54075 L .638 .77 .943 r

F

.59534 .41244 m .59544 .43857 L .596 .47241 L 0 0 .022 r

F

.59479 .37898 m .59544 .43857 L .59534 .41244 L F

.60683 .28296 m .60761 .31542 L .6075 .31544 L .572 .341 .527 r

F

.60683 .28296 m .60694 .28293 L .60761 .31542 L F

0 g

.60617 .25109 m

.60683 .28296 L

s

.596 .47241 m .60652 .52958 L .59657 .50691 L .963 .713 .274 r

F

.59657 .50691 m .65357 .51938 L .60652 .52958 L .638 .77 .943 r

F

0 g

.60652 .52958 m

.62516 .54973 L

s

.60819 .34855 m .59479 .37898 L .59534 .41244 L 0 0 .319 r

F

.6075 .31544 m .59479 .37898 L .60819 .34855 L F

.59591 .44656 m .596 .47241 L .59657 .50691 L 0 0 .022 r

F

.59534 .41244 m .596 .47241 L .59591 .44656 L F

.59657 .50691 m .63957 .49744 L .65357 .51938 L .638 .77 .943 r

F

.6075 .31544 m .60829 .34852 L .60819 .34855 L .572 .341 .527 r

F

.6075 .31544 m .60761 .31542 L .60829 .34852 L F

0 g

.60683 .28296 m

.6075 .31544 L

s

.60888 .3823 m .59534 .41244 L .59591 .44656 L 0 0 .319 r

F

.60819 .34855 m .59534 .41244 L .60888 .3823 L F

.59591 .44656 m .59657 .50691 L .59649 .48133 L 0 0 .022 r

F

.59649 .48133 m .63957 .49744 L .59657 .50691 L .638 .77 .943 r

F

0 g

.59657 .50691 m

.60652 .52958 L

s

.60819 .34855 m .60899 .38227 L .60888 .3823 L .572 .341 .527 r

F

.60819 .34855 m .60829 .34852 L .60899 .38227 L F

0 g

.6075 .31544 m

.60819 .34855 L

s

.60959 .41671 m .59591 .44656 L .59649 .48133 L 0 0 .319 r

F

.60888 .3823 m .59591 .44656 L .60959 .41671 L F

.59649 .48133 m .6252 .47492 L .63957 .49744 L .638 .77 .943 r

F

0 g

.78017 .44227 m

.75184 .0273 L

s

.60888 .3823 m .6097 .41668 L .60959 .41671 L .572 .341 .527 r

F

.60888 .3823 m .60899 .38227 L .6097 .41668 L F

0 g

.60819 .34855 m

.60888 .3823 L

s

.61032 .4518 m .6252 .47492 L .59649 .48133 L .638 .77 .943 r

F

.60959 .41671 m .59649 .48133 L .61032 .4518 L 0 0 .319 r

F

0 g

.59649 .48133 m

.59657 .50691 L

s

.61032 .4518 m .61043 .45177 L .6252 .47492 L .638 .77 .943 r

F

.60959 .41671 m .61043 .45177 L .61032 .4518 L .572 .341 .527 r

F

0 g

.59649 .48133 m

.61032 .4518 L

s

.60959 .41671 m .6097 .41668 L .61043 .45177 L .572 .341 .527 r

F

0 g

.60888 .3823 m

.60959 .41671 L

s

.60628 .25106 m

.61043 .45177 L

s

.61043 .45177 m

.69344 .58186 L

s

.60959 .41671 m

.61032 .4518 L

s

.56445 .49044 m

.78017 .44227 L

s

.02897 .61001 m

.56445 .49044 L

s

.25 Mabswid

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.488992 0.97619 0.913279 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

1.63888e-16 1.07296 -0.0200146 1.07296 [

[.5 .94805 -52.8 0 ]

[.5 .94805 52.8 7.2 ]

[.06656 .18332 -4.38263 -7.2 ]

[.06656 .18332 .41737 0 ]

[.27748 .1236 -8.15353 -7.2 ]

[.27748 .1236 1.44647 0 ]

[.50155 .06024 -11.3127 -7.2 ]

[.50155 .06024 3.08728 0 ]

[.74001 -0.00708 -10.3951 -7.2 ]

[.74001 -0.00708 4.00487 0 ]

[.78244 .00944 0 -4.60542 ]

[.78244 .00944 14.4 2.59458 ]

[.852 .16975 0 -4.52236 ]

[.852 .16975 4.8 2.67764 ]

[.91193 .30788 0 -4.45197 ]

[.91193 .30788 9.6 2.74803 ]

[.9641 .42813 0 -4.39157 ]

[.9641 .42813 14.4 2.80843 ]

[.04565 .21043 -14.4 -2.59212 ]

[.04565 .21043 0 4.60788 ]

[.03254 .30147 -14.4 -2.63724 ]

[.03254 .30147 0 4.56276 ]

[.01869 .39763 -4.8 -2.68508 ]

[.01869 .39763 0 4.51492 ]

[.00404 .49935 -9.6 -2.7359 ]

[.00404 .49935 0 4.4641 ]

[-0.01149 .60714 -9.6 -2.78998 ]

[-0.01149 .60714 0 4.41002 ]

[ 0 0 0 0 ]

[ 1 .93555 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Move[object, {100,50}])] .5 .94805 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

.25 Mabswid

.76386 0 m

.95464 .43939 L

s

.76952 .01305 m

.76306 .01485 L

s

[(-50)] .78244 .00944 -1 .27928 Mshowa

.83901 .17308 m

.83251 .17475 L

s

[(0)] .852 .16975 -1 .25621 Mshowa

.89888 .31097 m

.89236 .31251 L

s

[(50)] .91193 .30788 -1 .23666 Mshowa

.95101 .43101 m

.94446 .43245 L

s

[(100)] .9641 .42813 -1 .21988 Mshowa

.125 Mabswid

.7843 .04708 m

.78042 .04814 L

s

.79861 .08005 m

.79473 .0811 L

s

.81249 .11201 m

.8086 .11304 L

s

.82595 .14301 m

.82206 .14402 L

s

.85169 .20228 m

.84778 .20326 L

s

.864 .23063 m

.86009 .23159 L

s

.87596 .25817 m

.87205 .25912 L

s

.88758 .28494 m

.88367 .28588 L

s

.90988 .33629 m

.90596 .3372 L

s

.92057 .36093 m

.91665 .36183 L

s

.93099 .38491 m

.92706 .3858 L

s

.94113 .40826 m

.9372 .40914 L

s

.25 Mabswid

.05984 .19796 m

0 .61535 L

s

.05857 .20681 m

.06503 .205 L

s

[(-50)] .04565 .21043 1 -0.27997 Mshowa

.04549 .298 m

.05197 .29627 L

s

[(-25)] .03254 .30147 1 -0.26743 Mshowa

.03169 .39433 m

.03818 .39267 L

s

[(0)] .01869 .39763 1 -0.25414 Mshowa

.01708 .49622 m

.0236 .49466 L

s

[(25)] .00404 .49935 1 -0.24003 Mshowa

.0016 .6042 m

.00814 .60272 L

s

[(50)] -0.01149 .60714 1 -0.22501 Mshowa

.125 Mabswid

.05601 .22466 m

.05989 .22358 L

s

.05342 .2427 m

.0573 .24163 L

s

.05081 .26093 m

.05469 .25988 L

s

.04817 .27937 m

.05205 .27832 L

s

.04279 .31684 m

.04668 .31581 L

s

.04006 .33589 m

.04395 .33487 L

s

.0373 .35515 m

.0412 .35414 L

s

.03451 .37463 m

.03841 .37363 L

s

.02883 .41424 m

.03273 .41326 L

s

.02594 .43439 m

.02985 .43342 L

s

.02302 .45477 m

.02693 .45381 L

s

.02007 .47538 m

.02398 .47443 L

s

.01405 .51732 m

.01797 .51639 L

s

.01099 .53865 m

.01491 .53774 L

s

.0079 .56024 m

.01182 .55934 L

s

.00477 .58209 m

.00869 .58119 L

s

0 0 m

1 0 L

1 .93555 L

0 .93555 L

closepath

clip

newpath

.5 Mabswid

.93683 .44267 m

.37533 .56553 L

s

.35997 .9174 m

.37533 .56553 L

s

.93683 .44267 m

.97822 .81165 L

s

.35997 .9174 m

.97822 .81165 L

s

.75357 .5081 m .74291 .48933 L .71847 .49466 L .655 .752 .921 r

F

.75357 .5081 m .75367 .50808 L .74291 .48933 L F

.71847 .49466 m .75357 .5081 L .75534 .53776 L .833 .57 .542 r

F

.75534 .53776 m .75367 .50808 L .75357 .5081 L .604 .393 .568 r

F

0 g

.75357 .5081 m

.75357 .5081 L

s

.75534 .53776 m .75544 .53774 L .75367 .50808 L .604 .393 .568 r

F

.71847 .49466 m .73191 .47015 L .6945 .47841 L .655 .752 .921 r

F

.71847 .49466 m .74291 .48933 L .73191 .47015 L F

.71847 .49466 m .75534 .53776 L .71997 .52445 L .833 .57 .542 r

F

.6945 .47841 m .71847 .49466 L .71997 .52445 L .908 .632 .508 r

F

.75714 .5679 m .75544 .53774 L .75534 .53776 L .604 .393 .568 r

F

.71997 .52445 m .75534 .53776 L .75714 .5679 L .833 .57 .542 r

F

.75714 .5679 m .75724 .56788 L .75544 .53774 L .604 .393 .568 r

F

.71997 .52445 m .75714 .5679 L .72149 .55473 L .833 .57 .542 r

F

.75897 .59855 m .75724 .56788 L .75714 .5679 L .604 .393 .568 r

F

.72149 .55473 m .75714 .5679 L .75897 .59855 L .833 .57 .542 r

F

.75897 .59855 m .75907 .59853 L .75724 .56788 L .604 .393 .568 r

F

.6945 .47841 m .72066 .45052 L .67884 .45988 L .655 .752 .921 r

F

.6945 .47841 m .73191 .47015 L .72066 .45052 L F

.72149 .55473 m .75897 .59855 L .72304 .58552 L .833 .57 .542 r

F

.76083 .6297 m .75907 .59853 L .75897 .59855 L .604 .393 .568 r

F

.72304 .58552 m .75897 .59855 L .76083 .6297 L .833 .57 .542 r

F

.76083 .6297 m .76093 .62968 L .75907 .59853 L .604 .393 .568 r

F

.67884 .45988 m .70914 .43043 L .67097 .43909 L .655 .752 .921 r

F

.67884 .45988 m .72066 .45052 L .70914 .43043 L F

.72304 .58552 m .76083 .6297 L .72461 .61683 L .833 .57 .542 r

F

.76273 .66139 m .76093 .62968 L .76083 .6297 L .604 .393 .568 r

F

.72461 .61683 m .76083 .6297 L .76273 .66139 L .833 .57 .542 r

F

.76273 .66139 m .76282 .66137 L .76093 .62968 L .604 .393 .568 r

F

.67097 .43909 m .69735 .40987 L .6719 .41572 L .655 .752 .921 r

F

.67097 .43909 m .70914 .43043 L .69735 .40987 L F

.72461 .61683 m .76273 .66139 L .72621 .64867 L .833 .57 .542 r

F

.76465 .69361 m .76282 .66137 L .76273 .66139 L .604 .393 .568 r

F

.72621 .64867 m .76273 .66139 L .76465 .69361 L .833 .57 .542 r

F

.76465 .69361 m .76475 .69359 L .76282 .66137 L .604 .393 .568 r

F

.6719 .41572 m .69735 .40987 L .68527 .38882 L .655 .752 .921 r

F

.68527 .38882 m .75367 .50808 L .76475 .69359 L .984 .709 .342 r

F

.23539 .47063 m .27493 .48446 L .27276 .51435 L .822 .574 .564 r

F

0 g

.21598 .37365 m

.37533 .56553 L

s

.27493 .48446 m .25862 .46514 L .23539 .47063 L .655 .752 .921 r

F

.27493 .48446 m .27502 .48444 L .25862 .46514 L F

.27276 .51435 m .27502 .48444 L .27493 .48446 L .59 .37 .55 r

F

0 g

.27493 .48446 m

.27493 .48446 L

s

.27276 .51435 m .27285 .51433 L .27502 .48444 L .59 .37 .55 r

F

.23539 .47063 m .24183 .4454 L .2063 .45391 L .655 .752 .921 r

F

.23539 .47063 m .25862 .46514 L .24183 .4454 L F

.23539 .47063 m .27276 .51435 L .23287 .50065 L .822 .574 .564 r

F

.2063 .45391 m .23539 .47063 L .23287 .50065 L .881 .631 .555 r

F

.23287 .50065 m .27276 .51435 L .27056 .54473 L .822 .574 .564 r

F

.27056 .54473 m .27285 .51433 L .27276 .51435 L .59 .37 .55 r

F

.27056 .54473 m .27065 .54471 L .27285 .51433 L F

.23287 .50065 m .27056 .54473 L .23032 .53118 L .822 .574 .564 r

F

.20352 .48409 m .23287 .50065 L .23032 .53118 L .881 .631 .555 r

F

.2063 .45391 m .23287 .50065 L .20352 .48409 L F

.23032 .53118 m .27056 .54473 L .26832 .57563 L .822 .574 .564 r

F

.26832 .57563 m .27065 .54471 L .27056 .54473 L .59 .37 .55 r

F

.26832 .57563 m .26842 .57561 L .27065 .54471 L F

.2063 .45391 m .22466 .4252 L .18497 .43484 L .655 .752 .921 r

F

.2063 .45391 m .24183 .4454 L .22466 .4252 L F

.18497 .43484 m .2063 .45391 L .20352 .48409 L .939 .691 .535 r

F

.23032 .53118 m .26832 .57563 L .22772 .56222 L .822 .574 .564 r

F

.20069 .51478 m .23032 .53118 L .22772 .56222 L .881 .631 .555 r

F

.20352 .48409 m .23032 .53118 L .20069 .51478 L F

.22772 .56222 m .26832 .57563 L .26605 .60705 L .822 .574 .564 r

F

.26605 .60705 m .26842 .57561 L .26832 .57563 L .59 .37 .55 r

F

.26605 .60705 m .26614 .60703 L .26842 .57561 L F

.18497 .43484 m .20707 .40451 L .17088 .41343 L .655 .752 .921 r

F

.18497 .43484 m .22466 .4252 L .20707 .40451 L F

.22772 .56222 m .26605 .60705 L .22508 .5938 L .822 .574 .564 r

F

.22508 .5938 m .26605 .60705 L .26373 .63901 L F

.26373 .63901 m .26614 .60703 L .26605 .60705 L .59 .37 .55 r

F

.26373 .63901 m .26383 .63899 L .26614 .60703 L F

.17088 .41343 m .18906 .38332 L .16495 .38935 L .655 .752 .921 r

F

.17088 .41343 m .20707 .40451 L .18906 .38332 L F

.22508 .5938 m .26373 .63901 L .22239 .62592 L .822 .574 .564 r

F

.22239 .62592 m .26373 .63901 L .26138 .67153 L F

.26138 .67153 m .26383 .63899 L .26373 .63901 L .59 .37 .55 r

F

.26138 .67153 m .26147 .67151 L .26383 .63899 L F

.16495 .38935 m .18906 .38332 L .17062 .36162 L .655 .752 .921 r

F

.17062 .36162 m .27502 .48444 L .26147 .67151 L .97 .724 .507 r

F

0 g

.18138 .75155 m

.35997 .9174 L

s

.69581 .50836 m .71997 .52445 L .72149 .55473 L .908 .632 .508 r

F

.6945 .47841 m .71997 .52445 L .69581 .50836 L F

.67884 .45988 m .6945 .47841 L .69581 .50836 L .974 .694 .435 r

F

0 g

.6945 .47841 m

.71167 .49005 L

s

.69715 .53881 m .72149 .55473 L .72304 .58552 L .908 .632 .508 r

F

.69581 .50836 m .72149 .55473 L .69715 .53881 L F

.68003 .49001 m .69581 .50836 L .69715 .53881 L .974 .694 .435 r

F

.67884 .45988 m .69581 .50836 L .68003 .49001 L F

.67097 .43909 m .67884 .45988 L .68003 .49001 L .956 .706 .255 r

F

0 g

.67884 .45988 m

.6945 .47841 L

s

.69851 .56977 m .72304 .58552 L .72461 .61683 L .908 .632 .508 r

F

.69715 .53881 m .72304 .58552 L .69851 .56977 L F

.68125 .52064 m .69715 .53881 L .69851 .56977 L .974 .694 .435 r

F

.68003 .49001 m .69715 .53881 L .68125 .52064 L F

.67211 .46941 m .68003 .49001 L .68125 .52064 L .956 .706 .255 r

F

.67097 .43909 m .68003 .49001 L .67211 .46941 L F

.18198 .46519 m .20352 .48409 L .20069 .51478 L .939 .691 .535 r

F

.18497 .43484 m .20352 .48409 L .18198 .46519 L F

.6719 .41572 m .67097 .43909 L .67211 .46941 L 0 0 .099 r

F

0 g

.67201 .44183 m

.67884 .45988 L

s

.69851 .56977 m .72461 .61683 L .69989 .60126 L .908 .632 .508 r

F

.69989 .60126 m .72461 .61683 L .72621 .64867 L F

.68249 .55179 m .69851 .56977 L .69989 .60126 L .974 .694 .435 r

F

.68125 .52064 m .69851 .56977 L .68249 .55179 L F

.17088 .41343 m .18497 .43484 L .18198 .46519 L .989 .755 .486 r

F

0 g

.18497 .43484 m

.19461 .44346 L

s

.67328 .50024 m .68125 .52064 L .68249 .55179 L .956 .706 .255 r

F

.67211 .46941 m .68125 .52064 L .67328 .50024 L F

.19781 .546 m .22772 .56222 L .22508 .5938 L .881 .631 .555 r

F

.20069 .51478 m .22772 .56222 L .19781 .546 L F

.17893 .49607 m .20069 .51478 L .19781 .546 L .939 .691 .535 r

F

.18198 .46519 m .20069 .51478 L .17893 .49607 L F

.67307 .44625 m .67211 .46941 L .67328 .50024 L 0 0 .099 r

F

.6719 .41572 m .67211 .46941 L .67307 .44625 L F

.72621 .64867 m .76465 .69361 L .72784 .68106 L .833 .57 .542 r

F

.70129 .63329 m .72621 .64867 L .72784 .68106 L .908 .632 .508 r

F

.69989 .60126 m .72621 .64867 L .70129 .63329 L F

.72784 .68106 m .76475 .69359 L .76465 .69361 L .638 .77 .943 r

F

0 g

.76462 .69309 m

.76465 .69356 L

s

.76465 .69361 m

.76465 .69361 L

s

.72784 .68106 m .75357 .67608 L .76475 .69359 L .638 .77 .943 r

F

.68527 .38882 m .76475 .69359 L .69344 .58186 L .984 .709 .342 r

F

0 g

.75367 .50808 m

.76475 .69359 L

s

.75184 .0273 m

.93683 .44267 L

s

.68249 .55179 m .69989 .60126 L .68375 .58349 L .974 .694 .435 r

F

.68375 .58349 m .69989 .60126 L .70129 .63329 L F

.16772 .44398 m .18198 .46519 L .17893 .49607 L .989 .755 .486 r

F

.17088 .41343 m .18198 .46519 L .16772 .44398 L F

.67446 .53161 m .68249 .55179 L .68375 .58349 L .956 .706 .255 r

F

.67328 .50024 m .68249 .55179 L .67446 .53161 L F

.6719 .41572 m .68527 .38882 L .68518 .38884 L .655 .752 .921 r

F

.68518 .38884 m .6719 .41572 L .67307 .44625 L 0 0 .392 r

F

0 g

.67097 .43909 m

.6719 .41572 L

s

.16495 .38935 m .17088 .41343 L .16772 .44398 L .966 .782 .346 r

F

0 g

.17088 .41343 m

.18497 .43484 L

s

.19781 .546 m .22508 .5938 L .19489 .57776 L .881 .631 .555 r

F

.19489 .57776 m .22508 .5938 L .22239 .62592 L F

.17583 .52748 m .19781 .546 L .19489 .57776 L .939 .691 .535 r

F

.17893 .49607 m .19781 .546 L .17583 .52748 L F

.67426 .47731 m .67328 .50024 L .67446 .53161 L 0 0 .099 r

F

.67307 .44625 m .67328 .50024 L .67426 .47731 L F

.70129 .63329 m .72784 .68106 L .70272 .66587 L .908 .632 .508 r

F

.70272 .66587 m .75357 .67608 L .72784 .68106 L .638 .77 .943 r

F

0 g

.72784 .68106 m

.76465 .69361 L

s

.68502 .61573 m .70129 .63329 L .70272 .66587 L .974 .694 .435 r

F

.68375 .58349 m .70129 .63329 L .68502 .61573 L F

.16451 .47506 m .17893 .49607 L .17583 .52748 L .989 .755 .486 r

F

.16772 .44398 m .17893 .49607 L .16451 .47506 L F

.70272 .66587 m .74213 .65814 L .75357 .67608 L .638 .77 .943 r

F

0 g

.97822 .81165 m

.78017 .44227 L

s

.67446 .53161 m .68375 .58349 L .67566 .56353 L .956 .706 .255 r

F

.67566 .56353 m .68375 .58349 L .68502 .61573 L F

.68648 .41961 m .67307 .44625 L .67426 .47731 L 0 0 .392 r

F

.68518 .38884 m .67307 .44625 L .68648 .41961 L F

.1617 .42011 m .16772 .44398 L .16451 .47506 L .966 .782 .346 r

F

.16495 .38935 m .16772 .44398 L .1617 .42011 L F

.22239 .62592 m .26138 .67153 L .21965 .6586 L .822 .574 .564 r

F

.19191 .61007 m .22239 .62592 L .21965 .6586 L .881 .631 .555 r

F

.19489 .57776 m .22239 .62592 L .19191 .61007 L F

.21965 .6586 m .26147 .67151 L .26138 .67153 L .638 .77 .943 r

F

0 g

.26138 .67153 m

.26138 .67153 L

s

.26138 .67148 m

.2614 .67126 L

s

.17583 .52748 m .19489 .57776 L .17267 .55944 L .939 .691 .535 r

F

.17267 .55944 m .19489 .57776 L .19191 .61007 L F

.16125 .50668 m .17583 .52748 L .17267 .55944 L .989 .755 .486 r

F

.16451 .47506 m .17583 .52748 L .16125 .50668 L F

.1584 .45142 m .16451 .47506 L .16125 .50668 L .966 .782 .346 r

F

.1617 .42011 m .16451 .47506 L .1584 .45142 L F

.17267 .55944 m .19191 .61007 L .16946 .59197 L .939 .691 .535 r

F

.16125 .50668 m .17267 .55944 L .15792 .53887 L .989 .755 .486 r

F

.15792 .53887 m .17267 .55944 L .16946 .59197 L F

.15503 .48328 m .16125 .50668 L .15792 .53887 L .966 .782 .346 r

F

.1584 .45142 m .16125 .50668 L .15503 .48328 L F

.15792 .53887 m .16946 .59197 L .15454 .57163 L .989 .755 .486 r

F

.15503 .48328 m .15792 .53887 L .1516 .51571 L .966 .782 .346 r

F

.1516 .51571 m .15792 .53887 L .15454 .57163 L F

.14811 .54873 m .15454 .57163 L .1511 .60498 L F

.1516 .51571 m .15454 .57163 L .14811 .54873 L F

.17062 .36162 m .26147 .67151 L .1502 .55627 L .97 .724 .507 r

F

.21965 .6586 m .24405 .65346 L .26147 .67151 L .638 .77 .943 r

F

0 g

.26147 .67151 m

.27502 .48444 L

s

.67547 .50891 m .67446 .53161 L .67566 .56353 L 0 0 .099 r

F

.67426 .47731 m .67446 .53161 L .67547 .50891 L F

.68502 .61573 m .70272 .66587 L .68633 .64854 L .974 .694 .435 r

F

.68633 .64854 m .74213 .65814 L .70272 .66587 L .638 .77 .943 r

F

0 g

.70272 .66587 m

.72784 .68106 L

s

.16495 .38935 m .17062 .36162 L .17052 .36165 L .655 .752 .921 r

F

.17052 .36165 m .16495 .38935 L .1617 .42011 L 0 0 .013 r

F

0 g

.16582 .39285 m

.16689 .3972 L

s

.08284 .21333 m

.17066 .31908 L

s

.17066 .31908 m

.21598 .37365 L

s

.68518 .38884 m .68658 .41958 L .68648 .41961 L .59 .37 .55 r

F

.68518 .38884 m .68527 .38882 L .68658 .41958 L F

0 g

.68527 .38882 m

.75367 .50808 L

s

.6719 .41572 m

.68518 .38884 L

s

.68518 .38884 m

.68518 .38884 L

s

.67689 .59601 m .68502 .61573 L .68633 .64854 L .956 .706 .255 r

F

.67566 .56353 m .68502 .61573 L .67689 .59601 L F

.6878 .45091 m .67426 .47731 L .67547 .50891 L 0 0 .392 r

F

.68648 .41961 m .67426 .47731 L .6878 .45091 L F

.19191 .61007 m .21965 .6586 L .18887 .64295 L .881 .631 .555 r

F

.18887 .64295 m .24405 .65346 L .21965 .6586 L .638 .77 .943 r

F

0 g

.21965 .6586 m

.26138 .67153 L

s

.68633 .64854 m .7304 .63977 L .74213 .65814 L .638 .77 .943 r

F

.16946 .59197 m .19191 .61007 L .18887 .64295 L .939 .691 .535 r

F

0 g

.15604 .72802 m

.18138 .75155 L

s

.67547 .50891 m .67566 .56353 L .6767 .54107 L 0 0 .099 r

F

.6767 .54107 m .67566 .56353 L .67689 .59601 L F

.18887 .64295 m .2262 .63497 L .24405 .65346 L .638 .77 .943 r

F

.16727 .39265 m .1617 .42011 L .1584 .45142 L 0 0 .013 r

F

.17052 .36165 m .1617 .42011 L .16727 .39265 L F

.68648 .41961 m .6879 .45089 L .6878 .45091 L .59 .37 .55 r

F

.68648 .41961 m .68658 .41958 L .6879 .45089 L F

0 g

.68518 .38884 m

.68648 .41961 L

s

.67689 .59601 m .68633 .64854 L .67814 .62906 L .956 .706 .255 r

F

.67814 .62906 m .7304 .63977 L .68633 .64854 L .638 .77 .943 r

F

0 g

.68633 .64854 m

.70272 .66587 L

s

.68915 .48278 m .67547 .50891 L .6767 .54107 L 0 0 .392 r

F

.6878 .45091 m .67547 .50891 L .68915 .48278 L F

.16946 .59197 m .18887 .64295 L .1662 .62507 L .939 .691 .535 r

F

.1662 .62507 m .2262 .63497 L .18887 .64295 L .638 .77 .943 r

F

0 g

.18887 .64295 m

.21965 .6586 L

s

.67795 .57381 m .67689 .59601 L .67814 .62906 L 0 0 .099 r

F

.6767 .54107 m .67689 .59601 L .67795 .57381 L F

.17052 .36165 m .16737 .39262 L .16727 .39265 L .572 .341 .527 r

F

.17052 .36165 m .17062 .36162 L .16737 .39262 L F

0 g

.16495 .38935 m

.17052 .36165 L

s

.17062 .36162 m

.27502 .48444 L

s

.17052 .36165 m

.17052 .36165 L

s

.67814 .62906 m .71839 .62094 L .7304 .63977 L .638 .77 .943 r

F

.15454 .57163 m .16946 .59197 L .1662 .62507 L .989 .755 .486 r

F

.16396 .4242 m .1584 .45142 L .15503 .48328 L 0 0 .013 r

F

.16727 .39265 m .1584 .45142 L .16396 .4242 L F

.6878 .45091 m .68925 .48276 L .68915 .48278 L .59 .37 .55 r

F

.6878 .45091 m .6879 .45089 L .68925 .48276 L F

0 g

.68648 .41961 m

.6878 .45091 L

s

.1662 .62507 m .2079 .61603 L .2262 .63497 L .638 .77 .943 r

F

.68915 .48278 m .6767 .54107 L .69052 .51522 L 0 0 .392 r

F

.69052 .51522 m .6767 .54107 L .67795 .57381 L F

0 g

.08284 .21333 m

.75184 .0273 L

s

.02897 .61001 m

.08284 .21333 L

s

.67795 .57381 m .67814 .62906 L .67922 .60714 L 0 0 .099 r

F

.67922 .60714 m .71839 .62094 L .67814 .62906 L .638 .77 .943 r

F

0 g

.67814 .62906 m

.68633 .64854 L

s

.16727 .39265 m .16406 .42418 L .16396 .4242 L .572 .341 .527 r

F

.16727 .39265 m .16737 .39262 L .16406 .42418 L F

0 g

.16727 .39265 m

.17052 .36165 L

s

.15454 .57163 m .1662 .62507 L .1511 .60498 L .989 .755 .486 r

F

.1511 .60498 m .2079 .61603 L .1662 .62507 L .638 .77 .943 r

F

0 g

.1662 .62507 m

.18887 .64295 L

s

.16059 .45633 m .15503 .48328 L .1516 .51571 L 0 0 .013 r

F

.16396 .4242 m .15503 .48328 L .16059 .45633 L F

.68915 .48278 m .69062 .5152 L .69052 .51522 L .59 .37 .55 r

F

.68915 .48278 m .68925 .48276 L .69062 .5152 L F

0 g

.6878 .45091 m

.68915 .48278 L

s

.69192 .54825 m .67795 .57381 L .67922 .60714 L 0 0 .392 r


F

.69052 .51522 m .67795 .57381 L .69192 .54825 L F

.67922 .60714 m .70607 .60164 L .71839 .62094 L .638 .77 .943 r

F

.1511 .60498 m .18915 .59661 L .2079 .61603 L F

0 g

.02897 .61001 m

.15604 .72802 L

s

.16396 .4242 m .16069 .4563 L .16059 .45633 L .572 .341 .527 r

F

.16396 .4242 m .16406 .42418 L .16069 .4563 L F

0 g

.16396 .4242 m

.16727 .39265 L

s

.15716 .48904 m .1516 .51571 L .14811 .54873 L 0 0 .013 r

F

.16059 .45633 m .1516 .51571 L .15716 .48904 L F

.69052 .51522 m .69202 .54822 L .69192 .54825 L .59 .37 .55 r

F

.69052 .51522 m .69062 .5152 L .69202 .54822 L F

0 g

.68915 .48278 m

.69052 .51522 L

s

.69334 .58188 m .70607 .60164 L .67922 .60714 L .638 .77 .943 r

F

.69192 .54825 m .67922 .60714 L .69334 .58188 L 0 0 .392 r

F

0 g

.67814 .62906 m

.67922 .60714 L

s

.14811 .54873 m .1511 .60498 L .14456 .58236 L .966 .782 .346 r

F

.14456 .58236 m .18915 .59661 L .1511 .60498 L .638 .77 .943 r

F

0 g

.1511 .60498 m

.1662 .62507 L

s

.69334 .58188 m .69344 .58186 L .70607 .60164 L .638 .77 .943 r

F

.16059 .45633 m .15726 .48902 L .15716 .48904 L .572 .341 .527 r

F

.16059 .45633 m .16069 .4563 L .15726 .48902 L F

0 g

.16059 .45633 m

.16396 .4242 L

s

.15366 .52235 m .14811 .54873 L .14456 .58236 L 0 0 .013 r

F

.15716 .48904 m .14811 .54873 L .15366 .52235 L F

.14456 .58236 m .16992 .57669 L .18915 .59661 L .638 .77 .943 r

F

.69192 .54825 m .69344 .58186 L .69334 .58188 L .59 .37 .55 r

F

0 g

.67922 .60714 m

.69334 .58188 L

s

.69192 .54825 m .69202 .54822 L .69344 .58186 L .59 .37 .55 r

F

0 g

.69052 .51522 m

.69192 .54825 L

s

.68527 .38882 m

.69344 .58186 L

s

.69344 .58186 m

.76475 .69359 L

s

.69192 .54825 m

.69334 .58188 L

s

.15716 .48904 m .15376 .52233 L .15366 .52235 L .572 .341 .527 r

F

.15716 .48904 m .15726 .48902 L .15376 .52233 L F

0 g

.15716 .48904 m

.16059 .45633 L

s

.1501 .55629 m .16992 .57669 L .14456 .58236 L .638 .77 .943 r

F

.15366 .52235 m .14456 .58236 L .1501 .55629 L 0 0 .013 r

F

0 g

.14456 .58236 m

.1511 .60498 L

s

.1501 .55629 m .1502 .55627 L .16992 .57669 L .638 .77 .943 r

F

.15366 .52235 m .1502 .55627 L .1501 .55629 L .572 .341 .527 r

F

0 g

.14456 .58236 m

.1501 .55629 L

s

.15366 .52235 m .15376 .52233 L .1502 .55627 L .572 .341 .527 r

F

0 g

.15366 .52235 m

.15716 .48904 L

s

.1502 .55627 m

.17062 .36162 L

s

.1502 .55627 m

.26147 .67151 L

s

.1501 .55629 m

.15366 .52235 L

s

.78017 .44227 m

.75184 .0273 L

s

.78017 .44227 m

.02897 .61001 L

s

.25 Mabswid

.05984 .19796 m

.76386 0 L

s

.0751 .19367 m

.07937 .19884 L

s

[(0)] .06656 .18332 .8261 1 Mshowa

.28517 .1346 m

.28901 .1401 L

s

[(50)] .27748 .1236 .69865 1 Mshowa

.5082 .07188 m

.51153 .07771 L

s

[(100)] .50155 .06024 .57121 1 Mshowa

.74545 .00517 m

.74817 .0113 L

s

[(150)] .74001 -0.00708 .44377 1 Mshowa

.125 Mabswid

.11613 .18213 m

.11864 .18527 L

s

.15764 .17046 m

.16011 .17364 L

s

.19965 .15864 m

.20206 .16186 L

s

.24215 .14669 m

.24451 .14995 L

s

.3287 .12236 m

.33094 .1257 L

s

.37276 .10997 m

.37495 .11335 L

s

.41736 .09743 m

.41948 .10085 L

s

.4625 .08474 m

.46456 .08819 L

s

.55447 .05887 m

.5564 .06241 L

s

.60132 .0457 m

.60318 .04927 L

s

.64876 .03236 m

.65054 .03597 L

s

.6968 .01885 m

.69851 .0225 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
 ImageSize->{366.125, 342.375},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"},
 CellLabel->"From In[69]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 365.125}, {341.375, 0}} -> {-0.0506801, \
-0.0467876, 0.00575519, 0.00575519}, {{8.75, 174.25}, {333.188, 178.375}} -> \
{-0.128628, -0.0928678, 0.00642587, 0.00642587}, {{190.812, 356.312}, \
{333.188, 178.375}} -> {-1.29854, -0.0928678, 0.00642587, 0.00642587}, \
{{8.75, 174.25}, {162.938, 8.125}} -> {-0.128628, -1.18687, 0.00642587, \
0.00642587}, {{190.812, 356.312}, {162.938, 8.125}} -> {-1.29854, -1.18687, \
0.00642587, 0.00642587}}],

Cell[TextData[{
 "Rotation and twist angles with two-dimensional displacement.  Plot labels  \
show what input to ",
 StyleBox["Move", "MB"],
 " generated the graphic."
}], "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[{
 "The top-left graphic shows one-dimensional translation with ",
 StyleBox["Move", "MB"],
 ".  The top-right graphic shows two-dimensional translation.  Both cases  \
omit orientation parameters, which are optional.  The bottom-left graphic  \
shows how rotation angle works.  The component rotates 45 degrees about its  \
local ",
 StyleBox["z",
  FontSlant->"Italic"],
 "-axis.  The bottom-right graphic takes matters a step further, adding to  \
this initial rotation a twist angle of 45 degrees."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[{
 "In rare cases, you may wish to supply your own rotation matrix to ",
 StyleBox["Move", "MB"],
 ".  The function pattern for this type of call is ",
 StyleBox["Move[object,{x,y,z},R]", "MB"],
 " where ",
 StyleBox["R", "MB"],
 " is a 3 x 3 rotation matrix.  Generally under these circumstances you will  \
prefer to use ",
 StyleBox["Rotate", "MB"],
 "."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3.2 Rotate", "Subsection",
 CellTags->{"2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[TextData[{
 "The ",
 StyleBox["Rotate", "MB"],
 " function performs general rotations.  ",
 StyleBox["Rotate", "MB"],
 " can use a 3 x 3 rotation matrix of your design, but is even more general,  \
for it can rotate objects about an arbitrary axis. A 3 x 3 transformation can \
 only rotate about an axis through the origin. Such rotations happen when  \
mechanical alignment issues prevent exact placement of components at some  \
rotation center."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[TextData[{
 "The primary calling pattern accepts three parameters:  angle of rotation,  \
axis direction vector, and axis center position. The angle specifies the  \
amount of rotation.  The direction and center define a line in space that is  \
the axis of rotation. The center is a point on the line, while the direction  \
fixes its attitude.  When omitted, these parameters adopt default values of  ",
 StyleBox["{1,0,0}", "MB"],
 " for the direction vector and ",
 StyleBox["{0,0,0}", "MB"],
 " for the center.  This default is a vertical line through the origin."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell["The figure below shows how the defaults operate.", "Text",
 PageBreakAbove->True,
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1.1463 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.0272929 0.47619 [

[ 0 0 0 0 ]

[ 1 1.1463 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 1.1463 L

0 1.1463 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.0272929 0.477324 0.547157 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-9.04587e-05 1.06704 1.66533e-16 1.06704 [

[.5 .99171 -50.4 0 ]

[.5 .99171 50.4 16.8 ]

[.1102 .17291 -4.29846 -7.2 ]

[.1102 .17291 .50154 0 ]

[.29667 .11985 -4.0344 -7.2 ]

[.29667 .11985 .7656 0 ]

[.49322 .06399 -7.5407 -7.2 ]

[.49322 .06399 2.0593 0 ]

[.70067 .00511 -7.0126 -7.2 ]

[.70067 .00511 2.5874 0 ]

[.78608 .01052 0 -4.6103 ]

[.78608 .01052 14.4 2.5897 ]

[.84724 .15297 0 -4.53709 ]

[.84724 .15297 9.6 2.66291 ]

[.90091 .27799 0 -4.47378 ]

[.90091 .27799 4.8 2.72622 ]

[.94839 .38859 0 -4.41848 ]

[.94839 .38859 4.8 2.78152 ]

[.04416 .27461 -9.6 -2.61825 ]

[.04416 .27461 0 4.58175 ]

[.02049 .44328 -4.8 -2.70141 ]

[.02049 .44328 0 4.49859 ]

[-0.00565 .62954 -4.8 -2.79389 ]

[-0.00565 .62954 0 4.40611 ]

[ 0 0 0 0 ]

[ 1 .97921 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Rotate[object,)( 30,{0,0,1},{12,0,0}])] .5 .99171 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.06726 .19785 m

.76718 0 L

s

.11847 .18337 m

.12261 .1886 L

s

[(0)] .1102 .17291 .79102 1 Mshowa

.30418 .13088 m

.30793 .13639 L

s

[(5)] .29667 .11985 .681 1 Mshowa

.49983 .07557 m

.50314 .08136 L

s

[(10)] .49322 .06399 .57098 1 Mshowa

.70625 .01722 m

.70904 .02328 L

s

[(15)] .70067 .00511 .46096 1 Mshowa

.125 Mabswid

.15486 .17309 m

.1573 .17626 L

s

.19161 .1627 m

.19401 .1659 L

s

.22875 .1522 m

.2311 .15544 L

s

.26627 .14159 m

.26857 .14487 L

s

.34249 .12005 m

.34469 .12339 L

s

.3812 .1091 m

.38335 .11248 L

s

.42033 .09805 m

.42242 .10145 L

s

.45987 .08687 m

.46191 .09031 L

s

.54023 .06415 m

.54215 .06766 L

s

.58106 .05261 m

.58292 .05615 L

s

.62233 .04094 m

.62414 .04451 L

s

.66406 .02915 m

.6658 .03275 L

s

.08246 .19355 m

.08498 .19666 L

s

.7489 .00516 m

.75051 .00883 L

s

.25 Mabswid

.76718 0 m

.94771 .42025 L

s

.77324 .01412 m

.76682 .01592 L

s

[(-10)] .78608 .01052 -1 .28064 Mshowa

.83433 .15633 m

.82788 .15801 L

s

[(-5)] .84724 .15297 -1 .2603 Mshowa

.88795 .28113 m

.88147 .28271 L

s

[(0)] .90091 .27799 -1 .24272 Mshowa

.93538 .39155 m

.92888 .39302 L

s

[(5)] .94839 .38859 -1 .22736 Mshowa

.125 Mabswid

.78613 .04413 m

.78228 .04519 L

s

.79867 .07332 m

.79481 .07437 L

s

.81088 .10173 m

.80701 .10276 L

s

.82276 .12939 m

.81889 .13041 L

s

.84561 .18257 m

.84173 .18357 L

s

.8566 .20815 m

.85272 .20913 L

s

.86731 .23309 m

.86343 .23406 L

s

.87776 .25741 m

.87387 .25836 L

s

.8979 .30428 m

.894 .30521 L

s

.9076 .32688 m

.90371 .3278 L

s

.91708 .34894 m

.91319 .34985 L

s

.92634 .37049 m

.92244 .37139 L

s

.94422 .41212 m

.94032 .41299 L

s

.25 Mabswid

.06726 .19785 m

0 .67937 L

s

.05703 .2711 m

.06347 .26934 L

s

[(-5)] .04416 .27461 1 -0.27271 Mshowa

.03343 .44005 m

.0399 .43844 L

s

[(0)] .02049 .44328 1 -0.24961 Mshowa

.00737 .62662 m

.01388 .62517 L

s

[(5)] -0.00565 .62954 1 -0.22392 Mshowa

.125 Mabswid

.05249 .3036 m

.05636 .30256 L

s

.04786 .33673 m

.05173 .33571 L

s

.04315 .3705 m

.04702 .3695 L

s

.03834 .40494 m

.04221 .40395 L

s

.02843 .47587 m

.03231 .47492 L

s

.02332 .51242 m

.02721 .51149 L

s

.01811 .54971 m

.02201 .54879 L

s

.0128 .58777 m

.0167 .58687 L

s

.06149 .2392 m

.06534 .23813 L

s

.06586 .2079 m

.06971 .20681 L

s

.00183 .6663 m

.00574 .66544 L

s

0 0 m

1 0 L

1 .97921 L

0 .97921 L

closepath

clip

newpath

.50315 .55749 m .49831 .54076 L .43555 .55461 L .659 .747 .915 r

F

.50315 .55749 m .50954 .5561 L .49831 .54076 L F

.50295 .58242 m .50954 .5561 L .50315 .55749 L .607 .398 .572 r

F

.43555 .55461 m .50315 .55749 L .50295 .58242 L .713 .485 .577 r

F

0 g

.5 Mabswid

.50315 .55749 m

.50315 .55749 L

s

.50295 .58242 m .50938 .58103 L .50954 .5561 L .607 .398 .572 r

F

.43555 .55461 m .48687 .52514 L .39457 .54573 L .659 .747 .915 r

F

.43555 .55461 m .49831 .54076 L .48687 .52514 L F

.43555 .55461 m .50295 .58242 L .43489 .57956 L .713 .485 .577 r

F

.39457 .54573 m .43555 .55461 L .43489 .57956 L .776 .538 .575 r

F

.43489 .57956 m .50295 .58242 L .50274 .60768 L .713 .485 .577 r

F

.50274 .60768 m .50938 .58103 L .50295 .58242 L .607 .398 .572 r

F

.39457 .54573 m .4752 .50921 L .36342 .53443 L .659 .747 .915 r

F

.39457 .54573 m .48687 .52514 L .4752 .50921 L F

.39457 .54573 m .43489 .57956 L .39362 .57076 L .776 .538 .575 r

F

.50274 .60768 m .50922 .60631 L .50938 .58103 L .607 .398 .572 r

F

.43489 .57956 m .50274 .60768 L .43422 .60485 L .713 .485 .577 r

F

.39362 .57076 m .43489 .57956 L .43422 .60485 L .776 .538 .575 r

F

.50253 .63329 m .50922 .60631 L .50274 .60768 L .607 .398 .572 r

F

.43422 .60485 m .50274 .60768 L .50253 .63329 L .713 .485 .577 r

F

.39362 .57076 m .43422 .60485 L .39267 .59612 L .776 .538 .575 r

F

.36342 .53443 m .46332 .49298 L .33854 .52145 L .659 .747 .915 r

F

.36342 .53443 m .4752 .50921 L .46332 .49298 L F

.50253 .63329 m .50905 .63193 L .50922 .60631 L .607 .398 .572 r

F

.43422 .60485 m .50253 .63329 L .43354 .63048 L .713 .485 .577 r

F

.39267 .59612 m .43422 .60485 L .43354 .63048 L .776 .538 .575 r

F

.50232 .65925 m .50905 .63193 L .50253 .63329 L .607 .398 .572 r

F

.43354 .63048 m .50253 .63329 L .50232 .65925 L .713 .485 .577 r

F

.50232 .65925 m .50888 .6579 L .50905 .63193 L .607 .398 .572 r

F

.33854 .52145 m .4512 .47644 L .31855 .50704 L .659 .747 .915 r

F

.33854 .52145 m .46332 .49298 L .4512 .47644 L F

.43354 .63048 m .50232 .65925 L .43285 .65647 L .713 .485 .577 r

F

.5021 .68557 m .50888 .6579 L .50232 .65925 L .607 .398 .572 r

F

.43285 .65647 m .50232 .65925 L .5021 .68557 L .713 .485 .577 r

F

.5021 .68557 m .50871 .68424 L .50888 .6579 L .607 .398 .572 r

F

.43285 .65647 m .5021 .68557 L .43216 .68282 L .713 .485 .577 r

F

.31855 .50704 m .43885 .45957 L .30289 .4913 L .659 .747 .915 r

F

.31855 .50704 m .4512 .47644 L .43885 .45957 L F

.50188 .71225 m .50871 .68424 L .5021 .68557 L .607 .398 .572 r

F

.43216 .68282 m .5021 .68557 L .50188 .71225 L .713 .485 .577 r

F

.50188 .71225 m .50854 .71094 L .50871 .68424 L .607 .398 .572 r

F

.43216 .68282 m .50188 .71225 L .43145 .70953 L .713 .485 .577 r

F

.30289 .4913 m .42625 .44236 L .29147 .47418 L .659 .747 .915 r

F

.30289 .4913 m .43885 .45957 L .42625 .44236 L F

.50166 .73931 m .50854 .71094 L .50188 .71225 L .607 .398 .572 r

F

.43145 .70953 m .50188 .71225 L .50166 .73931 L .713 .485 .577 r

F

.50166 .73931 m .50836 .73801 L .50854 .71094 L .607 .398 .572 r

F

.43145 .70953 m .50166 .73931 L .43073 .73663 L .713 .485 .577 r

F

.43073 .73663 m .50166 .73931 L .50144 .76676 L F

.50144 .76676 m .50836 .73801 L .50166 .73931 L .607 .398 .572 r

F

.50144 .76676 m .50819 .76547 L .50836 .73801 L F

.29147 .47418 m .41339 .42481 L .28458 .45558 L .659 .747 .915 r

F

.29147 .47418 m .42625 .44236 L .41339 .42481 L F

.43073 .73663 m .50144 .76676 L .43 .7641 L .713 .485 .577 r

F

.50121 .79459 m .50819 .76547 L .50144 .76676 L .607 .398 .572 r

F

.43 .7641 m .50144 .76676 L .50121 .79459 L .713 .485 .577 r

F

.50121 .79459 m .50801 .79332 L .50819 .76547 L .607 .398 .572 r

F

.43 .7641 m .50121 .79459 L .42926 .79197 L .713 .485 .577 r

F

.28458 .45558 m .40028 .40691 L .28302 .43526 L .659 .747 .915 r

F

.28458 .45558 m .41339 .42481 L .40028 .40691 L F

.42926 .79197 m .50121 .79459 L .50098 .82283 L .713 .485 .577 r

F

.50098 .82283 m .50801 .79332 L .50121 .79459 L .607 .398 .572 r

F

.50098 .82283 m .50782 .82158 L .50801 .79332 L F

.42926 .79197 m .50098 .82283 L .42851 .82024 L .713 .485 .577 r

F

.37797 .44317 m .38532 .4438 L .38844 .42516 L .659 .747 .915 r

F

.36342 .53443 m .39457 .54573 L .39362 .57076 L .822 .578 .571 r

F

.36226 .55955 m .39362 .57076 L .39267 .59612 L F

.36342 .53443 m .39362 .57076 L .36226 .55955 L F

.36108 .58502 m .39267 .59612 L .3917 .62184 L F

.36226 .55955 m .39267 .59612 L .36108 .58502 L F

.35989 .61083 m .3917 .62184 L .39072 .64791 L F

.36108 .58502 m .3917 .62184 L .35989 .61083 L F

.35868 .63701 m .39072 .64791 L .38972 .67434 L F

.35989 .61083 m .39072 .64791 L .35868 .63701 L F

.35745 .66356 m .38972 .67434 L .38871 .70115 L F

.35868 .63701 m .38972 .67434 L .35745 .66356 L F

.35745 .66356 m .38871 .70115 L .3562 .69048 L F

.3562 .69048 m .38871 .70115 L .38769 .72834 L F

.35494 .71779 m .38769 .72834 L .38665 .75591 L F

.3562 .69048 m .38769 .72834 L .35494 .71779 L F

.35366 .74549 m .38665 .75591 L .38559 .78388 L F

.35494 .71779 m .38665 .75591 L .35366 .74549 L F

.35236 .77359 m .38559 .78388 L .38452 .81226 L F

.35366 .74549 m .38559 .78388 L .35236 .77359 L F

.38255 .66381 m .38532 .4438 L .37139 .78067 L 0 0 .094 r

F

.42851 .82024 m .50098 .82283 L .50074 .85147 L .713 .485 .577 r

F

.50074 .85147 m .50782 .82158 L .50098 .82283 L .607 .398 .572 r

F

.50074 .85147 m .50764 .85024 L .50782 .82158 L F

.42851 .82024 m .50074 .85147 L .42775 .84892 L .713 .485 .577 r

F

.42775 .84892 m .50074 .85147 L .5005 .88053 L F

.5005 .88053 m .50764 .85024 L .50074 .85147 L .607 .398 .572 r

F

.5005 .88053 m .50745 .87932 L .50764 .85024 L F

.39055 .46237 m .50954 .5561 L .50745 .87932 L .982 .726 .465 r

F

.28302 .43526 m .40028 .40691 L .3869 .38864 L .659 .747 .915 r

F

.39313 .39715 m .50954 .5561 L .39055 .46237 L .982 .726 .465 r

F

.39313 .39715 m .38532 .4438 L .38255 .66381 L 0 0 .094 r

F

.33854 .52145 m .36342 .53443 L .36226 .55955 L .864 .617 .563 r

F

.39267 .59612 m .43354 .63048 L .3917 .62184 L .776 .538 .575 r

F

.3372 .54668 m .36226 .55955 L .36108 .58502 L .864 .617 .563 r

F

.33854 .52145 m .36226 .55955 L .3372 .54668 L F

.3917 .62184 m .43354 .63048 L .43285 .65647 L .776 .538 .575 r

F

.3917 .62184 m .43285 .65647 L .39072 .64791 L F

.33584 .57225 m .36108 .58502 L .35989 .61083 L .864 .617 .563 r

F

.3372 .54668 m .36108 .58502 L .33584 .57225 L F

.39072 .64791 m .43285 .65647 L .43216 .68282 L .776 .538 .575 r

F

.39072 .64791 m .43216 .68282 L .38972 .67434 L F

.33446 .59819 m .35989 .61083 L .35868 .63701 L .864 .617 .563 r

F

.33584 .57225 m .35989 .61083 L .33446 .59819 L F

.38972 .67434 m .43216 .68282 L .43145 .70953 L .776 .538 .575 r

F

.38972 .67434 m .43145 .70953 L .38871 .70115 L F

.33306 .62449 m .35868 .63701 L .35745 .66356 L .864 .617 .563 r

F

.33446 .59819 m .35868 .63701 L .33306 .62449 L F

.38871 .70115 m .43145 .70953 L .43073 .73663 L .776 .538 .575 r

F

.38871 .70115 m .43073 .73663 L .38769 .72834 L F

.33164 .65116 m .35745 .66356 L .3562 .69048 L .864 .617 .563 r

F

.33306 .62449 m .35745 .66356 L .33164 .65116 L F

.38769 .72834 m .43073 .73663 L .43 .7641 L .776 .538 .575 r

F

.38769 .72834 m .43 .7641 L .38665 .75591 L F

.3302 .67821 m .3562 .69048 L .35494 .71779 L .864 .617 .563 r

F

.33164 .65116 m .3562 .69048 L .3302 .67821 L F

.38665 .75591 m .43 .7641 L .42926 .79197 L .776 .538 .575 r

F

.38665 .75591 m .42926 .79197 L .38559 .78388 L F

.3302 .67821 m .35494 .71779 L .32874 .70566 L .864 .617 .563 r

F

.38559 .78388 m .42926 .79197 L .42851 .82024 L .776 .538 .575 r

F

.37685 .46902 m .38532 .4438 L .37797 .44317 L .729 .489 .564 r

F

.37685 .46902 m .38425 .46965 L .38532 .4438 L F

.37797 .44317 m .38844 .42516 L .3153 .41875 L .659 .747 .915 r

F

.28302 .43526 m .3869 .38864 L .2885 .41272 L F

.3153 .41875 m .37797 .44317 L .37685 .46902 L .83 .578 .558 r

F

.37571 .49524 m .38425 .46965 L .37685 .46902 L .729 .489 .564 r

F

.37571 .49524 m .38317 .49587 L .38425 .46965 L F

.31371 .44479 m .37685 .46902 L .37571 .49524 L .83 .578 .558 r

F

.3153 .41875 m .37685 .46902 L .31371 .44479 L F

.3153 .41875 m .38844 .42516 L .39163 .40611 L .659 .747 .915 r

F

.3153 .41875 m .39163 .40611 L .28316 .39651 L F

.37456 .52185 m .38317 .49587 L .37571 .49524 L .729 .489 .564 r

F

.37456 .52185 m .38207 .52247 L .38317 .49587 L F

.31371 .44479 m .37571 .49524 L .31209 .47121 L .83 .578 .558 r

F

.31209 .47121 m .37571 .49524 L .37456 .52185 L F

.2885 .41272 m .37325 .37 L .30523 .38684 L .659 .747 .915 r

F

.2885 .41272 m .3869 .38864 L .37325 .37 L F

.28316 .39651 m .39163 .40611 L .39489 .38665 L F

.37339 .54885 m .38207 .52247 L .37456 .52185 L .729 .489 .564 r

F

.37339 .54885 m .38095 .54947 L .38207 .52247 L F

.31044 .49802 m .37456 .52185 L .37339 .54885 L .83 .578 .558 r

F

.31209 .47121 m .37456 .52185 L .31044 .49802 L F

.28316 .39651 m .39489 .38665 L .26265 .37482 L .659 .747 .915 r

F

.3722 .57626 m .38095 .54947 L .37339 .54885 L .729 .489 .564 r

F

.3722 .57626 m .37982 .57687 L .38095 .54947 L F

.31855 .50704 m .33854 .52145 L .3372 .54668 L .907 .657 .55 r

F

.31706 .53239 m .3372 .54668 L .33584 .57225 L F

.31855 .50704 m .3372 .54668 L .31706 .53239 L F

.30289 .4913 m .31855 .50704 L .31706 .53239 L .95 .701 .526 r

F

.30128 .51677 m .31706 .53239 L .31554 .55809 L F

.30289 .4913 m .31706 .53239 L .30128 .51677 L F

.30878 .52523 m .37339 .54885 L .3722 .57626 L .83 .578 .558 r

F

.31044 .49802 m .37339 .54885 L .30878 .52523 L F

.30523 .38684 m .37325 .37 L .35931 .35096 L .659 .747 .915 r

F

.26265 .37482 m .39489 .38665 L .39822 .36676 L F

.37099 .60407 m .37982 .57687 L .3722 .57626 L .729 .489 .564 r

F

.37099 .60407 m .37867 .60468 L .37982 .57687 L F

.31554 .55809 m .33584 .57225 L .33446 .59819 L .907 .657 .55 r

F

.31706 .53239 m .33584 .57225 L .31554 .55809 L F

.31554 .55809 m .33446 .59819 L .31401 .58415 L F

.29964 .5426 m .31554 .55809 L .31401 .58415 L .95 .701 .526 r

F

.30128 .51677 m .31554 .55809 L .29964 .5426 L F

.30708 .55285 m .3722 .57626 L .37099 .60407 L .83 .578 .558 r

F

.30878 .52523 m .3722 .57626 L .30708 .55285 L F

.26265 .37482 m .39822 .36676 L .24982 .35333 L .659 .747 .915 r

F

.24982 .35333 m .39822 .36676 L .40163 .34642 L F

.36976 .63231 m .37867 .60468 L .37099 .60407 L .729 .489 .564 r

F

.36976 .63231 m .3775 .6329 L .37867 .60468 L F

.29797 .5688 m .31401 .58415 L .31245 .61059 L .95 .701 .526 r

F

.29964 .5426 m .31401 .58415 L .29797 .5688 L F

.30708 .55285 m .37099 .60407 L .30536 .58089 L .83 .578 .558 r

F

.31401 .58415 m .33446 .59819 L .33306 .62449 L .907 .657 .55 r

F

.31401 .58415 m .33306 .62449 L .31245 .61059 L F

.30536 .58089 m .37099 .60407 L .36976 .63231 L .83 .578 .558 r

F

.36852 .66097 m .3775 .6329 L .36976 .63231 L .729 .489 .564 r

F

.36852 .66097 m .37632 .66156 L .3775 .6329 L F

.31245 .61059 m .33306 .62449 L .33164 .65116 L .907 .657 .55 r

F

.31245 .61059 m .33164 .65116 L .31087 .6374 L F

.29628 .59538 m .31245 .61059 L .31087 .6374 L .95 .701 .526 r

F

.30362 .60936 m .36976 .63231 L .36852 .66097 L .83 .578 .558 r

F

.29797 .5688 m .31245 .61059 L .29628 .59538 L .95 .701 .526 r

F

.30536 .58089 m .36976 .63231 L .30362 .60936 L .83 .578 .558 r

F

.36726 .69007 m .37632 .66156 L .36852 .66097 L .729 .489 .564 r

F

.36726 .69007 m .37512 .69065 L .37632 .66156 L F

.31087 .6374 m .33164 .65116 L .3302 .67821 L .907 .657 .55 r

F

.31087 .6374 m .3302 .67821 L .30927 .66459 L F

.29457 .62234 m .31087 .6374 L .30927 .66459 L .95 .701 .526 r

F

.30185 .63827 m .36852 .66097 L .36726 .69007 L .83 .578 .558 r

F

.29628 .59538 m .31087 .6374 L .29457 .62234 L .95 .701 .526 r

F

.30362 .60936 m .36852 .66097 L .30185 .63827 L .83 .578 .558 r

F

.36597 .71962 m .37512 .69065 L .36726 .69007 L .729 .489 .564 r

F

.36597 .71962 m .37389 .7202 L .37512 .69065 L F

.30927 .66459 m .3302 .67821 L .32874 .70566 L .907 .657 .55 r

F

.30927 .66459 m .32874 .70566 L .30764 .69218 L F

.29284 .64969 m .30927 .66459 L .30764 .69218 L .95 .701 .526 r

F

.30005 .66763 m .36726 .69007 L .36597 .71962 L .83 .578 .558 r

F

.29457 .62234 m .30927 .66459 L .29284 .64969 L .95 .701 .526 r

F

.30185 .63827 m .36726 .69007 L .30005 .66763 L .83 .578 .558 r

F

.36467 .74963 m .37389 .7202 L .36597 .71962 L .729 .489 .564 r

F

.36467 .74963 m .37265 .7502 L .37389 .7202 L F

.32874 .70566 m .35494 .71779 L .35366 .74549 L .864 .617 .563 r

F

.32874 .70566 m .35366 .74549 L .32725 .7335 L F

.30764 .69218 m .32874 .70566 L .32725 .7335 L .907 .657 .55 r

F

.30764 .69218 m .32725 .7335 L .30599 .72018 L F

.29107 .67744 m .30764 .69218 L .30599 .72018 L .95 .701 .526 r

F

.29822 .69745 m .36597 .71962 L .36467 .74963 L .83 .578 .558 r

F

.29284 .64969 m .30764 .69218 L .29107 .67744 L .95 .701 .526 r

F

.30005 .66763 m .36597 .71962 L .29822 .69745 L .83 .578 .558 r

F

.35931 .35096 m .39055 .46237 L .34198 .69822 L .982 .726 .465 r

F

.39055 .46237 m .50745 .87932 L .37956 .73934 L F

.38255 .66381 m .37139 .78067 L .37956 .73934 L 0 0 .094 r

F

.39055 .46237 m .37956 .73934 L .34198 .69822 L .982 .726 .465 r

F

.42776 .19038 m .38255 .66381 L .41623 .55363 L 0 0 .094 r

F

.38255 .66381 m .37956 .73934 L .41623 .55363 L F

.42776 .19038 m .39313 .39715 L .38255 .66381 L F

.35931 .35096 m .39313 .39715 L .39055 .46237 L .982 .726 .465 r

F

0 g

.42004 .43388 m

.50954 .5561 L

s

.52291 .51598 m

.9301 .42506 L

s

.48617 .52418 m

.52291 .51598 L

s

.34673 .95966 m

.35506 .77683 L

s

.7558 .02958 m

.9301 .42506 L

s

.9301 .42506 m

.97777 .85348 L

s

.29147 .47418 m .30289 .4913 L .30128 .51677 L .987 .746 .481 r

F

0 g

.30289 .4913 m

.31039 .49884 L

s

.28976 .49979 m .30128 .51677 L .29964 .5426 L .987 .746 .481 r

F

.29147 .47418 m .30128 .51677 L .28976 .49979 L F

.28458 .45558 m .29147 .47418 L .28976 .49979 L .989 .774 .387 r

F

0 g

.29147 .47418 m

.30289 .4913 L

s

.28802 .52577 m .29964 .5426 L .29797 .5688 L .987 .746 .481 r

F

.28976 .49979 m .29964 .5426 L .28802 .52577 L F

.2828 .48134 m .28976 .49979 L .28802 .52577 L .989 .774 .387 r

F

.28458 .45558 m .28976 .49979 L .2828 .48134 L F

0 g

.52172 .93022 m

.97777 .85348 L

s

.34673 .95966 m

.52172 .93022 L

s

.28302 .43526 m .28458 .45558 L .2828 .48134 L .859 .714 .189 r

F

0 g

.28458 .45558 m

.29147 .47418 L

s

.28625 .55212 m .29797 .5688 L .29628 .59538 L .987 .746 .481 r

F

.28802 .52577 m .29797 .5688 L .28625 .55212 L F

.28099 .50747 m .28802 .52577 L .28625 .55212 L .989 .774 .387 r

F

.2828 .48134 m .28802 .52577 L .28099 .50747 L F

.2812 .46117 m .2828 .48134 L .28099 .50747 L .859 .714 .189 r

F

.28302 .43526 m .2828 .48134 L .2812 .46117 L F

.28446 .57885 m .29628 .59538 L .29457 .62234 L .987 .746 .481 r

F

.28625 .55212 m .29628 .59538 L .28446 .57885 L F

.38559 .78388 m .42851 .82024 L .38452 .81226 L .776 .538 .575 r

F

.32725 .7335 m .35366 .74549 L .35236 .77359 L .864 .617 .563 r

F

.27915 .53397 m .28625 .55212 L .28446 .57885 L .989 .774 .387 r

F

.28099 .50747 m .28625 .55212 L .27915 .53397 L F

.38452 .81226 m .42851 .82024 L .42775 .84892 L .776 .538 .575 r

F

.2885 .41272 m .28302 .43526 L .2812 .46117 L 0 0 .116 r

F

0 g

.28372 .44443 m

.28458 .45558 L

s

.27234 .43746 m

.28203 .44931 L

s

.27936 .48745 m .28099 .50747 L .27915 .53397 L .859 .714 .189 r

F

.2812 .46117 m .28099 .50747 L .27936 .48745 L F

.28265 .60597 m .29457 .62234 L .29284 .64969 L .987 .746 .481 r

F

.28446 .57885 m .29457 .62234 L .28265 .60597 L F

.38452 .81226 m .42775 .84892 L .38344 .84105 L .776 .538 .575 r

F

.35104 .80209 m .38452 .81226 L .38344 .84105 L .822 .578 .571 r

F

.35236 .77359 m .38452 .81226 L .35104 .80209 L F

.32575 .76174 m .35236 .77359 L .35104 .80209 L .864 .617 .563 r

F

.32725 .7335 m .35236 .77359 L .32575 .76174 L F

.30599 .72018 m .32725 .7335 L .32575 .76174 L .907 .657 .55 r

F

.27729 .56087 m .28446 .57885 L .28265 .60597 L .989 .774 .387 r

F

.27915 .53397 m .28446 .57885 L .27729 .56087 L F

.42775 .84892 m .5005 .88053 L .42698 .87802 L .713 .485 .577 r

F

.38344 .84105 m .42775 .84892 L .42698 .87802 L .776 .538 .575 r

F

.2867 .43879 m .2812 .46117 L .27936 .48745 L 0 0 .116 r

F

.2885 .41272 m .2812 .46117 L .2867 .43879 L F

.29292 .42136 m .2885 .41272 L .2867 .43879 L 0 0 .36 r

F

.29349 .41284 m .3153 .41875 L .31371 .44479 L .903 .647 .541 r

F

.29409 .40407 m .3153 .41875 L .29349 .41284 L F

.29409 .40407 m .2885 .41272 L .29292 .42136 L 0 0 .36 r

F

.28316 .39651 m .29349 .41284 L .2813 .42271 L .903 .647 .541 r

F

.29349 .41284 m .31371 .44479 L .29232 .43021 L F

.30523 .38684 m .29292 .42136 L .30353 .41311 L 0 0 .36 r

F

.29292 .42136 m .2867 .43879 L .29232 .43021 L F

.29292 .42136 m .29232 .43021 L .30353 .41311 L F

.29172 .43912 m .31371 .44479 L .31209 .47121 L .903 .647 .541 r

F

.29232 .43021 m .2867 .43879 L .29114 .44776 L 0 0 .36 r

F

.2813 .42271 m .29232 .43021 L .29172 .43912 L .903 .647 .541 r

F

.29232 .43021 m .31371 .44479 L .29172 .43912 L F

.29349 .41284 m .29232 .43021 L .2813 .42271 L F

.29114 .44776 m .2867 .43879 L .28487 .46526 L 0 0 .36 r

F

.2867 .43879 m .27936 .48745 L .28487 .46526 L 0 0 .116 r

F

.2813 .42271 m .29172 .43912 L .27942 .4493 L .903 .647 .541 r

F

.29172 .43912 m .31209 .47121 L .29053 .45675 L F

.30353 .41311 m .29114 .44776 L .30181 .43977 L 0 0 .36 r

F

.29114 .44776 m .28487 .46526 L .29053 .45675 L F

.29114 .44776 m .29053 .45675 L .30181 .43977 L F

.28992 .46578 m .31209 .47121 L .31044 .49802 L .903 .647 .541 r

F

.29053 .45675 m .28487 .46526 L .28933 .47455 L 0 0 .36 r

F

.27942 .4493 m .29053 .45675 L .28992 .46578 L .903 .647 .541 r

F

.29053 .45675 m .31209 .47121 L .28992 .46578 L F

.29172 .43912 m .29053 .45675 L .27942 .4493 L F

.28933 .47455 m .28487 .46526 L .28302 .49212 L 0 0 .36 r

F

.27936 .48745 m .27915 .53397 L .27749 .51413 L .859 .714 .189 r

F

.28487 .46526 m .27936 .48745 L .27749 .51413 L 0 0 .116 r

F

.28487 .46526 m .27749 .51413 L .28302 .49212 L F

.27942 .4493 m .28992 .46578 L .27751 .47628 L .903 .647 .541 r

F

.28992 .46578 m .31044 .49802 L .28871 .48367 L F

.30181 .43977 m .28933 .47455 L .30005 .46683 L 0 0 .36 r

F

.28933 .47455 m .28302 .49212 L .28871 .48367 L F

.28933 .47455 m .28871 .48367 L .30005 .46683 L F

.28809 .49285 m .31044 .49802 L .30878 .52523 L .903 .647 .541 r

F

.28871 .48367 m .28302 .49212 L .28749 .50175 L 0 0 .36 r

F

.27751 .47628 m .28871 .48367 L .28809 .49285 L .903 .647 .541 r

F

.28871 .48367 m .31044 .49802 L .28809 .49285 L F

.28992 .46578 m .28871 .48367 L .27751 .47628 L F

.28749 .50175 m .28302 .49212 L .28114 .51938 L 0 0 .36 r

F

.27749 .51413 m .27915 .53397 L .27729 .56087 L .859 .714 .189 r

F

.27749 .51413 m .27729 .56087 L .2756 .5412 L F

.28302 .49212 m .27749 .51413 L .2756 .5412 L 0 0 .116 r

F

.28302 .49212 m .2756 .5412 L .28114 .51938 L F

.27751 .47628 m .28809 .49285 L .27557 .50368 L .903 .647 .541 r

F

.28809 .49285 m .30878 .52523 L .28686 .51101 L F

.30005 .46683 m .28749 .50175 L .29828 .49431 L 0 0 .36 r

F

.28749 .50175 m .28114 .51938 L .28686 .51101 L F

.28749 .50175 m .28686 .51101 L .29828 .49431 L F

.28623 .52032 m .30878 .52523 L .30708 .55285 L .903 .647 .541 r

F

.28686 .51101 m .28114 .51938 L .28562 .52935 L 0 0 .36 r

F

.27557 .50368 m .28686 .51101 L .28623 .52032 L .903 .647 .541 r

F

.28686 .51101 m .30878 .52523 L .28623 .52032 L F

.28809 .49285 m .28686 .51101 L .27557 .50368 L F

.28562 .52935 m .28114 .51938 L .27923 .54705 L 0 0 .36 r

F

.2756 .5412 m .27729 .56087 L .2754 .58816 L .859 .714 .189 r

F

.2756 .5412 m .2754 .58816 L .27367 .56868 L F

.28114 .51938 m .2756 .5412 L .27367 .56868 L 0 0 .116 r

F

.28114 .51938 m .27367 .56868 L .27923 .54705 L F

.27557 .50368 m .28623 .52032 L .2736 .5315 L .903 .647 .541 r

F

.28623 .52032 m .30708 .55285 L .28499 .53876 L F

.29828 .49431 m .28562 .52935 L .29647 .52221 L 0 0 .36 r

F

.28562 .52935 m .27923 .54705 L .28499 .53876 L F

.28562 .52935 m .28499 .53876 L .29647 .52221 L F

.28435 .54821 m .30708 .55285 L .30536 .58089 L .903 .647 .541 r

F

.28499 .53876 m .27923 .54705 L .28373 .55739 L 0 0 .36 r

F

.2736 .5315 m .28499 .53876 L .28435 .54821 L .903 .647 .541 r

F

.28499 .53876 m .30708 .55285 L .28435 .54821 L F

.28623 .52032 m .28499 .53876 L .2736 .5315 L F

.27729 .56087 m .28265 .60597 L .2754 .58816 L .989 .774 .387 r

F

.28373 .55739 m .27923 .54705 L .2773 .57515 L 0 0 .36 r

F

.27367 .56868 m .2754 .58816 L .27349 .61585 L .859 .714 .189 r

F

.27367 .56868 m .27349 .61585 L .27172 .59656 L F

.27923 .54705 m .27367 .56868 L .27172 .59656 L 0 0 .116 r

F

.27923 .54705 m .27172 .59656 L .2773 .57515 L F

.2736 .5315 m .28435 .54821 L .2716 .55974 L .903 .647 .541 r

F

.28435 .54821 m .30536 .58089 L .28308 .56693 L F

.28373 .55739 m .2773 .57515 L .28308 .56693 L 0 0 .36 r

F

.28435 .54821 m .28308 .56693 L .2716 .55974 L .903 .647 .541 r

F

.29647 .52221 m .28373 .55739 L .29464 .55054 L 0 0 .36 r

F

.28373 .55739 m .28308 .56693 L .29464 .55054 L F

.29647 .52221 m .28499 .53876 L .28373 .55739 L F

.29828 .49431 m .28686 .51101 L .28562 .52935 L F

.30005 .46683 m .28871 .48367 L .28749 .50175 L F

.30181 .43977 m .29053 .45675 L .28933 .47455 L F

.30353 .41311 m .29232 .43021 L .29114 .44776 L F

.30523 .38684 m .29409 .40407 L .29292 .42136 L F

.28316 .39651 m .29409 .40407 L .29349 .41284 L .903 .647 .541 r

F

0 g

.2911 .40201 m

.29409 .40407 L

s

.30369 .41072 m

.3153 .41875 L

s

.3153 .41875 m

.35515 .43428 L

s

.28265 .60597 m .29284 .64969 L .2808 .63348 L .987 .746 .481 r

F

.2808 .63348 m .29284 .64969 L .29107 .67744 L F

.42698 .87802 m .50745 .87932 L .5005 .88053 L .626 .78 .955 r

F

0 g

.50052 .8792 m

.50058 .87179 L

s

.5005 .88053 m

.5005 .88053 L

s

.35104 .80209 m .38344 .84105 L .3497 .83102 L .822 .578 .571 r

F

.38344 .84105 m .42698 .87802 L .38234 .87026 L .776 .538 .575 r

F

.3497 .83102 m .38344 .84105 L .38234 .87026 L .822 .578 .571 r

F

.32423 .7904 m .35104 .80209 L .3497 .83102 L .864 .617 .563 r

F

.32575 .76174 m .35104 .80209 L .32423 .7904 L F

.42698 .87802 m .49521 .86591 L .50745 .87932 L .626 .78 .955 r

F

0 g

.50745 .87932 m

.50954 .5561 L

s

.30432 .74859 m .32575 .76174 L .32423 .7904 L .907 .657 .55 r

F

.30599 .72018 m .32575 .76174 L .30432 .74859 L F

.2754 .58816 m .28265 .60597 L .2808 .63348 L .989 .774 .387 r

F

.38234 .87026 m .49521 .86591 L .42698 .87802 L .626 .78 .955 r

F

0 g

.42698 .87802 m

.5005 .88053 L

s

.28928 .70561 m .30599 .72018 L .30432 .74859 L .95 .701 .526 r

F

.29107 .67744 m .30599 .72018 L .28928 .70561 L F

.27893 .66141 m .29107 .67744 L .28928 .70561 L .987 .746 .481 r

F

.2808 .63348 m .29107 .67744 L .27893 .66141 L F

.38234 .87026 m .48271 .85224 L .49521 .86591 L .626 .78 .955 r

F

.3497 .83102 m .38234 .87026 L .34834 .86038 L .822 .578 .571 r

F

.34834 .86038 m .48271 .85224 L .38234 .87026 L .626 .78 .955 r

F

0 g

.38234 .87026 m

.42698 .87802 L

s

.32423 .7904 m .3497 .83102 L .32268 .81949 L .864 .617 .563 r

F

.32268 .81949 m .3497 .83102 L .34834 .86038 L F

.30262 .77741 m .32423 .7904 L .32268 .81949 L .907 .657 .55 r

F

.30432 .74859 m .32423 .7904 L .30262 .77741 L F

.27349 .61585 m .2808 .63348 L .27893 .66141 L .989 .774 .387 r

F

.2754 .58816 m .2808 .63348 L .27349 .61585 L F

0 0 0 r

.01 w

[ .015 ] 0 setdash

.83481 .30408 m

.87382 .74989 L

s

.26265 .37482 m .28316 .39651 L .2813 .42271 L .957 .704 .512 r

F

0 g

.5 Mabswid

[ ] 0 setdash

.28316 .39651 m

.2911 .40201 L

s

.28747 .73419 m .30432 .74859 L .30262 .77741 L .95 .701 .526 r

F

.28928 .70561 m .30432 .74859 L .28747 .73419 L F

.27704 .68975 m .28928 .70561 L .28747 .73419 L .987 .746 .481 r

F

.27893 .66141 m .28928 .70561 L .27704 .68975 L F

.34834 .86038 m .46995 .83827 L .48271 .85224 L .626 .78 .955 r

F

.32268 .81949 m .34834 .86038 L .32111 .84901 L .864 .617 .563 r

F

.32111 .84901 m .46995 .83827 L .34834 .86038 L .626 .78 .955 r

F

0 g

.34834 .86038 m

.38234 .87026 L

s

.30523 .38684 m .35931 .35096 L .35226 .35273 L .659 .747 .915 r

F

.35226 .35273 m .30523 .38684 L .30353 .41311 L .35 .168 .488 r

F

0 g

.29409 .40407 m

.30523 .38684 L

s

.30262 .77741 m .32268 .81949 L .3009 .80667 L .907 .657 .55 r

F

.3009 .80667 m .32268 .81949 L .32111 .84901 L F

.27154 .64396 m .27893 .66141 L .27704 .68975 L .989 .774 .387 r

F

.27349 .61585 m .27893 .66141 L .27154 .64396 L F

.26062 .40117 m .2813 .42271 L .27942 .4493 L .957 .704 .512 r

F

.26265 .37482 m .2813 .42271 L .26062 .40117 L F

.28563 .7632 m .30262 .77741 L .3009 .80667 L .95 .701 .526 r

F

.28747 .73419 m .30262 .77741 L .28563 .7632 L F

.27172 .59656 m .27349 .61585 L .27154 .64396 L .859 .714 .189 r

F

.27511 .71852 m .28747 .73419 L .28563 .7632 L .987 .746 .481 r

F

.27704 .68975 m .28747 .73419 L .27511 .71852 L F

.24982 .35333 m .26265 .37482 L .26062 .40117 L .993 .753 .459 r

F

0 g

.26265 .37482 m

.28316 .39651 L

s

.35089 .37924 m .30353 .41311 L .30181 .43977 L .35 .168 .488 r

F

.35226 .35273 m .30353 .41311 L .35089 .37924 L F

.3009 .80667 m .32111 .84901 L .29915 .83637 L .907 .657 .55 r

F

.32111 .84901 m .45693 .82402 L .46995 .83827 L .626 .78 .955 r

F

.29915 .83637 m .45693 .82402 L .32111 .84901 L F

0 g

.21993 .8447 m

.34673 .95966 L

s

.32111 .84901 m

.34834 .86038 L

s

.26956 .6725 m .27704 .68975 L .27511 .71852 L .989 .774 .387 r

F

.27154 .64396 m .27704 .68975 L .26956 .6725 L F

.26062 .40117 m .27942 .4493 L .25856 .42792 L .957 .704 .512 r

F

.25856 .42792 m .27942 .4493 L .27751 .47628 L F

.28563 .7632 m .3009 .80667 L .28376 .79264 L .95 .701 .526 r

F

.28376 .79264 m .3009 .80667 L .29915 .83637 L F

.26973 .62487 m .27154 .64396 L .26956 .6725 L .859 .714 .189 r

F

.27172 .59656 m .27154 .64396 L .26973 .62487 L F

.27315 .74772 m .28563 .7632 L .28376 .79264 L .987 .746 .481 r

F

.27511 .71852 m .28563 .7632 L .27315 .74772 L F

.24767 .37984 m .26062 .40117 L .25856 .42792 L .993 .753 .459 r

F

.24982 .35333 m .26062 .40117 L .24767 .37984 L F

.35089 .37924 m .30181 .43977 L .34949 .40615 L .35 .168 .488 r

F

.34949 .40615 m .30181 .43977 L .30005 .46683 L F

.26756 .70147 m .27511 .71852 L .27315 .74772 L .989 .774 .387 r

F

.26956 .6725 m .27511 .71852 L .26756 .70147 L F

.25647 .45508 m .27751 .47628 L .27557 .50368 L .957 .704 .512 r

F

.25856 .42792 m .27751 .47628 L .25647 .45508 L F

.2773 .57515 m .27172 .59656 L .26973 .62487 L 0 0 .116 r

F

.28376 .79264 m .29915 .83637 L .28186 .82254 L .95 .701 .526 r

F

.29915 .83637 m .44363 .80946 L .45693 .82402 L .626 .78 .955 r

F

.28186 .82254 m .44363 .80946 L .29915 .83637 L F

0 g

.29915 .83637 m

.32111 .84901 L

s

.24982 .35333 m .40163 .34642 L .24316 .33193 L .659 .747 .915 r

F

.24316 .33193 m .24982 .35333 L .24767 .37984 L .979 .773 .358 r

F

0 g

.24982 .35333 m

.26265 .37482 L

s

.35226 .35273 m .35799 .37748 L .35089 .37924 L .581 .356 .539 r

F

.35226 .35273 m .35931 .35096 L .35799 .37748 L F

0 g

.30523 .38684 m

.35226 .35273 L

s

.35226 .35273 m

.35226 .35273 L

s

.35931 .35096 m

.39313 .39715 L

s

.26772 .65362 m .26956 .6725 L .26756 .70147 L .859 .714 .189 r

F

.26973 .62487 m .26956 .6725 L .26772 .65362 L F

.27315 .74772 m .28376 .79264 L .27117 .77737 L .987 .746 .481 r

F

.27117 .77737 m .28376 .79264 L .28186 .82254 L F

.24767 .37984 m .25856 .42792 L .24548 .40674 L .993 .753 .459 r

F

.24548 .40674 m .25856 .42792 L .25647 .45508 L F

.24316 .33193 m .40163 .34642 L .40511 .32564 L .659 .747 .915 r

F

.34807 .43348 m .30005 .46683 L .29828 .49431 L .35 .168 .488 r

F

.34949 .40615 m .30005 .46683 L .34807 .43348 L F

.26552 .73088 m .27315 .74772 L .27117 .77737 L .989 .774 .387 r

F

.26756 .70147 m .27315 .74772 L .26552 .73088 L F

.25435 .48265 m .27557 .50368 L .2736 .5315 L .957 .704 .512 r

F

.25647 .45508 m .27557 .50368 L .25435 .48265 L F

.27533 .60368 m .26973 .62487 L .26772 .65362 L 0 0 .116 r

F

.2773 .57515 m .26973 .62487 L .27533 .60368 L F

.24093 .35858 m .24767 .37984 L .24548 .40674 L .979 .773 .358 r

F

.24316 .33193 m .24767 .37984 L .24093 .35858 L F

.35089 .37924 m .35664 .40441 L .34949 .40615 L .581 .356 .539 r

F

.35089 .37924 m .35799 .37748 L .35664 .40441 L F

0 g

.35089 .37924 m

.35226 .35273 L

s

.28181 .58585 m .2773 .57515 L .27533 .60368 L 0 0 .36 r

F

.28244 .57653 m .30536 .58089 L .30362 .60936 L .903 .647 .541 r

F

.28308 .56693 m .30536 .58089 L .28244 .57653 L F

.28308 .56693 m .2773 .57515 L .28181 .58585 L 0 0 .36 r

F

.2716 .55974 m .28244 .57653 L .26957 .58842 L .903 .647 .541 r

F

.28244 .57653 m .30362 .60936 L .28115 .59554 L F

.29464 .55054 m .28181 .58585 L .29277 .57931 L 0 0 .36 r

F

.28181 .58585 m .27533 .60368 L .28115 .59554 L F

.28181 .58585 m .28115 .59554 L .29277 .57931 L F

.28049 .60529 m .30362 .60936 L .30185 .63827 L .903 .647 .541 r

F

.28115 .59554 m .27533 .60368 L .27986 .61475 L 0 0 .36 r

F

.26957 .58842 m .28115 .59554 L .28049 .60529 L .903 .647 .541 r

F

.28115 .59554 m .30362 .60936 L .28049 .60529 L F

.28244 .57653 m .28115 .59554 L .26957 .58842 L F

.27986 .61475 m .27533 .60368 L .27333 .63265 L 0 0 .36 r

F

.27533 .60368 m .26772 .65362 L .27333 .63265 L 0 0 .116 r

F

.26957 .58842 m .28049 .60529 L .26751 .61755 L .903 .647 .541 r

F

.28049 .60529 m .30185 .63827 L .27919 .6246 L F

.29277 .57931 m .27986 .61475 L .29088 .60854 L 0 0 .36 r

F

.27986 .61475 m .27333 .63265 L .27919 .6246 L F

.27986 .61475 m .27919 .6246 L .29088 .60854 L F

.27852 .6345 m .30185 .63827 L .30005 .66763 L .903 .647 .541 r

F

.27919 .6246 m .27333 .63265 L .27787 .64411 L 0 0 .36 r

F

.26751 .61755 m .27919 .6246 L .27852 .6345 L .903 .647 .541 r

F

.27919 .6246 m .30185 .63827 L .27852 .6345 L F

.28049 .60529 m .27919 .6246 L .26751 .61755 L F

.27787 .64411 m .27333 .63265 L .2713 .66207 L 0 0 .36 r

F

.26772 .65362 m .26756 .70147 L .26568 .6828 L .859 .714 .189 r

F

.27333 .63265 m .26772 .65362 L .26568 .6828 L 0 0 .116 r

F

.27333 .63265 m .26568 .6828 L .2713 .66207 L F

.26751 .61755 m .27852 .6345 L .26542 .64714 L .903 .647 .541 r

F

.27852 .6345 m .30005 .66763 L .2772 .65411 L F

.29088 .60854 m .27787 .64411 L .28896 .63822 L 0 0 .36 r

F

.27787 .64411 m .2713 .66207 L .2772 .65411 L F

.27787 .64411 m .2772 .65411 L .28896 .63822 L F

.27652 .66417 m .30005 .66763 L .29822 .69745 L .903 .647 .541 r

F

.2772 .65411 m .2713 .66207 L .27586 .67393 L 0 0 .36 r

F

.26542 .64714 m .2772 .65411 L .27652 .66417 L .903 .647 .541 r

F

.2772 .65411 m .30005 .66763 L .27652 .66417 L F

.27852 .6345 m .2772 .65411 L .26542 .64714 L F

.27586 .67393 m .2713 .66207 L .26924 .69195 L 0 0 .36 r

F

.26568 .6828 m .26756 .70147 L .26552 .73088 L .859 .714 .189 r

F

.26568 .6828 m .26552 .73088 L .2636 .71244 L F

.2713 .66207 m .26568 .6828 L .2636 .71244 L 0 0 .116 r

F

.2713 .66207 m .2636 .71244 L .26924 .69195 L F

.26542 .64714 m .27652 .66417 L .26329 .6772 L .903 .647 .541 r

F

.27652 .66417 m .29822 .69745 L .27517 .68409 L F

.28896 .63822 m .27586 .67393 L .28701 .66839 L 0 0 .36 r

F

.27586 .67393 m .26924 .69195 L .27517 .68409 L F

.27586 .67393 m .27517 .68409 L .28701 .66839 L F

.27448 .6943 m .29822 .69745 L .29636 .72774 L .903 .647 .541 r

F

.27517 .68409 m .26924 .69195 L .27381 .70422 L 0 0 .36 r

F

.26329 .6772 m .27517 .68409 L .27448 .6943 L .903 .647 .541 r

F

.27517 .68409 m .29822 .69745 L .27448 .6943 L F

.27652 .66417 m .27517 .68409 L .26329 .6772 L F

.27381 .70422 m .26924 .69195 L .26715 .72231 L 0 0 .36 r

F

.2636 .71244 m .26552 .73088 L .26346 .76075 L .859 .714 .189 r

F

.2636 .71244 m .26346 .76075 L .26149 .74254 L F

.26924 .69195 m .2636 .71244 L .26149 .74254 L 0 0 .116 r

F

.26924 .69195 m .26149 .74254 L .26715 .72231 L F

.26329 .6772 m .27448 .6943 L .26113 .70774 L .903 .647 .541 r

F

.27448 .6943 m .29636 .72774 L .27311 .71454 L F

.27381 .70422 m .26715 .72231 L .27311 .71454 L 0 0 .36 r

F

.27448 .6943 m .27311 .71454 L .26113 .70774 L .903 .647 .541 r

F

.28701 .66839 m .27381 .70422 L .28503 .69903 L 0 0 .36 r

F

.27381 .70422 m .27311 .71454 L .28503 .69903 L F

.28701 .66839 m .27517 .68409 L .27381 .70422 L F

.28896 .63822 m .2772 .65411 L .27586 .67393 L F

.29088 .60854 m .27919 .6246 L .27787 .64411 L F

.29277 .57931 m .28115 .59554 L .27986 .61475 L F

.29464 .55054 m .28308 .56693 L .28181 .58585 L F

.2716 .55974 m .28308 .56693 L .28244 .57653 L .903 .647 .541 r

F

.28186 .82254 m .43004 .79459 L .44363 .80946 L .626 .78 .955 r

F

.27117 .77737 m .28186 .82254 L .26915 .80748 L .987 .746 .481 r

F

.26915 .80748 m .43004 .79459 L .28186 .82254 L .626 .78 .955 r

F

0 g

.28186 .82254 m

.29915 .83637 L

s

.24326 .43407 m .25647 .45508 L .25435 .48265 L .993 .753 .459 r

F

.24548 .40674 m .25647 .45508 L .24326 .43407 L F

.24316 .33193 m .40511 .32564 L .24211 .31055 L .659 .747 .915 r

F

.24211 .31055 m .24316 .33193 L .24093 .35858 L .844 .71 .18 r

F

0 g

.24316 .33193 m

.24982 .35333 L

s

.34663 .46123 m .29828 .49431 L .29647 .52221 L .35 .168 .488 r

F

.34807 .43348 m .29828 .49431 L .34663 .46123 L F

.26552 .73088 m .27117 .77737 L .26346 .76075 L .989 .774 .387 r

F

.26346 .76075 m .27117 .77737 L .26915 .80748 L F

.25219 .51066 m .2736 .5315 L .2716 .55974 L .957 .704 .512 r

F

.25435 .48265 m .2736 .5315 L .25219 .51066 L F

.24211 .31055 m .40511 .32564 L .40867 .30437 L .659 .747 .915 r

F

.24093 .35858 m .24548 .40674 L .23867 .38564 L .979 .773 .358 r

F

.23867 .38564 m .24548 .40674 L .24326 .43407 L F

.34949 .40615 m .35528 .43175 L .34807 .43348 L .581 .356 .539 r

F

.34949 .40615 m .35664 .40441 L .35528 .43175 L F

0 g

.34949 .40615 m

.35089 .37924 L

s

.24101 .46181 m .25435 .48265 L .25219 .51066 L .993 .753 .459 r

F

.24326 .43407 m .25435 .48265 L .24101 .46181 L F

.23984 .33734 m .24093 .35858 L .23867 .38564 L .844 .71 .18 r

F

0 g

.09069 .21533 m

.23981 .39768 L

s

.24211 .31055 m .24093 .35858 L .23984 .33734 L .844 .71 .18 r

F

.34517 .48941 m .29647 .52221 L .29464 .55054 L .35 .168 .488 r

F

.34663 .46123 m .29647 .52221 L .34517 .48941 L F

.26346 .76075 m .26915 .80748 L .26136 .79108 L .989 .774 .387 r

F

.26915 .80748 m .41616 .7794 L .43004 .79459 L .626 .78 .955 r

F

.26136 .79108 m .41616 .7794 L .26915 .80748 L F

0 g

.26915 .80748 m

.28186 .82254 L

s

.43074 .12036 m

.7558 .02958 L

s

.03031 .6728 m

.09069 .21533 L

s

.25219 .51066 m .2716 .55974 L .25 .53909 L .957 .704 .512 r

F

.25 .53909 m .2716 .55974 L .26957 .58842 L F

0 g

.97777 .85348 m

.7894 .50836 L

s

.23637 .41312 m .24326 .43407 L .24101 .46181 L .979 .773 .358 r

F

.23867 .38564 m .24326 .43407 L .23637 .41312 L F

.24211 .31055 m .40867 .30437 L .24663 .28921 L .659 .747 .915 r

F

.24663 .28921 m .24211 .31055 L .23984 .33734 L 0 0 .057 r

F

0 g

.2425 .31851 m

.24316 .33193 L

s

.34807 .43348 m .35389 .45951 L .34663 .46123 L .581 .356 .539 r

F

.34807 .43348 m .35528 .43175 L .35389 .45951 L F

0 g

.34807 .43348 m

.34949 .40615 L

s

.26149 .74254 m .26346 .76075 L .26136 .79108 L .859 .714 .189 r

F

.23872 .49 m .25219 .51066 L .25 .53909 L .993 .753 .459 r

F

.24101 .46181 m .25219 .51066 L .23872 .49 L F

.24663 .28921 m .40867 .30437 L .41231 .28262 L .659 .747 .915 r

F

.23755 .36456 m .23867 .38564 L .23637 .41312 L .844 .71 .18 r

F

.23984 .33734 m .23867 .38564 L .23755 .36456 L F

.34517 .48941 m .29464 .55054 L .34369 .51805 L .35 .168 .488 r

F

.34369 .51805 m .29464 .55054 L .29277 .57931 L F

.24777 .56798 m .26957 .58842 L .26751 .61755 L .957 .704 .512 r

F

.25 .53909 m .26957 .58842 L .24777 .56798 L F

.23404 .44104 m .24101 .46181 L .23872 .49 L .979 .773 .358 r

F

.23637 .41312 m .24101 .46181 L .23404 .44104 L F

.24437 .31614 m .23984 .33734 L .23755 .36456 L 0 0 .057 r

F

.24663 .28921 m .23984 .33734 L .24437 .31614 L F

.34663 .46123 m .35249 .48772 L .34517 .48941 L .581 .356 .539 r

F

.34663 .46123 m .35389 .45951 L .35249 .48772 L F

0 g

.34663 .46123 m

.34807 .43348 L

s

.36335 .78011 m .37265 .7502 L .36467 .74963 L .729 .489 .564 r

F

.36335 .78011 m .37139 .78067 L .37265 .7502 L F

.29636 .72774 m .36467 .74963 L .36335 .78011 L .83 .578 .558 r

F

.29822 .69745 m .36467 .74963 L .29636 .72774 L F

0 g

.36467 .74963 m

.36577 .72425 L

s

.26149 .74254 m .26136 .79108 L .25935 .77312 L .859 .714 .189 r

F

.29636 .72774 m .36335 .78011 L .29448 .75851 L .83 .578 .558 r

F

.26136 .79108 m .40198 .76388 L .41616 .7794 L .626 .78 .955 r

F

.25935 .77312 m .40198 .76388 L .26136 .79108 L F

0 g

.37201 .76582 m

.37338 .73258 L

s

.36395 .76634 m

.36467 .74963 L

s

.26136 .79108 m

.26915 .80748 L

s

.23872 .49 m .25 .53909 L .2364 .51862 L .993 .753 .459 r

F

.2364 .51862 m .25 .53909 L .24777 .56798 L F

.24663 .28921 m .41231 .28262 L .25714 .26793 L .659 .747 .915 r

F

.25714 .26793 m .24663 .28921 L .24437 .31614 L 0 0 .259 r

F

0 g

.24211 .31055 m

.24663 .28921 L

s

.23521 .39219 m .23637 .41312 L .23404 .44104 L .844 .71 .18 r

F

.23755 .36456 m .23637 .41312 L .23521 .39219 L F

.34218 .54713 m .29277 .57931 L .29088 .60854 L .35 .168 .488 r

F

.34369 .51805 m .29277 .57931 L .34218 .54713 L F

.24551 .59732 m .26751 .61755 L .26542 .64714 L .957 .704 .512 r

F

.24777 .56798 m .26751 .61755 L .24551 .59732 L F

.26715 .72231 m .26149 .74254 L .25935 .77312 L 0 0 .116 r

F

.25714 .26793 m .41231 .28262 L .41604 .26037 L .659 .747 .915 r

F

.23166 .46939 m .23872 .49 L .2364 .51862 L .979 .773 .358 r

F

.23404 .44104 m .23872 .49 L .23166 .46939 L F

.24209 .34349 m .23755 .36456 L .23521 .39219 L 0 0 .057 r

F

.24437 .31614 m .23755 .36456 L .24209 .34349 L F

.34517 .48941 m .35106 .51636 L .34369 .51805 L .581 .356 .539 r

F

.34517 .48941 m .35249 .48772 L .35106 .51636 L F

0 g

.34517 .48941 m

.34663 .46123 L

s

.29448 .75851 m .37139 .78067 L .36335 .78011 L .626 .78 .955 r

F

.29448 .75851 m .37465 .76418 L .37139 .78067 L F

0 g

.36335 .78011 m

.36335 .78011 L

s

.23404 .5477 m .24777 .56798 L .24551 .59732 L .993 .753 .459 r

F

.2364 .51862 m .24777 .56798 L .23404 .5477 L F

.25495 .29499 m .24437 .31614 L .24209 .34349 L 0 0 .259 r

F

.25714 .26793 m .24437 .31614 L .25495 .29499 L F

.23284 .42027 m .23404 .44104 L .23166 .46939 L .844 .71 .18 r

F

.23521 .39219 m .23404 .44104 L .23284 .42027 L F

.34064 .57669 m .29088 .60854 L .28896 .63822 L .35 .168 .488 r

F

.34218 .54713 m .29088 .60854 L .34064 .57669 L F

.24321 .62713 m .26542 .64714 L .26329 .6772 L .957 .704 .512 r

F

.24551 .59732 m .26542 .64714 L .24321 .62713 L F

.26715 .72231 m .25935 .77312 L .26502 .75315 L 0 0 .116 r

F

.25935 .77312 m .38748 .74801 L .40198 .76388 L .626 .78 .955 r

F

.27241 .72492 m .29636 .72774 L .29448 .75851 L .903 .647 .541 r

F

.27311 .71454 m .26715 .72231 L .27173 .735 L 0 0 .36 r

F

.26113 .70774 m .27311 .71454 L .27241 .72492 L .903 .647 .541 r

F

.27311 .71454 m .29636 .72774 L .27241 .72492 L F

.27173 .735 m .26715 .72231 L .26502 .75315 L 0 0 .36 r

F

.26113 .70774 m .27241 .72492 L .25893 .73877 L .903 .647 .541 r

F

.27241 .72492 m .29448 .75851 L .27102 .74549 L F

.27173 .735 m .26502 .75315 L .27102 .74549 L 0 0 .36 r

F

.27241 .72492 m .27102 .74549 L .25893 .73877 L .903 .647 .541 r

F

.28503 .69903 m .27173 .735 L .28301 .73018 L 0 0 .36 r

F

.27173 .735 m .27102 .74549 L .28301 .73018 L F

.28503 .69903 m .27311 .71454 L .27173 .735 L F

.26502 .75315 m .38748 .74801 L .25935 .77312 L .626 .78 .955 r

F

0 g

.25935 .77312 m

.26136 .79108 L

s

.25714 .26793 m .41604 .26037 L .27466 .24682 L .659 .747 .915 r

F

.27466 .24682 m .25714 .26793 L .25495 .29499 L .102 0 .383 r

F

0 g

.24663 .28921 m

.25714 .26793 L

s

.23166 .46939 m .2364 .51862 L .22925 .4982 L .979 .773 .358 r

F

.22925 .4982 m .2364 .51862 L .23404 .5477 L F

.23976 .37128 m .23521 .39219 L .23284 .42027 L 0 0 .057 r

F

.24209 .34349 m .23521 .39219 L .23976 .37128 L F

.34369 .51805 m .34961 .54546 L .34218 .54713 L .581 .356 .539 r

F

.34369 .51805 m .35106 .51636 L .34961 .54546 L F

0 g

.34369 .51805 m

.34517 .48941 L

s

.27466 .24682 m .41604 .26037 L .41986 .23759 L .659 .747 .915 r

F

.23164 .57725 m .24551 .59732 L .24321 .62713 L .993 .753 .459 r

F

.23404 .5477 m .24551 .59732 L .23164 .57725 L F

.25272 .32249 m .24209 .34349 L .23976 .37128 L 0 0 .259 r

F

.25495 .29499 m .24209 .34349 L .25272 .32249 L F

.23043 .4488 m .23166 .46939 L .22925 .4982 L .844 .71 .18 r

F

.23284 .42027 m .23166 .46939 L .23043 .4488 L F

.33909 .60672 m .28896 .63822 L .28701 .66839 L .35 .168 .488 r

F

.34064 .57669 m .28896 .63822 L .33909 .60672 L F

.25893 .73877 m .37465 .76418 L .29448 .75851 L .626 .78 .955 r

F

.25893 .73877 m .37799 .74729 L .37465 .76418 L F

0 g

.29448 .75851 m

.36335 .78011 L

s

.24088 .65742 m .26329 .6772 L .26113 .70774 L .957 .704 .512 r

F

.24321 .62713 m .26329 .6772 L .24088 .65742 L F

.27258 .27401 m .25495 .29499 L .25272 .32249 L .102 0 .383 r

F

.27466 .24682 m .25495 .29499 L .27258 .27401 L F

.22681 .52748 m .23404 .5477 L .23164 .57725 L .979 .773 .358 r

F

.22925 .4982 m .23404 .5477 L .22681 .52748 L F

.2374 .39952 m .23284 .42027 L .23043 .4488 L 0 0 .057 r

F

.23976 .37128 m .23284 .42027 L .2374 .39952 L F

.34218 .54713 m .34813 .57503 L .34064 .57669 L .581 .356 .539 r

F

.34218 .54713 m .34961 .54546 L .34813 .57503 L F

0 g

.34218 .54713 m

.34369 .51805 L

s

.27466 .24682 m .41986 .23759 L .30127 .22609 L .659 .747 .915 r

F

.30127 .22609 m .27466 .24682 L .27258 .27401 L .304 .117 .454 r

F

0 g

.25714 .26793 m

.27466 .24682 L

s

.2292 .60728 m .24321 .62713 L .24088 .65742 L .993 .753 .459 r

F

.23164 .57725 m .24321 .62713 L .2292 .60728 L F

.25045 .35043 m .23976 .37128 L .2374 .39952 L 0 0 .259 r

F

.25272 .32249 m .23976 .37128 L .25045 .35043 L F

.23043 .4488 m .22925 .4982 L .22798 .47779 L .844 .71 .18 r

F

.22798 .47779 m .22925 .4982 L .22681 .52748 L F

.3375 .63724 m .28701 .66839 L .28503 .69903 L .35 .168 .488 r

F

.33909 .60672 m .28701 .66839 L .3375 .63724 L F

.26502 .75315 m .37265 .73178 L .38748 .74801 L .626 .78 .955 r

F

.28301 .73018 m .37265 .73178 L .26502 .75315 L F

0 g

.25935 .77312 m

.26502 .75315 L

s

.24088 .65742 m .26113 .70774 L .23851 .6882 L .957 .704 .512 r

F

.23851 .6882 m .26113 .70774 L .25893 .73877 L F

.30127 .22609 m .41986 .23759 L .42376 .21426 L .659 .747 .915 r

F

.27047 .30165 m .25272 .32249 L .25045 .35043 L .102 0 .383 r

F

.27258 .27401 m .25272 .32249 L .27047 .30165 L F

.22432 .55723 m .23164 .57725 L .2292 .60728 L .979 .773 .358 r

F

.22681 .52748 m .23164 .57725 L .22432 .55723 L F

.235 .42822 m .23043 .4488 L .22798 .47779 L 0 0 .057 r

F

.2374 .39952 m .23043 .4488 L .235 .42822 L F

.34064 .57669 m .34663 .60508 L .33909 .60672 L .581 .356 .539 r

F

.34064 .57669 m .34813 .57503 L .34663 .60508 L F

0 g

.34064 .57669 m

.34218 .54713 L

s

.33589 .66826 m .28503 .69903 L .28301 .73018 L .35 .168 .488 r

F

.23851 .6882 m .25893 .73877 L .2361 .71948 L .957 .704 .512 r

F

.33589 .66826 m .28301 .73018 L .33426 .69979 L .35 .168 .488 r

F

.2361 .71948 m .37799 .74729 L .25893 .73877 L .626 .78 .955 r

F

.2361 .71948 m .3814 .73001 L .37799 .74729 L F

0 g

.37139 .78067 m

.37956 .73934 L

s

.26772 .74365 m

.27102 .74549 L

s

.27102 .74549 m

.29448 .75851 L

s

.26502 .75315 m

.27102 .74549 L

s

.25893 .73877 m

.26772 .74365 L

s

.37956 .73934 m

.50745 .87932 L

s

.29939 .25341 m .27258 .27401 L .27047 .30165 L .304 .117 .454 r

F

.30127 .22609 m .27258 .27401 L .29939 .25341 L F

.22672 .63779 m .24088 .65742 L .23851 .6882 L .993 .753 .459 r

F

.2292 .60728 m .24088 .65742 L .22672 .63779 L F

.24815 .37882 m .2374 .39952 L .235 .42822 L 0 0 .259 r

F

.25045 .35043 m .2374 .39952 L .24815 .37882 L F

.2255 .50726 m .22681 .52748 L .22432 .55723 L .844 .71 .18 r

F

.22798 .47779 m .22681 .52748 L .2255 .50726 L F

.3375 .63724 m .28503 .69903 L .33589 .66826 L .35 .168 .488 r

F

.30127 .22609 m .42376 .21426 L .34202 .20624 L .659 .747 .915 r

F

.34202 .20624 m .30127 .22609 L .29939 .25341 L .454 .237 .494 r

F

0 g

.09069 .21533 m

.33707 .14652 L

s

.33707 .14652 m

.43074 .12036 L

s

.27466 .24682 m

.30127 .22609 L

s

.26832 .32973 m .25045 .35043 L .24815 .37882 L .102 0 .383 r

F

.27047 .30165 m .25045 .35043 L .26832 .32973 L F

.22179 .58746 m .2292 .60728 L .22672 .63779 L .979 .773 .358 r

F

.22432 .55723 m .2292 .60728 L .22179 .58746 L F

.235 .42822 m .22798 .47779 L .23256 .45739 L 0 0 .057 r

F

.23256 .45739 m .22798 .47779 L .2255 .50726 L F

.33909 .60672 m .34511 .63562 L .3375 .63724 L .581 .356 .539 r

F

.33909 .60672 m .34663 .60508 L .34511 .63562 L F

0 g

.33909 .60672 m

.34064 .57669 L

s

.29747 .28117 m .27047 .30165 L .26832 .32973 L .304 .117 .454 r

F

.29939 .25341 m .27047 .30165 L .29747 .28117 L F

.34202 .20624 m .42376 .21426 L .42776 .19038 L .659 .747 .915 r

F

.28301 .73018 m .35749 .71519 L .37265 .73178 L .626 .78 .955 r

F

.22672 .63779 m .23851 .6882 L .2242 .6688 L .993 .753 .459 r

F

.2242 .6688 m .23851 .6882 L .2361 .71948 L F

.24581 .40769 m .235 .42822 L .23256 .45739 L 0 0 .259 r

F

.24815 .37882 m .235 .42822 L .24581 .40769 L F

.22297 .5372 m .22432 .55723 L .22179 .58746 L .844 .71 .18 r

F

.2255 .50726 m .22432 .55723 L .22297 .5372 L F

.33426 .69979 m .35749 .71519 L .28301 .73018 L .626 .78 .955 r

F

0 g

.27102 .74549 m

.28301 .73018 L

s

.2242 .6688 m .2361 .71948 L .22164 .70033 L .993 .753 .459 r

F

.22164 .70033 m .3814 .73001 L .2361 .71948 L .626 .78 .955 r

F

.22164 .70033 m .3849 .7123 L .3814 .73001 L F

0 g

.2361 .71948 m

.25893 .73877 L

s

.34045 .23367 m .29939 .25341 L .29747 .28117 L .454 .237 .494 r

F

.34202 .20624 m .29939 .25341 L .34045 .23367 L F

.34202 .20624 m .42776 .19038 L .41937 .18955 L .659 .747 .915 r

F

.41937 .18955 m .34202 .20624 L .34045 .23367 L .59 .349 .52 r

F

0 g

.30127 .22609 m

.34202 .20624 L

s

.26614 .35827 m .24815 .37882 L .24581 .40769 L .102 0 .383 r

F

.26832 .32973 m .24815 .37882 L .26614 .35827 L F

.21922 .6182 m .22672 .63779 L .2242 .6688 L .979 .773 .358 r

F

.22179 .58746 m .22672 .63779 L .21922 .6182 L F

.23008 .48703 m .2255 .50726 L .22297 .5372 L 0 0 .057 r

F

.23256 .45739 m .2255 .50726 L .23008 .48703 L F

.3375 .63724 m .34356 .66666 L .33589 .66826 L .581 .356 .539 r

F

.3375 .63724 m .34511 .63562 L .34356 .66666 L F

0 g

.3375 .63724 m

.33909 .60672 L

s

.29553 .30939 m .26832 .32973 L .26614 .35827 L .304 .117 .454 r

F

.29747 .28117 m .26832 .32973 L .29553 .30939 L F

.24343 .43702 m .23256 .45739 L .23008 .48703 L 0 0 .259 r

F

.24581 .40769 m .23256 .45739 L .24343 .43702 L F

.2204 .56764 m .22179 .58746 L .21922 .6182 L .844 .71 .18 r

F

.22297 .5372 m .22179 .58746 L .2204 .56764 L F

.33886 .26156 m .29747 .28117 L .29553 .30939 L .454 .237 .494 r

F

.34045 .23367 m .29747 .28117 L .33886 .26156 L F

.41937 .18955 m .42776 .19038 L .42689 .2179 L .73 .466 .528 r

F

0 g

.39313 .39715 m

.4246 .20927 L

s

.33426 .69979 m .34198 .69822 L .35749 .71519 L .626 .78 .955 r

F

.41843 .21707 m .34045 .23367 L .33886 .26156 L .59 .349 .52 r

F

.41937 .18955 m .34045 .23367 L .41843 .21707 L F

.41937 .18955 m .42689 .2179 L .41843 .21707 L .73 .466 .528 r

F

0 g

.34202 .20624 m

.41937 .18955 L

s

.41937 .18955 m

.41937 .18955 L

s

.26392 .38729 m .24581 .40769 L .24343 .43702 L .102 0 .383 r

F

.26614 .35827 m .24581 .40769 L .26392 .38729 L F

.21661 .64944 m .2242 .6688 L .22164 .70033 L .979 .773 .358 r

F

.21922 .6182 m .2242 .6688 L .21661 .64944 L F

.22756 .51717 m .22297 .5372 L .2204 .56764 L 0 0 .057 r

F

.23008 .48703 m .22297 .5372 L .22756 .51717 L F

.21661 .64944 m .22164 .70033 L .21395 .68121 L .979 .773 .358 r

F

.21395 .68121 m .3849 .7123 L .22164 .70033 L .626 .78 .955 r

F

.33589 .66826 m .34198 .69822 L .33426 .69979 L .581 .356 .539 r

F

.33589 .66826 m .34356 .66666 L .34198 .69822 L F

.21395 .68121 m .38848 .69417 L .3849 .7123 L .626 .78 .955 r

F

0 g

.34236 .69074 m

.35931 .35096 L

s

.28301 .73018 m

.33426 .69979 L

s

.34198 .69822 m

.37956 .73934 L

s

.22164 .70033 m

.2361 .71948 L

s

.33589 .66826 m

.3375 .63724 L

s

.33476 .69018 m

.33589 .66826 L

s

.29355 .33808 m .26614 .35827 L .26392 .38729 L .304 .117 .454 r

F

.29553 .30939 m .26614 .35827 L .29355 .33808 L F

.24101 .46685 m .23008 .48703 L .22756 .51717 L 0 0 .259 r

F

.24343 .43702 m .23008 .48703 L .24101 .46685 L F

.21778 .59859 m .21922 .6182 L .21661 .64944 L .844 .71 .18 r

F

.2204 .56764 m .21922 .6182 L .21778 .59859 L F

.33724 .28991 m .29553 .30939 L .29355 .33808 L .454 .237 .494 r

F

.33886 .26156 m .29553 .30939 L .33724 .28991 L F

.41843 .21707 m .42689 .2179 L .426 .24588 L .73 .466 .528 r

F

.41747 .24505 m .33886 .26156 L .33724 .28991 L .59 .349 .52 r

F

.41843 .21707 m .33886 .26156 L .41747 .24505 L F

.41843 .21707 m .426 .24588 L .41747 .24505 L .73 .466 .528 r

F

0 g

.41843 .21707 m

.41937 .18955 L

s

.26167 .4168 m .24343 .43702 L .24101 .46685 L .102 0 .383 r

F

.26392 .38729 m .24343 .43702 L .26167 .4168 L F

.22499 .54782 m .2204 .56764 L .21778 .59859 L 0 0 .057 r

F

.22756 .51717 m .2204 .56764 L .22499 .54782 L F

.29154 .36725 m .26392 .38729 L .26167 .4168 L .304 .117 .454 r

F

.29355 .33808 m .26392 .38729 L .29154 .36725 L F

.23855 .49718 m .22756 .51717 L .22499 .54782 L 0 0 .259 r

F

.24101 .46685 m .22756 .51717 L .23855 .49718 L F

.21512 .63007 m .21661 .64944 L .21395 .68121 L .844 .71 .18 r

F

.21512 .63007 m .21395 .68121 L .21242 .66207 L F

.21242 .66207 m .38848 .69417 L .21395 .68121 L .626 .78 .955 r

F

.21242 .66207 m .39215 .67558 L .38848 .69417 L F

0 g

.21395 .68121 m

.22164 .70033 L

s

.21778 .59859 m .21661 .64944 L .21512 .63007 L .844 .71 .18 r

F

.33559 .31873 m .29355 .33808 L .29154 .36725 L .454 .237 .494 r

F

.33724 .28991 m .29355 .33808 L .33559 .31873 L F

.41747 .24505 m .426 .24588 L .4251 .27433 L .73 .466 .528 r

F

.41649 .27351 m .33724 .28991 L .33559 .31873 L .59 .349 .52 r

F

.41747 .24505 m .33724 .28991 L .41649 .27351 L F

.41747 .24505 m .4251 .27433 L .41649 .27351 L .73 .466 .528 r

F

0 g

.41747 .24505 m

.41843 .21707 L

s

.25938 .4468 m .24101 .46685 L .23855 .49718 L .102 0 .383 r

F

.26167 .4168 m .24101 .46685 L .25938 .4468 L F

.22239 .57898 m .21778 .59859 L .21512 .63007 L 0 0 .057 r

F

.22499 .54782 m .21778 .59859 L .22239 .57898 L F

.28949 .39691 m .26167 .4168 L .25938 .4468 L .304 .117 .454 r

F

.29154 .36725 m .26167 .4168 L .28949 .39691 L F

.23605 .52802 m .22499 .54782 L .22239 .57898 L 0 0 .259 r

F

.23855 .49718 m .22499 .54782 L .23605 .52802 L F

.33391 .34804 m .29154 .36725 L .28949 .39691 L .454 .237 .494 r

F

.33559 .31873 m .29154 .36725 L .33391 .34804 L F

.41649 .27351 m .4251 .27433 L .42418 .30326 L .73 .466 .528 r

F

.4155 .30244 m .33559 .31873 L .33391 .34804 L .59 .349 .52 r

F

.41649 .27351 m .33559 .31873 L .4155 .30244 L F

.41649 .27351 m .42418 .30326 L .4155 .30244 L .73 .466 .528 r

F

0 g

.41649 .27351 m

.41747 .24505 L

s

.25704 .47731 m .23855 .49718 L .23605 .52802 L .102 0 .383 r

F

.25938 .4468 m .23855 .49718 L .25704 .47731 L F

0 g

.7894 .50836 m

.7558 .02958 L

s

.21704 .64291 m .39215 .67558 L .21242 .66207 L .626 .78 .955 r

F

.21704 .64291 m .39591 .65653 L .39215 .67558 L F

0 g

.03031 .6728 m

.21993 .8447 L

s

.21974 .61067 m .21512 .63007 L .21242 .66207 L 0 0 .057 r

F

.22239 .57898 m .21512 .63007 L .21974 .61067 L F

.28741 .42708 m .25938 .4468 L .25704 .47731 L .304 .117 .454 r

F

.28949 .39691 m .25938 .4468 L .28741 .42708 L F

.23351 .55939 m .22239 .57898 L .21974 .61067 L 0 0 .259 r

F

.23605 .52802 m .22239 .57898 L .23351 .55939 L F

.3322 .37786 m .28949 .39691 L .28741 .42708 L .454 .237 .494 r

F

.33391 .34804 m .28949 .39691 L .3322 .37786 L F

.4155 .30244 m .42418 .30326 L .42325 .33268 L .73 .466 .528 r

F

.41449 .33187 m .33391 .34804 L .3322 .37786 L .59 .349 .52 r

F

.4155 .30244 m .33391 .34804 L .41449 .33187 L F

.4155 .30244 m .42325 .33268 L .41449 .33187 L .73 .466 .528 r

F

0 g

.4155 .30244 m

.41649 .27351 L

s

.25467 .50835 m .23605 .52802 L .23351 .55939 L .102 0 .383 r

F

.25704 .47731 m .23605 .52802 L .25467 .50835 L F

.21974 .61067 m .21242 .66207 L .21704 .64291 L 0 0 .057 r

F

0 g

.21242 .66207 m

.21395 .68121 L

s

.28529 .45777 m .25704 .47731 L .25467 .50835 L .304 .117 .454 r

F

.28741 .42708 m .25704 .47731 L .28529 .45777 L F

.22829 .62377 m .39591 .65653 L .21704 .64291 L .626 .78 .955 r

F

.22829 .62377 m .39977 .637 L .39591 .65653 L F

.23092 .59131 m .21974 .61067 L .21704 .64291 L 0 0 .259 r

F

.23351 .55939 m .21974 .61067 L .23092 .59131 L F

.33047 .40819 m .28741 .42708 L .28529 .45777 L .454 .237 .494 r

F

.3322 .37786 m .28741 .42708 L .33047 .40819 L F

.41449 .33187 m .42325 .33268 L .4223 .36261 L .73 .466 .528 r

F

.41347 .36181 m .3322 .37786 L .33047 .40819 L .59 .349 .52 r

F

.41449 .33187 m .3322 .37786 L .41347 .36181 L F

.41449 .33187 m .4223 .36261 L .41347 .36181 L .73 .466 .528 r

F

0 g

.41449 .33187 m

.4155 .30244 L

s

.25226 .53992 m .23351 .55939 L .23092 .59131 L .102 0 .383 r

F

.25467 .50835 m .23351 .55939 L .25226 .53992 L F

.28314 .489 m .25467 .50835 L .25226 .53992 L .304 .117 .454 r

F

.28529 .45777 m .25467 .50835 L .28314 .489 L F

.23092 .59131 m .21704 .64291 L .22829 .62377 L 0 0 .259 r

F

0 g

.21242 .66207 m

.21704 .64291 L

s

.3287 .43904 m .28529 .45777 L .28314 .489 L .454 .237 .494 r

F

.33047 .40819 m .28529 .45777 L .3287 .43904 L F

.41347 .36181 m .4223 .36261 L .42133 .39307 L .73 .466 .528 r

F

.41242 .39227 m .33047 .40819 L .3287 .43904 L .59 .349 .52 r

F

.41347 .36181 m .33047 .40819 L .41242 .39227 L F

.41347 .36181 m .42133 .39307 L .41242 .39227 L .73 .466 .528 r

F

0 g

.41347 .36181 m

.41449 .33187 L

s

.2498 .57205 m .23092 .59131 L .22829 .62377 L .102 0 .383 r

F

.25226 .53992 m .23092 .59131 L .2498 .57205 L F

.24731 .60474 m .39977 .637 L .22829 .62377 L .626 .78 .955 r

F

.24731 .60474 m .40373 .61696 L .39977 .637 L F

.28095 .52077 m .25226 .53992 L .2498 .57205 L .304 .117 .454 r

F

.28314 .489 m .25226 .53992 L .28095 .52077 L F

.32691 .47044 m .28314 .489 L .28095 .52077 L .454 .237 .494 r

F

.3287 .43904 m .28314 .489 L .32691 .47044 L F

.41242 .39227 m .42133 .39307 L .42035 .42405 L .73 .466 .528 r

F

.41136 .42326 m .3287 .43904 L .32691 .47044 L .59 .349 .52 r

F

.41242 .39227 m .3287 .43904 L .41136 .42326 L F

.41242 .39227 m .42035 .42405 L .41136 .42326 L .73 .466 .528 r

F

0 g

.41242 .39227 m

.41347 .36181 L

s

.2498 .57205 m .22829 .62377 L .24731 .60474 L .102 0 .383 r

F

0 g

.21704 .64291 m

.22829 .62377 L

s

.27872 .5531 m .2498 .57205 L .24731 .60474 L .304 .117 .454 r

F

.28095 .52077 m .2498 .57205 L .27872 .5531 L F

.27645 .58601 m .40373 .61696 L .24731 .60474 L .626 .78 .955 r

F

.27645 .58601 m .40779 .5964 L .40373 .61696 L F

0 g

.03031 .6728 m

.26828 .62125 L

s

.32508 .5024 m .28095 .52077 L .27872 .5531 L .454 .237 .494 r

F

.32691 .47044 m .28095 .52077 L .32508 .5024 L F

.41136 .42326 m .42035 .42405 L .41935 .45559 L .73 .466 .528 r

F

.41028 .45481 m .32691 .47044 L .32508 .5024 L .59 .349 .52 r

F

.41136 .42326 m .32691 .47044 L .41028 .45481 L F

.41136 .42326 m .41935 .45559 L .41028 .45481 L .73 .466 .528 r

F

0 g

.41136 .42326 m

.41242 .39227 L

s

.27872 .5531 m .24731 .60474 L .27645 .58601 L .304 .117 .454 r

F

0 g

.26828 .62125 m

.28874 .61682 L

s

.22829 .62377 m

.24731 .60474 L

s

.32322 .53492 m .27872 .5531 L .27645 .58601 L .454 .237 .494 r

F

.32508 .5024 m .27872 .5531 L .32322 .53492 L F

.41028 .45481 m .41935 .45559 L .41833 .48769 L .73 .466 .528 r

F

.40918 .48691 m .32508 .5024 L .32322 .53492 L .59 .349 .52 r

F

.41028 .45481 m .32508 .5024 L .40918 .48691 L F

.41028 .45481 m .41833 .48769 L .40918 .48691 L .73 .466 .528 r

F

0 g

.41028 .45481 m

.41136 .42326 L

s

.32132 .56803 m .40779 .5964 L .27645 .58601 L .626 .78 .955 r

F

.32132 .56803 m .41196 .5753 L .40779 .5964 L F

0 g

.28874 .61682 m

.41597 .58926 L

s

.32322 .53492 m .27645 .58601 L .32132 .56803 L .454 .237 .494 r

F

0 g

.24731 .60474 m

.27645 .58601 L

s

.40918 .48691 m .41833 .48769 L .41729 .52036 L .73 .466 .528 r

F

.40806 .5196 m .32322 .53492 L .32132 .56803 L .59 .349 .52 r

F

.40918 .48691 m .32322 .53492 L .40806 .5196 L F

.40918 .48691 m .41729 .52036 L .40806 .5196 L .73 .466 .528 r

F

0 g

.40918 .48691 m

.41028 .45481 L

s

.40692 .55288 m .41196 .5753 L .32132 .56803 L .626 .78 .955 r

F

.40692 .55288 m .41623 .55363 L .41196 .5753 L F

.40806 .5196 m .41729 .52036 L .41623 .55363 L .73 .466 .528 r

F

.40806 .5196 m .32132 .56803 L .40692 .55288 L .59 .349 .52 r

F

0 g

.27645 .58601 m

.32132 .56803 L

s

.40806 .5196 m .41623 .55363 L .40692 .55288 L .73 .466 .528 r

F

0 g

.37956 .73934 m

.41623 .55363 L

s

.40806 .5196 m

.40918 .48691 L

s

.32132 .56803 m

.40692 .55288 L

s

.41623 .55363 m

.42776 .19038 L

s

.41597 .58926 m

.7894 .50836 L

s

.40692 .55288 m

.40806 .5196 L

s

.25 Mabswid

.06726 .19785 m

.76718 0 L

s

.11847 .18337 m

.12261 .1886 L

s

[(0)] .1102 .17291 .79102 1 Mshowa

.30418 .13088 m

.30793 .13639 L

s

[(5)] .29667 .11985 .681 1 Mshowa

.49983 .07557 m

.50314 .08136 L

s

[(10)] .49322 .06399 .57098 1 Mshowa

.70625 .01722 m

.70904 .02328 L

s

[(15)] .70067 .00511 .46096 1 Mshowa

.125 Mabswid

.15486 .17309 m

.1573 .17626 L

s

.19161 .1627 m

.19401 .1659 L

s

.22875 .1522 m

.2311 .15544 L

s

.26627 .14159 m

.26857 .14487 L

s

.34249 .12005 m

.34469 .12339 L

s

.3812 .1091 m

.38335 .11248 L

s

.42033 .09805 m

.42242 .10145 L

s

.45987 .08687 m

.46191 .09031 L

s

.54023 .06415 m

.54215 .06766 L

s

.58106 .05261 m

.58292 .05615 L

s

.62233 .04094 m

.62414 .04451 L

s

.66406 .02915 m

.6658 .03275 L

s

.08246 .19355 m

.08498 .19666 L

s

.7489 .00516 m

.75051 .00883 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.0272929 0.97619 0.547157 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.130586 1.32139 0 1.32139 [

[.5 1.26311 -48 0 ]

[.5 1.26311 48 16.8 ]

[.05098 .11635 -14.4 -5.08585 ]

[.05098 .11635 0 2.11415 ]

[.08788 .08764 -9.6 -5.11858 ]

[.08788 .08764 0 2.08142 ]

[.12584 .0581 -4.8 -5.15279 ]

[.12584 .0581 0 2.04721 ]

[.16492 .02769 -4.8 -5.18857 ]

[.16492 .02769 0 2.01143 ]

[.20517 -0.00363 -9.6 -5.22604 ]

[.20517 -0.00363 0 1.97396 ]

[.20877 1.14086 -7.48424 0 ]

[.20877 1.14086 6.91576 7.2 ]

[.43707 1.18932 -2.42727 0 ]

[.43707 1.18932 2.37273 7.2 ]

[.64431 1.2333 -4.73341 0 ]

[.64431 1.2333 4.86659 7.2 ]

[.04189 .20118 -4.8 -5.02049 ]

[.04189 .20118 0 2.17951 ]

[.02583 .44285 -9.6 -4.83808 ]

[.02583 .44285 0 2.36192 ]

[.00868 .70127 -9.6 -4.64435 ]

[.00868 .70127 0 2.55565 ]

[-0.00967 .97824 -9.6 -4.43822 ]

[-0.00967 .97824 0 2.76178 ]

[ 0 0 0 0 ]

[ 1 1.25061 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Rotate[object,angle,)( {1,0,0},{0,0,30}])] .5 1.26311 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.06262 .12546 m

.22431 0 L

s

.06625 .12265 m

.07389 .1258 L

s

[(-10)] .05098 .11635 1 .41274 Mshowa

.1031 .09406 m

.11071 .09727 L

s

[(-5)] .08788 .08764 1 .42183 Mshowa

.14101 .06464 m

.14859 .06791 L

s

[(0)] .12584 .0581 1 .43133 Mshowa

.18003 .03436 m

.18759 .03769 L

s

[(5)] .16492 .02769 1 .44127 Mshowa

.22022 .00317 m

.22775 .00657 L

s

[(10)] .20517 -0.00363 1 .45168 Mshowa

.125 Mabswid

.07354 .11699 m

.07812 .11889 L

s

.08087 .11131 m

.08544 .11321 L

s

.08823 .10559 m

.09281 .1075 L

s

.09564 .09984 m

.10021 .10176 L

s

.11059 .08824 m

.11516 .09017 L

s

.11813 .08239 m

.12269 .08433 L

s

.12571 .07651 m

.13027 .07845 L

s

.13334 .07059 m

.13789 .07254 L

s

.14872 .05865 m

.15327 .06062 L

s

.15648 .05263 m

.16103 .05461 L

s

.16429 .04657 m

.16883 .04856 L

s

.17214 .04048 m

.17667 .04248 L

s

.18798 .02819 m

.19251 .0302 L

s

.19597 .02199 m

.20049 .02401 L

s

.204 .01575 m

.20853 .01778 L

s

.21209 .00948 m

.21661 .01151 L

s

.25 Mabswid

0 1.07982 m

.80315 1.25061 L

s

.20942 1.12436 m

.20975 1.11611 L

s

[(-20)] .20877 1.14086 .03948 -1 Mshowa

.43726 1.17281 m


.43736 1.16455 L

s

[(0)] .43707 1.18932 .01136 -1 Mshowa

.64408 1.21679 m

.64396 1.20853 L

s

[(20)] .64431 1.2333 -0.01387 -1 Mshowa

.125 Mabswid

.26853 1.13693 m

.26869 1.13197 L

s

.32617 1.14918 m

.32629 1.14423 L

s

.38239 1.16114 m

.38248 1.15619 L

s

.49082 1.1842 m

.49084 1.17924 L

s

.54311 1.19532 m

.5431 1.19036 L

s

.59418 1.20618 m

.59415 1.20122 L

s

.1488 1.11147 m

.14903 1.10652 L

s

.0866 1.09824 m

.08687 1.09329 L

s

.02275 1.08466 m

.02306 1.07971 L

s

.69284 1.22716 m

.69274 1.2222 L

s

.74049 1.23729 m

.74037 1.23234 L

s

.78709 1.2472 m

.78693 1.24225 L

s

.25 Mabswid

.06262 .12546 m

0 1.07982 L

s

.05726 .20724 m

.06494 .21027 L

s

[(0)] .04189 .20118 1 .39458 Mshowa

.04145 .44822 m

.04926 .4509 L

s

[(20)] .02583 .44285 1 .34391 Mshowa

.02454 .70587 m

.03247 .70817 L

s

[(40)] .00868 .70127 1 .2901 Mshowa

.00642 .98199 m

.01446 .98386 L

s

[(60)] -0.00967 .97824 1 .23284 Mshowa

.125 Mabswid

.0534 .26601 m

.05803 .26778 L

s

.04948 .32575 m

.05413 .32747 L

s

.0455 .38648 m

.05016 .38814 L

s

.03733 .511 m

.04203 .51256 L

s

.03314 .57485 m

.03786 .57635 L

s

.02887 .6398 m

.03362 .64124 L

s

.02013 .77309 m

.0249 .77441 L

s

.01564 .8415 m

.02043 .84275 L

s

.01107 .91112 m

.01588 .91231 L

s

.06105 .14942 m

.06564 .15128 L

s

.00169 1.05414 m

.00653 1.05519 L

s

0 0 m

1 0 L

1 1.25061 L

0 1.25061 L

closepath

clip

newpath

.5 Mabswid

.93231 .34642 m

.76572 .43241 L

s

.93231 .34642 m

.97757 1.173 L

s

.8359 .61125 m .83023 .62236 L .82917 .61189 L .871 .695 .662 r

F

.8359 .61125 m .83696 .6217 L .83023 .62236 L F

.8359 .61125 m .8654 .58689 L .83622 .60018 L .508 .429 .702 r

F

.8359 .61125 m .86829 .59661 L .8654 .58689 L F

.83696 .6217 m .86829 .59661 L .8359 .61125 L F

.83622 .60018 m .8359 .61125 L .82917 .61189 L .873 .736 .708 r

F

.83696 .6217 m .87118 .60634 L .86829 .59661 L .508 .429 .702 r

F

.83922 .63161 m .87118 .60634 L .83696 .6217 L F

.83696 .6217 m .83249 .63229 L .83023 .62236 L .864 .653 .615 r

F

.83696 .6217 m .83922 .63161 L .83249 .63229 L F

0 g

.8359 .61125 m

.83696 .6217 L

s

.83922 .63161 m .87407 .61609 L .87118 .60634 L .508 .429 .702 r

F

.84265 .64101 m .87407 .61609 L .83922 .63161 L F

.83922 .63161 m .83592 .64171 L .83249 .63229 L .854 .606 .564 r

F

.83922 .63161 m .84265 .64101 L .83592 .64171 L F

0 g

.83696 .6217 m

.83922 .63161 L

s

.83622 .60018 m .86252 .57719 L .8383 .58829 L .508 .429 .702 r

F

.83622 .60018 m .8654 .58689 L .86252 .57719 L F

.83622 .60018 m .82917 .61189 L .82949 .60079 L .873 .736 .708 r

F

.8383 .58829 m .83622 .60018 L .82949 .60079 L .871 .778 .756 r

F

0 g

.8359 .61125 m

.83622 .60018 L

s

.84265 .64101 m .87696 .62584 L .87407 .61609 L .508 .429 .702 r

F

.84729 .64989 m .87696 .62584 L .84265 .64101 L F

.84265 .64101 m .84057 .65061 L .83592 .64171 L .838 .552 .504 r

F

.84265 .64101 m .84729 .64989 L .84057 .65061 L F

0 g

.83922 .63161 m

.84265 .64101 L

s

.8383 .58829 m .85964 .56749 L .8431 .57513 L .508 .429 .702 r

F

.8383 .58829 m .86252 .57719 L .85964 .56749 L F

.8383 .58829 m .82949 .60079 L .83156 .58888 L .871 .778 .756 r

F

.8431 .57513 m .8383 .58829 L .83156 .58888 L .861 .827 .813 r

F

0 g

.83622 .60018 m

.8383 .58829 L

s

.82917 .61189 m .82347 .62302 L .82241 .61253 L .871 .695 .662 r

F

.82917 .61189 m .83023 .62236 L .82347 .62302 L F

.82949 .60079 m .82917 .61189 L .82241 .61253 L .873 .736 .708 r

F

.83023 .62236 m .82574 .63297 L .82347 .62302 L .864 .653 .615 r

F

.83023 .62236 m .83249 .63229 L .82574 .63297 L F

.84729 .64989 m .87986 .6356 L .87696 .62584 L .508 .429 .702 r

F

.85334 .65819 m .87986 .6356 L .84729 .64989 L F

.84729 .64989 m .84662 .65893 L .84057 .65061 L .812 .482 .429 r

F

.84729 .64989 m .85334 .65819 L .84662 .65893 L F

0 g

.84265 .64101 m

.84729 .64989 L

s

.83249 .63229 m .82917 .64241 L .82574 .63297 L .854 .606 .564 r

F

.83249 .63229 m .83592 .64171 L .82917 .64241 L F

.82949 .60079 m .82241 .61253 L .82273 .60141 L .873 .736 .708 r

F

.83156 .58888 m .82949 .60079 L .82273 .60141 L .871 .778 .756 r

F

.8431 .57513 m .85677 .5578 L .85508 .55859 L .508 .429 .702 r

F

.8431 .57513 m .85964 .56749 L .85677 .5578 L F

.8431 .57513 m .83156 .58888 L .83636 .57569 L .861 .827 .813 r

F

.85508 .55859 m .8431 .57513 L .83636 .57569 L .819 .893 .896 r

F

0 g

.8383 .58829 m

.8431 .57513 L

s

.83592 .64171 m .83382 .65133 L .82917 .64241 L .838 .552 .504 r

F

.83592 .64171 m .84057 .65061 L .83382 .65133 L F

.83156 .58888 m .82273 .60141 L .8248 .58947 L .871 .778 .756 r

F

.83636 .57569 m .83156 .58888 L .8248 .58947 L .861 .827 .813 r

F

.85334 .65819 m .88276 .64537 L .87986 .6356 L .508 .429 .702 r

F

.86117 .66575 m .88276 .64537 L .85334 .65819 L F

.85334 .65819 m .85445 .6665 L .84662 .65893 L .768 .382 .324 r

F

.85334 .65819 m .86117 .66575 L .85445 .6665 L F

0 g

.84729 .64989 m

.85334 .65819 L

s

.82241 .61253 m .81669 .62368 L .81563 .61317 L .871 .695 .662 r

F

.82241 .61253 m .82347 .62302 L .81669 .62368 L F

.82273 .60141 m .82241 .61253 L .81563 .61317 L .873 .736 .708 r

F

.82347 .62302 m .81895 .63365 L .81669 .62368 L .864 .653 .615 r

F

.82347 .62302 m .82574 .63297 L .81895 .63365 L F

.84057 .65061 m .83987 .65967 L .83382 .65133 L .812 .482 .429 r

F

.84057 .65061 m .84662 .65893 L .83987 .65967 L F

.82574 .63297 m .82239 .64312 L .81895 .63365 L .854 .606 .564 r

F

.82574 .63297 m .82917 .64241 L .82239 .64312 L F

.82273 .60141 m .81563 .61317 L .81594 .60202 L .873 .736 .708 r

F

.8248 .58947 m .82273 .60141 L .81594 .60202 L .871 .778 .756 r

F

.83636 .57569 m .8248 .58947 L .82959 .57625 L .861 .827 .813 r

F

.84834 .55911 m .83636 .57569 L .82959 .57625 L .819 .893 .896 r

F

.85508 .55859 m .83636 .57569 L .84834 .55911 L F

.82917 .64241 m .82704 .65206 L .82239 .64312 L .838 .552 .504 r

F

.82917 .64241 m .83382 .65133 L .82704 .65206 L F

.7112 .38929 m .73586 .3651 L .70282 .383 L .58 .613 .85 r

F

0 g

.53988 .34034 m

.76572 .43241 L

s

.7112 .38929 m .74255 .37242 L .73586 .3651 L .58 .613 .85 r

F

.7209 .39487 m .74255 .37242 L .7112 .38929 L F

.7112 .38929 m .71734 .40117 L .70761 .39559 L .77 .509 .54 r

F

.7112 .38929 m .7209 .39487 L .71734 .40117 L F

.70282 .383 m .7112 .38929 L .70761 .39559 L .808 .559 .561 r

F

.73232 .39954 m .74922 .37972 L .7209 .39487 L .58 .613 .85 r

F

.7209 .39487 m .74922 .37972 L .74255 .37242 L F

.7209 .39487 m .72877 .40585 L .71734 .40117 L .726 .453 .515 r

F

.7209 .39487 m .73232 .39954 L .72877 .40585 L F

0 g

.7112 .38929 m

.7209 .39487 L

s

.8248 .58947 m .81594 .60202 L .81801 .59006 L .871 .778 .756 r

F

.82959 .57625 m .8248 .58947 L .81801 .59006 L .861 .827 .813 r

F

.86117 .66575 m .86508 .67292 L .85445 .6665 L .675 .213 .147 r

F

.86117 .66575 m .87179 .67215 L .86508 .67292 L F

.86117 .66575 m .88566 .65515 L .88276 .64537 L .508 .429 .702 r

F

.87179 .67215 m .88566 .65515 L .86117 .66575 L F

0 g

.85334 .65819 m

.86117 .66575 L

s

.70282 .383 m .70761 .39559 L .69921 .38928 L .808 .559 .561 r

F

.70282 .383 m .72916 .35777 L .69559 .37606 L .58 .613 .85 r

F

.70282 .383 m .73586 .3651 L .72916 .35777 L F

.69559 .37606 m .70282 .383 L .69921 .38928 L .843 .606 .581 r

F

0 g

.70282 .383 m

.7112 .38929 L

s

.84662 .65893 m .84771 .66726 L .83987 .65967 L .768 .382 .324 r

F

.84662 .65893 m .85445 .6665 L .84771 .66726 L F

.73232 .39954 m .75588 .38701 L .74922 .37972 L .58 .613 .85 r

F

.74639 .40281 m .75588 .38701 L .73232 .39954 L F

.73232 .39954 m .74287 .40914 L .72877 .40585 L .666 .381 .48 r

F

.73232 .39954 m .74639 .40281 L .74287 .40914 L F

0 g

.7209 .39487 m

.73232 .39954 L

s

.81563 .61317 m .80987 .62434 L .80881 .61381 L .871 .695 .662 r

F

.81563 .61317 m .81669 .62368 L .80987 .62434 L F

.81594 .60202 m .81563 .61317 L .80881 .61381 L .873 .736 .708 r

F

.81669 .62368 m .81214 .63434 L .80987 .62434 L .864 .653 .615 r

F

.81669 .62368 m .81895 .63365 L .81214 .63434 L F

.83382 .65133 m .83309 .66041 L .82704 .65206 L .812 .482 .429 r

F

.83382 .65133 m .83987 .65967 L .83309 .66041 L F

.69559 .37606 m .72245 .35043 L .68948 .36851 L .58 .613 .85 r

F

.69559 .37606 m .72916 .35777 L .72245 .35043 L F

.69559 .37606 m .69921 .38928 L .69197 .38234 L .843 .606 .581 r

F

.68948 .36851 m .69559 .37606 L .69197 .38234 L .876 .655 .599 r

F

0 g

.69559 .37606 m

.70282 .383 L

s

.81895 .63365 m .81558 .64382 L .81214 .63434 L .854 .606 .564 r

F

.81895 .63365 m .82239 .64312 L .81558 .64382 L F

.81594 .60202 m .80881 .61381 L .80912 .60264 L .873 .736 .708 r

F

.81801 .59006 m .81594 .60202 L .80912 .60264 L .871 .778 .756 r

F

.85508 .55859 m .85003 .55833 L .84834 .55911 L .551 .912 .96 r

F

.85508 .55859 m .85677 .5578 L .85003 .55833 L F

0 g

.8431 .57513 m

.85508 .55859 L

s

.85508 .55859 m

.85508 .55859 L

s

.74639 .40281 m .76402 .40877 L .74287 .40914 L .553 .253 .413 r

F

.74639 .40281 m .76752 .40241 L .76402 .40877 L F

.74639 .40281 m .76253 .39428 L .75588 .38701 L .58 .613 .85 r

F

.76752 .40241 m .76253 .39428 L .74639 .40281 L F

0 g

.73232 .39954 m

.74639 .40281 L

s

.70761 .39559 m .71375 .4075 L .70401 .40191 L .77 .509 .54 r

F

.70761 .39559 m .71734 .40117 L .71375 .4075 L F

.69921 .38928 m .70761 .39559 L .70401 .40191 L .808 .559 .561 r

F

.82959 .57625 m .81801 .59006 L .8228 .57682 L .861 .827 .813 r

F

.84157 .55964 m .82959 .57625 L .8228 .57682 L .819 .893 .896 r

F

.84834 .55911 m .82959 .57625 L .84157 .55964 L F

.71734 .40117 m .72521 .4122 L .71375 .4075 L .726 .453 .515 r

F

.71734 .40117 m .72877 .40585 L .72521 .4122 L F

.82239 .64312 m .82024 .65278 L .81558 .64382 L .838 .552 .504 r

F

.82239 .64312 m .82704 .65206 L .82024 .65278 L F

.81801 .59006 m .80912 .60264 L .81119 .59066 L .871 .778 .756 r

F

.8228 .57682 m .81801 .59006 L .81119 .59066 L .861 .827 .813 r

F

.80881 .61381 m .80303 .62501 L .80196 .61445 L .871 .695 .662 r

F

.80881 .61381 m .80987 .62434 L .80303 .62501 L F

.80912 .60264 m .80881 .61381 L .80196 .61445 L .873 .736 .708 r

F

.80987 .62434 m .8053 .63503 L .80303 .62501 L .864 .653 .615 r

F

.80987 .62434 m .81214 .63434 L .8053 .63503 L F

.82704 .65206 m .82629 .66116 L .82024 .65278 L .812 .482 .429 r

F

.81214 .63434 m .80874 .64453 L .8053 .63503 L .854 .606 .564 r

F

.81214 .63434 m .81558 .64382 L .80874 .64453 L F

.80912 .60264 m .80196 .61445 L .80227 .60327 L .873 .736 .708 r

F

.81119 .59066 m .80912 .60264 L .80227 .60327 L .871 .778 .756 r

F

.84834 .55911 m .84326 .55885 L .84157 .55964 L .551 .912 .96 r

F

.84834 .55911 m .85003 .55833 L .84326 .55885 L F

.8228 .57682 m .81119 .59066 L .81598 .57739 L .861 .827 .813 r

F

.83478 .56018 m .8228 .57682 L .81598 .57739 L .819 .893 .896 r

F

.84157 .55964 m .8228 .57682 L .83478 .56018 L F

.81558 .64382 m .8134 .65351 L .80874 .64453 L .838 .552 .504 r

F

.81558 .64382 m .82024 .65278 L .8134 .65351 L F

.81119 .59066 m .80227 .60327 L .80434 .59126 L .871 .778 .756 r

F

.81598 .57739 m .81119 .59066 L .80434 .59126 L .861 .827 .813 r

F

.80196 .61445 m .79616 .62568 L .79509 .6151 L .871 .695 .662 r

F

.80196 .61445 m .80303 .62501 L .79616 .62568 L F

.80227 .60327 m .80196 .61445 L .79509 .6151 L .873 .736 .708 r

F

.80303 .62501 m .79843 .63572 L .79616 .62568 L .864 .653 .615 r

F

.80303 .62501 m .8053 .63503 L .79843 .63572 L F

.82024 .65278 m .81946 .6619 L .8134 .65351 L .812 .482 .429 r

F

.82024 .65278 m .82629 .66116 L .81946 .6619 L F

.8053 .63503 m .80187 .64525 L .79843 .63572 L .854 .606 .564 r

F

.8053 .63503 m .80874 .64453 L .80187 .64525 L F

.80227 .60327 m .79509 .6151 L .7954 .60389 L .873 .736 .708 r

F

.80434 .59126 m .80227 .60327 L .7954 .60389 L .871 .778 .756 r

F

.84157 .55964 m .83647 .55939 L .83478 .56018 L .551 .912 .96 r

F

.84157 .55964 m .84326 .55885 L .83647 .55939 L F

.81598 .57739 m .80434 .59126 L .80912 .57796 L .861 .827 .813 r

F

.82795 .56071 m .81598 .57739 L .80912 .57796 L .819 .893 .896 r

F

.83478 .56018 m .81598 .57739 L .82795 .56071 L F

.80874 .64453 m .80654 .65425 L .80187 .64525 L .838 .552 .504 r

F

.80874 .64453 m .8134 .65351 L .80654 .65425 L F

.80434 .59126 m .7954 .60389 L .79746 .59186 L .871 .778 .756 r

F

.80912 .57796 m .80434 .59126 L .79746 .59186 L .861 .827 .813 r

F

.79509 .6151 m .78925 .62636 L .78818 .61575 L .871 .695 .662 r

F

.79509 .6151 m .79616 .62568 L .78925 .62636 L F

.7954 .60389 m .79509 .6151 L .78818 .61575 L .873 .736 .708 r

F

.79616 .62568 m .79153 .63642 L .78925 .62636 L .864 .653 .615 r

F

.79616 .62568 m .79843 .63572 L .79153 .63642 L F

.8134 .65351 m .81259 .66266 L .80654 .65425 L .812 .482 .429 r

F

.8134 .65351 m .81946 .6619 L .81259 .66266 L F

.79843 .63572 m .79498 .64596 L .79153 .63642 L .854 .606 .564 r

F

.79843 .63572 m .80187 .64525 L .79498 .64596 L F

.7954 .60389 m .78818 .61575 L .78849 .60452 L .873 .736 .708 r

F

.79746 .59186 m .7954 .60389 L .78849 .60452 L .871 .778 .756 r

F

.83478 .56018 m .82965 .55992 L .82795 .56071 L .551 .912 .96 r

F

.83478 .56018 m .83647 .55939 L .82965 .55992 L F

.80912 .57796 m .79746 .59186 L .80224 .57853 L .861 .827 .813 r

F

.8211 .56125 m .80912 .57796 L .80224 .57853 L .819 .893 .896 r

F

.82795 .56071 m .80912 .57796 L .8211 .56125 L F

.80187 .64525 m .79964 .65498 L .79498 .64596 L .838 .552 .504 r

F

.80187 .64525 m .80654 .65425 L .79964 .65498 L F

.79746 .59186 m .78849 .60452 L .79055 .59246 L .871 .778 .756 r

F

.80224 .57853 m .79746 .59186 L .79055 .59246 L .861 .827 .813 r

F

.81946 .6619 m .82044 .67032 L .81259 .66266 L .768 .382 .324 r

F

.78849 .60452 m .78818 .61575 L .78125 .61641 L .873 .736 .708 r

F

.80654 .65425 m .8057 .66341 L .79964 .65498 L .812 .482 .429 r

F

.80654 .65425 m .81259 .66266 L .8057 .66341 L F

.78849 .60452 m .78125 .61641 L .78155 .60515 L .873 .736 .708 r

F

.79055 .59246 m .78849 .60452 L .78155 .60515 L .871 .778 .756 r

F

.82795 .56071 m .82279 .56046 L .8211 .56125 L .551 .912 .96 r

F

.82795 .56071 m .82965 .55992 L .82279 .56046 L F

.80224 .57853 m .79055 .59246 L .79533 .57911 L .861 .827 .813 r

F

.81422 .56179 m .80224 .57853 L .79533 .57911 L .819 .893 .896 r

F

.8211 .56125 m .80224 .57853 L .81422 .56179 L F

.79055 .59246 m .78155 .60515 L .78361 .59306 L .871 .778 .756 r

F

.79533 .57911 m .79055 .59246 L .78361 .59306 L .861 .827 .813 r

F

.81259 .66266 m .81355 .67109 L .8057 .66341 L .768 .382 .324 r

F

.81259 .66266 m .82044 .67032 L .81355 .67109 L F

.79964 .65498 m .8057 .66341 L .79878 .66417 L .812 .482 .429 r

F

.78361 .59306 m .78155 .60515 L .77459 .60578 L .871 .778 .756 r

F

.8211 .56125 m .81591 .56099 L .81422 .56179 L .551 .912 .96 r

F

.8211 .56125 m .82279 .56046 L .81591 .56099 L F

.79533 .57911 m .78361 .59306 L .78839 .57968 L .861 .827 .813 r

F

.80731 .56233 m .79533 .57911 L .78839 .57968 L .819 .893 .896 r

F

.81422 .56179 m .79533 .57911 L .80731 .56233 L F

.78361 .59306 m .77459 .60578 L .77665 .59367 L .871 .778 .756 r

F

.78839 .57968 m .78361 .59306 L .77665 .59367 L .861 .827 .813 r

F

.82044 .67032 m .8242 .6776 L .81355 .67109 L .675 .213 .147 r

F

.8057 .66341 m .80664 .67187 L .79878 .66417 L .768 .382 .324 r

F

.8057 .66341 m .81355 .67109 L .80664 .67187 L F

.81422 .56179 m .809 .56153 L .80731 .56233 L .551 .912 .96 r

F

.81422 .56179 m .81591 .56099 L .809 .56153 L F

.78839 .57968 m .77665 .59367 L .78142 .58026 L .861 .827 .813 r

F

.80037 .56287 m .78839 .57968 L .78142 .58026 L .819 .893 .896 r

F

.80731 .56233 m .78839 .57968 L .80037 .56287 L F

.78142 .58026 m .77665 .59367 L .76965 .59428 L .861 .827 .813 r

F

.81355 .67109 m .81728 .6784 L .80664 .67187 L .675 .213 .147 r

F

.81355 .67109 m .8242 .6776 L .81728 .6784 L F

.79878 .66417 m .80664 .67187 L .79969 .67265 L .768 .382 .324 r

F

.80731 .56233 m .80206 .56208 L .80037 .56287 L .551 .912 .96 r

F

.80731 .56233 m .809 .56153 L .80206 .56208 L F

.78142 .58026 m .76965 .59428 L .77443 .58085 L .861 .827 .813 r

F

.7934 .56342 m .78142 .58026 L .77443 .58085 L .819 .893 .896 r

F

.80037 .56287 m .78142 .58026 L .7934 .56342 L F

.80664 .67187 m .81034 .67919 L .79969 .67265 L .675 .213 .147 r

F

.80664 .67187 m .81728 .6784 L .81034 .67919 L F

.80037 .56287 m .79509 .56262 L .7934 .56342 L .551 .912 .96 r

F

.80037 .56287 m .80206 .56208 L .79509 .56262 L F

.78639 .56397 m .77443 .58085 L .7674 .58143 L .819 .893 .896 r

F

.7934 .56342 m .77443 .58085 L .78639 .56397 L F

.79969 .67265 m .81034 .67919 L .80336 .67999 L .675 .213 .147 r

F

.81728 .6784 m .82835 .68263 L .81034 .67919 L .371 0 0 r

F

.7934 .56342 m .78809 .56317 L .78639 .56397 L .551 .912 .96 r

F

.7934 .56342 m .79509 .56262 L .78809 .56317 L F

.77936 .56452 m .7674 .58143 L .76034 .58202 L .819 .893 .896 r

F

.78639 .56397 m .7674 .58143 L .77936 .56452 L F

.81034 .67919 m .82137 .68344 L .80336 .67999 L .371 0 0 r

F

.81034 .67919 m .82835 .68263 L .82137 .68344 L F

.78639 .56397 m .78105 .56372 L .77936 .56452 L .551 .912 .96 r

F

.78639 .56397 m .78809 .56317 L .78105 .56372 L F

.77936 .56452 m .76034 .58202 L .7723 .56507 L .819 .893 .896 r

F

.80336 .67999 m .81437 .68425 L .79636 .68079 L .371 0 0 r

F

.80336 .67999 m .82137 .68344 L .81437 .68425 L F

.77936 .56452 m .77399 .56427 L .7723 .56507 L .551 .912 .96 r

F

.77936 .56452 m .78105 .56372 L .77399 .56427 L F

.79636 .68079 m .81437 .68425 L .80734 .68507 L .371 0 0 r

F

.85677 .5578 m .80906 .68432 L .77399 .56427 L .862 .631 .587 r

F

0 g

.7886 1.15405 m

.79081 1.22396 L

s

.78137 .92617 m

.7886 1.15405 L

s

.77804 .82106 m

.78137 .92617 L

s

.77584 .75166 m

.77804 .82106 L

s

.76572 .43241 m

.77003 .5683 L

s

.77043 .58118 m

.77075 .59118 L

s

.77085 .59418 m

.77584 .75166 L

s

.85445 .6665 m .85834 .67369 L .84771 .66726 L .675 .213 .147 r

F

.85445 .6665 m .86508 .67292 L .85834 .67369 L F

.83987 .65967 m .84094 .66802 L .83309 .66041 L .768 .382 .324 r

F

.83987 .65967 m .84771 .66726 L .84094 .66802 L F

.82704 .65206 m .83309 .66041 L .82629 .66116 L .812 .482 .429 r

F

.87179 .67215 m .88857 .66495 L .88566 .65515 L .508 .429 .702 r

F

.88976 .67548 m .88857 .66495 L .87179 .67215 L F

.87179 .67215 m .88305 .67626 L .86508 .67292 L .371 0 0 r

F

.87179 .67215 m .88976 .67548 L .88305 .67626 L F

.84771 .66726 m .85157 .67447 L .84094 .66802 L .675 .213 .147 r

F

.84771 .66726 m .85834 .67369 L .85157 .67447 L F

.83309 .66041 m .83413 .66878 L .82629 .66116 L .768 .382 .324 r

F

.83309 .66041 m .84094 .66802 L .83413 .66878 L F

.86508 .67292 m .87632 .67705 L .85834 .67369 L .371 0 0 r

F

.86508 .67292 m .88305 .67626 L .87632 .67705 L F

.84094 .66802 m .84477 .67525 L .83413 .66878 L .675 .213 .147 r

F

.84094 .66802 m .85157 .67447 L .84477 .67525 L F

.82629 .66116 m .8273 .66955 L .81946 .6619 L .768 .382 .324 r

F

.82629 .66116 m .83413 .66878 L .8273 .66955 L F

.85834 .67369 m .86955 .67783 L .85157 .67447 L .371 0 0 r

F

.85834 .67369 m .87632 .67705 L .86955 .67783 L F

.88976 .67548 m .89148 .67475 L .88857 .66495 L .508 .429 .702 r

F

.83413 .66878 m .83794 .67603 L .8273 .66955 L .675 .213 .147 r

F

.83413 .66878 m .84477 .67525 L .83794 .67603 L F

.81946 .6619 m .8273 .66955 L .82044 .67032 L .768 .382 .324 r

F

.85157 .67447 m .86276 .67862 L .84477 .67525 L .371 0 0 r

F

.85157 .67447 m .86955 .67783 L .86276 .67862 L F

.8273 .66955 m .83108 .67681 L .82044 .67032 L .675 .213 .147 r

F

.8273 .66955 m .83794 .67603 L .83108 .67681 L F

.84477 .67525 m .85593 .67942 L .83794 .67603 L .371 0 0 r

F

.84477 .67525 m .86276 .67862 L .85593 .67942 L F

.82044 .67032 m .83108 .67681 L .8242 .6776 L .675 .213 .147 r

F

.83794 .67603 m .84908 .68022 L .83108 .67681 L .371 0 0 r

F

.83794 .67603 m .85593 .67942 L .84908 .68022 L F

.83108 .67681 m .8422 .68102 L .8242 .6776 L F

.83108 .67681 m .84908 .68022 L .8422 .68102 L F

.8242 .6776 m .83529 .68182 L .81728 .6784 L F

.8242 .6776 m .8422 .68102 L .83529 .68182 L F

.81728 .6784 m .83529 .68182 L .82835 .68263 L F

.85677 .5578 m .89148 .67475 L .80906 .68432 L .862 .631 .587 r

F

.68948 .36851 m .71572 .34307 L .68451 .36029 L .58 .613 .85 r

F

.68948 .36851 m .72245 .35043 L .71572 .34307 L F

.68948 .36851 m .69197 .38234 L .68584 .37477 L .876 .655 .599 r

F

.68451 .36029 m .68948 .36851 L .68584 .37477 L .91 .708 .617 r

F

0 g

.68948 .36851 m

.69559 .37606 L

s

.69921 .38928 m .70401 .40191 L .69559 .39559 L .808 .559 .561 r

F

.69197 .38234 m .69921 .38928 L .69559 .39559 L .843 .606 .581 r

F

.72877 .40585 m .73933 .4155 L .72521 .4122 L .666 .381 .48 r

F

.72877 .40585 m .74287 .40914 L .73933 .4155 L F

.69197 .38234 m .69559 .39559 L .68833 .38864 L .843 .606 .581 r

F

.68584 .37477 m .69197 .38234 L .68833 .38864 L .876 .655 .599 r

F

.68451 .36029 m .70898 .3357 L .68086 .35131 L .58 .613 .85 r

F

.68451 .36029 m .71572 .34307 L .70898 .3357 L F

.68451 .36029 m .68584 .37477 L .68086 .36655 L .91 .708 .617 r

F

.68086 .35131 m .68451 .36029 L .68086 .36655 L .944 .769 .634 r

F

0 g

.68451 .36029 m

.68948 .36851 L

s

.74287 .40914 m .76051 .41515 L .73933 .4155 L .553 .253 .413 r

F

.74287 .40914 m .76402 .40877 L .76051 .41515 L F

.70401 .40191 m .71016 .41386 L .70039 .40825 L .77 .509 .54 r

F

.70401 .40191 m .71375 .4075 L .71016 .41386 L F

.69559 .39559 m .70401 .40191 L .70039 .40825 L .808 .559 .561 r

F

.71375 .4075 m .72163 .41857 L .71016 .41386 L .726 .453 .515 r

F

.71375 .4075 m .72521 .4122 L .72163 .41857 L F

.68584 .37477 m .68833 .38864 L .68219 .38107 L .876 .655 .599 r

F

.68086 .36655 m .68584 .37477 L .68219 .38107 L .91 .708 .617 r

F

.69559 .39559 m .70039 .40825 L .69196 .40193 L .808 .559 .561 r

F

.68833 .38864 m .69559 .39559 L .69196 .40193 L .843 .606 .581 r

F

.72521 .4122 m .73577 .42189 L .72163 .41857 L .666 .381 .48 r

F

.72521 .4122 m .73933 .4155 L .73577 .42189 L F

.68833 .38864 m .69196 .40193 L .68468 .39497 L .843 .606 .581 r

F

.68219 .38107 m .68833 .38864 L .68468 .39497 L .876 .655 .599 r

F

.76752 .40241 m .76917 .40154 L .76253 .39428 L .58 .613 .85 r

F

.76402 .40877 m .76917 .40154 L .76752 .40241 L .215 0 .208 r

F

0 g

.74639 .40281 m

.76752 .40241 L

s

.76752 .40241 m

.76752 .40241 L

s

.68086 .35131 m .70223 .32831 L .67888 .34136 L .58 .613 .85 r

F

.68086 .35131 m .70898 .3357 L .70223 .32831 L F

.68086 .35131 m .68086 .36655 L .67719 .35757 L .944 .769 .634 r

F

.67888 .34136 m .68086 .35131 L .67719 .35757 L .975 .842 .646 r

F

0 g

.68086 .35131 m

.68451 .36029 L

s

.67719 .35757 m .68086 .36655 L .67719 .37284 L .944 .769 .634 r

F

.68086 .36655 m .68219 .38107 L .67719 .37284 L .91 .708 .617 r

F

.73933 .4155 m .75699 .42155 L .73577 .42189 L .553 .253 .413 r

F

.73933 .4155 m .76051 .41515 L .75699 .42155 L F

.76402 .40877 m .76568 .4079 L .76917 .40154 L .215 0 .208 r

F

.71016 .41386 m .71804 .42496 L .70654 .42024 L .726 .453 .515 r

F

.71016 .41386 m .72163 .41857 L .71804 .42496 L F

.72163 .41857 m .73221 .42829 L .71804 .42496 L .666 .381 .48 r

F

.72163 .41857 m .73577 .42189 L .73221 .42829 L F

.76051 .41515 m .76568 .4079 L .76402 .40877 L .215 0 .208 r

F

.73577 .42189 m .75345 .42798 L .73221 .42829 L .553 .253 .413 r

F

.73577 .42189 m .75699 .42155 L .75345 .42798 L F

.76051 .41515 m .76217 .41428 L .76568 .4079 L .215 0 .208 r

F

.70654 .42024 m .71804 .42496 L .71443 .43138 L .726 .453 .515 r

F

.67888 .34136 m .69547 .32091 L .67951 .32988 L .58 .613 .85 r

F

.67888 .34136 m .70223 .32831 L .69547 .32091 L F

.71804 .42496 m .72863 .43473 L .71443 .43138 L .666 .381 .48 r

F

.71804 .42496 m .73221 .42829 L .72863 .43473 L F

.75699 .42155 m .76217 .41428 L .76051 .41515 L .215 0 .208 r

F

.73221 .42829 m .7499 .43444 L .72863 .43473 L .553 .253 .413 r

F

.73221 .42829 m .75345 .42798 L .7499 .43444 L F

.75699 .42155 m .75864 .42069 L .76217 .41428 L .215 0 .208 r

F

.71443 .43138 m .72503 .44119 L .71082 .43782 L .666 .381 .48 r

F

.71443 .43138 m .72863 .43473 L .72503 .44119 L F

.75345 .42798 m .75864 .42069 L .75699 .42155 L .215 0 .208 r

F

.67951 .32988 m .69547 .32091 L .68869 .3135 L .58 .613 .85 r

F

.72863 .43473 m .74633 .44092 L .72503 .44119 L .553 .253 .413 r

F

.72863 .43473 m .7499 .43444 L .74633 .44092 L F

.75345 .42798 m .75511 .42712 L .75864 .42069 L .215 0 .208 r

F

.71082 .43782 m .72142 .44767 L .70718 .44429 L .666 .381 .48 r

F

.71082 .43782 m .72503 .44119 L .72142 .44767 L F

.7499 .43444 m .75511 .42712 L .75345 .42798 L .215 0 .208 r

F

.72503 .44119 m .74275 .44743 L .72142 .44767 L .553 .253 .413 r

F

.72503 .44119 m .74633 .44092 L .74275 .44743 L F

.7499 .43444 m .75156 .43358 L .75511 .42712 L .215 0 .208 r

F

.70718 .44429 m .72142 .44767 L .71779 .45419 L .666 .381 .48 r

F

.74633 .44092 m .75156 .43358 L .7499 .43444 L .215 0 .208 r

F

.72142 .44767 m .73915 .45396 L .71779 .45419 L .553 .253 .413 r

F

.72142 .44767 m .74275 .44743 L .73915 .45396 L F

.74633 .44092 m .74799 .44006 L .75156 .43358 L .215 0 .208 r

F

.74275 .44743 m .74799 .44006 L .74633 .44092 L F

.71779 .45419 m .73555 .46052 L .71416 .46072 L .553 .253 .413 r

F

.71779 .45419 m .73915 .45396 L .73555 .46052 L F

.74275 .44743 m .74441 .44657 L .74799 .44006 L .215 0 .208 r

F

.73915 .45396 m .74441 .44657 L .74275 .44743 L F

.71416 .46072 m .73192 .46711 L .7105 .46729 L .553 .253 .413 r

F

.71416 .46072 m .73555 .46052 L .73192 .46711 L F

.73915 .45396 m .74082 .45311 L .74441 .44657 L .215 0 .208 r

F

.73555 .46052 m .74082 .45311 L .73915 .45396 L F

.7105 .46729 m .72828 .47372 L .70683 .47388 L .553 .253 .413 r

F

.7105 .46729 m .73192 .46711 L .72828 .47372 L F

.73555 .46052 m .73721 .45967 L .74082 .45311 L .215 0 .208 r

F

.73192 .46711 m .73721 .45967 L .73555 .46052 L F

.70683 .47388 m .72828 .47372 L .72463 .48036 L .553 .253 .413 r

F

.73192 .46711 m .73359 .46626 L .73721 .45967 L .215 0 .208 r

F

.72828 .47372 m .73359 .46626 L .73192 .46711 L F

.72828 .47372 m .72995 .47287 L .73359 .46626 L F

.72463 .48036 m .72995 .47287 L .72828 .47372 L F

.72463 .48036 m .7263 .47951 L .72995 .47287 L F

.68869 .3135 m .76917 .40154 L .7263 .47951 L .862 .631 .587 r

F

.70039 .40825 m .70654 .42024 L .69676 .41462 L .77 .509 .54 r

F

.70039 .40825 m .71016 .41386 L .70654 .42024 L F

.69196 .40193 m .70039 .40825 L .69676 .41462 L .808 .559 .561 r

F

.68219 .38107 m .68468 .39497 L .67852 .38739 L .876 .655 .599 r

F

.67719 .37284 m .68219 .38107 L .67852 .38739 L .91 .708 .617 r

F

.69196 .40193 m .69676 .41462 L .68831 .40829 L .808 .559 .561 r

F

.68468 .39497 m .69196 .40193 L .68831 .40829 L .843 .606 .581 r

F

.68468 .39497 m .68831 .40829 L .68102 .40132 L F

.67852 .38739 m .68468 .39497 L .68102 .40132 L .876 .655 .599 r

F

.67719 .35757 m .67719 .37284 L .6735 .36385 L .944 .769 .634 r

F

.67519 .34761 m .67719 .35757 L .6735 .36385 L .975 .842 .646 r

F

.67888 .34136 m .67719 .35757 L .67519 .34761 L F

.67719 .37284 m .67852 .38739 L .67351 .37915 L .91 .708 .617 r

F

.6735 .36385 m .67719 .37284 L .67351 .37915 L .944 .769 .634 r

F

.69676 .41462 m .70292 .42665 L .69312 .42102 L .77 .509 .54 r

F

.69676 .41462 m .70654 .42024 L .70292 .42665 L F

.68831 .40829 m .69676 .41462 L .69312 .42102 L .808 .559 .561 r

F

.70654 .42024 m .71443 .43138 L .70292 .42665 L .726 .453 .515 r

F

.67951 .32988 m .67888 .34136 L .67519 .34761 L .976 .922 .633 r

F

0 g

.67888 .34136 m

.68086 .35131 L

s

.88305 .67626 m .89148 .67475 L .88976 .67548 L .5 .899 .934 r

F

0 g

.888 .67516 m

.8886 .67527 L

s

.88976 .67548 m

.88976 .67548 L

s

.67852 .38739 m .68102 .40132 L .67484 .39373 L .876 .655 .599 r

F

.67351 .37915 m .67852 .38739 L .67484 .39373 L .91 .708 .617 r

F

.68831 .40829 m .69312 .42102 L .68464 .41467 L .808 .559 .561 r

F

.68102 .40132 m .68831 .40829 L .68464 .41467 L .843 .606 .581 r

F

.88305 .67626 m .88477 .67553 L .89148 .67475 L .5 .899 .934 r

F

0 g

.85677 .5578 m

.89148 .67475 L

s

.68102 .40132 m .68464 .41467 L .67734 .40769 L .843 .606 .581 r

F

.67484 .39373 m .68102 .40132 L .67734 .40769 L .876 .655 .599 r

F

.78818 .61575 m .78232 .62703 L .78125 .61641 L .871 .695 .662 r

F

.78818 .61575 m .78925 .62636 L .78232 .62703 L F

.78925 .62636 m .7846 .63711 L .78232 .62703 L .864 .653 .615 r

F

.78925 .62636 m .79153 .63642 L .7846 .63711 L F

.6735 .36385 m .67351 .37915 L .66981 .37016 L .944 .769 .634 r

F

.6715 .35389 m .6735 .36385 L .66981 .37016 L .975 .842 .646 r

F

.67519 .34761 m .6735 .36385 L .6715 .35389 L F

.66981 .37016 m .67351 .37915 L .66981 .38549 L .944 .769 .634 r

F

.67351 .37915 m .67484 .39373 L .66981 .38549 L .91 .708 .617 r

F

.79153 .63642 m .78805 .64668 L .7846 .63711 L .854 .606 .564 r

F

.79153 .63642 m .79498 .64596 L .78805 .64668 L F

.69312 .42102 m .69928 .43308 L .68946 .42744 L .77 .509 .54 r

F

.69312 .42102 m .70292 .42665 L .69928 .43308 L F

.68464 .41467 m .69312 .42102 L .68946 .42744 L .808 .559 .561 r

F

.70292 .42665 m .71082 .43782 L .69928 .43308 L .726 .453 .515 r

F

.70292 .42665 m .71443 .43138 L .71082 .43782 L F

.67581 .33613 m .67519 .34761 L .6715 .35389 L .976 .922 .633 r

F

.67951 .32988 m .67519 .34761 L .67581 .33613 L F

.67484 .39373 m .67734 .40769 L .67114 .4001 L .876 .655 .599 r

F

.66981 .38549 m .67484 .39373 L .67114 .4001 L .91 .708 .617 r

F

.68464 .41467 m .68946 .42744 L .68097 .42108 L .808 .559 .561 r

F

.67734 .40769 m .68464 .41467 L .68097 .42108 L .843 .606 .581 r

F

.87632 .67705 m .88477 .67553 L .88305 .67626 L .5 .899 .934 r

F

0 g

.88305 .67626 m

.88976 .67548 L

s

.79498 .64596 m .79272 .65572 L .78805 .64668 L .838 .552 .504 r

F

.79498 .64596 m .79964 .65498 L .79272 .65572 L F

.87632 .67705 m .87804 .67631 L .88477 .67553 L .5 .899 .934 r

F

.67734 .40769 m .68097 .42108 L .67364 .4141 L .843 .606 .581 r

F

.67114 .4001 m .67734 .40769 L .67364 .4141 L .876 .655 .599 r

F

.67951 .32988 m .68869 .3135 L .68706 .31442 L .58 .613 .85 r

F

.68706 .31442 m .67951 .32988 L .67581 .33613 L .718 .858 .436 r

F

0 g

.67888 .34136 m

.67951 .32988 L

s

.78125 .61641 m .77536 .62771 L .77429 .61707 L .871 .695 .662 r

F

.78125 .61641 m .78232 .62703 L .77536 .62771 L F

.78155 .60515 m .78125 .61641 L .77429 .61707 L .873 .736 .708 r

F

.78232 .62703 m .77765 .63782 L .77536 .62771 L .864 .653 .615 r

F

.78232 .62703 m .7846 .63711 L .77765 .63782 L F

.66981 .37016 m .66981 .38549 L .66609 .37649 L .944 .769 .634 r

F

.66779 .36019 m .66981 .37016 L .66609 .37649 L .975 .842 .646 r

F

.6715 .35389 m .66981 .37016 L .66779 .36019 L F

.79964 .65498 m .79878 .66417 L .79272 .65572 L .812 .482 .429 r

F

.66981 .38549 m .67114 .4001 L .6661 .39185 L .91 .708 .617 r

F

.66609 .37649 m .66981 .38549 L .6661 .39185 L .944 .769 .634 r

F

.68946 .42744 m .69562 .43954 L .68578 .43388 L .77 .509 .54 r

F

.68946 .42744 m .69928 .43308 L .69562 .43954 L F

.68097 .42108 m .68946 .42744 L .68578 .43388 L .808 .559 .561 r

F

.69928 .43308 m .70718 .44429 L .69562 .43954 L .726 .453 .515 r

F

.69928 .43308 m .71082 .43782 L .70718 .44429 L F

.7846 .63711 m .78109 .6474 L .77765 .63782 L .854 .606 .564 r

F

.7846 .63711 m .78805 .64668 L .78109 .6474 L F

.78155 .60515 m .77429 .61707 L .77459 .60578 L .873 .736 .708 r

F

.67211 .34241 m .6715 .35389 L .66779 .36019 L .976 .922 .633 r

F

.67581 .33613 m .6715 .35389 L .67211 .34241 L F

.67114 .4001 m .67364 .4141 L .66743 .40649 L .876 .655 .599 r

F

.6661 .39185 m .67114 .4001 L .66743 .40649 L .91 .708 .617 r

F

.68097 .42108 m .68578 .43388 L .67727 .42752 L .808 .559 .561 r

F

.67364 .4141 m .68097 .42108 L .67727 .42752 L .843 .606 .581 r

F

.86955 .67783 m .87804 .67631 L .87632 .67705 L .5 .899 .934 r

F

0 g

.87632 .67705 m

.88305 .67626 L

s

.78805 .64668 m .78576 .65646 L .78109 .6474 L .838 .552 .504 r

F

.78805 .64668 m .79272 .65572 L .78576 .65646 L F

.86955 .67783 m .87127 .6771 L .87804 .67631 L .5 .899 .934 r

F

.67364 .4141 m .67727 .42752 L .66993 .42052 L .843 .606 .581 r

F

.66743 .40649 m .67364 .4141 L .66993 .42052 L .876 .655 .599 r

F

.68336 .32067 m .67581 .33613 L .67211 .34241 L .718 .858 .436 r

F

.68706 .31442 m .67581 .33613 L .68336 .32067 L F

.66609 .37649 m .6661 .39185 L .66237 .38284 L .944 .769 .634 r

F

.66406 .36652 m .66609 .37649 L .66237 .38284 L .975 .842 .646 r

F

.66779 .36019 m .66609 .37649 L .66406 .36652 L F

.66237 .38284 m .6661 .39185 L .66237 .39823 L .944 .769 .634 r

F

.6661 .39185 m .66743 .40649 L .66237 .39823 L .91 .708 .617 r

F

.77429 .61707 m .76837 .6284 L .7673 .61772 L .871 .695 .662 r

F

.77429 .61707 m .77536 .62771 L .76837 .6284 L F

.77459 .60578 m .77429 .61707 L .7673 .61772 L .873 .736 .708 r

F

.77536 .62771 m .77066 .63852 L .76837 .6284 L .864 .653 .615 r

F

.77536 .62771 m .77765 .63782 L .77066 .63852 L F

.79272 .65572 m .79183 .66493 L .78576 .65646 L .812 .482 .429 r

F

.79272 .65572 m .79878 .66417 L .79183 .66493 L F

.68578 .43388 m .69195 .44602 L .68209 .44035 L .77 .509 .54 r

F

.68578 .43388 m .69562 .43954 L .69195 .44602 L F

.67727 .42752 m .68578 .43388 L .68209 .44035 L .808 .559 .561 r

F

.69562 .43954 m .70353 .45079 L .69195 .44602 L .726 .453 .515 r

F

.69562 .43954 m .70718 .44429 L .70353 .45079 L F

.66839 .34871 m .66779 .36019 L .66406 .36652 L .976 .922 .633 r

F

.67211 .34241 m .66779 .36019 L .66839 .34871 L F

.77765 .63782 m .77411 .64813 L .77066 .63852 L .854 .606 .564 r

F

.77765 .63782 m .78109 .6474 L .77411 .64813 L F

.77459 .60578 m .7673 .61772 L .76759 .60642 L .873 .736 .708 r

F

.77665 .59367 m .77459 .60578 L .76759 .60642 L .871 .778 .756 r

F

.66743 .40649 m .66993 .42052 L .6637 .41291 L .876 .655 .599 r

F

.66237 .39823 m .66743 .40649 L .6637 .41291 L .91 .708 .617 r

F

.67727 .42752 m .68209 .44035 L .67357 .43398 L .808 .559 .561 r

F

.66993 .42052 m .67727 .42752 L .67357 .43398 L .843 .606 .581 r

F

.70718 .44429 m .71779 .45419 L .70353 .45079 L .666 .381 .48 r

F

.86276 .67862 m .87127 .6771 L .86955 .67783 L .5 .899 .934 r

F

0 g

.86955 .67783 m

.87632 .67705 L

s

.78109 .6474 m .77878 .65721 L .77411 .64813 L .838 .552 .504 r

F

.78109 .6474 m .78576 .65646 L .77878 .65721 L F

.66993 .42052 m .67357 .43398 L .66621 .42698 L .843 .606 .581 r

F

.6637 .41291 m .66993 .42052 L .66621 .42698 L .876 .655 .599 r

F

.86276 .67862 m .86448 .67789 L .87127 .6771 L .5 .899 .934 r

F

.77665 .59367 m .76759 .60642 L .76965 .59428 L .871 .778 .756 r

F

.79878 .66417 m .79969 .67265 L .79183 .66493 L .768 .382 .324 r

F

.68336 .32067 m .67211 .34241 L .67965 .32695 L .718 .858 .436 r

F

.67965 .32695 m .67211 .34241 L .66839 .34871 L F

.66237 .38284 m .66237 .39823 L .65863 .38922 L .944 .769 .634 r

F

.66032 .37287 m .66237 .38284 L .65863 .38922 L .975 .842 .646 r

F

.66406 .36652 m .66237 .38284 L .66032 .37287 L F

.66237 .39823 m .6637 .41291 L .65863 .40465 L .91 .708 .617 r

F

.65863 .38922 m .66237 .39823 L .65863 .40465 L .944 .769 .634 r

F

.68209 .44035 m .68827 .45253 L .67839 .44685 L .77 .509 .54 r

F

.68209 .44035 m .69195 .44602 L .68827 .45253 L F

.67357 .43398 m .68209 .44035 L .67839 .44685 L .808 .559 .561 r

F

.69195 .44602 m .69987 .45731 L .68827 .45253 L .726 .453 .515 r

F

.69195 .44602 m .70353 .45079 L .69987 .45731 L F

.76759 .60642 m .7673 .61772 L .76027 .61839 L .873 .736 .708 r

F

.7673 .61772 m .76135 .62908 L .76027 .61839 L .871 .695 .662 r

F

.7673 .61772 m .76837 .6284 L .76135 .62908 L F

.76837 .6284 m .76364 .63923 L .76135 .62908 L .864 .653 .615 r

F

.76837 .6284 m .77066 .63852 L .76364 .63923 L F

.78576 .65646 m .78485 .6657 L .77878 .65721 L .812 .482 .429 r

F

.78576 .65646 m .79183 .66493 L .78485 .6657 L F

.66465 .35503 m .66406 .36652 L .66032 .37287 L .976 .922 .633 r

F

.66839 .34871 m .66406 .36652 L .66465 .35503 L F

.6637 .41291 m .66621 .42698 L .65996 .41936 L .876 .655 .599 r

F

.65863 .40465 m .6637 .41291 L .65996 .41936 L .91 .708 .617 r

F

.67357 .43398 m .67839 .44685 L .66985 .44047 L .808 .559 .561 r

F

.66621 .42698 m .67357 .43398 L .66985 .44047 L .843 .606 .581 r

F

.77066 .63852 m .76709 .64886 L .76364 .63923 L .854 .606 .564 r

F

.77066 .63852 m .77411 .64813 L .76709 .64886 L F

.76759 .60642 m .76027 .61839 L .76057 .60706 L .873 .736 .708 r

F

.76965 .59428 m .76759 .60642 L .76057 .60706 L .871 .778 .756 r

F

.70353 .45079 m .71416 .46072 L .69987 .45731 L .666 .381 .48 r

F

.70353 .45079 m .71779 .45419 L .71416 .46072 L F

.85593 .67942 m .86448 .67789 L .86276 .67862 L .5 .899 .934 r

F

0 g

.86276 .67862 m

.86955 .67783 L

s

.68706 .31442 m .68499 .31975 L .68336 .32067 L .16 0 .152 r

F

0 g

.67951 .32988 m

.68425 .32017 L

s

.68706 .31442 m .68869 .3135 L .68499 .31975 L .16 0 .152 r

F

0 g

.68706 .31442 m

.68706 .31442 L

s

.77411 .64813 m .77177 .65796 L .76709 .64886 L .838 .552 .504 r

F

.77411 .64813 m .77878 .65721 L .77177 .65796 L F

.66621 .42698 m .66985 .44047 L .66247 .43345 L .843 .606 .581 r

F

.65996 .41936 m .66621 .42698 L .66247 .43345 L .876 .655 .599 r

F

.85593 .67942 m .85765 .67868 L .86448 .67789 L .5 .899 .934 r

F

.76965 .59428 m .76057 .60706 L .76262 .5949 L .871 .778 .756 r

F

.77443 .58085 m .76965 .59428 L .76262 .5949 L .861 .827 .813 r

F

.67592 .33325 m .66839 .34871 L .66465 .35503 L .718 .858 .436 r

F

.67965 .32695 m .66839 .34871 L .67592 .33325 L F

.65863 .38922 m .65863 .40465 L .65487 .39563 L .944 .769 .634 r

F

.65657 .37924 m .65863 .38922 L .65487 .39563 L .975 .842 .646 r

F

.66032 .37287 m .65863 .38922 L .65657 .37924 L F

.65487 .39563 m .65863 .40465 L .65487 .41108 L .944 .769 .634 r

F

.65863 .40465 m .65996 .41936 L .65487 .41108 L .91 .708 .617 r

F

.6609 .36138 m .66032 .37287 L .65657 .37924 L .976 .922 .633 r

F

.66465 .35503 m .66032 .37287 L .6609 .36138 L F

.69987 .45731 m .71416 .46072 L .7105 .46729 L .666 .381 .48 r

F

.67218 .33958 m .66465 .35503 L .6609 .36138 L .718 .858 .436 r

F

.67592 .33325 m .66465 .35503 L .67218 .33958 L F

.65487 .39563 m .65487 .41108 L .6511 .40206 L .944 .769 .634 r

F

.6528 .38565 m .65487 .39563 L .6511 .40206 L .975 .842 .646 r

F

.65657 .37924 m .65487 .39563 L .6528 .38565 L F

.6609 .36138 m .65657 .37924 L .65713 .36775 L .976 .922 .633 r

F

.65713 .36775 m .65657 .37924 L .6528 .38565 L F

.66842 .34593 m .6609 .36138 L .65713 .36775 L .718 .858 .436 r

F

.67218 .33958 m .6609 .36138 L .66842 .34593 L F

.64901 .39207 m .6511 .40206 L .64731 .40852 L .975 .842 .646 r

F

.6528 .38565 m .6511 .40206 L .64901 .39207 L F

.65335 .37416 m .6528 .38565 L .64901 .39207 L .976 .922 .633 r

F

.65713 .36775 m .6528 .38565 L .65335 .37416 L F

.66465 .35231 m .65713 .36775 L .65335 .37416 L .718 .858 .436 r

F

.66842 .34593 m .65713 .36775 L .66465 .35231 L F

.64901 .39207 m .64731 .40852 L .64521 .39853 L .975 .842 .646 r

F

.64955 .38058 m .64901 .39207 L .64521 .39853 L .976 .922 .633 r

F

.65335 .37416 m .64901 .39207 L .64955 .38058 L F

.66086 .35872 m .65335 .37416 L .64955 .38058 L .718 .858 .436 r

F

.66465 .35231 m .65335 .37416 L .66086 .35872 L F

.64574 .38703 m .64521 .39853 L .6414 .40501 L .976 .922 .633 r

F

.64955 .38058 m .64521 .39853 L .64574 .38703 L F

.65706 .36515 m .64955 .38058 L .64574 .38703 L .718 .858 .436 r

F

.66086 .35872 m .64955 .38058 L .65706 .36515 L F

.64574 .38703 m .6414 .40501 L .64192 .39351 L .976 .922 .633 r

F

.65324 .3716 m .64574 .38703 L .64192 .39351 L .718 .858 .436 r

F

.65706 .36515 m .64574 .38703 L .65324 .3716 L F

.64941 .37809 m .64192 .39351 L .63807 .40002 L F

.65324 .3716 m .64192 .39351 L .64941 .37809 L F

.68869 .3135 m .7263 .47951 L .64334 .39023 L .862 .631 .587 r

F

0 g

.68869 .3135 m

.76917 .40154 L

s

.70389 .24449 m

.93231 .34642 L

s

.79183 .66493 m .79271 .67343 L .78485 .6657 L .768 .382 .324 r

F

.79183 .66493 m .79969 .67265 L .79271 .67343 L F

.67839 .44685 m .68457 .45906 L .67467 .45337 L .77 .509 .54 r

F

.67839 .44685 m .68827 .45253 L .68457 .45906 L F

.66985 .44047 m .67839 .44685 L .67467 .45337 L .808 .559 .561 r

F

.68827 .45253 m .69619 .46386 L .68457 .45906 L .726 .453 .515 r

F

.68827 .45253 m .69987 .45731 L .69619 .46386 L F

.76027 .61839 m .7543 .62977 L .75322 .61905 L .871 .695 .662 r

F

.76027 .61839 m .76135 .62908 L .7543 .62977 L F

.76057 .60706 m .76027 .61839 L .75322 .61905 L .873 .736 .708 r

F

.76135 .62908 m .75659 .63994 L .7543 .62977 L .864 .653 .615 r

F

.76135 .62908 m .76364 .63923 L .75659 .63994 L F

.77878 .65721 m .77784 .66646 L .77177 .65796 L .812 .482 .429 r

F

.77878 .65721 m .78485 .6657 L .77784 .66646 L F

.65996 .41936 m .66247 .43345 L .6562 .42583 L .876 .655 .599 r

F

.65487 .41108 m .65996 .41936 L .6562 .42583 L .91 .708 .617 r

F

.66985 .44047 m .67467 .45337 L .66611 .44698 L .808 .559 .561 r

F

.66247 .43345 m .66985 .44047 L .66611 .44698 L .843 .606 .581 r

F

.69987 .45731 m .7105 .46729 L .69619 .46386 L .666 .381 .48 r

F

.76364 .63923 m .76005 .64959 L .75659 .63994 L .854 .606 .564 r

F

.76364 .63923 m .76709 .64886 L .76005 .64959 L F

.76057 .60706 m .75322 .61905 L .75352 .6077 L .873 .736 .708 r

F

.76262 .5949 m .76057 .60706 L .75352 .6077 L .871 .778 .756 r

F

.68336 .32067 m .68128 .32603 L .67965 .32695 L .16 0 .152 r

F

.68336 .32067 m .68499 .31975 L .68128 .32603 L F

0 g

.68336 .32067 m

.68706 .31442 L

s

.84908 .68022 m .85765 .67868 L .85593 .67942 L .5 .899 .934 r

F

0 g

.85593 .67942 m

.86276 .67862 L

s

.66247 .43345 m .66611 .44698 L .65871 .43996 L .843 .606 .581 r

F

.6562 .42583 m .66247 .43345 L .65871 .43996 L .876 .655 .599 r

F

.77443 .58085 m .76262 .5949 L .7674 .58143 L .861 .827 .813 r

F

.76709 .64886 m .76472 .65871 L .76005 .64959 L .838 .552 .504 r

F

.76709 .64886 m .77177 .65796 L .76472 .65871 L F

.84908 .68022 m .8508 .67948 L .85765 .67868 L .5 .899 .934 r

F

.76262 .5949 m .75352 .6077 L .75556 .59551 L .871 .778 .756 r

F

.7674 .58143 m .76262 .5949 L .75556 .59551 L .861 .827 .813 r

F

.79969 .67265 m .80336 .67999 L .79271 .67343 L .675 .213 .147 r

F

.78485 .6657 m .7857 .67421 L .77784 .66646 L .768 .382 .324 r

F

.78485 .6657 m .79271 .67343 L .7857 .67421 L F

.65487 .41108 m .6562 .42583 L .6511 .41755 L .91 .708 .617 r

F

.6511 .40206 m .65487 .41108 L .6511 .41755 L .944 .769 .634 r

F

.67467 .45337 m .68086 .46562 L .67094 .45992 L .77 .509 .54 r

F

.67467 .45337 m .68457 .45906 L .68086 .46562 L F

.66611 .44698 m .67467 .45337 L .67094 .45992 L .808 .559 .561 r

F

.68457 .45906 m .6925 .47043 L .68086 .46562 L .726 .453 .515 r

F

.68457 .45906 m .69619 .46386 L .6925 .47043 L F

.6562 .42583 m .65871 .43996 L .65243 .43232 L .876 .655 .599 r

F

.6511 .41755 m .6562 .42583 L .65243 .43232 L .91 .708 .617 r

F

.75322 .61905 m .78855 .6141 L .7543 .62977 L .497 .421 .701 r

F

.75322 .61905 m .78563 .60411 L .78855 .6141 L F

.75352 .6077 m .78563 .60411 L .75322 .61905 L F

.7543 .62977 m .79147 .6241 L .75659 .63994 L F

.7543 .62977 m .78855 .6141 L .79147 .6241 L F

0 g

.75322 .61905 m

.7543 .62977 L

s

.77177 .65796 m .7708 .66723 L .76472 .65871 L .812 .482 .429 r

F

.77177 .65796 m .77784 .66646 L .7708 .66723 L F

.66611 .44698 m .67094 .45992 L .66236 .45352 L .808 .559 .561 r

F

.65871 .43996 m .66611 .44698 L .66236 .45352 L .843 .606 .581 r

F

.69619 .46386 m .70683 .47388 L .6925 .47043 L .666 .381 .48 r

F

.69619 .46386 m .7105 .46729 L .70683 .47388 L F

.75659 .63994 m .79439 .63411 L .76005 .64959 L .497 .421 .701 r

F

.75659 .63994 m .79147 .6241 L .79439 .63411 L F

0 g

.7543 .62977 m

.75659 .63994 L

s

.75352 .6077 m .78272 .59413 L .78563 .60411 L .497 .421 .701 r

F

.75556 .59551 m .78272 .59413 L .75352 .6077 L F

0 g

.75322 .61905 m

.75352 .6077 L

s

.67965 .32695 m .67756 .33233 L .67592 .33325 L .16 0 .152 r

F

.67965 .32695 m .68128 .32603 L .67756 .33233 L F

0 g

.67965 .32695 m

.68336 .32067 L

s

.8422 .68102 m .8508 .67948 L .84908 .68022 L .5 .899 .934 r

F

0 g

.84908 .68022 m

.85593 .67942 L

s

.65871 .43996 m .66236 .45352 L .65494 .44649 L .843 .606 .581 r

F

.65243 .43232 m .65871 .43996 L .65494 .44649 L .876 .655 .599 r

F

.7674 .58143 m .75556 .59551 L .76034 .58202 L .861 .827 .813 r

F

.76005 .64959 m .79732 .64413 L .76472 .65871 L .497 .421 .701 r

F

.76005 .64959 m .79439 .63411 L .79732 .64413 L F

0 g

.75659 .63994 m

.76005 .64959 L

s

.8422 .68102 m .84392 .68027 L .8508 .67948 L .5 .899 .934 r

F

.75556 .59551 m .7798 .58417 L .78272 .59413 L .497 .421 .701 r

F

.76034 .58202 m .7798 .58417 L .75556 .59551 L F

0 g

.75352 .6077 m

.75556 .59551 L

s

.6511 .40206 m .6511 .41755 L .64731 .40852 L .944 .769 .634 r

F

.79271 .67343 m .79636 .68079 L .7857 .67421 L .675 .213 .147 r

F

.79271 .67343 m .80336 .67999 L .79636 .68079 L F

.6511 .41755 m .65243 .43232 L .64731 .42404 L .91 .708 .617 r

F

.64731 .40852 m .6511 .41755 L .64731 .42404 L .944 .769 .634 r

F

.77784 .66646 m .77866 .675 L .7708 .66723 L .768 .382 .324 r

F

.77784 .66646 m .7857 .67421 L .77866 .675 L F

.67094 .45992 m .67713 .47221 L .66719 .4665 L .77 .509 .54 r

F

.67094 .45992 m .68086 .46562 L .67713 .47221 L F

.66236 .45352 m .67094 .45992 L .66719 .4665 L .808 .559 .561 r

F

.68086 .46562 m .6888 .47703 L .67713 .47221 L .726 .453 .515 r

F

.68086 .46562 m .6925 .47043 L .6888 .47703 L F

.65243 .43232 m .65494 .44649 L .64865 .43885 L .876 .655 .599 r

F

.64731 .42404 m .65243 .43232 L .64865 .43885 L .91 .708 .617 r

F

.66236 .45352 m .66719 .4665 L .65859 .46009 L .808 .559 .561 r

F

.65494 .44649 m .66236 .45352 L .65859 .46009 L .843 .606 .581 r

F

.76472 .65871 m .80025 .65416 L .7708 .66723 L .497 .421 .701 r

F

.76472 .65871 m .79732 .64413 L .80025 .65416 L F

0 g

.76005 .64959 m

.76472 .65871 L

s

.6925 .47043 m .70315 .48049 L .6888 .47703 L .666 .381 .48 r

F

.6925 .47043 m .70683 .47388 L .70315 .48049 L F

.67592 .33325 m .67382 .33866 L .67218 .33958 L .16 0 .152 r

F

.67592 .33325 m .67756 .33233 L .67382 .33866 L F

0 g

.67592 .33325 m

.67965 .32695 L

s

.65494 .44649 m .65859 .46009 L .65116 .45305 L .843 .606 .581 r

F

.64865 .43885 m .65494 .44649 L .65116 .45305 L .876 .655 .599 r

F

.83529 .68182 m .84392 .68027 L .8422 .68102 L .5 .899 .934 r

F

0 g

.8422 .68102 m

.84908 .68022 L

s

.76034 .58202 m .7769 .57421 L .7798 .58417 L .497 .421 .701 r

F

.7723 .56507 m .7769 .57421 L .76034 .58202 L F

0 g

.75556 .59551 m

.76034 .58202 L

s

.64731 .40852 m .64731 .42404 L .64351 .41501 L .944 .769 .634 r

F

.64521 .39853 m .64731 .40852 L .64351 .41501 L .975 .842 .646 r

F

.83529 .68182 m .83701 .68108 L .84392 .68027 L .5 .899 .934 r

F

.64731 .42404 m .64865 .43885 L .64351 .43055 L .91 .708 .617 r

F

.64351 .41501 m .64731 .42404 L .64351 .43055 L .944 .769 .634 r

F

.70683 .47388 m .72463 .48036 L .70315 .48049 L .553 .253 .413 r

F

.7857 .67421 m .78932 .6816 L .77866 .675 L .675 .213 .147 r

F

.7857 .67421 m .79636 .68079 L .78932 .6816 L F

.66719 .4665 m .70574 .45739 L .67713 .47221 L .572 .614 .856 r

F

.66719 .4665 m .69886 .44998 L .70574 .45739 L F

.65859 .46009 m .69886 .44998 L .66719 .4665 L F

.67713 .47221 m .71261 .46478 L .6888 .47703 L F

.67713 .47221 m .70574 .45739 L .71261 .46478 L F

0 g

.66719 .4665 m

.67713 .47221 L

s

.7708 .66723 m .80318 .6642 L .77866 .675 L .497 .421 .701 r

F

.7708 .66723 m .80025 .65416 L .80318 .6642 L F

0 g

.76472 .65871 m

.7708 .66723 L

s

.64865 .43885 m .65116 .45305 L .64485 .44539 L .876 .655 .599 r

F

.64351 .43055 m .64865 .43885 L .64485 .44539 L .91 .708 .617 r

F

.65859 .46009 m .69197 .44257 L .69886 .44998 L .572 .614 .856 r

F

.65116 .45305 m .69197 .44257 L .65859 .46009 L F

0 g

.65859 .46009 m

.66719 .4665 L

s

.6888 .47703 m .71946 .47215 L .70315 .48049 L .572 .614 .856 r

F

.6888 .47703 m .71261 .46478 L .71946 .47215 L F

0 g

.67713 .47221 m

.6888 .47703 L

s

.67218 .33958 m .67006 .34502 L .66842 .34593 L .16 0 .152 r

F

.67218 .33958 m .67382 .33866 L .67006 .34502 L F

0 g

.67218 .33958 m

.67592 .33325 L

s

.65116 .45305 m .68507 .43513 L .69197 .44257 L .572 .614 .856 r

F

.64485 .44539 m .68507 .43513 L .65116 .45305 L F

0 g

.65116 .45305 m

.65859 .46009 L

s

.82835 .68263 m .83701 .68108 L .83529 .68182 L .5 .899 .934 r

F

0 g

.83529 .68182 m

.8422 .68102 L

s

.64351 .41501 m .64351 .43055 L .63969 .42152 L .944 .769 .634 r

F

.6414 .40501 m .64351 .41501 L .63969 .42152 L .975 .842 .646 r

F

.64521 .39853 m .64351 .41501 L .6414 .40501 L F

.64351 .43055 m .64485 .44539 L .63969 .4371 L .91 .708 .617 r

F

.63969 .42152 m .64351 .43055 L .63969 .4371 L .944 .769 .634 r

F

.70315 .48049 m .7263 .47951 L .72463 .48036 L .572 .614 .856 r

F

.70315 .48049 m .71946 .47215 L .7263 .47951 L F

0 g

.7263 .47951 m

.76917 .40154 L

s

.6888 .47703 m

.70315 .48049 L

s

.70315 .48049 m

.72463 .48036 L

s

.82835 .68263 m .83007 .68188 L .83701 .68108 L .5 .899 .934 r

F

.77866 .675 m .80612 .67426 L .78932 .6816 L .497 .421 .701 r

F

.77866 .675 m .80318 .6642 L .80612 .67426 L F

0 g

.7708 .66723 m

.77866 .675 L

s

.64485 .44539 m .67815 .42768 L .68507 .43513 L .572 .614 .856 r

F

.63969 .4371 m .67815 .42768 L .64485 .44539 L F

0 g

.64485 .44539 m

.65116 .45305 L

s

.79636 .68079 m .80734 .68507 L .78932 .6816 L .371 0 0 r

F

.87001 .87034 m .85556 .8752 L .86284 .86477 L .787 .676 .742 r

F

.87001 .87034 m .86273 .88076 L .85556 .8752 L F

.88011 .85887 m .87001 .87034 L .86284 .86477 L .757 .683 .78 r

F

.87001 .87034 m .89734 .85244 L .88011 .85887 L .391 .166 .448 r

F

.87001 .87034 m .89523 .86099 L .89734 .85244 L F

.86273 .88076 m .89523 .86099 L .87001 .87034 L F

.66842 .34593 m .66629 .3514 L .66465 .35231 L .16 0 .152 r

F

.66842 .34593 m .67006 .34502 L .66629 .3514 L F

0 g

.66842 .34593 m

.67218 .33958 L

s

.86273 .88076 m .8931 .86956 L .89523 .86099 L .391 .166 .448 r

F

.85727 .89052 m .8931 .86956 L .86273 .88076 L F

.86273 .88076 m .85008 .88497 L .85556 .8752 L .811 .668 .705 r

F

.86273 .88076 m .85727 .89052 L .85008 .88497 L F

0 g

.86273 .88076 m

.87001 .87034 L

s

.88011 .85887 m .89945 .84393 L .89769 .84459 L .391 .166 .448 r

F

.88011 .85887 m .89734 .85244 L .89945 .84393 L F

.88011 .85887 m .86284 .86477 L .87295 .85329 L .757 .683 .78 r

F

.89769 .84459 m .88011 .85887 L .87295 .85329 L .704 .687 .831 r

F

0 g

.87001 .87034 m

.88011 .85887 L

s

.7723 .56507 m .77399 .56427 L .7769 .57421 L .497 .421 .701 r

F

0 g

.76034 .58202 m

.7723 .56507 L

s

.77399 .56427 m

.85677 .5578 L

s

.82137 .68344 m .83007 .68188 L .82835 .68263 L .5 .899 .934 r

F

0 g

.82835 .68263 m

.83529 .68182 L

s

.6414 .40501 m .63969 .42152 L .63757 .41152 L .975 .842 .646 r

F

.63969 .42152 m .63969 .4371 L .63586 .42805 L .944 .769 .634 r

F

.63757 .41152 m .63969 .42152 L .63586 .42805 L .975 .842 .646 r

F

.63969 .4371 m .67121 .42022 L .67815 .42768 L .572 .614 .856 r

F

.63586 .42805 m .67121 .42022 L .63969 .4371 L F

0 g

.63969 .4371 m

.64485 .44539 L

s

.85727 .89052 m .89097 .87817 L .8931 .86956 L .391 .166 .448 r

F

.85323 .89977 m .89097 .87817 L .85727 .89052 L F

.85727 .89052 m .84603 .89423 L .85008 .88497 L .831 .656 .665 r

F

.85727 .89052 m .85323 .89977 L .84603 .89423 L F

0 g

.85727 .89052 m

.86273 .88076 L

s

.82137 .68344 m .82309 .68269 L .83007 .68188 L .5 .899 .934 r

F

.86284 .86477 m .84836 .86963 L .85566 .85919 L .787 .676 .742 r

F

.86284 .86477 m .85556 .8752 L .84836 .86963 L F

.87295 .85329 m .86284 .86477 L .85566 .85919 L .757 .683 .78 r

F

.64192 .39351 m .6414 .40501 L .63757 .41152 L .976 .922 .633 r

F

.85556 .8752 m .84288 .87941 L .84836 .86963 L .811 .668 .705 r

F

.85556 .8752 m .85008 .88497 L .84288 .87941 L F

.87295 .85329 m .85566 .85919 L .86578 .84769 L .757 .683 .78 r

F

.89054 .83897 m .87295 .85329 L .86578 .84769 L .704 .687 .831 r

F

.89769 .84459 m .87295 .85329 L .89054 .83897 L F

.78932 .6816 m .80906 .68432 L .80734 .68507 L .497 .421 .701 r

F

.78932 .6816 m .80612 .67426 L .80906 .68432 L F

0 g

.77866 .675 m

.78932 .6816 L

s

.66465 .35231 m .66251 .3578 L .66086 .35872 L .16 0 .152 r

F

.66465 .35231 m .66629 .3514 L .66251 .3578 L F

0 g

.66465 .35231 m

.66842 .34593 L

s

.85323 .89977 m .88884 .88681 L .89097 .87817 L .391 .166 .448 r

F

.85044 .90859 m .88884 .88681 L .85323 .89977 L F

.85323 .89977 m .84322 .90305 L .84603 .89423 L .851 .641 .618 r

F

.85323 .89977 m .85044 .90859 L .84322 .90305 L F

0 g

.85323 .89977 m

.85727 .89052 L

s

.85008 .88497 m .83881 .88867 L .84288 .87941 L .831 .656 .665 r

F

.85008 .88497 m .84603 .89423 L .83881 .88867 L F

.85566 .85919 m .84115 .86405 L .84846 .8536 L .787 .676 .742 r

F

.85566 .85919 m .84836 .86963 L .84115 .86405 L F

.86578 .84769 m .85566 .85919 L .84846 .8536 L .757 .683 .78 r

F

0 g

.72463 .48036 m

.72463 .48036 L

s

.81437 .68425 m .82309 .68269 L .82137 .68344 L .5 .899 .934 r

F

0 g

.82137 .68344 m

.82835 .68263 L

s

.84836 .86963 m .83565 .87383 L .84115 .86405 L .811 .668 .705 r

F

.84836 .86963 m .84288 .87941 L .83565 .87383 L F

.63586 .42805 m .66427 .41275 L .67121 .42022 L .572 .614 .856 r

F

.63757 .41152 m .63586 .42805 L .63372 .41805 L .975 .842 .646 r

F

.63372 .41805 m .66427 .41275 L .63586 .42805 L .572 .614 .856 r

F

0 g

.63586 .42805 m

.63969 .4371 L

s

.86578 .84769 m .84846 .8536 L .85859 .84207 L .757 .683 .78 r

F

.88337 .83334 m .86578 .84769 L .85859 .84207 L .704 .687 .831 r

F

.89054 .83897 m .86578 .84769 L .88337 .83334 L F

.89769 .84459 m .8923 .8383 L .89054 .83897 L .57 .671 .907 r

F

.89769 .84459 m .89945 .84393 L .8923 .8383 L F

0 g

.88011 .85887 m

.89769 .84459 L

s

.89769 .84459 m

.89769 .84459 L

s

.64192 .39351 m .63757 .41152 L .63807 .40002 L .976 .922 .633 r

F

.63807 .40002 m .63757 .41152 L .63372 .41805 L F

.81437 .68425 m .81609 .68351 L .82309 .68269 L .5 .899 .934 r

F

.84603 .89423 m .83599 .8975 L .83881 .88867 L .851 .641 .618 r

F

.84603 .89423 m .84322 .90305 L .83599 .8975 L F

.84288 .87941 m .83157 .8831 L .83565 .87383 L .831 .656 .665 r

F

.84288 .87941 m .83881 .88867 L .83157 .8831 L F

.84846 .8536 m .83392 .85845 L .84124 .84798 L .787 .676 .742 r

F

.84846 .8536 m .84115 .86405 L .83392 .85845 L F

.85859 .84207 m .84846 .8536 L .84124 .84798 L .757 .683 .78 r

F

.84115 .86405 m .82841 .86824 L .83392 .85845 L .811 .668 .705 r

F

.85859 .84207 m .84124 .84798 L .85138 .83644 L .757 .683 .78 r

F

.87618 .82769 m .85859 .84207 L .85138 .83644 L .704 .687 .831 r

F

.88337 .83334 m .85859 .84207 L .87618 .82769 L F

.89054 .83897 m .88513 .83267 L .88337 .83334 L .57 .671 .907 r

F

.89054 .83897 m .8923 .8383 L .88513 .83267 L F

.84124 .84798 m .82667 .85284 L .834 .84236 L .787 .676 .742 r

F

.84124 .84798 m .83392 .85845 L .82667 .85284 L F

.85138 .83644 m .84124 .84798 L .834 .84236 L .757 .683 .78 r

F

.83392 .85845 m .82114 .86264 L .82667 .85284 L .811 .668 .705 r

F

.83392 .85845 m .82841 .86824 L .82114 .86264 L F

.85138 .83644 m .834 .84236 L .84415 .8308 L .757 .683 .78 r

F

.86897 .82202 m .85138 .83644 L .84415 .8308 L .704 .687 .831 r

F

.87618 .82769 m .85138 .83644 L .86897 .82202 L F

.88337 .83334 m .87794 .82701 L .87618 .82769 L .57 .671 .907 r

F

.88337 .83334 m .88513 .83267 L .87794 .82701 L F

.82841 .86824 m .81703 .87191 L .82114 .86264 L .831 .656 .665 r

F

.834 .84236 m .8194 .84721 L .82674 .83672 L .787 .676 .742 r

F

.834 .84236 m .82667 .85284 L .8194 .84721 L F

.84415 .8308 m .834 .84236 L .82674 .83672 L .757 .683 .78 r

F

.82667 .85284 m .81386 .85702 L .8194 .84721 L .811 .668 .705 r

F

.82667 .85284 m .82114 .86264 L .81386 .85702 L F

.84415 .8308 m .82674 .83672 L .8369 .82514 L .757 .683 .78 r

F

.86174 .81635 m .84415 .8308 L .8369 .82514 L .704 .687 .831 r

F

.86897 .82202 m .84415 .8308 L .86174 .81635 L F

.87618 .82769 m .87073 .82135 L .86897 .82202 L .57 .671 .907 r

F

.87618 .82769 m .87794 .82701 L .87073 .82135 L F

.82114 .86264 m .80973 .8663 L .81386 .85702 L .831 .656 .665 r

F

.82114 .86264 m .81703 .87191 L .80973 .8663 L F

.82674 .83672 m .81211 .84157 L .81947 .83106 L .787 .676 .742 r

F

.82674 .83672 m .8194 .84721 L .81211 .84157 L F

.8369 .82514 m .82674 .83672 L .81947 .83106 L .757 .683 .78 r

F

.8194 .84721 m .80656 .85138 L .81211 .84157 L .811 .668 .705 r

F

.8194 .84721 m .81386 .85702 L .80656 .85138 L F

.8369 .82514 m .81947 .83106 L .82963 .81947 L .757 .683 .78 r

F

.8545 .81065 m .8369 .82514 L .82963 .81947 L .704 .687 .831 r

F

.86174 .81635 m .8369 .82514 L .8545 .81065 L F

.86897 .82202 m .8635 .81567 L .86174 .81635 L .57 .671 .907 r

F

.86897 .82202 m .87073 .82135 L .8635 .81567 L F

.81703 .87191 m .80685 .87514 L .80973 .8663 L .851 .641 .618 r

F

.81386 .85702 m .80242 .86067 L .80656 .85138 L .831 .656 .665 r

F

.81386 .85702 m .80973 .8663 L .80242 .86067 L F

.81947 .83106 m .8048 .83591 L .81217 .82539 L .787 .676 .742 r

F

.81947 .83106 m .81211 .84157 L .8048 .83591 L F

.82963 .81947 m .81947 .83106 L .81217 .82539 L .757 .683 .78 r

F

.81211 .84157 m .79924 .84573 L .8048 .83591 L .811 .668 .705 r

F

.81211 .84157 m .80656 .85138 L .79924 .84573 L F

.82963 .81947 m .81217 .82539 L .82235 .81378 L .757 .683 .78 r

F

.84724 .80495 m .82963 .81947 L .82235 .81378 L .704 .687 .831 r

F

.8545 .81065 m .82963 .81947 L .84724 .80495 L F

.86174 .81635 m .85625 .80997 L .8545 .81065 L .57 .671 .907 r

F

.86174 .81635 m .8635 .81567 L .85625 .80997 L F

.80973 .8663 m .79951 .86951 L .80242 .86067 L .851 .641 .618 r


F

.80973 .8663 m .80685 .87514 L .79951 .86951 L F

.80656 .85138 m .79508 .85503 L .79924 .84573 L .831 .656 .665 r

F

.80656 .85138 m .80242 .86067 L .79508 .85503 L F

.81217 .82539 m .79747 .83024 L .80486 .81971 L .787 .676 .742 r

F

.81217 .82539 m .8048 .83591 L .79747 .83024 L F

.82235 .81378 m .81217 .82539 L .80486 .81971 L .757 .683 .78 r

F

.8048 .83591 m .7919 .84007 L .79747 .83024 L .811 .668 .705 r

F

.8048 .83591 m .79924 .84573 L .7919 .84007 L F

.82235 .81378 m .80486 .81971 L .81504 .80808 L .757 .683 .78 r

F

.83995 .79922 m .82235 .81378 L .81504 .80808 L .704 .687 .831 r

F

.84724 .80495 m .82235 .81378 L .83995 .79922 L F

.8545 .81065 m .84899 .80426 L .84724 .80495 L .57 .671 .907 r

F

.8545 .81065 m .85625 .80997 L .84899 .80426 L F

.80242 .86067 m .79216 .86387 L .79508 .85503 L .851 .641 .618 r

F

.80242 .86067 m .79951 .86951 L .79216 .86387 L F

.79924 .84573 m .78772 .84937 L .7919 .84007 L .831 .656 .665 r

F

.79924 .84573 m .79508 .85503 L .78772 .84937 L F

.80486 .81971 m .79013 .82455 L .79752 .81401 L .787 .676 .742 r

F

.80486 .81971 m .79747 .83024 L .79013 .82455 L F

.81504 .80808 m .80486 .81971 L .79752 .81401 L .757 .683 .78 r

F

.80685 .87514 m .7978 .87792 L .79951 .86951 L .868 .618 .558 r

F

.81504 .80808 m .79752 .81401 L .80772 .80236 L .757 .683 .78 r

F

.83265 .79348 m .81504 .80808 L .80772 .80236 L .704 .687 .831 r

F

.83995 .79922 m .81504 .80808 L .83265 .79348 L F

.84724 .80495 m .8417 .79853 L .83995 .79922 L .57 .671 .907 r

F

.84724 .80495 m .84899 .80426 L .8417 .79853 L F

.79508 .85503 m .78479 .85821 L .78772 .84937 L .851 .641 .618 r

F

.79508 .85503 m .79216 .86387 L .78479 .85821 L F

.80772 .80236 m .79752 .81401 L .79017 .8083 L .757 .683 .78 r

F

.79951 .86951 m .79043 .87228 L .79216 .86387 L .868 .618 .558 r

F

.79951 .86951 m .7978 .87792 L .79043 .87228 L F

.80772 .80236 m .79017 .8083 L .80037 .79663 L .757 .683 .78 r

F

.82533 .78773 m .80772 .80236 L .80037 .79663 L .704 .687 .831 r

F

.83265 .79348 m .80772 .80236 L .82533 .78773 L F

.83995 .79922 m .8344 .79279 L .83265 .79348 L .57 .671 .907 r

F

.83995 .79922 m .8417 .79853 L .8344 .79279 L F

.79216 .86387 m .78305 .86662 L .78479 .85821 L .868 .618 .558 r

F

.79216 .86387 m .79043 .87228 L .78305 .86662 L F

.81799 .78196 m .80037 .79663 L .79301 .79088 L .704 .687 .831 r

F

.82533 .78773 m .80037 .79663 L .81799 .78196 L F

.83265 .79348 m .82707 .78703 L .82533 .78773 L .57 .671 .907 r

F

.83265 .79348 m .8344 .79279 L .82707 .78703 L F

.7978 .87792 m .78995 .88026 L .79043 .87228 L .883 .582 .474 r

F

.81799 .78196 m .79301 .79088 L .81063 .77618 L .704 .687 .831 r

F

.82533 .78773 m .81973 .78126 L .81799 .78196 L .57 .671 .907 r

F

.82533 .78773 m .82707 .78703 L .81973 .78126 L F

.79043 .87228 m .78255 .8746 L .78305 .86662 L .883 .582 .474 r

F

.79043 .87228 m .78995 .88026 L .78255 .8746 L F

.81799 .78196 m .81237 .77547 L .81063 .77618 L .57 .671 .907 r

F

.81799 .78196 m .81973 .78126 L .81237 .77547 L F

.78995 .88026 m .78347 .88207 L .78255 .8746 L .885 .518 .341 r

F

.89945 .84393 m .78417 .87988 L .81237 .77547 L .862 .631 .587 r

F

0 g

.89759 .84451 m

.89769 .84459 L

s

.85044 .90859 m .88669 .89548 L .88884 .88681 L .391 .166 .448 r

F

.84885 .91701 m .88669 .89548 L .85044 .90859 L F

.85044 .90859 m .84161 .91147 L .84322 .90305 L .868 .618 .558 r

F

.85044 .90859 m .84885 .91701 L .84161 .91147 L F

.84115 .86405 m .83565 .87383 L .82841 .86824 L .811 .668 .705 r

F

.83881 .88867 m .82873 .89193 L .83157 .8831 L .851 .641 .618 r

F

.83881 .88867 m .83599 .8975 L .82873 .89193 L F

.83565 .87383 m .82431 .87751 L .82841 .86824 L .831 .656 .665 r

F

.83565 .87383 m .83157 .8831 L .82431 .87751 L F

.84322 .90305 m .83436 .90592 L .83599 .8975 L .868 .618 .558 r

F

.84322 .90305 m .84161 .91147 L .83436 .90592 L F

.84885 .91701 m .88454 .90418 L .88669 .89548 L .391 .166 .448 r

F

.84851 .92501 m .88454 .90418 L .84885 .91701 L F

.84885 .91701 m .84126 .91947 L .84161 .91147 L .883 .582 .474 r

F

.84885 .91701 m .84851 .92501 L .84126 .91947 L F

.83157 .8831 m .82145 .88635 L .82431 .87751 L .851 .641 .618 r

F

.83157 .8831 m .82873 .89193 L .82145 .88635 L F

.82841 .86824 m .82431 .87751 L .81703 .87191 L .831 .656 .665 r

F

.83599 .8975 m .82709 .90035 L .82873 .89193 L .868 .618 .558 r

F

.83599 .8975 m .83436 .90592 L .82709 .90035 L F

.84161 .91147 m .83399 .91391 L .83436 .90592 L .883 .582 .474 r

F

.84161 .91147 m .84126 .91947 L .83399 .91391 L F

.82431 .87751 m .81416 .88075 L .81703 .87191 L .851 .641 .618 r

F

.82431 .87751 m .82145 .88635 L .81416 .88075 L F

.82873 .89193 m .81979 .89476 L .82145 .88635 L .868 .618 .558 r

F

.82873 .89193 m .82709 .90035 L .81979 .89476 L F

.84851 .92501 m .88237 .91292 L .88454 .90418 L .391 .166 .448 r

F

.84961 .93254 m .88237 .91292 L .84851 .92501 L F

.84851 .92501 m .84234 .92699 L .84126 .91947 L .885 .518 .341 r

F

.84851 .92501 m .84961 .93254 L .84234 .92699 L F

.83436 .90592 m .8267 .90834 L .82709 .90035 L .883 .582 .474 r

F

.83436 .90592 m .83399 .91391 L .8267 .90834 L F

.81703 .87191 m .81416 .88075 L .80685 .87514 L .851 .641 .618 r

F

.82145 .88635 m .81248 .88917 L .81416 .88075 L .868 .618 .558 r

F

.82145 .88635 m .81979 .89476 L .81248 .88917 L F

.84126 .91947 m .83505 .92143 L .83399 .91391 L .885 .518 .341 r

F

.84126 .91947 m .84234 .92699 L .83505 .92143 L F

.82709 .90035 m .81939 .90275 L .81979 .89476 L .883 .582 .474 r

F

.82709 .90035 m .8267 .90834 L .81939 .90275 L F

.81416 .88075 m .80515 .88355 L .80685 .87514 L .868 .618 .558 r

F

.81416 .88075 m .81248 .88917 L .80515 .88355 L F

.83399 .91391 m .82774 .91585 L .8267 .90834 L .885 .518 .341 r

F

.83399 .91391 m .83505 .92143 L .82774 .91585 L F

.84961 .93254 m .8802 .92169 L .88237 .91292 L .391 .166 .448 r

F

.85256 .93946 m .8802 .92169 L .84961 .93254 L F

.81979 .89476 m .81206 .89715 L .81248 .88917 L .883 .582 .474 r

F

.81979 .89476 m .81939 .90275 L .81206 .89715 L F

.80685 .87514 m .80515 .88355 L .7978 .87792 L .868 .618 .558 r

F

.8267 .90834 m .82041 .91026 L .81939 .90275 L .885 .518 .341 r

F

.8267 .90834 m .82774 .91585 L .82041 .91026 L F

.81248 .88917 m .80471 .89154 L .80515 .88355 L .883 .582 .474 r

F

.81248 .88917 m .81206 .89715 L .80471 .89154 L F

.81939 .90275 m .81306 .90465 L .81206 .89715 L .885 .518 .341 r

F

.81939 .90275 m .82041 .91026 L .81306 .90465 L F

.80515 .88355 m .79734 .8859 L .7978 .87792 L .883 .582 .474 r

F

.80515 .88355 m .80471 .89154 L .79734 .8859 L F

.85256 .93946 m .87803 .93049 L .8802 .92169 L .391 .166 .448 r

F

.8584 .94542 m .87803 .93049 L .85256 .93946 L F

.81206 .89715 m .80569 .89903 L .80471 .89154 L .885 .518 .341 r

F

.81206 .89715 m .81306 .90465 L .80569 .89903 L F

.7978 .87792 m .79734 .8859 L .78995 .88026 L .883 .582 .474 r

F

.80471 .89154 m .79831 .89339 L .79734 .8859 L .885 .518 .341 r

F

.80471 .89154 m .80569 .89903 L .79831 .89339 L F

.79734 .8859 m .7909 .88774 L .78995 .88026 L F

.79734 .8859 m .79831 .89339 L .7909 .88774 L F

.8584 .94542 m .87584 .93932 L .87803 .93049 L .391 .166 .448 r

F

.87186 .94881 m .87584 .93932 L .8584 .94542 L F

.78995 .88026 m .7909 .88774 L .78347 .88207 L .885 .518 .341 r

F

.87186 .94881 m .87364 .94819 L .87584 .93932 L .391 .166 .448 r

F

.89945 .84393 m .87364 .94819 L .78417 .87988 L .862 .631 .587 r

F

.66086 .35872 m .6587 .36424 L .65706 .36515 L .16 0 .152 r

F

.66086 .35872 m .66251 .3578 L .6587 .36424 L F

0 g

.66086 .35872 m

.66465 .35231 L

s

.80734 .68507 m .81609 .68351 L .81437 .68425 L .5 .899 .934 r

F

0 g

.81437 .68425 m

.82137 .68344 L

s

.63372 .41805 m .65731 .40525 L .66427 .41275 L .572 .614 .856 r


F

.63807 .40002 m .63372 .41805 L .63421 .40655 L .976 .922 .633 r

F

.63421 .40655 m .65731 .40525 L .63372 .41805 L .572 .614 .856 r

F

0 g

.63372 .41805 m

.63586 .42805 L

s

.80734 .68507 m .80906 .68432 L .81609 .68351 L .5 .899 .934 r

F

0 g

.80734 .68507 m

.81437 .68425 L

s

.77399 .56427 m

.80906 .68432 L

s

.78932 .6816 m

.80734 .68507 L

s

.80906 .68432 m

.89148 .67475 L

s

.65706 .36515 m .65489 .3707 L .65324 .3716 L .16 0 .152 r

F

.65706 .36515 m .6587 .36424 L .65489 .3707 L F

0 g

.65706 .36515 m

.66086 .35872 L

s

.64556 .3846 m .63807 .40002 L .63421 .40655 L .718 .858 .436 r

F

.64941 .37809 m .63807 .40002 L .64556 .3846 L F

0 g

.80734 .68507 m

.80734 .68507 L

s

.79081 1.22396 m

.97757 1.173 L

s

.65324 .3716 m .65106 .37718 L .64941 .37809 L .16 0 .152 r

F

.65324 .3716 m .65489 .3707 L .65106 .37718 L F

0 g

.65324 .3716 m

.65706 .36515 L

s

.63421 .40655 m .65033 .39775 L .65731 .40525 L .572 .614 .856 r

F

.64556 .3846 m .63421 .40655 L .6417 .39113 L .718 .858 .436 r

F

.6417 .39113 m .65033 .39775 L .63421 .40655 L .572 .614 .856 r

F

0 g

.63372 .41805 m

.63421 .40655 L

s

.64941 .37809 m .64721 .38369 L .64556 .3846 L .16 0 .152 r

F

.64941 .37809 m .65106 .37718 L .64721 .38369 L F

0 g

.64941 .37809 m

.65324 .3716 L

s

.84961 .93254 m .84527 .9339 L .84234 .92699 L .841 .381 .1 r

F

.84961 .93254 m .85256 .93946 L .84527 .9339 L F

0 g

.84917 .9295 m

.84961 .93254 L

s

.79747 .83024 m .78454 .83439 L .79013 .82455 L .811 .668 .705 r

F

.79747 .83024 m .7919 .84007 L .78454 .83439 L F

.64556 .3846 m .64334 .39023 L .6417 .39113 L .16 0 .152 r

F

.64556 .3846 m .64721 .38369 L .64334 .39023 L F

0 g

.64556 .3846 m

.64941 .37809 L

s

.84234 .92699 m .83796 .92833 L .83505 .92143 L .841 .381 .1 r

F

.84234 .92699 m .84527 .9339 L .83796 .92833 L F

.7919 .84007 m .78035 .84369 L .78454 .83439 L .831 .656 .665 r

F

.7919 .84007 m .78772 .84937 L .78035 .84369 L F

.79752 .81401 m .78276 .81885 L .79017 .8083 L .787 .676 .742 r

F

.79752 .81401 m .79013 .82455 L .78276 .81885 L F

.79013 .82455 m .77716 .82869 L .78276 .81885 L .811 .668 .705 r

F

.79013 .82455 m .78454 .83439 L .77716 .82869 L F

.6417 .39113 m .64334 .39023 L .65033 .39775 L .572 .614 .856 r

F

0 g

.6417 .39113 m

.64556 .3846 L

s

.64334 .39023 m

.68869 .3135 L

s

.64334 .39023 m

.7263 .47951 L

s

.63421 .40655 m

.6417 .39113 L

s

.83505 .92143 m .83063 .92274 L .82774 .91585 L .841 .381 .1 r

F

.83505 .92143 m .83796 .92833 L .83063 .92274 L F

.78772 .84937 m .7774 .85254 L .78035 .84369 L .851 .641 .618 r

F

.78772 .84937 m .78479 .85821 L .7774 .85254 L F

.78454 .83439 m .77295 .838 L .77716 .82869 L .831 .656 .665 r

F

.78454 .83439 m .78035 .84369 L .77295 .838 L F

.79017 .8083 m .77538 .81313 L .78279 .80257 L .787 .676 .742 r

F

.79017 .8083 m .78276 .81885 L .77538 .81313 L F

.80037 .79663 m .79017 .8083 L .78279 .80257 L .757 .683 .78 r

F

.85256 .93946 m .85108 .93985 L .84527 .9339 L .597 .051 0 r

F

.85256 .93946 m .8584 .94542 L .85108 .93985 L F

0 g

.84961 .93254 m

.85256 .93946 L

s

.78276 .81885 m .76976 .82298 L .77538 .81313 L .811 .668 .705 r

F

.78276 .81885 m .77716 .82869 L .76976 .82298 L F

.80037 .79663 m .78279 .80257 L .79301 .79088 L .757 .683 .78 r

F

.82774 .91585 m .82328 .91714 L .82041 .91026 L .841 .381 .1 r

F

.82774 .91585 m .83063 .92274 L .82328 .91714 L F

.51253 .23711 m .52728 .2209 L .49975 .23814 L .646 .84 .975 r

F

0 g

.58328 .19067 m

.70389 .24449 L

s

.23953 .03727 m

.58328 .19067 L

s

.42113 .29193 m

.53988 .34034 L

s

.08459 .15474 m

.42113 .29193 L

s

.51253 .23711 m .53543 .22283 L .52728 .2209 L .646 .84 .975 r

F

.52787 .23448 m .53543 .22283 L .51253 .23711 L F

.51253 .23711 m .52929 .24421 L .51394 .24684 L .68 .506 .644 r

F

.51253 .23711 m .52787 .23448 L .52929 .24421 L F

.49975 .23814 m .51253 .23711 L .51394 .24684 L .726 .538 .636 r

F

.78035 .84369 m .76999 .84685 L .77295 .838 L .851 .641 .618 r

F

.78035 .84369 m .7774 .85254 L .76999 .84685 L F

.52787 .23448 m .54355 .22474 L .53543 .22283 L .646 .84 .975 r

F

.55003 .22764 m .54355 .22474 L .52787 .23448 L F

.52787 .23448 m .55148 .23738 L .52929 .24421 L .608 .455 .649 r

F

.52787 .23448 m .55003 .22764 L .55148 .23738 L F

0 g

.51253 .23711 m

.52787 .23448 L

s

.77716 .82869 m .76554 .8323 L .76976 .82298 L .831 .656 .665 r

F

.77716 .82869 m .77295 .838 L .76554 .8323 L F

.78279 .80257 m .80544 .80114 L .77538 .81313 L .367 .136 .427 r

F

.78279 .80257 m .80776 .79255 L .80544 .80114 L F

.79301 .79088 m .80776 .79255 L .78279 .80257 L F

.49975 .23814 m .5191 .21898 L .4886 .23814 L .646 .84 .975 r

F

.49975 .23814 m .52728 .2209 L .5191 .21898 L F

.49975 .23814 m .51394 .24684 L .50115 .24788 L .726 .538 .636 r

F

.4886 .23814 m .49975 .23814 L .50115 .24788 L .764 .565 .627 r

F

0 g

.49975 .23814 m

.51253 .23711 L

s

.78479 .85821 m .77564 .86095 L .7774 .85254 L .868 .618 .558 r

F

.78479 .85821 m .78305 .86662 L .77564 .86095 L F

.84527 .9339 m .84375 .93426 L .83796 .92833 L .597 .051 0 r

F

.84527 .9339 m .85108 .93985 L .84375 .93426 L F

.77538 .81313 m .80311 .80975 L .76976 .82298 L .367 .136 .427 r

F

.77538 .81313 m .80544 .80114 L .80311 .80975 L F

0 g

.77538 .81313 m

.78279 .80257 L

s

.51394 .24684 m .53072 .25396 L .51535 .25659 L .68 .506 .644 r

F

.51394 .24684 m .52929 .24421 L .53072 .25396 L F

.50115 .24788 m .51394 .24684 L .51535 .25659 L .726 .538 .636 r

F

.79301 .79088 m .81007 .784 L .80776 .79255 L .367 .136 .427 r

F

.81063 .77618 m .81007 .784 L .79301 .79088 L F

0 g

.78279 .80257 m

.79301 .79088 L

s

.52929 .24421 m .55293 .24715 L .53072 .25396 L .608 .455 .649 r

F

.52929 .24421 m .55148 .23738 L .55293 .24715 L F

.82041 .91026 m .81591 .91152 L .81306 .90465 L .841 .381 .1 r

F

.82041 .91026 m .82328 .91714 L .81591 .91152 L F

.50115 .24788 m .51535 .25659 L .50255 .25763 L .726 .538 .636 r

F

.48999 .24789 m .50115 .24788 L .50255 .25763 L .764 .565 .627 r

F

.4886 .23814 m .50115 .24788 L .48999 .24789 L F

.4886 .23814 m .51088 .21704 L .47873 .23732 L .646 .84 .975 r

F

.4886 .23814 m .5191 .21898 L .51088 .21704 L F

.47873 .23732 m .4886 .23814 L .48999 .24789 L .802 .59 .616 r

F

0 g

.4886 .23814 m

.49975 .23814 L

s

.77295 .838 m .76256 .84115 L .76554 .8323 L .851 .641 .618 r

F

.77295 .838 m .76999 .84685 L .76256 .84115 L F

.76976 .82298 m .80077 .81841 L .76554 .8323 L .367 .136 .427 r

F

.76976 .82298 m .80311 .80975 L .80077 .81841 L F

0 g

.76976 .82298 m

.77538 .81313 L

s

.51535 .25659 m .53215 .26372 L .51677 .26635 L .68 .506 .644 r

F

.51535 .25659 m .53072 .25396 L .53215 .26372 L F

.50255 .25763 m .51535 .25659 L .51677 .26635 L .726 .538 .636 r

F

.7774 .85254 m .76821 .85527 L .76999 .84685 L .868 .618 .558 r

F

.7774 .85254 m .77564 .86095 L .76821 .85527 L F

.83796 .92833 m .83639 .92866 L .83063 .92274 L .597 .051 0 r

F

.83796 .92833 m .84375 .93426 L .83639 .92866 L F

.53072 .25396 m .55438 .25693 L .53215 .26372 L .608 .455 .649 r

F

.53072 .25396 m .55293 .24715 L .55438 .25693 L F

.50255 .25763 m .51677 .26635 L .50395 .2674 L .726 .538 .636 r

F

.49139 .25765 m .50255 .25763 L .50395 .2674 L .764 .565 .627 r

F

.48999 .24789 m .50255 .25763 L .49139 .25765 L F

.48011 .24708 m .48999 .24789 L .49139 .25765 L .802 .59 .616 r

F

.47873 .23732 m .48999 .24789 L .48011 .24708 L F

.81306 .90465 m .80852 .90589 L .80569 .89903 L .841 .381 .1 r

F

.81306 .90465 m .81591 .91152 L .80852 .90589 L F

.78305 .86662 m .77512 .86892 L .77564 .86095 L .883 .582 .474 r

F

.78305 .86662 m .78255 .8746 L .77512 .86892 L F

.51677 .26635 m .53359 .2735 L .51819 .27613 L .68 .506 .644 r

F

.51677 .26635 m .53215 .26372 L .53359 .2735 L F

.50395 .2674 m .51677 .26635 L .51819 .27613 L .726 .538 .636 r

F

.55003 .22764 m .55163 .22664 L .54355 .22474 L .646 .84 .975 r

F

.55148 .23738 m .55163 .22664 L .55003 .22764 L .445 .341 .642 r

F

0 g

.52787 .23448 m

.55003 .22764 L

s

.55003 .22764 m

.55003 .22764 L

s

.76554 .8323 m .79843 .82709 L .76256 .84115 L .367 .136 .427 r

F

.76554 .8323 m .80077 .81841 L .79843 .82709 L F

0 g

.76554 .8323 m

.76976 .82298 L

s

.47873 .23732 m .50263 .2151 L .46995 .23579 L .646 .84 .975 r

F

.47873 .23732 m .51088 .21704 L .50263 .2151 L F

.46995 .23579 m .47873 .23732 L .48011 .24708 L .84 .617 .6 r

F

0 g

.47873 .23732 m

.4886 .23814 L

s

.53215 .26372 m .55584 .26673 L .53359 .2735 L .608 .455 .649 r

F

.53215 .26372 m .55438 .25693 L .55584 .26673 L F

.76999 .84685 m .76076 .84956 L .76256 .84115 L .868 .618 .558 r

F

.76999 .84685 m .76821 .85527 L .76076 .84956 L F

.50395 .2674 m .51819 .27613 L .50536 .27719 L .726 .538 .636 r

F

.49278 .26743 m .50395 .2674 L .50536 .27719 L .764 .565 .627 r

F

.49139 .25765 m .50395 .2674 L .49278 .26743 L F

.83063 .92274 m .82902 .92304 L .82328 .91714 L .597 .051 0 r

F

.83063 .92274 m .83639 .92866 L .82902 .92304 L F

.55148 .23738 m .55308 .23639 L .55163 .22664 L .445 .341 .642 r

F

.51819 .27613 m .53502 .2833 L .51961 .28593 L .68 .506 .644 r

F

.51819 .27613 m .53359 .2735 L .53502 .2833 L F

.50536 .27719 m .51819 .27613 L .51961 .28593 L .726 .538 .636 r

F

.55293 .24715 m .55308 .23639 L .55148 .23738 L .445 .341 .642 r

F

.53359 .2735 m .5573 .27655 L .53502 .2833 L .608 .455 .649 r

F

.53359 .2735 m .55584 .26673 L .5573 .27655 L F

.55293 .24715 m .55454 .24616 L .55308 .23639 L .445 .341 .642 r

F

.51961 .28593 m .53646 .29312 L .52103 .29575 L .68 .506 .644 r

F

.51961 .28593 m .53502 .2833 L .53646 .29312 L F

.55438 .25693 m .55454 .24616 L .55293 .24715 L .445 .341 .642 r

F

.46995 .23579 m .49434 .21314 L .46223 .23355 L .646 .84 .975 r

F

.46995 .23579 m .50263 .2151 L .49434 .21314 L F

.53502 .2833 m .55876 .28639 L .53646 .29312 L .608 .455 .649 r

F

.53502 .2833 m .5573 .27655 L .55876 .28639 L F

.55438 .25693 m .556 .25595 L .55454 .24616 L .445 .341 .642 r

F

.52103 .29575 m .5379 .30296 L .52246 .30559 L .68 .506 .644 r

F

.52103 .29575 m .53646 .29312 L .5379 .30296 L F

.55584 .26673 m .556 .25595 L .55438 .25693 L .445 .341 .642 r

F

.53646 .29312 m .56023 .29624 L .5379 .30296 L .608 .455 .649 r

F

.53646 .29312 m .55876 .28639 L .56023 .29624 L F

.55584 .26673 m .55746 .26575 L .556 .25595 L .445 .341 .642 r

F

.52246 .30559 m .5379 .30296 L .53934 .31282 L .68 .506 .644 r

F

.5573 .27655 m .55746 .26575 L .55584 .26673 L .445 .341 .642 r

F

.5379 .30296 m .5617 .30612 L .53934 .31282 L .608 .455 .649 r

F

.5379 .30296 m .56023 .29624 L .5617 .30612 L F

.5573 .27655 m .55892 .27558 L .55746 .26575 L .445 .341 .642 r

F

.46223 .23355 m .48602 .21118 L .45561 .23059 L .646 .84 .975 r

F

.46223 .23355 m .49434 .21314 L .48602 .21118 L F

.55876 .28639 m .55892 .27558 L .5573 .27655 L .445 .341 .642 r

F

.53934 .31282 m .56317 .31601 L .54079 .32269 L .608 .455 .649 r

F

.53934 .31282 m .5617 .30612 L .56317 .31601 L F

.55876 .28639 m .56038 .28542 L .55892 .27558 L .445 .341 .642 r

F

.56023 .29624 m .56038 .28542 L .55876 .28639 L F

.54079 .32269 m .56464 .32593 L .54224 .33259 L .608 .455 .649 r

F

.54079 .32269 m .56317 .31601 L .56464 .32593 L F

.56023 .29624 m .56185 .29528 L .56038 .28542 L .445 .341 .642 r

F

.5617 .30612 m .56185 .29528 L .56023 .29624 L F

.54224 .33259 m .56612 .33586 L .54369 .3425 L .608 .455 .649 r

F

.54224 .33259 m .56464 .32593 L .56612 .33586 L F

.45561 .23059 m .47766 .20921 L .45024 .22678 L .646 .84 .975 r

F

.45561 .23059 m .48602 .21118 L .47766 .20921 L F

.5617 .30612 m .56332 .30516 L .56185 .29528 L .445 .341 .642 r

F

.56317 .31601 m .56332 .30516 L .5617 .30612 L F

.54369 .3425 m .56612 .33586 L .5676 .34581 L .608 .455 .649 r

F

.56317 .31601 m .5648 .31506 L .56332 .30516 L .445 .341 .642 r

F

.56464 .32593 m .5648 .31506 L .56317 .31601 L F

.56464 .32593 m .56627 .32497 L .5648 .31506 L F

.56612 .33586 m .56627 .32497 L .56464 .32593 L F

.56612 .33586 m .56775 .33491 L .56627 .32497 L F

.45024 .22678 m .46927 .20724 L .44649 .22188 L .646 .84 .975 r

F

.45024 .22678 m .47766 .20921 L .46927 .20724 L F

.5676 .34581 m .56775 .33491 L .56612 .33586 L .445 .341 .642 r

F

.5676 .34581 m .56923 .34486 L .56775 .33491 L F

.44649 .22188 m .46084 .20525 L .44526 .2153 L .646 .84 .975 r

F

.44649 .22188 m .46927 .20724 L .46084 .20525 L F

.44526 .2153 m .46084 .20525 L .45238 .20326 L F

.45238 .20326 m .55163 .22664 L .56923 .34486 L .862 .631 .587 r

F

.48149 .25686 m .49139 .25765 L .49278 .26743 L .802 .59 .616 r

F

.48011 .24708 m .49139 .25765 L .48149 .25686 L F

.8584 .94542 m .86451 .9432 L .85108 .93985 L .092 .479 .895 r

F

0 g

.85256 .93946 m

.85355 .94047 L

s

.8584 .94542 m .87186 .94881 L .86451 .9432 L .092 .479 .895 r

F

.81063 .77618 m .81237 .77547 L .81007 .784 L .367 .136 .427 r

F

0 g

.79301 .79088 m

.81063 .77618 L

s

.81237 .77547 m

.89945 .84393 L

s

.80569 .89903 m .80111 .90024 L .79831 .89339 L .841 .381 .1 r

F

.80569 .89903 m .80852 .90589 L .80111 .90024 L F

.77564 .86095 m .76767 .86323 L .76821 .85527 L .883 .582 .474 r

F

.77564 .86095 m .77512 .86892 L .76767 .86323 L F

.47133 .24556 m .48011 .24708 L .48149 .25686 L .84 .617 .6 r

F

.46995 .23579 m .48011 .24708 L .47133 .24556 L F

.50536 .27719 m .51961 .28593 L .50677 .28699 L .726 .538 .636 r

F

.49418 .27723 m .50536 .27719 L .50677 .28699 L .764 .565 .627 r

F

.49278 .26743 m .50536 .27719 L .49418 .27723 L F

.48288 .26665 m .49278 .26743 L .49418 .27723 L .802 .59 .616 r

F

.48149 .25686 m .49278 .26743 L .48288 .26665 L F

.76256 .84115 m .79607 .8358 L .76076 .84956 L .367 .136 .427 r

F

.76256 .84115 m .79843 .82709 L .79607 .8358 L F

0 g

.76256 .84115 m

.76554 .8323 L

s

.50677 .28699 m .51961 .28593 L .52103 .29575 L .726 .538 .636 r

F

.82328 .91714 m .82163 .91741 L .81591 .91152 L .597 .051 0 r

F

.82328 .91714 m .82902 .92304 L .82163 .91741 L F

.85108 .93985 m .85715 .93758 L .84375 .93426 L .092 .479 .895 r

F

.85108 .93985 m .86451 .9432 L .85715 .93758 L F

.47271 .25536 m .48149 .25686 L .48288 .26665 L .84 .617 .6 r

F

.47133 .24556 m .48149 .25686 L .47271 .25536 L F

.46223 .23355 m .46995 .23579 L .47133 .24556 L .881 .645 .577 r

F

0 g

.46995 .23579 m

.47873 .23732 L

s

.78255 .8746 m .77603 .87639 L .77512 .86892 L .885 .518 .341 r

F

.78255 .8746 m .78347 .88207 L .77603 .87639 L F

.50677 .28699 m .52103 .29575 L .50818 .29682 L .726 .538 .636 r

F

.49558 .28704 m .50677 .28699 L .50818 .29682 L .764 .565 .627 r

F

.49418 .27723 m .50677 .28699 L .49558 .28704 L F

.79831 .89339 m .79368 .89458 L .7909 .88774 L .841 .381 .1 r

F

.79831 .89339 m .80111 .90024 L .79368 .89458 L F

.76821 .85527 m .76021 .85753 L .76076 .84956 L .883 .582 .474 r

F

.76821 .85527 m .76767 .86323 L .76021 .85753 L F

.48427 .27646 m .49418 .27723 L .49558 .28704 L .802 .59 .616 r

F

.48288 .26665 m .49418 .27723 L .48427 .27646 L F

.50818 .29682 m .52103 .29575 L .52246 .30559 L .726 .538 .636 r

F

.47409 .26517 m .48288 .26665 L .48427 .27646 L .84 .617 .6 r

F

.47271 .25536 m .48288 .26665 L .47409 .26517 L F

.4636 .24335 m .47133 .24556 L .47271 .25536 L .881 .645 .577 r

F

.46223 .23355 m .47133 .24556 L .4636 .24335 L F

.81591 .91152 m .81421 .91176 L .80852 .90589 L .597 .051 0 r

F

.81591 .91152 m .82163 .91741 L .81421 .91176 L F

.50818 .29682 m .52246 .30559 L .5096 .30666 L .726 .538 .636 r

F

.49698 .29688 m .50818 .29682 L .5096 .30666 L .764 .565 .627 r

F

.49558 .28704 m .50818 .29682 L .49698 .29688 L F

.84375 .93426 m .84976 .93195 L .83639 .92866 L .092 .479 .895 r

F

.84375 .93426 m .85715 .93758 L .84976 .93195 L F

.48567 .2863 m .49558 .28704 L .49698 .29688 L .802 .59 .616 r

F

.48427 .27646 m .49558 .28704 L .48567 .2863 L F

.77512 .86892 m .76856 .87069 L .76767 .86323 L .885 .518 .341 r

F

.77512 .86892 m .77603 .87639 L .76856 .87069 L F

.52246 .30559 m .53934 .31282 L .52388 .31544 L .68 .506 .644 r

F

.5096 .30666 m .52246 .30559 L .52388 .31544 L .726 .538 .636 r

F

.7909 .88774 m .78623 .8889 L .78347 .88207 L .841 .381 .1 r

F

.7909 .88774 m .79368 .89458 L .78623 .8889 L F

.76076 .84956 m .79371 .84455 L .76021 .85753 L .367 .136 .427 r

F

.76076 .84956 m .79607 .8358 L .79371 .84455 L F

0 g

.76076 .84956 m

.76256 .84115 L

s

.47547 .275 m .48427 .27646 L .48567 .2863 L .84 .617 .6 r

F

.47409 .26517 m .48427 .27646 L .47547 .275 L F

.46498 .25316 m .47271 .25536 L .47409 .26517 L .881 .645 .577 r

F

.4636 .24335 m .47271 .25536 L .46498 .25316 L F

.5096 .30666 m .52388 .31544 L .51102 .31652 L .726 .538 .636 r

F

.49839 .30673 m .5096 .30666 L .51102 .31652 L .764 .565 .627 r

F

.49698 .29688 m .5096 .30666 L .49839 .30673 L F

.48706 .29615 m .49698 .29688 L .49839 .30673 L .802 .59 .616 r

F

.48567 .2863 m .49698 .29688 L .48706 .29615 L F

.45561 .23059 m .46223 .23355 L .4636 .24335 L .926 .675 .54 r

F

0 g

.46223 .23355 m

.46995 .23579 L

s

.80852 .90589 m .80678 .9061 L .80111 .90024 L .597 .051 0 r

F

.80852 .90589 m .81421 .91176 L .80678 .9061 L F

.52388 .31544 m .54079 .32269 L .52532 .32532 L .68 .506 .644 r

F

.52388 .31544 m .53934 .31282 L .54079 .32269 L F

.51102 .31652 m .52388 .31544 L .52532 .32532 L .726 .538 .636 r

F

.83639 .92866 m .84236 .9263 L .82902 .92304 L .092 .479 .895 r

F

.83639 .92866 m .84976 .93195 L .84236 .9263 L F

.76767 .86323 m .76107 .86498 L .76021 .85753 L .885 .518 .341 r

F

.76767 .86323 m .76856 .87069 L .76107 .86498 L F

.47686 .28484 m .48567 .2863 L .48706 .29615 L .84 .617 .6 r

F

.47547 .275 m .48567 .2863 L .47686 .28484 L F

.46636 .26299 m .47409 .26517 L .47547 .275 L .881 .645 .577 r

F

.46498 .25316 m .47409 .26517 L .46636 .26299 L F

.78347 .88207 m .77876 .88321 L .77603 .87639 L .841 .381 .1 r

F

.78347 .88207 m .78623 .8889 L .77876 .88321 L F

.51102 .31652 m .52532 .32532 L .51244 .3264 L .726 .538 .636 r

F

.4998 .3166 m .51102 .31652 L .51244 .3264 L .764 .565 .627 r

F

.49839 .30673 m .51102 .31652 L .4998 .3166 L F

.48846 .30601 m .49839 .30673 L .4998 .3166 L .802 .59 .616 r

F

.48706 .29615 m .49839 .30673 L .48846 .30601 L F

.45698 .2404 m .4636 .24335 L .46498 .25316 L .926 .675 .54 r

F

.45561 .23059 m .4636 .24335 L .45698 .2404 L F

.52532 .32532 m .54224 .33259 L .52675 .33521 L .68 .506 .644 r

F

.52532 .32532 m .54079 .32269 L .54224 .33259 L F

.51244 .3264 m .52532 .32532 L .52675 .33521 L .726 .538 .636 r

F

.80111 .90024 m .79933 .90042 L .79368 .89458 L .597 .051 0 r

F

.80111 .90024 m .80678 .9061 L .79933 .90042 L F

.47825 .29471 m .48706 .29615 L .48846 .30601 L .84 .617 .6 r

F

.47686 .28484 m .48706 .29615 L .47825 .29471 L F

.46774 .27284 m .47547 .275 L .47686 .28484 L .881 .645 .577 r

F

.46636 .26299 m .47547 .275 L .46774 .27284 L F

.82902 .92304 m .83493 .92063 L .82163 .91741 L .092 .479 .895 r

F

.82902 .92304 m .84236 .9263 L .83493 .92063 L F

.51244 .3264 m .52675 .33521 L .51386 .3363 L .726 .538 .636 r

F

.50121 .3265 m .51244 .3264 L .51386 .3363 L .764 .565 .627 r

F

.4998 .3166 m .51244 .3264 L .50121 .3265 L F

.76021 .85753 m .79134 .85333 L .76107 .86498 L .367 .136 .427 r

F

.76021 .85753 m .79371 .84455 L .79134 .85333 L F

0 g

.76021 .85753 m

.76076 .84956 L

s

.48986 .3159 m .4998 .3166 L .50121 .3265 L .802 .59 .616 r

F

.48846 .30601 m .4998 .3166 L .48986 .3159 L F

.45835 .25024 m .46498 .25316 L .46636 .26299 L .926 .675 .54 r

F

.45698 .2404 m .46498 .25316 L .45835 .25024 L F

.77603 .87639 m .77128 .87751 L .76856 .87069 L .841 .381 .1 r

F

.77603 .87639 m .77876 .88321 L .77128 .87751 L F

.52675 .33521 m .54369 .3425 L .52819 .34512 L .68 .506 .644 r

F

.52675 .33521 m .54224 .33259 L .54369 .3425 L F

.51386 .3363 m .52675 .33521 L .52819 .34512 L .726 .538 .636 r

F

.47964 .3046 m .48846 .30601 L .48986 .3159 L .84 .617 .6 r

F

.47825 .29471 m .48846 .30601 L .47964 .3046 L F

.46912 .28271 m .47686 .28484 L .47825 .29471 L .881 .645 .577 r

F

.46774 .27284 m .47686 .28484 L .46912 .28271 L F

.45024 .22678 m .45561 .23059 L .45698 .2404 L .971 .705 .469 r

F

0 g

.45561 .23059 m

.46223 .23355 L

s

.51386 .3363 m .52819 .34512 L .51528 .34622 L .726 .538 .636 r

F

.50262 .33641 m .51386 .3363 L .51528 .34622 L .764 .565 .627 r

F

.50121 .3265 m .51386 .3363 L .50262 .33641 L F

.79368 .89458 m .79185 .89473 L .78623 .8889 L .597 .051 0 r

F

.79368 .89458 m .79933 .90042 L .79185 .89473 L F

.49126 .32581 m .50121 .3265 L .50262 .33641 L .802 .59 .616 r

F

.48986 .3159 m .50121 .3265 L .49126 .32581 L F

.45972 .26009 m .46636 .26299 L .46774 .27284 L .926 .675 .54 r

F

.45835 .25024 m .46636 .26299 L .45972 .26009 L F

.86451 .9432 m .87364 .94819 L .87186 .94881 L .558 .673 .915 r

F

0 g

.87186 .94881 m

.87186 .94881 L

s

.8584 .94542 m

.87186 .94881 L

s

.82163 .91741 m .82749 .91495 L .81421 .91176 L .092 .479 .895 r

F

.82163 .91741 m .83493 .92063 L .82749 .91495 L F

.52819 .34512 m .54515 .35243 L .52963 .35505 L .68 .506 .644 r

F

.52819 .34512 m .54369 .3425 L .54515 .35243 L F

.51528 .34622 m .52819 .34512 L .52963 .35505 L .726 .538 .636 r

F

.76856 .87069 m .76377 .87178 L .76107 .86498 L .841 .381 .1 r

F

.76856 .87069 m .77128 .87751 L .76377 .87178 L F

.48104 .3145 m .48986 .3159 L .49126 .32581 L .84 .617 .6 r

F

.47964 .3046 m .48986 .3159 L .48104 .3145 L F

.86451 .9432 m .8663 .94258 L .87364 .94819 L .558 .673 .915 r

F

0 g

.87364 .94819 m

.89945 .84393 L

s

.47051 .2926 m .47825 .29471 L .47964 .3046 L .881 .645 .577 r

F

.46912 .28271 m .47825 .29471 L .47051 .2926 L F

.54369 .3425 m .5676 .34581 L .54515 .35243 L .608 .455 .649 r

F

.45161 .23662 m .45698 .2404 L .45835 .25024 L .971 .705 .469 r

F

.45024 .22678 m .45698 .2404 L .45161 .23662 L F

.51528 .34622 m .52963 .35505 L .51671 .35616 L .726 .538 .636 r

F

.50404 .34633 m .51528 .34622 L .51671 .35616 L .764 .565 .627 r

F

.50262 .33641 m .51528 .34622 L .50404 .34633 L F

.49267 .33573 m .50262 .33641 L .50404 .34633 L .802 .59 .616 r

F

.49126 .32581 m .50262 .33641 L .49267 .33573 L F

.4611 .26997 m .46774 .27284 L .46912 .28271 L .926 .675 .54 r

F

.45972 .26009 m .46774 .27284 L .4611 .26997 L F

.52963 .35505 m .5611 .34319 L .54515 .35243 L .631 .85 .983 r

F

.52963 .35505 m .55292 .3415 L .5611 .34319 L F

.51671 .35616 m .55292 .3415 L .52963 .35505 L F

.78623 .8889 m .78436 .88902 L .77876 .88321 L .597 .051 0 r

F

.78623 .8889 m .79185 .89473 L .78436 .88902 L F

.85715 .93758 m .8663 .94258 L .86451 .9432 L .558 .673 .915 r

F

0 g

.86451 .9432 m

.87186 .94881 L

s

.48244 .32442 m .49126 .32581 L .49267 .33573 L .84 .617 .6 r

F

.48104 .3145 m .49126 .32581 L .48244 .32442 L F

.47189 .3025 m .47964 .3046 L .48104 .3145 L .881 .645 .577 r

F

.47051 .2926 m .47964 .3046 L .47189 .3025 L F

.54515 .35243 m .56923 .34486 L .5676 .34581 L .631 .85 .983 r

F

.54515 .35243 m .5611 .34319 L .56923 .34486 L F

0 g

.52963 .35505 m

.54515 .35243 L

s

.81421 .91176 m .82003 .90925 L .80678 .9061 L .092 .479 .895 r

F

.81421 .91176 m .82749 .91495 L .82003 .90925 L F

.45298 .24648 m .45835 .25024 L .45972 .26009 L .971 .705 .469 r

F

.45161 .23662 m .45835 .25024 L .45298 .24648 L F

.51671 .35616 m .54472 .33981 L .55292 .3415 L .631 .85 .983 r

F

0 g

.54515 .35243 m

.5676 .34581 L

s

.50404 .34633 m .51671 .35616 L .50546 .35628 L .764 .565 .627 r

F

.50546 .35628 m .54472 .33981 L .51671 .35616 L .631 .85 .983 r

F

0 g

.51671 .35616 m

.52963 .35505 L

s

.76107 .86498 m .78896 .86215 L .76377 .87178 L .367 .136 .427 r

F

.76107 .86498 m .79134 .85333 L .78896 .86215 L F

0 g

.76021 .85753 m

.76107 .86498 L

s

.49408 .34567 m .50404 .34633 L .50546 .35628 L .802 .59 .616 r

F

.49267 .33573 m .50404 .34633 L .49408 .34567 L F

.46248 .27986 m .46912 .28271 L .47051 .2926 L .926 .675 .54 r

F

.4611 .26997 m .46912 .28271 L .46248 .27986 L F

.85715 .93758 m .85893 .93695 L .8663 .94258 L .558 .673 .915 r

F

.48384 .33437 m .49267 .33573 L .49408 .34567 L .84 .617 .6 r

F

.48244 .32442 m .49267 .33573 L .48384 .33437 L F

.47329 .31243 m .48104 .3145 L .48244 .32442 L .881 .645 .577 r

F

.47189 .3025 m .48104 .3145 L .47329 .31243 L F

.77876 .88321 m .77685 .88329 L .77128 .87751 L .597 .051 0 r

F

.77876 .88321 m .78436 .88902 L .77685 .88329 L F

.45435 .25637 m .45972 .26009 L .4611 .26997 L .971 .705 .469 r

F

.45298 .24648 m .45972 .26009 L .45435 .25637 L F

.84976 .93195 m .85893 .93695 L .85715 .93758 L .558 .673 .915 r

F

0 g

.85715 .93758 m

.86451 .9432 L

s

.50546 .35628 m .53648 .33811 L .54472 .33981 L .631 .85 .983 r

F

.49408 .34567 m .50546 .35628 L .49549 .35564 L .802 .59 .616 r

F

.49549 .35564 m .53648 .33811 L .50546 .35628 L .631 .85 .983 r

F

0 g

.50546 .35628 m

.51671 .35616 L

s

.46387 .28977 m .47051 .2926 L .47189 .3025 L .926 .675 .54 r

F

.46248 .27986 m .47051 .2926 L .46387 .28977 L F

.80678 .9061 m .81254 .90354 L .79933 .90042 L .092 .479 .895 r

F

.80678 .9061 m .82003 .90925 L .81254 .90354 L F

.44649 .22188 m .45024 .22678 L .45161 .23662 L .979 .704 .311 r

F

0 g

.45024 .22678 m

.45561 .23059 L

s

.56707 .34224 m

.5674 .34449 L

s

.84976 .93195 m .85155 .93131 L .85893 .93695 L .558 .673 .915 r

F

.48384 .33437 m .49408 .34567 L .48524 .34433 L .84 .617 .6 r

F

.48524 .34433 m .49408 .34567 L .49549 .35564 L F

.47468 .32237 m .48244 .32442 L .48384 .33437 L .881 .645 .577 r

F

.47329 .31243 m .48244 .32442 L .47468 .32237 L F

.45573 .26627 m .4611 .26997 L .46248 .27986 L .971 .705 .469 r

F

.45435 .25637 m .4611 .26997 L .45573 .26627 L F

.46525 .2997 m .47189 .3025 L .47329 .31243 L .926 .675 .54 r

F

.46387 .28977 m .47189 .3025 L .46525 .2997 L F

.44786 .23176 m .45161 .23662 L .45298 .24648 L .979 .704 .311 r

F

.44649 .22188 m .45161 .23662 L .44786 .23176 L F

.77128 .87751 m .76931 .87755 L .76377 .87178 L .597 .051 0 r

F

.77128 .87751 m .77685 .88329 L .76931 .87755 L F

.84236 .9263 m .85155 .93131 L .84976 .93195 L .558 .673 .915 r

F

0 g

.84976 .93195 m

.85715 .93758 L

s

.5676 .34581 m

.5676 .34581 L

s

.79933 .90042 m .80504 .89782 L .79185 .89473 L .092 .479 .895 r

F

.79933 .90042 m .81254 .90354 L .80504 .89782 L F

.49549 .35564 m .5282 .3364 L .53648 .33811 L .631 .85 .983 r

F

.48524 .34433 m .49549 .35564 L .48665 .35431 L .84 .617 .6 r

F

.48665 .35431 m .5282 .3364 L .49549 .35564 L .631 .85 .983 r

F

0 g

.49549 .35564 m

.50546 .35628 L

s

.47608 .33234 m .48384 .33437 L .48524 .34433 L .881 .645 .577 r

F

.47468 .32237 m .48384 .33437 L .47608 .33234 L F

.45711 .27619 m .46248 .27986 L .46387 .28977 L .971 .705 .469 r

F

.45573 .26627 m .46248 .27986 L .45711 .27619 L F

.84236 .9263 m .84414 .92566 L .85155 .93131 L .558 .673 .915 r

F

.46664 .30965 m .47329 .31243 L .47468 .32237 L .926 .675 .54 r

F

.46525 .2997 m .47329 .31243 L .46664 .30965 L F

.46803 .31962 m .47468 .32237 L .47608 .33234 L F

.46664 .30965 m .47468 .32237 L .46803 .31962 L F

.46803 .31962 m .47608 .33234 L .46943 .3296 L F

.45238 .20326 m .56923 .34486 L .46928 .32425 L .862 .631 .587 r

F

0 g

.55163 .22664 m

.56923 .34486 L

s

.44923 .24165 m .45298 .24648 L .45435 .25637 L .979 .704 .311 r

F

.44786 .23176 m .45298 .24648 L .44923 .24165 L F

.76377 .87178 m .78657 .87099 L .76931 .87755 L .367 .136 .427 r

F

.76377 .87178 m .78896 .86215 L .78657 .87099 L F

0 g

.76107 .86498 m

.76377 .87178 L

s

.47748 .34232 m .48524 .34433 L .48665 .35431 L .881 .645 .577 r

F

.47608 .33234 m .48524 .34433 L .47748 .34232 L F

.83493 .92063 m .84414 .92566 L .84236 .9263 L .558 .673 .915 r

F

0 g

.84236 .9263 m

.84976 .93195 L

s

.45711 .27619 m .46387 .28977 L .45849 .28612 L .971 .705 .469 r

F

.45849 .28612 m .46387 .28977 L .46525 .2997 L F

.79185 .89473 m .79751 .89207 L .78436 .88902 L .092 .479 .895 r

F

.79185 .89473 m .80504 .89782 L .79751 .89207 L F

.45061 .25157 m .45435 .25637 L .45573 .26627 L .979 .704 .311 r

F

.44923 .24165 m .45435 .25637 L .45061 .25157 L F

.83493 .92063 m .83671 .91999 L .84414 .92566 L .558 .673 .915 r

F

.48665 .35431 m .51989 .33469 L .5282 .3364 L .631 .85 .983 r

F

.47748 .34232 m .48665 .35431 L .47888 .35232 L .881 .645 .577 r

F

.47888 .35232 m .51989 .33469 L .48665 .35431 L .631 .85 .983 r

F

0 g

.48665 .35431 m

.49549 .35564 L

s

.45988 .29608 m .46525 .2997 L .46664 .30965 L .971 .705 .469 r

F

.45849 .28612 m .46525 .2997 L .45988 .29608 L F

.44526 .2153 m .44649 .22188 L .44786 .23176 L .742 .523 0 r

F

0 g

.44649 .22188 m

.45024 .22678 L

s

.46943 .3296 m .47608 .33234 L .47748 .34232 L .926 .675 .54 r

F

.45199 .2615 m .45573 .26627 L .45711 .27619 L .979 .704 .311 r

F

.45061 .25157 m .45573 .26627 L .45199 .2615 L F

.82749 .91495 m .83671 .91999 L .83493 .92063 L .558 .673 .915 r

F

0 g

.83493 .92063 m

.84236 .9263 L

s

.78436 .88902 m .78997 .88632 L .77685 .88329 L .092 .479 .895 r

F

.78436 .88902 m .79751 .89207 L .78997 .88632 L F

.82749 .91495 m .82927 .91431 L .83671 .91999 L .558 .673 .915 r

F

0 0 0 r

.01 w

[ .015 ] 0 setdash

.44663 .70287 m

.61843 .62033 L

s

.46127 .30606 m .46664 .30965 L .46803 .31962 L .971 .705 .469 r

F

.45988 .29608 m .46664 .30965 L .46127 .30606 L F

.44664 .22522 m .44786 .23176 L .44923 .24165 L .742 .523 0 r

F

.44526 .2153 m .44786 .23176 L .44664 .22522 L F

.47082 .33961 m .47748 .34232 L .47888 .35232 L .926 .675 .54 r

F

.46943 .3296 m .47748 .34232 L .47082 .33961 L F

.45337 .27145 m .45711 .27619 L .45849 .28612 L .979 .704 .311 r

F

.45199 .2615 m .45711 .27619 L .45337 .27145 L F

.82003 .90925 m .82927 .91431 L .82749 .91495 L .558 .673 .915 r

F

0 g

.5 Mabswid

[ ] 0 setdash

.82749 .91495 m

.83493 .92063 L

s

.77685 .88329 m .7824 .88054 L .76931 .87755 L .092 .479 .895 r

F

.77685 .88329 m .78997 .88632 L .7824 .88054 L F

.46266 .31605 m .46803 .31962 L .46943 .3296 L .971 .705 .469 r

F

.46127 .30606 m .46803 .31962 L .46266 .31605 L F

.44664 .22522 m .44923 .24165 L .44802 .23515 L .742 .523 0 r

F

.44802 .23515 m .44923 .24165 L .45061 .25157 L F

.47888 .35232 m .51154 .33297 L .51989 .33469 L .631 .85 .983 r

F

.47082 .33961 m .47888 .35232 L .47222 .34963 L .926 .675 .54 r

F

.47222 .34963 m .51154 .33297 L .47888 .35232 L .631 .85 .983 r

F

0 g

.47888 .35232 m

.48665 .35431 L

s

.82003 .90925 m .8218 .90861 L .82927 .91431 L .558 .673 .915 r

F

.45475 .28142 m .45849 .28612 L .45988 .29608 L .979 .704 .311 r

F

.45337 .27145 m .45849 .28612 L .45475 .28142 L F

.46405 .32607 m .46943 .3296 L .47082 .33961 L .971 .705 .469 r

F

.46266 .31605 m .46943 .3296 L .46405 .32607 L F

.81254 .90354 m .8218 .90861 L .82003 .90925 L .558 .673 .915 r

F

0 g

.82003 .90925 m

.82749 .91495 L

s

.4494 .2451 m .45061 .25157 L .45199 .2615 L .742 .523 0 r

F

.44802 .23515 m .45061 .25157 L .4494 .2451 L F

.45614 .29141 m .45988 .29608 L .46127 .30606 L .979 .704 .311 r

F

.45475 .28142 m .45988 .29608 L .45614 .29141 L F

.76931 .87755 m .78417 .87988 L .7824 .88054 L .367 .136 .427 r

F

.76931 .87755 m .78657 .87099 L .78417 .87988 L F

0 g

.76377 .87178 m

.76931 .87755 L

s

.81254 .90354 m .81432 .90289 L .8218 .90861 L .558 .673 .915 r

F

.46405 .32607 m .47082 .33961 L .46545 .3361 L .971 .705 .469 r

F

.46545 .3361 m .47082 .33961 L .47222 .34963 L F

.45078 .25508 m .45199 .2615 L .45337 .27145 L .742 .523 0 r

F

.4494 .2451 m .45199 .2615 L .45078 .25508 L F

.45753 .30142 m .46127 .30606 L .46266 .31605 L .979 .704 .311 r

F

.45614 .29141 m .46127 .30606 L .45753 .30142 L F

.80504 .89782 m .81432 .90289 L .81254 .90354 L .558 .673 .915 r

F

0 g

.81254 .90354 m

.82003 .90925 L

s

.44526 .2153 m .45238 .20326 L .45079 .20429 L .646 .84 .975 r

F

.45079 .20429 m .44526 .2153 L .44664 .22522 L 0 0 .506 r

F

.47222 .34963 m .50316 .33124 L .51154 .33297 L .631 .85 .983 r

F

.46545 .3361 m .47222 .34963 L .46685 .34615 L .971 .705 .469 r

F

.46685 .34615 m .50316 .33124 L .47222 .34963 L .631 .85 .983 r

F

0 g

.47222 .34963 m

.47888 .35232 L

s

.80504 .89782 m .80681 .89716 L .81432 .90289 L .558 .673 .915 r

F

.45217 .26507 m .45337 .27145 L .45475 .28142 L .742 .523 0 r

F

.45078 .25508 m .45337 .27145 L .45217 .26507 L F

.45892 .31145 m .46266 .31605 L .46405 .32607 L .979 .704 .311 r

F

.45753 .30142 m .46266 .31605 L .45892 .31145 L F

.45218 .21426 m .44664 .22522 L .44802 .23515 L 0 0 .506 r

F

.45079 .20429 m .44664 .22522 L .45218 .21426 L F

.79751 .89207 m .80681 .89716 L .80504 .89782 L .558 .673 .915 r

F

0 g

.80504 .89782 m

.81254 .90354 L

s

.45217 .26507 m .45475 .28142 L .45356 .27508 L .742 .523 0 r

F

.45356 .27508 m .45475 .28142 L .45614 .29141 L F

.46032 .32149 m .46405 .32607 L .46545 .3361 L .979 .704 .311 r

F

.45892 .31145 m .46405 .32607 L .46032 .32149 L F

.79751 .89207 m .79928 .89141 L .80681 .89716 L .558 .673 .915 r

F

.45357 .22425 m .44802 .23515 L .4494 .2451 L 0 0 .506 r

F

.45218 .21426 m .44802 .23515 L .45357 .22425 L F

.45495 .2851 m .45614 .29141 L .45753 .30142 L .742 .523 0 r

F

.45356 .27508 m .45614 .29141 L .45495 .2851 L F

.46032 .32149 m .46545 .3361 L .46171 .33156 L .979 .704 .311 r

F

.46171 .33156 m .46545 .3361 L .46685 .34615 L F

.78997 .88632 m .79928 .89141 L .79751 .89207 L .558 .673 .915 r

F

0 g

.79751 .89207 m

.80504 .89782 L

s

.45497 .23426 m .4494 .2451 L .45078 .25508 L 0 0 .506 r

F

.45357 .22425 m .4494 .2451 L .45497 .23426 L F

.78997 .88632 m .79174 .88565 L .79928 .89141 L .558 .673 .915 r

F

.45635 .29515 m .45753 .30142 L .45892 .31145 L .742 .523 0 r

F

.45495 .2851 m .45753 .30142 L .45635 .29515 L F

.46685 .34615 m .49474 .3295 L .50316 .33124 L .631 .85 .983 r

F

.46171 .33156 m .46685 .34615 L .46311 .34165 L .979 .704 .311 r

F

.46311 .34165 m .49474 .3295 L .46685 .34615 L .631 .85 .983 r

F

0 g

.46685 .34615 m

.47222 .34963 L

s

.7824 .88054 m .79174 .88565 L .78997 .88632 L .558 .673 .915 r

F

0 g

.78997 .88632 m

.79751 .89207 L

s

.45637 .24429 m .45078 .25508 L .45217 .26507 L 0 0 .506 r

F

.45497 .23426 m .45078 .25508 L .45637 .24429 L F

.45774 .30522 m .45892 .31145 L .46032 .32149 L .742 .523 0 r

F

.45635 .29515 m .45892 .31145 L .45774 .30522 L F

.7824 .88054 m .78417 .87988 L .79174 .88565 L .558 .673 .915 r

F

0 g

.7824 .88054 m

.78997 .88632 L

s

.76931 .87755 m

.7824 .88054 L

s

.78417 .87988 m

.87364 .94819 L

s

.78417 .87988 m

.81237 .77547 L

s

.45777 .25434 m .45217 .26507 L .45356 .27508 L 0 0 .506 r

F

.45637 .24429 m .45217 .26507 L .45777 .25434 L F

.45914 .31531 m .46032 .32149 L .46171 .33156 L .742 .523 0 r

F

.45774 .30522 m .46032 .32149 L .45914 .31531 L F

0 g

.7824 .88054 m

.7824 .88054 L

s

.45777 .25434 m .45356 .27508 L .45917 .26441 L 0 0 .506 r

F

.45917 .26441 m .45356 .27508 L .45495 .2851 L F

.46055 .32541 m .46171 .33156 L .46311 .34165 L .742 .523 0 r

F

.45914 .31531 m .46171 .33156 L .46055 .32541 L F

.46058 .2745 m .45495 .2851 L .45635 .29515 L 0 0 .506 r

F

.45917 .26441 m .45495 .2851 L .46058 .2745 L F

.45079 .20429 m .45377 .21323 L .45218 .21426 L .428 .326 .636 r

F

.45079 .20429 m .45238 .20326 L .45377 .21323 L F

0 g

.44526 .2153 m

.45079 .20429 L

s

.45238 .20326 m

.55163 .22664 L

s

.45079 .20429 m

.45079 .20429 L

s

.46311 .34165 m .48629 .32776 L .49474 .3295 L .631 .85 .983 r

F

.46055 .32541 m .46311 .34165 L .46195 .33554 L .742 .523 0 r

F

.46195 .33554 m .48629 .32776 L .46311 .34165 L .631 .85 .983 r

F

0 g

.46311 .34165 m

.46685 .34615 L

s

.46199 .2846 m .45635 .29515 L .45774 .30522 L 0 0 .506 r

F

.46058 .2745 m .45635 .29515 L .46199 .2846 L F

.45218 .21426 m .45517 .22323 L .45357 .22425 L .428 .326 .636 r

F

.45218 .21426 m .45377 .21323 L .45517 .22323 L F

0 g

.45079 .20429 m

.45218 .21426 L

s

.4634 .29473 m .45774 .30522 L .45914 .31531 L 0 0 .506 r

F

.46199 .2846 m .45774 .30522 L .4634 .29473 L F

.45357 .22425 m .45657 .23324 L .45497 .23426 L .428 .326 .636 r

F

.45357 .22425 m .45517 .22323 L .45657 .23324 L F

0 g

.45218 .21426 m

.45357 .22425 L

s

.46482 .30488 m .45914 .31531 L .46055 .32541 L 0 0 .506 r

F

.4634 .29473 m .45914 .31531 L .46482 .30488 L F

.45497 .23426 m .45797 .24328 L .45637 .24429 L .428 .326 .636 r

F

.45497 .23426 m .45657 .23324 L .45797 .24328 L F

0 g

.45357 .22425 m

.45497 .23426 L

s

.46623 .31504 m .46055 .32541 L .46195 .33554 L 0 0 .506 r

F

.46482 .30488 m .46055 .32541 L .46623 .31504 L F

.45637 .24429 m .45937 .25333 L .45777 .25434 L .428 .326 .636 r

F

.45637 .24429 m .45797 .24328 L .45937 .25333 L F

0 g

.45497 .23426 m

.45637 .24429 L

s

.46623 .31504 m .46195 .33554 L .46765 .32523 L 0 0 .506 r

F

.46195 .33554 m .4778 .32601 L .48629 .32776 L .631 .85 .983 r

F

.46765 .32523 m .4778 .32601 L .46195 .33554 L F

0 g

.46195 .33554 m

.46311 .34165 L

s

.45777 .25434 m .46078 .2634 L .45917 .26441 L .428 .326 .636 r

F

.45777 .25434 m .45937 .25333 L .46078 .2634 L F

0 g

.45637 .24429 m

.45777 .25434 L

s

.45917 .26441 m .46219 .2735 L .46058 .2745 L .428 .326 .636 r

F

.45917 .26441 m .46078 .2634 L .46219 .2735 L F

0 g

.45777 .25434 m

.45917 .26441 L

s

.46058 .2745 m .4636 .28361 L .46199 .2846 L .428 .326 .636 r

F

.46058 .2745 m .46219 .2735 L .4636 .28361 L F

0 g

.45917 .26441 m

.46058 .2745 L

s

.46199 .2846 m .46501 .29374 L .4634 .29473 L .428 .326 .636 r

F

.46199 .2846 m .4636 .28361 L .46501 .29374 L F

0 g

.46058 .2745 m

.46199 .2846 L

s

.4634 .29473 m .46643 .30389 L .46482 .30488 L .428 .326 .636 r

F

.4634 .29473 m .46501 .29374 L .46643 .30389 L F

0 g

.46199 .2846 m

.4634 .29473 L

s

.46482 .30488 m .46785 .31406 L .46623 .31504 L .428 .326 .636 r

F

.46482 .30488 m .46643 .30389 L .46785 .31406 L F

0 g

.4634 .29473 m

.46482 .30488 L

s

.46765 .32523 m .46928 .32425 L .4778 .32601 L .631 .85 .983 r

F

.46623 .31504 m .46928 .32425 L .46765 .32523 L .428 .326 .636 r

F

0 g

.46195 .33554 m

.46765 .32523 L

s

.46623 .31504 m .46785 .31406 L .46928 .32425 L .428 .326 .636 r

F

0 g

.46482 .30488 m

.46623 .31504 L

s

.45238 .20326 m

.46928 .32425 L

s

.46928 .32425 m

.56923 .34486 L

s

.46623 .31504 m

.46765 .32523 L

s

.08459 .15474 m

.23953 .03727 L

s

.02837 1.05739 m

.08459 .15474 L

s

.71833 .96013 m .69896 .95603 L .71401 .94978 L .698 .563 .699 r

F

.71833 .96013 m .70329 .96637 L .69896 .95603 L F

.70329 .96637 m .68676 .96124 L .69896 .95603 L .738 .582 .68 r

F

.74094 .95115 m .71833 .96013 L .71401 .94978 L .634 .532 .72 r

F

.69896 .95603 m .71735 .95011 L .68676 .96124 L 0 0 0 r

F

.74094 .95115 m .71401 .94978 L .7366 .94078 L .634 .532 .72 r

F

.69896 .95603 m .72439 .94677 L .71735 .95011 L 0 0 0 r

F

.71401 .94978 m .72439 .94677 L .69896 .95603 L F

.71401 .94978 m .73141 .94344 L .72439 .94677 L F

.7366 .94078 m .73141 .94344 L .71401 .94978 L F

0 g

.69896 .95603 m

.71401 .94978 L

s

.72266 .97048 m .70329 .96637 L .71833 .96013 L .698 .563 .699 r

F

.72266 .97048 m .70761 .97673 L .70329 .96637 L F

.70329 .96637 m .69108 .9716 L .68676 .96124 L .738 .582 .68 r

F

.70761 .97673 m .69108 .9716 L .70329 .96637 L F

.74529 .96152 m .71833 .96013 L .74094 .95115 L .634 .532 .72 r

F

.74529 .96152 m .72266 .97048 L .71833 .96013 L F

.70761 .97673 m .6954 .98196 L .69108 .9716 L .738 .582 .68 r

F

.71193 .98708 m .6954 .98196 L .70761 .97673 L F

.72699 .98084 m .70761 .97673 L .72266 .97048 L .698 .563 .699 r

F

.72699 .98084 m .71193 .98708 L .70761 .97673 L F

.74963 .9719 m .72266 .97048 L .74529 .96152 L .634 .532 .72 r

F

.74963 .9719 m .72699 .98084 L .72266 .97048 L F

.73132 .9912 m .71193 .98708 L .72699 .98084 L .698 .563 .699 r

F

.73132 .9912 m .71626 .99744 L .71193 .98708 L F

.71193 .98708 m .69973 .99233 L .6954 .98196 L .738 .582 .68 r

F

.71626 .99744 m .69973 .99233 L .71193 .98708 L F

.75397 .98229 m .72699 .98084 L .74963 .9719 L .634 .532 .72 r

F

.75397 .98229 m .73132 .9912 L .72699 .98084 L F

.73565 1.00156 m .71626 .99744 L .73132 .9912 L .698 .563 .699 r

F

.73565 1.00156 m .72059 1.00781 L .71626 .99744 L F

.71626 .99744 m .70406 1.0027 L .69973 .99233 L .738 .582 .68 r

F

.72059 1.00781 m .70406 1.0027 L .71626 .99744 L F

.69108 .9716 m .67636 .9658 L .68676 .96124 L .773 .597 .661 r

F

.68676 .96124 m .71027 .95348 L .67636 .9658 L 0 0 0 r

F

.68676 .96124 m .71735 .95011 L .71027 .95348 L F

0 g

.68676 .96124 m

.69896 .95603 L

s

.75832 .99268 m .73132 .9912 L .75397 .98229 L .634 .532 .72 r

F

.75832 .99268 m .73565 1.00156 L .73132 .9912 L F

.73998 1.01193 m .72059 1.00781 L .73565 1.00156 L .698 .563 .699 r

F

.73998 1.01193 m .72492 1.01817 L .72059 1.00781 L F

.72059 1.00781 m .70839 1.01307 L .70406 1.0027 L .738 .582 .68 r

F

.72492 1.01817 m .70839 1.01307 L .72059 1.00781 L F

.69108 .9716 m .68069 .97617 L .67636 .9658 L .773 .597 .661 r

F

.6954 .98196 m .68069 .97617 L .69108 .9716 L F

.76267 1.00307 m .73565 1.00156 L .75832 .99268 L .634 .532 .72 r

F

.76267 1.00307 m .73998 1.01193 L .73565 1.00156 L F

.74432 1.0223 m .72492 1.01817 L .73998 1.01193 L .698 .563 .699 r

F

.74432 1.0223 m .72925 1.02855 L .72492 1.01817 L F

.72492 1.01817 m .71272 1.02344 L .70839 1.01307 L .738 .582 .68 r

F

.72925 1.02855 m .71272 1.02344 L .72492 1.01817 L F

.6954 .98196 m .68502 .98655 L .68069 .97617 L .773 .597 .661 r

F

.69973 .99233 m .68502 .98655 L .6954 .98196 L F

.76702 1.01346 m .73998 1.01193 L .76267 1.00307 L .634 .532 .72 r

F

.76702 1.01346 m .74432 1.0223 L .73998 1.01193 L F

.74865 1.03267 m .72925 1.02855 L .74432 1.0223 L .698 .563 .699 r

F

.74865 1.03267 m .73358 1.03892 L .72925 1.02855 L F

.72925 1.02855 m .71705 1.03382 L .71272 1.02344 L .738 .582 .68 r

F

.73358 1.03892 m .71705 1.03382 L .72925 1.02855 L F

.69973 .99233 m .68935 .99693 L .68502 .98655 L .773 .597 .661 r

F

.70406 1.0027 m .68935 .99693 L .69973 .99233 L F

.77137 1.02386 m .74432 1.0223 L .76702 1.01346 L .634 .532 .72 r

F

.77137 1.02386 m .74865 1.03267 L .74432 1.0223 L F

.75299 1.04305 m .73358 1.03892 L .74865 1.03267 L .698 .563 .699 r

F

.75299 1.04305 m .73792 1.0493 L .73358 1.03892 L F

.73358 1.03892 m .72138 1.04421 L .71705 1.03382 L .738 .582 .68 r

F

.73792 1.0493 m .72138 1.04421 L .73358 1.03892 L F

.70406 1.0027 m .69368 1.00731 L .68935 .99693 L .773 .597 .661 r

F

.70839 1.01307 m .69368 1.00731 L .70406 1.0027 L F

.77572 1.03426 m .74865 1.03267 L .77137 1.02386 L .634 .532 .72 r

F

.77572 1.03426 m .75299 1.04305 L .74865 1.03267 L F

.75733 1.05343 m .73792 1.0493 L .75299 1.04305 L .698 .563 .699 r

F

.75733 1.05343 m .74225 1.05968 L .73792 1.0493 L F

0 g

.02837 1.05739 m

.56651 1.17496 L

s

.56651 1.17496 m

.79081 1.22396 L

s

.73792 1.0493 m .72572 1.05459 L .72138 1.04421 L .738 .582 .68 r

F

.74225 1.05968 m .72572 1.05459 L .73792 1.0493 L F

.70839 1.01307 m .69801 1.0177 L .69368 1.00731 L .773 .597 .661 r

F

.71272 1.02344 m .69801 1.0177 L .70839 1.01307 L F

.78007 1.04467 m .75299 1.04305 L .77572 1.03426 L .634 .532 .72 r

F

.78007 1.04467 m .75733 1.05343 L .75299 1.04305 L F

.76167 1.06382 m .74225 1.05968 L .75733 1.05343 L .698 .563 .699 r

F

.76167 1.06382 m .74659 1.07007 L .74225 1.05968 L F

.74225 1.05968 m .73006 1.06499 L .72572 1.05459 L .738 .582 .68 r

F

.74659 1.07007 m .73006 1.06499 L .74225 1.05968 L F

.71272 1.02344 m .70234 1.02809 L .69801 1.0177 L .773 .597 .661 r

F

.71705 1.03382 m .70234 1.02809 L .71272 1.02344 L F

.78443 1.05508 m .75733 1.05343 L .78007 1.04467 L .634 .532 .72 r

F

.78443 1.05508 m .76167 1.06382 L .75733 1.05343 L F

.76601 1.07421 m .74659 1.07007 L .76167 1.06382 L .698 .563 .699 r

F

.76601 1.07421 m .75093 1.08046 L .74659 1.07007 L F

.74659 1.07007 m .73439 1.07538 L .73006 1.06499 L .738 .582 .68 r

F

.75093 1.08046 m .73439 1.07538 L .74659 1.07007 L F

.71705 1.03382 m .70668 1.03848 L .70234 1.02809 L .773 .597 .661 r

F

.72138 1.04421 m .70668 1.03848 L .71705 1.03382 L F

.68069 .97617 m .66737 .96985 L .67636 .9658 L .807 .611 .638 r

F

.67636 .9658 m .70316 .95685 L .66737 .96985 L 0 0 0 r

F

.67636 .9658 m .71027 .95348 L .70316 .95685 L F

0 g

.67636 .9658 m

.68676 .96124 L

s

.78879 1.0655 m .76167 1.06382 L .78443 1.05508 L .634 .532 .72 r

F

.78879 1.0655 m .76601 1.07421 L .76167 1.06382 L F

.75093 1.08046 m .78373 1.06853 L .76601 1.07421 L 0 0 0 r

F

.75093 1.08046 m .77683 1.07217 L .78373 1.06853 L F

.73873 1.08578 m .77683 1.07217 L .75093 1.08046 L F

.75093 1.08046 m .73873 1.08578 L .73439 1.07538 L .738 .582 .68 r

F

.72138 1.04421 m .71102 1.04888 L .70668 1.03848 L .773 .597 .661 r

F

.72572 1.05459 m .71102 1.04888 L .72138 1.04421 L F

.68069 .97617 m .67171 .98024 L .66737 .96985 L .807 .611 .638 r

F

.68502 .98655 m .67171 .98024 L .68069 .97617 L F

.76601 1.07421 m .7906 1.06491 L .78879 1.0655 L 0 0 0 r

F

.76601 1.07421 m .78373 1.06853 L .7906 1.06491 L F

0 g

.75093 1.08046 m

.76601 1.07421 L

s

.72572 1.05459 m .71536 1.05928 L .71102 1.04888 L .773 .597 .661 r

F

.73006 1.06499 m .71536 1.05928 L .72572 1.05459 L F

.68502 .98655 m .67604 .99064 L .67171 .98024 L .807 .611 .638 r

F

.68935 .99693 m .67604 .99064 L .68502 .98655 L F

.73006 1.06499 m .7197 1.06969 L .71536 1.05928 L .773 .597 .661 r

F

.73439 1.07538 m .7197 1.06969 L .73006 1.06499 L F

.74094 .95115 m .73839 .94013 L .7366 .94078 L .496 .458 .745 r

F

.7366 .94078 m .73839 .94013 L .73141 .94344 L 0 0 0 r

F

0 g

.71401 .94978 m

.7366 .94078 L

s

.68935 .99693 m .68038 1.00104 L .67604 .99064 L .807 .611 .638 r

F

.69368 1.00731 m .68038 1.00104 L .68935 .99693 L F

.73439 1.07538 m .72404 1.0801 L .7197 1.06969 L .773 .597 .661 r

F

.73873 1.08578 m .72404 1.0801 L .73439 1.07538 L F

.74094 .95115 m .74273 .9505 L .73839 .94013 L .496 .458 .745 r

F

.74529 .96152 m .74273 .9505 L .74094 .95115 L F

0 g

.73667 .94094 m

.74094 .95115 L

s

.69368 1.00731 m .68471 1.01144 L .68038 1.00104 L .807 .611 .638 r

F

.69801 1.0177 m .68471 1.01144 L .69368 1.00731 L F

0 g

.92559 1.16044 m

.97757 1.173 L

s

.73873 1.08578 m .76989 1.07582 L .77683 1.07217 L 0 0 0 r

F

0 g

.7247 1.11187 m

.92559 1.16044 L

s

.72839 1.09051 m .76989 1.07582 L .73873 1.08578 L 0 0 0 r

F

.73873 1.08578 m .72839 1.09051 L .72404 1.0801 L .773 .597 .661 r

F

0 g

.73873 1.08578 m

.75093 1.08046 L

s

.74529 .96152 m .74707 .96089 L .74273 .9505 L .496 .458 .745 r

F

.74963 .9719 m .74707 .96089 L .74529 .96152 L F

0 g

.74094 .95115 m

.74529 .96152 L

s

.69801 1.0177 m .68905 1.02185 L .68471 1.01144 L .807 .611 .638 r

F

.70234 1.02809 m .68905 1.02185 L .69801 1.0177 L F

.74963 .9719 m .75142 .97127 L .74707 .96089 L .496 .458 .745 r

F

.75397 .98229 m .75142 .97127 L .74963 .9719 L F

0 g

.74529 .96152 m

.74963 .9719 L

s

.75397 .98229 m .75576 .98166 L .75142 .97127 L .496 .458 .745 r

F

.75832 .99268 m .75576 .98166 L .75397 .98229 L F

.75832 .99268 m .76011 .99206 L .75576 .98166 L F

.76267 1.00307 m .76011 .99206 L .75832 .99268 L F

.76267 1.00307 m .76446 1.00245 L .76011 .99206 L F

.76702 1.01346 m .76446 1.00245 L .76267 1.00307 L F

.76702 1.01346 m .76882 1.01285 L .76446 1.00245 L F

.77137 1.02386 m .76882 1.01285 L .76702 1.01346 L F

.67171 .98024 m .65961 .97346 L .66737 .96985 L .841 .624 .609 r

F

.77137 1.02386 m .77317 1.02326 L .76882 1.01285 L .496 .458 .745 r

F

.77572 1.03426 m .77317 1.02326 L .77137 1.02386 L F

.67171 .98024 m .66395 .98387 L .65961 .97346 L .841 .624 .609 r

F

.67604 .99064 m .66395 .98387 L .67171 .98024 L F

.77572 1.03426 m .77752 1.03367 L .77317 1.02326 L .496 .458 .745 r

F

.78007 1.04467 m .77752 1.03367 L .77572 1.03426 L F

.67604 .99064 m .6683 .99429 L .66395 .98387 L .841 .624 .609 r

F

.68038 1.00104 m .6683 .99429 L .67604 .99064 L F

.78007 1.04467 m .78188 1.04408 L .77752 1.03367 L .496 .458 .745 r

F

.78443 1.05508 m .78188 1.04408 L .78007 1.04467 L F

.78443 1.05508 m .78624 1.05449 L .78188 1.04408 L F

.78879 1.0655 m .78624 1.05449 L .78443 1.05508 L F

.78879 1.0655 m .7906 1.06491 L .78624 1.05449 L F

.66395 .98387 m .65303 .97664 L .65961 .97346 L .879 .636 .568 r

F

.66395 .98387 m .65738 .98708 L .65303 .97664 L F

.6683 .99429 m .65738 .98708 L .66395 .98387 L F

.65738 .98708 m .64768 .97938 L .65303 .97664 L .919 .644 .504 r

F

.7906 1.06491 m .6524 .98095 L .73839 .94013 L .862 .631 .587 r

F

.70234 1.02809 m .69339 1.03226 L .68905 1.02185 L .807 .611 .638 r

F

.70668 1.03848 m .69339 1.03226 L .70234 1.02809 L F

.70668 1.03848 m .69774 1.04267 L .69339 1.03226 L F

.71102 1.04888 m .69774 1.04267 L .70668 1.03848 L F

.71102 1.04888 m .70208 1.05309 L .69774 1.04267 L F

.71536 1.05928 m .70208 1.05309 L .71102 1.04888 L F

.71536 1.05928 m .70643 1.06351 L .70208 1.05309 L F

.7197 1.06969 m .70643 1.06351 L .71536 1.05928 L F

.66737 .96985 m .69601 .96025 L .65961 .97346 L 0 0 0 r

F

.66737 .96985 m .70316 .95685 L .69601 .96025 L F

0 g

.66737 .96985 m

.67636 .9658 L

s

.7197 1.06969 m .71077 1.07393 L .70643 1.06351 L .807 .611 .638 r

F

.72404 1.0801 m .71077 1.07393 L .7197 1.06969 L F

.72404 1.0801 m .71512 1.08436 L .71077 1.07393 L F

.72839 1.09051 m .71512 1.08436 L .72404 1.0801 L F

.72839 1.09051 m .76292 1.07949 L .76989 1.07582 L 0 0 0 r

F

.71947 1.09479 m .76292 1.07949 L .72839 1.09051 L F

.72839 1.09051 m .71947 1.09479 L .71512 1.08436 L .807 .611 .638 r

F

0 g

.72839 1.09051 m

.73873 1.08578 L

s

.68038 1.00104 m .67264 1.00471 L .6683 .99429 L .841 .624 .609 r

F

.68471 1.01144 m .67264 1.00471 L .68038 1.00104 L F

0 g

.76601 1.07421 m

.78879 1.0655 L

s

.78784 1.06324 m

.78879 1.0655 L

s

.68471 1.01144 m .67699 1.01514 L .67264 1.00471 L .841 .624 .609 r

F

.68905 1.02185 m .67699 1.01514 L .68471 1.01144 L F

0 g

.78879 1.0655 m

.78879 1.0655 L

s

.68905 1.02185 m .68133 1.02557 L .67699 1.01514 L .841 .624 .609 r

F

.69339 1.03226 m .68133 1.02557 L .68905 1.02185 L F

.69339 1.03226 m .68568 1.036 L .68133 1.02557 L F

.69774 1.04267 m .68568 1.036 L .69339 1.03226 L F

.69774 1.04267 m .69003 1.04644 L .68568 1.036 L F

.70208 1.05309 m .69003 1.04644 L .69774 1.04267 L F

.70208 1.05309 m .69439 1.05688 L .69003 1.04644 L F

.70643 1.06351 m .69439 1.05688 L .70208 1.05309 L F

.70643 1.06351 m .69874 1.06733 L .69439 1.05688 L F

.71077 1.07393 m .69874 1.06733 L .70643 1.06351 L F

.71077 1.07393 m .70309 1.07777 L .69874 1.06733 L F

.71512 1.08436 m .70309 1.07777 L .71077 1.07393 L F

.71512 1.08436 m .70745 1.08823 L .70309 1.07777 L F

.71947 1.09479 m .70745 1.08823 L .71512 1.08436 L F

.71947 1.09479 m .75592 1.08317 L .76292 1.07949 L 0 0 0 r

F

.71181 1.09868 m .75592 1.08317 L .71947 1.09479 L F

.71947 1.09479 m .71181 1.09868 L .70745 1.08823 L .841 .624 .609 r

F

.6683 .99429 m .66174 .99753 L .65738 .98708 L .879 .636 .568 r

F

.67264 1.00471 m .66174 .99753 L .6683 .99429 L F

.67264 1.00471 m .66609 1.00798 L .66174 .99753 L F

.67699 1.01514 m .66609 1.00798 L .67264 1.00471 L F

.67699 1.01514 m .67045 1.01843 L .66609 1.00798 L F

.68133 1.02557 m .67045 1.01843 L .67699 1.01514 L F

.68133 1.02557 m .6748 1.02889 L .67045 1.01843 L F

.68568 1.036 m .6748 1.02889 L .68133 1.02557 L F

.68568 1.036 m .67916 1.03935 L .6748 1.02889 L F

.69003 1.04644 m .67916 1.03935 L .68568 1.036 L F

.69003 1.04644 m .68352 1.04981 L .67916 1.03935 L F

.69439 1.05688 m .68352 1.04981 L .69003 1.04644 L F

.69439 1.05688 m .68789 1.06028 L .68352 1.04981 L F

.69874 1.06733 m .68789 1.06028 L .69439 1.05688 L F

.69874 1.06733 m .69225 1.07076 L .68789 1.06028 L F

.70309 1.07777 m .69225 1.07076 L .69874 1.06733 L F

.70309 1.07777 m .69661 1.08123 L .69225 1.07076 L F

.70745 1.08823 m .69661 1.08123 L .70309 1.07777 L F

.70745 1.08823 m .70098 1.09171 L .69661 1.08123 L F

.71181 1.09868 m .70098 1.09171 L .70745 1.08823 L F

.71181 1.09868 m .74889 1.08688 L .75592 1.08317 L 0 0 0 r

F

.70535 1.10219 m .74889 1.08688 L .71181 1.09868 L F

.71181 1.09868 m .70535 1.10219 L .70098 1.09171 L .879 .636 .568 r

F

.65738 .98708 m .65205 .98986 L .64768 .97938 L .919 .644 .504 r

F

.66174 .99753 m .65205 .98986 L .65738 .98708 L F

.66174 .99753 m .65641 1.00033 L .65205 .98986 L F

.66609 1.00798 m .65641 1.00033 L .66174 .99753 L F

.66609 1.00798 m .66078 1.01081 L .65641 1.00033 L F

.67045 1.01843 m .66078 1.01081 L .66609 1.00798 L F

.67045 1.01843 m .66514 1.0213 L .66078 1.01081 L F

.6748 1.02889 m .66514 1.0213 L .67045 1.01843 L F

.6748 1.02889 m .66951 1.03179 L .66514 1.0213 L F

.67916 1.03935 m .66951 1.03179 L .6748 1.02889 L F

.67916 1.03935 m .67389 1.04228 L .66951 1.03179 L F

.68352 1.04981 m .67389 1.04228 L .67916 1.03935 L F

.68352 1.04981 m .67826 1.05278 L .67389 1.04228 L F

.68789 1.06028 m .67826 1.05278 L .68352 1.04981 L F

.68789 1.06028 m .68263 1.06328 L .67826 1.05278 L F

.69225 1.07076 m .68263 1.06328 L .68789 1.06028 L F

.69225 1.07076 m .68701 1.07378 L .68263 1.06328 L F

.69661 1.08123 m .68701 1.07378 L .69225 1.07076 L F

.69661 1.08123 m .69138 1.08429 L .68701 1.07378 L F

.70098 1.09171 m .69138 1.08429 L .69661 1.08123 L F

.70098 1.09171 m .69576 1.0948 L .69138 1.08429 L F

.70535 1.10219 m .69576 1.0948 L .70098 1.09171 L F

.70535 1.10219 m .74182 1.0906 L .74889 1.08688 L 0 0 0 r

F

.70014 1.10532 m .74182 1.0906 L .70535 1.10219 L F

.70535 1.10219 m .70014 1.10532 L .69576 1.0948 L .919 .644 .504 r

F

.70014 1.10532 m .73471 1.09434 L .74182 1.0906 L 0 0 0 r

F

.69637 1.10799 m .73471 1.09434 L .70014 1.10532 L F

.69637 1.10799 m .72758 1.0981 L .73471 1.09434 L F

.69446 1.11009 m .72758 1.0981 L .69637 1.10799 L F

.69446 1.11009 m .7204 1.10188 L .72758 1.0981 L F

.69544 1.11129 m .7204 1.10188 L .69446 1.11009 L F

.69544 1.11129 m .71319 1.10567 L .7204 1.10188 L F

.70413 1.11006 m .71319 1.10567 L .69544 1.11129 L F

.70413 1.11006 m .70595 1.10949 L .71319 1.10567 L F

.7906 1.06491 m .70595 1.10949 L .6524 .98095 L .862 .631 .587 r

F

0 g

.73839 .94013 m

.7906 1.06491 L

s

.65961 .97346 m .68883 .96366 L .65303 .97664 L 0 0 0 r

F

.65961 .97346 m .69601 .96025 L .68883 .96366 L F

0 g

.65961 .97346 m

.66737 .96985 L

s

.65303 .97664 m .68161 .96708 L .64768 .97938 L 0 0 0 r

F

.65303 .97664 m .68883 .96366 L .68161 .96708 L F

0 g

.65303 .97664 m

.65961 .97346 L

s

.65205 .98986 m .64374 .98162 L .64768 .97938 L .955 .638 .388 r

F

.64768 .97938 m .67436 .97052 L .64374 .98162 L 0 0 0 r

F

.64768 .97938 m .68161 .96708 L .67436 .97052 L F

0 g

.64768 .97938 m

.65303 .97664 L

s

.20039 .98512 m

.543 1.06795 L

s

.65205 .98986 m .64812 .99213 L .64374 .98162 L .955 .638 .388 r

F

.65641 1.00033 m .64812 .99213 L .65205 .98986 L F

.65641 1.00033 m .6525 1.00264 L .64812 .99213 L F

.66078 1.01081 m .6525 1.00264 L .65641 1.00033 L F

.66078 1.01081 m .65688 1.01316 L .6525 1.00264 L F

.66514 1.0213 m .65688 1.01316 L .66078 1.01081 L F

.66514 1.0213 m .66126 1.02368 L .65688 1.01316 L F

.66951 1.03179 m .66126 1.02368 L .66514 1.0213 L F

.66951 1.03179 m .66564 1.03421 L .66126 1.02368 L F

.67389 1.04228 m .66564 1.03421 L .66951 1.03179 L F

.67389 1.04228 m .67003 1.04474 L .66564 1.03421 L F

.67826 1.05278 m .67003 1.04474 L .67389 1.04228 L F

.67826 1.05278 m .67442 1.05527 L .67003 1.04474 L F

.68263 1.06328 m .67442 1.05527 L .67826 1.05278 L F

.68263 1.06328 m .6788 1.06581 L .67442 1.05527 L F

.68701 1.07378 m .6788 1.06581 L .68263 1.06328 L F

.68701 1.07378 m .68319 1.07635 L .6788 1.06581 L F

.69138 1.08429 m .68319 1.07635 L .68701 1.07378 L F

.69138 1.08429 m .68759 1.08689 L .68319 1.07635 L F

.69576 1.0948 m .68759 1.08689 L .69138 1.08429 L F

.69576 1.0948 m .69198 1.09744 L .68759 1.08689 L F

.70014 1.10532 m .69198 1.09744 L .69576 1.0948 L F

.70014 1.10532 m .69637 1.10799 L .69198 1.09744 L F

0 g

.70014 1.10532 m

.7034 1.10336 L

s

.363 .36647 m .39207 .34695 L .37626 .35662 L 0 0 0 r

F

.363 .36647 m .38611 .35235 L .39207 .34695 L F

.35232 .37475 m .38611 .35235 L .363 .36647 L F

.35622 .35738 m .37626 .35662 L .363 .36647 L .723 .621 .744 r

F

.34553 .36565 m .363 .36647 L .35232 .37475 L .758 .628 .716 r

F

.34553 .36565 m .35622 .35738 L .363 .36647 L F

.37626 .35662 m .398 .34157 L .39638 .34257 L 0 0 0 r

F

.37626 .35662 m .39207 .34695 L .398 .34157 L F

.36949 .34752 m .39638 .34257 L .37626 .35662 L .666 .607 .779 r

F

.35622 .35738 m .36949 .34752 L .37626 .35662 L .723 .621 .744 r

F

0 g

.363 .36647 m

.37626 .35662 L

s

.34943 .34827 m .36949 .34752 L .35622 .35738 L .723 .621 .744 r

F

.33873 .35655 m .35622 .35738 L .34553 .36565 L .758 .628 .716 r

F

.33873 .35655 m .34943 .34827 L .35622 .35738 L F

.35232 .37475 m .38012 .35778 L .38611 .35235 L 0 0 0 r

F

.34329 .38202 m .38012 .35778 L .35232 .37475 L F

.33648 .37292 m .35232 .37475 L .34329 .38202 L .789 .632 .687 r

F

.33648 .37292 m .34553 .36565 L .35232 .37475 L F

0 g

.35232 .37475 m

.363 .36647 L

s

.64812 .99213 m .64161 .9832 L .64374 .98162 L .928 .565 .144 r

F

.64374 .98162 m .66708 .97398 L .64161 .9832 L 0 0 0 r

F

.64374 .98162 m .67436 .97052 L .66708 .97398 L F

0 g

.64374 .98162 m

.64768 .97938 L

s

.36949 .34752 m .38961 .33343 L .39638 .34257 L .666 .607 .779 r

F

.36271 .33841 m .38961 .33343 L .36949 .34752 L F

.34943 .34827 m .36271 .33841 L .36949 .34752 L .723 .621 .744 r

F

.64812 .99213 m .64601 .99375 L .64161 .9832 L .928 .565 .144 r

F

.6525 1.00264 m .64601 .99375 L .64812 .99213 L F

.6525 1.00264 m .6504 1.00431 L .64601 .99375 L F

.65688 1.01316 m .6504 1.00431 L .6525 1.00264 L F

.34264 .33916 m .36271 .33841 L .34943 .34827 L .723 .621 .744 r

F

.33192 .34743 m .34943 .34827 L .33873 .35655 L .758 .628 .716 r

F

.33192 .34743 m .34264 .33916 L .34943 .34827 L F

.32967 .36381 m .34553 .36565 L .33648 .37292 L .789 .632 .687 r

F

.32967 .36381 m .33873 .35655 L .34553 .36565 L F

.65688 1.01316 m .6548 1.01487 L .6504 1.00431 L .928 .565 .144 r

F

.66126 1.02368 m .6548 1.01487 L .65688 1.01316 L F

.36271 .33841 m .38282 .32428 L .38961 .33343 L .666 .607 .779 r

F

.35592 .32928 m .38282 .32428 L .36271 .33841 L F

.34264 .33916 m .35592 .32928 L .36271 .33841 L .723 .621 .744 r

F

.66126 1.02368 m .6592 1.02544 L .6548 1.01487 L .928 .565 .144 r

F

.66564 1.03421 m .6592 1.02544 L .66126 1.02368 L F

.66564 1.03421 m .6636 1.036 L .6592 1.02544 L F

.67003 1.04474 m .6636 1.036 L .66564 1.03421 L F

.67003 1.04474 m .66801 1.04658 L .6636 1.036 L F

.67442 1.05527 m .66801 1.04658 L .67003 1.04474 L F

.33583 .33003 m .35592 .32928 L .34264 .33916 L .723 .621 .744 r

F

.3251 .3383 m .34264 .33916 L .33192 .34743 L .758 .628 .716 r

F

.3251 .3383 m .33583 .33003 L .34264 .33916 L F

.34329 .38202 m .3741 .36323 L .38012 .35778 L 0 0 0 r

F

.33554 .38852 m .3741 .36323 L .34329 .38202 L F

.32872 .37941 m .34329 .38202 L .33554 .38852 L .817 .634 .654 r

F

.32872 .37941 m .33648 .37292 L .34329 .38202 L F

0 g

.34329 .38202 m

.35232 .37475 L

s

.32285 .35468 m .33873 .35655 L .32967 .36381 L .789 .632 .687 r

F

.32285 .35468 m .33192 .34743 L .33873 .35655 L F

.67442 1.05527 m .67241 1.05715 L .66801 1.04658 L .928 .565 .144 r

F

.6788 1.06581 m .67241 1.05715 L .67442 1.05527 L F

.35592 .32928 m .37602 .31513 L .38282 .32428 L .666 .607 .779 r

F

.34912 .32014 m .37602 .31513 L .35592 .32928 L F

.33583 .33003 m .34912 .32014 L .35592 .32928 L .723 .621 .744 r

F

.6788 1.06581 m .67682 1.06773 L .67241 1.05715 L .928 .565 .144 r

F

.68319 1.07635 m .67682 1.06773 L .6788 1.06581 L F

0 g

.543 1.06795 m

.64073 1.09157 L

s

.68319 1.07635 m .68122 1.07832 L .67682 1.06773 L .928 .565 .144 r

F

.68759 1.08689 m .68122 1.07832 L .68319 1.07635 L F

.32901 .32089 m .34912 .32014 L .33583 .33003 L .723 .621 .744 r

F

.31827 .32916 m .33583 .33003 L .3251 .3383 L .758 .628 .716 r

F

.31827 .32916 m .32901 .32089 L .33583 .33003 L F

.32188 .37028 m .33648 .37292 L .32872 .37941 L .817 .634 .654 r

F

.32188 .37028 m .32967 .36381 L .33648 .37292 L F

.31601 .34555 m .33192 .34743 L .32285 .35468 L .789 .632 .687 r

F

.31601 .34555 m .3251 .3383 L .33192 .34743 L F

.68759 1.08689 m .68563 1.0889 L .68122 1.07832 L .928 .565 .144 r

F

.69198 1.09744 m .68563 1.0889 L .68759 1.08689 L F

.39638 .34257 m .39122 .33243 L .38961 .33343 L .536 .562 .829 r

F

.39638 .34257 m .398 .34157 L .39122 .33243 L F

0 g

.37626 .35662 m

.39638 .34257 L

s

.39638 .34257 m

.39638 .34257 L

s

.34912 .32014 m .36922 .30596 L .37602 .31513 L .666 .607 .779 r

F

.34231 .31099 m .36922 .30596 L .34912 .32014 L F

.32901 .32089 m .34231 .31099 L .34912 .32014 L .723 .621 .744 r

F

.69198 1.09744 m .69004 1.0995 L .68563 1.0889 L .928 .565 .144 r

F

.69637 1.10799 m .69004 1.0995 L .69198 1.09744 L F

.69637 1.10799 m .69446 1.11009 L .69004 1.0995 L F

0 g

.69637 1.10799 m

.70014 1.10532 L

s

.32219 .31173 m .34231 .31099 L .32901 .32089 L .723 .621 .744 r

F

.31144 .32001 m .32901 .32089 L .31827 .32916 L .758 .628 .716 r

F

.31144 .32001 m .32219 .31173 L .32901 .32089 L F

.31504 .36114 m .32967 .36381 L .32188 .37028 L .817 .634 .654 r

F

.31504 .36114 m .32285 .35468 L .32967 .36381 L F

.30917 .3364 m .3251 .3383 L .31601 .34555 L .789 .632 .687 r

F

.30917 .3364 m .31827 .32916 L .3251 .3383 L F

.33554 .38852 m .36805 .3687 L .3741 .36323 L 0 0 0 r

F

.32891 .39434 m .36805 .3687 L .33554 .38852 L F

.32207 .38521 m .33554 .38852 L .32891 .39434 L .845 .632 .615 r

F

.32207 .38521 m .32872 .37941 L .33554 .38852 L F

.30459 .31084 m .32219 .31173 L .31144 .32001 L .758 .628 .716 r

F

.30819 .352 m .32285 .35468 L .31504 .36114 L .817 .634 .654 r

F

.30819 .352 m .31601 .34555 L .32285 .35468 L F

.30232 .32724 m .31827 .32916 L .30917 .3364 L .789 .632 .687 r

F

.30232 .32724 m .31144 .32001 L .31827 .32916 L F

.31521 .37607 m .32872 .37941 L .32207 .38521 L .845 .632 .615 r

F

.31521 .37607 m .32188 .37028 L .32872 .37941 L F

.30133 .34284 m .31601 .34555 L .30819 .352 L .817 .634 .654 r

F

.30133 .34284 m .30917 .3364 L .31601 .34555 L F

.29546 .31806 m .31144 .32001 L .30232 .32724 L .789 .632 .687 r

F

.29546 .31806 m .30459 .31084 L .31144 .32001 L F

.30835 .36692 m .32188 .37028 L .31521 .37607 L .845 .632 .615 r

F

.30835 .36692 m .31504 .36114 L .32188 .37028 L F

.29447 .33366 m .30917 .3364 L .30133 .34284 L .817 .634 .654 r

F

.29447 .33366 m .30232 .32724 L .30917 .3364 L F

.28859 .30888 m .30459 .31084 L .29546 .31806 L .789 .632 .687 r

F

.30149 .35776 m .31504 .36114 L .30835 .36692 L .845 .632 .615 r

F

.30149 .35776 m .30819 .352 L .31504 .36114 L F

.32891 .39434 m .36198 .37421 L .36805 .3687 L 0 0 0 r

F

.32335 .39952 m .36198 .37421 L .32891 .39434 L F

.31649 .39037 m .32891 .39434 L .32335 .39952 L .875 .627 .561 r

F

.31649 .39037 m .32207 .38521 L .32891 .39434 L F

.28759 .32448 m .30232 .32724 L .29447 .33366 L .817 .634 .654 r

F

.28759 .32448 m .29546 .31806 L .30232 .32724 L F

.29461 .34858 m .30819 .352 L .30149 .35776 L .845 .632 .615 r

F

.29461 .34858 m .30133 .34284 L .30819 .352 L F

.30961 .38121 m .32207 .38521 L .31649 .39037 L .875 .627 .561 r

F

.30961 .38121 m .31521 .37607 L .32207 .38521 L F

.2807 .31528 m .29546 .31806 L .28759 .32448 L .817 .634 .654 r

F

.2807 .31528 m .28859 .30888 L .29546 .31806 L F

.28772 .33939 m .30133 .34284 L .29461 .34858 L .845 .632 .615 r

F

.28772 .33939 m .29447 .33366 L .30133 .34284 L F

.30273 .37204 m .31521 .37607 L .30961 .38121 L .875 .627 .561 r

F

.30273 .37204 m .30835 .36692 L .31521 .37607 L F

.27381 .30608 m .28859 .30888 L .2807 .31528 L .817 .634 .654 r

F

.27381 .30608 m .28171 .29968 L .28859 .30888 L F

.28082 .33019 m .29447 .33366 L .28772 .33939 L .845 .632 .615 r

F

.28082 .33019 m .28759 .32448 L .29447 .33366 L F

.29584 .36285 m .30835 .36692 L .30273 .37204 L .875 .627 .561 r

F

.29584 .36285 m .30149 .35776 L .30835 .36692 L F

.2669 .29686 m .28171 .29968 L .27381 .30608 L .817 .634 .654 r

F

.27392 .32098 m .28759 .32448 L .28082 .33019 L .845 .632 .615 r

F

.27392 .32098 m .2807 .31528 L .28759 .32448 L F

.32335 .39952 m .35588 .37973 L .36198 .37421 L 0 0 0 r

F

.31891 .40402 m .35588 .37973 L .32335 .39952 L F

.31202 .39485 m .32335 .39952 L .31891 .40402 L .904 .611 .48 r

F

.31202 .39485 m .31649 .39037 L .32335 .39952 L F

.28894 .35366 m .30149 .35776 L .29584 .36285 L .875 .627 .561 r

F

.28894 .35366 m .29461 .34858 L .30149 .35776 L F

.26701 .31176 m .2807 .31528 L .27392 .32098 L .845 .632 .615 r

F

.26701 .31176 m .27381 .30608 L .2807 .31528 L F

.30513 .38567 m .31649 .39037 L .31202 .39485 L .904 .611 .48 r

F

.30513 .38567 m .30961 .38121 L .31649 .39037 L F

.28204 .34445 m .29461 .34858 L .28894 .35366 L .875 .627 .561 r

F

.28204 .34445 m .28772 .33939 L .29461 .34858 L F

.26008 .30252 m .27381 .30608 L .26701 .31176 L .845 .632 .615 r

F

.26008 .30252 m .2669 .29686 L .27381 .30608 L F

.29822 .37647 m .30961 .38121 L .30513 .38567 L .904 .611 .48 r

F

.29822 .37647 m .30273 .37204 L .30961 .38121 L F

.27512 .33523 m .28772 .33939 L .28204 .34445 L .875 .627 .561 r

F

.27512 .33523 m .28082 .33019 L .28772 .33939 L F

.25315 .29327 m .2669 .29686 L .26008 .30252 L .845 .632 .615 r

F

.29131 .36726 m .30273 .37204 L .29822 .37647 L .904 .611 .48 r

F

.29131 .36726 m .29584 .36285 L .30273 .37204 L F

.26819 .326 m .28082 .33019 L .27512 .33523 L .875 .627 .561 r

F

.26819 .326 m .27392 .32098 L .28082 .33019 L F

.28439 .35804 m .29584 .36285 L .29131 .36726 L .904 .611 .48 r

F

.28439 .35804 m .28894 .35366 L .29584 .36285 L F

.26126 .31675 m .27392 .32098 L .26819 .326 L .875 .627 .561 r

F

.26126 .31675 m .26701 .31176 L .27392 .32098 L F

.31891 .40402 m .34974 .38529 L .35588 .37973 L 0 0 0 r

F

.31575 .40776 m .34974 .38529 L .31891 .40402 L F

.27746 .34881 m .28894 .35366 L .28439 .35804 L .904 .611 .48 r

F

.27746 .34881 m .28204 .34445 L .28894 .35366 L F

.25431 .3075 m .26701 .31176 L .26126 .31675 L .875 .627 .561 r

F

.25431 .3075 m .26008 .30252 L .26701 .31176 L F

.27052 .33957 m .28204 .34445 L .27746 .34881 L .904 .611 .48 r

F

.27052 .33957 m .27512 .33523 L .28204 .34445 L F

.24736 .29823 m .26008 .30252 L .25431 .3075 L .875 .627 .561 r

F

.24736 .29823 m .25315 .29327 L .26008 .30252 L F

.26357 .33031 m .27512 .33523 L .27052 .33957 L .904 .611 .48 r

F

.26357 .33031 m .26819 .326 L .27512 .33523 L F

.2404 .28895 m .25315 .29327 L .24736 .29823 L .875 .627 .561 r

F

.25661 .32104 m .26819 .326 L .26357 .33031 L .904 .611 .48 r

F

.25661 .32104 m .26126 .31675 L .26819 .326 L F

.24964 .31176 m .26126 .31675 L .25661 .32104 L F

.24964 .31176 m .25431 .3075 L .26126 .31675 L F

.31575 .40776 m .34358 .39087 L .34974 .38529 L 0 0 0 r

F

.31425 .41051 m .34358 .39087 L .31575 .40776 L F

.24266 .30247 m .25431 .3075 L .24964 .31176 L .904 .611 .48 r

F

.24266 .30247 m .24736 .29823 L .25431 .3075 L F

.23568 .29316 m .24736 .29823 L .24266 .30247 L F

.23568 .29316 m .2404 .28895 L .24736 .29823 L F

.31425 .41051 m .33739 .39648 L .34358 .39087 L 0 0 0 r

F

.31533 .4117 m .33739 .39648 L .31425 .41051 L F

.31533 .4117 m .33117 .40211 L .33739 .39648 L F

.3233 .40875 m .33117 .40211 L .31533 .4117 L F

.3233 .40875 m .32492 .40777 L .33117 .40211 L F

.24001 .29465 m .398 .34157 L .32492 .40777 L .862 .631 .587 r

F

.38961 .33343 m .38443 .32328 L .38282 .32428 L .536 .562 .829 r

F

.38961 .33343 m .39122 .33243 L .38443 .32328 L F

.34231 .31099 m .36241 .29677 L .36922 .30596 L .666 .607 .779 r

F

.33549 .30183 m .36241 .29677 L .34231 .31099 L F

.32219 .31173 m .33549 .30183 L .34231 .31099 L .723 .621 .744 r

F

.31535 .30257 m .33549 .30183 L .32219 .31173 L F

.30459 .31084 m .31535 .30257 L .32219 .31173 L .758 .628 .716 r

F

.38282 .32428 m .37763 .31412 L .37602 .31513 L .536 .562 .829 r

F

.38282 .32428 m .38443 .32328 L .37763 .31412 L F

.33549 .30183 m .35558 .28758 L .36241 .29677 L .666 .607 .779 r

F

.32866 .29266 m .35558 .28758 L .33549 .30183 L F

.31535 .30257 m .32866 .29266 L .33549 .30183 L .723 .621 .744 r

F

.30851 .29339 m .32866 .29266 L .31535 .30257 L F

.29774 .30166 m .31535 .30257 L .30459 .31084 L .758 .628 .716 r

F

.29774 .30166 m .30851 .29339 L .31535 .30257 L F

.37602 .31513 m .37083 .30494 L .36922 .30596 L .536 .562 .829 r

F

.37602 .31513 m .37763 .31412 L .37083 .30494 L F

.32866 .29266 m .34875 .27837 L .35558 .28758 L .666 .607 .779 r

F

.32183 .28347 m .34875 .27837 L .32866 .29266 L F

.30851 .29339 m .32183 .28347 L .32866 .29266 L .723 .621 .744 r

F

.30166 .2842 m .32183 .28347 L .30851 .29339 L F

.29088 .29247 m .30851 .29339 L .29774 .30166 L .758 .628 .716 r

F

.29088 .29247 m .30166 .2842 L .30851 .29339 L F

.28859 .30888 m .29774 .30166 L .30459 .31084 L .789 .632 .687 r

F

.36922 .30596 m .36401 .29576 L .36241 .29677 L .536 .562 .829 r

F

.36922 .30596 m .37083 .30494 L .36401 .29576 L F

.32183 .28347 m .34191 .26916 L .34875 .27837 L .666 .607 .779 r

F

.31498 .27428 m .34191 .26916 L .32183 .28347 L F

.30166 .2842 m .31498 .27428 L .32183 .28347 L .723 .621 .744 r

F

.2948 .275 m .31498 .27428 L .30166 .2842 L F

.284 .28327 m .30166 .2842 L .29088 .29247 L .758 .628 .716 r

F

.284 .28327 m .2948 .275 L .30166 .2842 L F

.28171 .29968 m .29774 .30166 L .28859 .30888 L .789 .632 .687 r

F

.28171 .29968 m .29088 .29247 L .29774 .30166 L F

.36241 .29677 m .35719 .28656 L .35558 .28758 L .536 .562 .829 r

F

.36241 .29677 m .36401 .29576 L .35719 .28656 L F

.31498 .27428 m .33507 .25993 L .34191 .26916 L .666 .607 .779 r

F

.30813 .26507 m .33507 .25993 L .31498 .27428 L F

.2948 .275 m .30813 .26507 L .31498 .27428 L .723 .621 .744 r

F

.28793 .26579 m .30813 .26507 L .2948 .275 L F

.27712 .27406 m .2948 .275 L .284 .28327 L .758 .628 .716 r

F

.27712 .27406 m .28793 .26579 L .2948 .275 L F

.27483 .29048 m .29088 .29247 L .28171 .29968 L .789 .632 .687 r

F

.27483 .29048 m .284 .28327 L .29088 .29247 L F

.35558 .28758 m .35035 .27734 L .34875 .27837 L .536 .562 .829 r

F

.35558 .28758 m .35719 .28656 L .35035 .27734 L F

.30813 .26507 m .32821 .25068 L .33507 .25993 L .666 .607 .779 r

F

.30127 .25585 m .32821 .25068 L .30813 .26507 L F

.28793 .26579 m .30127 .25585 L .30813 .26507 L .723 .621 .744 r

F

.28105 .25657 m .30127 .25585 L .28793 .26579 L F

.27023 .26483 m .28793 .26579 L .27712 .27406 L .758 .628 .716 r

F

.27023 .26483 m .28105 .25657 L .28793 .26579 L F

.26793 .28125 m .284 .28327 L .27483 .29048 L .789 .632 .687 r

F

.26793 .28125 m .27712 .27406 L .284 .28327 L F

.34875 .27837 m .34351 .26812 L .34191 .26916 L .536 .562 .829 r

F

.34875 .27837 m .35035 .27734 L .34351 .26812 L F

.30127 .25585 m .32134 .24143 L .32821 .25068 L .666 .607 .779 r

F

.2944 .24661 m .32134 .24143 L .30127 .25585 L F

.28105 .25657 m .2944 .24661 L .30127 .25585 L .723 .621 .744 r

F

.2669 .29686 m .27483 .29048 L .28171 .29968 L .817 .634 .654 r

F

.26103 .27202 m .27712 .27406 L .26793 .28125 L .789 .632 .687 r

F

.26103 .27202 m .27023 .26483 L .27712 .27406 L F

.34191 .26916 m .33666 .25888 L .33507 .25993 L .536 .562 .829 r

F

.34191 .26916 m .34351 .26812 L .33666 .25888 L F

.2944 .24661 m .31447 .23216 L .32134 .24143 L .666 .607 .779 r

F

.25999 .28762 m .27483 .29048 L .2669 .29686 L .817 .634 .654 r

F

.25999 .28762 m .26793 .28125 L .27483 .29048 L F

.33507 .25993 m .3298 .24964 L .32821 .25068 L .536 .562 .829 r

F

.33507 .25993 m .33666 .25888 L .3298 .24964 L F

.25307 .27838 m .26793 .28125 L .25999 .28762 L .817 .634 .654 r

F

.25307 .27838 m .26103 .27202 L .26793 .28125 L F

.32821 .25068 m .32293 .24038 L .32134 .24143 L .536 .562 .829 r

F

.32821 .25068 m .3298 .24964 L .32293 .24038 L F

.32134 .24143 m .31605 .2311 L .31447 .23216 L F

.32134 .24143 m .32293 .24038 L .31605 .2311 L F

.25315 .29327 m .25999 .28762 L .2669 .29686 L .845 .632 .615 r

F

.24621 .28401 m .25999 .28762 L .25315 .29327 L F

.24621 .28401 m .25307 .27838 L .25999 .28762 L F

.2404 .28895 m .24621 .28401 L .25315 .29327 L .875 .627 .561 r

F

.24001 .29465 m .31605 .2311 L .398 .34157 L .862 .631 .587 r

F

.64161 .9832 m .65975 .97746 L .64233 .98376 L 0 0 0 r

F

.64161 .9832 m .66708 .97398 L .65975 .97746 L F

.64601 .99375 m .64233 .98376 L .64161 .9832 L 0 0 .332 r

F

0 g

.64161 .9832 m

.64374 .98162 L

s

.64601 .99375 m .64675 .99437 L .64233 .98376 L 0 0 .332 r

F

.6504 1.00431 m .64675 .99437 L .64601 .99375 L F

.6504 1.00431 m .65116 1.00498 L .64675 .99437 L F

.6548 1.01487 m .65116 1.00498 L .6504 1.00431 L F

.6548 1.01487 m .65558 1.01559 L .65116 1.00498 L F

.6592 1.02544 m .65558 1.01559 L .6548 1.01487 L F

.6592 1.02544 m .66 1.02621 L .65558 1.01559 L F

.6636 1.036 m .66 1.02621 L .6592 1.02544 L F

.6636 1.036 m .66443 1.03683 L .66 1.02621 L F

.66801 1.04658 m .66443 1.03683 L .6636 1.036 L F

.66801 1.04658 m .66885 1.04745 L .66443 1.03683 L F

.67241 1.05715 m .66885 1.04745 L .66801 1.04658 L F

.67241 1.05715 m .67328 1.05808 L .66885 1.04745 L F

.67682 1.06773 m .67328 1.05808 L .67241 1.05715 L F

.67682 1.06773 m .67771 1.06872 L .67328 1.05808 L F

.68122 1.07832 m .67771 1.06872 L .67682 1.06773 L F

.68122 1.07832 m .68214 1.07935 L .67771 1.06872 L F

.68563 1.0889 m .68214 1.07935 L .68122 1.07832 L F

.69004 1.0995 m .68657 1.08999 L .68563 1.0889 L F

.68563 1.0889 m .68657 1.08999 L .68214 1.07935 L F

.69004 1.0995 m .691 1.10064 L .68657 1.08999 L F

.69446 1.11009 m .691 1.10064 L .69004 1.0995 L F

.69446 1.11009 m .69544 1.11129 L .691 1.10064 L F

0 g

.69479 1.10973 m

.69637 1.10799 L

s

.28105 .25657 m .29744 .24665 L .27023 .26483 L 0 0 0 r

F

.28105 .25657 m .30367 .24145 L .29744 .24665 L F

.2944 .24661 m .30367 .24145 L .28105 .25657 L F

.2944 .24661 m .30988 .23626 L .30367 .24145 L F

.31447 .23216 m .30988 .23626 L .2944 .24661 L F

0 g

.28105 .25657 m

.2944 .24661 L

s

.27023 .26483 m .29118 .25188 L .26103 .27202 L 0 0 0 r

F

.27023 .26483 m .29744 .24665 L .29118 .25188 L F

0 g

.27023 .26483 m

.28105 .25657 L

s

.26103 .27202 m .28489 .25714 L .25307 .27838 L 0 0 0 r

F

.26103 .27202 m .29118 .25188 L .28489 .25714 L F

0 g

.26103 .27202 m

.27023 .26483 L

s

.64233 .98376 m .6524 .98095 L .65061 .9816 L 0 0 0 r

F

.64233 .98376 m .65975 .97746 L .6524 .98095 L F

.64675 .99437 m .65061 .9816 L .64233 .98376 L .095 .218 .702 r

F

0 g

.64161 .9832 m

.64233 .98376 L

s

.65116 1.00498 m .65506 .99228 L .64675 .99437 L .095 .218 .702 r

F

.64675 .99437 m .65506 .99228 L .65061 .9816 L F

.65116 1.00498 m .65952 1.00297 L .65506 .99228 L F

.65558 1.01559 m .65952 1.00297 L .65116 1.00498 L F

.65558 1.01559 m .66397 1.01366 L .65952 1.00297 L F

.66 1.02621 m .66397 1.01366 L .65558 1.01559 L F

.66 1.02621 m .66843 1.02436 L .66397 1.01366 L F

.66443 1.03683 m .66843 1.02436 L .66 1.02621 L F

.31447 .23216 m .31605 .2311 L .30988 .23626 L 0 0 0 r

F

0 g

.2944 .24661 m

.31447 .23216 L

s

.31605 .2311 m

.398 .34157 L

s

.31447 .23216 m

.31447 .23216 L

s

.66443 1.03683 m .67288 1.03505 L .66843 1.02436 L .095 .218 .702 r

F

.66885 1.04745 m .67288 1.03505 L .66443 1.03683 L F

.66885 1.04745 m .67734 1.04576 L .67288 1.03505 L F

.67328 1.05808 m .67734 1.04576 L .66885 1.04745 L F

.67328 1.05808 m .6818 1.05647 L .67734 1.04576 L F

.67771 1.06872 m .6818 1.05647 L .67328 1.05808 L F

.30884 .39856 m .31891 .40402 L .31575 .40776 L .924 .57 .342 r

F

.30884 .39856 m .31202 .39485 L .31891 .40402 L F

0 g

.31891 .40402 m

.32073 .40218 L

s

.67771 1.06872 m .68627 1.06718 L .6818 1.05647 L .095 .218 .702 r

F

.68214 1.07935 m .68627 1.06718 L .67771 1.06872 L F

.68214 1.07935 m .69073 1.07789 L .68627 1.06718 L F

.68657 1.08999 m .69073 1.07789 L .68214 1.07935 L F

.25307 .27838 m .27857 .26242 L .24621 .28401 L 0 0 0 r

F

.25307 .27838 m .28489 .25714 L .27857 .26242 L F

0 g

.25307 .27838 m

.26103 .27202 L

s

.68657 1.08999 m .6952 1.08861 L .69073 1.07789 L .095 .218 .702 r

F

.691 1.10064 m .6952 1.08861 L .68657 1.08999 L F

.691 1.10064 m .69966 1.09933 L .6952 1.08861 L F

.69544 1.11129 m .69966 1.09933 L .691 1.10064 L F

.30192 .38935 m .31202 .39485 L .30884 .39856 L .924 .57 .342 r

F

.30192 .38935 m .30513 .38567 L .31202 .39485 L F

.69544 1.11129 m .70413 1.11006 L .69966 1.09933 L .095 .218 .702 r

F

0 g

.69446 1.11009 m

.69544 1.11129 L

s

.29499 .38012 m .30513 .38567 L .30192 .38935 L .924 .57 .342 r

F

.29499 .38012 m .29822 .37647 L .30513 .38567 L F

.28805 .37088 m .29822 .37647 L .29499 .38012 L F

.28805 .37088 m .29131 .36726 L .29822 .37647 L F

.24621 .28401 m .27222 .26773 L .2404 .28895 L 0 0 0 r

F

.24621 .28401 m .27857 .26242 L .27222 .26773 L F

0 g

.24621 .28401 m

.25307 .27838 L

s

.2811 .36163 m .29131 .36726 L .28805 .37088 L .924 .57 .342 r

F

.2811 .36163 m .28439 .35804 L .29131 .36726 L F

.27415 .35237 m .28439 .35804 L .2811 .36163 L F

.27415 .35237 m .27746 .34881 L .28439 .35804 L F

.30731 .40127 m .31575 .40776 L .31425 .41051 L .879 .447 .068 r

F

.30731 .40127 m .30884 .39856 L .31575 .40776 L F

0 g

.31575 .40776 m

.31891 .40402 L

s

.26718 .3431 m .27746 .34881 L .27415 .35237 L .924 .57 .342 r

F

.26718 .3431 m .27052 .33957 L .27746 .34881 L F

.30036 .39202 m .30884 .39856 L .30731 .40127 L .879 .447 .068 r

F

.30036 .39202 m .30192 .38935 L .30884 .39856 L F

.2602 .33381 m .27052 .33957 L .26718 .3431 L .924 .57 .342 r

F

.2602 .33381 m .26357 .33031 L .27052 .33957 L F

.2934 .38276 m .30192 .38935 L .30036 .39202 L .879 .447 .068 r

F

.2934 .38276 m .29499 .38012 L .30192 .38935 L F

.2404 .28895 m .26584 .27306 L .23568 .29316 L 0 0 0 r

F

.2404 .28895 m .27222 .26773 L .26584 .27306 L F

0 g

.2404 .28895 m

.24621 .28401 L

s

.25322 .32452 m .26357 .33031 L .2602 .33381 L .924 .57 .342 r

F

.25322 .32452 m .25661 .32104 L .26357 .33031 L F

.28643 .37349 m .29499 .38012 L .2934 .38276 L .879 .447 .068 r

F

.28643 .37349 m .28805 .37088 L .29499 .38012 L F

.24622 .3152 m .25661 .32104 L .25322 .32452 L .924 .57 .342 r

F

.24622 .3152 m .24964 .31176 L .25661 .32104 L F

.65061 .9816 m .65685 .99164 L .65506 .99228 L .483 .451 .745 r

F

.65061 .9816 m .6524 .98095 L .65685 .99164 L F

0 g

.64233 .98376 m

.65061 .9816 L

s

.65061 .9816 m

.65061 .9816 L

s

.6524 .98095 m

.73839 .94013 L

s

.27946 .36421 m .28805 .37088 L .28643 .37349 L .879 .447 .068 r

F

.27946 .36421 m .2811 .36163 L .28805 .37088 L F

.65506 .99228 m .66131 1.00234 L .65952 1.00297 L .483 .451 .745 r

F

.65506 .99228 m .65685 .99164 L .66131 1.00234 L F

0 g

.65061 .9816 m

.65506 .99228 L

s

.65952 1.00297 m .66576 1.01303 L .66397 1.01366 L .483 .451 .745 r

F

.65952 1.00297 m .66131 1.00234 L .66576 1.01303 L F

0 g

.65506 .99228 m

.65952 1.00297 L

s

.66397 1.01366 m .67022 1.02373 L .66843 1.02436 L .483 .451 .745 r

F

.66397 1.01366 m .66576 1.01303 L .67022 1.02373 L F

0 g

.65952 1.00297 m

.66397 1.01366 L

s

.23922 .30588 m .24964 .31176 L .24622 .3152 L .924 .57 .342 r

F

.23922 .30588 m .24266 .30247 L .24964 .31176 L F

.66843 1.02436 m .67468 1.03444 L .67288 1.03505 L .483 .451 .745 r

F

.66843 1.02436 m .67022 1.02373 L .67468 1.03444 L F

0 g

.66397 1.01366 m

.66843 1.02436 L

s

.27247 .35491 m .2811 .36163 L .27946 .36421 L .879 .447 .068 r

F

.27247 .35491 m .27415 .35237 L .2811 .36163 L F

.67288 1.03505 m .67914 1.04515 L .67734 1.04576 L .483 .451 .745 r

F

.67288 1.03505 m .67468 1.03444 L .67914 1.04515 L F

0 g

.66843 1.02436 m

.67288 1.03505 L

s

.67734 1.04576 m .68361 1.05586 L .6818 1.05647 L .483 .451 .745 r

F

.67734 1.04576 m .67914 1.04515 L .68361 1.05586 L F

0 g

.67288 1.03505 m

.67734 1.04576 L

s

.23221 .29655 m .24266 .30247 L .23922 .30588 L .924 .57 .342 r

F

.23221 .29655 m .23568 .29316 L .24266 .30247 L F

.6818 1.05647 m .68807 1.06658 L .68627 1.06718 L .483 .451 .745 r

F

.6818 1.05647 m .68361 1.05586 L .68807 1.06658 L F

0 g

.67734 1.04576 m

.6818 1.05647 L

s

.26547 .3456 m .27415 .35237 L .27247 .35491 L .879 .447 .068 r

F

.26547 .3456 m .26718 .3431 L .27415 .35237 L F

.30836 .40242 m .31425 .41051 L .31533 .4117 L 0 0 .446 r

F

0 g

.31433 .41037 m

.31575 .40776 L

s

.30836 .40242 m .30731 .40127 L .31425 .41051 L 0 0 .446 r

F

.68627 1.06718 m .69254 1.0773 L .69073 1.07789 L .483 .451 .745 r

F

.68627 1.06718 m .68807 1.06658 L .69254 1.0773 L F

0 g

.6818 1.05647 m

.68627 1.06718 L

s

.69073 1.07789 m .69701 1.08803 L .6952 1.08861 L .483 .451 .745 r

F

.69073 1.07789 m .69254 1.0773 L .69701 1.08803 L F

0 g

.68627 1.06718 m

.69073 1.07789 L

s

.6952 1.08861 m .70148 1.09876 L .69966 1.09933 L .483 .451 .745 r

F

.6952 1.08861 m .69701 1.08803 L .70148 1.09876 L F

0 g

.64073 1.09157 m

.69746 1.10529 L

s

.69073 1.07789 m

.6952 1.08861 L

s

.23568 .29316 m .25943 .27842 L .23221 .29655 L 0 0 0 r

F

.23568 .29316 m .26584 .27306 L .25943 .27842 L F

0 g

.23568 .29316 m

.2404 .28895 L

s

.69966 1.09933 m .70595 1.10949 L .70413 1.11006 L .483 .451 .745 r

F

0 g

.69544 1.11129 m

.70413 1.11006 L

s

.69966 1.09933 m .70148 1.09876 L .70595 1.10949 L .483 .451 .745 r

F

0 g

.70595 1.10949 m

.7906 1.06491 L

s

.69746 1.10529 m

.7247 1.11187 L

s

.6524 .98095 m

.70595 1.10949 L

s

.6952 1.08861 m

.69966 1.09933 L

s

.69966 1.09933 m

.70413 1.11006 L

s

.25847 .33628 m .26718 .3431 L .26547 .3456 L .879 .447 .068 r

F

.25847 .33628 m .2602 .33381 L .26718 .3431 L F

.30138 .39313 m .30731 .40127 L .30836 .40242 L 0 0 .446 r

F

.30138 .39313 m .30036 .39202 L .30731 .40127 L F

0 g

.70413 1.11006 m

.70413 1.11006 L

s

.25145 .32694 m .2602 .33381 L .25847 .33628 L .879 .447 .068 r

F

.25145 .32694 m .25322 .32452 L .2602 .33381 L F

.29438 .38382 m .30036 .39202 L .30138 .39313 L 0 0 .446 r

F

.29438 .38382 m .2934 .38276 L .30036 .39202 L F

.24443 .3176 m .25322 .32452 L .25145 .32694 L .879 .447 .068 r

F

.24443 .3176 m .24622 .3152 L .25322 .32452 L F

.28738 .37451 m .2934 .38276 L .29438 .38382 L 0 0 .446 r

F

.28738 .37451 m .28643 .37349 L .2934 .38276 L F

.2374 .30824 m .24622 .3152 L .24443 .3176 L .879 .447 .068 r

F

.2374 .30824 m .23922 .30588 L .24622 .3152 L F

.28037 .36518 m .28643 .37349 L .28738 .37451 L 0 0 .446 r

F

.28037 .36518 m .27946 .36421 L .28643 .37349 L F

.23035 .29887 m .23922 .30588 L .2374 .30824 L .879 .447 .068 r

F

.23035 .29887 m .23221 .29655 L .23922 .30588 L F

.27335 .35583 m .27946 .36421 L .28037 .36518 L 0 0 .446 r

F

.27335 .35583 m .27247 .35491 L .27946 .36421 L F

.23221 .29655 m .25299 .2838 L .23035 .29887 L 0 0 0 r

F

.23221 .29655 m .25943 .27842 L .25299 .2838 L F

0 g

.23221 .29655 m

.23568 .29316 L

s

.26632 .34648 m .27247 .35491 L .27335 .35583 L 0 0 .446 r

F

.26632 .34648 m .26547 .3456 L .27247 .35491 L F

.25928 .33711 m .26547 .3456 L .26632 .34648 L F

.25928 .33711 m .25847 .33628 L .26547 .3456 L F

.31628 .3994 m .31533 .4117 L .3233 .40875 L .139 .373 .828 r

F

.31628 .3994 m .30836 .40242 L .31533 .4117 L F

0 g

.31425 .41051 m

.31533 .4117 L

s

.25223 .32773 m .25847 .33628 L .25928 .33711 L 0 0 .446 r

F

.25223 .32773 m .25145 .32694 L .25847 .33628 L F

.30925 .39004 m .30836 .40242 L .31628 .3994 L .139 .373 .828 r

F

.30925 .39004 m .30138 .39313 L .30836 .40242 L F

.24517 .31834 m .25145 .32694 L .25223 .32773 L 0 0 .446 r

F

.24517 .31834 m .24443 .3176 L .25145 .32694 L F

.30221 .38066 m .30138 .39313 L .30925 .39004 L .139 .373 .828 r

F

.30221 .38066 m .29438 .38382 L .30138 .39313 L F

.2381 .30893 m .24443 .3176 L .24517 .31834 L 0 0 .446 r

F

.2381 .30893 m .2374 .30824 L .24443 .3176 L F

.29516 .37127 m .29438 .38382 L .30221 .38066 L .139 .373 .828 r

F

.29516 .37127 m .28738 .37451 L .29438 .38382 L F

.23103 .29951 m .2374 .30824 L .2381 .30893 L 0 0 .446 r

F

.23103 .29951 m .23035 .29887 L .2374 .30824 L F

.2881 .36187 m .28738 .37451 L .29516 .37127 L .139 .373 .828 r

F

.2881 .36187 m .28037 .36518 L .28738 .37451 L F

.23035 .29887 m .24652 .28921 L .23103 .29951 L 0 0 0 r

F

.23035 .29887 m .25299 .2838 L .24652 .28921 L F

0 g

.23035 .29887 m

.23221 .29655 L

s

.28104 .35246 m .28037 .36518 L .2881 .36187 L .139 .373 .828 r

F

.28104 .35246 m .27335 .35583 L .28037 .36518 L F

.27396 .34303 m .27335 .35583 L .28104 .35246 L F

.27396 .34303 m .26632 .34648 L .27335 .35583 L F

.26687 .33359 m .26632 .34648 L .27396 .34303 L F

.26687 .33359 m .25928 .33711 L .26632 .34648 L F

.25978 .32414 m .25928 .33711 L .26687 .33359 L F

.25978 .32414 m .25223 .32773 L .25928 .33711 L F

.25267 .31467 m .25223 .32773 L .25978 .32414 L F

.25267 .31467 m .24517 .31834 L .25223 .32773 L F

.24555 .30519 m .24517 .31834 L .25267 .31467 L F

.24555 .30519 m .2381 .30893 L .24517 .31834 L F

.23843 .2957 m .2381 .30893 L .24555 .30519 L F

.23843 .2957 m .23103 .29951 L .2381 .30893 L F

.31628 .3994 m .32492 .40777 L .3233 .40875 L .525 .56 .833 r

F

0 g

.31533 .4117 m

.3233 .40875 L

s

.31628 .3994 m .3179 .39841 L .32492 .40777 L .525 .56 .833 r

F

0 g

.32492 .40777 m

.398 .34157 L

s

.23103 .29951 m .24001 .29465 L .23843 .2957 L 0 0 0 r

F

.23103 .29951 m .24652 .28921 L .24001 .29465 L F

0 g

.23035 .29887 m

.23103 .29951 L

s

.30925 .39004 m .3179 .39841 L .31628 .3994 L .525 .56 .833 r

F

0 g

.31628 .3994 m

.3233 .40875 L

s

.30925 .39004 m .31087 .38904 L .3179 .39841 L .525 .56 .833 r

F

.30221 .38066 m .31087 .38904 L .30925 .39004 L F

0 g

.30925 .39004 m

.31628 .3994 L

s

.30221 .38066 m .30382 .37966 L .31087 .38904 L .525 .56 .833 r

F

.29516 .37127 m .30382 .37966 L .30221 .38066 L F

0 g

.30221 .38066 m

.30925 .39004 L

s

.29516 .37127 m .29677 .37027 L .30382 .37966 L .525 .56 .833 r

F

.2881 .36187 m .29677 .37027 L .29516 .37127 L F

0 g

.29516 .37127 m

.30221 .38066 L

s

.2881 .36187 m .28971 .36086 L .29677 .37027 L .525 .56 .833 r

F

.28104 .35246 m .28971 .36086 L .2881 .36187 L F

0 g

.2881 .36187 m

.29516 .37127 L

s

.28104 .35246 m .28264 .35144 L .28971 .36086 L .525 .56 .833 r

F

.27396 .34303 m .28264 .35144 L .28104 .35246 L F

0 g

.28104 .35246 m

.2881 .36187 L

s

.27396 .34303 m .27556 .342 L .28264 .35144 L .525 .56 .833 r

F

.26687 .33359 m .27556 .342 L .27396 .34303 L F

0 g

.27396 .34303 m

.28104 .35246 L

s

.26687 .33359 m .26847 .33256 L .27556 .342 L .525 .56 .833 r

F

.25978 .32414 m .26847 .33256 L .26687 .33359 L F

0 g

.26687 .33359 m

.27396 .34303 L

s

.25978 .32414 m .26137 .3231 L .26847 .33256 L .525 .56 .833 r

F

.25267 .31467 m .26137 .3231 L .25978 .32414 L F

0 g

.25978 .32414 m

.26687 .33359 L

s

.25267 .31467 m .25426 .31363 L .26137 .3231 L .525 .56 .833 r

F

.24555 .30519 m .25426 .31363 L .25267 .31467 L F

0 g

.25267 .31467 m

.25978 .32414 L

s

.24555 .30519 m .24714 .30414 L .25426 .31363 L .525 .56 .833 r

F

.23843 .2957 m .24714 .30414 L .24555 .30519 L F

0 g

.24555 .30519 m

.25267 .31467 L

s

.23843 .2957 m .24001 .29465 L .24714 .30414 L .525 .56 .833 r

F

0 g

.23843 .2957 m

.24555 .30519 L

s

.23103 .29951 m

.23843 .2957 L

s

.24001 .29465 m

.32492 .40777 L

s

.24001 .29465 m

.31605 .2311 L

s

.23843 .2957 m

.23843 .2957 L

s

.20039 .98512 m

.23953 .03727 L

s

.20039 .98512 m

.02837 1.05739 L

s

.25 Mabswid

.06262 .12546 m

.22431 0 L

s

.06625 .12265 m

.07389 .1258 L

s

[(-10)] .05098 .11635 1 .41274 Mshowa

.1031 .09406 m

.11071 .09727 L

s

[(-5)] .08788 .08764 1 .42183 Mshowa

.14101 .06464 m

.14859 .06791 L

s

[(0)] .12584 .0581 1 .43133 Mshowa

.18003 .03436 m

.18759 .03769 L

s

[(5)] .16492 .02769 1 .44127 Mshowa

.22022 .00317 m

.22775 .00657 L

s

[(10)] .20517 -0.00363 1 .45168 Mshowa

.125 Mabswid

.07354 .11699 m

.07812 .11889 L

s

.08087 .11131 m

.08544 .11321 L

s

.08823 .10559 m

.09281 .1075 L

s

.09564 .09984 m

.10021 .10176 L

s

.11059 .08824 m

.11516 .09017 L

s

.11813 .08239 m

.12269 .08433 L

s

.12571 .07651 m

.13027 .07845 L

s

.13334 .07059 m

.13789 .07254 L

s

.14872 .05865 m

.15327 .06062 L

s

.15648 .05263 m

.16103 .05461 L

s

.16429 .04657 m

.16883 .04856 L

s

.17214 .04048 m

.17667 .04248 L

s

.18798 .02819 m

.19251 .0302 L

s

.19597 .02199 m

.20049 .02401 L

s

.204 .01575 m

.20853 .01778 L

s

.21209 .00948 m

.21661 .01151 L

s

.25 Mabswid

0 1.07982 m

.80315 1.25061 L

s

.20942 1.12436 m

.20975 1.11611 L

s

[(-20)] .20877 1.14086 .03948 -1 Mshowa

.43726 1.17281 m

.43736 1.16455 L

s

[(0)] .43707 1.18932 .01136 -1 Mshowa

.64408 1.21679 m

.64396 1.20853 L

s

[(20)] .64431 1.2333 -0.01387 -1 Mshowa

.125 Mabswid

.26853 1.13693 m

.26869 1.13197 L

s

.32617 1.14918 m

.32629 1.14423 L

s

.38239 1.16114 m

.38248 1.15619 L

s

.49082 1.1842 m

.49084 1.17924 L

s

.54311 1.19532 m

.5431 1.19036 L

s

.59418 1.20618 m

.59415 1.20122 L

s

.1488 1.11147 m

.14903 1.10652 L

s

.0866 1.09824 m

.08687 1.09329 L

s

.02275 1.08466 m

.02306 1.07971 L

s

.69284 1.22716 m

.69274 1.2222 L

s

.74049 1.23729 m

.74037 1.23234 L

s

.78709 1.2472 m

.78693 1.24225 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.599143 0.477324 1.11901 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.0758753 1.23041 0 1.23041 [

[.5 1.1588 -43.2 0 ]

[.5 1.1588 43.2 7.2 ]

[.22738 .13454 -4.06786 -7.2 ]

[.22738 .13454 .73214 0 ]

[.4631 .06495 -3.76302 -7.2 ]

[.4631 .06495 1.03698 0 ]

[.71452 -0.00913 -6.91634 -7.2 ]

[.71452 -0.00913 2.68366 0 ]

[.79004 .08295 0 -4.61184 ]

[.79004 .08295 9.6 2.58816 ]

[.86153 .24831 0 -4.52801 ]

[.86153 .24831 4.8 2.67199 ]

[.92309 .39073 0 -4.45702 ]

[.92309 .39073 4.8 2.74298 ]

[.06116 .28327 -9.6 -2.58588 ]

[.06116 .28327 0 4.61412 ]

[.03304 .48783 -4.8 -2.68508 ]

[.03304 .48783 0 4.51492 ]

[.0013 .71872 -4.8 -2.79799 ]

[.0013 .71872 0 4.40201 ]

[ 0 0 0 0 ]

[ 1 1.1463 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Rotate[object, 30])] .5 1.1588 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.08806 .19064 m

.73754 0 L

s

.23615 .14717 m

.24054 .15349 L

s

[(0)] .22738 .13454 .69494 1 Mshowa

.47069 .07833 m

.47449 .08501 L

s

[(5)] .4631 .06495 .56792 1 Mshowa

.72072 .00494 m

.72382 .01197 L

s

[(10)] .71452 -0.00913 .4409 1 Mshowa

.125 Mabswid

.28189 .13375 m

.28446 .13758 L

s

.3282 .12015 m

.3307 .12403 L

s

.3751 .10639 m

.37753 .11031 L

s

.42259 .09245 m

.42495 .09641 L

s

.51941 .06403 m

.52161 .06808 L

s

.56876 .04954 m

.57088 .05364 L

s

.61875 .03487 m

.62079 .03901 L

s

.6694 .02 m

.67135 .02418 L

s

.19098 .16043 m

.19367 .16418 L

s

.14635 .17353 m

.14911 .17723 L

s

.10227 .18647 m

.10509 .19012 L

s

.25 Mabswid

.73754 0 m

.93418 .4545 L

s

.77523 .08711 m

.76783 .08919 L

s

[(-5)] .79004 .08295 -1 .28107 Mshowa

.84663 .25215 m

.83919 .25407 L

s

[(0)] .86153 .24831 -1 .25778 Mshowa

.90813 .39429 m

.90065 .39607 L

s

[(5)] .92309 .39073 -1 .23806 Mshowa

.125 Mabswid

.79042 .12221 m

.78597 .12344 L

s

.80513 .15622 m

.80068 .15742 L

s

.81939 .18917 m

.81493 .19036 L

s

.83322 .22114 m

.82876 .22231 L

s

.85966 .28224 m

.85518 .28338 L

s

.8723 .31147 m

.86783 .31259 L

s

.88459 .33987 m

.88011 .34097 L

s

.89652 .36746 m

.89204 .36854 L

s

.75955 .05086 m

.75511 .05213 L

s

.74334 .01341 m

.73891 .0147 L

s

.91942 .42038 m

.91493 .42144 L

s

.93041 .44577 m

.92591 .44681 L

s

.25 Mabswid

.08806 .19064 m

0 .83471 L

s

.07597 .2791 m

.08337 .27701 L

s

[(-5)] .06116 .28327 1 -0.2817 Mshowa

.04795 .48404 m

.0554 .48215 L

s

[(0)] .03304 .48783 1 -0.25414 Mshowa

.01632 .71537 m

.02382 .7137 L

s

[(5)] .0013 .71872 1 -0.22278 Mshowa

.125 Mabswid

.07062 .3182 m

.07507 .31697 L

s

.06515 .35821 m

.06961 .357 L

s

.05955 .39916 m

.06401 .39798 L

s

.05382 .4411 m

.05828 .43994 L

s

.04193 .52804 m

.04641 .52693 L

s

.03576 .57313 m

.04025 .57205 L

s

.02944 .61936 m

.03394 .6183 L

s

.02296 .66675 m

.02746 .66572 L

s

.08119 .24088 m

.08563 .23961 L

s

.0863 .20352 m

.09073 .20223 L

s

.0095 .76526 m

.01401 .76428 L

s

.00249 .81646 m

.00701 .81552 L

s

0 0 m

1 0 L

1 1.1463 L

0 1.1463 L

closepath

clip

newpath

.5 Mabswid

.79123 .49021 m

.5109 .55452 L

s

.79123 .49021 m

.83047 1.051 L

s

.63382 .54329 m .62933 .52108 L .54947 .53947 L .663 .742 .909 r

F

.63382 .54329 m .64195 .54144 L .62933 .52108 L F

.63461 .57372 m .64195 .54144 L .63382 .54329 L .605 .395 .57 r

F

.54947 .53947 m .63382 .54329 L .63461 .57372 L .713 .48 .571 r

F

0 g

.63382 .54329 m

.63382 .54329 L

s

.63461 .57372 m .64281 .57189 L .64195 .54144 L .605 .395 .57 r

F

.54947 .53947 m .61641 .50025 L .49882 .52769 L .663 .742 .909 r

F

.54947 .53947 m .62933 .52108 L .61641 .50025 L F

.54947 .53947 m .63461 .57372 L .54955 .56994 L .713 .48 .571 r

F

.49882 .52769 m .54947 .53947 L .54955 .56994 L .779 .535 .566 r

F

.58668 .7365 m .67278 .70153 L .66457 .70322 L .499 .144 .296 r

F

.57496 .70463 m .66457 .70322 L .58668 .7365 L .752 .669 .769 r

F

.57496 .70463 m .65334 .67127 L .66457 .70322 L F

.58668 .7365 m .66757 .72004 L .67278 .70153 L .499 .144 .296 r

F

.54955 .56994 m .63461 .57372 L .63541 .60467 L .713 .48 .571 r

F

.63541 .60467 m .64281 .57189 L .63461 .57372 L .605 .395 .57 r

F

.49882 .52769 m .60319 .47893 L .46057 .51265 L .663 .742 .909 r

F

.49882 .52769 m .61641 .50025 L .60319 .47893 L F

.63541 .60467 m .64368 .60286 L .64281 .57189 L .605 .395 .57 r

F

.54283 .76307 m .66757 .72004 L .58668 .7365 L .499 .144 .296 r

F

.54955 .56994 m .63541 .60467 L .54964 .60093 L .713 .48 .571 r

F

.65334 .67127 m .65027 .63717 L .64199 .63895 L .66 .619 .797 r

F

.5631 .67239 m .65334 .67127 L .57496 .70463 L .752 .669 .769 r

F

.5631 .67239 m .64199 .63895 L .65334 .67127 L F

.5511 .63976 m .56672 .63317 L .64199 .63895 L F

.54964 .60093 m .55581 .6012 L .61182 .62554 L .713 .48 .571 r

F

.54964 .60093 m .61182 .62554 L .61064 .62574 L F

.55581 .6012 m .63541 .60467 L .63585 .62147 L F

.61459 .63684 m .63585 .62147 L .64199 .63895 L .752 .669 .769 r

F

.56672 .63317 m .63585 .62147 L .61459 .63684 L F

.63585 .62147 m .64368 .60286 L .63541 .60467 L .605 .395 .57 r

F

.64199 .63895 m .64049 .62265 L .63585 .62147 L .66 .619 .797 r

F

.64049 .62265 m .64029 .6205 L .63585 .62147 L F

.6397 .62063 m .64022 .61831 L .63585 .62147 L .605 .395 .57 r

F

.64022 .61831 m .64368 .60286 L .63585 .62147 L F

.64199 .63895 m .65027 .63717 L .64415 .61967 L .66 .619 .797 r

F

.64199 .63895 m .64415 .61967 L .64029 .6205 L F

.63623 .63614 m .64456 .63435 L .64415 .61967 L .605 .395 .57 r

F

.6397 .62063 m .64415 .61967 L .64368 .60286 L F

.63623 .63614 m .64415 .61967 L .6397 .62063 L F

.64029 .6205 m .64415 .61967 L .63882 .60442 L .66 .619 .797 r

F

.64029 .6205 m .63882 .60442 L .63585 .62147 L F

.63623 .63614 m .6397 .62063 L .63585 .62147 L .605 .395 .57 r

F

.61182 .62554 m .63585 .62147 L .63623 .63614 L .713 .48 .571 r

F

.55581 .6012 m .63585 .62147 L .61182 .62554 L F

.54964 .60093 m .63623 .63614 L .54973 .63244 L F

.49814 .58936 m .54964 .60093 L .54973 .63244 L .779 .535 .566 r

F

.53896 .60674 m .6305 .60624 L .56672 .63317 L .752 .669 .769 r

F

.54974 .63604 m .56672 .63317 L .5511 .63976 L F

.5511 .63976 m .64199 .63895 L .5631 .67239 L F

.54973 .63244 m .63623 .63614 L .63705 .66815 L .713 .48 .571 r

F

.49814 .58936 m .54973 .63244 L .49779 .62099 L .779 .535 .566 r

F

.50617 .66599 m .5511 .63976 L .5631 .67239 L .809 .696 .74 r

F

.5045 .66158 m .5511 .63976 L .50617 .66599 L F

.54455 .63897 m .5511 .63976 L .5045 .66158 L F

.49779 .62099 m .54973 .63244 L .54974 .63604 L .779 .535 .566 r

F

.49779 .62099 m .54974 .63604 L .52054 .64002 L F

.49754 .64315 m .54455 .63897 L .5045 .66158 L .809 .696 .74 r

F

.46111 .65647 m .47629 .64545 L .50617 .66599 L .852 .714 .71 r

F

.45854 .60638 m .49779 .62099 L .49754 .64315 L .828 .577 .559 r

F

.45854 .60638 m .49754 .64315 L .4898 .64399 L F

.47629 .64545 m .49754 .64315 L .50617 .66599 L .852 .714 .71 r

F

.45854 .60638 m .4898 .64399 L .45783 .63871 L .828 .577 .559 r

F

.4898 .64399 m .49743 .65316 L .47629 .64545 L F

.4898 .64399 m .47629 .64545 L .45783 .63871 L F

.42734 .58952 m .45854 .60638 L .45783 .63871 L .874 .617 .548 r

F

.44811 .62272 m .49365 .63285 L .47629 .64545 L .852 .714 .71 r

F

.45764 .64746 m .47629 .64545 L .46111 .65647 L F

.47395 .6898 m .50617 .66599 L .51853 .69873 L F

.46111 .65647 m .50617 .66599 L .47395 .6898 L F

.45783 .63871 m .49743 .65316 L .49706 .6859 L .828 .577 .559 r

F

.43674 .67866 m .46111 .65647 L .47395 .6898 L .892 .728 .671 r

F

.43099 .66397 m .46111 .65647 L .43674 .67866 L F

.44916 .65272 m .46111 .65647 L .43099 .66397 L F

.42635 .62203 m .45783 .63871 L .45764 .64746 L .874 .617 .548 r

F

.42635 .62203 m .45764 .64746 L .44285 .64861 L F

.42734 .58952 m .45783 .63871 L .42635 .62203 L F

.43738 .64903 m .45764 .64746 L .46111 .65647 L .892 .728 .671 r

F

.42551 .64995 m .44916 .65272 L .43099 .66397 L F

.40522 .66559 m .4186 .65022 L .43674 .67866 L .931 .736 .618 r

F

.4012 .60344 m .42635 .62203 L .42551 .64995 L .919 .659 .53 r

F

.4012 .60344 m .42551 .64995 L .42299 .65005 L F

.4186 .65022 m .42551 .64995 L .43674 .67866 L .931 .736 .618 r

F

.4012 .60344 m .42299 .65005 L .39996 .63672 L .919 .659 .53 r

F

.42299 .65005 m .42535 .65511 L .4186 .65022 L F

.42299 .65005 m .4186 .65022 L .39996 .63672 L F

.39943 .65097 m .4186 .65022 L .40522 .66559 L .931 .736 .618 r

F

.40522 .66559 m .43674 .67866 L .4188 .69989 L F

.39996 .63672 m .42535 .65511 L .42433 .68878 L .919 .659 .53 r

F

.38166 .58301 m .4012 .60344 L .39996 .63672 L .962 .704 .498 r

F

.39279 .68571 m .40522 .66559 L .4188 .69989 L .967 .735 .535 r

F

.38973 .67803 m .40522 .66559 L .39279 .68571 L F

.39605 .6604 m .40522 .66559 L .38973 .67803 L F

.38023 .61651 m .39996 .63672 L .39943 .65097 L .962 .704 .498 r

F

.38023 .61651 m .39943 .65097 L .39195 .65084 L F

.37877 .65063 m .39943 .65097 L .40522 .66559 L .967 .735 .535 r

F

.37877 .65063 m .39605 .6604 L .38973 .67803 L F

.38023 .61651 m .3987 .67061 L .37877 .65063 L .962 .704 .498 r

F

.37877 .65063 m .39147 .63086 L .39943 .65097 L .967 .735 .535 r

F

.39195 .65084 m .39943 .65097 L .3987 .67061 L .962 .704 .498 r

F

.39943 .65097 m .42433 .68878 L .3987 .67061 L .919 .659 .53 r

F

.39996 .63672 m .40255 .64226 L .39943 .65097 L F

.40255 .64226 m .42433 .68878 L .39943 .65097 L F

.38166 .58301 m .39996 .63672 L .38023 .61651 L .962 .704 .498 r

F

.39147 .63086 m .42344 .64467 L .4186 .65022 L .931 .736 .618 r

F

.39147 .63086 m .4186 .65022 L .39943 .65097 L F

.4186 .65022 m .42344 .64467 L .42551 .64995 L F

.42299 .65005 m .42551 .64995 L .42535 .65511 L .919 .659 .53 r

F

.42551 .64995 m .45712 .6716 L .42535 .65511 L .874 .617 .548 r

F

.42635 .62203 m .44285 .64861 L .42551 .64995 L F

.43738 .64903 m .44916 .65272 L .42551 .64995 L .892 .728 .671 r

F

.44285 .64861 m .45712 .6716 L .42551 .64995 L .874 .617 .548 r

F

.42344 .64467 m .43738 .64903 L .42551 .64995 L .892 .728 .671 r

F

.42344 .64467 m .44811 .62272 L .45764 .64746 L F

.42344 .64467 m .45764 .64746 L .43738 .64903 L F

.44285 .64861 m .45764 .64746 L .45712 .6716 L .874 .617 .548 r

F

.45764 .64746 m .49706 .6859 L .45712 .6716 L .828 .577 .559 r

F

.45783 .63871 m .46257 .64441 L .45764 .64746 L F

.46257 .64441 m .49706 .6859 L .45764 .64746 L F

.44811 .62272 m .47629 .64545 L .45764 .64746 L .852 .714 .71 r

F

.47629 .64545 m .49365 .63285 L .49754 .64315 L F

.4898 .64399 m .49754 .64315 L .49743 .65316 L .828 .577 .559 r

F

.49754 .64315 m .54982 .66449 L .49743 .65316 L .779 .535 .566 r

F

.49779 .62099 m .52054 .64002 L .49754 .64315 L F

.53587 .63793 m .54455 .63897 L .49754 .64315 L .809 .696 .74 r

F

.52054 .64002 m .54982 .66449 L .49754 .64315 L .779 .535 .566 r

F

.49365 .63285 m .53587 .63793 L .49754 .64315 L .809 .696 .74 r

F

.49365 .63285 m .53896 .60674 L .54974 .63604 L F

.53587 .63793 m .54974 .63604 L .5511 .63976 L F

.49365 .63285 m .54974 .63604 L .53587 .63793 L F

.52054 .64002 m .54974 .63604 L .54982 .66449 L .779 .535 .566 r

F

.54974 .63604 m .63705 .66815 L .54982 .66449 L .713 .48 .571 r

F

.54973 .63244 m .55343 .63395 L .54974 .63604 L F

.55343 .63395 m .63705 .66815 L .54974 .63604 L F

.53896 .60674 m .56672 .63317 L .54974 .63604 L .752 .669 .769 r

F

.56672 .63317 m .6305 .60624 L .63585 .62147 L F

.61064 .62574 m .61182 .62554 L .63623 .63614 L .713 .48 .571 r

F

.63585 .62147 m .63882 .60442 L .6305 .60624 L .66 .619 .797 r

F

.46057 .51265 m .58965 .45709 L .43019 .49532 L .663 .742 .909 r

F

.46057 .51265 m .60319 .47893 L .58965 .45709 L F

.54283 .76307 m .66223 .73905 L .66757 .72004 L .499 .144 .296 r

F

.51155 .78743 m .66223 .73905 L .54283 .76307 L F

.6305 .60624 m .62723 .57128 L .61887 .57315 L .66 .619 .797 r

F

.6305 .60624 m .63882 .60442 L .62723 .57128 L F

.53896 .60674 m .61887 .57315 L .6305 .60624 L .752 .669 .769 r

F

.63705 .66815 m .64456 .63435 L .63623 .63614 L .605 .395 .57 r

F

.63705 .66815 m .64546 .66638 L .64456 .63435 L F

.43019 .49532 m .55248 .44442 L .40594 .47601 L .663 .742 .909 r

F

.57095 .43676 m .56716 .3995 L .55861 .40162 L .66 .619 .797 r

F

.57095 .43676 m .57946 .43469 L .56716 .3995 L F

.55248 .44442 m .54442 .44235 L .40594 .47601 L .663 .742 .909 r

F

.40594 .47601 m .50943 .43332 L .38713 .45482 L F

.52031 .43613 m .55861 .40162 L .57095 .43676 L .752 .669 .769 r

F

.49227 .4289 m .55861 .40162 L .52031 .43613 L F

.50943 .43332 m .56158 .41181 L .49227 .4289 L .663 .742 .909 r

F

.50943 .43332 m .49227 .4289 L .38713 .45482 L F

.52031 .43613 m .57095 .43676 L .55243 .44441 L .752 .669 .769 r

F

.40594 .47601 m .57578 .43472 L .56158 .41181 L .663 .742 .909 r

F

.47602 .43558 m .49227 .4289 L .52031 .43613 L .752 .669 .769 r

F

.47602 .43558 m .52031 .43613 L .48891 .47065 L F

.52031 .43613 m .55243 .44441 L .48891 .47065 L F

.43019 .49532 m .58965 .45709 L .58738 .45343 L .663 .742 .909 r

F

.55243 .44441 m .57095 .43676 L .57576 .45043 L .752 .669 .769 r

F

.57576 .45043 m .57946 .43469 L .57095 .43676 L .66 .619 .797 r

F

.57576 .45043 m .58738 .45343 L .58425 .44838 L .663 .742 .909 r

F

.43019 .49532 m .58738 .45343 L .57576 .45043 L F

.48616 .47202 m .57576 .45043 L .55248 .44442 L F

.43019 .49532 m .57576 .45043 L .48616 .47202 L F

.58315 .47147 m .59162 .46946 L .58425 .44838 L .66 .619 .797 r

F

.58092 .44918 m .58425 .44838 L .57946 .43469 L F

.58315 .47147 m .58425 .44838 L .58092 .44918 L F

.58315 .47147 m .58092 .44918 L .57576 .45043 L F

.58092 .44918 m .57946 .43469 L .57576 .45043 L F

.55248 .44442 m .57576 .45043 L .57578 .43472 L .663 .742 .909 r

F

.57576 .45043 m .58425 .44838 L .57578 .43472 L F

.55248 .44442 m .57578 .43472 L .54442 .44235 L F

.48891 .47065 m .55243 .44441 L .58315 .47147 L .752 .669 .769 r

F

.55243 .44441 m .57576 .45043 L .58315 .47147 L F

.51155 .78743 m .65674 .75856 L .66223 .73905 L .499 .144 .296 r

F

.48833 .81058 m .65674 .75856 L .51155 .78743 L F

.61887 .57315 m .6155 .53774 L .60711 .53966 L .66 .619 .797 r

F

.61887 .57315 m .62723 .57128 L .6155 .53774 L F

.49848 .55827 m .54955 .56994 L .54964 .60093 L .779 .535 .566 r

F

.49848 .55827 m .54964 .60093 L .49814 .58936 L F

.52667 .57333 m .61887 .57315 L .53896 .60674 L .752 .669 .769 r

F

.49882 .52769 m .54955 .56994 L .49848 .55827 L .779 .535 .566 r

F

.52667 .57333 m .60711 .53966 L .61887 .57315 L .752 .669 .769 r

F

.54982 .66449 m .63705 .66815 L .6379 .70071 L .713 .48 .571 r

F

.6379 .70071 m .64546 .66638 L .63705 .66815 L .605 .395 .57 r

F

.6379 .70071 m .64638 .69896 L .64546 .66638 L F

.60711 .53966 m .60363 .50381 L .5952 .50577 L .66 .619 .797 r

F

.60711 .53966 m .6155 .53774 L .60363 .50381 L F

.51424 .53951 m .60711 .53966 L .52667 .57333 L .752 .669 .769 r

F

.51424 .53951 m .5952 .50577 L .60711 .53966 L F

.51853 .69873 m .5631 .67239 L .57496 .70463 L .809 .696 .74 r

F

.50617 .66599 m .5631 .67239 L .51853 .69873 L F

.54982 .66449 m .6379 .70071 L .54991 .69709 L .713 .48 .571 r

F

.48833 .81058 m .6511 .77861 L .65674 .75856 L .499 .144 .296 r

F

.48177 .81928 m .6511 .77861 L .48833 .81058 L F

.47147 .83292 m .58025 .80004 L .48177 .81928 L F

.58025 .80004 m .6511 .77861 L .48177 .81928 L F

.64051 .80186 m .64357 .78766 L .64016 .78833 L .605 .395 .57 r

F

.64051 .80186 m .64923 .80017 L .64884 .78663 L F

.58025 .80004 m .63632 .78908 L .6511 .77861 L .499 .144 .296 r

F

.64051 .80186 m .64884 .78663 L .64357 .78766 L .605 .395 .57 r

F

.62746 .79639 m .64016 .78833 L .64051 .80186 L .713 .48 .571 r

F

.47147 .83292 m .6132 .80544 L .63632 .78908 L .499 .144 .296 r

F

.47147 .83292 m .63632 .78908 L .58025 .80004 L F

.6132 .80544 m .65015 .78199 L .6511 .77861 L F

.55009 .76402 m .62746 .79639 L .55019 .79837 L .713 .48 .571 r

F

.62746 .79639 m .64051 .80186 L .62009 .80107 L F

.62746 .79639 m .62009 .80107 L .55019 .79837 L F

.46031 .85465 m .60307 .81188 L .47147 .83292 L .499 .144 .296 r

F

.60307 .81188 m .6132 .80544 L .47147 .83292 L F

.59477 .81714 m .64051 .80186 L .64142 .83678 L .713 .48 .571 r

F

.46031 .85465 m .56819 .83402 L .60307 .81188 L .499 .144 .296 r

F

.55019 .79837 m .62009 .80107 L .59477 .81714 L .713 .48 .571 r

F

.62009 .80107 m .64051 .80186 L .59477 .81714 L F

.64142 .83678 m .64923 .80017 L .64051 .80186 L .605 .395 .57 r

F

.60307 .81188 m .63934 .82041 L .6453 .79922 L .499 .144 .296 r

F

.55019 .79837 m .59477 .81714 L .55029 .83334 L .713 .48 .571 r

F

.59477 .81714 m .64142 .83678 L .56819 .83402 L F

.59477 .81714 m .56819 .83402 L .55029 .83334 L F

.45482 .87585 m .54497 .84876 L .46031 .85465 L .499 .144 .296 r

F

.54497 .84876 m .55032 .84537 L .46031 .85465 L F

.55032 .84537 m .56819 .83402 L .56093 .83541 L F

.55032 .84537 m .56093 .83541 L .46031 .85465 L F

.49554 .82273 m .55029 .83334 L .55032 .84537 L .779 .535 .566 r

F

.53711 .85776 m .55032 .84537 L .55038 .86894 L F

.56167 .83816 m .64142 .83678 L .64233 .87232 L .713 .48 .571 r

F

.55029 .83334 m .56819 .83402 L .56167 .83816 L F

.56819 .83402 m .64142 .83678 L .56167 .83816 L F

.55032 .84537 m .64233 .87232 L .55038 .86894 L F

.55029 .83334 m .56167 .83816 L .55032 .84537 L F

.56167 .83816 m .64233 .87232 L .55032 .84537 L F

.54497 .84876 m .63322 .8422 L .63934 .82041 L .499 .144 .296 r

F

.45482 .87585 m .52238 .8631 L .54497 .84876 L F

.52238 .8631 m .53369 .86097 L .54497 .84876 L F

.53369 .86097 m .54685 .84862 L .54497 .84876 L F

.49554 .82273 m .53711 .85776 L .49514 .85849 L .779 .535 .566 r

F

.53711 .85776 m .55038 .86894 L .52942 .86498 L F

.45547 .89648 m .51533 .8782 L .45482 .87585 L .499 .144 .296 r

F

.51683 .87679 m .55038 .86894 L .55048 .90519 L .779 .535 .566 r

F

.52942 .86498 m .55038 .86894 L .51683 .87679 L F

.51533 .8782 m .53369 .86097 L .45482 .87585 L .499 .144 .296 r

F

.45547 .89648 m .50582 .88712 L .51533 .8782 L F

.51683 .87679 m .55048 .90519 L .49706 .89534 L .779 .535 .566 r

F

.55038 .86894 m .64233 .87232 L .64327 .90852 L .713 .48 .571 r

F

.55038 .86894 m .64327 .90852 L .55048 .90519 L F

.46345 .91643 m .48028 .91109 L .45547 .89648 L .499 .144 .296 r

F

.4962 .89615 m .55048 .90519 L .55059 .94211 L .779 .535 .566 r

F

.49706 .89534 m .55048 .90519 L .4962 .89615 L F

.48028 .91109 m .49471 .89755 L .45547 .89648 L .499 .144 .296 r

F

.49471 .89755 m .50582 .88712 L .50301 .88765 L F

.49471 .89755 m .50301 .88765 L .45547 .89648 L F

.44188 .8628 m .45482 .87585 L .45547 .89648 L .925 .597 .138 r

F

.45255 .88178 m .49474 .89491 L .49471 .89755 L .828 .577 .559 r

F

.48013 .91494 m .49471 .89755 L .49432 .93201 L F

.49471 .89755 m .55059 .94211 L .49432 .93201 L .779 .535 .566 r

F

.49474 .89491 m .4962 .89615 L .49471 .89755 L F

.4962 .89615 m .55059 .94211 L .49471 .89755 L F

.48028 .91109 m .62691 .86462 L .50582 .88712 L .499 .144 .296 r

F

.48447 .90976 m .62042 .88769 L .62691 .86462 L F

.46345 .91643 m .48168 .91309 L .48447 .90976 L F

.48168 .91309 m .62042 .88769 L .48447 .90976 L F

.45239 .88904 m .45547 .89648 L .46345 .91643 L .659 .323 0 r

F

.41895 .8666 m .44878 .88007 L .45174 .9191 L .874 .617 .548 r

F

.4501 .88335 m .45018 .88354 L .45239 .88904 L .659 .323 0 r

F

.45018 .88354 m .45547 .89648 L .45239 .88904 L F

.4501 .88335 m .44188 .8628 L .45547 .89648 L F

.44894 .8822 m .45239 .88904 L .45174 .9191 L .874 .617 .548 r

F

.44878 .88007 m .45239 .88904 L .44894 .8822 L F

.44878 .88007 m .44188 .8628 L .4501 .88335 L .659 .323 0 r

F

.44878 .88007 m .45255 .88178 L .45239 .88904 L .874 .617 .548 r

F

.44968 .88232 m .4501 .88335 L .45239 .88904 L .659 .323 0 r

F

.46434 .91275 m .45239 .88904 L .46345 .91643 L 0 .057 .621 r

F

.48013 .91494 m .49432 .93201 L .4716 .92512 L .828 .577 .559 r

F

.55048 .90519 m .64327 .90852 L .64422 .94537 L .713 .48 .571 r

F

.55048 .90519 m .64422 .94537 L .55059 .94211 L F

.4716 .92512 m .62042 .88769 L .46345 .91643 L .499 .144 .296 r

F

.4716 .92512 m .62513 .90843 L .49432 .93201 L .623 .782 .957 r

F

.53188 .91417 m .62513 .90843 L .4716 .92512 L F

.55571 .90983 m .62042 .88769 L .4716 .92512 L .499 .144 .296 r

F

.45255 .88178 m .48013 .91494 L .46719 .91684 L .828 .577 .559 r

F

.46456 .91189 m .45239 .88904 L .46434 .91275 L 0 .057 .621 r

F

.46456 .91189 m .46345 .91643 L .4716 .92512 L F

.46719 .91684 m .4716 .92512 L .45174 .9191 L .828 .577 .559 r

F

.48013 .91494 m .4716 .92512 L .46719 .91684 L F

.45255 .88178 m .46719 .91684 L .45842 .90036 L F

.46728 .90072 m .46456 .91189 L .4716 .92512 L 0 .057 .621 r

F

.53188 .91417 m .61734 .89864 L .62513 .90843 L .623 .782 .957 r

F

.49432 .93201 m .63938 .92634 L .55059 .94211 L F

.49432 .93201 m .62513 .90843 L .63938 .92634 L F

.48119 .93534 m .61374 .91146 L .61734 .89864 L .499 .144 .296 r

F

.55571 .90983 m .61734 .89864 L .62042 .88769 L F

.48119 .93534 m .61734 .89864 L .55571 .90983 L F

.47051 .91794 m .61051 .89005 L .61734 .89864 L .623 .782 .957 r

F

.47051 .91794 m .61734 .89864 L .53188 .91417 L F

.46728 .90072 m .4716 .92512 L .46828 .90322 L 0 .057 .621 r

F

.45842 .90036 m .46692 .91632 L .46365 .91692 L .828 .577 .559 r

F

.46692 .91632 m .46719 .91684 L .46365 .91692 L F

.46365 .91692 m .46719 .91684 L .46378 .91733 L F

.45239 .88904 m .46378 .91733 L .45174 .9191 L F

.45255 .88178 m .46378 .91733 L .45239 .88904 L F

.45174 .9191 m .47018 .91572 L .47051 .91794 L .623 .782 .957 r

F

.45255 .88178 m .49471 .89755 L .48013 .91494 L .828 .577 .559 r

F

.47018 .91572 m .61051 .89005 L .47051 .91794 L .623 .782 .957 r

F

.48119 .93534 m .55571 .90983 L .4716 .92512 L .499 .144 .296 r

F

.45174 .9191 m .53188 .91417 L .4716 .92512 L .623 .782 .957 r

F

.46728 .90072 m .45239 .88904 L .46456 .91189 L 0 .057 .621 r

F

.46728 .90072 m .44968 .88232 L .45239 .88904 L F

.44142 .84255 m .46031 .85465 L .45482 .87585 L .984 .705 .393 r

F

.44142 .84255 m .44714 .8217 L .46031 .85465 L F

.44188 .8628 m .44142 .84255 L .45482 .87585 L .925 .597 .138 r

F

.42006 .82972 m .43044 .83452 L .44385 .86784 L .874 .617 .548 r

F

.42006 .82972 m .44385 .86784 L .41895 .8666 L F

.44385 .86784 m .44878 .88007 L .41895 .8666 L F

.43572 .84776 m .43845 .85443 L .44968 .88232 L .659 .323 0 r

F

.43845 .85443 m .44188 .8628 L .44878 .88007 L F

.43845 .85443 m .44878 .88007 L .44968 .88232 L F

.44385 .86784 m .45255 .88178 L .44878 .88007 L .874 .617 .548 r

F

.44385 .86784 m .45334 .84514 L .45255 .88178 L F

.44714 .8217 m .47147 .83292 L .46031 .85465 L .967 .735 .535 r

F

.45334 .84514 m .49474 .89491 L .45255 .88178 L .828 .577 .559 r

F

.45319 .86565 m .44968 .88232 L .46728 .90072 L 0 .057 .621 r

F

.41895 .8666 m .45174 .9191 L .41781 .90418 L .874 .617 .548 r

F

.46864 .90139 m .46728 .90072 L .46828 .90322 L .187 .339 .786 r

F

.46882 .90044 m .61051 .89005 L .46574 .91654 L .623 .782 .957 r

F

.45334 .84514 m .49514 .85849 L .49474 .89491 L .828 .577 .559 r

F

.49474 .89491 m .49706 .89534 L .4962 .89615 L .779 .535 .566 r

F

.49514 .85849 m .51683 .87679 L .49474 .89491 L F

.51683 .87679 m .49706 .89534 L .49474 .89491 L F

.46882 .90044 m .59549 .87117 L .61051 .89005 L .623 .782 .957 r

F

.46995 .8945 m .59549 .87117 L .46882 .90044 L F

.44968 .88232 m .44878 .88007 L .4501 .88335 L .659 .323 0 r

F

.51533 .8782 m .62691 .86462 L .63322 .8422 L .499 .144 .296 r

F

.50582 .88712 m .62691 .86462 L .51533 .8782 L F

.51533 .8782 m .63322 .8422 L .53369 .86097 L F

.39204 .84966 m .41895 .8666 L .41781 .90418 L .919 .659 .53 r

F

.39204 .84966 m .41781 .90418 L .39063 .88753 L F

.46912 .89887 m .45319 .86565 L .46728 .90072 L .187 .339 .786 r

F

.47363 .87531 m .45319 .86565 L .46912 .89887 L F

.39063 .88753 m .47254 .88099 L .41781 .90418 L .623 .782 .957 r

F

.47254 .88099 m .59549 .87117 L .46995 .8945 L F

.47254 .88099 m .46995 .8945 L .41781 .90418 L F

.49514 .85849 m .52942 .86498 L .51683 .87679 L .779 .535 .566 r

F

.53711 .85776 m .52942 .86498 L .49514 .85849 L F

.53369 .86097 m .63322 .8422 L .54685 .84862 L .499 .144 .296 r

F

.42786 .80884 m .44714 .8217 L .44142 .84255 L .984 .705 .393 r

F

.42811 .82869 m .44142 .84255 L .44188 .8628 L .925 .597 .138 r

F

.42811 .82869 m .42786 .80884 L .44142 .84255 L F

.43845 .85443 m .42811 .82869 L .44188 .8628 L .659 .323 0 r

F

.43572 .84776 m .43044 .83452 L .43845 .85443 L F

.43044 .83452 m .42811 .82869 L .43845 .85443 L F

.42786 .80884 m .43381 .78834 L .44714 .8217 L .984 .705 .393 r

F

.41413 .77469 m .43381 .78834 L .42786 .80884 L F

.42065 .81023 m .42786 .80884 L .42811 .82869 L .925 .597 .138 r

F

.39477 .77604 m .41128 .78697 L .42006 .82972 L .919 .659 .53 r

F

.41128 .78697 m .41415 .78887 L .41533 .79702 L F

.41128 .78697 m .41533 .79702 L .42006 .82972 L F

.41415 .78887 m .42065 .81023 L .42006 .82972 L F

.42065 .81023 m .43044 .83452 L .42006 .82972 L .874 .617 .548 r

F

.42159 .81275 m .41416 .79414 L .42065 .81023 L .659 .323 0 r

F

.42716 .82638 m .42065 .81023 L .42811 .82869 L F

.42159 .81275 m .42065 .81023 L .42716 .82638 L F

.41416 .79414 m .41653 .79668 L .42065 .81023 L .925 .597 .138 r

F

.41653 .79668 m .42786 .80884 L .42065 .81023 L F

.41653 .79668 m .41413 .77469 L .42786 .80884 L F

.41416 .79414 m .41415 .78887 L .41653 .79668 L F

.41415 .78887 m .41413 .77469 L .41653 .79668 L F

.42031 .75456 m .44546 .76722 L .43381 .78834 L .967 .735 .535 r

F

.41413 .77469 m .42031 .75456 L .43381 .78834 L .984 .705 .393 r

F

.40022 .74011 m .42031 .75456 L .41413 .77469 L F

.39611 .74025 m .40529 .75977 L .39477 .77604 L .919 .659 .53 r

F

.40529 .75977 m .41415 .78887 L .39477 .77604 L F

.40003 .75914 m .40766 .76756 L .41416 .79414 L .925 .597 .138 r

F

.40766 .76756 m .41413 .77469 L .41415 .78887 L F

.40766 .76756 m .41415 .78887 L .41416 .79414 L F

.39611 .74025 m .40019 .74302 L .40529 .75977 L .919 .659 .53 r

F

.40766 .76756 m .40022 .74011 L .41413 .77469 L .925 .597 .138 r

F

.40003 .75914 m .40019 .74302 L .40766 .76756 L F

.40019 .74302 m .40022 .74011 L .40766 .76756 L F

.42031 .75456 m .43221 .73377 L .44546 .76722 L .967 .735 .535 r

F

.40664 .72035 m .43221 .73377 L .42031 .75456 L F

.40022 .74011 m .40664 .72035 L .42031 .75456 L .984 .705 .393 r

F

.39646 .73077 m .40664 .72035 L .40022 .74011 L F

.37729 .68537 m .38198 .68998 L .39611 .74025 L .962 .704 .498 r

F

.38198 .68998 m .38897 .69683 L .3929 .72074 L F

.38198 .68998 m .3929 .72074 L .39611 .74025 L F

.3929 .72074 m .39646 .73077 L .39611 .74025 L F

.38897 .69683 m .39646 .73077 L .3929 .72074 L F

.37729 .68537 m .39611 .74025 L .37578 .72077 L F

.38571 .72369 m .38613 .70509 L .39646 .73077 L .925 .597 .138 r

F

.39948 .73927 m .39646 .73077 L .40022 .74011 L F

.39646 .73077 m .40019 .74302 L .39611 .74025 L .919 .659 .53 r

F

.38571 .72369 m .39646 .73077 L .39948 .73927 L .925 .597 .138 r

F

.37578 .72077 m .39611 .74025 L .39477 .77604 L .962 .704 .498 r

F

.38571 .72369 m .39948 .73927 L .40003 .75914 L .925 .597 .138 r

F

.39948 .73927 m .40022 .74011 L .4002 .74133 L F

.39948 .73927 m .4002 .74133 L .40003 .75914 L F

.38613 .70509 m .39171 .70924 L .39646 .73077 L .984 .705 .393 r

F

.39171 .70924 m .40664 .72035 L .39646 .73077 L F

.39171 .70924 m .39279 .68571 L .40664 .72035 L F

.38613 .70509 m .38897 .69683 L .39171 .70924 L F

.38897 .69683 m .39279 .68571 L .39171 .70924 L F

.37877 .65063 m .38897 .69683 L .37729 .68537 L .962 .704 .498 r

F

.36918 .64955 m .37877 .65063 L .37729 .68537 L .992 .745 .44 r

F

.3574 .63367 m .36501 .63971 L .36353 .64891 L .984 .705 .393 r

F

.36501 .63971 m .37877 .65063 L .36353 .64891 L F

.3574 .63367 m .36457 .61509 L .37877 .65063 L F

.34275 .59725 m .36457 .61509 L .3574 .63367 L F

.34275 .59725 m .35019 .5791 L .36457 .61509 L F

.35624 .60489 m .36447 .62878 L .36353 .64891 L .971 .756 .325 r

F

.36214 .65756 m .36353 .64891 L .36283 .66379 L F

.36107 .64806 m .36353 .64891 L .36214 .65756 L F

.36447 .62878 m .37729 .68537 L .36283 .66379 L .992 .745 .44 r

F

.35515 .64601 m .36283 .66379 L .36117 .69946 L .971 .756 .325 r

F

.3547 .6422 m .3574 .63367 L .35675 .64657 L .925 .597 .138 r

F

.34163 .61448 m .35608 .63206 L .3547 .6422 L F

.35608 .63206 m .3574 .63367 L .3547 .6422 L F

.34163 .61448 m .35675 .64657 L .35423 .64569 L F

.34163 .61448 m .34275 .59725 L .3574 .63367 L F

.35343 .61416 m .3545 .64017 L .35423 .64569 L .797 .663 .112 r

F

.35297 .65496 m .35423 .64569 L .35272 .67613 L F

.3531 .64301 m .35423 .64569 L .35297 .65496 L F

.36283 .66379 m .37578 .72077 L .36117 .69946 L .992 .745 .44 r

F

.35423 .64569 m .36117 .69946 L .35272 .67613 L .971 .756 .325 r

F

.3545 .64017 m .35546 .64873 L .35423 .64569 L F

.35546 .64873 m .36117 .69946 L .35423 .64569 L F

.35211 .64065 m .35272 .67613 L .35162 .65043 L .797 .663 .112 r

F

.34804 .63057 m .3453 .6237 L .34954 .63415 L .659 .323 0 r

F

.3506 .63684 m .34954 .63415 L .35395 .64502 L F

.34804 .63057 m .34954 .63415 L .3506 .63684 L F

.34804 .63057 m .35395 .64502 L .35346 .64387 L F

.3453 .6237 m .34163 .61448 L .35423 .64569 L F

.3453 .6237 m .35423 .64569 L .35652 .65136 L F

.34804 .63057 m .35346 .64387 L .35211 .64065 L F

.35343 .61416 m .3531 .64301 L .35211 .64065 L .797 .663 .112 r

F

.35343 .61416 m .35423 .64569 L .3531 .64301 L F

.35675 .64657 m .3574 .63367 L .36353 .64891 L .925 .597 .138 r

F

.35624 .60489 m .36353 .64891 L .36107 .64806 L .971 .756 .325 r

F

.36766 .56068 m .38166 .58301 L .38023 .61651 L .992 .745 .44 r

F

.35019 .5791 m .36741 .58955 L .36457 .61509 L .967 .735 .535 r

F

.38307 .5501 m .40241 .57074 L .4012 .60344 L .962 .704 .498 r

F

.38307 .5501 m .4012 .60344 L .38166 .58301 L F

.36921 .52756 m .38307 .5501 L .38166 .58301 L .992 .745 .44 r

F

.36921 .52756 m .38166 .58301 L .36766 .56068 L F

.36741 .58955 m .37032 .59131 L .36753 .60285 L .967 .735 .535 r

F

.36741 .58955 m .36753 .60285 L .36457 .61509 L F

.37032 .59131 m .37211 .60383 L .36457 .61509 L F

.36766 .56068 m .38023 .61651 L .37699 .61146 L .992 .745 .44 r

F

.36724 .56966 m .37699 .61146 L .37211 .60383 L F

.36766 .56068 m .37699 .61146 L .36724 .56966 L F

.37211 .60383 m .38023 .61651 L .37877 .65063 L F

.37454 .62094 m .37754 .59569 L .39147 .63086 L .967 .735 .535 r

F

.36457 .61509 m .37211 .60383 L .37454 .62094 L F

.37211 .60383 m .37754 .59569 L .37454 .62094 L F

.35019 .5791 m .36344 .56008 L .37754 .59569 L F

.36724 .56966 m .37211 .60383 L .36608 .59442 L .992 .745 .44 r

F

.36643 .55695 m .36714 .55912 L .36696 .56527 L .971 .756 .325 r

F

.36714 .55912 m .36766 .56068 L .36724 .56966 L F

.36344 .56008 m .36672 .5616 L .36724 .56966 L .931 .736 .618 r

F

.36696 .56527 m .36724 .56966 L .36608 .59442 L .971 .756 .325 r

F

.36714 .55912 m .36724 .56966 L .36696 .56527 L F

.38445 .51778 m .40241 .57074 L .38307 .5501 L .962 .704 .498 r

F

.37073 .49502 m .38445 .51778 L .38307 .5501 L .992 .745 .44 r

F

.37073 .49502 m .38307 .5501 L .36921 .52756 L F

.36532 .5396 m .36921 .52756 L .36766 .56068 L .971 .756 .325 r

F

.36341 .50958 m .36921 .52756 L .36532 .5396 L F

.34916 .524 m .36481 .53155 L .36344 .56008 L .931 .736 .618 r

F

.36532 .5396 m .36766 .56068 L .36643 .55695 L .971 .756 .325 r

F

.36481 .53155 m .38254 .54011 L .36643 .55695 L .931 .736 .618 r

F

.36481 .53155 m .36643 .55695 L .36344 .56008 L F

.36288 .47015 m .37073 .49502 L .36921 .52756 L .971 .756 .325 r

F

.36288 .47015 m .36921 .52756 L .36428 .51229 L F

.36331 .50164 m .36428 .51229 L .36341 .50958 L F

.36288 .47015 m .36428 .51229 L .36331 .50164 L F

.36288 .47015 m .36331 .50164 L .36202 .48763 L F

.36331 .50164 m .36341 .50958 L .36202 .48763 L F

.38713 .45482 m .40478 .50704 L .3858 .48602 L .962 .704 .498 r

F

.37369 .43167 m .38713 .45482 L .3858 .48602 L .992 .745 .44 r

F

.37222 .46306 m .3858 .48602 L .38445 .51778 L F

.37369 .43167 m .3858 .48602 L .37222 .46306 L F

.36602 .40638 m .37369 .43167 L .37222 .46306 L .971 .756 .325 r

F

.37222 .46306 m .38445 .51778 L .37073 .49502 L .992 .745 .44 r

F

.36446 .43798 m .37222 .46306 L .37073 .49502 L .971 .756 .325 r

F

.36602 .40638 m .37222 .46306 L .36446 .43798 L F

.36446 .43798 m .37073 .49502 L .36288 .47015 L F

.36341 .42648 m .36446 .43798 L .36288 .47015 L .797 .663 .112 r

F

.3637 .41356 m .36446 .43798 L .36341 .42648 L F

.38713 .45482 m .46584 .42208 L .37369 .43167 L .663 .742 .909 r

F

.46296 .40008 m .55861 .40162 L .49227 .4289 L .752 .669 .769 r

F

.46296 .40008 m .49227 .4289 L .4716 .42357 L F

.46296 .40008 m .54611 .36604 L .55861 .40162 L F

.46584 .42208 m .46746 .42141 L .43935 .41525 L .663 .742 .909 r

F

.46746 .42141 m .45034 .4125 L .43935 .41525 L F

.46584 .42208 m .43935 .41525 L .37369 .43167 L F

.44489 .40966 m .46296 .40008 L .4716 .42357 L .809 .696 .74 r

F

.38713 .45482 m .56158 .41181 L .54701 .38832 L .663 .742 .909 r

F

.44974 .36413 m .54611 .36604 L .46296 .40008 L .752 .669 .769 r

F

.44974 .36413 m .53346 .33003 L .54611 .36604 L F

.40775 .39034 m .46296 .40008 L .44489 .40966 L .809 .696 .74 r

F

.40775 .39034 m .44974 .36413 L .46296 .40008 L F

.40367 .38821 m .44974 .36413 L .40775 .39034 L F

.43636 .32774 m .53346 .33003 L .44974 .36413 L .752 .669 .769 r

F

.36602 .40638 m .40448 .38934 L .36519 .37859 L .663 .742 .909 r

F

.40448 .38934 m .40332 .38852 L .36519 .37859 L F

.369 .36432 m .38785 .3527 L .40067 .38665 L .852 .714 .71 r

F

.38785 .3527 m .44974 .36413 L .40367 .38821 L .809 .696 .74 r

F

.38785 .3527 m .40367 .38821 L .40067 .38665 L F

.38785 .3527 m .43636 .32774 L .44974 .36413 L F

.40521 .38901 m .51678 .33956 L .37857 .37515 L .663 .742 .909 r

F

.40521 .38901 m .37857 .37515 L .36519 .37859 L F

.43636 .32774 m .52065 .29357 L .53346 .33003 L .752 .669 .769 r

F

.43636 .32774 m .51384 .31993 L .38785 .3527 L .347 0 .059 r

F

.43636 .32774 m .52169 .3054 L .51384 .31993 L F

.38785 .3527 m .45013 .34329 L .369 .36432 L F

.38785 .3527 m .51384 .31993 L .50954 .32789 L F

.36519 .37859 m .51678 .33956 L .50954 .32789 L .663 .742 .909 r

F

.36519 .37859 m .50954 .32789 L .42714 .34925 L F

.45013 .34329 m .50954 .32789 L .50576 .33488 L .347 0 .059 r

F

.38785 .3527 m .50954 .32789 L .45013 .34329 L F

.42714 .34925 m .50954 .32789 L .50107 .31423 L .663 .742 .909 r

F

.369 .36432 m .50107 .31423 L .37348 .34758 L F

.36519 .37859 m .42714 .34925 L .369 .36432 L F

.42714 .34925 m .50107 .31423 L .369 .36432 L F

.36714 .37889 m .369 .36432 L .40166 .38926 L .852 .714 .71 r

F

.36519 .37859 m .36602 .40638 L .36446 .43798 L .797 .663 .112 r

F

.36519 .37859 m .36446 .43798 L .36373 .41455 L F

.36378 .41163 m .36373 .41455 L .3637 .41356 L F

.36519 .37859 m .36373 .41455 L .36378 .41163 L F

.36519 .37859 m .3637 .41356 L .36391 .40411 L F

.37369 .43167 m .43611 .4051 L .36602 .40638 L .663 .742 .909 r

F

.43611 .4051 m .4148 .39401 L .36602 .40638 L F

.36602 .40638 m .53209 .36425 L .51678 .33956 L F

.36391 .40411 m .40166 .38926 L .36668 .4113 L .852 .714 .71 r

F

.3525 .37449 m .36437 .37806 L .36391 .40411 L F

.369 .36432 m .36519 .37859 L .36391 .40411 L 0 0 .164 r

F

.36437 .37806 m .36714 .37889 L .36391 .40411 L .852 .714 .71 r

F

.36714 .37889 m .40166 .38926 L .36391 .40411 L F

.37369 .43167 m .45034 .4125 L .43611 .4051 L .663 .742 .909 r

F

.34007 .43152 m .3637 .41356 L .36308 .44066 L .892 .728 .671 r

F

.36341 .42648 m .36288 .47015 L .3626 .46177 L .797 .663 .112 r

F

.34007 .43152 m .36308 .44066 L .35441 .46818 L .892 .728 .671 r

F

.36308 .44066 m .38068 .44765 L .3626 .46177 L F

.36308 .44066 m .3626 .46177 L .35441 .46818 L F

.35984 .46394 m .3626 .46177 L .36044 .47049 L F

.3626 .46177 m .36246 .46821 L .36044 .47049 L F

.36044 .47049 m .36246 .46821 L .36239 .47124 L F

.35441 .46818 m .36044 .47049 L .36202 .48763 L F

.3626 .46177 m .36288 .47015 L .36202 .48763 L .797 .663 .112 r

F

.36044 .47049 m .39451 .48354 L .36202 .48763 L .892 .728 .671 r

F

.33469 .48746 m .36856 .50437 L .34916 .524 L .931 .736 .618 r

F

.33469 .48746 m .35441 .46818 L .36856 .50437 L F

.36198 .4428 m .3626 .46177 L .36126 .50291 L .797 .663 .112 r

F

.3626 .46177 m .36202 .48763 L .36126 .50291 L F

.32555 .3944 m .36668 .4113 L .34007 .43152 L .892 .728 .671 r

F

.3636 .4104 m .36341 .42648 L .36198 .4428 L .797 .663 .112 r

F

.36341 .42648 m .3626 .46177 L .36198 .4428 L F

.3626 .46177 m .38068 .44765 L .36246 .46821 L .892 .728 .671 r

F

.36308 .44066 m .36668 .4113 L .38068 .44765 L F

.3637 .41356 m .36668 .4113 L .36308 .44066 L F

.32555 .3944 m .3525 .37449 L .36668 .4113 L F

.36391 .40411 m .3637 .41356 L .3636 .4104 L .797 .663 .112 r

F

.3525 .37449 m .369 .36432 L .36714 .37889 L .852 .714 .71 r

F

.369 .36432 m .40067 .38665 L .40166 .38926 L F

.369 .36432 m .50576 .33488 L .37031 .36989 L .347 0 .059 r

F

.37011 .36902 m .369 .36432 L .3636 .4104 L 0 0 .164 r

F

.369 .36432 m .36391 .40411 L .3636 .4104 L F

.45013 .34329 m .50576 .33488 L .369 .36432 L .347 0 .059 r

F

.37205 .3773 m .3636 .4104 L .37194 .37962 L 0 0 .164 r

F

.37068 .37145 m .49745 .35027 L .37601 .38144 L .347 0 .059 r

F

.37258 .37785 m .37205 .3773 L .37194 .37962 L .009 0 .368 r

F

.37068 .37145 m .37601 .38144 L .37205 .3773 L .347 0 .059 r

F

.36668 .4113 m .40166 .38926 L .41529 .42536 L .852 .714 .71 r

F

.38003 .38564 m .37194 .37962 L .37038 .41226 L .009 0 .368 r

F

.37011 .36902 m .3636 .4104 L .37205 .3773 L 0 0 .164 r

F

.36704 .37206 m .50576 .33488 L .49745 .35027 L .347 0 .059 r

F

.3525 .37449 m .36602 .37099 L .36704 .37206 L F

.36602 .37099 m .50576 .33488 L .36704 .37206 L F

.37348 .34758 m .48496 .28824 L .39646 .31172 L .663 .742 .909 r

F

.52065 .29357 m .52169 .3054 L .43636 .32774 L .347 0 .059 r

F

.37348 .34758 m .50107 .31423 L .48496 .28824 L .663 .742 .909 r

F

.39646 .31172 m .37258 .37785 L .39511 .34402 L .009 0 .368 r

F

.37258 .37785 m .37194 .37962 L .37289 .37817 L F

.37258 .37785 m .37289 .37817 L .39511 .34402 L F

.37289 .37817 m .37194 .37962 L .38003 .38564 L F

.40067 .38665 m .40367 .38821 L .40166 .38926 L .809 .696 .74 r

F

.3636 .4104 m .3637 .41356 L .36341 .42648 L .797 .663 .112 r

F

.36668 .4113 m .41529 .42536 L .38068 .44765 L .852 .714 .71 r

F

.37194 .37962 m .3636 .4104 L .36198 .4428 L 0 0 .164 r

F

.30519 .41294 m .32555 .3944 L .34007 .43152 L .931 .736 .618 r

F

.37194 .37962 m .36198 .4428 L .37038 .41226 L 0 0 .164 r

F

.32555 .3944 m .37947 .38506 L .30519 .41294 L .347 0 .059 r

F

.37947 .38506 m .48888 .36612 L .38635 .39225 L F

.38003 .38564 m .37038 .41226 L .38473 .39056 L .009 0 .368 r

F

.38766 .39362 m .37038 .41226 L .36878 .44552 L F

.37947 .38506 m .49745 .35027 L .48888 .36612 L .347 0 .059 r

F

.37601 .38144 m .49745 .35027 L .37947 .38506 L F

.38473 .39056 m .37038 .41226 L .38766 .39362 L .009 0 .368 r

F

.40448 .38934 m .40521 .38901 L .40332 .38852 L .663 .742 .909 r

F

.40166 .38926 m .40367 .38821 L .40775 .39034 L .809 .696 .74 r

F

.43611 .4051 m .53209 .36425 L .4148 .39401 L .663 .742 .909 r

F

.40166 .38926 m .40775 .39034 L .41529 .42536 L .809 .696 .74 r

F

.40775 .39034 m .44489 .40966 L .41529 .42536 L F

.39171 .39785 m .48888 .36612 L .48006 .38245 L .347 0 .059 r

F

.38766 .39362 m .36878 .44552 L .39281 .39901 L .009 0 .368 r

F

.30519 .41294 m .38635 .39225 L .39171 .39785 L .347 0 .059 r

F

.38635 .39225 m .48888 .36612 L .39171 .39785 L F

.39281 .39901 m .36878 .44552 L .39233 .41048 L .009 0 .368 r

F

.30519 .41294 m .34007 .43152 L .32003 .45044 L .931 .736 .618 r

F

.29075 .43035 m .30519 .41294 L .32003 .45044 L .967 .735 .535 r

F

.30519 .41294 m .3893 .39827 L .29075 .43035 L .347 0 .059 r

F

.3893 .39827 m .48006 .38245 L .40474 .40151 L F

.40035 .40059 m .39281 .39901 L .39233 .41048 L .338 .155 .48 r

F

.45764 .32992 m .40035 .40059 L .45684 .36383 L F

.40035 .40059 m .39233 .41048 L .40474 .40151 L F

.40035 .40059 m .40474 .40151 L .45684 .36383 L F

.43611 .4051 m .54701 .38832 L .53209 .36425 L .663 .742 .909 r

F

.45034 .4125 m .54701 .38832 L .43611 .4051 L F

.42882 .40655 m .48006 .38245 L .47097 .39928 L .347 0 .059 r

F

.36198 .4428 m .36126 .50291 L .36034 .4758 L .797 .663 .112 r

F

.37038 .41226 m .36198 .4428 L .36034 .4758 L 0 0 .164 r

F

.37038 .41226 m .36034 .4758 L .36878 .44552 L F

.36239 .47124 m .38068 .44765 L .39451 .48354 L .892 .728 .671 r

F

.36246 .46821 m .38068 .44765 L .36239 .47124 L F

.39233 .41048 m .36878 .44552 L .36715 .47941 L .009 0 .368 r

F

.40594 .47601 m .43019 .49532 L .42925 .52618 L .919 .659 .53 r

F

.40594 .47601 m .42925 .52618 L .40478 .50704 L F

.38713 .45482 m .40594 .47601 L .40478 .50704 L .962 .704 .498 r

F

.38068 .44765 m .42875 .46101 L .39451 .48354 L .852 .714 .71 r

F

.38068 .44765 m .41529 .42536 L .42875 .46101 L F

.39233 .41048 m .36715 .47941 L .39091 .44468 L .009 0 .368 r

F

.40474 .40151 m .48006 .38245 L .42882 .40655 L .347 0 .059 r

F

.42299 .40533 m .39233 .41048 L .39091 .44468 L .338 .155 .48 r

F

.45684 .36383 m .40474 .40151 L .42299 .40533 L F

.40474 .40151 m .39233 .41048 L .42299 .40533 L F

.29075 .43035 m .32003 .45044 L .3059 .46828 L .967 .735 .535 r

F

.28218 .44669 m .29075 .43035 L .3059 .46828 L .984 .705 .393 r

F

.42882 .40655 m .47097 .39928 L .43603 .40806 L .347 0 .059 r

F

.41529 .42536 m .44489 .40966 L .47602 .43558 L .809 .696 .74 r

F

.41529 .42536 m .47602 .43558 L .42875 .46101 L F

.45684 .36383 m .42299 .40533 L .45602 .39841 L .338 .155 .48 r

F

.42299 .40533 m .39091 .44468 L .44099 .40909 L F

.44489 .40966 m .4716 .42357 L .47602 .43558 L .809 .696 .74 r

F

.46746 .42141 m .54701 .38832 L .45034 .4125 L .663 .742 .909 r

F

.43603 .40806 m .47097 .39928 L .4653 .40977 L .347 0 .059 r

F

.45946 .41123 m .46485 .43131 L .45569 .41217 L .571 .339 .525 r

F

.43603 .40806 m .4653 .40977 L .45569 .41217 L .347 0 .059 r

F

.45602 .39841 m .46559 .396 L .4653 .40977 L .571 .339 .525 r

F

.45946 .41123 m .4653 .40977 L .46485 .43131 L F

.45602 .39841 m .4653 .40977 L .45946 .41123 L F

.32003 .45044 m .34007 .43152 L .35441 .46818 L .931 .736 .618 r

F

.45602 .39841 m .39091 .44468 L .38945 .47955 L .338 .155 .48 r

F

.45602 .39841 m .38945 .47955 L .45518 .4337 L F

.28218 .44669 m .43603 .40806 L .45144 .41323 L .347 0 .059 r

F

.45569 .41217 m .46485 .43131 L .45518 .4337 L .571 .339 .525 r

F

.38945 .42873 m .45144 .41323 L .46158 .41665 L .347 0 .059 r

F

.28218 .44669 m .45144 .41323 L .38945 .42873 L F

.45569 .41217 m .4653 .40977 L .46316 .41373 L F

.45602 .39841 m .45946 .41123 L .45569 .41217 L .571 .339 .525 r

F

.42299 .40533 m .44099 .40909 L .45602 .39841 L .338 .155 .48 r

F

.43603 .40806 m .46316 .41373 L .46158 .41665 L .347 0 .059 r

F

.29075 .43035 m .42882 .40655 L .28218 .44669 L F

.42882 .40655 m .43603 .40806 L .28218 .44669 L F

.29075 .43035 m .40474 .40151 L .42882 .40655 L F

.3893 .39827 m .40474 .40151 L .29075 .43035 L F

.45764 .32992 m .39373 .37693 L .39281 .39901 L .338 .155 .48 r

F

.45764 .32992 m .39281 .39901 L .40035 .40059 L F

.39373 .37693 m .38766 .39362 L .39281 .39901 L .009 0 .368 r

F

.39373 .37693 m .38473 .39056 L .38766 .39362 L F

.32555 .3944 m .37601 .38144 L .37947 .38506 L .347 0 .059 r

F

.37947 .38506 m .38635 .39225 L .30519 .41294 L F

.39511 .34402 m .38003 .38564 L .39373 .37693 L .009 0 .368 r

F

.38003 .38564 m .38473 .39056 L .39373 .37693 L F

.39511 .34402 m .37289 .37817 L .38003 .38564 L F

.36784 .37289 m .3732 .38216 L .32555 .3944 L .347 0 .059 r

F

.37068 .37145 m .37205 .3773 L .36784 .37289 L F

.37205 .3773 m .3732 .38216 L .36784 .37289 L F

.37205 .3773 m .37601 .38144 L .3732 .38216 L F

.39646 .31172 m .37348 .34758 L .37205 .3773 L .009 0 .368 r

F

.39646 .31172 m .37205 .3773 L .37258 .37785 L F

.37348 .34758 m .37011 .36902 L .37205 .3773 L 0 0 .164 r

F

.3525 .37449 m .37068 .37145 L .32555 .3944 L .347 0 .059 r

F

.369 .36432 m .37031 .36989 L .3525 .37449 L F

.37348 .34758 m .369 .36432 L .37011 .36902 L 0 0 .164 r

F

.4716 .42357 m .49227 .4289 L .47602 .43558 L .752 .669 .769 r

F

.35441 .46818 m .35984 .46394 L .36044 .47049 L .892 .728 .671 r

F

.3858 .48602 m .40478 .50704 L .40361 .53861 L .962 .704 .498 r

F

.3858 .48602 m .40361 .53861 L .38445 .51778 L F

.36202 .48763 m .39451 .48354 L .36856 .50437 L .892 .728 .671 r

F

.36481 .53155 m .36856 .50437 L .38254 .54011 L .931 .736 .618 r

F

.34916 .524 m .36341 .50958 L .36481 .53155 L F

.36341 .50958 m .36856 .50437 L .36481 .53155 L F

.36202 .48763 m .36341 .50958 L .36126 .50291 L .971 .756 .325 r

F

.36126 .50291 m .36532 .5396 L .35962 .53627 L F

.36532 .5396 m .36643 .55695 L .35962 .53627 L F

.36126 .50291 m .36341 .50958 L .36532 .5396 L F

.36469 .55877 m .36643 .55695 L .36519 .56089 L .931 .736 .618 r

F

.36643 .55695 m .38254 .54011 L .36657 .55923 L F

.36643 .55695 m .36657 .55923 L .36519 .56089 L F

.36672 .5616 m .38254 .54011 L .39634 .5754 L F

.36519 .56089 m .36657 .55923 L .36672 .5616 L F

.36657 .55923 m .38254 .54011 L .36672 .5616 L F

.36344 .56008 m .36469 .55877 L .36519 .56089 L F

.36724 .56966 m .39634 .5754 L .37754 .59569 L F

.36672 .5616 m .39634 .5754 L .36724 .56966 L F

.33562 .54264 m .36344 .56008 L .35019 .5791 L .967 .735 .535 r

F

.33562 .54264 m .34916 .524 L .36344 .56008 L F

.35962 .53627 m .36643 .55695 L .36608 .59442 L .971 .756 .325 r

F

.36643 .55695 m .36696 .56527 L .36608 .59442 L F

.37032 .59131 m .37754 .59569 L .37211 .60383 L .967 .735 .535 r

F

.36457 .61509 m .39147 .63086 L .37877 .65063 L F

.36608 .59442 m .37211 .60383 L .37877 .65063 L .992 .745 .44 r

F

.35794 .57026 m .36608 .59442 L .36447 .62878 L .971 .756 .325 r

F

.35794 .57026 m .36447 .62878 L .35624 .60489 L F

.35695 .54367 m .35794 .57026 L .35624 .60489 L .797 .663 .112 r

F

.35624 .60489 m .36283 .66379 L .3545 .64017 L .971 .756 .325 r

F

.35695 .54367 m .35624 .60489 L .35521 .57858 L .797 .663 .112 r

F

.35521 .57858 m .35624 .60489 L .3545 .64017 L F

.35521 .57858 m .3545 .64017 L .35343 .61416 L F

.36209 .58508 m .35343 .61416 L .35211 .64065 L 0 0 .164 r

F

.3531 .64301 m .35299 .65316 L .35211 .64065 L .797 .663 .112 r

F

.35299 .65316 m .35272 .67613 L .35211 .64065 L F

.36209 .58508 m .35211 .64065 L .35339 .6394 L 0 0 .164 r

F

.35346 .64387 m .35395 .64502 L .35652 .65136 L .659 .323 0 r

F

.35211 .64065 m .35652 .65136 L .36315 .66799 L F

.35346 .64387 m .35652 .65136 L .35211 .64065 L F

.3545 .64017 m .35675 .64657 L .35515 .64601 L .971 .756 .325 r

F

.35675 .64657 m .36283 .66379 L .35515 .64601 L F

.35423 .64569 m .35675 .64657 L .35652 .65136 L .925 .597 .138 r

F

.35652 .65136 m .35675 .64657 L .37185 .66961 L F

.36283 .66379 m .37729 .68537 L .37578 .72077 L .992 .745 .44 r

F

.35652 .65136 m .37185 .66961 L .37121 .68776 L .925 .597 .138 r

F

.36315 .66799 m .35652 .65136 L .37121 .68776 L .659 .323 0 r

F

.3535 .63929 m .35211 .64065 L .36315 .66799 L 0 .057 .621 r

F

.35675 .64657 m .36353 .64891 L .37185 .66961 L .925 .597 .138 r

F

.35562 .63722 m .3535 .63929 L .36315 .66799 L 0 .057 .621 r

F

.36209 .58508 m .35339 .6394 L .36033 .6217 L 0 0 .164 r

F

.35339 .6394 m .35162 .65043 L .35562 .63722 L F

.35339 .6394 m .35562 .63722 L .36033 .6217 L F

.34906 .60649 m .34804 .63057 L .35562 .63722 L 0 .057 .621 r

F

.35978 .63317 m .35562 .63722 L .36455 .64505 L F

.36033 .6217 m .35562 .63722 L .35825 .63467 L 0 0 .164 r

F

.36353 .64891 m .37877 .65063 L .37185 .66961 L .984 .705 .393 r

F

.36455 .64505 m .35562 .63722 L .36315 .66799 L 0 .057 .621 r

F

.35272 .67613 m .36117 .69946 L .35947 .7358 L .971 .756 .325 r

F

.35272 .67613 m .35947 .7358 L .35092 .71279 L F

.35162 .65043 m .35272 .67613 L .35092 .71279 L .797 .663 .112 r

F

.35162 .65043 m .35092 .71279 L .34977 .68742 L F

.35978 .63317 m .34977 .68742 L .35854 .65905 L 0 0 .164 r

F

.36033 .6217 m .35752 .63921 L .35978 .63317 L F

.35752 .63921 m .34977 .68742 L .35978 .63317 L F

.36447 .62878 m .37877 .65063 L .36918 .64955 L .992 .745 .44 r

F

.36608 .59442 m .37877 .65063 L .36447 .62878 L F

.37754 .59569 m .40997 .61025 L .39147 .63086 L .931 .736 .618 r

F

.40241 .57074 m .42635 .62203 L .4012 .60344 L .919 .659 .53 r

F

.37754 .59569 m .39634 .5754 L .40997 .61025 L .931 .736 .618 r

F

.3849 .58838 m .36033 .6217 L .35978 .63317 L .009 0 .368 r

F

.37703 .62492 m .36589 .63025 L .36455 .64505 L .187 .339 .786 r

F

.3849 .58838 m .35978 .63317 L .37002 .62828 L .009 0 .368 r

F

.36589 .63025 m .35978 .63317 L .36455 .64505 L .187 .339 .786 r

F

.36748 .61261 m .35978 .63317 L .36589 .63025 L F

.37185 .66961 m .37556 .67246 L .37581 .67944 L .984 .705 .393 r

F

.37556 .67246 m .39279 .68571 L .37581 .67944 L F

.37581 .67944 m .39279 .68571 L .38613 .70509 L F

.37185 .66961 m .37877 .65063 L .39279 .68571 L F

.37121 .68776 m .37185 .66961 L .38613 .70509 L .925 .597 .138 r

F

.36455 .64505 m .36315 .66799 L .37983 .68308 L 0 .057 .621 r

F

.37877 .65063 m .39741 .70511 L .38897 .69683 L .962 .704 .498 r

F

.39279 .68571 m .4188 .69989 L .40664 .72035 L .967 .735 .535 r

F

.37877 .65063 m .3987 .67061 L .39741 .70511 L .962 .704 .498 r

F

.39733 .65666 m .36455 .64505 L .37983 .68308 L .187 .339 .786 r

F

.3849 .58838 m .37002 .62828 L .38351 .62183 L .009 0 .368 r

F

.38351 .62183 m .36455 .64505 L .39733 .65666 L .187 .339 .786 r

F

.38173 .61735 m .37969 .62063 L .38351 .62183 L F

.37969 .62063 m .36455 .64505 L .38351 .62183 L F

.42925 .52618 m .45991 .54337 L .45923 .5746 L .874 .617 .548 r

F

.4283 .55758 m .45923 .5746 L .45854 .60638 L F

.42925 .52618 m .45923 .5746 L .4283 .55758 L F

.4283 .55758 m .45854 .60638 L .42734 .58952 L F

.40361 .53861 m .4283 .55758 L .42734 .58952 L .919 .659 .53 r

F

.40241 .57074 m .42734 .58952 L .42635 .62203 L F

.40361 .53861 m .42734 .58952 L .40241 .57074 L F

.45991 .54337 m .49814 .58936 L .45923 .5746 L .828 .577 .559 r

F

.40478 .50704 m .42925 .52618 L .4283 .55758 L .919 .659 .53 r

F

.40478 .50704 m .4283 .55758 L .40361 .53861 L F

.42164 .55399 m .46817 .56537 L .43496 .58857 L .852 .714 .71 r

F

.43019 .49532 m .46057 .51265 L .45991 .54337 L .874 .617 .548 r

F

.43019 .49532 m .45991 .54337 L .42925 .52618 L F

.42164 .55399 m .45519 .53101 L .46817 .56537 L .852 .714 .71 r

F

.39634 .5754 m .43496 .58857 L .40997 .61025 L .892 .728 .671 r

F

.38445 .51778 m .40361 .53861 L .40241 .57074 L .962 .704 .498 r

F

.39634 .5754 m .42164 .55399 L .43496 .58857 L .892 .728 .671 r

F

.45256 .54393 m .3849 .58838 L .38351 .62183 L .338 .155 .48 r

F

.45923 .5746 m .49814 .58936 L .49779 .62099 L .828 .577 .559 r

F

.45923 .5746 m .49779 .62099 L .45854 .60638 L F

.44811 .62272 m .48099 .59932 L .49365 .63285 L .852 .714 .71 r

F

.43496 .58857 m .48099 .59932 L .44811 .62272 L F

.40997 .61025 m .44811 .62272 L .42344 .64467 L .892 .728 .671 r

F

.40997 .61025 m .43496 .58857 L .44811 .62272 L F

.39147 .63086 m .40997 .61025 L .42344 .64467 L .931 .736 .618 r

F

.45848 .61921 m .39645 .6177 L .39733 .65666 L .458 .516 .83 r

F

.45256 .54393 m .38351 .62183 L .38823 .62032 L .338 .155 .48 r

F

.39645 .6177 m .38351 .62183 L .39733 .65666 L .458 .516 .83 r

F

.43496 .58857 m .46817 .56537 L .48099 .59932 L .852 .714 .71 r

F

.45256 .54393 m .38823 .62032 L .45165 .58221 L .338 .155 .48 r

F

.38823 .62032 m .38333 .62614 L .39645 .6177 L F

.38823 .62032 m .39645 .6177 L .45165 .58221 L F

.44278 .57821 m .38173 .61735 L .39645 .6177 L .458 .516 .83 r

F

.45122 .60025 m .39645 .6177 L .45848 .61921 L F

.45165 .58221 m .38333 .62614 L .38172 .66468 L .338 .155 .48 r

F

.45165 .58221 m .38172 .66468 L .38655 .66164 L F

.45122 .60025 m .38655 .66164 L .45072 .62131 L F

.45165 .58221 m .38655 .66164 L .45122 .60025 L F

.45122 .60025 m .46858 .61696 L .45848 .61921 L .646 .627 .817 r

F

.43674 .67866 m .47395 .6898 L .44987 .71225 L .892 .728 .671 r

F

.42535 .65511 m .45712 .6716 L .45639 .70508 L .874 .617 .548 r

F

.4188 .69989 m .43674 .67866 L .44987 .71225 L .931 .736 .618 r

F

.42535 .65511 m .45639 .70508 L .42433 .68878 L .874 .617 .548 r

F

.45848 .61921 m .39733 .65666 L .47396 .65961 L .458 .516 .83 r

F

.45848 .61921 m .484 .65743 L .47396 .65961 L .646 .627 .817 r

F

.45848 .61921 m .46858 .61696 L .484 .65743 L F

.45122 .60025 m .4609 .61904 L .45072 .62131 L .571 .339 .525 r

F

.45165 .58221 m .45592 .5992 L .45122 .60025 L F

.45664 .59903 m .46858 .61696 L .45122 .60025 L .646 .627 .817 r

F

.45592 .5992 m .4609 .61904 L .45122 .60025 L .571 .339 .525 r

F

.45165 .58221 m .46172 .57992 L .46134 .59798 L F

.45664 .59903 m .46134 .59798 L .46858 .61696 L .646 .627 .817 r

F

.45592 .5992 m .46134 .59798 L .4609 .61904 L .571 .339 .525 r

F

.45165 .58221 m .46134 .59798 L .45592 .5992 L F

.45256 .54393 m .46172 .57992 L .45165 .58221 L F

.44278 .57821 m .45293 .57589 L .46134 .59798 L .646 .627 .817 r

F

.44278 .57821 m .46134 .59798 L .45664 .59903 L F

.45504 .59663 m .45664 .59903 L .45122 .60025 L F

.44278 .57821 m .45504 .59663 L .45122 .60025 L F

.44278 .57821 m .39645 .6177 L .45122 .60025 L .458 .516 .83 r

F

.39645 .6177 m .38173 .61735 L .38351 .62183 L F

.38823 .62032 m .38351 .62183 L .38624 .62268 L .338 .155 .48 r

F

.38624 .62268 m .38351 .62183 L .38333 .62614 L F

.38351 .62183 m .35854 .65905 L .38333 .62614 L .009 0 .368 r

F

.37002 .62828 m .35854 .65905 L .38351 .62183 L F

.37002 .62828 m .35978 .63317 L .35854 .65905 L F

.38173 .61735 m .36748 .61261 L .36589 .63025 L .187 .339 .786 r

F

.38173 .61735 m .36589 .63025 L .37703 .62492 L F

.35962 .53627 m .36608 .59442 L .35794 .57026 L .971 .756 .325 r

F

.35866 .50941 m .35962 .53627 L .35794 .57026 L .797 .663 .112 r

F

.35866 .50941 m .35794 .57026 L .35695 .54367 L F

.36381 .54917 m .35521 .57858 L .35343 .61416 L 0 0 .164 r

F

.36381 .54917 m .35343 .61416 L .36209 .58508 L F

.38645 .55138 m .36209 .58508 L .36033 .6217 L .009 0 .368 r

F

.38645 .55138 m .36033 .6217 L .3849 .58838 L F

.36748 .61261 m .34906 .60649 L .35978 .63317 L .187 .339 .786 r

F

.34906 .60649 m .35562 .63722 L .35978 .63317 L 0 .057 .621 r

F

.35162 .63371 m .35211 .64065 L .3535 .63929 L F

.35825 .63467 m .35162 .65043 L .34977 .68742 L 0 0 .164 r

F

.35562 .63722 m .35162 .65043 L .35825 .63467 L F

.35339 .6394 m .35211 .64065 L .35288 .64259 L F

.35562 .63722 m .35162 .63371 L .3535 .63929 L 0 .057 .621 r

F

.35162 .63371 m .34804 .63057 L .35211 .64065 L F

.35288 .64259 m .35211 .64065 L .35162 .65043 L 0 0 .164 r

F

.38897 .69683 m .39741 .70511 L .39646 .73077 L .962 .704 .498 r

F

.39741 .70511 m .42224 .75797 L .40019 .74302 L .919 .659 .53 r

F

.39741 .70511 m .40019 .74302 L .39646 .73077 L F

.40529 .75977 m .42116 .79351 L .41415 .78887 L F

.40529 .75977 m .42224 .75797 L .42116 .79351 L F

.40019 .74302 m .42224 .75797 L .40529 .75977 L F

.41415 .78887 m .42116 .79351 L .42065 .81023 L F

.42116 .79351 m .45334 .84514 L .43044 .83452 L .874 .617 .548 r

F

.42116 .79351 m .43044 .83452 L .42065 .81023 L F

.43044 .83452 m .45334 .84514 L .44385 .86784 L F

.45319 .86565 m .43572 .84776 L .44968 .88232 L 0 .057 .621 r

F

.47254 .88099 m .58007 .85179 L .59549 .87117 L .623 .782 .957 r

F

.45854 .80027 m .48833 .81058 L .47147 .83292 L .931 .736 .618 r

F

.44714 .8217 m .45854 .80027 L .47147 .83292 L .967 .735 .535 r

F

.45413 .80917 m .49514 .85849 L .45334 .84514 L .828 .577 .559 r

F

.47213 .84521 m .45319 .86565 L .47363 .87531 L .187 .339 .786 r

F

.47213 .84521 m .47363 .87531 L .47702 .85755 L F

.39063 .88753 m .47431 .87174 L .47254 .88099 L .623 .782 .957 r

F

.47431 .87174 m .58007 .85179 L .47254 .88099 L F

.54497 .84876 m .63934 .82041 L .56819 .83402 L .499 .144 .296 r

F

.49554 .82273 m .55032 .84537 L .53711 .85776 L .779 .535 .566 r

F

.39342 .81251 m .42006 .82972 L .41895 .8666 L .919 .659 .53 r

F

.43891 .83012 m .43572 .84776 L .45319 .86565 L 0 .057 .621 r

F

.39342 .81251 m .41895 .8666 L .39204 .84966 L .919 .659 .53 r

F

.37107 .83103 m .39204 .84966 L .39063 .88753 L .962 .704 .498 r

F

.43381 .78834 m .45854 .80027 L .44714 .8217 L .967 .735 .535 r

F

.42116 .79351 m .45413 .80917 L .45334 .84514 L .874 .617 .548 r

F

.47213 .84521 m .43891 .83012 L .45319 .86565 L .187 .339 .786 r

F

.37107 .83103 m .39063 .88753 L .36944 .8692 L .962 .704 .498 r

F

.36944 .8692 m .47436 .86053 L .39063 .88753 L .623 .782 .957 r

F

.47436 .86053 m .58007 .85179 L .4623 .87401 L F

.47436 .86053 m .4623 .87401 L .39063 .88753 L F

.45413 .80917 m .49554 .82273 L .49514 .85849 L .828 .577 .559 r

F

.48671 .84673 m .47213 .84521 L .47702 .85755 L .458 .516 .83 r

F

.47436 .86053 m .56423 .83187 L .58007 .85179 L .623 .782 .957 r

F

.36944 .8692 m .48671 .84673 L .47436 .86053 L F

.48671 .84673 m .56423 .83187 L .47436 .86053 L F

.47567 .7782 m .51155 .78743 L .48833 .81058 L .892 .728 .671 r

F

.49593 .7876 m .55019 .79837 L .55029 .83334 L .779 .535 .566 r

F

.49593 .7876 m .55029 .83334 L .49554 .82273 L F

.50018 .83167 m .47213 .84521 L .48671 .84673 L .458 .516 .83 r

F

.42159 .81275 m .42811 .82869 L .43572 .84776 L .659 .323 0 r

F

.43891 .83012 m .42159 .81275 L .43572 .84776 L 0 .057 .621 r

F

.37267 .79357 m .39342 .81251 L .39204 .84966 L .962 .704 .498 r

F

.37267 .79357 m .39204 .84966 L .37107 .83103 L F

.45854 .80027 m .47567 .7782 L .48833 .81058 L .931 .736 .618 r

F

.44546 .76722 m .47567 .7782 L .45854 .80027 L F

.43381 .78834 m .44546 .76722 L .45854 .80027 L .967 .735 .535 r

F

.45489 .77385 m .49554 .82273 L .45413 .80917 L .828 .577 .559 r

F

.45758 .80853 m .43891 .83012 L .47213 .84521 L .187 .339 .786 r

F

.35597 .81062 m .37107 .83103 L .36944 .8692 L .992 .745 .44 r

F

.35597 .81062 m .36944 .8692 L .35417 .84913 L F

.50018 .83167 m .45758 .80853 L .47213 .84521 L .458 .516 .83 r

F

.35417 .84913 m .49491 .83757 L .36944 .8692 L .623 .782 .957 r

F

.49491 .83757 m .56423 .83187 L .48671 .84673 L F

.49491 .83757 m .48671 .84673 L .36944 .8692 L F

.45489 .77385 m .49593 .7876 L .49554 .82273 L .828 .577 .559 r

F

.51608 .8139 m .45758 .80853 L .50018 .83167 L .458 .516 .83 r

F

.49491 .83757 m .54794 .8114 L .56423 .83187 L .623 .782 .957 r

F

.35417 .84913 m .51207 .81838 L .49491 .83757 L F

.51207 .81838 m .54794 .8114 L .49491 .83757 L F

.49917 .75527 m .54283 .76307 L .51155 .78743 L .852 .714 .71 r

F

.47567 .7782 m .49917 .75527 L .51155 .78743 L .892 .728 .671 r

F

.46285 .74542 m .49917 .75527 L .47567 .7782 L F

.46285 .74542 m .48663 .72273 L .49917 .75527 L F

.49631 .7531 m .55019 .79837 L .49593 .7876 L .779 .535 .566 r

F

.51907 .77737 m .45758 .80853 L .51608 .8139 L .458 .516 .83 r

F

.51907 .77737 m .51608 .8139 L .52797 .80061 L F

.39477 .77604 m .42006 .82972 L .39342 .81251 L .919 .659 .53 r

F

.42224 .75797 m .45413 .80917 L .42116 .79351 L .874 .617 .548 r

F

.42444 .7941 m .42159 .81275 L .43891 .83012 L 0 .057 .621 r

F

.35773 .77285 m .37267 .79357 L .37107 .83103 L .992 .745 .44 r

F

.42224 .75797 m .45489 .77385 L .45413 .80917 L .874 .617 .548 r

F

.45758 .80853 m .42444 .7941 L .43891 .83012 L .187 .339 .786 r

F

.35773 .77285 m .37107 .83103 L .35597 .81062 L .992 .745 .44 r

F

.3472 .78827 m .35597 .81062 L .35417 .84913 L .971 .756 .325 r

F

.3472 .78827 m .35417 .84913 L .34528 .82714 L F

.34528 .82714 m .54794 .8114 L .35417 .84913 L .623 .782 .957 r

F

.40727 .77728 m .41416 .79414 L .42159 .81275 L .659 .323 0 r

F

.40727 .77728 m .40003 .75914 L .41416 .79414 L F

.42444 .7941 m .40727 .77728 L .42159 .81275 L 0 .057 .621 r

F

.44283 .77135 m .42444 .7941 L .45758 .80853 L .187 .339 .786 r

F

.44546 .76722 m .46285 .74542 L .47567 .7782 L .931 .736 .618 r

F

.44987 .71225 m .48663 .72273 L .46285 .74542 L .892 .728 .671 r

F

.43221 .73377 m .46285 .74542 L .44546 .76722 L .931 .736 .618 r

F

.43221 .73377 m .44987 .71225 L .46285 .74542 L F

.45565 .73916 m .49631 .7531 L .49593 .7876 L .828 .577 .559 r

F

.45565 .73916 m .49593 .7876 L .45489 .77385 L F

.4188 .69989 m .44987 .71225 L .43221 .73377 L .931 .736 .618 r

F

.40664 .72035 m .4188 .69989 L .43221 .73377 L .967 .735 .535 r

F

.42329 .72306 m .45565 .73916 L .45489 .77385 L .874 .617 .548 r

F

.42329 .72306 m .45489 .77385 L .42224 .75797 L F

.51907 .77737 m .44283 .77135 L .45758 .80853 L .458 .516 .83 r

F

.51907 .77737 m .53395 .79943 L .52797 .80061 L .646 .627 .817 r

F

.42427 .82101 m .53782 .79867 L .54794 .8114 L .623 .782 .957 r

F

.53075 .73109 m .58668 .7365 L .54283 .76307 L .809 .696 .74 r

F

.49917 .75527 m .53075 .73109 L .54283 .76307 L .852 .714 .71 r

F

.48663 .72273 m .53075 .73109 L .49917 .75527 L F

.49631 .7531 m .55009 .76402 L .55019 .79837 L .779 .535 .566 r

F

.51907 .77737 m .52895 .77539 L .54351 .8136 L .646 .627 .817 r

F

.34528 .82714 m .5312 .79034 L .53782 .79867 L .623 .782 .957 r

F

.34528 .82714 m .53782 .79867 L .42427 .82101 L F

.52797 .80061 m .54351 .8136 L .53368 .81551 L .646 .627 .817 r

F

.53395 .79943 m .54351 .8136 L .52797 .80061 L F

.52797 .80061 m .51608 .8139 L .53368 .81551 L .458 .516 .83 r

F

.53368 .81551 m .51608 .8139 L .50018 .83167 L F

.53368 .81551 m .50018 .83167 L .54808 .85312 L F

.50018 .83167 m .48671 .84673 L .54808 .85312 L F

.54808 .85312 m .48671 .84673 L .48648 .88138 L F

.48671 .84673 m .47702 .85755 L .48648 .88138 L F

.47702 .85755 m .47363 .87531 L .48648 .88138 L .187 .339 .786 r

F

.48648 .88138 m .47363 .87531 L .46912 .89887 L F

.48648 .88138 m .46912 .89887 L .50063 .91707 L F

.46912 .89887 m .46728 .90072 L .46864 .90139 L F

.46912 .89887 m .46864 .90139 L .50063 .91707 L F

.41781 .90418 m .46995 .8945 L .46882 .90044 L .623 .782 .957 r

F

.41781 .90418 m .46882 .90044 L .45174 .9191 L F

.46882 .90044 m .46574 .91654 L .45174 .9191 L F

.50063 .91707 m .46864 .90139 L .48119 .93534 L .187 .339 .786 r

F

.46864 .90139 m .46828 .90322 L .48119 .93534 L F

.46828 .90322 m .4716 .92512 L .48119 .93534 L 0 .057 .621 r

F

.56819 .83402 m .63934 .82041 L .60307 .81188 L .499 .144 .296 r

F

.60307 .81188 m .6453 .79922 L .6132 .80544 L F

.6132 .80544 m .6453 .79922 L .65015 .78199 L F

.64357 .78766 m .64884 .78663 L .64826 .76584 L .605 .395 .57 r

F

.55009 .76402 m .63962 .76755 L .64016 .78833 L .713 .48 .571 r

F

.55009 .76402 m .64016 .78833 L .62746 .79639 L F

.64016 .78833 m .64826 .76584 L .63962 .76755 L .605 .395 .57 r

F

.64357 .78766 m .64826 .76584 L .64016 .78833 L F

.5952 .50577 m .59162 .46946 L .58315 .47147 L .66 .619 .797 r

F

.5952 .50577 m .60363 .50381 L .59162 .46946 L F

.50165 .50529 m .5952 .50577 L .51424 .53951 L .752 .669 .769 r

F

.50165 .50529 m .58315 .47147 L .5952 .50577 L F

.53075 .73109 m .57496 .70463 L .58668 .7365 L .809 .696 .74 r

F

.51853 .69873 m .57496 .70463 L .53075 .73109 L F

.54991 .69709 m .6379 .70071 L .63875 .73384 L .713 .48 .571 r

F

.63875 .73384 m .64638 .69896 L .6379 .70071 L .605 .395 .57 r

F

.63875 .73384 m .64731 .73211 L .64638 .69896 L F

.54991 .69709 m .63875 .73384 L .55 .73026 L .713 .48 .571 r

F

.48891 .47065 m .58315 .47147 L .50165 .50529 L .752 .669 .769 r

F

.63962 .76755 m .64731 .73211 L .63875 .73384 L .605 .395 .57 r

F

.55 .73026 m .63875 .73384 L .63962 .76755 L .713 .48 .571 r

F

.63962 .76755 m .64826 .76584 L .64731 .73211 L .605 .395 .57 r

F

.55 .73026 m .63962 .76755 L .55009 .76402 L .713 .48 .571 r

F

.64142 .83678 m .65021 .83511 L .64923 .80017 L .605 .395 .57 r

F

.64233 .87232 m .65021 .83511 L .64142 .83678 L F

.64233 .87232 m .65121 .87069 L .65021 .83511 L F

.64327 .90852 m .65121 .87069 L .64233 .87232 L F

.64327 .90852 m .65223 .90691 L .65121 .87069 L F

.64422 .94537 m .65223 .90691 L .64327 .90852 L F

.64422 .94537 m .65326 .94379 L .65223 .90691 L F

.39646 .31172 m .48496 .28824 L .46842 .26157 L .663 .742 .909 r

F

.46842 .26157 m .64195 .54144 L .65326 .94379 L .988 .721 .406 r

F

0 g

.57555 .07551 m

.66104 .23989 L

s

.50665 1.10204 m

.50734 1.01402 L

s

.50956 .72708 m

.50979 .69698 L

s

.24315 .17187 m

.35662 .33403 L

s

.35662 .33403 m

.35999 .33885 L

s

.35999 .33885 m

.37144 .35521 L

s

.48958 .52405 m

.49872 .53712 L

s

.66457 .70322 m .66159 .66954 L .65334 .67127 L .66 .619 .797 r

F

.66457 .70322 m .67278 .70153 L .66159 .66954 L F

0 g

.66457 .70322 m

.66457 .70322 L

s

.64671 .71085 m

.66457 .70322 L

s

.46057 .51265 m .49882 .52769 L .49848 .55827 L .828 .577 .559 r

F

.45991 .54337 m .49848 .55827 L .49814 .58936 L F

.46057 .51265 m .49848 .55827 L .45991 .54337 L F

.48663 .72273 m .51853 .69873 L .53075 .73109 L .852 .714 .71 r

F

.47395 .6898 m .51853 .69873 L .48663 .72273 L F

.48099 .59932 m .53896 .60674 L .49365 .63285 L .809 .696 .74 r

F

.48099 .59932 m .52667 .57333 L .53896 .60674 L F

.49743 .65316 m .54982 .66449 L .54991 .69709 L .779 .535 .566 r

F

.46817 .56537 m .52667 .57333 L .48099 .59932 L .809 .696 .74 r

F

.46817 .56537 m .51424 .53951 L .52667 .57333 L F

.49743 .65316 m .54991 .69709 L .49706 .6859 L .779 .535 .566 r

F

.49706 .6859 m .54991 .69709 L .55 .73026 L F

.45519 .53101 m .51424 .53951 L .46817 .56537 L .809 .696 .74 r

F

.45519 .53101 m .50165 .50529 L .51424 .53951 L F

.49706 .6859 m .55 .73026 L .49669 .7192 L .779 .535 .566 r

F

.44987 .71225 m .47395 .6898 L .48663 .72273 L .892 .728 .671 r

F

.45712 .6716 m .49706 .6859 L .49669 .7192 L .828 .577 .559 r

F

.44205 .49623 m .50165 .50529 L .45519 .53101 L .809 .696 .74 r

F

.49669 .7192 m .55 .73026 L .55009 .76402 L .779 .535 .566 r

F

.40816 .51898 m .45519 .53101 L .42164 .55399 L .852 .714 .71 r

F

.40816 .51898 m .44205 .49623 L .45519 .53101 L F

.49669 .7192 m .55009 .76402 L .49631 .7531 L .779 .535 .566 r

F

.39451 .48354 m .44205 .49623 L .40816 .51898 L .852 .714 .71 r

F

.55059 .94211 m .65326 .94379 L .64422 .94537 L .623 .782 .957 r

F

.55059 .94211 m .63938 .92634 L .65326 .94379 L F

.5146 .95228 m .61374 .91146 L .48119 .93534 L .499 .144 .296 r

F

.5146 .95228 m .60685 .93594 L .61374 .91146 L F

.59012 .96286 m .60685 .93594 L .5146 .95228 L F

.59012 .96286 m .59975 .96118 L .60685 .93594 L F

.42875 .46101 m .48891 .47065 L .44205 .49623 L .809 .696 .74 r

F

.42875 .46101 m .47602 .43558 L .48891 .47065 L F

.39451 .48354 m .42875 .46101 L .44205 .49623 L .852 .714 .71 r

F

.36856 .50437 m .40816 .51898 L .38254 .54011 L .892 .728 .671 r

F

.36856 .50437 m .39451 .48354 L .40816 .51898 L F

.45518 .4337 m .38796 .51511 L .45432 .46969 L .338 .155 .48 r

F

.38254 .54011 m .42164 .55399 L .39634 .5754 L .892 .728 .671 r

F

.38254 .54011 m .40816 .51898 L .42164 .55399 L F

.45432 .46969 m .38796 .51511 L .38645 .55138 L .338 .155 .48 r

F

.45345 .50643 m .38645 .55138 L .3849 .58838 L F

.44205 .49623 m .48891 .47065 L .50165 .50529 L .809 .696 .74 r

F

.45432 .46969 m .38645 .55138 L .45345 .50643 L .338 .155 .48 r

F

.45345 .50643 m .3849 .58838 L .45256 .54393 L F

.45345 .50643 m .46253 .54161 L .45256 .54393 L .571 .339 .525 r

F

.45345 .50643 m .46332 .50409 L .46253 .54161 L F

.45256 .54393 m .46253 .54161 L .46172 .57992 L F

.42092 .49191 m .67278 .70153 L .59975 .96118 L .988 .721 .406 r

F

0 g

.50734 1.01402 m

.50784 .94885 L

s

.65334 .67127 m .66159 .66954 L .65027 .63717 L .66 .619 .797 r

F

.55861 .40162 m .5547 .36387 L .54611 .36604 L F

.55861 .40162 m .56716 .3995 L .5547 .36387 L F

.54611 .36604 m .54208 .3278 L .53346 .33003 L F

.54611 .36604 m .5547 .36387 L .54208 .3278 L F

.53346 .33003 m .52931 .29128 L .52065 .29357 L F

.53346 .33003 m .54208 .3278 L .52931 .29128 L F

.45518 .4337 m .38945 .47955 L .38796 .51511 L .338 .155 .48 r

F

.45518 .4337 m .46409 .46733 L .45432 .46969 L .571 .339 .525 r

F

.45518 .4337 m .46485 .43131 L .46409 .46733 L F

.45432 .46969 m .46332 .50409 L .45345 .50643 L F

.45432 .46969 m .46409 .46733 L .46332 .50409 L F

.42092 .49191 m .52931 .29128 L .67278 .70153 L .988 .721 .406 r

F

0 g

.58738 .45343 m

.64195 .54144 L

s

.64415 .61967 m

.64884 .78663 L

s

.64404 .61555 m

.64415 .61967 L

s

.64195 .54144 m

.64404 .61555 L

s

.64884 .78663 m

.67278 .70153 L

s

.58425 .44838 m

.64415 .61967 L

s

.64415 .61967 m

.67278 .70153 L

s

.66104 .23989 m

.79123 .49021 L

s

.58425 .44838 m

.58738 .45343 L

s

.45712 .6716 m .49669 .7192 L .45639 .70508 L .828 .577 .559 r

F

.45639 .70508 m .49669 .7192 L .49631 .7531 L F

.45639 .70508 m .49631 .7531 L .45565 .73916 L F

.42433 .68878 m .45639 .70508 L .45565 .73916 L .874 .617 .548 r

F

0 g

.50665 1.10204 m

.83047 1.051 L

s

.35261 .95141 m

.3654 .96392 L

s

.3654 .96392 m

.40329 1.00097 L

s

.40329 1.00097 m

.50665 1.10204 L

s

.42433 .68878 m .45565 .73916 L .42329 .72306 L .874 .617 .548 r

F

.52065 .29357 m .52931 .29128 L .52169 .3054 L .347 0 .059 r

F

0 g

.52065 .29357 m

.52065 .29357 L

s

.52931 .29128 m

.58425 .44838 L

s

.49477 .30406 m

.52065 .29357 L

s

.3987 .67061 m .42433 .68878 L .42329 .72306 L .919 .659 .53 r

F

0 0 0 r

.01 w

[ .015 ] 0 setdash

.24643 .67983 m

.33105 .66116 L

s

.33105 .66116 m

.35131 .65669 L

s

0 g

.5 Mabswid

[ ] 0 setdash

.64323 .90675 m

.64327 .90852 L

s

.39741 .70511 m .42329 .72306 L .42224 .75797 L .919 .659 .53 r

F

.3987 .67061 m .42329 .72306 L .39741 .70511 L F

0 g

.369 .36432 m

.37348 .34758 L

s

.3525 .37449 m

.369 .36432 L

s

.64327 .90852 m

.64388 .932 L

s

.32003 .45044 m .35441 .46818 L .33469 .48746 L .931 .736 .618 r

F

0 g

.32555 .3944 m

.3525 .37449 L

s

.36034 .4758 m .36126 .50291 L .35962 .53627 L .797 .663 .112 r

F

0 g

.64422 .94537 m

.64422 .94537 L

s

.60459 .94399 m

.64422 .94537 L

s

.50424 .73868 m .44283 .77135 L .51907 .77737 L .458 .516 .83 r

F

.50424 .73868 m .42787 .73366 L .44283 .77135 L F

.48921 .69943 m .42787 .73366 L .50424 .73868 L F

.48921 .69943 m .41271 .69543 L .42787 .73366 L F

.47396 .65961 m .41271 .69543 L .48921 .69943 L F

.47396 .65961 m .39733 .65666 L .41271 .69543 L F

.50424 .73868 m .52895 .77539 L .51907 .77737 L .646 .627 .817 r

F

.50424 .73868 m .51418 .73663 L .52895 .77539 L F

.48921 .69943 m .51418 .73663 L .50424 .73868 L F

.48921 .69943 m .4992 .69732 L .51418 .73663 L F

.47396 .65961 m .4992 .69732 L .48921 .69943 L F

.47396 .65961 m .484 .65743 L .4992 .69732 L F

.46842 .26157 m .65326 .94379 L .4592 .69983 L .988 .721 .406 r

F

0 g

.61734 .89864 m

.65326 .94379 L

s

.534 .79387 m

.53782 .79867 L

s

0 0 0 r

.01 w

[ .015 ] 0 setdash

.56283 .61002 m

.85654 .54521 L

s

0 g

.5 Mabswid

[ ] 0 setdash

.50954 .32789 m

.52931 .29128 L

s

.46316 .41373 m

.4653 .40977 L

s

.50954 .32789 m

.58425 .44838 L

s

.64884 .78663 m

.65326 .94379 L

s

.61734 .89864 m

.64884 .78663 L

s

.32086 .5057 m .34916 .524 L .33562 .54264 L .967 .735 .535 r

F

.32086 .5057 m .33469 .48746 L .34916 .524 L F

.37121 .68776 m .38613 .70509 L .38571 .72369 L .925 .597 .138 r

F

.36034 .4758 m .35962 .53627 L .35866 .50941 L .797 .663 .112 r

F

0 g

.30519 .41294 m

.32555 .3944 L

s

.45174 .9191 m

.46451 .92297 L

s

.46451 .92297 m

.4716 .92512 L

s

.3059 .46828 m .33469 .48746 L .32086 .5057 L .967 .735 .535 r

F

.3059 .46828 m .32003 .45044 L .33469 .48746 L F

0 g

.75088 .94076 m

.83047 1.051 L

s

.32791 .56036 m .35019 .5791 L .34275 .59725 L .984 .705 .393 r

F

.32791 .56036 m .33562 .54264 L .35019 .5791 L F

.36878 .44552 m .36034 .4758 L .35866 .50941 L 0 0 .164 r

F

.37424 .75683 m .39477 .77604 L .39342 .81251 L .962 .704 .498 r

F

.37578 .72077 m .39477 .77604 L .37424 .75683 L F

.39276 .74133 m .40003 .75914 L .40727 .77728 L .659 .323 0 r

F

.39276 .74133 m .38571 .72369 L .40003 .75914 L F

.36117 .69946 m .37578 .72077 L .37424 .75683 L .992 .745 .44 r

F

.31287 .52297 m .33562 .54264 L .32791 .56036 L .984 .705 .393 r

F

.31287 .52297 m .32086 .5057 L .33562 .54264 L F

0 g

.41781 .90418 m

.45174 .9191 L

s

.39646 .31172 m .46842 .26157 L .45921 .26405 L .663 .742 .909 r

F

.45921 .26405 m .39646 .31172 L .39511 .34402 L .338 .155 .48 r

F

0 g

.37348 .34758 m

.39646 .31172 L

s

.36715 .47941 m .35866 .50941 L .35695 .54367 L 0 0 .164 r

F

.36878 .44552 m .35866 .50941 L .36715 .47941 L F

.37805 .7049 m .38571 .72369 L .39276 .74133 L .659 .323 0 r

F

.37805 .7049 m .37121 .68776 L .38571 .72369 L F

.37424 .75683 m .39342 .81251 L .37267 .79357 L .962 .704 .498 r

F

0 g

.29075 .43035 m

.30519 .41294 L

s

.29763 .48509 m .32086 .5057 L .31287 .52297 L .984 .705 .393 r

F

.29763 .48509 m .3059 .46828 L .32086 .5057 L F

.50063 .91707 m .48119 .93534 L .5146 .95228 L .187 .339 .786 r

F

0 g

.4716 .92512 m

.48119 .93534 L

s

.32653 .5771 m .34275 .59725 L .34163 .61448 L .925 .597 .138 r

F

.32653 .5771 m .32791 .56036 L .34275 .59725 L F

.35947 .7358 m .37424 .75683 L .37267 .79357 L .992 .745 .44 r

F

.36117 .69946 m .37424 .75683 L .35947 .7358 L F

0 g

.24315 .17187 m

.57555 .07551 L

s

.18738 .78984 m

.24315 .17187 L

s

.45843 .29666 m .39511 .34402 L .39373 .37693 L .338 .155 .48 r

F

.45921 .26405 m .39511 .34402 L .45843 .29666 L F

.36315 .66799 m .37121 .68776 L .37805 .7049 L .659 .323 0 r

F

0 g

.39063 .88753 m

.41781 .90418 L

s

.28218 .44669 m .3059 .46828 L .29763 .48509 L .984 .705 .393 r

F

.3655 .51396 m .35695 .54367 L .35521 .57858 L 0 0 .164 r

F

.36715 .47941 m .35695 .54367 L .3655 .51396 L F

.31124 .53921 m .32791 .56036 L .32653 .5771 L .925 .597 .138 r

F

.31124 .53921 m .31287 .52297 L .32791 .56036 L F

.40977 .75759 m .40727 .77728 L .42444 .7941 L 0 .057 .621 r

F

.40977 .75759 m .39276 .74133 L .40727 .77728 L F

.35947 .7358 m .37267 .79357 L .35773 .77285 L .992 .745 .44 r

F

.45843 .29666 m .39373 .37693 L .45764 .32992 L .338 .155 .48 r

F

.39091 .44468 m .36715 .47941 L .3655 .51396 L .009 0 .368 r

F

.29574 .50081 m .31287 .52297 L .31124 .53921 L .925 .597 .138 r

F

.29574 .50081 m .29763 .48509 L .31287 .52297 L F

.3949 .72059 m .39276 .74133 L .40977 .75759 L 0 .057 .621 r

F

.3949 .72059 m .37805 .7049 L .39276 .74133 L F

.35092 .71279 m .35947 .7358 L .35773 .77285 L .971 .756 .325 r

F

.3655 .51396 m .35521 .57858 L .36381 .54917 L 0 0 .164 r

F

0 g

.36944 .8692 m

.39063 .88753 L

s

.33273 .59264 m .34163 .61448 L .34804 .63057 L .659 .323 0 r

F

.33273 .59264 m .32653 .5771 L .34163 .61448 L F

.45921 .26405 m .46773 .2942 L .45843 .29666 L .571 .339 .525 r

F

.45921 .26405 m .46842 .26157 L .46773 .2942 L F

0 g

.39646 .31172 m

.45921 .26405 L

s

.45921 .26405 m

.45921 .26405 L

s

.46842 .26157 m

.50954 .32789 L

s

.5763 .92678 m .5146 .95228 L .59012 .96286 L .458 .516 .83 r

F

0 g

.58274 .70787 m

.70397 .87579 L

s

.70397 .87579 m

.75088 .94076 L

s

.5763 .92678 m .50063 .91707 L .5146 .95228 L .458 .516 .83 r

F

0 g

.48119 .93534 m

.5146 .95228 L

s

.28002 .46188 m .29763 .48509 L .29574 .50081 L .925 .597 .138 r

F

.28002 .46188 m .28218 .44669 L .29763 .48509 L F

.37983 .68308 m .37805 .7049 L .3949 .72059 L 0 .057 .621 r

F

.37983 .68308 m .36315 .66799 L .37805 .7049 L F

.38945 .47955 m .3655 .51396 L .36381 .54917 L .009 0 .368 r

F

.39091 .44468 m .3655 .51396 L .38945 .47955 L F

.3172 .55419 m .32653 .5771 L .33273 .59264 L .659 .323 0 r

F

.3172 .55419 m .31124 .53921 L .32653 .5771 L F

.34908 .75016 m .35773 .77285 L .35597 .81062 L .971 .756 .325 r

F

.35092 .71279 m .35773 .77285 L .34908 .75016 L F

.44283 .77135 m .40977 .75759 L .42444 .7941 L .187 .339 .786 r

F

.56229 .89021 m .50063 .91707 L .5763 .92678 L .458 .516 .83 r

F

.56229 .89021 m .48648 .88138 L .50063 .91707 L F

.28218 .44669 m .46158 .41665 L .28002 .46188 L .347 0 .059 r

F

0 g

.28218 .44669 m

.29075 .43035 L

s

.45843 .29666 m .46703 .32747 L .45764 .32992 L .571 .339 .525 r

F

.45843 .29666 m .46773 .2942 L .46703 .32747 L F

0 g

.45843 .29666 m

.45921 .26405 L

s

.34977 .68742 m .35092 .71279 L .34908 .75016 L .797 .663 .112 r

F

0 g

.35417 .84913 m

.36944 .8692 L

s

.30146 .51521 m .31124 .53921 L .3172 .55419 L .659 .323 0 r

F

.30146 .51521 m .29574 .50081 L .31124 .53921 L F

.38796 .51511 m .36381 .54917 L .36209 .58508 L .009 0 .368 r

F

.38945 .47955 m .36381 .54917 L .38796 .51511 L F

.42787 .73366 m .40977 .75759 L .44283 .77135 L .187 .339 .786 r

F

.42787 .73366 m .3949 .72059 L .40977 .75759 L F

.54808 .85312 m .48648 .88138 L .56229 .89021 L .458 .516 .83 r

F

.34908 .75016 m .35597 .81062 L .3472 .78827 L .971 .756 .325 r

F

.34906 .60649 m .33273 .59264 L .34804 .63057 L 0 .057 .621 r

F

.28551 .47568 m .29574 .50081 L .30146 .51521 L .659 .323 0 r

F

.28551 .47568 m .28002 .46188 L .29574 .50081 L F

.45764 .32992 m .46632 .3614 L .45684 .36383 L .571 .339 .525 r

F

.45764 .32992 m .46703 .32747 L .46632 .3614 L F

0 g

.45764 .32992 m

.45843 .29666 L

s

.34789 .72515 m .34908 .75016 L .3472 .78827 L .797 .663 .112 r

F

.34977 .68742 m .34908 .75016 L .34789 .72515 L F

.41271 .69543 m .3949 .72059 L .42787 .73366 L .187 .339 .786 r

F

.41271 .69543 m .37983 .68308 L .3949 .72059 L F

.33335 .56739 m .33273 .59264 L .34906 .60649 L 0 .057 .621 r

F

.33335 .56739 m .3172 .55419 L .33273 .59264 L F

.38796 .51511 m .36209 .58508 L .38645 .55138 L .009 0 .368 r

F

.28002 .46188 m .4519 .43456 L .28551 .47568 L .347 0 .059 r

F

.28002 .46188 m .46158 .41665 L .4519 .43456 L F

0 g

.28002 .46188 m

.28218 .44669 L

s

.46134 .59798 m

.4653 .40977 L

s

.35854 .65905 m .34977 .68742 L .34789 .72515 L 0 0 .164 r

F

.5763 .92678 m .59975 .96118 L .59012 .96286 L .646 .627 .817 r

F

0 g

.5146 .95228 m

.59012 .96286 L

s

.39733 .65666 m .37983 .68308 L .41271 .69543 L .187 .339 .786 r

F

0 g

.45929 .5926 m

.46134 .59798 L

s

.5763 .92678 m .58598 .92505 L .59975 .96118 L .646 .627 .817 r

F

0 g

.59975 .96118 m

.61734 .89864 L

s

.45684 .36383 m .46559 .396 L .45602 .39841 L .571 .339 .525 r

F

.45684 .36383 m .46632 .3614 L .46559 .396 L F

0 g

.4653 .40977 m

.50954 .32789 L

s

.4653 .40977 m

.46842 .26157 L

s

.45684 .36383 m

.45764 .32992 L

s

.45602 .39841 m

.45684 .36383 L

s

.57555 .07551 m

.58274 .70787 L

s

.31741 .52773 m .3172 .55419 L .33335 .56739 L 0 .057 .621 r

F

.31741 .52773 m .30146 .51521 L .3172 .55419 L F

.34789 .72515 m .3472 .78827 L .34597 .76363 L .797 .663 .112 r

F

.34597 .76363 m .3472 .78827 L .34528 .82714 L F

0 g

.34153 .94058 m

.35261 .95141 L

s

.18738 .78984 m

.34153 .94058 L

s

.56229 .89021 m .58598 .92505 L .5763 .92678 L .646 .627 .817 r

F

0 g

.5763 .92678 m

.59012 .96286 L

s

.56229 .89021 m .57202 .88842 L .58598 .92505 L .646 .627 .817 r

F

.35671 .69716 m .34789 .72515 L .34597 .76363 L 0 0 .164 r

F

.35854 .65905 m .34789 .72515 L .35671 .69716 L F

.30125 .48752 m .30146 .51521 L .31741 .52773 L 0 .057 .621 r

F

.30125 .48752 m .28551 .47568 L .30146 .51521 L F

0 g

.45569 .41217 m

.45602 .39841 L

s

.34597 .76363 m .34528 .82714 L .34401 .80289 L .797 .663 .112 r

F

.34401 .80289 m .5312 .79034 L .34528 .82714 L .623 .782 .957 r

F

0 g

.34528 .82714 m

.35417 .84913 L

s

.54808 .85312 m .57202 .88842 L .56229 .89021 L .646 .627 .817 r

F

0 g

.56229 .89021 m

.5763 .92678 L

s

.36591 .57746 m .34906 .60649 L .38173 .61735 L .187 .339 .786 r

F

.36591 .57746 m .33335 .56739 L .34906 .60649 L F

.54808 .85312 m .55787 .85127 L .57202 .88842 L .646 .627 .817 r

F

.28551 .47568 m .44191 .45306 L .30125 .48752 L .347 0 .059 r

F

.28551 .47568 m .4519 .43456 L .44191 .45306 L F

0 g

.28002 .46188 m

.28551 .47568 L

s

.38333 .62614 m .35854 .65905 L .35671 .69716 L .009 0 .368 r

F

.35671 .69716 m .34597 .76363 L .35484 .73604 L 0 0 .164 r

F

.35484 .73604 m .34597 .76363 L .34401 .80289 L F

.53368 .81551 m .55787 .85127 L .54808 .85312 L .646 .627 .817 r

F

0 g

.54808 .85312 m

.56229 .89021 L

s

.34986 .53701 m .33335 .56739 L .36591 .57746 L .187 .339 .786 r

F

.34986 .53701 m .31741 .52773 L .33335 .56739 L F

.53368 .81551 m .54351 .8136 L .55787 .85127 L .646 .627 .817 r

F

0 g

.53368 .81551 m

.54808 .85312 L

s

.53782 .79867 m

.61734 .89864 L

s

.53782 .79867 m

.59975 .96118 L

s

.38172 .66468 m .35671 .69716 L .35484 .73604 L .009 0 .368 r

F

.38333 .62614 m .35671 .69716 L .38172 .66468 L F

.33358 .49596 m .31741 .52773 L .34986 .53701 L .187 .339 .786 r

F

.33358 .49596 m .30125 .48752 L .31741 .52773 L F

.35484 .73604 m .34401 .80289 L .35294 .77573 L 0 0 .164 r

F

.34401 .80289 m .51397 .76869 L .5312 .79034 L .623 .782 .957 r

F

0 g

.52797 .80061 m

.53368 .81551 L

s

.35294 .77573 m .51397 .76869 L .34401 .80289 L .623 .782 .957 r

F

0 g

.34401 .80289 m

.34528 .82714 L

s

.30125 .48752 m .43159 .47216 L .33358 .49596 L .347 0 .059 r

F

.30125 .48752 m .44191 .45306 L .43159 .47216 L F

0 g

.28551 .47568 m

.30125 .48752 L

s

.44278 .57821 m .36591 .57746 L .38173 .61735 L .458 .516 .83 r

F

.38008 .70402 m .35484 .73604 L .35294 .77573 L .009 0 .368 r

F

.38172 .66468 m .35484 .73604 L .38008 .70402 L F

.42684 .5366 m .36591 .57746 L .44278 .57821 L .458 .516 .83 r

F

.42684 .5366 m .34986 .53701 L .36591 .57746 L F

.45072 .62131 m .38172 .66468 L .38008 .70402 L .338 .155 .48 r

F

.38008 .70402 m .35294 .77573 L .3784 .74419 L .009 0 .368 r

F

.35294 .77573 m .49624 .7464 L .51397 .76869 L .623 .782 .957 r

F

0 g

.49789 .74848 m

.534 .79387 L

s

.3784 .74419 m .49624 .7464 L .35294 .77573 L .623 .782 .957 r

F

0 g

.34401 .80289 m

.35294 .77573 L

s

.41067 .49438 m .34986 .53701 L .42684 .5366 L .458 .516 .83 r

F

.41067 .49438 m .33358 .49596 L .34986 .53701 L F

0 g

.4518 .57615 m

.45187 .57312 L

s

.45861 .61955 m

.46077 .62518 L

s

.45072 .62131 m .38008 .70402 L .44977 .66124 L .338 .155 .48 r

F

.44977 .66124 m .38008 .70402 L .3784 .74419 L F

.33358 .49596 m .42092 .49191 L .41067 .49438 L .347 0 .059 r

F

.33358 .49596 m .43159 .47216 L .42092 .49191 L F

0 g

.30125 .48752 m

.33358 .49596 L

s

.3784 .74419 m .47799 .72346 L .49624 .7464 L .623 .782 .957 r

F

.44881 .70204 m .47799 .72346 L .3784 .74419 L F

0 g

.46134 .59798 m

.53782 .79867 L

s

.44977 .66124 m .3784 .74419 L .44881 .70204 L .338 .155 .48 r

F

0 g

.35294 .77573 m

.3784 .74419 L

s

.42684 .5366 m .45293 .57589 L .44278 .57821 L .646 .627 .817 r

F

0 g

.44278 .57821 m

.45122 .60025 L

s

.42684 .5366 m .43704 .53421 L .45293 .57589 L .646 .627 .817 r

F

.45072 .62131 m .46006 .65901 L .44977 .66124 L .571 .339 .525 r

F

.45072 .62131 m .4609 .61904 L .46006 .65901 L F

0 g

.45072 .62131 m

.45122 .60025 L

s

.41067 .49438 m .43704 .53421 L .42684 .5366 L .646 .627 .817 r

F

0 g

.42684 .5366 m

.44278 .57821 L

s

.41067 .49438 m .42092 .49191 L .43704 .53421 L .646 .627 .817 r

F

0 g

.41067 .49438 m

.42684 .5366 L

s

.33358 .49596 m

.41067 .49438 L

s

.42092 .49191 m

.45929 .5926 L

s

.42092 .49191 m

.46316 .41373 L

s

.44881 .70204 m .4592 .69983 L .47799 .72346 L .623 .782 .957 r

F

.44977 .66124 m .4592 .69983 L .44881 .70204 L .571 .339 .525 r

F

0 g

.3784 .74419 m

.44881 .70204 L

s

.44977 .66124 m .46006 .65901 L .4592 .69983 L .571 .339 .525 r

F

0 g

.44977 .66124 m

.45072 .62131 L

s

.4592 .69983 m

.46134 .59798 L

s

.4592 .69983 m

.49789 .74848 L

s

.44881 .70204 m

.44977 .66124 L

s

.41067 .49438 m

.41067 .49438 L

s

.58274 .70787 m

.18738 .78984 L

s

.25 Mabswid

.08806 .19064 m

.73754 0 L

s

.23615 .14717 m

.24054 .15349 L

s

[(0)] .22738 .13454 .69494 1 Mshowa

.47069 .07833 m

.47449 .08501 L

s

[(5)] .4631 .06495 .56792 1 Mshowa

.72072 .00494 m

.72382 .01197 L

s

[(10)] .71452 -0.00913 .4409 1 Mshowa

.125 Mabswid

.28189 .13375 m

.28446 .13758 L

s

.3282 .12015 m

.3307 .12403 L

s

.3751 .10639 m

.37753 .11031 L

s

.42259 .09245 m

.42495 .09641 L

s

.51941 .06403 m

.52161 .06808 L

s

.56876 .04954 m

.57088 .05364 L

s

.61875 .03487 m

.62079 .03901 L

s

.6694 .02 m

.67135 .02418 L

s

.19098 .16043 m

.19367 .16418 L

s

.14635 .17353 m

.14911 .17723 L

s

.10227 .18647 m

.10509 .19012 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.599143 0.97619 1.11901 MathSubStart

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 8  scalefont  setfont

% Scaling calculations

-0.121606 1.30341 0 1.30341 [

[.5 1.24988 -62.4 0 ]

[.5 1.24988 62.4 7.2 ]

[.16742 .174 -18.1107 -7.2 ]

[.16742 .174 1.0893 0 ]

[.27607 .12856 -4.38789 -7.2 ]

[.27607 .12856 .41211 0 ]

[.38872 .08147 -12.7443 -7.2 ]

[.38872 .08147 1.65571 0 ]

[.50562 .03262 -4.10831 -7.2 ]

[.50562 .03262 .69169 0 ]

[.08245 .98588 -5.32129 0 ]

[.08245 .98588 4.27871 7.2 ]

[.24395 1.10541 -2.56192 0 ]

[.24395 1.10541 2.23808 7.2 ]

[.3844 1.20936 -2.48047 0 ]

[.3844 1.20936 2.31953 7.2 ]

[.06304 .31709 -9.6 -2.15129 ]

[.06304 .31709 0 5.04871 ]

[.03651 .51773 -4.8 -2.26802 ]

[.03651 .51773 0 4.93198 ]

[.00671 .74321 -4.8 -2.40047 ]

[.00671 .74321 0 4.79953 ]

[ 0 0 0 0 ]

[ 1 1.23738 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

[(Rotate[object, 30,{0,1,0}])] .5 1.24988 0 -1 Mshowa

.25 Mabswid

[ ] 0 setdash

.08969 .22307 m

.62525 0 L

s

.17823 .18619 m

.18363 .19228 L

s

[(-2.5)] .16742 .174 .88653 1 Mshowa

.28646 .14111 m

.29165 .14738 L

s

[(0)] .27607 .12856 .82829 1 Mshowa

.39866 .09438 m

.40363 .10083 L

s

[(2.5)] .38872 .08147 .77004 1 Mshowa

.51506 .04589 m

.51979 .05253 L

s

[(5)] .50562 .03262 .71179 1 Mshowa

.125 Mabswid

.19957 .1773 m

.20279 .18098 L

s

.22106 .16835 m

.22425 .17205 L

s

.2427 .15933 m

.24587 .16306 L

s

.2645 .15025 m

.26765 .154 L

s

.30857 .1319 m

.31167 .13568 L

s

.33085 .12262 m

.33392 .12643 L

s

.35329 .11327 m

.35633 .1171 L

s

.37589 .10386 m

.3789 .10771 L

s

.4216 .08482 m

.42455 .08872 L

s

.44471 .0752 m

.44763 .07911 L

s

.46798 .0655 m

.47088 .06944 L

s

.49144 .05573 m

.4943 .05969 L

s

.15704 .19501 m

.16031 .19865 L

s

.13601 .20377 m

.1393 .20739 L

s

.11512 .21248 m

.11843 .21607 L

s

.09437 .22112 m

.09771 .22469 L

s

.53887 .03598 m

.54167 .03998 L

s

.56285 .02599 m

.56563 .03001 L

s

.58702 .01592 m

.58976 .01997 L

s

.61137 .00578 m

.61408 .00985 L

s

.25 Mabswid

0 .90712 m

.44459 1.23738 L

s

.08421 .96968 m

.08509 .96158 L

s

[(-5)] .08245 .98588 .1086 -1 Mshowa

.24505 1.08915 m

.2456 1.08103 L

s

[(0)] .24395 1.10541 .06746 -1 Mshowa

.38494 1.19307 m

.38522 1.18493 L

s

[(5)] .3844 1.20936 .03353 -1 Mshowa

.125 Mabswid

.11828 .99498 m

.11876 .99012 L

s

.15135 1.01955 m

.1518 1.01468 L

s

.18348 1.04342 m

.18388 1.03855 L

s

.2147 1.06661 m

.21507 1.06173 L

s

.27457 1.11108 m

.27486 1.1062 L

s

.30328 1.13241 m

.30354 1.12753 L

s

.33123 1.15317 m

.33146 1.14829 L

s

.35844 1.17339 m

.35864 1.1685 L

s

.04911 .9436 m

.04969 .93875 L

s

.01293 .91673 m

.01355 .91188 L

s

.41076 1.21225 m

.4109 1.20737 L

s

.43593 1.23095 m

.43603 1.22606 L

s

.25 Mabswid

.08969 .22307 m

0 .90712 L

s

.07816 .31101 m

.08571 .30797 L

s

[(-5)] .06304 .31709 1 -0.40242 Mshowa

.05179 .51208 m

.05943 .50925 L

s

[(0)] .03651 .51773 1 -0.36999 Mshowa

.02217 .73806 m

.02989 .73549 L

s

[(5)] .00671 .74321 1 -0.3332 Mshowa

.125 Mabswid

.07312 .34943 m

.07766 .34763 L

s

.06797 .38872 m

.07252 .38694 L

s

.0627 .4289 m

.06726 .42715 L

s

.05731 .47001 m

.06188 .46829 L

s

.04615 .55514 m

.05074 .55348 L

s

.04037 .59923 m

.04497 .5976 L

s

.03445 .64439 m

.03906 .64278 L

s

.02838 .69065 m

.03301 .68908 L

s

.08308 .27343 m

.08761 .27158 L

s

.08791 .23665 m

.09242 .23478 L

s

.01579 .78666 m

.02044 .78515 L

s

.00926 .8365 m

.01392 .83502 L

s

.00256 .88761 m

.00723 .88617 L

s

0 0 m

1 0 L

1 1.23738 L

0 1.23738 L

closepath

clip

newpath

.5 Mabswid

.91145 .46795 m

.47193 .61269 L

s

.4627 1.20749 m

.47193 .61269 L

s

.91145 .46795 m

.97691 1.08657 L

s

.65455 .53518 m .71857 .48608 L .59978 .52602 L .669 .734 .898 r

F

.65455 .53518 m .7355 .50831 L .71857 .48608 L F

.74382 .53281 m .7355 .50831 L .65455 .53518 L F

.65455 .53518 m .74562 .56362 L .6556 .56598 L .683 .444 .554 r

F

.65455 .53518 m .74382 .53281 L .74562 .56362 L F

.59978 .52602 m .65455 .53518 L .6556 .56598 L .753 .5 .549 r

F

.74382 .53281 m .7521 .53009 L .7355 .50831 L .669 .734 .898 r

F

.74562 .56362 m .7521 .53009 L .74382 .53281 L .564 .354 .554 r

F

0 g

.65455 .53518 m

.74382 .53281 L

s

.74382 .53281 m

.74382 .53281 L

s

.74562 .56362 m .75396 .56092 L .7521 .53009 L .564 .354 .554 r

F

.59978 .52602 m .70129 .46339 L .55765 .51232 L .669 .734 .898 r

F

.59978 .52602 m .71857 .48608 L .70129 .46339 L F

.59978 .52602 m .6556 .56598 L .60037 .55688 L .753 .5 .549 r

F

.60037 .55688 m .6556 .56598 L .65666 .5973 L F

.6556 .56598 m .74744 .59495 L .65666 .5973 L .683 .444 .554 r

F

.6556 .56598 m .74562 .56362 L .74744 .59495 L F

.74744 .59495 m .75396 .56092 L .74562 .56362 L .564 .354 .554 r

F

.55765 .51232 m .68365 .44023 L .5235 .4955 L .669 .734 .898 r

F

.55765 .51232 m .70129 .46339 L .68365 .44023 L F

.74744 .59495 m .75586 .59227 L .75396 .56092 L .564 .354 .554 r

F

.60037 .55688 m .65666 .5973 L .60096 .58825 L .753 .5 .549 r

F

.65666 .5973 m .7493 .62682 L .65774 .62915 L .683 .444 .554 r

F

.65666 .5973 m .74744 .59495 L .7493 .62682 L F

.60096 .58825 m .65666 .5973 L .65774 .62915 L .753 .5 .549 r

F

.7493 .62682 m .75586 .59227 L .74744 .59495 L .564 .354 .554 r

F

.5235 .4955 m .66563 .41658 L .49553 .47607 L .669 .734 .898 r

F

.5235 .4955 m .68365 .44023 L .66563 .41658 L F

.7493 .62682 m .75779 .62416 L .75586 .59227 L .564 .354 .554 r

F

.65774 .62915 m .75119 .65923 L .65884 .66155 L .683 .444 .554 r

F

.65774 .62915 m .7493 .62682 L .75119 .65923 L F

.75119 .65923 m .75779 .62416 L .7493 .62682 L .564 .354 .554 r

F

.49553 .47607 m .64724 .39243 L .473 .45419 L .669 .734 .898 r

F

.49553 .47607 m .66563 .41658 L .64724 .39243 L F

.75119 .65923 m .75976 .65659 L .75779 .62416 L .564 .354 .554 r

F

.65884 .66155 m .75311 .69221 L .65996 .69451 L .683 .444 .554 r

F

.65884 .66155 m .75119 .65923 L .75311 .69221 L F

.75311 .69221 m .75976 .65659 L .75119 .65923 L .564 .354 .554 r

F

.75311 .69221 m .76176 .68959 L .75976 .65659 L F

.473 .45419 m .62844 .36776 L .45577 .4298 L .669 .734 .898 r

F

.473 .45419 m .64724 .39243 L .62844 .36776 L F

.65996 .69451 m .75506 .72577 L .66109 .72805 L .683 .444 .554 r

F

.65996 .69451 m .75311 .69221 L .75506 .72577 L F

.75506 .72577 m .76176 .68959 L .75311 .69221 L .564 .354 .554 r

F

.75506 .72577 m .76379 .72317 L .76176 .68959 L F

.45577 .4298 m .60924 .34255 L .44422 .40267 L .669 .734 .898 r

F

.45577 .4298 m .62844 .36776 L .60924 .34255 L F

.66109 .72805 m .75705 .75993 L .66225 .76218 L .683 .444 .554 r

F

.66109 .72805 m .75506 .72577 L .75705 .75993 L F

.75705 .75993 m .76379 .72317 L .75506 .72577 L .564 .354 .554 r

F

.75705 .75993 m .76586 .75735 L .76379 .72317 L F

.44422 .40267 m .58962 .31679 L .43934 .3723 L .669 .734 .898 r

F

.44422 .40267 m .60924 .34255 L .58962 .31679 L F

.66278 .77785 m .7077 .8616 L .64838 .79003 L .655 .498 .658 r

F

.66278 .77785 m .75908 .79469 L .70758 .79589 L .683 .444 .554 r

F

.66225 .76218 m .70782 .77748 L .66278 .77785 L F

.70782 .77748 m .75908 .79469 L .66278 .77785 L F

.66225 .76218 m .75705 .75993 L .75908 .79469 L F

.68017 .76315 m .68701 .78761 L .66278 .77785 L .655 .498 .658 r

F

.68701 .78761 m .7077 .8616 L .66278 .77785 L F

.68701 .78761 m .73987 .83446 L .7077 .8616 L F

.68017 .76315 m .70758 .79589 L .68701 .78761 L F

.70758 .79589 m .73987 .83446 L .68701 .78761 L F

.70758 .79589 m .75908 .79469 L .76039 .81716 L .683 .444 .554 r

F

.71199 .73624 m .73987 .83446 L .68017 .76315 L .655 .498 .658 r

F

.75908 .79469 m .76586 .75735 L .75705 .75993 L .564 .354 .554 r

F

.75908 .79469 m .76797 .79213 L .76586 .75735 L F

.76114 .83007 m .76797 .79213 L .75908 .79469 L F

.76114 .83007 m .77011 .82755 L .76797 .79213 L F

.71199 .73624 m .76724 .80156 L .73987 .83446 L .655 .498 .658 r

F

.70445 .59816 m .71233 .60751 L .70442 .66292 L .725 .62 .74 r

F

.6909 .44976 m .7648 .73986 L .75172 .70687 L .974 .684 .411 r

F

.74061 .67884 m .76662 .76984 L .7467 .70689 L F

.6909 .44976 m .75172 .70687 L .74061 .67884 L F

.75172 .70687 m .76662 .76984 L .74061 .67884 L F

.6909 .44976 m .7521 .53009 L .7648 .73986 L F

.70757 .59551 m .71233 .60751 L .70445 .59816 L .725 .62 .74 r

F

.71233 .60751 m .72679 .64398 L .70442 .66292 L F

.72679 .64398 m .74385 .7093 L .70442 .66292 L .698 .571 .708 r

F

.76724 .80156 m .76904 .80986 L .73987 .83446 L .655 .498 .658 r

F

.73987 .83446 m .77701 .81316 L .77208 .80729 L .564 .354 .554 r

F

.73987 .83446 m .74471 .84039 L .77701 .81316 L F

.66343 .79692 m .70758 .79589 L .75802 .82808 L .683 .444 .554 r

F

.45839 .95068 m .5154 1.02379 L .48348 1.05072 L .655 .498 .658 r

F

.48997 .92398 m .5154 1.02379 L .45839 .95068 L F

.48997 .92398 m .54736 .99684 L .5154 1.02379 L F

.52158 .89725 m .54736 .99684 L .48997 .92398 L F

.52158 .89725 m .57936 .96985 L .54736 .99684 L F

.55323 .87049 m .57936 .96985 L .52158 .89725 L F

.55323 .87049 m .61139 .94283 L .57936 .96985 L F

.58491 .8437 m .61139 .94283 L .55323 .87049 L F

.58491 .8437 m .64345 .91579 L .61139 .94283 L F

.61663 .81688 m .64345 .91579 L .58491 .8437 L F

.64838 .79003 m .67556 .88871 L .61663 .81688 L F

.61663 .81688 m .67556 .88871 L .64345 .91579 L F

.64838 .79003 m .7077 .8616 L .67556 .88871 L F

.48348 1.05072 m .51967 1.03017 L .5154 1.02379 L .564 .354 .554 r

F

.48348 1.05072 m .48766 1.05716 L .51967 1.03017 L F

.5154 1.02379 m .55171 1.00315 L .54736 .99684 L F

.5154 1.02379 m .51967 1.03017 L .55171 1.00315 L F

.54736 .99684 m .58378 .9761 L .57936 .96985 L F

.54736 .99684 m .55171 1.00315 L .58378 .9761 L F

.57936 .96985 m .6159 .94902 L .61139 .94283 L F

.57936 .96985 m .58378 .9761 L .6159 .94902 L F

.61139 .94283 m .64805 .92191 L .64345 .91579 L F

.61139 .94283 m .6159 .94902 L .64805 .92191 L F

.64345 .91579 m .68023 .89477 L .67556 .88871 L F

.64345 .91579 m .64805 .92191 L .68023 .89477 L F

.67556 .88871 m .71245 .8676 L .7077 .8616 L F

.67556 .88871 m .68023 .89477 L .71245 .8676 L F

.7077 .8616 m .74471 .84039 L .73987 .83446 L F

.7077 .8616 m .71245 .8676 L .74471 .84039 L F

.51757 .94159 m .63942 .88407 L .48766 1.05716 L .807 .799 .844 r

F

.63942 .88407 m .6546 .88337 L .48766 1.05716 L F

.66596 .87155 m .7241 .85778 L .48766 1.05716 L F

.56046 .8841 m .57197 .88721 L .56374 .88759 L .804 .542 .542 r

F

.60613 .85985 m .66585 .8683 L .66596 .87155 L .753 .5 .549 r

F

.60613 .85985 m .66596 .87155 L .63261 .87944 L F

.66343 .79692 m .75802 .82808 L .75687 .82863 L .683 .444 .554 r

F

.70442 .66292 m .71199 .73624 L .6726 .68987 L .698 .571 .708 r

F

.67251 .62525 m .70442 .66292 L .6726 .68987 L .725 .62 .74 r

F

.70442 .66292 m .74385 .7093 L .71199 .73624 L .698 .571 .708 r

F

.70445 .59816 m .70442 .66292 L .67251 .62525 L .725 .62 .74 r

F

.7467 .70689 m .76662 .76984 L .76904 .80986 L .974 .684 .411 r

F

.74385 .7093 m .77208 .80729 L .71199 .73624 L .655 .498 .658 r

F

.6773 .56561 m .67251 .62525 L .64518 .59288 L .748 .664 .768 r

F

.6773 .56561 m .70445 .59816 L .67251 .62525 L F

.68862 .556 m .70445 .59816 L .6773 .56561 L F

.43934 .3723 m .56956 .29045 L .44335 .33774 L .669 .734 .898 r

F

.43934 .3723 m .58962 .31679 L .56956 .29045 L F


.65069 .49647 m .65364 .53695 L .63294 .51157 L .791 .755 .82 r

F

.44335 .33774 m .54904 .26352 L .46167 .29674 L .669 .734 .898 r

F

.44335 .33774 m .56956 .29045 L .54904 .26352 L F

.46167 .29674 m .54904 .26352 L .52807 .23598 L F

.54706 .26092 m .6909 .44976 L .71075 .56251 L .974 .684 .411 r

F

.69136 .54119 m .71075 .56251 L .71511 .58733 L F

.54706 .26092 m .71075 .56251 L .69136 .54119 L F

.67887 .52746 m .71511 .58733 L .69318 .5564 L F

.54706 .26092 m .67465 .50873 L .66649 .50242 L F

.67967 .53734 m .71878 .60816 L .68862 .556 L F

.54706 .26092 m .69318 .5564 L .67967 .53734 L F

.69318 .5564 m .71878 .60816 L .67967 .53734 L F

.66649 .50242 m .69136 .54119 L .67887 .52746 L F

.67465 .50873 m .69136 .54119 L .66649 .50242 L F

.65986 .50941 m .6697 .52329 L .65364 .53695 L .791 .755 .82 r

F

.62306 .46883 m .63146 .47533 L .61505 .48931 L .83 .87 .874 r

F

.63146 .47533 m .63294 .51157 L .61505 .48931 L .811 .808 .847 r

F

.64078 .48558 m .63294 .51157 L .63146 .47533 L F

.64078 .48558 m .65069 .49647 L .63294 .51157 L F

.65986 .50941 m .65364 .53695 L .65069 .49647 L .791 .755 .82 r

F

.6697 .52329 m .6773 .56561 L .65364 .53695 L .77 .708 .794 r

F

.68088 .54261 m .6773 .56561 L .6697 .52329 L F

.7051 .59036 m .70445 .59816 L .68862 .556 L .748 .664 .768 r

F

.69136 .54119 m .71511 .58733 L .67887 .52746 L .974 .684 .411 r

F

.69318 .5564 m .71511 .58733 L .71878 .60816 L F

.68862 .556 m .71878 .60816 L .72176 .62508 L F

.6909 .44976 m .73488 .65243 L .72176 .62508 L F

.70946 .5383 m .73643 .57103 L .70757 .59551 L .748 .664 .768 r

F

.7051 .59036 m .70757 .59551 L .70445 .59816 L F

.70946 .5383 m .70757 .59551 L .7051 .59036 L F

.66596 .87155 m .76094 .8267 L .7241 .85778 L .807 .799 .844 r

F

.70758 .79589 m .76039 .81716 L .76114 .83007 L .683 .444 .554 r

F

.66278 .77785 m .70758 .79589 L .66343 .79692 L F

.60282 .68566 m .66109 .72805 L .60346 .71927 L .753 .5 .549 r

F

.60346 .71927 m .66109 .72805 L .66225 .76218 L F

.60346 .71927 m .66225 .76218 L .61931 .75576 L F

.60346 .71927 m .61741 .75139 L .604 .74798 L F

.61741 .75139 m .61931 .75576 L .604 .74798 L F

.55886 .67241 m .60346 .71927 L .55911 .70613 L .804 .542 .542 r

F

.57714 .74114 m .604 .74798 L .57736 .77054 L .725 .62 .74 r

F

.55911 .70613 m .60346 .71927 L .604 .74798 L .804 .542 .542 r

F

.57707 .73195 m .604 .74798 L .57714 .74114 L .725 .62 .74 r

F

.604 .74798 m .61663 .81688 L .57736 .77054 L .698 .571 .708 r

F

.60907 .74368 m .6101 .75361 L .604 .74798 L F

.6101 .75361 m .61663 .81688 L .604 .74798 L F

.5922 .74095 m .604 .74798 L .60411 .75348 L .804 .542 .542 r

F

.55911 .70613 m .604 .74798 L .5922 .74095 L F

.55923 .72133 m .57736 .77054 L .54508 .73332 L .725 .62 .74 r

F

.57707 .73195 m .57736 .77054 L .55923 .72133 L F

.55923 .72133 m .60411 .75348 L .55937 .74045 L .804 .542 .542 r

F

.55911 .70613 m .58167 .72987 L .55923 .72133 L F

.52321 .65614 m .55886 .67241 L .55911 .70613 L .851 .582 .531 r

F

.52321 .65614 m .55911 .70613 L .52315 .68999 L F

.54622 .71638 m .55923 .72133 L .54508 .73332 L .748 .664 .768 r

F

.52315 .68999 m .55911 .70613 L .55923 .72133 L .851 .582 .531 r

F

.54647 .71256 m .55923 .72133 L .54622 .71638 L .748 .664 .768 r

F

.52315 .68999 m .55923 .72133 L .5324 .70288 L .851 .582 .531 r

F

.52314 .69651 m .54508 .73332 L .51705 .70168 L .748 .664 .768 r

F

.52315 .68999 m .53029 .69993 L .52314 .69651 L .851 .582 .531 r

F

.53029 .69993 m .5324 .70288 L .52314 .69651 L F

.52327 .62289 m .55886 .67241 L .52321 .65614 L F

.52437 .64682 m .54902 .67453 L .52314 .69651 L .77 .708 .794 r

F

.51806 .69408 m .52314 .69651 L .51705 .70168 L F

.49431 .60394 m .52327 .62289 L .52321 .65614 L .896 .623 .515 r

F

.49399 .63733 m .52321 .65614 L .52315 .68999 L F

.49431 .60394 m .52321 .65614 L .49399 .63733 L F

.49399 .63733 m .52315 .68999 L .49366 .67133 L F

.49366 .67133 m .52315 .68999 L .52314 .69651 L F

.51826 .69261 m .52314 .69651 L .51806 .69408 L .77 .708 .794 r

F

.51705 .70168 m .51331 .76027 L .4851 .72881 L .748 .664 .768 r

F

.51705 .70168 m .54508 .73332 L .51331 .76027 L F

.49214 .67421 m .51517 .69961 L .4851 .72881 L .77 .708 .794 r

F

.51517 .69961 m .51705 .70168 L .51692 .70179 L F

.51517 .69961 m .51692 .70179 L .4851 .72881 L F

.49214 .67421 m .4851 .72881 L .45996 .70157 L F

.46988 .65029 m .49214 .67421 L .45996 .70157 L .791 .755 .82 r

F

.46988 .65029 m .4891 .66729 L .48926 .66875 L .941 .666 .488 r

F

.4891 .66729 m .49366 .67133 L .49365 .67293 L F

.4926 .67193 m .49214 .67421 L .46988 .65029 L .791 .755 .82 r

F

.49366 .67133 m .52314 .69651 L .49527 .67423 L .896 .623 .515 r

F

.49365 .67293 m .51705 .70168 L .49214 .67421 L .77 .708 .794 r

F

.49366 .67133 m .49497 .67369 L .49365 .67293 L .896 .623 .515 r

F

.49497 .67369 m .49527 .67423 L .49365 .67293 L F

.50242 .62261 m .52437 .64682 L .49365 .67293 L .791 .755 .82 r

F

.49253 .67229 m .49365 .67293 L .49214 .67421 L F

.4926 .67193 m .49365 .67293 L .49253 .67229 L F

.48926 .66875 m .49365 .67293 L .49333 .70594 L .941 .666 .488 r

F

.4891 .66729 m .49365 .67293 L .48926 .66875 L F

.47043 .61613 m .49399 .63733 L .49366 .67133 L F

.47043 .61613 m .49366 .67133 L .46988 .65029 L F

.50242 .62261 m .49365 .67293 L .4926 .67193 L .791 .755 .82 r

F

.52437 .64682 m .51826 .69261 L .49365 .67293 L .77 .708 .794 r

F

.51826 .69261 m .51705 .70168 L .49365 .67293 L F

.49365 .67293 m .52309 .72445 L .49333 .70594 L .896 .623 .515 r

F

.49527 .67423 m .52309 .72445 L .49365 .67293 L F

.47096 .58258 m .49431 .60394 L .49399 .63733 L .941 .666 .488 r

F

.47096 .58258 m .49399 .63733 L .47043 .61613 L F

.50242 .62261 m .4926 .67193 L .46988 .65029 L .791 .755 .82 r

F

.46988 .65029 m .48926 .66875 L .49333 .70594 L .941 .666 .488 r

F

.49527 .67423 m .52314 .69651 L .52309 .72445 L .896 .623 .515 r

F

.52437 .64682 m .52314 .69651 L .51826 .69261 L .77 .708 .794 r

F

.54902 .67453 m .54647 .71256 L .52314 .69651 L .748 .664 .768 r

F

.54647 .71256 m .54508 .73332 L .52314 .69651 L F

.54508 .73332 m .54568 .79737 L .51331 .76027 L .725 .62 .74 r

F

.54508 .73332 m .57736 .77054 L .54568 .79737 L F

.52314 .69651 m .55937 .74045 L .52309 .72445 L .851 .582 .531 r

F

.5324 .70288 m .55937 .74045 L .52314 .69651 L F

.5324 .70288 m .55923 .72133 L .55937 .74045 L F

.54902 .67453 m .55923 .72133 L .54647 .71256 L .748 .664 .768 r

F

.54902 .67453 m .57688 .70635 L .55923 .72133 L F

.58167 .72987 m .5922 .74095 L .55923 .72133 L .804 .542 .542 r

F

.5922 .74095 m .60411 .75348 L .55923 .72133 L F

.57688 .70635 m .57707 .73195 L .55923 .72133 L .725 .62 .74 r

F

.57688 .70635 m .604 .74798 L .57707 .73195 L F

.57688 .70635 m .60907 .74368 L .604 .74798 L F

.60982 .75093 m .64838 .79003 L .61663 .81688 L .698 .571 .708 r

F

.60907 .74368 m .61931 .75576 L .60982 .75093 L F

.61931 .75576 m .64838 .79003 L .60982 .75093 L F

.64713 .77798 m .66278 .77785 L .64838 .79003 L F

.61931 .75576 m .66225 .76218 L .66278 .77785 L .753 .5 .549 r

F

.64082 .71679 m .64838 .79003 L .60907 .74368 L .698 .571 .708 r

F

.60411 .75348 m .61931 .75576 L .66343 .79692 L .753 .5 .549 r

F

.64625 .76945 m .66278 .77785 L .64713 .77798 L .698 .571 .708 r

F

.61931 .75576 m .66278 .77785 L .66343 .79692 L .753 .5 .549 r

F

.604 .74798 m .61931 .75576 L .60411 .75348 L F

.64082 .71679 m .66278 .77785 L .64625 .76945 L .698 .571 .708 r

F

.64082 .71679 m .68017 .76315 L .66278 .77785 L F

.60157 .62017 m .65884 .66155 L .60219 .65263 L .753 .5 .549 r

F

.55836 .60672 m .60157 .62017 L .60219 .65263 L .804 .542 .542 r

F

.60219 .65263 m .65884 .66155 L .65996 .69451 L .753 .5 .549 r

F

.55836 .60672 m .60219 .65263 L .55861 .63928 L .804 .542 .542 r

F

.60219 .65263 m .65996 .69451 L .60282 .68566 L .753 .5 .549 r

F

.55861 .63928 m .60219 .65263 L .60282 .68566 L .804 .542 .542 r

F

.60282 .68566 m .65996 .69451 L .66109 .72805 L .753 .5 .549 r

F

.55861 .63928 m .60282 .68566 L .55886 .67241 L .804 .542 .542 r

F

.55886 .67241 m .60282 .68566 L .60346 .71927 L F

.51404 .82418 m .55323 .87049 L .52158 .89725 L .698 .571 .708 r

F

.54568 .79737 m .55323 .87049 L .51404 .82418 L F

.54568 .79737 m .58491 .8437 L .55323 .87049 L F

.57736 .77054 m .58491 .8437 L .54568 .79737 L F

.57736 .77054 m .61663 .81688 L .58491 .8437 L F

.60872 .67935 m .60907 .74368 L .57688 .70635 L .725 .62 .74 r

F

.60872 .67935 m .64082 .71679 L .60907 .74368 L F

.6726 .68987 m .68017 .76315 L .64082 .71679 L .698 .571 .708 r

F

.6406 .65231 m .64082 .71679 L .60872 .67935 L .725 .62 .74 r

F

.6406 .65231 m .6726 .68987 L .64082 .71679 L F

.6726 .68987 m .71199 .73624 L .68017 .76315 L .698 .571 .708 r

F

.60411 .75348 m .66343 .79692 L .60477 .7883 L .753 .5 .549 r

F

.55937 .74045 m .60411 .75348 L .60477 .7883 L .804 .542 .542 r

F

.58104 .64734 m .60872 .67935 L .57688 .70635 L .748 .664 .768 r

F

.60096 .58825 m .65774 .62915 L .60157 .62017 L .753 .5 .549 r

F

.60157 .62017 m .65774 .62915 L .65884 .66155 L F

.61309 .62013 m .60872 .67935 L .58104 .64734 L .748 .664 .768 r

F

.61309 .62013 m .6406 .65231 L .60872 .67935 L F

.66343 .79692 m .76114 .83007 L .66463 .83229 L .683 .444 .554 r

F

.60477 .7883 m .66343 .79692 L .66463 .83229 L .753 .5 .549 r

F

.55937 .74045 m .60477 .7883 L .55964 .77539 L .804 .542 .542 r

F

.55812 .57471 m .60096 .58825 L .60157 .62017 L F

.55812 .57471 m .60157 .62017 L .55836 .60672 L F

.58893 .59194 m .61309 .62013 L .58104 .64734 L .77 .708 .794 r

F

.60477 .7883 m .66463 .83229 L .60544 .82375 L .753 .5 .549 r

F

.55964 .77539 m .60477 .7883 L .60544 .82375 L .804 .542 .542 r

F

.66463 .83229 m .76324 .8661 L .66585 .8683 L .683 .444 .554 r

F

.66463 .83229 m .76114 .83007 L .76324 .8661 L F

.60544 .82375 m .66463 .83229 L .66585 .8683 L .753 .5 .549 r

F

.55964 .77539 m .60544 .82375 L .5599 .81097 L .804 .542 .542 r

F

.52302 .75954 m .55964 .77539 L .5599 .81097 L .851 .582 .531 r

F

.60544 .82375 m .66585 .8683 L .60613 .85985 L .753 .5 .549 r

F

.5599 .81097 m .60544 .82375 L .60613 .85985 L .804 .542 .542 r

F

.66585 .8683 m .76538 .9028 L .66709 .90496 L .683 .444 .554 r

F

.66585 .8683 m .76324 .8661 L .76538 .9028 L F

.51331 .76027 m .54568 .79737 L .51404 .82418 L .725 .62 .74 r

F

.52302 .75954 m .5599 .81097 L .52296 .79526 L .851 .582 .531 r

F

.5599 .81097 m .60613 .85985 L .56018 .8472 L .804 .542 .542 r

F

.52296 .79526 m .5599 .81097 L .56018 .8472 L .851 .582 .531 r

F

.59973 .62421 m .76094 .8267 L .66596 .87155 L .807 .799 .844 r

F

.56018 .8472 m .60613 .85985 L .60662 .8856 L .804 .542 .542 r

F

.5272 .90441 m .58296 .8912 L .51757 .94159 L .807 .799 .844 r

F

.58296 .8912 m .60662 .8856 L .59481 .89302 L F

.58296 .8912 m .59481 .89302 L .51757 .94159 L F

.52282 .86873 m .56046 .8841 L .56048 .88774 L .851 .582 .531 r

F

.60662 .8856 m .63942 .88407 L .51757 .94159 L .807 .799 .844 r

F

.52282 .86873 m .56048 .88774 L .53346 .88358 L .851 .582 .531 r

F

.56018 .8472 m .60662 .8856 L .59686 .88605 L .804 .542 .542 r

F

.60613 .85985 m .63261 .87944 L .60662 .8856 L .753 .5 .549 r

F

.52296 .79526 m .56018 .8472 L .52289 .83166 L .851 .582 .531 r

F

.59973 .62421 m .66596 .87155 L .60662 .8856 L .807 .799 .844 r

F

.53116 .8891 m .60662 .8856 L .5272 .90441 L F

.56018 .8472 m .59686 .88605 L .56046 .8841 L .804 .542 .542 r

F

.59686 .88605 m .57197 .88721 L .56046 .8841 L F

.52289 .83166 m .56018 .8472 L .56046 .8841 L .851 .582 .531 r

F

.52289 .83166 m .56046 .8841 L .52282 .86873 L F

.56046 .8841 m .60754 .93406 L .56074 .92169 L .804 .542 .542 r

F

.52282 .86873 m .53346 .88358 L .5228 .88194 L .851 .582 .531 r

F

.65364 .53695 m .64518 .59288 L .62127 .56446 L .77 .708 .794 r

F

.65364 .53695 m .6773 .56561 L .64518 .59288 L F

.68605 .5094 m .70946 .5383 L .68862 .556 L F

.68088 .54261 m .68862 .556 L .6773 .56561 L F

.59195 .45221 m .60011 .47028 L .58862 .45505 L .837 .943 .892 r

F

.54706 .26092 m .64999 .47549 L .60333 .4085 L .974 .684 .411 r

F

.64999 .47549 m .64507 .47351 L .60333 .4085 L F

.66081 .49803 m .65048 .49004 L .60333 .4085 L F

.63294 .51157 m .65364 .53695 L .62127 .56446 L .791 .755 .82 r

F

.60333 .4085 m .72176 .62508 L .75249 .79972 L .974 .684 .411 r

F

.68862 .556 m .72176 .62508 L .60333 .4085 L F

.62306 .46883 m .61505 .48931 L .61192 .46022 L .83 .87 .874 r

F

.52807 .23598 m .54706 .26092 L .62506 .46549 L .974 .684 .411 r

F

.61837 .4628 m .62506 .46549 L .75249 .79972 L F

.52807 .23598 m .62506 .46549 L .61837 .4628 L F

.60638 .458 m .61192 .46022 L .60011 .47028 L .837 .943 .892 r

F

.61192 .46022 m .61505 .48931 L .60011 .47028 L .83 .87 .874 r

F

.67251 .62525 m .6726 .68987 L .6406 .65231 L .725 .62 .74 r

F

.64518 .59288 m .67251 .62525 L .6406 .65231 L .748 .664 .768 r

F

.63294 .51157 m .62127 .56446 L .60025 .53938 L .791 .755 .82 r

F

.61505 .48931 m .63294 .51157 L .60025 .53938 L .811 .808 .847 r

F

.52807 .23598 m .75249 .79972 L .71096 .752 L .974 .684 .411 r

F

.62273 .42598 m .63367 .44169 L .61192 .46022 L .837 .943 .892 r

F

.60638 .458 m .60011 .47028 L .59195 .45221 L F

.52345 .52653 m .55812 .57471 L .52339 .55809 L .851 .582 .531 r

F

.52339 .55809 m .55812 .57471 L .55836 .60672 L F

.52339 .55809 m .55836 .60672 L .52333 .59021 L F

.52333 .59021 m .55836 .60672 L .55861 .63928 L F

.52333 .59021 m .55861 .63928 L .52327 .62289 L F

.49462 .57113 m .52333 .59021 L .52327 .62289 L .896 .623 .515 r

F

.52327 .62289 m .55861 .63928 L .55886 .67241 L .851 .582 .531 r

F

.49462 .57113 m .52327 .62289 L .49431 .60394 L .896 .623 .515 r

F

.48243 .85095 m .52158 .89725 L .48997 .92398 L .698 .571 .708 r

F

.51404 .82418 m .52158 .89725 L .48243 .85095 L F

.48158 .78718 m .51404 .82418 L .48243 .85095 L .725 .62 .74 r

F

.51331 .76027 m .51404 .82418 L .48158 .78718 L F

.4851 .72881 m .51331 .76027 L .48158 .78718 L .748 .664 .768 r

F

.58104 .64734 m .57688 .70635 L .54902 .67453 L F

.52309 .72445 m .55937 .74045 L .55964 .77539 L .851 .582 .531 r

F

.55663 .6194 m .54902 .67453 L .52437 .64682 L .77 .708 .794 r

F

.55663 .6194 m .58104 .64734 L .54902 .67453 L F

.58893 .59194 m .58104 .64734 L .55663 .6194 L F

.49333 .70594 m .52309 .72445 L .52302 .75954 L .896 .623 .515 r

F

.52309 .72445 m .55964 .77539 L .52302 .75954 L .851 .582 .531 r

F

.53499 .5949 m .52437 .64682 L .50242 .62261 L .791 .755 .82 r

F

.53499 .5949 m .55663 .6194 L .52437 .64682 L F

.55788 .54325 m .60096 .58825 L .55812 .57471 L .804 .542 .542 r

F

.56761 .56716 m .55663 .6194 L .53499 .5949 L .791 .755 .82 r

F

.56761 .56716 m .58893 .59194 L .55663 .6194 L F

.49299 .74119 m .52302 .75954 L .52296 .79526 L .896 .623 .515 r

F

.49333 .70594 m .52302 .75954 L .49299 .74119 L F

.49493 .53889 m .52339 .55809 L .52333 .59021 L F

.49493 .53889 m .52333 .59021 L .49462 .57113 L F

.51596 .57367 m .53499 .5949 L .50242 .62261 L .811 .808 .847 r

F

.52345 .52653 m .55788 .54325 L .55812 .57471 L .851 .582 .531 r

F

.54895 .54558 m .53499 .5949 L .51596 .57367 L .811 .808 .847 r

F

.54895 .54558 m .56761 .56716 L .53499 .5949 L F

.49265 .7771 m .52296 .79526 L .52289 .83166 L .896 .623 .515 r

F

.49299 .74119 m .52296 .79526 L .49265 .7771 L F

.5235 .4955 m .55788 .54325 L .52345 .52653 L .851 .582 .531 r

F

.49523 .50721 m .52345 .52653 L .52339 .55809 L .896 .623 .515 r

F

.49523 .50721 m .52339 .55809 L .49493 .53889 L F

.5331 .52736 m .54895 .54558 L .51596 .57367 L .83 .87 .874 r

F

.4923 .81367 m .52289 .83166 L .52282 .86873 L .896 .623 .515 r

F

.49265 .7771 m .52289 .83166 L .4923 .81367 L F

.4923 .81367 m .52282 .86873 L .49194 .85093 L F

.59973 .62421 m .53207 .8856 L .52788 .54167 L .807 .799 .844 r

F

.53207 .8856 m .48766 1.05716 L .50197 .87371 L F

.49194 .85093 m .52282 .86873 L .5228 .88194 L .896 .623 .515 r

F

.49194 .85093 m .5228 .88194 L .5053 .87503 L F

.38782 .93108 m .46696 1.03948 L .42685 .97735 L .799 .318 0 r

F

.38782 .93108 m .44581 1.02141 L .46696 1.03948 L F

.35501 .89453 m .44581 1.02141 L .38782 .93108 L F

.41932 .9044 m .42685 .97735 L .38782 .93108 L .698 .571 .708 r

F

.3866 .86774 m .38782 .93108 L .35501 .89453 L .725 .62 .74 r

F

.3866 .86774 m .41932 .9044 L .38782 .93108 L F

.41932 .9044 m .45839 .95068 L .42685 .97735 L .698 .571 .708 r

F

.45086 .87769 m .45839 .95068 L .41932 .9044 L F

.41823 .84092 m .41932 .9044 L .3866 .86774 L .725 .62 .74 r

F

.41823 .84092 m .45086 .87769 L .41932 .9044 L F

.42685 .97735 m .48766 1.05716 L .48348 1.05072 L .799 .318 0 r

F

.42685 .97735 m .46696 1.03948 L .48766 1.05716 L F

.45839 .95068 m .48348 1.05072 L .42685 .97735 L .655 .498 .658 r

F

.45086 .87769 m .48997 .92398 L .45839 .95068 L .698 .571 .708 r

F

.48243 .85095 m .48997 .92398 L .45086 .87769 L F

.44989 .81406 m .45086 .87769 L .41823 .84092 L .725 .62 .74 r

F

.44989 .81406 m .48243 .85095 L .45086 .87769 L F

.35501 .89453 m .42418 1.00294 L .44581 1.02141 L .799 .318 0 r

F

.32592 .86397 m .42418 1.00294 L .35501 .89453 L F

.35769 .83699 m .35501 .89453 L .32592 .86397 L .748 .664 .768 r

F

.35769 .83699 m .3866 .86774 L .35501 .89453 L F

.38949 .80999 m .3866 .86774 L .35769 .83699 L F

.38949 .80999 m .41823 .84092 L .3866 .86774 L F

.42132 .78296 m .41823 .84092 L .38949 .80999 L F

.42132 .78296 m .44989 .81406 L .41823 .84092 L F

.33156 .8107 m .32592 .86397 L .29956 .8379 L .77 .708 .794 r

F

.33156 .8107 m .35769 .83699 L .32592 .86397 L F

.36361 .78346 m .35769 .83699 L .33156 .8107 L F

.36361 .78346 m .38949 .80999 L .35769 .83699 L F

.30776 .78822 m .29956 .8379 L .27544 .81571 L .791 .755 .82 r

F

.30776 .78822 m .33156 .8107 L .29956 .8379 L F

.34011 .76069 m .33156 .8107 L .30776 .78822 L F

.34011 .76069 m .36361 .78346 L .33156 .8107 L F

.2861 .76937 m .27544 .81571 L .25341 .7972 L .811 .808 .847 r

F

.2861 .76937 m .30776 .78822 L .27544 .81571 L F

.26666 .75436 m .25341 .7972 L .23353 .78258 L .83 .87 .874 r

F

.26666 .75436 m .2861 .76937 L .25341 .7972 L F

.48158 .78718 m .48243 .85095 L .44989 .81406 L .725 .62 .74 r

F

.4532 .7559 m .44989 .81406 L .42132 .78296 L .748 .664 .768 r

F

.4532 .7559 m .48158 .78718 L .44989 .81406 L F

.44788 .80843 m .46701 .83086 L .46668 .85149 L .979 .709 .442 r

F

.47631 .86357 m .48766 1.05716 L .25339 .77547 L .807 .799 .844 r

F

.44788 .80843 m .46668 .85149 L .45753 .84001 L .979 .709 .442 r

F

.46701 .83086 m .49194 .85093 L .49177 .86968 L .941 .666 .488 r

F

.46701 .83086 m .49177 .86968 L .47976 .86097 L F

.49194 .85093 m .5053 .87503 L .49177 .86968 L .896 .623 .515 r

F

.472 .51726 m .49493 .53889 L .49462 .57113 L .941 .666 .488 r

F

.47148 .54963 m .49462 .57113 L .49431 .60394 L F

.472 .51726 m .49462 .57113 L .47148 .54963 L F

.47148 .54963 m .49431 .60394 L .47096 .58258 L F

.4851 .72881 m .48158 .78718 L .4532 .7559 L .748 .664 .768 r

F

.39569 .7562 m .38949 .80999 L .36361 .78346 L .77 .708 .794 r

F

.39569 .7562 m .42132 .78296 L .38949 .80999 L F

.4278 .7289 m .42132 .78296 L .39569 .7562 L F

.4278 .7289 m .4532 .7559 L .42132 .78296 L F

.45996 .70157 m .4532 .7559 L .4278 .7289 L F

.45996 .70157 m .4851 .72881 L .4532 .7559 L F

.45309 .55877 m .47096 .58258 L .47043 .61613 L .979 .709 .442 r

F

.3725 .73314 m .36361 .78346 L .34011 .76069 L .791 .755 .82 r

F

.3725 .73314 m .39569 .7562 L .36361 .78346 L F

.40492 .70556 m .39569 .7562 L .3725 .73314 L F

.40492 .70556 m .4278 .7289 L .39569 .7562 L F

.43738 .67794 m .4278 .7289 L .40492 .70556 L F

.43738 .67794 m .45996 .70157 L .4278 .7289 L F

.46988 .65029 m .45996 .70157 L .43738 .67794 L F

.45238 .59248 m .47043 .61613 L .46988 .65029 L .979 .709 .442 r

F

.45309 .55877 m .47043 .61613 L .45238 .59248 L F

.31882 .74151 m .30776 .78822 L .2861 .76937 L .811 .808 .847 r

F

.31882 .74151 m .34011 .76069 L .30776 .78822 L F

.35158 .71362 m .34011 .76069 L .31882 .74151 L F

.35158 .71362 m .3725 .73314 L .34011 .76069 L F

.38438 .68569 m .3725 .73314 L .35158 .71362 L F

.38438 .68569 m .40492 .70556 L .3725 .73314 L F

.46933 .68508 m .49333 .70594 L .49299 .74119 L .941 .666 .488 r

F

.46988 .65029 m .49333 .70594 L .46933 .68508 L F

.41722 .65773 m .40492 .70556 L .38438 .68569 L .811 .808 .847 r

F

.41722 .65773 m .43738 .67794 L .40492 .70556 L F

.4501 .62974 m .43738 .67794 L .41722 .65773 L F

.4501 .62974 m .45397 .63376 L .43738 .67794 L F

.45397 .63376 m .46988 .65029 L .46356 .65567 L F

.45397 .63376 m .46356 .65567 L .43738 .67794 L F

.43289 .61274 m .44194 .62168 L .41722 .65773 L .83 .87 .874 r

F

.44194 .62168 m .4501 .62974 L .44436 .63462 L F

.44194 .62168 m .44436 .63462 L .41722 .65773 L F

.43419 .57137 m .43941 .60067 L .43925 .60732 L .891 .701 .187 r

F

.43925 .60732 m .4501 .62974 L .43289 .61274 L .83 .87 .874 r

F

.43941 .60067 m .44035 .60268 L .44203 .61207 L .987 .737 .354 r

F

.43941 .60067 m .44203 .61207 L .44134 .61088 L F

.44035 .60268 m .45167 .62682 L .45163 .62844 L F

.45097 .6273 m .4501 .62974 L .43925 .60732 L .83 .87 .874 r

F

.45238 .59248 m .46988 .65029 L .45167 .62682 L .979 .709 .442 r

F

.45163 .62844 m .46988 .65029 L .4501 .62974 L .811 .808 .847 r

F

.45167 .62682 m .46988 .65029 L .45246 .62942 L .979 .709 .442 r

F

.45163 .62844 m .46933 .68508 L .45094 .66179 L F

.45167 .62682 m .45233 .62901 L .45163 .62844 L F

.45233 .62901 m .46933 .68508 L .45163 .62844 L F

.46626 .58431 m .48301 .60172 L .45163 .62844 L .83 .87 .874 r

F

.45081 .62775 m .45163 .62844 L .4501 .62974 L F

.45097 .6273 m .45163 .62844 L .45081 .62775 L F

.44203 .61207 m .45163 .62844 L .45094 .66179 L .987 .737 .354 r

F

.44035 .60268 m .45163 .62844 L .44203 .61207 L F

.44025 .56615 m .45238 .59248 L .45167 .62682 L F

.44025 .56615 m .45167 .62682 L .43941 .60067 L F

.46626 .58431 m .45163 .62844 L .45097 .6273 L .83 .87 .874 r

F

.48301 .60172 m .46988 .65029 L .45163 .62844 L .811 .808 .847 r

F

.45246 .62942 m .46988 .65029 L .46933 .68508 L .979 .709 .442 r

F

.43925 .60732 m .45094 .66179 L .43856 .63585 L .987 .737 .354 r

F

.43941 .60067 m .44102 .60923 L .43925 .60732 L F

.44102 .60923 m .45094 .66179 L .43925 .60732 L F

.44107 .53225 m .45309 .55877 L .45238 .59248 L F

.44107 .53225 m .45238 .59248 L .44025 .56615 L F

.45261 .57099 m .46626 .58431 L .43925 .60732 L .837 .943 .892 r

F

.43673 .60462 m .43925 .60732 L .43289 .61274 L F

.43787 .6022 m .43925 .60732 L .43673 .60462 L F

.43514 .58539 m .43925 .60732 L .43574 .59431 L .891 .701 .187 r

F

.43419 .57137 m .43925 .60732 L .43514 .58539 L F

.43509 .53664 m .44025 .56615 L .43941 .60067 L F

.43509 .53664 m .43941 .60067 L .43419 .57137 L F

.43378 .58703 m .43289 .61274 L .4187 .59989 L .837 .943 .892 r

F

.43419 .57137 m .43546 .5901 L .43378 .58703 L .891 .701 .187 r

F

.43546 .5901 m .43574 .59431 L .43378 .58703 L F

.42786 .57616 m .4187 .59989 L .40857 .59261 L .785 .997 .855 r

F

.43597 .50255 m .44107 .53225 L .44025 .56615 L .891 .701 .187 r

F

.43597 .50255 m .44025 .56615 L .43509 .53664 L F

.43683 .46909 m .44188 .49897 L .44107 .53225 L F

.43683 .46909 m .44107 .53225 L .43597 .50255 L F

.43922 .503 m .43509 .53664 L .43419 .57137 L 0 0 .067 r

F

.43922 .503 m .43419 .57137 L .43835 .53796 L F

.43835 .53796 m .43419 .57137 L .43378 .58703 L F

.45261 .57099 m .43787 .6022 L .43378 .58703 L .837 .943 .892 r

F

.43787 .6022 m .43289 .61274 L .43378 .58703 L F

.43378 .58703 m .43856 .63585 L .43327 .60676 L .891 .701 .187 r

F

.43574 .59431 m .43856 .63585 L .43378 .58703 L F

.43835 .53796 m .43378 .58703 L .43528 .57949 L 0 0 .067 r

F

.44312 .56315 m .45261 .57099 L .43378 .58703 L .785 .997 .855 r

F

.43835 .53796 m .43601 .56965 L .4376 .56786 L 0 0 .067 r

F

.43601 .56965 m .43528 .57949 L .4376 .56786 L F

.45445 .49314 m .472 .51726 L .47148 .54963 L .979 .709 .442 r

F

.45445 .49314 m .47148 .54963 L .45378 .52566 L F

.44267 .46629 m .45445 .49314 L .45378 .52566 L .987 .737 .354 r

F

.44188 .49897 m .45378 .52566 L .45309 .55877 L F

.44267 .46629 m .45378 .52566 L .44188 .49897 L F

.44188 .49897 m .45309 .55877 L .44107 .53225 L F

.45766 .49825 m .43835 .53796 L .4376 .56786 L 0 0 .303 r

F

.44247 .56346 m .44312 .56315 L .4376 .56786 L .483 .834 .563 r

F

.44312 .56315 m .43378 .58703 L .43658 .573 L .785 .997 .855 r

F

.44312 .56315 m .43658 .573 L .4376 .56786 L F

.43944 .56619 m .4376 .56786 L .43746 .5736 L 0 0 .303 r

F

.45766 .49825 m .4376 .56786 L .43944 .56619 L F

.45378 .52566 m .47148 .54963 L .47096 .58258 L .979 .709 .442 r

F

.45378 .52566 m .47096 .58258 L .45309 .55877 L F

.45766 .49825 m .43944 .56619 L .45694 .53416 L 0 0 .303 r

F

.43944 .56619 m .43746 .5736 L .44247 .56346 L F

.43944 .56619 m .44247 .56346 L .45694 .53416 L F

.476 .53414 m .44312 .56315 L .44247 .56346 L .483 .834 .563 r

F

.476 .53414 m .44247 .56346 L .45661 .55067 L F

.43574 .59431 m .43925 .60732 L .43856 .63585 L .891 .701 .187 r

F

.45261 .57099 m .43925 .60732 L .43787 .6022 L .837 .943 .892 r

F

.47772 .53364 m .45261 .57099 L .44312 .56315 L .785 .997 .855 r

F

.476 .53414 m .47772 .53364 L .44312 .56315 L .483 .834 .563 r

F

.45694 .53416 m .43746 .5736 L .43655 .60993 L 0 0 .303 r

F

.48655 .54206 m .46626 .58431 L .45261 .57099 L .837 .943 .892 r

F

.47772 .53364 m .48655 .54206 L .45261 .57099 L .785 .997 .855 r

F

.45661 .55067 m .43655 .60993 L .45621 .57078 L 0 0 .303 r

F

.45694 .53416 m .45356 .54672 L .45661 .55067 L F

.45356 .54672 m .43655 .60993 L .45661 .55067 L F

.44082 .56423 m .44247 .56346 L .4376 .56786 L .483 .834 .563 r

F

.44055 .56436 m .44082 .56423 L .40857 .59261 L F

.44082 .56423 m .4376 .56786 L .40857 .59261 L F

.48655 .54206 m .49966 .55585 L .46626 .58431 L .837 .943 .892 r

F

.46626 .58431 m .45097 .6273 L .43925 .60732 L .83 .87 .874 r

F

.44134 .61088 m .44203 .61207 L .45094 .66179 L .987 .737 .354 r

F

.43856 .63585 m .45094 .66179 L .4502 .69742 L F

.43856 .63585 m .4502 .69742 L .43769 .67169 L F

.43327 .60676 m .43856 .63585 L .43769 .67169 L .891 .701 .187 r

F

.43327 .60676 m .43769 .67169 L .43234 .64284 L F

.45621 .57078 m .43655 .60993 L .43562 .64698 L 0 0 .303 r

F

.49553 .47607 m .5235 .4955 L .52345 .52653 L .896 .623 .515 r

F

.49553 .47607 m .52345 .52653 L .49523 .50721 L F

.473 .45419 m .49553 .47607 L .49523 .50721 L .941 .666 .488 r

F

.4725 .48545 m .49523 .50721 L .49493 .53889 L F

.473 .45419 m .49523 .50721 L .4725 .48545 L F

.4725 .48545 m .49493 .53889 L .472 .51726 L F

.51237 .50411 m .48655 .54206 L .47772 .53364 L .785 .997 .855 r

F

.51149 .50388 m .47772 .53364 L .476 .53414 L .483 .834 .563 r

F

.51149 .50388 m .51237 .50411 L .47772 .53364 L F

.5182 .47894 m .45694 .53416 L .45661 .55067 L .242 .076 .445 r

F

.47155 .54805 m .45661 .55067 L .45621 .57078 L F

.48439 .54581 m .476 .53414 L .45661 .55067 L .153 0 .104 r

F

.53207 .8856 m .50197 .87371 L .52788 .54167 L .807 .799 .844 r

F

.59973 .62421 m .60662 .8856 L .56048 .88774 L F

.59973 .62421 m .56048 .88774 L .53262 .88345 L F

.66709 .90496 m .76538 .9028 L .76755 .94017 L .683 .444 .554 r

F

.76755 .94017 m .77452 .90032 L .76538 .9028 L .564 .354 .554 r

F

.76755 .94017 m .77678 .93772 L .77452 .90032 L F

.5331 .52736 m .51596 .57367 L .49966 .55585 L .83 .87 .874 r

F

.52053 .51309 m .5331 .52736 L .49966 .55585 L .837 .943 .892 r

F

.52789 .5315 m .77678 .93772 L .5278 .66864 L .974 .684 .411 r

F

.52053 .51309 m .49966 .55585 L .48655 .54206 L .837 .943 .892 r

F

.51237 .50411 m .52053 .51309 L .48655 .54206 L .785 .997 .855 r

F

.52889 .52878 m .476 .53414 L .52789 .5315 L .153 0 .104 r

F

.5235 .4955 m .55765 .51232 L .55788 .54325 L .851 .582 .531 r

F

.55456 .48409 m .5331 .52736 L .52053 .51309 L .837 .943 .892 r

F

.54705 .47453 m .52053 .51309 L .51237 .50411 L .785 .997 .855 r

F

.54705 .47453 m .55456 .48409 L .52053 .51309 L F

.57144 .45374 m .55456 .48409 L .54705 .47453 L F

.57588 .45341 m .55456 .48409 L .57144 .45374 L F

.7533 .80065 m .76094 .8267 L .59973 .62421 L .807 .799 .844 r

F

.55765 .51232 m .59978 .52602 L .60037 .55688 L .804 .542 .542 r

F

.55765 .51232 m .60037 .55688 L .55788 .54325 L F

.55788 .54325 m .60037 .55688 L .60096 .58825 L F

.64518 .59288 m .6406 .65231 L .61309 .62013 L .748 .664 .768 r

F

.62127 .56446 m .61309 .62013 L .58893 .59194 L .77 .708 .794 r

F

.62127 .56446 m .64518 .59288 L .61309 .62013 L F

.60025 .53938 m .58893 .59194 L .56761 .56716 L .791 .755 .82 r

F

.60025 .53938 m .62127 .56446 L .58893 .59194 L F

.58198 .51746 m .56761 .56716 L .54895 .54558 L .811 .808 .847 r

F

.58198 .51746 m .60025 .53938 L .56761 .56716 L F

.61505 .48931 m .60025 .53938 L .58198 .51746 L F

.56659 .49884 m .54895 .54558 L .5331 .52736 L .83 .87 .874 r

F

.56659 .49884 m .58198 .51746 L .54895 .54558 L F

.60011 .47028 m .58198 .51746 L .56659 .49884 L F

.60011 .47028 m .61505 .48931 L .58198 .51746 L F

.55456 .48409 m .56659 .49884 L .5331 .52736 L .837 .943 .892 r

F

.58862 .45505 m .56659 .49884 L .55456 .48409 L F

.58862 .45505 m .60011 .47028 L .56659 .49884 L F

.57588 .45341 m .58862 .45505 L .55456 .48409 L .785 .997 .855 r

F

.5502 .47087 m .54705 .47453 L .54702 .47358 L .483 .834 .563 r

F

.55608 .45488 m .55984 .46309 L .5502 .47087 L .974 .684 .411 r

F

.58133 .38627 m .59773 .43253 L .55608 .45488 L F

.59773 .43253 m .60438 .45129 L .57144 .45374 L F

.59773 .43253 m .57144 .45374 L .55608 .45488 L F

.5826 .44324 m .58178 .44492 L .57144 .45374 L .483 .834 .563 r

F

.56231 .4611 m .57144 .45374 L .54705 .47453 L F

.56231 .4611 m .54705 .47453 L .5502 .47087 L F

.58696 .45258 m .58862 .45505 L .57588 .45341 L .785 .997 .855 r

F

.61655 .41527 m .58862 .45505 L .58178 .44492 L F

.61655 .41527 m .62273 .42598 L .58862 .45505 L F

.60438 .45129 m .77678 .93772 L .55608 .45488 L .974 .684 .411 r

F

.5826 .44324 m .57144 .45374 L .56231 .4611 L .483 .834 .563 r

F

.5826 .44324 m .56231 .4611 L .5502 .47087 L F

.5502 .47087 m .77678 .93772 L .52789 .5315 L .974 .684 .411 r

F

.55984 .46309 m .77678 .93772 L .5502 .47087 L F

.58178 .44492 m .58696 .45258 L .57588 .45341 L .785 .997 .855 r

F

.58178 .44492 m .57588 .45341 L .57144 .45374 L F

.52807 .23598 m .58133 .38627 L .55608 .45488 L .974 .684 .411 r

F

.54702 .47358 m .51237 .50411 L .51149 .50388 L .483 .834 .563 r

F

.54702 .47358 m .54705 .47453 L .51237 .50411 L F

.53137 .52853 m .51149 .50388 L .476 .53414 L .153 0 .104 r

F

.56825 .49711 m .51149 .50388 L .53137 .52853 L F

.56825 .49711 m .54702 .47358 L .51149 .50388 L F

.60518 .46565 m .54702 .47358 L .56825 .49711 L F

.61822 .41286 m .58178 .44492 L .5826 .44324 L .483 .834 .563 r

F

.61822 .41286 m .61655 .41527 L .58178 .44492 L F

.60518 .46565 m .5826 .44324 L .54702 .47358 L .153 0 .104 r

F

.52793 .45697 m .55608 .45488 L .52789 .5315 L .974 .684 .411 r

F

.52807 .23598 m .55608 .45488 L .52793 .45697 L F

.49966 .55585 m .48301 .60172 L .46626 .58431 L .83 .87 .874 r

F

.49961 .54314 m .45621 .57078 L .45547 .60815 L .242 .076 .445 r

F

.52789 .5315 m .476 .53414 L .48439 .54581 L .153 0 .104 r

F

.52789 .5315 m .48439 .54581 L .51799 .53992 L F

.51807 .51595 m .48439 .54581 L .49961 .54314 L .242 .076 .445 r

F

.48439 .54581 m .45621 .57078 L .49961 .54314 L F

.48301 .60172 m .50242 .62261 L .46988 .65029 L .811 .808 .847 r

F

.51596 .57367 m .50242 .62261 L .48301 .60172 L F

.46877 .72051 m .49299 .74119 L .49265 .7771 L .941 .666 .488 r

F

.46933 .68508 m .49299 .74119 L .46877 .72051 L F

.45094 .66179 m .46933 .68508 L .46877 .72051 L .979 .709 .442 r

F

.49966 .55585 m .51596 .57367 L .48301 .60172 L .83 .87 .874 r

F

.46819 .7566 m .49265 .7771 L .4923 .81367 L .941 .666 .488 r

F

.46877 .72051 m .49265 .7771 L .46819 .7566 L F

.4502 .69742 m .46877 .72051 L .46819 .7566 L .979 .709 .442 r

F

.45094 .66179 m .46877 .72051 L .4502 .69742 L F

.46761 .79338 m .4923 .81367 L .49194 .85093 L .941 .666 .488 r

F

.46819 .7566 m .4923 .81367 L .46761 .79338 L F

.44944 .73372 m .46819 .7566 L .46761 .79338 L .979 .709 .442 r

F

.4502 .69742 m .46819 .7566 L .44944 .73372 L F

.43769 .67169 m .4502 .69742 L .44944 .73372 L .987 .737 .354 r

F

.46761 .79338 m .49194 .85093 L .46701 .83086 L .941 .666 .488 r

F

.44867 .77072 m .46761 .79338 L .46701 .83086 L .979 .709 .442 r

F

.44944 .73372 m .46761 .79338 L .44867 .77072 L F

.4368 .70822 m .44944 .73372 L .44867 .77072 L .987 .737 .354 r

F

.43769 .67169 m .44944 .73372 L .4368 .70822 L F

.43234 .64284 m .43769 .67169 L .4368 .70822 L .891 .701 .187 r

F

.43497 .78343 m .44788 .80843 L .44749 .82741 L .987 .737 .354 r

F

.37098 .78212 m .45367 .84206 L .35032 .81378 L .807 .799 .844 r

F

.45367 .84206 m .45622 .8481 L .35032 .81378 L F

.46668 .85149 m .47631 .86357 L .46003 .85713 L F

.45622 .8481 m .46003 .85713 L .35032 .81378 L F

.46668 .85149 m .46003 .85713 L .45622 .8481 L F

.43497 .78343 m .43996 .80957 L .43465 .79697 L .987 .737 .354 r

F

.43497 .78343 m .44749 .82741 L .43996 .80957 L F

.44788 .80843 m .45753 .84001 L .44749 .82741 L .979 .709 .442 r

F

.46701 .83086 m .47976 .86097 L .46668 .85149 L .941 .666 .488 r

F

.44867 .77072 m .46701 .83086 L .44788 .80843 L .979 .709 .442 r

F

.4359 .74546 m .44867 .77072 L .44788 .80843 L .987 .737 .354 r

F

.4368 .70822 m .44867 .77072 L .4359 .74546 L F

.43139 .67962 m .4368 .70822 L .4359 .74546 L .891 .701 .187 r

F

.43234 .64284 m .4368 .70822 L .43139 .67962 L F

.4359 .74546 m .44788 .80843 L .43497 .78343 L .987 .737 .354 r

F

.43042 .71712 m .4359 .74546 L .43497 .78343 L .891 .701 .187 r

F

.43139 .67962 m .4359 .74546 L .43042 .71712 L F

.43562 .64698 m .43139 .67962 L .43042 .71712 L 0 0 .067 r

F

.43042 .71712 m .43497 .78343 L .42943 .75537 L .891 .701 .187 r

F

.52788 .54167 m .49177 .86968 L .43954 .83182 L .807 .799 .844 r

F

.42933 .75914 m .43954 .83182 L .42332 .82006 L F

.42943 .75537 m .43497 .78343 L .43465 .79697 L .891 .701 .187 r

F

.42943 .75537 m .43465 .79697 L .43003 .76415 L F

.42943 .75537 m .43403 .82215 L .42842 .79438 L F

.43047 .74755 m .42943 .75537 L .42933 .75914 L 0 0 .067 r

F

.43468 .68477 m .43042 .71712 L .42943 .75537 L F

.43562 .64698 m .43042 .71712 L .43468 .68477 L F

.45547 .60815 m .43562 .64698 L .43468 .68477 L 0 0 .303 r

F

.52788 .54167 m .43954 .83182 L .42933 .75914 L .807 .799 .844 r

F

.43468 .68477 m .42943 .75537 L .43047 .74755 L 0 0 .067 r

F

.43468 .68477 m .43047 .74755 L .43401 .71177 L F

.45471 .64627 m .43468 .68477 L .43401 .71177 L 0 0 .303 r

F

.45471 .64627 m .43401 .71177 L .44983 .66418 L F

.52788 .54167 m .42933 .75914 L .43401 .71177 L .807 .799 .844 r

F

.45471 .64627 m .44983 .66418 L .45464 .64971 L 0 0 .303 r

F

.45179 .65828 m .43401 .71177 L .43706 .68086 L .807 .799 .844 r

F

.52788 .54167 m .43401 .71177 L .45179 .65828 L F

.45547 .60815 m .43468 .68477 L .45471 .64627 L 0 0 .303 r

F

.52788 .54167 m .35032 .81378 L .51796 .55012 L .807 .799 .844 r

F

.45464 .64971 m .43372 .72333 L .45393 .68518 L 0 0 .303 r

F

.44983 .66418 m .43372 .72333 L .45464 .64971 L F

.44983 .66418 m .43401 .71177 L .43372 .72333 L F

.43706 .68086 m .43401 .71177 L .42165 .70447 L .807 .799 .844 r

F

.43401 .71177 m .42933 .75914 L .42604 .73573 L F

.43401 .71177 m .42604 .73573 L .42165 .70447 L F

.43401 .71177 m .43047 .74755 L .43372 .72333 L 0 0 .067 r

F

.43003 .76415 m .43465 .79697 L .43403 .82215 L .891 .701 .187 r

F

.43372 .72333 m .43047 .74755 L .42842 .79438 L 0 0 .067 r

F

.43047 .74755 m .42933 .75914 L .42842 .79438 L F

.42165 .70447 m .42933 .75914 L .37098 .78212 L .807 .799 .844 r

F

.42933 .75914 m .42332 .82006 L .37098 .78212 L F

.43465 .79697 m .44708 .84688 L .43403 .82215 L .987 .737 .354 r

F

.43996 .80957 m .44708 .84688 L .43465 .79697 L F

.43996 .80957 m .44749 .82741 L .44708 .84688 L F

.45367 .84206 m .46668 .85149 L .45622 .8481 L .807 .799 .844 r

F

.46668 .85149 m .49177 .86968 L .47631 .86357 L F

.44749 .82741 m .4664 .86906 L .44708 .84688 L .979 .709 .442 r

F

.45753 .84001 m .4664 .86906 L .44749 .82741 L F

.49148 .88261 m .48766 1.05716 L .47631 .86357 L .807 .799 .844 r

F

.50173 .8769 m .48766 1.05716 L .49177 .86968 L F

.46668 .85149 m .49158 .88891 L .4664 .86906 L .941 .666 .488 r

F

.49177 .86968 m .49148 .88261 L .47631 .86357 L .807 .799 .844 r

F

.47976 .86097 m .49158 .88891 L .46668 .85149 L .941 .666 .488 r

F

.52788 .54167 m .50197 .87371 L .49177 .86968 L .807 .799 .844 r

F

.51807 .51595 m .45547 .60815 L .51284 .55817 L .242 .076 .445 r

F

.51807 .51595 m .51284 .55817 L .51796 .55012 L F

.29983 .7261 m .2861 .76937 L .26666 .75436 L .83 .87 .874 r

F

.29983 .7261 m .31882 .74151 L .2861 .76937 L F

.33304 .69781 m .31882 .74151 L .29983 .7261 L F

.33304 .69781 m .35158 .71362 L .31882 .74151 L F

.36628 .66949 m .35158 .71362 L .33304 .69781 L F

.36628 .66949 m .38438 .68569 L .35158 .71362 L F

.39957 .64113 m .38438 .68569 L .36628 .66949 L F

.39957 .64113 m .41722 .65773 L .38438 .68569 L F

.43289 .61274 m .41722 .65773 L .39957 .64113 L F

.43746 .5736 m .43327 .60676 L .43234 .64284 L 0 0 .067 r

F

.43655 .60993 m .43234 .64284 L .43139 .67962 L F

.43746 .5736 m .43234 .64284 L .43655 .60993 L F

.43655 .60993 m .43139 .67962 L .43562 .64698 L F

.45621 .57078 m .43562 .64698 L .45547 .60815 L 0 0 .303 r

F

.51795 .55373 m .45547 .60815 L .45471 .64627 L .242 .076 .445 r

F

.51782 .59229 m .45471 .64627 L .45393 .68518 L F

.51795 .55373 m .45471 .64627 L .51782 .59229 L F

.51796 .55012 m .35032 .81378 L .25339 .77547 L .807 .799 .844 r

F

.51796 .55012 m .51284 .55817 L .51795 .55373 L .242 .076 .445 r

F

.51799 .53992 m .48439 .54581 L .49454 .55991 L .153 0 .104 r

F

.53137 .52853 m .52889 .52878 L .52789 .5315 L F

.5182 .47894 m .45661 .55067 L .47155 .54805 L .242 .076 .445 r

F

.5182 .47894 m .45621 .57078 L .51807 .51595 L F

.49454 .55991 m .48439 .54581 L .44055 .56436 L .153 0 .104 r

F

.45661 .55067 m .44247 .56346 L .44055 .56436 L .483 .834 .563 r

F

.48439 .54581 m .45661 .55067 L .44055 .56436 L .153 0 .104 r

F

.47597 .57573 m .44055 .56436 L .45775 .59125 L F

.49454 .55991 m .46559 .5623 L .47597 .57573 L F

.46559 .5623 m .44055 .56436 L .47597 .57573 L F

.43658 .573 m .43378 .58703 L .4187 .59989 L .785 .997 .855 r

F

.4376 .56786 m .43327 .60676 L .43746 .5736 L 0 0 .067 r

F

.43528 .57949 m .43327 .60676 L .4376 .56786 L F

.43528 .57949 m .43378 .58703 L .43327 .60676 L F

.4376 .56786 m .43084 .58163 L .42786 .57616 L .785 .997 .855 r

F

.43658 .573 m .43084 .58163 L .4376 .56786 L F

.43084 .58163 m .4187 .59989 L .42786 .57616 L F

.45753 .84001 m .46668 .85149 L .4664 .86906 L .979 .709 .442 r

F

.50197 .87371 m .50173 .8769 L .49177 .86968 L .807 .799 .844 r

F

.47976 .86097 m .49177 .86968 L .49158 .88891 L .941 .666 .488 r

F

.49177 .86968 m .52276 .9065 L .49158 .88891 L .896 .623 .515 r


F

.5053 .87503 m .52276 .9065 L .49177 .86968 L F

.32592 .86397 m .40208 .98406 L .42418 1.00294 L .799 .318 0 r

F

.29956 .8379 m .40208 .98406 L .32592 .86397 L F

.29956 .8379 m .37946 .96474 L .40208 .98406 L F

.27544 .81571 m .37946 .96474 L .29956 .8379 L F

.27544 .81571 m .35633 .94498 L .37946 .96474 L F

.25341 .7972 m .35633 .94498 L .27544 .81571 L F

.25341 .7972 m .33267 .92477 L .35633 .94498 L F

.23353 .78258 m .33267 .92477 L .25341 .7972 L F

.23353 .78258 m .30844 .90408 L .33267 .92477 L F

.21614 .77255 m .30844 .90408 L .23353 .78258 L F

.21614 .77255 m .28364 .88289 L .30844 .90408 L F

.2021 .76866 m .28364 .88289 L .21614 .77255 L F

.2021 .76866 m .25824 .8612 L .28364 .88289 L F

.19367 .77487 m .25824 .8612 L .2021 .76866 L F

.19367 .77487 m .23223 .83898 L .25824 .8612 L F

.20157 .8095 m .23223 .83898 L .19367 .77487 L F

.20157 .8095 m .20557 .81621 L .23223 .83898 L F

.25339 .77547 m .48766 1.05716 L .20557 .81621 L .807 .799 .844 r

F

.5053 .87503 m .5228 .88194 L .52276 .9065 L .896 .623 .515 r

F

.62273 .42598 m .61192 .46022 L .60638 .458 L .837 .943 .892 r

F

.62273 .42598 m .60638 .458 L .59195 .45221 L F

.64999 .47549 m .66081 .49803 L .64507 .47351 L .974 .684 .411 r

F

.66081 .49803 m .68862 .556 L .65048 .49004 L F

.63367 .44169 m .62306 .46883 L .61192 .46022 L .83 .87 .874 r

F

.68605 .5094 m .68862 .556 L .68088 .54261 L .77 .708 .794 r

F

.63367 .44169 m .64816 .46112 L .63146 .47533 L .83 .87 .874 r

F

.63367 .44169 m .63146 .47533 L .62306 .46883 L F

.64816 .46112 m .64078 .48558 L .63146 .47533 L .811 .808 .847 r

F

.64816 .46112 m .73016 .54618 L .63367 .44169 L 0 .011 .548 r

F

.63367 .44169 m .71023 .52055 L .62273 .42598 L F

.63367 .44169 m .73016 .54618 L .71023 .52055 L F

.62273 .42598 m .68981 .49429 L .61655 .41527 L F

.62273 .42598 m .71023 .52055 L .68981 .49429 L F

.61655 .41527 m .66889 .46739 L .61822 .41286 L F

.61655 .41527 m .68981 .49429 L .66889 .46739 L F

.61822 .41286 m .66889 .46739 L .64745 .43983 L F

.64745 .43983 m .59973 .62421 L .52788 .54167 L .807 .799 .844 r

F

.5228 .88194 m .56074 .92169 L .52276 .9065 L .851 .582 .531 r

F

.53262 .88345 m .56048 .88774 L .53116 .8891 L .807 .799 .844 r

F

.53346 .88358 m .56074 .92169 L .5228 .88194 L .851 .582 .531 r

F

.59686 .88605 m .60683 .89661 L .57197 .88721 L .804 .542 .542 r

F

.53346 .88358 m .56048 .88774 L .56074 .92169 L .851 .582 .531 r

F

.59686 .88605 m .60662 .8856 L .60683 .89661 L .804 .542 .542 r

F

.60662 .8856 m .66596 .87155 L .63942 .88407 L .807 .799 .844 r

F

.60662 .8856 m .66709 .90496 L .60683 .89661 L .753 .5 .549 r

F

.63261 .87944 m .66709 .90496 L .60662 .8856 L F

.75687 .82863 m .75802 .82808 L .76114 .83007 L .683 .444 .554 r

F

.72176 .62508 m .76904 .80986 L .76962 .81939 L .974 .684 .411 r

F

.72176 .62508 m .76962 .81939 L .75249 .79972 L F

.7421 .69237 m .74385 .7093 L .72679 .64398 L .698 .571 .708 r

F

.73488 .65243 m .7467 .70689 L .72176 .62508 L .974 .684 .411 r

F

.7421 .69237 m .7467 .70689 L .74385 .7093 L .698 .571 .708 r

F

.75172 .70687 m .7648 .73986 L .76662 .76984 L .974 .684 .411 r

F

.74385 .7093 m .80433 .78009 L .77208 .80729 L .655 .498 .658 r

F

.77574 .68233 m .80433 .78009 L .74385 .7093 L F

.7467 .70689 m .76904 .80986 L .72578 .64078 L .974 .684 .411 r

F

.7467 .70689 m .72578 .64078 L .72176 .62508 L F

.73627 .63594 m .77574 .68233 L .7467 .70689 L .698 .571 .708 r

F

.73627 .63594 m .7467 .70689 L .7421 .69237 L F

.66566 .48374 m .68605 .5094 L .6697 .52329 L .791 .755 .82 r

F

.66566 .48374 m .6697 .52329 L .65986 .50941 L F

.64816 .46112 m .66566 .48374 L .65069 .49647 L .811 .808 .847 r

F

.66566 .48374 m .65986 .50941 L .65069 .49647 L .791 .755 .82 r

F

.68605 .5094 m .68088 .54261 L .6697 .52329 L .77 .708 .794 r

F

.70946 .5383 m .7051 .59036 L .68862 .556 L .748 .664 .768 r

F

.73643 .57103 m .73627 .63594 L .71233 .60751 L .725 .62 .74 r

F

.73643 .57103 m .71233 .60751 L .70757 .59551 L F

.71233 .60751 m .73627 .63594 L .72679 .64398 L F

.73627 .63594 m .7421 .69237 L .72679 .64398 L .698 .571 .708 r

F

.76724 .80156 m .77208 .80729 L .76904 .80986 L .655 .498 .658 r

F

.76816 .60893 m .77574 .68233 L .73627 .63594 L .698 .571 .708 r

F

.73643 .57103 m .76816 .60893 L .73627 .63594 L .725 .62 .74 r

F

.76816 .60893 m .82315 .66574 L .73643 .57103 L 0 .011 .548 r

F

.76816 .60893 m .84051 .68807 L .82315 .66574 L F

.80767 .65533 m .84051 .68807 L .76816 .60893 L F

.76816 .60893 m .80767 .65533 L .77574 .68233 L .698 .571 .708 r

F

.77574 .68233 m .83662 .75286 L .80433 .78009 L .655 .498 .658 r

F

.80767 .65533 m .83662 .75286 L .77574 .68233 L F

.80767 .65533 m .85749 .70991 L .84051 .68807 L 0 .011 .548 r

F

.86894 .7256 m .85749 .70991 L .80767 .65533 L F

.80767 .65533 m .86894 .7256 L .83662 .75286 L .655 .498 .658 r

F

.73643 .57103 m .80539 .64291 L .70946 .5383 L 0 .011 .548 r

F

.73643 .57103 m .82315 .66574 L .80539 .64291 L F

.70946 .5383 m .78723 .61956 L .68605 .5094 L F

.70946 .5383 m .80539 .64291 L .78723 .61956 L F

.77208 .80729 m .80934 .78589 L .80433 .78009 L .564 .354 .554 r

F

.77208 .80729 m .77701 .81316 L .80934 .78589 L F

.80433 .78009 m .84171 .7586 L .83662 .75286 L F

.80433 .78009 m .80934 .78589 L .84171 .7586 L F

.83662 .75286 m .87411 .73127 L .86894 .7256 L F

.83662 .75286 m .84171 .7586 L .87411 .73127 L F

.86894 .7256 m .87411 .73127 L .85749 .70991 L 0 .011 .548 r

F

.68605 .5094 m .76865 .59566 L .66566 .48374 L F

.68605 .5094 m .78723 .61956 L .76865 .59566 L F

.66566 .48374 m .74963 .57121 L .64816 .46112 L F

.66566 .48374 m .76865 .59566 L .74963 .57121 L F

.64816 .46112 m .74963 .57121 L .73016 .54618 L F

.64745 .43983 m .87411 .73127 L .76962 .81939 L .807 .799 .844 r

F

.7533 .80065 m .76962 .81939 L .76094 .8267 L F

.64745 .43983 m .76962 .81939 L .7533 .80065 L F

.76324 .8661 m .77011 .82755 L .76114 .83007 L .564 .354 .554 r

F

.76324 .8661 m .77229 .8636 L .77011 .82755 L F

.76538 .9028 m .77229 .8636 L .76324 .8661 L F

.76538 .9028 m .77452 .90032 L .77229 .8636 L F

.75249 .79972 m .76962 .81939 L .77678 .93772 L .974 .684 .411 r

F

.64816 .46112 m .65069 .49647 L .64078 .48558 L .811 .808 .847 r

F

.71096 .752 m .75249 .79972 L .77678 .93772 L .974 .684 .411 r

F

.64745 .43983 m .7533 .80065 L .59973 .62421 L .807 .799 .844 r

F

.56374 .88759 m .60683 .89661 L .60754 .93406 L .804 .542 .542 r

F

.57197 .88721 m .60683 .89661 L .56374 .88759 L F

.63942 .88407 m .66596 .87155 L .6546 .88337 L .807 .799 .844 r

F

.63261 .87944 m .66596 .87155 L .66709 .90496 L .753 .5 .549 r

F

0 g

.73711 .51041 m

.7521 .53009 L

s

.68737 .44512 m

.73711 .51041 L

s

.64732 .39254 m

.68737 .44512 L

s

.7521 .53009 m

.75501 .57812 L

s

.87172 .40853 m

.91145 .46795 L

s

.62047 .03269 m

.87172 .40853 L

s

.49553 .47607 m

.51013 .48621 L

s

.51815 .49178 m

.5223 .49466 L

s

.12376 .23722 m

.43316 .57089 L

s

.45577 .4298 m .473 .45419 L .4725 .48545 L .979 .709 .442 r

F

0 g

.473 .45419 m

.49553 .47607 L

s

.45512 .46119 m .4725 .48545 L .472 .51726 L .979 .709 .442 r

F

.45577 .4298 m .4725 .48545 L .45512 .46119 L F

.44422 .40267 m .45577 .4298 L .45512 .46119 L .987 .737 .354 r

F

0 g

.45577 .4298 m

.473 .45419 L

s

.45512 .46119 m .472 .51726 L .45445 .49314 L .979 .709 .442 r

F

.44345 .4342 m .45512 .46119 L .45445 .49314 L .987 .737 .354 r

F

.44422 .40267 m .45512 .46119 L .44345 .4342 L F

0 g

.4627 1.20749 m

.97691 1.08657 L

s

.04535 .8881 m

.42641 1.17973 L

s

.42641 1.17973 m

.4627 1.20749 L

s

.43934 .3723 m .44422 .40267 L .44345 .4342 L .891 .701 .187 r

F

0 g

.44422 .40267 m

.45577 .4298 L

s

.44345 .4342 m .45445 .49314 L .44267 .46629 L .987 .737 .354 r

F

.43852 .40398 m .44345 .4342 L .44267 .46629 L .891 .701 .187 r

F

.43934 .3723 m .44345 .4342 L .43852 .40398 L F

.44335 .33774 m .43934 .3723 L .43852 .40398 L 0 0 .067 r

F

0 g

.44036 .37868 m

.44422 .40267 L

s

.46896 1.04119 m

.48766 1.05716 L

s

.76962 .81939 m

.87411 .73127 L

s

.64035 .9284 m

.66783 .90522 L

s

.48766 1.05716 m

.64035 .9284 L

s

.47696 .09179 m

.62047 .03269 L

s

.04535 .8881 m

.12376 .23722 L

s

.43852 .40398 m .44267 .46629 L .43768 .43624 L .891 .701 .187 r

F

.43768 .43624 m .44267 .46629 L .44188 .49897 L F

.44255 .36958 m .43852 .40398 L .43768 .43624 L 0 0 .067 r

F

.44335 .33774 m .43852 .40398 L .44255 .36958 L F

.43768 .43624 m .44188 .49897 L .43683 .46909 L .891 .701 .187 r

F

.46167 .29674 m .44335 .33774 L .44255 .36958 L 0 0 .303 r

F

0 g

.43934 .3723 m

.44335 .33774 L

s

.44255 .36958 m .43768 .43624 L .44174 .40201 L 0 0 .067 r

F

.44174 .40201 m .43768 .43624 L .43683 .46909 L F

.66709 .90496 m .76755 .94017 L .66836 .94231 L .683 .444 .554 r

F

.60683 .89661 m .66709 .90496 L .66836 .94231 L .753 .5 .549 r

F

.46104 .32875 m .44255 .36958 L .44174 .40201 L 0 0 .303 r

F

.46167 .29674 m .44255 .36958 L .46104 .32875 L F

.44092 .43505 m .43683 .46909 L .43597 .50255 L 0 0 .067 r

F

.44174 .40201 m .43683 .46909 L .44092 .43505 L F

.60683 .89661 m .66836 .94231 L .60754 .93406 L .753 .5 .549 r

F

.46167 .29674 m .52807 .23598 L .51898 .23949 L .669 .734 .898 r

F

0 g

.12376 .23722 m

.47696 .09179 L

s

.51898 .23949 m .46167 .29674 L .46104 .32875 L .242 .076 .445 r

F

0 g

.44335 .33774 m

.46167 .29674 L

s

.66836 .94231 m .77678 .93772 L .76755 .94017 L .64 .768 .941 r

F

.66836 .94231 m .7586 .91807 L .77678 .93772 L F

0 g

.76962 .81939 m

.77678 .93772 L

s

.60754 .93406 m .7586 .91807 L .66836 .94231 L .64 .768 .941 r

F

0 g

.66836 .94231 m

.76755 .94017 L

s

.63367 .44169 m

.63817 .44773 L

s

.46104 .32875 m .44174 .40201 L .46039 .36138 L 0 0 .303 r

F

.46039 .36138 m .44174 .40201 L .44092 .43505 L F

0 g

.76755 .94017 m

.76755 .94017 L

s

.44008 .4687 m .43597 .50255 L .43509 .53664 L 0 0 .067 r

F

.44092 .43505 m .43597 .50255 L .44008 .4687 L F

.60754 .93406 m .74 .89797 L .7586 .91807 L .64 .768 .941 r

F

.56074 .92169 m .74 .89797 L .60754 .93406 L F

0 g

.60754 .93406 m

.66836 .94231 L

s

.2498 .74386 m .23353 .78258 L .21614 .77255 L .837 .943 .892 r

F

.2498 .74386 m .26666 .75436 L .23353 .78258 L F

0 g

.23353 .78258 m

.23971 .78713 L

s

.2835 .71513 m .26666 .75436 L .2498 .74386 L .837 .943 .892 r

F

.2835 .71513 m .29983 .7261 L .26666 .75436 L F

.31724 .68637 m .29983 .7261 L .2835 .71513 L F

.31724 .68637 m .33304 .69781 L .29983 .7261 L F

.35102 .65758 m .33304 .69781 L .31724 .68637 L F

.35102 .65758 m .36628 .66949 L .33304 .69781 L F

.51888 .27173 m .46104 .32875 L .46039 .36138 L .242 .076 .445 r

F

.51898 .23949 m .46104 .32875 L .51888 .27173 L F

.38484 .62875 m .36628 .66949 L .35102 .65758 L .837 .943 .892 r

F

.38484 .62875 m .39957 .64113 L .36628 .66949 L F

.4187 .59989 m .39957 .64113 L .38484 .62875 L F

.4187 .59989 m .43289 .61274 L .39957 .64113 L F

.45972 .39462 m .44092 .43505 L .44008 .4687 L 0 0 .303 r

F

.46039 .36138 m .44092 .43505 L .45972 .39462 L F

.56074 .92169 m .72098 .87741 L .74 .89797 L .64 .768 .941 r

F

.52276 .9065 m .72098 .87741 L .56074 .92169 L F

0 g

.56074 .92169 m

.60754 .93406 L

s

.44008 .4687 m .43509 .53664 L .43922 .503 L 0 0 .067 r

F

0 g

.62273 .42598 m

.63367 .44169 L

s

.51888 .27173 m .46039 .36138 L .51877 .3046 L .242 .076 .445 r

F

.51877 .3046 m .46039 .36138 L .45972 .39462 L F

.45905 .4285 m .44008 .4687 L .43922 .503 L 0 0 .303 r

F

.45972 .39462 m .44008 .4687 L .45905 .4285 L F

.52276 .9065 m .70152 .85638 L .72098 .87741 L .64 .768 .941 r

F

.49158 .88891 m .70152 .85638 L .52276 .9065 L F

0 g

.52276 .9065 m

.56074 .92169 L

s

.2364 .73941 m .21614 .77255 L .2021 .76866 L .785 .997 .855 r

F

.2364 .73941 m .2498 .74386 L .21614 .77255 L F

0 g

.21614 .77255 m

.23353 .78258 L

s

.51898 .23949 m .52805 .26824 L .51888 .27173 L .517 .285 .503 r

F

.51898 .23949 m .52807 .23598 L .52805 .26824 L F

0 g

.46167 .29674 m

.51898 .23949 L

s

.51898 .23949 m

.51898 .23949 L

s

.52807 .23598 m

.64732 .39254 L

s

.27075 .71012 m .2498 .74386 L .2364 .73941 L .785 .997 .855 r

F

.27075 .71012 m .2835 .71513 L .2498 .74386 L F

.30514 .6808 m .2835 .71513 L .27075 .71012 L F

.30514 .6808 m .31724 .68637 L .2835 .71513 L F

.33957 .65144 m .31724 .68637 L .30514 .6808 L F

.33957 .65144 m .35102 .65758 L .31724 .68637 L F

.37405 .62204 m .35102 .65758 L .33957 .65144 L F

.37405 .62204 m .38484 .62875 L .35102 .65758 L F

.40857 .59261 m .38484 .62875 L .37405 .62204 L F

.40857 .59261 m .4187 .59989 L .38484 .62875 L F

.51866 .33811 m .45972 .39462 L .45905 .4285 L .242 .076 .445 r

F

.51877 .3046 m .45972 .39462 L .51866 .33811 L F

.45836 .46304 m .43922 .503 L .43835 .53796 L 0 0 .303 r

F

.45905 .4285 m .43922 .503 L .45836 .46304 L F

.49158 .88891 m .68159 .83484 L .70152 .85638 L .64 .768 .941 r

F

.4664 .86906 m .68159 .83484 L .49158 .88891 L F

0 g

.49158 .88891 m

.52276 .9065 L

s

.61655 .41527 m

.62273 .42598 L

s

.51888 .27173 m .52803 .30113 L .51877 .3046 L .517 .285 .503 r

F

.51888 .27173 m .52805 .26824 L .52803 .30113 L F

0 g

.51888 .27173 m

.51898 .23949 L

s

.51855 .37228 m .45905 .4285 L .45836 .46304 L .242 .076 .445 r

F

.51866 .33811 m .45905 .4285 L .51855 .37228 L F

.45836 .46304 m .43835 .53796 L .45766 .49825 L 0 0 .303 r

F

.4664 .86906 m .66119 .8128 L .68159 .83484 L .64 .768 .941 r

F

.44708 .84688 m .66119 .8128 L .4664 .86906 L F

0 g

.4664 .86906 m

.49158 .88891 L

s

.22881 .74491 m .2021 .76866 L .19367 .77487 L .483 .834 .563 r

F

.22881 .74491 m .2364 .73941 L .2021 .76866 L F

0 g

.2021 .76866 m

.21614 .77255 L

s

.51877 .3046 m .52801 .33465 L .51866 .33811 L .517 .285 .503 r

F

.51877 .3046 m .52803 .30113 L .52801 .33465 L F

0 g

.51877 .3046 m

.51888 .27173 L

s

.26399 .71491 m .2364 .73941 L .22881 .74491 L .483 .834 .563 r

F

.26399 .71491 m .27075 .71012 L .2364 .73941 L F

.29921 .68488 m .27075 .71012 L .26399 .71491 L F

.29921 .68488 m .30514 .6808 L .27075 .71012 L F

.33448 .6548 m .30514 .6808 L .29921 .68488 L F

.33448 .6548 m .33957 .65144 L .30514 .6808 L F

.3698 .62469 m .33957 .65144 L .33448 .6548 L F

.3698 .62469 m .37405 .62204 L .33957 .65144 L F

.40515 .59455 m .37405 .62204 L .3698 .62469 L F

.40515 .59455 m .40857 .59261 L .37405 .62204 L F

.44055 .56436 m .40857 .59261 L .40515 .59455 L F

.51843 .40713 m .45836 .46304 L .45766 .49825 L .242 .076 .445 r

F

.51855 .37228 m .45836 .46304 L .51843 .40713 L F

0 g

.62047 .03269 m

.62925 .34048 L

s

.51866 .33811 m .52799 .36884 L .51855 .37228 L .517 .285 .503 r

F

.51866 .33811 m .52801 .33465 L .52799 .36884 L F

0 g

.51866 .33811 m

.51877 .3046 L

s

.44708 .84688 m .6403 .79022 L .66119 .8128 L .64 .768 .941 r

F

.43403 .82215 m .6403 .79022 L .44708 .84688 L F

0 g

.44708 .84688 m

.4664 .86906 L

s

.51843 .40713 m .45766 .49825 L .51831 .44267 L .242 .076 .445 r

F

.51831 .44267 m .45766 .49825 L .45694 .53416 L F

.51855 .37228 m .52796 .4037 L .51843 .40713 L .517 .285 .503 r

F

.51855 .37228 m .52799 .36884 L .52796 .4037 L F

0 g

.51855 .37228 m

.51866 .33811 L

s

.43403 .82215 m .6189 .76709 L .6403 .79022 L .64 .768 .941 r

F

0 g

.63968 .70605 m

.97691 1.08657 L

s

.42842 .79438 m .6189 .76709 L .43403 .82215 L .64 .768 .941 r

F

0 g

.43403 .82215 m

.44708 .84688 L

s

.23803 .77844 m .19367 .77487 L .20157 .8095 L .153 0 .104 r

F

.23803 .77844 m .22881 .74491 L .19367 .77487 L F

.51831 .44267 m .45694 .53416 L .5182 .47894 L .242 .076 .445 r

F

.27453 .74734 m .22881 .74491 L .23803 .77844 L .153 0 .104 r

F

.27453 .74734 m .26399 .71491 L .22881 .74491 L F

.31108 .7162 m .26399 .71491 L .27453 .74734 L F

.31108 .7162 m .29921 .68488 L .26399 .71491 L F

.34767 .68503 m .29921 .68488 L .31108 .7162 L F

.34767 .68503 m .33448 .6548 L .29921 .68488 L F

.38432 .65381 m .33448 .6548 L .34767 .68503 L F

.38432 .65381 m .3698 .62469 L .33448 .6548 L F

.42101 .62255 m .3698 .62469 L .38432 .65381 L F

.42101 .62255 m .40515 .59455 L .3698 .62469 L F

.45775 .59125 m .40515 .59455 L .42101 .62255 L F

.45775 .59125 m .44055 .56436 L .40515 .59455 L F

0 0 0 r

.01 w

[ .015 ] 0 setdash

.27549 .44467 m

.38719 .56282 L

s

.38719 .56282 m

.41181 .58887 L

s

.51843 .40713 m .52794 .43927 L .51831 .44267 L .517 .285 .503 r

F

.51843 .40713 m .52796 .4037 L .52794 .43927 L F

0 g

.5 Mabswid

[ ] 0 setdash

.51843 .40713 m

.51855 .37228 L

s

.52795 .42655 m

.52807 .23598 L

s

.61822 .41286 m .64745 .43983 L .64216 .43414 L 0 .011 .548 r

F

.64216 .43414 m .5826 .44324 L .60518 .46565 L .153 0 .104 r

F

0 g

.63534 .55388 m

.63968 .70605 L

s

.64216 .43414 m .61822 .41286 L .5826 .44324 L .153 0 .104 r

F

.42842 .79438 m .59697 .74339 L .6189 .76709 L .64 .768 .941 r

F

.43372 .72333 m .42842 .79438 L .43273 .76267 L 0 0 .067 r

F

.43273 .76267 m .59697 .74339 L .42842 .79438 L .64 .768 .941 r

F

0 g

.42842 .79438 m

.43403 .82215 L

s

.51831 .44267 m .52792 .47556 L .5182 .47894 L .517 .285 .503 r

F

.51831 .44267 m .52794 .43927 L .52792 .47556 L F

0 g

.51831 .44267 m

.51843 .40713 L

s

.45393 .68518 m .43372 .72333 L .43273 .76267 L 0 0 .303 r

F

.5182 .47894 m .5279 .51259 L .51807 .51595 L .517 .285 .503 r

F

.5182 .47894 m .52792 .47556 L .5279 .51259 L F

0 g

.5182 .47894 m

.51831 .44267 L

s

.43273 .76267 m .57449 .71909 L .59697 .74339 L .64 .768 .941 r

F

.45314 .7249 m .57449 .71909 L .43273 .76267 L F

.45393 .68518 m .43273 .76267 L .45314 .7249 L 0 0 .303 r

F

0 g

.42842 .79438 m

.43273 .76267 L

s

.51807 .51595 m .52788 .55039 L .51795 .55373 L .517 .285 .503 r

F

.51807 .51595 m .5279 .51259 L .52788 .55039 L F

0 g

.51807 .51595 m

.5182 .47894 L

s

.23803 .77844 m .20557 .81621 L .20157 .8095 L .517 .285 .503 r

F

0 g

.19367 .77487 m

.20157 .8095 L

s

.23803 .77844 m .24213 .78506 L .20557 .81621 L .517 .285 .503 r

F

0 g

.20557 .81621 m

.46896 1.04119 L

s

.27453 .74734 m .24213 .78506 L .23803 .77844 L .517 .285 .503 r

F

0 g

.20157 .8095 m

.23803 .77844 L

s

.27453 .74734 m .27874 .75388 L .24213 .78506 L .517 .285 .503 r

F

.31108 .7162 m .27874 .75388 L .27453 .74734 L F

0 g

.23803 .77844 m

.27453 .74734 L

s

.31108 .7162 m .3154 .72266 L .27874 .75388 L .517 .285 .503 r

F

.34767 .68503 m .3154 .72266 L .31108 .7162 L F

0 g

.27453 .74734 m

.31108 .7162 L

s

.34767 .68503 m .3521 .6914 L .3154 .72266 L .517 .285 .503 r

F

.38432 .65381 m .3521 .6914 L .34767 .68503 L F

0 g

.31108 .7162 m

.34767 .68503 L

s

.20557 .81621 m

.29024 .74409 L

s

.38432 .65381 m .38885 .66009 L .3521 .6914 L .517 .285 .503 r

F

.42101 .62255 m .38885 .66009 L .38432 .65381 L F

0 g

.34767 .68503 m

.38432 .65381 L

s

.51769 .63167 m .45393 .68518 L .45314 .7249 L .242 .076 .445 r

F

.51782 .59229 m .45393 .68518 L .51769 .63167 L F

.42101 .62255 m .42565 .62875 L .38885 .66009 L .517 .285 .503 r

F

.45775 .59125 m .42565 .62875 L .42101 .62255 L F

0 g

.38432 .65381 m

.42101 .62255 L

s

.45775 .59125 m .4625 .59736 L .42565 .62875 L .517 .285 .503 r

F

.49454 .55991 m .4625 .59736 L .45775 .59125 L F

0 g

.42101 .62255 m

.45775 .59125 L

s

.49454 .55991 m .49939 .56594 L .4625 .59736 L .517 .285 .503 r

F

0 g

.29024 .74409 m

.47582 .58602 L

s

.53137 .52853 m .49939 .56594 L .49454 .55991 L .517 .285 .503 r

F

0 g

.45775 .59125 m

.49454 .55991 L

s

.51799 .53992 m

.51807 .51595 L

s

.52789 .5315 m

.52795 .42655 L

s

.49454 .55991 m

.51799 .53992 L

s

.51799 .53992 m

.52789 .5315 L

s

.53137 .52853 m .53633 .53447 L .49939 .56594 L .517 .285 .503 r

F

0 g

.52788 .54167 m

.52789 .5315 L

s

.51796 .55012 m

.51799 .53992 L

s

.51796 .55012 m

.52788 .54167 L

s

.47582 .58602 m

.51796 .55012 L

s

.56825 .49711 m .53633 .53447 L .53137 .52853 L .517 .285 .503 r

F

0 g

.52789 .5315 m

.53137 .52853 L

s

.56825 .49711 m .57333 .50297 L .53633 .53447 L .517 .285 .503 r

F

.60518 .46565 m .57333 .50297 L .56825 .49711 L F

0 g

.53137 .52853 m

.56825 .49711 L

s

.60518 .46565 m .61036 .47142 L .57333 .50297 L .517 .285 .503 r

F

.64216 .43414 m .61036 .47142 L .60518 .46565 L F

0 g

.56825 .49711 m

.60518 .46565 L

s

.64216 .43414 m .64745 .43983 L .61036 .47142 L .517 .285 .503 r

F

0 g

.64216 .43414 m

.64216 .43414 L

s

.60518 .46565 m

.64216 .43414 L

s

.62925 .34048 m

.63534 .55388 L

s

.61822 .41286 m

.64216 .43414 L

s

.52788 .54167 m

.64745 .43983 L

s

.64745 .43983 m

.87411 .73127 L

s

.51795 .55373 m .52785 .58898 L .51782 .59229 L .517 .285 .503 r

F

.51795 .55373 m .52788 .55039 L .52785 .58898 L F

0 g

.51795 .55373 m

.51796 .55012 L

s

.45314 .7249 m .55144 .69419 L .57449 .71909 L .64 .768 .941 r

F

.51756 .67189 m .55144 .69419 L .45314 .7249 L F

.51769 .63167 m .45314 .7249 L .51756 .67189 L .242 .076 .445 r

F

0 g

.43273 .76267 m

.45314 .7249 L

s

.51782 .59229 m .52783 .62839 L .51769 .63167 L .517 .285 .503 r

F

.51782 .59229 m .52785 .58898 L .52783 .62839 L F

0 g

.51782 .59229 m

.51795 .55373 L

s

.51756 .67189 m .5278 .66864 L .55144 .69419 L .64 .768 .941 r

F

.51769 .63167 m .5278 .66864 L .51756 .67189 L .517 .285 .503 r

F

0 g

.45314 .7249 m

.51756 .67189 L

s

.51769 .63167 m .52783 .62839 L .5278 .66864 L .517 .285 .503 r

F

0 g

.51769 .63167 m

.51782 .59229 L

s

.5278 .66864 m

.52788 .54167 L

s

.5278 .66864 m

.77678 .93772 L

s

.51756 .67189 m

.51769 .63167 L

s

.63968 .70605 m

.04535 .8881 L

s

.25 Mabswid

.08969 .22307 m

.62525 0 L

s

.17823 .18619 m

.18363 .19228 L

s

[(-2.5)] .16742 .174 .88653 1 Mshowa

.28646 .14111 m

.29165 .14738 L

s

[(0)] .27607 .12856 .82829 1 Mshowa

.39866 .09438 m

.40363 .10083 L

s

[(2.5)] .38872 .08147 .77004 1 Mshowa

.51506 .04589 m

.51979 .05253 L

s

[(5)] .50562 .03262 .71179 1 Mshowa

.125 Mabswid

.19957 .1773 m

.20279 .18098 L

s

.22106 .16835 m

.22425 .17205 L

s

.2427 .15933 m

.24587 .16306 L

s

.2645 .15025 m

.26765 .154 L

s

.30857 .1319 m

.31167 .13568 L

s

.33085 .12262 m

.33392 .12643 L

s

.35329 .11327 m

.35633 .1171 L

s

.37589 .10386 m

.3789 .10771 L

s

.4216 .08482 m

.42455 .08872 L

s

.44471 .0752 m

.44763 .07911 L

s

.46798 .0655 m

.47088 .06944 L

s

.49144 .05573 m

.4943 .05969 L

s

.15704 .19501 m

.16031 .19865 L

s

.13601 .20377 m

.1393 .20739 L

s

.11512 .21248 m

.11843 .21607 L

s

.09437 .22112 m

.09771 .22469 L

s

.53887 .03598 m

.54167 .03998 L

s

.56285 .02599 m

.56563 .03001 L

s

.58702 .01592 m

.58976 .01997 L

s

.61137 .00578 m

.61408 .00985 L

s

.25 Mabswid

0 .90712 m

.44459 1.23738 L

s

.08421 .96968 m

.08509 .96158 L

s

[(-5)] .08245 .98588 .1086 -1 Mshowa

.24505 1.08915 m

.2456 1.08103 L

s

[(0)] .24395 1.10541 .06746 -1 Mshowa

.38494 1.19307 m

.38522 1.18493 L

s

[(5)] .3844 1.20936 .03353 -1 Mshowa

.125 Mabswid

.11828 .99498 m

.11876 .99012 L

s

.15135 1.01955 m

.1518 1.01468 L

s

.18348 1.04342 m

.18388 1.03855 L

s

.2147 1.06661 m

.21507 1.06173 L

s

.27457 1.11108 m

.27486 1.1062 L

s

.30328 1.13241 m

.30354 1.12753 L

s

.33123 1.15317 m

.33146 1.14829 L

s

.35844 1.17339 m

.35864 1.1685 L

s

.04911 .9436 m

.04969 .93875 L

s

.01293 .91673 m

.01355 .91188 L

s

.41076 1.21225 m

.4109 1.20737 L

s

.43593 1.23095 m

.43603 1.22606 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
 ImageSize->{357.312, 409.188},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"},
 CellLabel->"From In[113]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 356.312}, {408.188, 0}} -> {-0.0506521, \
-0.0573151, 0.00589737, 0.00589737}, {{8.5625, 170.062}, {398.438, 213.312}} -> \
{-0.0855841, -0.119396, 0.00601453, 0.00601453}, {{186.188, 347.688}, \
{398.438, 213.312}} -> {-1.12364, -0.090777, 0.00587773, 0.00587773}, \
{{8.5625, 170.062}, {194.812, 9.6875}} -> {-0.0413572, -1.23382, 0.00555999, \
0.00555999}, {{186.188, 347.688}, {194.812, 9.6875}} -> {-0.99387, -1.18158, \
0.00547028, 0.00547028}}],

Cell["Various capabilities of Rotate.", "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[TextData[{
 "The progression is as follows.  At the top-left, only the rotation angle  \
is supplied.  At the top-right, a different axis of rotation is used with the \
 same angle.  At the bottom-left, the same axis is used but at a different  \
center.  The mirror slides along a radial arc with the center of curvature at \
 ",
 StyleBox["{12,0,0}", "MB"],
 ".  Visualize the arc on the base of the plot, right below the mirrors.  At  \
the bottom-right, a different case altogether shows the general capabilities  \
of ",
 StyleBox["Rotate", "MB"],
 "."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[TextData[{
 "Yet another way to invoke the ",
 StyleBox["Rotate", "MB"],
 " function exists.  ",
 StyleBox["Rotate", "MB"],
 " can employ tilt vectors in a manner identical to ",
 StyleBox["Move", "MB"],
 ".  (See the Help Browser for details.)  You may prefer ",
 StyleBox["Rotate", "MB"],
 " as a more descriptive name than ",
 StyleBox["Move", "MB"],
 " in those cases involving angular orientation only."
}], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4 Advanced Placement with MoveAligned", "Section",
 CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}],

Cell[TextData[{
 "This section presents a useful advanced function that generalizes ",
 StyleBox["MoveLinear", "MB"],
 ".  Instead of following a linear rail, ",
 StyleBox["MoveAligned", "MB"],
 " follows an arbitrary light path through space.  Only component spacings  \
are specified.  ",
 StyleBox["MoveAligned", "MB"],
 " places each component at a given spacing along the light path determined  \
by the preceding component.  This function invokes ",
 StyleBox["PropagateSystem", "MB"],
 " internally to find the light path."
}], "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell[TextData[{
 "Here is a simple example of ",
 StyleBox["MoveAligned", "MB"],
 ".  The prism bends the light path, but ",
 StyleBox["MoveAligned", "MB"],
 " follows it.  The lens and screen are centered on the beam."
}], "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"prism", ",", "lens", ",", "screen"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ray", "=", 
   RowBox[{"SingleRay", "[", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"prism", "=", 
   RowBox[{"Prism", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"65", ",", "25", ",", "65"}], "}"}], ",", "25", ",", 
     RowBox[{"Centered", "\[Rule]", "True"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lens", "=", 
   RowBox[{"BiConvexLens", "[", 
    RowBox[{"30", ",", "25", ",", "8"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"screen", "=", 
   RowBox[{"Screen", "[", "20", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"optics", "=", 
   RowBox[{"MoveAligned", "[", 
    RowBox[{"ray", ",", 
     RowBox[{"{", 
      RowBox[{
      "50", ",", "prism", ",", "30", ",", "lens", ",", "30", ",", "screen"}], 
      "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"LineOfRays", "[", 
       RowBox[{"15", ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "6"}]}], "]"}], ",", "optics"}], 
     "}"}], ",", 
    RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", " ", 
    RowBox[{"Frame", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"FrameTicks", " ", "\[Rule]", " ", "Automatic"}]}], "]"}], 
  ";"}]}], "Input",
 CellTags->{"Advanced Placement", "PR2.4"},
 CellLabel->"In[68]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{43.75, -13.403168253184742`}, {56.25, 13.403168253184742`}, {
       56.25, 13.403168253184742`}, {43.75, -13.403168253184742`}, {
       43.75, -13.403168253184742`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{68.75, -13.403168253184742`}, {56.25, 13.403168253184742`}, {
       56.25, 13.403168253184742`}, {68.75, -13.403168253184742`}, {
       68.75, -13.403168253184742`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{43.75, -13.403168253184742`}, {68.75, -13.403168253184742`}, {
       68.75, -13.403168253184742`}, {43.75, -13.403168253184742`}, {
       43.75, -13.403168253184742`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{43.74375, -13.407635975935802`}, {56.25, 
       13.412103698686867`}, {68.75625, -13.4076359759358}, {
       43.74375, -13.407635975935802`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{43.74375, -13.407635975935802`}, {56.25, 
       13.412103698686867`}, {68.75625, -13.4076359759358}, {
       43.74375, -13.407635975935802`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{84.24966137595585, -30.346319744413933`}, {
      86.33541964722436, -31.689843571385737`}, {
      89.90832411778476, -29.035035797065852`}, {
      85.18943588694427, -25.995403226847067`}, {
      84.24966137595585, -30.346319744413933`}}], 
     PolygonBox[{{85.18943588694427, -25.995403226847067`}, {
      89.90832411778476, -29.035035797065852`}, {
      92.9209600742825, -26.019335723521166`}, {
      86.68947891199531, -22.005379008504995`}, {
      85.18943588694427, -25.995403226847067`}}], 
     PolygonBox[{{86.68947891199531, -22.005379008504995`}, {
      92.9209600742825, -26.019335723521166`}, {
      95.42430664401894, -22.675581131213125`}, {
      88.69881132380766, -18.34340930892628}, {
      86.68947891199531, -22.005379008504995`}}], 
     PolygonBox[{{88.69881132380766, -18.34340930892628}, {
      95.42430664401894, -22.67558113121312}, {
      97.43363905583129, -19.013611431634413`}, {
      91.2021578935441, -14.999654716618236`}, {
      88.69881132380766, -18.34340930892628}}], 
     PolygonBox[{{91.2021578935441, -14.999654716618236`}, {
      97.43363905583129, -19.013611431634413`}, {
      98.93368208088233, -15.023587213292336`}, {
      94.21479385004184, -11.983954643073552`}, {
      91.2021578935441, -14.999654716618236`}}], 
     PolygonBox[{{94.21479385004184, -11.983954643073552`}, {
      98.93368208088233, -15.023587213292336`}, {
      99.87345659187073, -10.67267069572547}, {
      97.78769832060223, -9.329146868753664}, {
      94.21479385004184, -11.983954643073552`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{84.24966137595585, -30.346319744413933`}, {
       85.18943588694427, -25.995403226847067`}, {
       86.68947891199531, -22.005379008504995`}, {
       88.69881132380766, -18.34340930892628}, {
       91.2021578935441, -14.999654716618236`}, {
       94.21479385004184, -11.983954643073554`}, {
       97.78769832060223, -9.329146868753664}, {
       99.87345659187075, -10.672670695725467`}, {
       98.93368208088233, -15.023587213292334`}, {
       97.43363905583129, -19.01361143163441}, {
       95.42430664401894, -22.67558113121312}, {
       92.9209600742825, -26.019335723521166`}, {
       89.90832411778476, -29.035035797065845`}, {
       86.33541964722437, -31.689843571385737`}, {
       84.24966137595585, -30.346319744413933`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{91.01867984827905, -19.8377333065838}, {
        93.10443811954755, -21.1812571335556}, {
        94.42100309933355, -22.02931150517909}, {
        89.70211486849306, -18.98967893496031}, {
        91.01867984827905, -19.8377333065838}}], 
       PolygonBox[{{89.70211486849306, -18.98967893496031}, {
        94.42100309933355, -22.02931150517909}, {
        95.1772995650569, -22.516473577577788`}, {
        88.9458184027697, -18.502516862561613`}, {
        89.70211486849306, -18.98967893496031}}], 
       PolygonBox[{{88.9458184027697, -18.502516862561613`}, {
        95.1772995650569, -22.516473577577788`}, {
        95.42430664401894, -22.67558113121312}, {
        88.69881132380766, -18.34340930892628}, {
        88.9458184027697, -18.502516862561613`}}], 
       PolygonBox[{{88.69881132380766, -18.34340930892628}, {
        95.42430664401894, -22.67558113121312}, {
        95.1772995650569, -22.51647357757779}, {
        88.9458184027697, -18.502516862561613`}, {
        88.69881132380766, -18.34340930892628}}], 
       PolygonBox[{{88.9458184027697, -18.502516862561613`}, {
        95.1772995650569, -22.51647357757779}, {
        94.42100309933355, -22.02931150517909}, {
        89.70211486849306, -18.98967893496031}, {
        88.9458184027697, -18.502516862561613`}}], 
       PolygonBox[{{89.70211486849306, -18.98967893496031}, {
        94.42100309933355, -22.02931150517909}, {
        93.10443811954755, -21.181257133555604`}, {
        91.01867984827905, -19.837733306583797`}, {
        89.70211486849306, -18.98967893496031}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{91.01867984827905, -19.8377333065838}, {
         89.70211486849306, -18.98967893496031}, {
         88.9458184027697, -18.502516862561613`}, {
         88.69881132380766, -18.34340930892628}, {
         88.9458184027697, -18.502516862561613`}, {
         89.70211486849306, -18.98967893496031}, {
         91.01867984827905, -19.837733306583797`}, {
         93.10443811954755, -21.1812571335556}, {
         94.42100309933355, -22.02931150517909}, {
         95.1772995650569, -22.51647357757779}, {
         95.42430664401894, -22.67558113121312}, {
         95.1772995650569, -22.51647357757779}, {
         94.42100309933355, -22.029311505179095`}, {
         93.10443811954755, -21.181257133555604`}, {
         91.01867984827905, -19.8377333065838}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{97.78769832060225, -9.329146868753668}, {
       99.87345659187075, -10.672670695725467`}, {
       99.6428078805923, -11.030742095464431`}, {
       97.5570496093238, -9.687218268492629}, {
       97.78769832060225, -9.329146868753668}}], 
      LineBox[{{97.5570496093238, -9.687218268492629}, {
       99.6428078805923, -11.030742095464431`}, {
       98.96658007526557, -12.080554320530082`}, {
       96.88082180399707, -10.73703049355828}, {
       97.5570496093238, -9.687218268492629}}], 
      LineBox[{{96.88082180399707, -10.73703049355828}, {
       98.96658007526557, -12.080554320530082`}, {
       97.89085698330429, -13.750564402680926`}, {
       95.80509871203579, -12.407040575709125`}, {
       96.88082180399707, -10.73703049355828}}], 
      LineBox[{{95.80509871203579, -12.407040575709125`}, {
       97.89085698330429, -13.750564402680926`}, {
       96.48894735570914, -15.926963914640531`}, {
       94.40318908444064, -14.58344008766873}, {
       95.80509871203579, -12.407040575709125`}}], 
      LineBox[{{94.40318908444064, -14.58344008766873}, {
       96.48894735570914, -15.926963914640531`}, {
       94.85638901683556, -18.461434826339104`}, {
       92.77063074556706, -17.117910999367304`}, {
       94.40318908444064, -14.58344008766873}}], 
      LineBox[{{92.77063074556706, -17.117910999367304`}, {
       94.85638901683556, -18.461434826339104`}, {
       93.10443811954755, -21.181257133555597`}, {
       91.01867984827905, -19.8377333065838}, {
       92.77063074556706, -17.117910999367304`}}], 
      LineBox[{{91.01867984827905, -19.8377333065838}, {
       93.10443811954755, -21.1812571335556}, {
       91.35248722225954, -23.901079440772094`}, {
       89.26672895099104, -22.557555613800297`}, {
       91.01867984827905, -19.8377333065838}}], 
      LineBox[{{89.26672895099104, -22.557555613800297`}, {
       91.35248722225954, -23.901079440772094`}, {
       89.71992888338596, -26.435550352470667`}, {
       87.63417061211746, -25.092026525498866`}, {
       89.26672895099104, -22.557555613800297`}}], 
      LineBox[{{87.63417061211746, -25.092026525498866`}, {
       89.71992888338596, -26.435550352470667`}, {
       88.31801925579082, -28.611949864430272`}, {
       86.23226098452231, -27.268426037458475`}, {
       87.63417061211746, -25.092026525498866`}}], 
      LineBox[{{86.23226098452231, -27.268426037458475`}, {
       88.31801925579082, -28.611949864430272`}, {
       87.24229616382954, -30.281959946581118`}, {
       85.15653789256103, -28.93843611960932}, {
       86.23226098452231, -27.268426037458475`}}], 
      LineBox[{{85.15653789256103, -28.938436119609314`}, {
       87.24229616382954, -30.281959946581118`}, {
       86.5660683585028, -31.33177217164677}, {
       84.4803100872343, -29.98824834467497}, {
       85.15653789256103, -28.938436119609314`}}], 
      LineBox[{{84.4803100872343, -29.98824834467497}, {
       86.5660683585028, -31.33177217164677}, {
       86.33541964722436, -31.689843571385737`}, {
       84.24966137595585, -30.346319744413933`}, {
       84.4803100872343, -29.98824834467497}}], 
      LineBox[{{84.24966137595585, -30.346319744413933`}, {
       86.33541964722436, -31.689843571385737`}, {
       86.5660683585028, -31.33177217164677}, {
       84.4803100872343, -29.98824834467497}, {
       84.24966137595585, -30.346319744413933`}}], 
      LineBox[{{84.4803100872343, -29.98824834467497}, {
       86.5660683585028, -31.331772171646772`}, {
       87.24229616382954, -30.281959946581118`}, {
       85.15653789256103, -28.93843611960932}, {
       84.4803100872343, -29.98824834467497}}], 
      LineBox[{{85.15653789256103, -28.93843611960932}, {
       87.24229616382954, -30.281959946581118`}, {
       88.31801925579082, -28.611949864430276`}, {
       86.23226098452231, -27.268426037458475`}, {
       85.15653789256103, -28.93843611960932}}], 
      LineBox[{{86.23226098452231, -27.268426037458475`}, {
       88.31801925579082, -28.61194986443028}, {
       89.71992888338596, -26.435550352470674`}, {
       87.63417061211746, -25.092026525498873`}, {
       86.23226098452231, -27.268426037458475`}}], 
      LineBox[{{87.63417061211746, -25.092026525498873`}, {
       89.71992888338596, -26.435550352470674`}, {
       91.35248722225954, -23.901079440772104`}, {
       89.26672895099104, -22.557555613800304`}, {
       87.63417061211746, -25.092026525498873`}}], 
      LineBox[{{89.26672895099104, -22.557555613800304`}, {
       91.35248722225954, -23.901079440772104`}, {
       93.10443811954754, -21.18125713355561}, {
       91.01867984827904, -19.837733306583814`}, {
       89.26672895099104, -22.557555613800304`}}], 
      LineBox[{{91.01867984827905, -19.8377333065838}, {
       93.10443811954755, -21.181257133555604`}, {
       94.85638901683556, -18.46143482633911}, {
       92.77063074556706, -17.11791099936731}, {
       91.01867984827905, -19.8377333065838}}], 
      LineBox[{{92.77063074556706, -17.11791099936731}, {
       94.85638901683556, -18.46143482633911}, {
       96.48894735570914, -15.92696391464054}, {
       94.40318908444064, -14.583440087668741`}, {
       92.77063074556706, -17.11791099936731}}], 
      LineBox[{{94.40318908444064, -14.583440087668741`}, {
       96.48894735570914, -15.92696391464054}, {
       97.89085698330427, -13.750564402680933`}, {
       95.80509871203577, -12.407040575709134`}, {
       94.40318908444064, -14.583440087668741`}}], 
      LineBox[{{95.80509871203579, -12.407040575709125`}, {
       97.89085698330429, -13.750564402680928`}, {
       98.96658007526557, -12.080554320530085`}, {
       96.88082180399707, -10.737030493558287`}, {
       95.80509871203579, -12.407040575709125`}}], 
      LineBox[{{96.88082180399707, -10.737030493558287`}, {
       98.96658007526557, -12.080554320530085`}, {
       99.6428078805923, -11.030742095464433`}, {
       97.5570496093238, -9.687218268492632}, {
       96.88082180399707, -10.737030493558287`}}], 
      LineBox[{{97.5570496093238, -9.687218268492632}, {
       99.6428078805923, -11.030742095464433`}, {
       99.87345659187075, -10.672670695725467`}, {
       97.78769832060225, -9.329146868753668}, {
       97.5570496093238, -9.687218268492632}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{115.22969931695273`, -47.32809461505286}, {
       117.03477090957225`, -44.525804898298155`}, {
       118.83984250219176`, -41.723515181543455`}, {
       120.64491409481127`, -38.92122546478875}, {
       122.44998568743078`, -36.11893574803404}, {
       124.2550572800503, -33.31664603127934}, {
       126.06012887266981`, -30.514356314524633`}, {
       126.06012887266981`, -30.514356314524633`}, {
       124.2550572800503, -33.31664603127934}, {
       122.44998568743078`, -36.11893574803404}, {
       120.64491409481127`, -38.92122546478875}, {
       118.83984250219176`, -41.723515181543455`}, {
       117.03477090957225`, -44.525804898298155`}, {
       115.22969931695273`, -47.32809461505286}, {
       115.22969931695273`, -47.32809461505286}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}, {
       120.64491409481127`, -38.92122546478875}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQnZh1VO1mc7zDjfi/t9Y02x34yCv/j7Mi3qFs6jdp
prN2BxojFbuyQuMdgssUG5mW2B84VZh6KUwu3iG2rHkCc63DgdTPLtv6r8U5
zLZIm/Qg2vFAv0Rd4c+mOIflU4+aZMQ7HcioOeLqphnn4HXQd/urUucDjg+4
pCafj3V48+aqZW6Py4FsVperf6pjHX56mt750u96gK1deaepSayDGY/EvYt5
bgf856czKv2Nccg6zqV3RdL9wP1Xmb1Nt2IcbpovSAhpdT+Q33c4ZfO5GIcV
l2QY/6/ElIfpz4bqh5lvDjUfZv8vqP0w972Dug/d/TD/rYD6LwXq/zlQ/8PC
Jw4aPrDwC4GGH3r4ooc/AHFevlo=
      "]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -7.5}, {46.5026925638375, -7.500000000000001}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., -4.5}, {47.9016155383025, -4.500000000000004}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -1.5}, {49.3005385127675, -1.5000000000000027`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 1.5}, {50.69946148723249, 1.4999999999999993`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 4.5}, {52.098384461697485`, 4.500000000000001}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 7.5}, {53.49730743616249, 7.499999999999997}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{46.5026925638375, -7.500000000000001}, {
       67.52288405784653, -10.771609622969002`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{47.9016155383025, -4.500000000000004}, {
       65.90501198391405, -7.302071763921649}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{49.3005385127675, -1.5000000000000027`}, {
       64.28713990998156, -3.832533904874292}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.69946148723249, 1.4999999999999993`}, {
       62.66926783604908, -0.3629960458269362}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.098384461697485`, 4.500000000000001}, {
       61.051395762116606`, 3.106541813220419}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.49730743616249, 7.499999999999997}, {59.433523688184124`, 
       6.576079672267772}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{67.52288405784653, -10.771609622969002`}, {
       86.30736385056744, -22.871475904904887`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{65.90501198391405, -7.302071763921649}, {
       87.17420669114833, -21.002446473351686`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{64.28713990998156, -3.832533904874292}, {
       88.1610179699039, -19.210693712538603`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{62.66926783604908, -0.3629960458269362}, {
       89.26609142874283, -17.495118550520306`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.051395762116606`, 3.106541813220419}, {
       90.48942706766506, -15.855720987296777`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.433523688184124`, 6.576079672267772}, {
       91.83273114476202, -14.293600094813385`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{86.30736385056744, -22.871475904904887`}, {
       92.58150189602739, -26.405050729406636`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{87.17420669114833, -21.002446473351686`}, {
       93.80408916873706, -24.948590508613883`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{88.1610179699039, -19.210693712538603`}, {
       94.91029877804512, -23.44684016494564}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{89.26609142874283, -17.495118550520306`}, {
       95.91399115853581, -21.888654413126005`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{90.48942706766506, -15.855720987296777`}, {
       96.82390730304627, -20.260463268207076`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{91.83273114476202, -14.293600094813385`}, {
       97.64446358013669, -18.545038128403284`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{92.58150189602739, -26.405050729406636`}, {
       121.03413917102556`, -38.316971631844915`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{93.80408916873706, -24.948590508613883`}, {
       120.82586257892173`, -38.640311356806336`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{94.91029877804512, -23.44684016494564}, {
       120.69712358669618`, -38.84017265623297}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{95.91399115853581, -21.888654413126005`}, {
       120.59270460292633`, -39.00227827334458}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{96.82390730304627, -20.260463268207076`}, {
       120.46396561070078`, -39.20213957277121}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{97.64446358013669, -18.545038128403284`}, {
       120.25568901859695`, -39.52547929773263}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQ/e78HasIB3cHRgYQkDvQ7xmonPHZ3YEVzBc6YHD4
KHfFMg8HHjD/x/7zNlZf2iM9Hf7+B4Hv9vnb1t2ZzuMF1S/kIGCgfHT5fi+o
vKyDLfOmd2UPAxx67szPEuhWPdARmbT9dWWAw5KoNz5BprIHLq0XakgQCnAI
/2HYyb6S74AlT9vEVaH+Dq63I48EW1/ff37HM6UpbX4OLY3SM4xucTikpLpv
qd3u62Amn3jlua+Ug1VX7s3Vk0MdOi/WcUveNztQ53fJWO10qIMlJ3PoAgbT
A32bA+T8uMIcai+/Yf1ganxgIk/EEvbAMIe1CvfEDtQZHmiOfHE0aH6YQ8fD
tfyK2/QPuLhPKvf+GubwYlnWgaBpOgd+1e8KNlcNd9jPOiV9Y7rVgZObsozK
isMdXp26ffnaJ4sDO4POhTrtCncQ+f1NNqXI/MDS9Uev1P0Kd2i4xHm77rHp
AZvETU93mUQ4WBxq2rHWyeTAHE6dJ3aZEQ7rJmTMa+82OuB/hD9M3ynOwd/l
SNskDecDiXe3v7tlEudwJu7Hjq+BzgfCO+zXzNWJczh7UOB4V7bzgfICz/vv
VOMczh/oWu7V4HwgV/rinI2yQL7y4q33ZzofqDepNI0ViHPwsbv+3Omw8wEA
yxzdqw==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"Prism\"\>", {34.13880763062484, -3.361192369375164}, \
{0., 0.}], 
    InsetBox["\<\"L\"\>", {83.47238265260353, -33.843792101720155`}, \
{0., 0.}], 
    InsetBox["\<\"S\"\>", {113.40954145796616`, -50.15380505887318}, \
{0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  Frame:>True,
  FrameTicks:>Automatic,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563366879188633*^9, 3.566086392435206*^9, 
  3.567272848110662*^9, 3.614727108649879*^9},
 CellTags->{"Advanced Placement", "PR2.4"},
 CellLabel->"During evaluation of In[68]:="]
}, Open  ]],

Cell[TextData[{
 "The custom ",
 StyleBox["MoveAligned", "MB"],
 " function lets you place components by defining their spacing along the  \
light path of the system."
}], "Commentary",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell["\<\
We define only the spacing between components along the light path.  A \
three-dimensional example is more dramatic.\
\>", "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"m1", ",", "m2", ",", "l1", ",", " ", "b"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m1", " ", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"Mirror", "[", 
      RowBox[{"20", ",", "10", ",", "\"\<m1\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m2", " ", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"SphericalMirror", "[", 
      RowBox[{
       RowBox[{"-", "30"}], ",", "20", ",", "10", ",", "\"\<m2\>\""}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"l1", "=", " ", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"BiConvexLens", "[", 
      RowBox[{"30", ",", "25", ",", "8", ",", "\"\<l1\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "5"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", " ", "=", " ", 
   RowBox[{"Screen", "[", "40", "]"}]}], ";"}], "\n", 
 RowBox[{"optics", " ", "=", " ", 
  RowBox[{"MoveAligned", "[", 
   RowBox[{
    RowBox[{"SingleRay", "[", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "50", ",", "l1", ",", " ", "50", ",", " ", "m1", ",", "100", ",", "m2", 
      ",", "100", ",", " ", "l1", ",", "50", ",", "m1", ",", "50", ",", "b"}],
      "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"AnalyzeSystem", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"CircleOfRays", "[", ".5", "]"}], ",", "optics"}], "}"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "True"}]}], "]"}], ";"}]}], "Input",
 CellTags->{"Advanced Placement", "PR2.4"},
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"l1\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"50.`", ",", 
          RowBox[{"-", "5.`"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"m1\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"106.90665681893226`", ",", 
          RowBox[{"-", "8.979039814748752`"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.46999895894262783`", ",", 
            RowBox[{"-", "0.667658329731243`"}], ",", 
            RowBox[{"-", "0.5773502691896258`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "0.8177111151802142`", ",", "0.5756288145243694`", ",", "0"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.33233945101894985`", ",", 
            RowBox[{"-", "0.4721057324686458`"}], ",", 
            "0.8164965809277261`"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"m2\"\>", ",", 
        RowBox[{"{", 
         RowBox[{
         "149.18079946016908`", ",", "48.31545848670344`", ",", 
          "70.3934466291662`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "0.8819067335112902`", ",", "0.004276817183928694`", ",", 
            "0.47140452079103085`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2560718898391977`"}], ",", "0.8439223690671794`", 
            ",", "0.4714045207910309`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.39581270901984433`"}], ",", 
            RowBox[{"-", "0.5364482676109736`"}], ",", "0.745355992499931`"}],
            "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"l1\"\>", ",", 
        RowBox[{"{", 
         RowBox[{
         "68.57877132916778`", ",", "103.71744175698937`", ",", 
          "87.04515064183323`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8480813187052465`"}], ",", "0.48743202343552466`",
             ",", "0.20776934180172094`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4983061361161002`"}], ",", 
            RowBox[{"-", "0.8670011503504724`"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.18013625834965258`", ",", 
            RowBox[{"-", "0.10353273791660092`"}], ",", 
            "0.9781778471256032`"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{"\<\"m1\"\>", ",", 
        RowBox[{"{", 
         RowBox[{
         "22.300078726600404`", ",", "134.90540073387004`", ",", 
          "98.86860927323919`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.15295114052465983`"}], ",", "0.8813916529581364`",
             ",", 
            RowBox[{"-", "0.4469392606472721`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.9846560559475741`"}], ",", 
            RowBox[{"-", "0.09747233397238975`"}], ",", 
            "0.1447466600503886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "0.08401428508279768`", ",", "0.4622206163789098`", ",", 
            "0.8827761333975492`"}], "}"}]}], "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", "40", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6.382516467527822`"}], ",", "115.45068673522093`", 
          ",", "134.90779400542402`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5736519038825628`"}], ",", 
          RowBox[{"-", "0.3890942799729824`"}], ",", "0.7207836946436965`"}], 
         "}"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.563366889353207*^9, 3.566086395915743*^9, 
  3.567272849371969*^9, 3.614727109399474*^9},
 CellTags->{"Advanced Placement", "PR2.4"},
 CellLabel->"Out[80]="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{52.75949165260709, -17.5, 0.}, {55.24050834739292, -17.5, 
      3.061616997868383*^-15}, {56.806566955245316`, -13.333333333333336`, 
      2.551347498223653*^-15}, {51.19343304475469, -13.333333333333334`, 
      0.}, {52.75949165260709, -17.5, 0.}}], 
     Polygon3DBox[{{51.19343304475469, -13.333333333333334`, 0.}, {
      56.806566955245316`, -13.333333333333336`, 2.551347498223653*^-15}, {
      57.70618422322623, -9.166666666666668, 2.0410779985789223`*^-15}, {
      50.293815776773776`, -9.166666666666668, 0.}, {
      51.19343304475469, -13.333333333333334`, 0.}}], 
     Polygon3DBox[{{50.293815776773776`, -9.166666666666668, 0.}, {
      57.70618422322623, -9.166666666666668, 2.0410779985789223`*^-15}, {
      58., -5.0000000000000036`, 1.530808498934192*^-15}, {50., -5., 0.}, {
      50.293815776773776`, -9.166666666666668, 0.}}], 
     Polygon3DBox[{{50., -5., 0.}, {58., -5., 1.5308084989341915`*^-15}, {
      57.70618422322623, -0.8333333333333339, 1.0205389992894611`*^-15}, {
      50.293815776773776`, -0.8333333333333357, 0.}, {50., -5., 0.}}], 
     Polygon3DBox[{{50.293815776773776`, -0.8333333333333357, 0.}, {
      57.70618422322623, -0.8333333333333339, 1.0205389992894611`*^-15}, {
      56.806566955245316`, 3.333333333333332, 5.102694996447307*^-16}, {
      51.19343304475469, 3.333333333333332, 0.}, {
      50.293815776773776`, -0.8333333333333357, 0.}}], 
     Polygon3DBox[{{51.19343304475469, 3.333333333333332, 0.}, {
      56.806566955245316`, 3.333333333333332, 5.102694996447308*^-16}, {
      55.24050834739292, 7.499999999999998, 2.5493082627129206`*^-31}, {
      52.75949165260708, 7.4999999999999964`, 0.}, {51.19343304475469, 
      3.333333333333332, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFY/coDVPNHLgQEEGgwPMEDB5+l/Mg/N8HRYvQoE
tODi6aoJB2erejqEhYKAElwcAjwdmMC0CIb6A2BzXu2HiX+Cmr8ALM7lABNX
g7rnz38QkIWL37K2/3VinjeULwcX58tgnmab7uOwBs2cWbfm26Xc8oGaj7AX
Anwd/oHNFz6Arj4EzV8w81eghQPMPWBj6hHhhis8AZrmaxA=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{52.75949165260709, -5., -12.5}, {
        55.24050834739292, -4.999999999999998, -12.5}, {
        56.806566955245316`, -4.999999999999999, -8.333333333333336}, {
        51.19343304475469, -5., -8.333333333333334}, {
        52.75949165260709, -5., -12.5}}], 
       Polygon3DBox[{{51.19343304475469, -5., -8.333333333333334}, {
        56.806566955245316`, -4.999999999999999, -8.333333333333336}, {
        57.70618422322623, -4.999999999999999, -4.166666666666668}, {
        50.293815776773776`, -4.999999999999999, -4.166666666666668}, {
        51.19343304475469, -5., -8.333333333333334}}], 
       Polygon3DBox[{{
        50.293815776773776`, -4.999999999999999, -4.166666666666668}, {
        57.70618422322623, -4.999999999999999, -4.166666666666668}, {
        58., -4.999999999999999, -3.552713678800501*^-15}, {
        50., -4.999999999999999, 0.}, {
        50.293815776773776`, -4.999999999999999, -4.166666666666668}}], 
       Polygon3DBox[{{50., -4.999999999999999, 0.}, {58., -4.999999999999999, 
        0.}, {57.70618422322623, -4.999999999999999, 4.166666666666666}, {
        50.293815776773776`, -4.999999999999999, 4.166666666666664}, {
        50., -4.999999999999999, 0.}}], 
       Polygon3DBox[{{50.293815776773776`, -4.999999999999999, 
        4.166666666666664}, {57.70618422322623, -4.999999999999999, 
        4.166666666666666}, {56.806566955245316`, -5., 8.333333333333332}, {
        51.19343304475469, -4.999999999999999, 8.333333333333332}, {
        50.293815776773776`, -4.999999999999999, 4.166666666666664}}], 
       Polygon3DBox[{{51.19343304475469, -4.999999999999999, 
        8.333333333333332}, {56.806566955245316`, -5., 8.333333333333332}, {
        55.24050834739292, -5., 12.499999999999998`}, {
        52.75949165260708, -4.999999999999998, 12.499999999999996`}, {
        51.19343304475469, -4.999999999999999, 8.333333333333332}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFY/coDVPNHLgQEMRA5AaM0Dn6f/yTw0wxMuvnoV
CCgcSFdNODhbFSG+BiwuANXniWbOgz3o6ldA1Dt8QjMfIq7goIbmnn//QUDD
4Za1/a8T87zR3enAl8E8zTbdB92dDrNuzbdLuYUQh7oTyvdFd6cNunqoOw+g
mw915wF090DdeQBXeAIANelzSQ==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{52.75949165260709, 7.5, 0.}, {55.24050834739292, 7.5, 0.}, {
       55.24050834739292, 7.074072828613353, 3.2352380637815092`}, {
       52.75949165260709, 7.074072828613353, 3.2352380637815092`}, {
       52.75949165260709, 7.5, 0.}}], 
      Line3DBox[{{52.75949165260709, 7.074072828613353, 
       3.2352380637815092`}, {55.24050834739292, 7.074072828613353, 
       3.2352380637815092`}, {55.24050834739292, 5.825317547305485, 
       6.249999999999999}, {52.75949165260709, 5.825317547305485, 
       6.249999999999999}, {52.75949165260709, 7.074072828613353, 
       3.2352380637815092`}}], 
      Line3DBox[{{52.75949165260709, 5.825317547305485, 6.249999999999999}, {
       55.24050834739292, 5.825317547305485, 6.249999999999999}, {
       55.24050834739292, 3.8388347648318444`, 8.838834764831843}, {
       52.75949165260709, 3.8388347648318444`, 8.838834764831843}, {
       52.75949165260709, 5.825317547305485, 6.249999999999999}}], 
      Line3DBox[{{52.75949165260709, 3.8388347648318444`, 
       8.838834764831843}, {55.24050834739292, 3.8388347648318444`, 
       8.838834764831843}, {55.24050834739292, 1.2500000000000018`, 
       10.825317547305483`}, {52.75949165260709, 1.2500000000000018`, 
       10.825317547305483`}, {52.75949165260709, 3.8388347648318444`, 
       8.838834764831843}}], 
      Line3DBox[{{52.75949165260709, 1.2500000000000018`, 
       10.825317547305483`}, {55.24050834739292, 1.2500000000000018`, 
       10.825317547305483`}, {55.24050834739292, -1.764761936218488, 
       12.074072828613353`}, {52.75949165260709, -1.764761936218488, 
       12.074072828613353`}, {52.75949165260709, 1.2500000000000018`, 
       10.825317547305483`}}], 
      Line3DBox[{{52.75949165260709, -1.764761936218488, 
       12.074072828613353`}, {55.24050834739292, -1.764761936218488, 
       12.074072828613353`}, {55.24050834739292, -4.9999999999999964`, 
       12.5}, {52.75949165260709, -4.9999999999999964`, 12.5}, {
       52.75949165260709, -1.764761936218488, 12.074072828613353`}}], 
      Line3DBox[{{52.75949165260709, -4.999999999999999, 12.5}, {
       55.24050834739292, -4.999999999999999, 12.5}, {
       55.24050834739292, -8.235238063781509, 12.074072828613353`}, {
       52.75949165260709, -8.235238063781509, 12.074072828613353`}, {
       52.75949165260709, -4.999999999999999, 12.5}}], 
      Line3DBox[{{52.75949165260709, -8.235238063781509, 
       12.074072828613353`}, {55.24050834739292, -8.235238063781509, 
       12.074072828613353`}, {55.24050834739292, -11.249999999999996`, 
       10.825317547305485`}, {52.75949165260709, -11.249999999999996`, 
       10.825317547305485`}, {52.75949165260709, -8.235238063781509, 
       12.074072828613353`}}], 
      Line3DBox[{{52.75949165260709, -11.249999999999996`, 
       10.825317547305485`}, {55.24050834739292, -11.249999999999996`, 
       10.825317547305485`}, {55.24050834739292, -13.838834764831843`, 
       8.838834764831844}, {52.75949165260709, -13.838834764831843`, 
       8.838834764831844}, {52.75949165260709, -11.249999999999996`, 
       10.825317547305485`}}], 
      Line3DBox[{{52.75949165260709, -13.838834764831843`, 
       8.838834764831844}, {55.24050834739292, -13.838834764831843`, 
       8.838834764831844}, {55.24050834739292, -15.825317547305485`, 
       6.249999999999999}, {52.75949165260709, -15.825317547305485`, 
       6.249999999999999}, {52.75949165260709, -13.838834764831843`, 
       8.838834764831844}}], 
      Line3DBox[{{52.759491652607096`, -15.825317547305481`, 
       6.250000000000004}, {55.24050834739291, -15.825317547305481`, 
       6.250000000000004}, {55.24050834739292, -17.074072828613353`, 
       3.235238063781513}, {52.75949165260709, -17.074072828613353`, 
       3.235238063781513}, {52.759491652607096`, -15.825317547305481`, 
       6.250000000000004}}], 
      Line3DBox[{{52.75949165260709, -17.074072828613353`, 
       3.235238063781513}, {55.24050834739292, -17.074072828613353`, 
       3.235238063781513}, {55.24050834739292, -17.5, 
       1.5308084989341915`*^-15}, {52.75949165260709, -17.5, 
       1.5308084989341915`*^-15}, {52.75949165260709, -17.074072828613353`, 
       3.235238063781513}}], 
      Line3DBox[{{52.75949165260709, -17.5, 1.5308084989341915`*^-15}, {
       55.24050834739292, -17.5, 1.5308084989341915`*^-15}, {
       55.24050834739292, -17.074072828613353`, -3.23523806378151}, {
       52.75949165260709, -17.074072828613353`, -3.23523806378151}, {
       52.75949165260709, -17.5, 1.5308084989341915`*^-15}}], 
      Line3DBox[{{
       52.75949165260709, -17.074072828613353`, -3.2352380637815044`}, {
       55.24050834739292, -17.074072828613353`, -3.2352380637815044`}, {
       55.24050834739292, -15.825317547305485`, -6.2499999999999964`}, {
       52.75949165260709, -15.825317547305485`, -6.2499999999999964`}, {
       52.75949165260709, -17.074072828613353`, -3.2352380637815044`}}], 
      Line3DBox[{{
       52.75949165260709, -15.825317547305485`, -6.2499999999999964`}, {
       55.24050834739292, -15.825317547305485`, -6.2499999999999964`}, {
       55.24050834739292, -13.838834764831846`, -8.838834764831843}, {
       52.75949165260709, -13.838834764831846`, -8.838834764831843}, {
       52.75949165260709, -15.825317547305485`, -6.2499999999999964`}}], 
      Line3DBox[{{
       52.75949165260709, -13.838834764831848`, -8.838834764831839}, {
       55.24050834739292, -13.838834764831848`, -8.838834764831839}, {
       55.24050834739292, -11.250000000000005`, -10.82531754730548}, {
       52.75949165260709, -11.250000000000005`, -10.82531754730548}, {
       52.75949165260709, -13.838834764831848`, -8.838834764831839}}], 
      Line3DBox[{{
       52.75949165260709, -11.250000000000005`, -10.82531754730548}, {
       55.24050834739292, -11.250000000000005`, -10.82531754730548}, {
       55.24050834739292, -8.23523806378152, -12.074072828613351`}, {
       52.75949165260709, -8.23523806378152, -12.074072828613351`}, {
       52.75949165260709, -11.250000000000005`, -10.82531754730548}}], 
      Line3DBox[{{
       52.75949165260709, -8.23523806378152, -12.074072828613351`}, {
       55.24050834739292, -8.23523806378152, -12.074072828613351`}, {
       55.24050834739292, -5.000000000000013, -12.5}, {
       52.75949165260709, -5.000000000000013, -12.5}, {
       52.75949165260709, -8.23523806378152, -12.074072828613351`}}], 
      Line3DBox[{{52.75949165260709, -5.000000000000003, -12.5}, {
       55.24050834739292, -5.000000000000003, -12.5}, {
       55.24050834739292, -1.7647619362184965`, -12.074072828613355`}, {
       52.75949165260709, -1.7647619362184965`, -12.074072828613355`}, {
       52.75949165260709, -5.000000000000003, -12.5}}], 
      Line3DBox[{{
       52.75949165260709, -1.7647619362184965`, -12.074072828613355`}, {
       55.24050834739292, -1.7647619362184965`, -12.074072828613355`}, {
       55.24050834739292, 1.249999999999992, -10.825317547305488`}, {
       52.75949165260709, 1.249999999999992, -10.825317547305488`}, {
       52.75949165260709, -1.7647619362184965`, -12.074072828613355`}}], 
      Line3DBox[{{52.75949165260709, 
       1.249999999999992, -10.825317547305488`}, {55.24050834739292, 
       1.249999999999992, -10.825317547305488`}, {55.24050834739291, 
       3.8388347648318355`, -8.838834764831855}, {52.759491652607096`, 
       3.8388347648318355`, -8.838834764831855}, {52.75949165260709, 
       1.249999999999992, -10.825317547305488`}}], 
      Line3DBox[{{52.75949165260709, 
       3.8388347648318426`, -8.838834764831846}, {55.24050834739292, 
       3.8388347648318426`, -8.838834764831846}, {55.24050834739292, 
       5.825317547305479, -6.250000000000005}, {52.75949165260709, 
       5.825317547305479, -6.250000000000005}, {52.75949165260709, 
       3.8388347648318426`, -8.838834764831846}}], 
      Line3DBox[{{52.75949165260709, 5.825317547305479, -6.250000000000005}, {
       55.24050834739292, 5.825317547305479, -6.250000000000005}, {
       55.24050834739292, 7.074072828613351, -3.2352380637815195`}, {
       52.75949165260709, 7.074072828613351, -3.2352380637815195`}, {
       52.75949165260709, 5.825317547305479, -6.250000000000005}}], 
      Line3DBox[{{52.75949165260709, 
       7.074072828613351, -3.2352380637815195`}, {55.24050834739292, 
       7.074072828613351, -3.2352380637815195`}, {55.24050834739292, 
       7.5, -1.4163847244119949`*^-14}, {52.75949165260709, 
       7.5, -1.4163847244119949`*^-14}, {52.75949165260709, 
       7.074072828613351, -3.2352380637815195`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{98.72954566713013, -14.735327959992446`, 0.}, {
      103.4295352565564, -21.411911257304876`, -5.773502691896256}, {
      106.15523897382378`, -19.493148542223647`, -5.773502691896256}, {
      101.4552493843975, -12.816565244911216`, 0.}, {
      98.72954566713013, -14.735327959992446`, 0.}}], 
     Polygon3DBox[{{101.4552493843975, -12.816565244911216`, 0.}, {
      106.15523897382378`, -19.493148542223647`, -5.773502691896256}, {
      108.88094269109116`, -17.574385827142414`, -5.773502691896256}, {
      104.18095310166488`, -10.897802529829985`, 0.}, {
      101.4552493843975, -12.816565244911216`, 0.}}], 
     Polygon3DBox[{{104.18095310166488`, -10.897802529829985`, 0.}, {
      108.88094269109116`, -17.574385827142414`, -5.773502691896256}, {
      111.60664640835854`, -15.655623112061184`, -5.773502691896257}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      104.18095310166488`, -10.897802529829985`, 0.}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      111.60664640835854`, -15.655623112061182`, -5.773502691896257}, {
      114.33235012562592`, -13.736860396979951`, -5.773502691896257}, {
      109.63236053619964`, -7.0602770996675215`, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.63236053619964`, -7.0602770996675215`, 0.}, {
      114.33235012562592`, -13.736860396979951`, -5.773502691896257}, {
      117.0580538428933, -11.81809768189872, -5.773502691896258}, {
      112.35806425346702`, -5.141514384586291, 0.}, {
      109.63236053619964`, -7.0602770996675215`, 0.}}], 
     Polygon3DBox[{{112.35806425346702`, -5.141514384586291, 0.}, {
      117.0580538428933, -11.81809768189872, -5.773502691896258}, {
      119.78375756016068`, -9.899334966817488, -5.773502691896258}, {
      115.0837679707344, -3.22275166950506, 0.}, {
      112.35806425346702`, -5.141514384586291, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID4d4P9gw7oIBwZGjhc1FboHGKBgd0LAOaXYSAf3
x7+viSzShIuvLgjcM4U7yqHv6Puja06rwsVnNwStYtsV5XBl+eMtLl8V4eLd
E4JnVGREO5iJrHffaSsDF69eENL2SizG4ciNaaovJ4jAxbM3hJbEHI1xWGD1
l83oBCdcvNGiQlTzU6zDPqe/C0vPKB94Yv9FTFBC/MBEjXL17c6xDuUJnJvv
LlKHiy+UKLN0nRrjYFAnesS1UhsuvpGj1Pvys2iHV7MVr67114eLH/xRHJto
Ee1w6Y7YZ67JhnDxiy+K8t93Rjmsez3nt12dMVz84Y3CxtrbkQ7dv5RYijNN
4eK4whMAtkmL/w==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        103.58326230874276`, -4.257982490062294, -8.16496580927726}, {
        108.28325189816904`, -10.934565787374723`, -13.938468501173519`}, {
        109.3910500682322, -12.50825156227021, -11.216813231414434`}, {
        104.69106047880592`, -5.831668264957781, -5.4433105395181745`}, {
        103.58326230874276`, -4.257982490062294, -8.16496580927726}}], 
       Polygon3DBox[{{
        104.69106047880592`, -5.831668264957781, -5.4433105395181745`}, {
        109.3910500682322, -12.50825156227021, -11.216813231414434`}, {
        110.49884823829538`, -14.081937337165694`, -8.495157961655348}, {
        105.7988586488691, -7.4053540398532665`, -2.7216552697590877`}, {
        104.69106047880592`, -5.831668264957781, -5.4433105395181745`}}], 
       Polygon3DBox[{{
        105.7988586488691, -7.4053540398532665`, -2.7216552697590877`}, {
        110.49884823829538`, -14.081937337165694`, -8.495157961655348}, {
        111.60664640835854`, -15.655623112061182`, -5.77350269189626}, {
        106.90665681893226`, -8.979039814748752, 0.}, {
        105.7988586488691, -7.4053540398532665`, -2.7216552697590877`}}], 
       Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
        111.60664640835854`, -15.655623112061182`, -5.773502691896258}, {
        112.7144445784217, -17.229308886956666`, -3.051847422137172}, {
        108.01445498899542`, -10.552725589644238`, 2.7216552697590863`}, {
        106.90665681893226`, -8.979039814748752, 0.}}], 
       Polygon3DBox[{{108.01445498899542`, -10.552725589644238`, 
        2.7216552697590863`}, {
        112.7144445784217, -17.229308886956666`, -3.051847422137172}, {
        113.82224274848488`, -18.802994661852154`, -0.33019215237808464`}, {
        109.12225315905859`, -12.126411364539724`, 5.443310539518173}, {
        108.01445498899542`, -10.552725589644238`, 2.7216552697590863`}}], 
       Polygon3DBox[{{109.12225315905859`, -12.126411364539724`, 
        5.443310539518173}, {
        113.82224274848487`, -18.802994661852154`, -0.3301921523780855}, {
        114.93004091854804`, -20.37668043674764, 2.3914631173810026`}, {
        110.23005132912176`, -13.700097139435208`, 8.164965809277259}, {
        109.12225315905859`, -12.126411364539724`, 5.443310539518173}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO50ytcOeRrpkMpxvV+HQ/DA8tnsaWUhCgeeMO4O
tdKJcqgprbmxIFj8QNf5LUafj4oecDjI1qBQHOUw6ZGiouh82QPdYHHWA7Mb
glax7YpyuLL88RaXr4oHGKDgm/28K28Yoh3i48xu/pNSPdABUe8Q+P/lv0vu
0Q6vRDr/7nDQgIqLOqzdZ6q5sy/aoez0bcXiNG2YexwOu0Wcat0d43DsPo9i
XoLJgSvvTLO2KzI7ZLTzLJhfEuPQ0PKYb+JZowMLWL8731O8up/nxIHSnbox
Dtaau/5stjI8YLvB+LdeFseBjRyl3pefAe2drXh1rb/+gSf2X8QEJcQPhHlq
Kr6dD3Tn03MbPmvqHLgSrB7R+lfhwO/Ou9/YIqMdrujV9FiyaB7Y1n5FhSlf
7cD8UxPPKAhFO3hUaGbU31M9MHN348e6B9oHcIUnAFeEqJw=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.63236053619964`, -7.0602770996675215`, 0.}, {
      109.82620369879501`, -7.532957203281128, 0.7044162180172904}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.63236053619964`, -7.0602770996675215`, 0.}, {
      112.35806425346702`, -5.14151438458629, 0.}, {
      112.74575057865776`, -6.086874591813504, 1.4088324360345807`}, {
      109.82620369879501`, -7.532957203281128, 0.7044162180172904}, {
      109.63236053619964`, -7.0602770996675215`, 0.}}], 
     Polygon3DBox[{{112.35806425346702`, -5.14151438458629, 0.}, {
      115.0837679707344, -3.222751669505058, 0.}, {
      115.6652974585205, -4.640791980345879, 2.1132486540518713`}, {
      112.74575057865776`, -6.086874591813504, 1.4088324360345807`}, {
      112.35806425346702`, -5.14151438458629, 0.}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.82620369879501`, -7.532957203281128, 0.7044162180172904}, {
      109.82108456630708`, -8.104185447101745, 1.3608276348795432`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.82620369879501`, -7.532957203281128, 
      0.7044162180172904}, {112.74575057865776`, -6.086874591813504, 
      1.4088324360345807`}, {112.73551231368188`, -7.22933107945474, 
      2.7216552697590863`}, {109.82108456630708`, -8.104185447101745, 
      1.3608276348795432`}, {109.82620369879501`, -7.532957203281128, 
      0.7044162180172904}}], 
     Polygon3DBox[{{112.74575057865776`, -6.086874591813504, 
      1.4088324360345807`}, {115.6652974585205, -4.640791980345879, 
      2.1132486540518713`}, {115.6499400610567, -6.354476711807733, 
      4.08248290463863}, {112.73551231368188`, -7.22933107945474, 
      2.7216552697590863`}, {112.74575057865776`, -6.086874591813504, 
      1.4088324360345807`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.82108456630708`, -8.104185447101745, 1.3608276348795432`}, {
      109.61735199915512`, -8.735033570312307, 1.9245008972987525`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.82108456630708`, -8.104185447101745, 
      1.3608276348795432`}, {112.73551231368188`, -7.22933107945474, 
      2.7216552697590863`}, {112.32804717937799`, -8.491027325875862, 
      3.849001794597505}, {109.61735199915512`, -8.735033570312307, 
      1.9245008972987525`}, {109.82108456630708`, -8.104185447101745, 
      1.3608276348795432`}}], 
     Polygon3DBox[{{112.73551231368188`, -7.22933107945474, 
      2.7216552697590863`}, {115.6499400610567, -6.354476711807733, 
      4.08248290463863}, {115.03874235960083`, -8.247021081439415, 
      5.773502691896258}, {112.32804717937799`, -8.491027325875862, 
      3.849001794597505}, {112.73551231368188`, -7.22933107945474, 
      2.7216552697590863`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.61735199915512`, -8.735033570312307, 1.9245008972987525`}, {
      109.22889003510657`, -9.382510315841825, 2.357022603955158}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.61735199915512`, -8.735033570312307, 
      1.9245008972987525`}, {112.32804717937799`, -8.491027325875862, 
      3.849001794597505}, {111.55112325128087`, -9.7859808169349, 
      4.714045207910316}, {109.22889003510657`, -9.382510315841825, 
      2.357022603955158}, {109.61735199915512`, -8.735033570312307, 
      1.9245008972987525`}}], 
     Polygon3DBox[{{112.32804717937799`, -8.491027325875862, 
      3.849001794597505}, {115.03874235960083`, -8.247021081439415, 
      5.773502691896258}, {113.87335646745518`, -10.189451318027977`, 
      7.0710678118654755`}, {111.55112325128087`, -9.7859808169349, 
      4.714045207910316}, {112.32804717937799`, -8.491027325875862, 
      3.849001794597505}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.22889003510657`, -9.382510315841825, 2.357022603955158}, {
      108.68217171504757`, -10.002491213488383`, 2.628917115316043}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{109.22889003510657`, -9.382510315841825, 
      2.357022603955158}, {111.55112325128087`, -9.7859808169349, 
      4.714045207910316}, {110.4576866111629, -11.025942612228011`, 
      5.257834230632086}, {108.68217171504757`, -10.002491213488383`, 
      2.628917115316043}, {109.22889003510657`, -9.382510315841825, 
      2.357022603955158}}], 
     Polygon3DBox[{{111.55112325128087`, -9.7859808169349, 
      4.714045207910316}, {113.87335646745518`, -10.189451318027977`, 
      7.0710678118654755`}, {112.23320150727821`, -12.049394010967642`, 
      7.886751345948128}, {110.4576866111629, -11.025942612228011`, 
      5.257834230632086}, {111.55112325128087`, -9.7859808169349, 
      4.714045207910316}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      108.68217171504757`, -10.002491213488383`, 2.628917115316043}, {
      108.01445498899542`, -10.552725589644238`, 2.721655269759087}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{108.68217171504757`, -10.002491213488383`, 
      2.628917115316043}, {110.4576866111629, -11.025942612228011`, 
      5.257834230632086}, {109.1222531590586, -12.126411364539722`, 
      5.443310539518174}, {108.01445498899542`, -10.552725589644238`, 
      2.721655269759087}, {108.68217171504757`, -10.002491213488383`, 
      2.628917115316043}}], 
     Polygon3DBox[{{110.4576866111629, -11.025942612228011`, 
      5.257834230632086}, {112.23320150727821`, -12.049394010967642`, 
      7.886751345948128}, {110.23005132912176`, -13.700097139435208`, 
      8.16496580927726}, {109.1222531590586, -12.126411364539722`, 
      5.443310539518174}, {110.4576866111629, -11.025942612228011`, 
      5.257834230632086}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      108.01445498899542`, -10.552725589644238`, 2.721655269759087}, {
      107.27124364837651`, -10.995715880879672`, 2.628917115316043}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{108.01445498899542`, -10.552725589644238`, 
      2.721655269759087}, {109.1222531590586, -12.126411364539724`, 
      5.443310539518174}, {107.63583047782075`, -13.01239194701059, 
      5.257834230632086}, {107.27124364837651`, -10.995715880879672`, 
      2.628917115316043}, {108.01445498899542`, -10.552725589644238`, 
      2.721655269759087}}], 
     Polygon3DBox[{{109.1222531590586, -12.126411364539724`, 
      5.443310539518174}, {110.23005132912176`, -13.700097139435211`, 
      8.16496580927726}, {108.000417307265, -15.02906801314151, 
      7.88675134594813}, {107.63583047782075`, -13.01239194701059, 
      5.257834230632086}, {109.1222531590586, -12.126411364539724`, 
      5.443310539518174}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      107.27124364837651`, -10.995715880879672`, 2.628917115316043}, {
      106.5031863178392, -11.301273030923058`, 2.357022603955159}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{107.27124364837651`, -10.995715880879672`, 
      2.628917115316043}, {107.63583047782075`, -13.01239194701059, 
      5.257834230632086}, {106.09971581674611`, -13.623506247097364`, 
      4.714045207910318}, {106.5031863178392, -11.301273030923058`, 
      2.357022603955159}, {107.27124364837651`, -10.995715880879672`, 
      2.628917115316043}}], 
     Polygon3DBox[{{107.63583047782075`, -13.01239194701059, 
      5.257834230632086}, {108.000417307265, -15.02906801314151, 
      7.88675134594813}, {105.69624531565304`, -15.945739463271671`, 
      7.071067811865477}, {106.09971581674611`, -13.623506247097364`, 
      4.714045207910318}, {107.63583047782075`, -13.01239194701059, 
      5.257834230632086}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      106.5031863178392, -11.301273030923058`, 2.357022603955159}, {
      105.76262483518482`, -11.448573824956007`, 1.924500897298753}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{106.5031863178392, -11.301273030923058`, 
      2.357022603955159}, {106.09971581674611`, -13.623506247097364`, 
      4.714045207910318}, {104.6185928514374, -13.918107835163262`, 
      3.849001794597506}, {105.76262483518482`, -11.448573824956007`, 
      1.924500897298753}, {106.5031863178392, -11.301273030923058`, 
      2.357022603955159}}], 
     Polygon3DBox[{{106.09971581674611`, -13.623506247097364`, 
      4.714045207910318}, {105.69624531565304`, -15.945739463271671`, 
      7.071067811865477}, {103.47456086768997`, -16.387641845370517`, 
      5.773502691896259}, {104.6185928514374, -13.918107835163262`, 
      3.849001794597506}, {106.09971581674611`, -13.623506247097364`, 
      4.714045207910318}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      105.76262483518482`, -11.448573824956007`, 1.924500897298753}, {
      105.10002724162062`, -11.427579957291243`, 1.3608276348795432`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{105.76262483518482`, -11.448573824956007`, 
      1.924500897298753}, {104.6185928514374, -13.918107835163262`, 
      3.849001794597506}, {103.29339766430897`, -13.876120099833736`, 
      2.7216552697590863`}, {105.10002724162062`, -11.427579957291243`, 
      1.3608276348795432`}, {105.76262483518482`, -11.448573824956007`, 
      1.924500897298753}}], 
     Polygon3DBox[{{104.6185928514374, -13.918107835163262`, 
      3.849001794597506}, {103.47456086768997`, -16.387641845370517`, 
      5.773502691896259}, {101.48676808699733`, -16.32466024237623, 
      4.08248290463863}, {103.29339766430897`, -13.876120099833736`, 
      2.7216552697590863`}, {104.6185928514374, -13.918107835163262`, 
      3.849001794597506}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      105.10002724162062`, -11.427579957291245`, 1.3608276348795445`}, {
      104.56054846815366`, -11.239722125316117`, 0.704416218017291}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{105.10002724162062`, -11.427579957291245`, 
      1.3608276348795445`}, {103.29339766430897`, -13.876120099833738`, 
      2.721655269759089}, {102.21444011737505`, -13.500404435883482`, 
      1.408832436034582}, {104.56054846815366`, -11.239722125316117`, 
      0.704416218017291}, {105.10002724162062`, -11.427579957291245`, 
      1.3608276348795445`}}], 
     Polygon3DBox[{{103.29339766430897`, -13.876120099833738`, 
      2.721655269759089}, {101.48676808699733`, -16.32466024237623, 
      4.082482904638634}, {99.86833176659643, -15.761086746450847`, 
      2.1132486540518736`}, {102.21444011737505`, -13.500404435883482`, 
      1.408832436034582}, {103.29339766430897`, -13.876120099833738`, 
      2.721655269759089}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      104.56054846815366`, -11.239722125316117`, 0.704416218017291}, {
      104.18095310166488`, -10.897802529829983`, 3.3330664144929925`*^-16}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{104.56054846815366`, -11.239722125316117`, 
      0.704416218017291}, {102.21444011737505`, -13.500404435883482`, 
      1.408832436034582}, {101.4552493843975, -12.816565244911214`, 
      6.666132828985985*^-16}, {104.18095310166488`, -10.897802529829983`, 
      3.3330664144929925`*^-16}, {104.56054846815366`, -11.239722125316117`, 
      0.704416218017291}}], 
     Polygon3DBox[{{102.21444011737505`, -13.500404435883482`, 
      1.408832436034582}, {99.86833176659643, -15.761086746450847`, 
      2.1132486540518736`}, {98.72954566713013, -14.735327959992446`, 
      9.999199243478977*^-16}, {101.4552493843975, -12.816565244911214`, 
      6.666132828985985*^-16}, {102.21444011737505`, -13.500404435883482`, 
      1.408832436034582}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      104.18095310166488`, -10.897802529829983`, 3.3330664144929925`*^-16}, {
      103.98710993906951`, -10.425122426216376`, -0.7044162180172906}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{104.18095310166488`, -10.897802529829983`, 
      3.3330664144929925`*^-16}, {101.4552493843975, -12.816565244911214`, 
      6.666132828985985*^-16}, {
      101.06756305920676`, -11.871205037684, -1.4088324360345812`}, {
      103.98710993906951`, -10.425122426216376`, -0.7044162180172906}, {
      104.18095310166488`, -10.897802529829983`, 3.3330664144929925`*^-16}}], 
     Polygon3DBox[{{101.4552493843975, -12.816565244911214`, 
      6.666132828985985*^-16}, {98.72954566713013, -14.735327959992446`, 
      9.999199243478977*^-16}, {
      98.14801617934403, -13.317287649151627`, -2.113248654051872}, {
      101.06756305920676`, -11.871205037684, -1.4088324360345812`}, {
      101.4552493843975, -12.816565244911214`, 6.666132828985985*^-16}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      103.98710993906951`, -10.425122426216378`, -0.7044162180172893}, {
      103.99222907155745`, -9.85389418239576, -1.3608276348795427`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      103.98710993906951`, -10.425122426216378`, -0.7044162180172893}, {
      101.06756305920676`, -11.871205037684003`, -1.4088324360345785`}, {
      101.07780132418264`, -10.728748550042766`, -2.7216552697590854`}, {
      103.99222907155745`, -9.85389418239576, -1.3608276348795427`}, {
      103.98710993906951`, -10.425122426216378`, -0.7044162180172893}}], 
     Polygon3DBox[{{
      101.06756305920676`, -11.871205037684003`, -1.4088324360345785`}, {
      98.14801617934403, -13.317287649151629`, -2.1132486540518682`}, {
      98.16337357680783, -11.603602917689773`, -4.082482904638629}, {
      101.07780132418264`, -10.728748550042766`, -2.7216552697590854`}, {
      101.06756305920676`, -11.871205037684003`, -1.4088324360345785`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      103.99222907155745`, -9.85389418239576, -1.3608276348795427`}, {
      104.1959616387094, -9.223046059185197, -1.9245008972987525`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      103.99222907155745`, -9.85389418239576, -1.3608276348795427`}, {
      101.07780132418264`, -10.728748550042766`, -2.7216552697590854`}, {
      101.48526645848654`, -9.467052303621642, -3.849001794597505}, {
      104.1959616387094, -9.223046059185197, -1.9245008972987525`}, {
      103.99222907155745`, -9.85389418239576, -1.3608276348795427`}}], 
     Polygon3DBox[{{
      101.07780132418264`, -10.728748550042766`, -2.7216552697590854`}, {
      98.16337357680783, -11.603602917689773`, -4.082482904638629}, {
      98.77457127826368, -9.711058548058089, -5.773502691896258}, {
      101.48526645848654`, -9.467052303621642, -3.849001794597505}, {
      101.07780132418264`, -10.728748550042766`, -2.7216552697590854`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      104.1959616387094, -9.223046059185197, -1.9245008972987514`}, {
      104.58442360275795`, -8.575569313655679, -2.357022603955158}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      104.1959616387094, -9.223046059185197, -1.9245008972987514`}, {
      101.48526645848654`, -9.467052303621646, -3.849001794597503}, {
      102.26219038658365`, -8.172098812562606, -4.714045207910316}, {
      104.58442360275795`, -8.575569313655679, -2.357022603955158}, {
      104.1959616387094, -9.223046059185197, -1.9245008972987514`}}], 
     Polygon3DBox[{{
      101.48526645848654`, -9.467052303621646, -3.849001794597503}, {
      98.77457127826368, -9.71105854805809, -5.773502691896255}, {
      99.93995717040934, -7.7686283114695325`, -7.071067811865474}, {
      102.26219038658365`, -8.172098812562606, -4.714045207910316}, {
      101.48526645848654`, -9.467052303621646, -3.849001794597503}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      104.58442360275795`, -8.575569313655679, -2.357022603955158}, {
      105.13114192281695`, -7.955588416009124, -2.628917115316043}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      104.58442360275795`, -8.575569313655679, -2.357022603955158}, {
      102.26219038658365`, -8.172098812562606, -4.714045207910316}, {
      103.35562702670163`, -6.932137017269495, -5.257834230632086}, {
      105.13114192281695`, -7.955588416009124, -2.628917115316043}, {
      104.58442360275795`, -8.575569313655679, -2.357022603955158}}], 
     Polygon3DBox[{{
      102.26219038658365`, -8.172098812562606, -4.714045207910316}, {
      99.93995717040934, -7.7686283114695325`, -7.071067811865474}, {
      101.58011213058631`, -5.908685618529867, -7.886751345948128}, {
      103.35562702670163`, -6.932137017269495, -5.257834230632086}, {
      102.26219038658365`, -8.172098812562606, -4.714045207910316}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      105.13114192281695`, -7.955588416009124, -2.628917115316043}, {
      105.7988586488691, -7.405354039853268, -2.721655269759087}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      105.13114192281695`, -7.955588416009124, -2.628917115316043}, {
      103.35562702670163`, -6.932137017269495, -5.257834230632086}, {
      104.69106047880592`, -5.831668264957784, -5.443310539518174}, {
      105.7988586488691, -7.405354039853268, -2.721655269759087}, {
      105.13114192281695`, -7.955588416009124, -2.628917115316043}}], 
     Polygon3DBox[{{
      103.35562702670163`, -6.932137017269495, -5.257834230632086}, {
      101.58011213058631`, -5.908685618529867, -7.886751345948128}, {
      103.58326230874275`, -4.257982490062299, -8.16496580927726}, {
      104.69106047880592`, -5.831668264957784, -5.443310539518174}, {
      103.35562702670163`, -6.932137017269495, -5.257834230632086}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      105.7988586488691, -7.4053540398532665`, -2.721655269759087}, {
      106.54206998948801`, -6.9623637486178325`, -2.6289171153160438`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      105.7988586488691, -7.4053540398532665`, -2.721655269759087}, {
      104.69106047880592`, -5.831668264957781, -5.443310539518174}, {
      106.17748316004376`, -4.9456876824869145`, -5.2578342306320875`}, {
      106.54206998948801`, -6.9623637486178325`, -2.6289171153160438`}, {
      105.7988586488691, -7.4053540398532665`, -2.721655269759087}}], 
     Polygon3DBox[{{
      104.69106047880592`, -5.831668264957781, -5.443310539518174}, {
      103.58326230874276`, -4.257982490062296, -8.16496580927726}, {
      105.81289633059953`, -2.9290116163559956`, -7.886751345948132}, {
      106.17748316004376`, -4.9456876824869145`, -5.2578342306320875`}, {
      104.69106047880592`, -5.831668264957781, -5.443310539518174}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      106.54206998948801`, -6.9623637486178325`, -2.6289171153160438`}, {
      107.31012732002533`, -6.6568065985744465`, -2.35702260395516}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      106.54206998948801`, -6.9623637486178325`, -2.6289171153160438`}, {
      106.17748316004376`, -4.9456876824869145`, -5.2578342306320875`}, {
      107.71359782111841`, -4.334573382400141, -4.71404520791032}, {
      107.31012732002533`, -6.6568065985744465`, -2.35702260395516}, {
      106.54206998948801`, -6.9623637486178325`, -2.6289171153160438`}}], 
     Polygon3DBox[{{
      106.17748316004376`, -4.9456876824869145`, -5.2578342306320875`}, {
      105.81289633059953`, -2.9290116163559956`, -7.886751345948132}, {
      108.11706832221148`, -2.012340166225836, -7.07106781186548}, {
      107.71359782111841`, -4.334573382400141, -4.71404520791032}, {
      106.17748316004376`, -4.9456876824869145`, -5.2578342306320875`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      107.31012732002533`, -6.6568065985744465`, -2.35702260395516}, {
      108.0506888026797, -6.509505804541497, -1.924500897298755}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      107.31012732002533`, -6.6568065985744465`, -2.35702260395516}, {
      107.71359782111841`, -4.334573382400141, -4.71404520791032}, {
      109.19472078642711`, -4.039971794334242, -3.84900179459751}, {
      108.0506888026797, -6.509505804541497, -1.924500897298755}, {
      107.31012732002533`, -6.6568065985744465`, -2.35702260395516}}], 
     Polygon3DBox[{{
      107.71359782111841`, -4.334573382400141, -4.71404520791032}, {
      108.11706832221148`, -2.012340166225836, -7.07106781186548}, {
      110.33875277017455`, -1.5704377841269874`, -5.773502691896265}, {
      109.19472078642711`, -4.039971794334242, -3.84900179459751}, {
      107.71359782111841`, -4.334573382400141, -4.71404520791032}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      108.0506888026797, -6.509505804541497, -1.9245008972987532`}, {
      108.7132863962439, -6.530499672206259, -1.3608276348795447`}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      108.0506888026797, -6.509505804541497, -1.9245008972987532`}, {
      109.19472078642711`, -4.039971794334242, -3.8490017945975064`}, {
      110.51991597355556`, -4.081959529663767, -2.7216552697590894`}, {
      108.7132863962439, -6.530499672206259, -1.3608276348795447`}, {
      108.0506888026797, -6.509505804541497, -1.9245008972987532`}}], 
     Polygon3DBox[{{
      109.19472078642711`, -4.039971794334242, -3.8490017945975064`}, {
      110.33875277017455`, -1.5704377841269865`, -5.77350269189626}, {
      112.3265455508672, -1.633419387121275, -4.082482904638634}, {
      110.51991597355556`, -4.081959529663767, -2.7216552697590894`}, {
      109.19472078642711`, -4.039971794334242, -3.8490017945975064`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      108.7132863962439, -6.530499672206259, -1.3608276348795447`}, {
      109.25276516971087`, -6.7183575041813866`, -0.7044162180172927}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      108.7132863962439, -6.530499672206259, -1.3608276348795447`}, {
      110.51991597355556`, -4.081959529663767, -2.7216552697590894`}, {
      111.59887352048948`, -4.457675193614021, -1.4088324360345854`}, {
      109.25276516971087`, -6.7183575041813866`, -0.7044162180172927}, {
      108.7132863962439, -6.530499672206259, -1.3608276348795447`}}], 
     Polygon3DBox[{{
      110.51991597355556`, -4.081959529663767, -2.7216552697590894`}, {
      112.3265455508672, -1.633419387121275, -4.082482904638634}, {
      113.94498187126808`, -2.196992883046655, -2.113248654051878}, {
      111.59887352048948`, -4.457675193614021, -1.4088324360345854`}, {
      110.51991597355556`, -4.081959529663767, -2.7216552697590894`}}], 
     Polygon3DBox[{{106.90665681893226`, -8.979039814748752, 0.}, {
      109.25276516971087`, -6.7183575041813866`, -0.7044162180172927}, {
      109.63236053619964`, -7.06027709966752, -3.083928759361742*^-15}, {
      106.90665681893226`, -8.979039814748752, 0.}, {
      106.90665681893226`, -8.979039814748752, 0.}}], 
     Polygon3DBox[{{
      109.25276516971087`, -6.7183575041813866`, -0.7044162180172927}, {
      111.59887352048948`, -4.457675193614021, -1.4088324360345854`}, {
      112.35806425346702`, -5.141514384586286, -6.167857518723484*^-15}, {
      109.63236053619964`, -7.06027709966752, -3.083928759361742*^-15}, {
      109.25276516971087`, -6.7183575041813866`, -0.7044162180172927}}], 
     Polygon3DBox[{{
      111.59887352048948`, -4.457675193614021, -1.4088324360345854`}, {
      113.94498187126808`, -2.196992883046655, -2.113248654051878}, {
      115.0837679707344, -3.222751669505053, -9.251786278085227*^-15}, {
      112.35806425346702`, -5.141514384586286, -6.167857518723484*^-15}, {
      111.59887352048948`, -4.457675193614021, -1.4088324360345854`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIM7eEFoSczTGYYHVXzajE5wHGKDAfe4p6ymvYhzm
1d85qj1B6IDsAe6X754zOAQtM5o34yVQfGHhx99ZkgeWz2ZPKwsRcFC7a32w
6lCMw8MMkZ7KOoUDT+y/iAlKiDuIxbUJPS2PcWiwijv8P0HlwAEueYZjHjIO
l04wH3vDF+Nwrei3tpekxoGP8lXdHD3yDmv3mWru7It2KDt9W7E4TRtqvoJD
n3PANTaGaIf7s1YzPOLTO/AZqt5Nr9mjPyfKYc3kpm/mT/QPHIKar7am2yT+
XqRDXu6POptkgwNPoe75NiPUVD0+0sE2kPm9TLDBgdVQ9zM/T9s/6XuEw6Wb
VZprW/UPKEH9ezrA/8GGdREODIwcL2oqdA90Xm8VDWS+ZPM++ZZEZWeEw23+
m23Fi7QOiEHUH3gSVbStpCvC4VYdXyG3qfqBpRDzD/CrZE6etDHC4cSzTXf5
c5QPPIC454DCYjknjT8RDmFal3yEheUP7IO4/0CKxcI+hdRIh5U7p1fXLRKH
hc+BTqd87ZCnkQ7pHNf7dTgEYeFzYMXekDq2kigHtct5S+bmsR/4ClX/4ZIi
Tx17tMO390JnXSUZDhyFmi8QKqmwbmq0Q8yyzXHNCj/3P4O6xyHDX/6ZSIxD
XiZrXI3Sr/3Q8DlgJGU3taomxiHouiFj4WTGAzpQ/8LSz1xo+oGEz6M9ABP+
Auw=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIG60qBDV/BTrsM/p78LSM8oHnth/EROUED8Qq/r2
ToJ4nMMTYx3m+kVqB1bvv+Ni7MF7IEMv1D5VDCh+5JvEc36tA18mbDqcxfd7
v01qXJL7+1iH7zFBax7d0D3AAAU6z1Zs3rgk1sFb/FzhlrsGBwq0Vy+5fOiL
/YsAtfSd1rEOZZtllt3caXRA6gD3y3fPGRwOu0Wcat0d43DsPo9iXoLJgSvv
TLO2KzI7LDldVH5ZJ8ah6njJhKVbTA/IQdXHbFv6MnpmtMND54TugPlmByqg
5tuYrLuqzR3tUJUuzl8oYA51zwUbHsWKa5+7oxw8vZXqAxnMDzyBul8yvzMh
XiXK4UvaHRXuArMDy6D+fXijsLH2dqRD9y8lluJM0wOPoeHD+ubPTtdtkQ4/
GruD8/4ZH3gvX9XN0SN/4NejKeGO2yMdKiyXeexyNzpw5G3tPudtygdU13Sb
xN+LdMjP/VFnk2xw4BHYHPUDZtqOj79oRDk4ci4/9umxzoHApZ3d2Rs0D1Qd
OKz/dmKUw6sLnHErtDUPvNI3v8gTpH1g/qmJZxSEoh28KjQz6u+pHpi5u/Fj
3QPtA/tcy+UvL4h2eLAislPATPnAG6h6tmiXtV4mMQ4iG5om70pQPBACNV/t
rvXBqkMxDo8yRHoq6xQOPIW6J+xD4YFNjrEOLgv/rd4xT+HACaj7PRYlmLmv
jHV4ldmV4Lpf8cAvqH9h6WcvNP08g4YPAGqPGdI=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{115.0837679707344, -3.222751669505058, 0.}, {
       119.78375756016068`, -9.899334966817488, -5.773502691896258}, {
       120.36528704794678`, -11.317375277658307`, -3.660254037844387}, {
       115.6652974585205, -4.640791980345879, 2.1132486540518713`}, {
       115.0837679707344, -3.222751669505058, 0.}}], 
      Line3DBox[{{115.6652974585205, -4.640791980345879, 
       2.1132486540518713`}, {
       120.36528704794678`, -11.317375277658307`, -3.660254037844387}, {
       120.34992965048298`, -13.03106000912016, -1.6910197872576278`}, {
       115.6499400610567, -6.354476711807733, 4.08248290463863}, {
       115.6652974585205, -4.640791980345879, 2.1132486540518713`}}], 
      Line3DBox[{{115.6499400610567, -6.354476711807733, 4.08248290463863}, {
       120.34992965048298`, -13.03106000912016, -1.6910197872576278`}, {
       119.73873194902711`, -14.923604378751845`, 0.}, {
       115.03874235960083`, -8.247021081439415, 5.773502691896258}, {
       115.6499400610567, -6.354476711807733, 4.08248290463863}}], 
      Line3DBox[{{115.03874235960083`, -8.247021081439415, 
       5.773502691896258}, {119.73873194902711`, -14.923604378751845`, 0.}, {
       118.57334605688146`, -16.866034615340407`, 1.2975651199692173`}, {
       113.87335646745518`, -10.189451318027977`, 7.0710678118654755`}, {
       115.03874235960083`, -8.247021081439415, 5.773502691896258}}], 
      Line3DBox[{{113.87335646745518`, -10.189451318027977`, 
       7.0710678118654755`}, {118.57334605688146`, -16.866034615340407`, 
       1.2975651199692173`}, {116.93319109670449`, -18.725977308280072`, 
       2.11324865405187}, {112.23320150727821`, -12.049394010967642`, 
       7.886751345948128}, {113.87335646745518`, -10.189451318027977`, 
       7.0710678118654755`}}], 
      Line3DBox[{{112.23320150727821`, -12.049394010967642`, 
       7.886751345948128}, {116.93319109670449`, -18.725977308280072`, 
       2.11324865405187}, {114.93004091854804`, -20.376680436747638`, 
       2.3914631173810026`}, {110.23005132912176`, -13.700097139435208`, 
       8.16496580927726}, {112.23320150727821`, -12.049394010967642`, 
       7.886751345948128}}], 
      Line3DBox[{{110.23005132912176`, -13.700097139435211`, 
       8.16496580927726}, {114.93004091854804`, -20.37668043674764, 
       2.3914631173810026`}, {112.70040689669128`, -21.705651310453938`, 
       2.113248654051872}, {108.000417307265, -15.02906801314151, 
       7.88675134594813}, {110.23005132912176`, -13.700097139435211`, 
       8.16496580927726}}], 
      Line3DBox[{{108.000417307265, -15.02906801314151, 7.88675134594813}, {
       112.70040689669128`, -21.705651310453938`, 2.113248654051872}, {
       110.39623490507933`, -22.6223227605841, 1.297565119969219}, {
       105.69624531565304`, -15.945739463271671`, 7.071067811865477}, {
       108.000417307265, -15.02906801314151, 7.88675134594813}}], 
      Line3DBox[{{105.69624531565304`, -15.945739463271671`, 
       7.071067811865477}, {110.39623490507933`, -22.6223227605841, 
       1.297565119969219}, {108.17455045711625`, -23.06422514268295, 
       8.881784197001252*^-16}, {103.47456086768997`, -16.387641845370517`, 
       5.773502691896259}, {105.69624531565304`, -15.945739463271671`, 
       7.071067811865477}}], 
      Line3DBox[{{103.47456086768997`, -16.387641845370517`, 
       5.773502691896259}, {108.17455045711625`, -23.06422514268295, 
       8.881784197001252*^-16}, {
       106.18675767642361`, -23.00124353968866, -1.6910197872576278`}, {
       101.48676808699733`, -16.32466024237623, 4.08248290463863}, {
       103.47456086768997`, -16.387641845370517`, 5.773502691896259}}], 
      Line3DBox[{{101.48676808699733`, -16.32466024237623, 
       4.082482904638634}, {
       106.18675767642361`, -23.001243539688662`, -1.6910197872576243`}, {
       104.56832135602271`, -22.437670043763276`, -3.6602540378443846`}, {
       99.86833176659643, -15.761086746450847`, 2.1132486540518736`}, {
       101.48676808699733`, -16.32466024237623, 4.082482904638634}}], 
      Line3DBox[{{99.86833176659643, -15.761086746450847`, 
       2.1132486540518736`}, {
       104.56832135602271`, -22.437670043763276`, -3.6602540378443846`}, {
       103.4295352565564, -21.411911257304876`, -5.773502691896257}, {
       98.72954566713013, -14.735327959992446`, 9.999199243478977*^-16}, {
       99.86833176659643, -15.761086746450847`, 2.1132486540518736`}}], 
      Line3DBox[{{98.72954566713013, -14.735327959992446`, 
       9.999199243478977*^-16}, {
       103.4295352565564, -21.411911257304876`, -5.773502691896257}, {
       102.8480057687703, -19.993870946464057`, -7.88675134594813}, {
       98.14801617934403, -13.317287649151627`, -2.113248654051872}, {
       98.72954566713013, -14.735327959992446`, 9.999199243478977*^-16}}], 
      Line3DBox[{{
       98.14801617934403, -13.317287649151629`, -2.1132486540518682`}, {
       102.8480057687703, -19.993870946464057`, -7.886751345948126}, {
       102.86336316623411`, -18.280186215002203`, -9.855985596534886}, {
       98.16337357680783, -11.603602917689773`, -4.082482904638629}, {
       98.14801617934403, -13.317287649151629`, -2.1132486540518682`}}], 
      Line3DBox[{{
       98.16337357680783, -11.603602917689773`, -4.082482904638629}, {
       102.86336316623411`, -18.280186215002203`, -9.855985596534886}, {
       103.47456086768996`, -16.38764184537052, -11.547005383792516`}, {
       98.77457127826368, -9.711058548058089, -5.773502691896258}, {
       98.16337357680783, -11.603602917689773`, -4.082482904638629}}], 
      Line3DBox[{{98.77457127826368, -9.71105854805809, -5.773502691896255}, {
       103.47456086768996`, -16.38764184537052, -11.547005383792513`}, {
       104.63994675983562`, -14.445211608781962`, -12.844570503761732`}, {
       99.93995717040934, -7.7686283114695325`, -7.071067811865474}, {
       98.77457127826368, -9.71105854805809, -5.773502691896255}}], 
      Line3DBox[{{
       99.93995717040934, -7.7686283114695325`, -7.071067811865474}, {
       104.63994675983562`, -14.445211608781962`, -12.844570503761732`}, {
       106.2801017200126, -12.585268915842295`, -13.660254037844386`}, {
       101.58011213058631`, -5.908685618529867, -7.886751345948128}, {
       99.93995717040934, -7.7686283114695325`, -7.071067811865474}}], 
      Line3DBox[{{
       101.58011213058631`, -5.908685618529867, -7.886751345948128}, {
       106.2801017200126, -12.585268915842295`, -13.660254037844386`}, {
       108.28325189816903`, -10.93456578737473, -13.938468501173519`}, {
       103.58326230874275`, -4.257982490062299, -8.16496580927726}, {
       101.58011213058631`, -5.908685618529867, -7.886751345948128}}], 
      Line3DBox[{{
       103.58326230874276`, -4.257982490062296, -8.16496580927726}, {
       108.28325189816904`, -10.934565787374726`, -13.938468501173519`}, {
       110.51288592002581`, -9.605594913668426, -13.660254037844389`}, {
       105.81289633059953`, -2.9290116163559956`, -7.886751345948132}, {
       103.58326230874276`, -4.257982490062296, -8.16496580927726}}], 
      Line3DBox[{{
       105.81289633059953`, -2.9290116163559956`, -7.886751345948132}, {
       110.51288592002581`, -9.605594913668426, -13.660254037844389`}, {
       112.81705791163776`, -8.688923463538266, -12.844570503761737`}, {
       108.11706832221148`, -2.012340166225836, -7.07106781186548}, {
       105.81289633059953`, -2.9290116163559956`, -7.886751345948132}}], 
      Line3DBox[{{
       108.11706832221148`, -2.012340166225836, -7.07106781186548}, {
       112.81705791163776`, -8.688923463538266, -12.844570503761737`}, {
       115.03874235960083`, -8.247021081439417, -11.547005383792524`}, {
       110.33875277017455`, -1.5704377841269874`, -5.773502691896265}, {
       108.11706832221148`, -2.012340166225836, -7.07106781186548}}], 
      Line3DBox[{{
       110.33875277017455`, -1.5704377841269865`, -5.77350269189626}, {
       115.03874235960083`, -8.247021081439417, -11.547005383792518`}, {
       117.02653514029348`, -8.310002684433705, -9.855985596534893}, {
       112.3265455508672, -1.633419387121275, -4.082482904638634}, {
       110.33875277017455`, -1.5704377841269865`, -5.77350269189626}}], 
      Line3DBox[{{
       112.3265455508672, -1.633419387121275, -4.082482904638634}, {
       117.02653514029348`, -8.310002684433705, -9.855985596534893}, {
       118.64497146069436`, -8.873576180359084, -7.886751345948136}, {
       113.94498187126808`, -2.196992883046655, -2.113248654051878}, {
       112.3265455508672, -1.633419387121275, -4.082482904638634}}], 
      Line3DBox[{{
       113.94498187126808`, -2.196992883046655, -2.113248654051878}, {
       118.64497146069436`, -8.873576180359084, -7.886751345948136}, {
       119.78375756016068`, -9.899334966817483, -5.773502691896267}, {
       115.0837679707344, -3.222751669505053, -9.251786278085227*^-15}, {
       113.94498187126808`, -2.196992883046655, -2.113248654051878}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{150.22840561881878`, 39.868896937819834`, 
      64.87059913085828}, {160.56058569367394`, 39.91900296787093, 
      70.39344662916622}, {159.7070127275433, 42.732077531428196`, 
      71.96479503180298}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {150.22840561881878`, 39.868896937819834`, 
      64.87059913085828}}], 
     Polygon3DBox[{{150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {159.7070127275433, 42.732077531428196`, 
      71.96479503180298}, {158.85343976141263`, 45.54515209498546, 
      73.53614343443975}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}}], 
     Polygon3DBox[{{149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {158.85343976141263`, 45.54515209498546, 
      73.53614343443975}, {157.99986679528197`, 48.358226658542726`, 
      75.10749183707652}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {157.99986679528197`, 48.358226658542726`, 
      75.10749183707652}, {157.14629382915132`, 51.17130122209999, 
      76.6788402397133}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {157.14629382915132`, 51.17130122209999, 
      76.6788402397133}, {156.29272086302066`, 53.98437578565726, 
      78.25018864235007}, {146.8121187877787, 53.93839949323465, 
      73.18253408403197}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}}], 
     Polygon3DBox[{{146.8121187877787, 53.93839949323465, 
      73.18253408403197}, {156.29272086302066`, 53.98437578565726, 
      78.25018864235007}, {155.43914789689, 56.79745034921452, 
      79.82153704498683}, {145.10696782203485`, 56.747344319163425`, 
      74.2986895466789}, {146.8121187877787, 53.93839949323465, 
      73.18253408403197}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7y0EfS/3iSw/vDZ5kt3js7TN+b9XS7eYCDaXLv
QTuguOjicK1L4a4O7kkP9mftDHA4qfu28/buJIdOphhRkwNuDgrvOLuY9AMd
Pgp+lj65NMmh/eLUjwkaHg6J9ket9GYGOpyfnT3TqjXJYemm93siJ3g6BDy/
WK3yI9DB0b7rwZ/IJAdf5vpK2R9eDstCChav8w5yWKZ9wj1HOcnB+UrHrxXx
Pg5qKw/tkp0c5PDv+eN63rxkh83sibeE0nwcPmjJCkz5Euzwe4PKj9jOZIel
+tPZGP55OUTqWYozTwh2+FGZWrBuSbLD9PCzRm+nejocNAyVK9IOdvjqtOzF
v/3JDp31zPG3dD0cNE0LVR8eC3L4xP08wf92skP1csvu40fdHCZa9OoEJAU5
vL+ifnP+t2SH3PP527fEujr8tF5pvP9voMObuRmBHwRTHOK/L3288KuzQxLU
v7jCEwBc66gY
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{151.62581381062526`, 53.67260330460137, 
        62.13108441376929}, {161.95799388548042`, 53.722709334652464`, 
        67.65393191207721}, {160.6386181887476, 51.934548442615885`, 
        70.13845188707698}, {151.15801611350562`, 51.888572150193276`, 
        65.07079732875889}, {151.62581381062526`, 53.67260330460137, 
        62.13108441376929}}], 
       Polygon3DBox[{{151.15801611350562`, 51.888572150193276`, 
        65.07079732875889}, {160.6386181887476, 51.934548442615885`, 
        70.13845188707698}, {159.31924249201478`, 50.146387550579306`, 
        72.62297186207675}, {150.33635189751035`, 50.102824915896875`, 
        67.82135840896161}, {151.15801611350562`, 51.888572150193276`, 
        65.07079732875889}}], 
       Polygon3DBox[{{150.33635189751035`, 50.102824915896875`, 
        67.82135840896161}, {159.31924249201478`, 50.146387550579306`, 
        72.62297186207675}, {157.99986679528197`, 48.358226658542726`, 
        75.10749183707652}, {149.18079946016908`, 48.31545848670344, 
        70.3934466291662}, {150.33635189751035`, 50.102824915896875`, 
        67.82135840896161}}], 
       Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
        70.3934466291662}, {157.99986679528197`, 48.358226658542726`, 
        75.10749183707652}, {156.68049109854917`, 46.57006576650615, 
        77.5920118120763}, {147.69760050404471`, 46.526503131823716`, 
        72.79039835896116}, {149.18079946016908`, 48.31545848670344, 
        70.3934466291662}}], 
       Polygon3DBox[{{147.69760050404471`, 46.526503131823716`, 
        72.79039835896116}, {156.68049109854917`, 46.57006576650615, 
        77.5920118120763}, {155.36111540181633`, 44.78190487446957, 
        80.07653178707606}, {145.88051332657437`, 44.73592858204696, 
        75.00887722875797}, {147.69760050404471`, 46.526503131823716`, 
        72.79039835896116}}], 
       Polygon3DBox[{{145.88051332657437`, 44.73592858204696, 
        75.00887722875797}, {155.36111540181633`, 44.78190487446957, 
        80.07653178707606}, {154.04173970508353`, 42.99374398243299, 
        82.56105176207583}, {143.70955963022837`, 42.9436379523819, 
        77.03820426376791}, {145.88051332657437`, 44.73592858204696, 
        75.00887722875797}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7psH4V25ckh0cWZXfFr3k5HBE+HH9cwN/h7fdz
5XxPkxy2zy7aveejp0PFq5aP7S4BDqo/eFMPn0pyuFX3MlaT19PB0uiO0sQv
AQ4fBT9Ln1ya5NB+cerHBA0Ph0T7o1Z6MwMdii567QsqS3IIMUsqSXF2dzBf
/P/RVKMgh45VHlq6NkkOq7lSXhjFuTmUnDldOPFAkMPEM6nbtnxLdAiIf6Bw
ssLV4c4d7w+FTsEOLzsa34U6JjscmLSDwbje1WFZ3DLXF4tDHJxkHjv2ZSc7
MJvXlIqmuDmoL5vy9ClLiMOc9S5Tj01NdnC7bf/qu4e7w4q3Ta2PU4Mdvjot
e/Fvf7JDZz1z/C1dDwdN00LVh8eCHPyusduYv0p2OKN8/PIeIU+HVTXxR++p
BzmsyMzszxdJceA/0eUx/7ung/YR39Q7HYEOjH9PPVpul+IQlOO3t/GOl8Ma
bhvWWy8DHHCFJwAGLak/
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {147.8510084702099, 50.56907530151053, 
      72.4667254756339}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {146.8121187877787, 53.93839949323465, 
      73.18253408403197}, {146.18732925890475`, 52.82107292142059, 
      74.36153146210344}, {147.8510084702099, 50.56907530151053, 
      72.4667254756339}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}}], 
     Polygon3DBox[{{146.8121187877787, 53.93839949323465, 
      73.18253408403197}, {145.10696782203485`, 56.747344319163425`, 
      74.2986895466789}, {144.16978352872394`, 55.07135446144233, 
      76.06718561378612}, {146.18732925890475`, 52.82107292142059, 
      74.36153146210344}, {146.8121187877787, 53.93839949323465, 
      73.18253408403197}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.8510084702099, 50.56907530151053, 
      72.4667254756339}, {147.61807247975835`, 49.85677761262242, 
      72.90896600634082}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.8510084702099, 50.56907530151053, 72.4667254756339}, {
      146.18732925890475`, 52.82107292142059, 74.36153146210344}, {
      145.72145727800162`, 51.396477543644366`, 75.2460125235173}, {
      147.61807247975835`, 49.85677761262242, 72.90896600634082}, {
      147.8510084702099, 50.56907530151053, 72.4667254756339}}], 
     Polygon3DBox[{{146.18732925890475`, 52.82107292142059, 
      74.36153146210344}, {144.16978352872394`, 55.07135446144233, 
      76.06718561378612}, {143.47097555736923`, 52.934461394778005`, 
      77.39390720590687}, {145.72145727800162`, 51.396477543644366`, 
      75.2460125235173}, {146.18732925890475`, 52.82107292142059, 
      74.36153146210344}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.61807247975835`, 49.85677761262242, 
      72.90896600634082}, {147.48046946609654`, 49.03938743112337, 
      73.17381041738827}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.61807247975835`, 49.85677761262242, 
      72.90896600634082}, {145.72145727800162`, 51.396477543644366`, 
      75.2460125235173}, {145.446251250678, 49.76169718064627, 
      75.77570134561219}, {147.48046946609654`, 49.03938743112337, 
      73.17381041738827}, {147.61807247975835`, 49.85677761262242, 
      72.90896600634082}}], 
     Polygon3DBox[{{145.72145727800162`, 51.396477543644366`, 
      75.2460125235173}, {143.47097555736923`, 52.934461394778005`, 
      77.39390720590687}, {143.0581665163838, 50.48229085028087, 
      78.18844043904923}, {145.446251250678, 49.76169718064627, 
      75.77570134561219}, {145.72145727800162`, 51.396477543644366`, 
      75.2460125235173}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.48046946609654`, 49.03938743112337, 
      73.17381041738827}, {147.4475768472058, 48.17260854708141, 
      73.24320999983945}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.48046946609654`, 49.03938743112337, 
      73.17381041738827}, {145.446251250678, 49.76169718064627, 
      75.77570134561219}, {145.38046601289653`, 48.028139412562346`, 
      75.91450051051456}, {147.4475768472058, 48.17260854708141, 
      73.24320999983945}, {147.48046946609654`, 49.03938743112337, 
      73.17381041738827}}], 
     Polygon3DBox[{{145.446251250678, 49.76169718064627, 75.77570134561219}, {
      143.0581665163838, 50.48229085028087, 78.18844043904923}, {
      142.9594886597116, 47.881954198154965`, 78.3966391864028}, {
      145.38046601289653`, 48.028139412562346`, 75.91450051051456}, {
      145.446251250678, 49.76169718064627, 75.77570134561219}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.4475768472058, 48.17260854708141, 
      73.24320999983945}, {147.52163620070593`, 47.31551050902415, 
      73.11243528683856}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.4475768472058, 48.17260854708141, 
      73.24320999983945}, {145.38046601289653`, 48.028139412562346`, 
      75.91450051051456}, {145.52858471989677`, 46.31394333644783, 
      75.65295108451278}, {147.52163620070593`, 47.31551050902415, 
      73.11243528683856}, {147.4475768472058, 48.17260854708141, 
      73.24320999983945}}], 
     Polygon3DBox[{{145.38046601289653`, 48.028139412562346`, 
      75.91450051051456}, {142.9594886597116, 47.881954198154965`, 
      78.3966391864028}, {143.18166672021195`, 45.31066008398319, 
      78.0043150474001}, {145.52858471989677`, 46.31394333644783, 
      75.65295108451278}, {145.38046601289653`, 48.028139412562346`, 
      75.91450051051456}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.52163620070593`, 47.31551050902415, 
      73.11243528683856}, {147.69760050404471`, 46.526503131823716`, 
      72.79039835896116}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.52163620070593`, 47.31551050902415, 
      73.11243528683856}, {145.52858471989677`, 46.31394333644783, 
      75.65295108451278}, {145.88051332657437`, 44.73592858204696, 
      75.00887722875797}, {147.69760050404471`, 46.526503131823716`, 
      72.79039835896116}, {147.52163620070593`, 47.31551050902415, 
      73.11243528683856}}], 
     Polygon3DBox[{{145.52858471989677`, 46.31394333644783, 
      75.65295108451278}, {143.18166672021195`, 45.31066008398319, 
      78.0043150474001}, {143.70955963022837`, 42.94363795238189, 
      77.03820426376791}, {145.88051332657437`, 44.73592858204696, 
      75.00887722875797}, {145.52858471989677`, 46.31394333644783, 
      75.65295108451278}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.69760050404471`, 46.526503131823716`, 
      72.79039835896116}, {147.96347808074447`, 45.85935596433998, 
      72.29904550065092}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.69760050404471`, 46.526503131823716`, 
      72.79039835896116}, {145.88051332657437`, 44.73592858204696, 
      75.00887722875797}, {146.41226847997382`, 43.4016342470795, 
      74.0261715121375}, {147.96347808074447`, 45.85935596433998, 
      72.29904550065092}, {147.69760050404471`, 46.526503131823716`, 
      72.79039835896116}}], 
     Polygon3DBox[{{145.88051332657437`, 44.73592858204696, 
      75.00887722875797}, {143.70955963022837`, 42.94363795238189, 
      77.03820426376791}, {144.50719236032754`, 40.9421964499307, 
      75.56414568883717}, {146.41226847997382`, 43.4016342470795, 
      74.0261715121375}, {145.88051332657437`, 44.73592858204696, 
      75.00887722875797}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {147.96347808074447`, 45.85935596433998, 
      72.29904550065092}, {148.30114981333645`, 45.359533983524145`, 
      71.67186159720268}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{147.96347808074447`, 45.85935596433998, 
      72.29904550065092}, {146.41226847997382`, 43.4016342470795, 
      74.0261715121375}, {147.08761194515785`, 42.40199028544781, 
      72.77180370524101}, {148.30114981333645`, 45.359533983524145`, 
      71.67186159720268}, {147.96347808074447`, 45.85935596433998, 
      72.29904550065092}}], 
     Polygon3DBox[{{146.41226847997382`, 43.4016342470795, 
      74.0261715121375}, {144.50719236032754`, 40.9421964499307, 
      75.56414568883717}, {145.52020755810355`, 39.44273050748317, 
      73.68259397849248}, {147.08761194515785`, 42.40199028544781, 
      72.77180370524101}, {146.41226847997382`, 43.4016342470795, 
      74.0261715121375}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {148.30114981333645`, 45.359533983524145`, 
      71.67186159720268}, {148.68760393127354`, 45.061099231373916`, 
      70.95158819516605}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.30114981333645`, 45.359533983524145`, 
      71.67186159720268}, {147.08761194515785`, 42.40199028544781, 
      72.77180370524101}, {147.860520181032, 41.80512078114736, 
      71.33125690116775}, {148.68760393127354`, 45.061099231373916`, 
      70.95158819516605}, {148.30114981333645`, 45.359533983524145`, 
      71.67186159720268}}], 
     Polygon3DBox[{{147.08761194515785`, 42.40199028544781, 
      72.77180370524101}, {145.52020755810355`, 39.44273050748317, 
      73.68259397849248}, {146.67956991191483`, 38.54742625103249, 
      71.52177377238257}, {147.860520181032, 41.80512078114736, 
      71.33125690116775}, {147.08761194515785`, 42.40199028544781, 
      72.77180370524101}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {148.68760393127354`, 45.061099231373916`, 
      70.95158819516605}, {149.0965042250639, 44.984389543061596`, 
      70.18731073658174}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.68760393127354`, 45.061099231373916`, 
      70.95158819516605}, {147.860520181032, 41.80512078114736, 
      71.33125690116775}, {148.67832076861276`, 41.65170140452271, 
      69.80270198399913}, {149.0965042250639, 44.984389543061596`, 
      70.18731073658174}, {148.68760393127354`, 45.061099231373916`, 
      70.95158819516605}}], 
     Polygon3DBox[{{147.860520181032, 41.80512078114736, 71.33125690116775}, {
      146.67956991191483`, 38.54742625103249, 71.52177377238257}, {
      147.90627079328596`, 38.31729718609552, 69.22894139662962}, {
      148.67832076861276`, 41.65170140452271, 69.80270198399913}, {
      147.860520181032, 41.80512078114736, 71.33125690116775}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.0965042250639, 44.98438954306159, 
      70.18731073658174}, {149.49998481542545`, 45.134632557076905`, 
      69.43111346722404}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{149.0965042250639, 44.98438954306159, 
      70.18731073658174}, {148.67832076861276`, 41.65170140452271, 
      69.80270198399913}, {149.4852819493358, 41.95218743255334, 
      68.29030744528373}, {149.49998481542545`, 45.134632557076905`, 
      69.43111346722404}, {149.0965042250639, 44.98438954306159, 
      70.18731073658174}}], 
     Polygon3DBox[{{148.67832076861276`, 41.65170140452271, 
      69.80270198399913}, {147.90627079328596`, 38.317297186095516`, 
      69.22894139662962}, {149.11671256437052`, 38.76802622814146, 
      66.96034958855655}, {149.4852819493358, 41.95218743255334, 
      68.29030744528373}, {148.67832076861276`, 41.65170140452271, 
      69.80270198399913}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.49998481542545`, 45.134632557076905`, 
      69.43111346722404}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{149.49998481542545`, 45.134632557076905`, 
      69.43111346722404}, {149.4852819493358, 41.95218743255334, 
      68.29030744528373}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {149.49998481542545`, 45.134632557076905`, 
      69.43111346722404}}], 
     Polygon3DBox[{{149.4852819493358, 41.95218743255334, 
      68.29030744528373}, {149.11671256437052`, 38.76802622814146, 
      66.96034958855655}, {150.22840561881878`, 39.868896937819834`, 
      64.87059913085828}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {149.4852819493358, 41.95218743255334, 
      68.29030744528373}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {150.18294393134516`, 46.06025274621006, 
      68.14503129228888}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{149.8705491669082, 45.50158946030303, 
      68.73452998132461}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {150.85120018117524`, 43.80342781081965, 
      65.71814309541341}, {150.18294393134516`, 46.06025274621006, 
      68.14503129228888}, {149.8705491669082, 45.50158946030303, 
      68.73452998132461}}], 
     Polygon3DBox[{{150.22641065230133`, 42.68610123900559, 
      66.8971404734849}, {150.22840561881878`, 39.868896937819834`, 
      64.87059913085828}, {151.1655899121297, 41.54488679554093, 
      63.10210306375107}, {150.85120018117524`, 43.80342781081965, 
      65.71814309541341}, {150.22641065230133`, 42.68610123900559, 
      66.8971404734849}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.18294393134516`, 46.06025274621006, 
      68.14503129228888}, {150.41587992179672`, 46.77255043509817, 
      67.70279076158197}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.18294393134516`, 46.06025274621006, 
      68.14503129228888}, {150.85120018117524`, 43.80342781081965, 
      65.71814309541342}, {151.3170721620784, 45.22802318859587, 
      64.83366203399959}, {150.41587992179672`, 46.77255043509817, 
      67.70279076158197}, {150.18294393134516`, 46.06025274621006, 
      68.14503129228888}}], 
     Polygon3DBox[{{150.85120018117524`, 43.80342781081965, 
      65.71814309541342}, {151.1655899121297, 41.544886795540926`, 
      63.10210306375107}, {151.8643978834844, 43.68177986220525, 
      61.77538147163031}, {151.3170721620784, 45.22802318859587, 
      64.83366203399959}, {150.85120018117524`, 43.80342781081965, 
      65.71814309541342}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.41587992179672`, 46.77255043509817, 
      67.70279076158197}, {150.55348293545853`, 47.58994061659722, 
      67.43794635053452}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.41587992179672`, 46.77255043509817, 
      67.70279076158197}, {151.3170721620784, 45.22802318859587, 
      64.83366203399959}, {151.592278189402, 46.86280355159396, 
      64.30397321190468}, {150.55348293545853`, 47.58994061659722, 
      67.43794635053452}, {150.41587992179672`, 46.77255043509817, 
      67.70279076158197}}], 
     Polygon3DBox[{{151.3170721620784, 45.22802318859587, 
      64.83366203399959}, {151.8643978834844, 43.68177986220525, 
      61.77538147163031}, {152.27720692446982`, 46.13395040670239, 
      60.980848238487965`}, {151.592278189402, 46.86280355159396, 
      64.30397321190468}, {151.3170721620784, 45.22802318859587, 
      64.83366203399959}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.55348293545853`, 47.58994061659722, 
      67.43794635053452}, {150.58637555434927`, 48.45671950063918, 
      67.36854676808332}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.55348293545853`, 47.58994061659722, 
      67.43794635053452}, {151.592278189402, 46.86280355159396, 
      64.30397321190468}, {151.6580634271835, 48.59636131967789, 
      64.16517404700231}, {150.58637555434927`, 48.45671950063918, 
      67.36854676808332}, {150.55348293545853`, 47.58994061659722, 
      67.43794635053452}}], 
     Polygon3DBox[{{151.592278189402, 46.86280355159396, 64.30397321190468}, {
      152.27720692446982`, 46.13395040670239, 60.980848238487965`}, {
      152.37588478114202`, 48.734287058828286`, 60.7726494911344}, {
      151.6580634271835, 48.59636131967789, 64.16517404700231}, {
      151.592278189402, 46.86280355159396, 64.30397321190468}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.58637555434927`, 48.45671950063918, 
      67.36854676808332}, {150.51231620084917`, 49.31381753869644, 
      67.49932148108422}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.58637555434927`, 48.45671950063918, 
      67.36854676808332}, {151.6580634271835, 48.59636131967789, 
      64.16517404700231}, {151.50994472018326`, 50.31055739579241, 
      64.4267234730041}, {150.51231620084917`, 49.31381753869644, 
      67.49932148108422}, {150.58637555434927`, 48.45671950063918, 
      67.36854676808332}}], 
     Polygon3DBox[{{151.6580634271835, 48.59636131967789, 
      64.16517404700231}, {152.37588478114202`, 48.734287058828286`, 
      60.7726494911344}, {152.15370672064168`, 51.305581173000064`, 
      61.164973630137084`}, {151.50994472018326`, 50.31055739579241, 
      64.4267234730041}, {151.6580634271835, 48.59636131967789, 
      64.16517404700231}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.51231620084917`, 49.31381753869644, 
      67.49932148108422}, {150.33635189751035`, 50.102824915896875`, 
      67.82135840896161}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.51231620084917`, 49.31381753869644, 
      67.49932148108422}, {151.50994472018326`, 50.31055739579241, 
      64.4267234730041}, {151.15801611350562`, 51.88857215019327, 
      65.07079732875889}, {150.33635189751035`, 50.102824915896875`, 
      67.82135840896161}, {150.51231620084917`, 49.31381753869644, 
      67.49932148108422}}], 
     Polygon3DBox[{{151.50994472018326`, 50.31055739579241, 
      64.4267234730041}, {152.15370672064168`, 51.305581173000064`, 
      61.164973630137084`}, {151.62581381062526`, 53.67260330460136, 
      62.13108441376927}, {151.15801611350562`, 51.88857215019327, 
      65.07079732875889}, {151.50994472018326`, 50.31055739579241, 
      64.4267234730041}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.33635189751035`, 50.102824915896875`, 
      67.82135840896161}, {150.07047432081063`, 50.7699720833806, 
      68.31271126727187}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.33635189751035`, 50.102824915896875`, 
      67.82135840896161}, {151.15801611350562`, 51.888572150193276`, 
      65.07079732875889}, {150.6262609601062, 53.222866485160736`, 
      66.05350304537939}, {150.07047432081063`, 50.7699720833806, 
      68.31271126727187}, {150.33635189751035`, 50.102824915896875`, 
      67.82135840896161}}], 
     Polygon3DBox[{{151.15801611350562`, 51.888572150193276`, 
      65.07079732875889}, {151.62581381062526`, 53.67260330460137, 
      62.13108441376929}, {150.8281810805261, 55.67404480705256, 
      63.60514298870001}, {150.6262609601062, 53.222866485160736`, 
      66.05350304537939}, {151.15801611350562`, 51.888572150193276`, 
      65.07079732875889}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {150.07047432081063`, 50.7699720833806, 
      68.31271126727187}, {149.73280258821862`, 51.26979406419645, 
      68.93989517072009}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{150.07047432081063`, 50.7699720833806, 
      68.31271126727187}, {150.6262609601062, 53.222866485160736`, 
      66.05350304537939}, {149.95091749492218`, 54.22251044679242, 
      67.30787085227584}, {149.73280258821862`, 51.26979406419645, 
      68.93989517072009}, {150.07047432081063`, 50.7699720833806, 
      68.31271126727187}}], 
     Polygon3DBox[{{150.6262609601062, 53.222866485160736`, 
      66.05350304537939}, {150.8281810805261, 55.67404480705256, 
      63.60514298870001}, {149.81516588275008`, 57.17351074950008, 
      65.4866946990447}, {149.95091749492218`, 54.22251044679242, 
      67.30787085227584}, {150.6262609601062, 53.222866485160736`, 
      66.05350304537939}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.73280258821862`, 51.26979406419645, 
      68.93989517072009}, {149.34634847028153`, 51.568228816346675`, 
      69.66016857275673}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{149.73280258821862`, 51.26979406419645, 
      68.93989517072009}, {149.95091749492218`, 54.22251044679242, 
      67.30787085227584}, {149.178009259048, 54.81937995109288, 
      68.7484176563491}, {149.34634847028153`, 51.568228816346675`, 
      69.66016857275673}, {149.73280258821862`, 51.26979406419645, 
      68.93989517072009}}], 
     Polygon3DBox[{{149.95091749492218`, 54.22251044679242, 
      67.30787085227584}, {149.81516588275008`, 57.17351074950008, 
      65.4866946990447}, {148.6558035289388, 58.068815005950775`, 
      67.64751490515461}, {149.178009259048, 54.81937995109288, 
      68.7484176563491}, {149.95091749492218`, 54.22251044679242, 
      67.30787085227584}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.34634847028153`, 51.568228816346675`, 
      69.66016857275673}, {148.93744817649116`, 51.644938504659, 
      70.42444603134105}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{149.34634847028153`, 51.568228816346675`, 
      69.66016857275673}, {149.178009259048, 54.81937995109288, 
      68.74841765634912}, {148.36020867146726`, 54.972799327717524`, 
      70.27697257351775}, {148.93744817649116`, 51.644938504659, 
      70.42444603134105}, {149.34634847028153`, 51.568228816346675`, 
      69.66016857275673}}], 
     Polygon3DBox[{{149.178009259048, 54.81937995109288, 68.74841765634912}, {
      148.6558035289388, 58.06881500595077, 67.64751490515461}, {
      147.42910264756767`, 58.29894407088774, 69.94034728090756}, {
      148.36020867146726`, 54.972799327717524`, 70.27697257351775}, {
      149.178009259048, 54.81937995109288, 68.74841765634912}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {148.93744817649116`, 51.644938504659, 
      70.42444603134105}, {148.53396758612962`, 51.494695490643686`, 
      71.18064330069873}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.93744817649116`, 51.644938504659, 
      70.42444603134105}, {148.36020867146726`, 54.972799327717524`, 
      70.27697257351775}, {147.5532474907442, 54.672313299686905`, 
      71.78936711223312}, {148.53396758612962`, 51.494695490643686`, 
      71.18064330069873}, {148.93744817649116`, 51.644938504659, 
      70.42444603134105}}], 
     Polygon3DBox[{{148.36020867146726`, 54.972799327717524`, 
      70.27697257351775}, {147.42910264756767`, 58.29894407088774, 
      69.94034728090756}, {146.2186608764831, 57.8482150288418, 
      72.20893908898063}, {147.5532474907442, 54.672313299686905`, 
      71.78936711223312}, {148.36020867146726`, 54.972799327717524`, 
      70.27697257351775}}], 
     Polygon3DBox[{{149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {148.53396758612962`, 51.494695490643686`, 
      71.18064330069873}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}, {149.18079946016908`, 48.31545848670344, 
      70.3934466291662}}], 
     Polygon3DBox[{{148.53396758612962`, 51.494695490643686`, 
      71.18064330069873}, {147.5532474907442, 54.672313299686905`, 
      71.78936711223312}, {146.8121187877787, 53.938399493234655`, 
      73.18253408403197}, {148.1634032346469, 51.12773858741756, 
      71.87722678659816}, {148.53396758612962`, 51.494695490643686`, 
      71.18064330069873}}], 
     Polygon3DBox[{{147.5532474907442, 54.672313299686905`, 
      71.78936711223312}, {146.2186608764831, 57.8482150288418, 
      72.20893908898063}, {145.10696782203485`, 56.74734431916343, 
      74.2986895466789}, {146.8121187877787, 53.938399493234655`, 
      73.18253408403197}, {147.5532474907442, 54.672313299686905`, 
      71.78936711223312}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1kv0v1HEAx08uuZK41urKWQqJtPrBwzTznuPOPZ/7Zi2qc5+j9eCpLReN
dhVbmspjEblWi04eFpeEU3mI1jFZowdn7rjUNKctNtLq/oF+eP36+uX18iLp
8uQ1NBqNZcfRTm3AIC9lNwHnw7WVxwoRfHU9HexSOe5+M5nS1hL0+1V57yoQ
gndpuk9Ep9DuGHeIaVOCtXw4rfqCAOOvi98EHaUw2+KkmTArYb1p0XeG86E2
5JzaVEiB/u6Wl35SCe3o+qnpBR4UF6kCUklB2/MieMSqxNOM+me9dVzoTTUt
XA2FYmNym35JCZliaufbrGhMTAgXzkVSOO2SPRfmRsBIa5ypzIrCBlve0vYZ
OVZ85NcfHSDIFDQmPWnn4E5eXU3zWTkeJJ5kvIwjcCoLc2NyOTAyRw1J5lio
pVUBtFwCWUvbwXt+HKiGR5ZrJbHwnFrd0fWQIDxgqUlCOFic8TyhNshQZhax
pAMEtt4hx1Cb3W84Y30eIsN975CrIitBanrnp+7+KMyPlLa535DiCuOVj+43
AUvrUBQ1Hg0jP6Q1YloCKt7VPOmsgphxnu/jzkORXJlemCtBcGR+xDoXFUr6
hZ5/jseg+2Nr4FciQZUgwX+OroJmT0MMu44PJpP9hV0ugQ7N9U6/CCyhatPW
MQH6NvcqBtykeE+rztR8Jtjrr2PxxoRIssmozCEpMNsztqWDoEusqwy6be9r
yXfwVchQ0dB0ZLWMYB/dY37YWYyfVIIl47sMfYbsoM5Uu9+qNXJ8xYivOFa7
PycWHoHbov9yCRZTEqUlP0QYvOwaqdgox//++Qc4IA8r
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1kv0v1HEAxy/H2bLy0CiiTVKO87CxUTPe3J2Hc7iHL1vyEJ8vU+NotiSh
s0w2ueGktrPucqnNnWnW7lI3UqZZ/JDpwXPMdBu6StlFdP9AP7x+ff3yevkW
lEkK7RgMhqcNpo29tZW6QzKCAcf8GbciISyBPi7KLSm+a63uLiKCiOwK+2ZF
ClwZMV6vCym4DJdXDJwlaOIEp7FqBdBw14/rBinElp001nAIqJFBpT8vGYj9
aGrYoHChsfd8BpvAmbUylLqdCPaufuHTHwrbtdOyK2EEvtr6juC+BNTmWR1N
XyiYb8s3M+IIhtuMjPA6Pnpye/hfuym8eqv0m8siqNI0vGHW8fChfDGllU9B
ulw6klBNsFrTwHMf4iKfZbflPyHFjnd93EU1wdUxN0u1kIu7Ss6R2XgpJp0M
RDNm86+2uDqGchEiCkr36ZegUnWMytkk0OdOthiLuRgqqhpYPyHBelex2OJK
I2/70YrmFxcFsaPnQu6LYV2SvNgIpTH/sP15wDse4i5rw/bPiDEzOpsjSKDR
9P5zWd88H09P/w7xmBKh1yPQ86aUhilayFYcTYRbkNOdaLUIij115ZNMGkyr
314RnQS2LKLE3CbCT1ZlQXM6DUvWrYBGfTKmDprjHXQiHPg7vvw4hoakJM0k
nxNA5xTtMGMWgW0y6H39adzLkVv751Jww2q3H5YkRmf3wmGDPQ2OXF71QGXr
S5YyVcNifCseV3QtEqgityainFPxcvpZ5JpAAu/rHaXZRgKJ5zWdnpOKU16G
He28BBXm8Bp1K0GhOip094cQ7cxLndMyKf73zz+www6l
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{145.10696782203485`, 56.747344319163425`, 
       74.2986895466789}, {155.43914789689, 56.79745034921452, 
       79.82153704498683}, {154.50196360357907`, 55.12146049149342, 
       81.59003311209405}, {144.16978352872394`, 55.07135446144233, 
       76.06718561378612}, {145.10696782203485`, 56.747344319163425`, 
       74.2986895466789}}], 
      Line3DBox[{{144.16978352872394`, 55.07135446144233, 
       76.06718561378612}, {154.50196360357907`, 55.12146049149342, 
       81.59003311209405}, {153.8031556322244, 52.9845674248291, 
       82.9167547042148}, {143.47097555736923`, 52.934461394778005`, 
       77.39390720590687}, {144.16978352872394`, 55.07135446144233, 
       76.06718561378612}}], 
      Line3DBox[{{143.47097555736923`, 52.934461394778005`, 
       77.39390720590687}, {153.8031556322244, 52.9845674248291, 
       82.9167547042148}, {153.39034659123897`, 50.53239688033196, 
       83.71128793735716}, {143.0581665163838, 50.48229085028087, 
       78.18844043904923}, {143.47097555736923`, 52.934461394778005`, 
       77.39390720590687}}], 
      Line3DBox[{{143.0581665163838, 50.48229085028087, 78.18844043904923}, {
       153.39034659123897`, 50.53239688033196, 83.71128793735716}, {
       153.29166873456674`, 47.93206022820606, 83.91948668471072}, {
       142.9594886597116, 47.881954198154965`, 78.3966391864028}, {
       143.0581665163838, 50.48229085028087, 78.18844043904923}}], 
      Line3DBox[{{142.9594886597116, 47.881954198154965`, 78.3966391864028}, {
       153.29166873456674`, 47.93206022820606, 83.91948668471072}, {
       153.5138467950671, 45.360766114034284`, 83.52716254570802}, {
       143.18166672021195`, 45.31066008398319, 78.0043150474001}, {
       142.9594886597116, 47.881954198154965`, 78.3966391864028}}], 
      Line3DBox[{{143.18166672021195`, 45.31066008398319, 78.0043150474001}, {
       153.5138467950671, 45.360766114034284`, 83.52716254570802}, {
       154.04173970508353`, 42.99374398243299, 82.56105176207583}, {
       143.70955963022837`, 42.94363795238189, 77.03820426376791}, {
       143.18166672021195`, 45.31066008398319, 78.0043150474001}}], 
      Line3DBox[{{143.70955963022837`, 42.94363795238189, 
       77.03820426376791}, {154.04173970508353`, 42.99374398243299, 
       82.56105176207583}, {154.8393724351827, 40.992302479981795`, 
       81.08699318714511}, {144.50719236032754`, 40.9421964499307, 
       75.56414568883717}, {143.70955963022837`, 42.94363795238189, 
       77.03820426376791}}], 
      Line3DBox[{{144.50719236032754`, 40.9421964499307, 75.56414568883717}, {
       154.8393724351827, 40.992302479981795`, 81.08699318714511}, {
       155.85238763295874`, 39.49283653753427, 79.2054414768004}, {
       145.52020755810355`, 39.44273050748317, 73.68259397849248}, {
       144.50719236032754`, 40.9421964499307, 75.56414568883717}}], 
      Line3DBox[{{145.52020755810355`, 39.44273050748317, 
       73.68259397849248}, {155.85238763295874`, 39.49283653753427, 
       79.2054414768004}, {157.01174998677, 38.59753228108359, 
       77.0446212706905}, {146.67956991191483`, 38.54742625103249, 
       71.52177377238257}, {145.52020755810355`, 39.44273050748317, 
       73.68259397849248}}], 
      Line3DBox[{{146.67956991191483`, 38.54742625103249, 
       71.52177377238257}, {157.01174998677, 38.59753228108359, 
       77.0446212706905}, {158.23845086814111`, 38.36740321614662, 
       74.75178889493755}, {147.90627079328596`, 38.31729718609552, 
       69.22894139662962}, {146.67956991191483`, 38.54742625103249, 
       71.52177377238257}}], 
      Line3DBox[{{147.90627079328596`, 38.317297186095516`, 
       69.22894139662962}, {158.23845086814111`, 38.36740321614661, 
       74.75178889493756}, {159.4488926392257, 38.818132258192556`, 
       72.48319708686448}, {149.11671256437052`, 38.76802622814146, 
       66.96034958855655}, {147.90627079328596`, 38.317297186095516`, 
       69.22894139662962}}], 
      Line3DBox[{{149.11671256437052`, 38.76802622814146, 
       66.96034958855655}, {159.4488926392257, 38.818132258192556`, 
       72.48319708686448}, {160.56058569367394`, 39.91900296787093, 
       70.39344662916622}, {150.22840561881878`, 39.868896937819834`, 
       64.87059913085828}, {149.11671256437052`, 38.76802622814146, 
       66.96034958855655}}], 
      Line3DBox[{{150.22840561881878`, 39.868896937819834`, 
       64.87059913085828}, {160.56058569367394`, 39.91900296787093, 
       70.39344662916622}, {161.49776998698488`, 41.59499282559204, 
       68.624950562059}, {151.1655899121297, 41.54488679554093, 
       63.10210306375107}, {150.22840561881878`, 39.868896937819834`, 
       64.87059913085828}}], 
      Line3DBox[{{151.1655899121297, 41.544886795540926`, 
       63.10210306375107}, {161.49776998698488`, 41.59499282559202, 
       68.624950562059}, {162.19657795833956`, 43.73188589225635, 
       67.29822896993825}, {151.8643978834844, 43.68177986220525, 
       61.77538147163031}, {151.1655899121297, 41.544886795540926`, 
       63.10210306375107}}], 
      Line3DBox[{{151.8643978834844, 43.68177986220525, 61.77538147163031}, {
       162.19657795833956`, 43.73188589225635, 67.29822896993825}, {
       162.60938699932498`, 46.18405643675349, 66.50369573679589}, {
       152.27720692446982`, 46.13395040670239, 60.980848238487965`}, {
       151.8643978834844, 43.68177986220525, 61.77538147163031}}], 
      Line3DBox[{{152.27720692446982`, 46.13395040670239, 
       60.980848238487965`}, {162.60938699932498`, 46.18405643675349, 
       66.50369573679589}, {162.7080648559972, 48.78439308887939, 
       66.29549698944233}, {152.37588478114202`, 48.734287058828286`, 
       60.7726494911344}, {152.27720692446982`, 46.13395040670239, 
       60.980848238487965`}}], 
      Line3DBox[{{152.37588478114202`, 48.734287058828286`, 
       60.7726494911344}, {162.7080648559972, 48.78439308887939, 
       66.29549698944233}, {162.48588679549684`, 51.35568720305116, 
       66.68782112844501}, {152.15370672064168`, 51.305581173000064`, 
       61.164973630137084`}, {152.37588478114202`, 48.734287058828286`, 
       60.7726494911344}}], 
      Line3DBox[{{152.15370672064168`, 51.305581173000064`, 
       61.164973630137084`}, {162.48588679549684`, 51.35568720305116, 
       66.68782112844501}, {161.95799388548042`, 53.72270933465246, 
       67.65393191207721}, {151.62581381062526`, 53.67260330460136, 
       62.13108441376927}, {152.15370672064168`, 51.305581173000064`, 
       61.164973630137084`}}], 
      Line3DBox[{{151.62581381062526`, 53.67260330460137, 
       62.13108441376929}, {161.95799388548042`, 53.722709334652464`, 
       67.65393191207721}, {161.16036115538125`, 55.72415083710365, 
       69.12799048700793}, {150.8281810805261, 55.67404480705256, 
       63.60514298870001}, {151.62581381062526`, 53.67260330460137, 
       62.13108441376929}}], 
      Line3DBox[{{150.8281810805261, 55.67404480705256, 63.60514298870001}, {
       161.16036115538125`, 55.72415083710365, 69.12799048700793}, {
       160.1473459576052, 57.22361677955118, 71.00954219735263}, {
       149.81516588275008`, 57.17351074950008, 65.4866946990447}, {
       150.8281810805261, 55.67404480705256, 63.60514298870001}}], 
      Line3DBox[{{149.81516588275008`, 57.17351074950008, 65.4866946990447}, {
       160.1473459576052, 57.22361677955118, 71.00954219735263}, {
       158.98798360379396`, 58.118921036001865`, 73.17036240346253}, {
       148.6558035289388, 58.068815005950775`, 67.64751490515461}, {
       149.81516588275008`, 57.17351074950008, 65.4866946990447}}], 
      Line3DBox[{{148.6558035289388, 58.06881500595077, 67.64751490515461}, {
       158.98798360379394`, 58.118921036001865`, 73.17036240346255}, {
       157.76128272242283`, 58.34905010093884, 75.46319477921548}, {
       147.42910264756767`, 58.29894407088774, 69.94034728090756}, {
       148.6558035289388, 58.06881500595077, 67.64751490515461}}], 
      Line3DBox[{{147.42910264756767`, 58.29894407088774, 
       69.94034728090756}, {157.76128272242283`, 58.34905010093884, 
       75.46319477921548}, {156.55084095133824`, 57.8983210588929, 
       77.73178658728857}, {146.2186608764831, 57.8482150288418, 
       72.20893908898063}, {147.42910264756767`, 58.29894407088774, 
       69.94034728090756}}], 
      Line3DBox[{{146.2186608764831, 57.8482150288418, 72.20893908898063}, {
       156.55084095133824`, 57.8983210588929, 77.73178658728857}, {
       155.43914789689, 56.79745034921453, 79.82153704498681}, {
       145.10696782203485`, 56.74734431916343, 74.2986895466789}, {
       146.2186608764831, 57.8482150288418, 72.20893908898063}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{72.4673247109199, 115.90002073625398`, 
      87.61848840620274}, {70.3632208006762, 117.10934772397077`, 
      88.13396761187748}, {66.95880018420861, 114.26019004688791`, 
      88.45934657805388}, {71.71919419308665, 111.5241688270829, 
      87.29310944002634}, {72.4673247109199, 115.90002073625398`, 
      87.61848840620274}}], 
     Polygon3DBox[{{71.71919419308665, 111.5241688270829, 
      87.29310944002634}, {66.95880018420861, 114.26019004688791`, 
      88.45934657805388}, {64.11957601809894, 111.08618751901044`, 
      88.64625946569575}, {70.4058672248955, 107.47316176870646`, 
      87.10619655238447}, {71.71919419308665, 111.5241688270829, 
      87.29310944002634}}], 
     Polygon3DBox[{{70.4058672248955, 107.47316176870646`, 
      87.10619655238447}, {64.11957601809894, 111.08618751901044`, 
      88.64625946569575}, {61.79412077952581, 107.61689794447358`, 
      88.70730537624699}, {68.57877132916778, 103.71744175698937`, 
      87.04515064183323}, {70.4058672248955, 107.47316176870646`, 
      87.10619655238447}}], 
     Polygon3DBox[{{68.57877132916778, 103.71744175698937`, 
      87.04515064183323}, {61.79412077952581, 107.61689794447358`, 
      88.70730537624699}, {59.967024883798096`, 103.86117793275649`, 
      88.64625946569575}, {66.25331609059467, 100.24815218245251`, 
      87.10619655238447}, {68.57877132916778, 103.71744175698937`, 
      87.04515064183323}}], 
     Polygon3DBox[{{66.25331609059467, 100.24815218245251`, 
      87.10619655238447}, {59.967024883798096`, 103.86117793275649`, 
      88.64625946569575}, {58.65369791560694, 99.81017087438005, 
      88.45934657805388}, {63.41409192448498, 97.07414965457504, 
      87.29310944002634}, {66.25331609059467, 100.24815218245251`, 
      87.10619655238447}}], 
     Polygon3DBox[{{63.41409192448498, 97.07414965457504, 
      87.29310944002634}, {58.65369791560694, 99.81017087438005, 
      88.45934657805388}, {57.90556739777369, 95.43431896520897, 
      88.13396761187748}, {60.009671308017396`, 94.22499197749218, 
      87.61848840620274}, {63.41409192448498, 97.07414965457504, 
      87.29310944002634}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7f8HzpC9kgh42/J32Y+TPGQSUtNWDq81CHDxtF
3NnfBTpcr8z43f0w2uHHYQm/Q5dCHYpi2nb9nBno8GWyj4fHvSgH2Tvz35w+
FupwbcWzaVyqgQ7lh69MePU20sGnpWX/40OhDs80N4aYTQhwUGLZuPMhfyRc
/YaZV74xbPV3MI0yvLfPJQJufvml8y9sGP0c7HwOuKT1hcPd0/Lw1cKXn30c
dj47+vD07XAH7feP30ziCHNIqp8QvybY12FKxodrNz9HOIRPNHifKhvmEK+1
tuL4b1+Hcj+eLtnvkQ5GlSsDYjTDHKZNfLN/6VM/hy9yLY7Vz6McmC8eqXXR
DXPYc1xbaTl7gIPHveUSLUej4epPLin6HbM3wMGsQ/3LsgkxDhFQ89M4Spns
pwc66E2b0fvfLRbuHlzhCQA607Lq
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{63.986794780097995`, 106.3566655808306, 
        75.3912653171327}, {61.88269086985429, 107.56599256854737`, 
        75.90674452280744}, {61.30511356366067, 107.89795327660566`, 
        80.30786451867385}, {66.0655075725387, 105.16193205680065`, 
        79.14162738064631}, {63.986794780097995`, 106.3566655808306, 
        75.3912653171327}}], 
       Polygon3DBox[{{66.0655075725387, 105.16193205680065`, 
        79.14162738064631}, {61.30511356366067, 107.89795327660566`, 
        80.30786451867385}, {61.29273270782496, 107.9050691338693, 
        84.57051843600573}, {67.57902391462153, 104.29204338356533`, 
        83.03045552269447}, {66.0655075725387, 105.16193205680065`, 
        79.14162738064631}}], 
       Polygon3DBox[{{67.57902391462153, 104.29204338356533`, 
        83.03045552269447}, {61.29273270782496, 107.9050691338693, 
        84.57051843600573}, {61.79412077952581, 107.61689794447358`, 
        88.70730537624699}, {68.57877132916778, 103.71744175698937`, 
        87.04515064183323}, {67.57902391462153, 104.29204338356533`, 
        83.03045552269447}}], 
       Polygon3DBox[{{68.57877132916778, 103.71744175698937`, 
        87.04515064183323}, {61.79412077952581, 107.61689794447358`, 
        88.70730537624699}, {62.79386819407207, 107.04229631789762`, 
        92.72200049538576}, {69.08015940086864, 103.42927056759365`, 
        91.18193758207448}, {68.57877132916778, 103.71744175698937`, 
        87.04515064183323}}], 
       Polygon3DBox[{{69.08015940086864, 103.42927056759365`, 
        91.18193758207448}, {62.79386819407207, 107.04229631789762`, 
        92.72200049538576}, {64.30738453615488, 106.1724076446623, 
        96.61082863743391}, {69.06777854503292, 103.43638642485729`, 
        95.44459149940637}, {69.08015940086864, 103.42927056759365`, 
        91.18193758207448}}], 
       Polygon3DBox[{{69.06777854503292, 103.43638642485729`, 
        95.44459149940637}, {64.30738453615488, 106.1724076446623, 
        96.61082863743391}, {66.38609732859561, 104.97767412063237`, 
        100.36119070094752`}, {68.4902012388393, 103.76834713291558`, 
        99.84571149527278}, {69.06777854503292, 103.43638642485729`, 
        95.44459149940637}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDYxnObl/8/fYV3g/dmXp0U5WHiur+W6GeSQk7PG
zbAlwKGBw00i1ivKgZXNK0fgZLDDBsugXXxPAxw8ondf2yAU5aBSu+P3p4Mh
DtdWPJvGpRroUH74yoRXbyMdfFpa9j8+FOqwwudpiKJroMM5GyftytuRDmLW
7XeXnA5ziJ50qTrMJdCh93TwwbdA8VeNz/VL7oQ7NAaylMbLBzo4fSueqfMx
0kGgWVpZ4VuEA8fNiRe3zghw2Duh0mySXZSDOM+s/bLikQ6mrQYGa4QDHF7f
FNrF0R3l4OX//4K4eoTD43zRyrmp/g7K7XN/bzkU5aBzY4KjqV64w7SJb/Yv
fern8EWuxbH6eZQD88UjtS66YQ6fPd87Vyz1c5i7VGz5m59RDpZSh+KbVUId
uvaJfONd7udwX4xVsAIonnY5kXeLcIiDvcNG5j8f/By03jyxsHwS5WB/SVeK
41eQA67wBAA21KAZ
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{60.00967130801739, 94.22499197749218, 87.61848840620274}, {
       57.905567397773694`, 95.43431896520896, 88.13396761187748}, {
       58.70059320049421, 95.46864525821141, 91.29860581604608}, {
       60.804697110737905`, 94.25931827049463, 90.78312661037134}, {
       60.00967130801739, 94.22499197749218, 87.61848840620274}}], 
      Line3DBox[{{60.804697110737905`, 94.25931827049463, 
       90.78312661037134}, {58.70059320049421, 95.46864525821141, 
       91.29860581604608}, {59.86592355468267, 96.2391909661881, 
       94.2475791564125}, {61.97002746492636, 95.02986397847133, 
       93.73209995073776}, {60.804697110737905`, 94.25931827049463, 
       90.78312661037134}}], 
      Line3DBox[{{61.97002746492636, 95.02986397847133, 93.73209995073776}, {
       59.86592355468267, 96.2391909661881, 94.2475791564125}, {
       61.32214312250058, 97.69344467252743, 96.77991997323963}, {
       63.42624703274427, 96.48411768481066, 96.26444076756489}, {
       61.97002746492636, 95.02986397847133, 93.73209995073776}}], 
      Line3DBox[{{63.42624703274427, 96.48411768481066, 96.26444076756489}, {
       61.32214312250058, 97.69344467252743, 96.77991997323963}, {
       62.97001294691776, 99.73230139041026, 98.72305342475177}, {
       65.07411685716147, 98.52297440269348, 98.20757421907703}, {
       63.42624703274427, 96.48411768481066, 96.26444076756489}}], 
      Line3DBox[{{65.07411685716147, 98.52297440269348, 98.20757421907703}, {
       62.97001294691776, 99.73230139041026, 98.72305342475177}, {
       64.69723342263387, 102.21681640388289`, 99.94455817740824}, {
       66.80133733287757, 101.00748941616611`, 99.42907897173349}, {
       65.07411685716147, 98.52297440269348, 98.20757421907703}}], 
      Line3DBox[{{66.80133733287757, 101.00748941616611`, 
       99.42907897173349}, {64.69723342263387, 102.21681640388289`, 
       99.94455817740824}, {66.38609732859561, 104.97767412063236`, 
       100.36119070094752`}, {68.4902012388393, 103.76834713291558`, 
       99.84571149527278}, {66.80133733287757, 101.00748941616611`, 
       99.42907897173349}}], 
      Line3DBox[{{68.4902012388393, 103.76834713291558`, 99.84571149527278}, {
       66.38609732859561, 104.97767412063236`, 100.36119070094752`}, {
       67.92151138059126, 107.82672664979529`, 99.94455817740824}, {
       70.02561529083496, 106.61739966207851`, 99.42907897173349}, {
       68.4902012388393, 103.76834713291558`, 99.84571149527278}}], 
      Line3DBox[{{70.02561529083496, 106.61739966207851`, 
       99.42907897173349}, {67.92151138059126, 107.82672664979529`, 
       99.94455817740824}, {69.19883964836902, 110.56981576979116`, 
       98.72305342475177}, {71.30294355861272, 109.36048878207438`, 
       98.20757421907703}, {70.02561529083496, 106.61739966207851`, 
       99.42907897173349}}], 
      Line3DBox[{{71.30294355861272, 109.36048878207438`, 
       98.20757421907703}, {69.19883964836902, 110.56981576979116`, 
       98.72305342475177}, {70.1310343213646, 113.02000449026134`, 
       96.77991997323963}, {72.2351382316083, 111.81067750254456`, 
       96.26444076756489}, {71.30294355861272, 109.36048878207438`, 
       98.20757421907703}}], 
      Line3DBox[{{72.2351382316083, 111.81067750254456`, 96.26444076756489}, {
       70.1310343213646, 113.02000449026134`, 96.77991997323963}, {
       70.65456787313789, 115.01031649903412`, 94.2475791564125}, {
       72.75867178338159, 113.80098951131734`, 93.73209995073776}, {
       72.2351382316083, 111.81067750254456`, 96.26444076756489}}], 
      Line3DBox[{{72.75867178338159, 113.80098951131734`, 
       93.73209995073776}, {70.65456787313789, 115.01031649903412`, 
       94.2475791564125}, {70.73376235731564, 116.40511532185772`, 
       91.29860581604609}, {72.83786626755933, 115.19578833414094`, 
       90.78312661037135}, {72.75867178338159, 113.80098951131734`, 
       93.73209995073776}}], 
      Line3DBox[{{72.83786626755933, 115.19578833414094`, 
       90.78312661037135}, {70.73376235731564, 116.40511532185772`, 
       91.29860581604609}, {70.3632208006762, 117.10934772397077`, 
       88.13396761187748}, {72.4673247109199, 115.90002073625398`, 
       87.61848840620274}, {72.83786626755933, 115.19578833414094`, 
       90.78312661037135}}], 
      Line3DBox[{{72.4673247109199, 115.90002073625398`, 87.61848840620274}, {
       70.3632208006762, 117.10934772397077`, 88.13396761187748}, {
       69.56819499795569, 117.07502143096832`, 84.96932940770888}, {
       71.67229890819938, 115.86569444325157`, 84.45385020203415}, {
       72.4673247109199, 115.90002073625398`, 87.61848840620274}}], 
      Line3DBox[{{71.67229890819938, 115.86569444325157`, 
       84.45385020203415}, {69.56819499795569, 117.07502143096832`, 
       84.96932940770888}, {68.40286464376723, 116.30447572299163`, 
       82.02035606734246}, {70.50696855401092, 115.09514873527486`, 
       81.50487686166773}, {71.67229890819938, 115.86569444325157`, 
       84.45385020203415}}], 
      Line3DBox[{{70.50696855401092, 115.09514873527486`, 
       81.50487686166773}, {68.40286464376723, 116.30447572299163`, 
       82.02035606734246}, {66.94664507594933, 114.8502220166523, 
       79.48801525051533}, {69.05074898619303, 113.64089502893552`, 
       78.9725360448406}, {70.50696855401092, 115.09514873527486`, 
       81.50487686166773}}], 
      Line3DBox[{{69.05074898619303, 113.64089502893552`, 78.9725360448406}, {
       66.94664507594933, 114.8502220166523, 79.48801525051533}, {
       65.29877525153213, 112.81136529876947`, 77.54488179900319}, {
       67.40287916177583, 111.6020383110527, 77.02940259332846}, {
       69.05074898619303, 113.64089502893552`, 78.9725360448406}}], 
      Line3DBox[{{67.40287916177583, 111.6020383110527, 77.02940259332846}, {
       65.29877525153213, 112.81136529876947`, 77.54488179900319}, {
       63.57155477581604, 110.32685028529686`, 76.32337704634674}, {
       65.67565868605973, 109.11752329758008`, 75.807897840672}, {
       67.40287916177583, 111.6020383110527, 77.02940259332846}}], 
      Line3DBox[{{65.67565868605973, 109.11752329758008`, 75.807897840672}, {
       63.57155477581604, 110.32685028529686`, 76.32337704634674}, {
       61.88269086985429, 107.56599256854739`, 75.90674452280744}, {
       63.986794780097995`, 106.35666558083061`, 75.3912653171327}, {
       65.67565868605973, 109.11752329758008`, 75.807897840672}}], 
      Line3DBox[{{63.986794780097995`, 106.3566655808306, 75.3912653171327}, {
       61.88269086985429, 107.56599256854737`, 75.90674452280744}, {
       60.34727681785864, 104.71694003938444`, 76.32337704634672}, {
       62.451380728102336`, 103.50761305166766`, 75.80789784067198}, {
       63.986794780097995`, 106.3566655808306, 75.3912653171327}}], 
      Line3DBox[{{62.451380728102336`, 103.50761305166766`, 
       75.80789784067198}, {60.34727681785864, 104.71694003938444`, 
       76.32337704634672}, {59.069948550080866`, 101.97385091938858`, 
       77.54488179900318}, {61.174052460324575`, 100.76452393167179`, 
       77.02940259332844}, {62.451380728102336`, 103.50761305166766`, 
       75.80789784067198}}], 
      Line3DBox[{{61.174052460324575`, 100.76452393167179`, 
       77.02940259332844}, {59.069948550080866`, 101.97385091938858`, 
       77.54488179900318}, {58.1377538770853, 99.52366219891839, 
       79.48801525051532}, {60.24185778732899, 98.31433521120161, 
       78.97253604484058}, {61.174052460324575`, 100.76452393167179`, 
       77.02940259332844}}], 
      Line3DBox[{{60.241857787328996`, 98.31433521120161, 78.9725360448406}, {
       58.1377538770853, 99.52366219891839, 79.48801525051533}, {
       57.614220325312004`, 97.53335019014561, 82.02035606734246}, {
       59.7183242355557, 96.32402320242883, 81.50487686166773}, {
       60.241857787328996`, 98.31433521120161, 78.9725360448406}}], 
      Line3DBox[{{59.7183242355557, 96.32402320242883, 81.50487686166773}, {
       57.614220325312004`, 97.53335019014561, 82.02035606734246}, {
       57.53502584113426, 96.13855136732201, 84.96932940770887}, {
       59.63912975137795, 94.92922437960523, 84.45385020203413}, {
       59.7183242355557, 96.32402320242883, 81.50487686166773}}], 
      Line3DBox[{{59.63912975137795, 94.92922437960523, 84.45385020203413}, {
       57.53502584113426, 96.13855136732201, 84.96932940770887}, {
       57.905567397773694`, 95.43431896520896, 88.13396761187747}, {
       60.00967130801739, 94.22499197749218, 87.61848840620273}, {
       59.63912975137795, 94.92922437960523, 84.45385020203413}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{32.146639286076145`, 135.88012407359395`, 
      97.4211426727353}, {30.617127880829546`, 144.69404060317532`, 
      92.95175006626258}, {27.33494102767097, 144.36913282326734`, 
      93.4342389330972}, {28.864452432917567`, 135.55521629368596`, 
      97.90363153956993}, {32.146639286076145`, 135.88012407359395`, 
      97.4211426727353}}], 
     Polygon3DBox[{{28.864452432917567`, 135.55521629368596`, 
      97.90363153956993}, {27.33494102767097, 144.36913282326734`, 
      93.4342389330972}, {24.052754174512387`, 144.04422504335938`, 
      93.91672779993183}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {28.864452432917567`, 135.55521629368596`, 
      97.90363153956993}}], 
     Polygon3DBox[{{25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {24.052754174512387`, 144.04422504335938`, 
      93.91672779993183}, {20.770567321353806`, 143.71931726345142`, 
      94.39921666676646}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {20.770567321353806`, 143.71931726345142`, 
      94.39921666676646}, {17.488380468195228`, 143.39440948354346`, 
      94.88170553360109}, {19.017891873441826`, 134.58049295396208`, 
      99.35109814007382}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.017891873441826`, 134.58049295396208`, 
      99.35109814007382}, {17.488380468195228`, 143.39440948354346`, 
      94.88170553360109}, {14.206193615036646`, 143.0695017036355, 
      95.36419440043572}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {19.017891873441826`, 134.58049295396208`, 
      99.35109814007382}}], 
     Polygon3DBox[{{15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {14.206193615036646`, 143.0695017036355, 
      95.36419440043572}, {10.924006761878067`, 142.7445939237275, 
      95.84668326727035}, {12.453518167124667`, 133.93067739414613`, 
      100.31607587374307`}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7PUCt8VMjBwUXg20/NPwkOHtNSGb5ERTjIhRgc
9Llr43D209eQIx8THCa2JkperYxw2LssLZp/qqVD+NWv6+OeJzjcKok12jYj
wiHm55yvF33MHB5u/8r1806Cg3JKpPf07REOf7wv909hMXbInvU1dfKlBIec
4NCUimsRDma2wiHrKvQdvtZ8PaB7IsFhq1NgbeTXCIeSR/Udxi80HOriv0qf
2Jvg8M/Qd5qVSKSDliR/lvhNVYcdzxZtu3w90eHEfmZ+g2/hDq+LF5lOytRx
0GdZHG35KNGh/gL7N7/r4Q5hz2c1sNUaOixVXMww/02ig9lD7ru5O8Idtk9J
eeZ81MRB2n7xUpbviQ5vP/If6ZkZ7iDupOfTyGvhMDFmsVcWY5LDEiaR1aur
wh0q3n/fuC/U2oG9avH789xJDtHCEpNORYc73JxzUPzPXDuHuumLp5iKJTkI
qchUvrQJd8AVngDJs6Nh
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{21.459935875772427`, 130.28319457008095`, 
        90.0408479392637}, {19.93042447052583, 139.09711109966233`, 
        85.57145533279098}, {20.21047208746849, 140.63784648759201`, 
        88.51404244411613}, {21.739983492715087`, 131.82392995801064`, 
        92.98343505058885}, {21.459935875772427`, 130.28319457008095`, 
        90.0408479392637}}], 
       Polygon3DBox[{{21.739983492715087`, 131.82392995801064`, 
        92.98343505058885}, {20.21047208746849, 140.63784648759201`, 
        88.51404244411613}, {20.490519704411145`, 142.17858187552173`, 
        91.4566295554413}, {22.020031109657744`, 133.36466534594035`, 
        95.92602216191402}, {21.739983492715087`, 131.82392995801064`, 
        92.98343505058885}}], 
       Polygon3DBox[{{22.020031109657744`, 133.36466534594035`, 
        95.92602216191402}, {20.490519704411145`, 142.17858187552173`, 
        91.4566295554413}, {20.770567321353806`, 143.71931726345142`, 
        94.39921666676646}, {22.300078726600404`, 134.90540073387004`, 
        98.86860927323919}, {22.020031109657744`, 133.36466534594035`, 
        95.92602216191402}}], 
       Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
        98.86860927323919}, {20.770567321353806`, 143.71931726345142`, 
        94.39921666676646}, {21.050614938296466`, 145.2600526513811, 
        97.34180377809163}, {22.580126343543064`, 136.44613612179973`, 
        101.81119638456435`}, {22.300078726600404`, 134.90540073387004`, 
        98.86860927323919}}], 
       Polygon3DBox[{{22.580126343543064`, 136.44613612179973`, 
        101.81119638456435`}, {21.050614938296466`, 145.2600526513811, 
        97.34180377809163}, {21.330662555239122`, 146.80078803931082`, 
        100.28439088941678`}, {22.86017396048572, 137.98687150972944`, 
        104.75378349588951`}, {22.580126343543064`, 136.44613612179973`, 
        101.81119638456435`}}], 
       Polygon3DBox[{{22.86017396048572, 137.98687150972944`, 
        104.75378349588951`}, {21.330662555239122`, 146.80078803931082`, 
        100.28439088941678`}, {21.610710172181783`, 148.3415234272405, 
        103.22697800074195`}, {23.14022157742838, 139.52760689765913`, 
        107.69637060721467`}, {22.86017396048572, 137.98687150972944`, 
        104.75378349588951`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbf3BG9r9TU4aEM/zt+zwSHE+fXOMxtCnPoPPWk
L3+vqYPZ7+hFsVUJDtaME2d+sAt3+PTQ4ZACq5lDz80VYatXJzisNyr95Pw7
3CHm55yvF33MHB5u/8r1806Cg3JKpPf07REOxwR+ajRPMXMwm+a0340v0WH6
VNslr4ojHfQ1QmNM7gDNKekvnmKf6MB1XPGvrUGUw0z7jf1Plc0dHgbdUX9U
kOhQ94M1bOKbKIcvtyoawueYOkjf6jz0tivJwaNtz7m2c5EOXYdlfJeFmDoc
+23DtyAyyeFqyI1SY6FIB8U1ByS/8pg6FMh+iAzSSHJIVP4i8yA0wmH7lJRn
zkdNHKTtFy9l+Z7o8PYj/5GemeEOvrUcmyfVmjgcSwj7uO1ookPlAe1sy7th
Dk9S19Q/NDVxKGjitM2ckujA1u8u9EwhzKHKL8DH4J2xg/SSPR3SyYkOk2KT
d05KCXXAFZ4ALG2jlg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.017891873441823`, 134.58049295396208`, 
      99.35109814007382}, {19.20221133522842, 134.99033557995432`, 
      100.09625531689586`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.017891873441823`, 134.58049295396208`, 
      99.35109814007382}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {16.10434394385644, 135.0752704260386, 
      101.32390136055254`}, {19.20221133522842, 134.99033557995432`, 
      100.09625531689586`}, {19.017891873441823`, 134.58049295396208`, 
      99.35109814007382}}], 
     Polygon3DBox[{{15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {12.453518167124663`, 133.93067739414613`, 
      100.31607587374307`}, {13.006476552484454`, 135.16020527212288`, 
      102.55154740420922`}, {16.10434394385644, 135.0752704260386, 
      101.32390136055254`}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.20221133522842, 134.99033557995432`, 
      100.09625531689586`}, {19.5976453402691, 135.3943900365474, 
      100.75775044462372`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.20221133522842, 134.99033557995432`, 
      100.09625531689586`}, {16.10434394385644, 135.0752704260386, 
      101.32390136055254`}, {16.895211953937793`, 135.88337933922472`, 
      102.64689161600826`}, {19.5976453402691, 135.3943900365474, 
      100.75775044462372`}, {19.20221133522842, 134.99033557995432`, 
      100.09625531689586`}}], 
     Polygon3DBox[{{16.10434394385644, 135.0752704260386, 
      101.32390136055254`}, {13.006476552484454`, 135.16020527212288`, 
      102.55154740420922`}, {14.192778567606485`, 136.37236864190209`, 
      104.5360327873928}, {16.895211953937793`, 135.88337933922472`, 
      102.64689161600826`}, {16.10434394385644, 135.0752704260386, 
      101.32390136055254`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.5976453402691, 135.3943900365474, 
      100.75775044462372`}, {20.17724571460592, 135.76512068025602`, 
      101.29050372347513`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.5976453402691, 135.3943900365474, 
      100.75775044462372`}, {16.895211953937793`, 135.88337933922472`, 
      102.64689161600826`}, {18.054412702611444`, 136.624840626642, 
      103.71239817371105`}, {20.17724571460592, 135.76512068025602`, 
      101.29050372347513`}, {19.5976453402691, 135.3943900365474, 
      100.75775044462372`}}], 
     Polygon3DBox[{{16.895211953937793`, 135.88337933922472`, 
      102.64689161600826`}, {14.192778567606485`, 136.37236864190209`, 
      104.5360327873928}, {15.931579690616962`, 137.484560573028, 
      106.134292623947}, {18.054412702611444`, 136.624840626642, 
      103.71239817371105`}, {16.895211953937793`, 135.88337933922472`, 
      102.64689161600826`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {20.17724571460592, 135.76512068025602`, 
      101.29050372347513`}, {20.90151365056275, 136.07726283037286`, 
      101.65820889791276`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{20.17724571460592, 135.76512068025602`, 
      101.29050372347513`}, {18.054412702611444`, 136.624840626642, 
      103.71239817371105`}, {19.502948574525096`, 137.24912492687565`, 
      104.44780852258634`}, {20.90151365056275, 136.07726283037286`, 
      101.65820889791276`}, {20.17724571460592, 135.76512068025602`, 
      101.29050372347513`}}], 
     Polygon3DBox[{{18.054412702611444`, 136.624840626642, 
      103.71239817371105`}, {15.931579690616962`, 137.484560573028, 
      106.134292623947}, {18.10438349848744, 138.42098702337847`, 
      107.2374081472599}, {19.502948574525096`, 137.24912492687565`, 
      104.44780852258634`}, {18.054412702611444`, 136.624840626642, 
      103.71239817371105`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {20.90151365056275, 136.07726283037286`, 
      101.65820889791276`}, {21.721091485213478`, 136.30954451520668`, 
      101.83580746796024`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{20.90151365056275, 136.07726283037286`, 
      101.65820889791276`}, {19.502948574525096`, 137.24912492687565`, 
      104.44780852258634`}, {21.142104243826545`, 137.71368829654332`, 
      104.8030056626813}, {21.721091485213478`, 136.30954451520668`, 
      101.83580746796024`}, {20.90151365056275, 136.07726283037286`, 
      101.65820889791276`}}], 
     Polygon3DBox[{{19.502948574525096`, 137.24912492687565`, 
      104.44780852258634`}, {18.10438349848744, 138.42098702337847`, 
      107.2374081472599}, {20.563117002439615`, 139.11783207787997`, 
      107.77020385740236`}, {21.142104243826545`, 137.71368829654332`, 
      104.8030056626813}, {19.502948574525096`, 137.24912492687565`, 
      104.44780852258634`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {21.721091485213478`, 136.30954451520668`, 
      101.83580746796024`}, {22.580126343543064`, 136.44613612179973`, 
      101.81119638456435`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{21.721091485213478`, 136.30954451520668`, 
      101.83580746796024`}, {21.142104243826545`, 137.71368829654332`, 
      104.8030056626813}, {22.860173960485717`, 137.98687150972944`, 
      104.75378349588951`}, {22.580126343543064`, 136.44613612179973`, 
      101.81119638456435`}, {21.721091485213478`, 136.30954451520668`, 
      101.83580746796024`}}], 
     Polygon3DBox[{{21.142104243826545`, 137.71368829654332`, 
      104.8030056626813}, {20.563117002439615`, 139.11783207787997`, 
      107.77020385740236`}, {23.140221577428377`, 139.52760689765913`, 
      107.69637060721467`}, {22.860173960485717`, 137.98687150972944`, 
      104.75378349588951`}, {21.142104243826545`, 137.71368829654332`, 
      104.8030056626813}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.580126343543064`, 136.44613612179973`, 
      101.81119638456435`}, {23.420076419578578`, 136.477729157891, 
      101.58605285238677`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{22.580126343543064`, 136.44613612179973`, 
      101.81119638456435`}, {22.86017396048572, 137.98687150972944`, 
      104.75378349588951`}, {24.54007411255675, 138.05005758191194`, 
      104.30349643153437`}, {23.420076419578578`, 136.477729157891, 
      101.58605285238677`}, {22.580126343543064`, 136.44613612179973`, 
      101.81119638456435`}}], 
     Polygon3DBox[{{22.86017396048572, 137.98687150972944`, 
      104.75378349588951`}, {23.14022157742838, 139.52760689765913`, 
      107.69637060721467`}, {25.660071805534926`, 139.62238600593295`, 
      107.02094001068194`}, {24.54007411255675, 138.05005758191194`, 
      104.30349643153437`}, {22.86017396048572, 137.98687150972944`, 
      104.75378349588951`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {23.420076419578578`, 136.477729157891, 
      101.58605285238677`}, {24.18370050372133, 136.40217061028082`, 
      101.17572003107814`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{23.420076419578578`, 136.477729157891, 
      101.58605285238677`}, {24.54007411255675, 138.05005758191194`, 
      104.30349643153437`}, {26.067322280842255`, 137.89894048669157`, 
      103.48283078891708`}, {24.18370050372133, 136.40217061028082`, 
      101.17572003107814`}, {23.420076419578578`, 136.477729157891, 
      101.58605285238677`}}], 
     Polygon3DBox[{{24.54007411255675, 138.05005758191194`, 
      104.30349643153437`}, {25.660071805534926`, 139.62238600593295`, 
      107.02094001068194`}, {27.950944057963177`, 139.39571036310235`, 
      105.78994154675603`}, {26.067322280842255`, 137.89894048669157`, 
      103.48283078891708`}, {24.54007411255675, 138.05005758191194`, 
      104.30349643153437`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {24.18370050372133, 136.40217061028082`, 
      101.17572003107814`}, {24.818958876585455`, 136.2246096691224, 
      100.60816142430357`}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{24.18370050372133, 136.40217061028082`, 
      101.17572003107814`}, {26.067322280842255`, 137.89894048669157`, 
      103.48283078891708`}, {27.337839026570514`, 137.54381860437476`, 
      102.34771357536795`}, {24.818958876585455`, 136.2246096691224, 
      100.60816142430357`}, {24.18370050372133, 136.40217061028082`, 
      101.17572003107814`}}], 
     Polygon3DBox[{{26.067322280842255`, 137.89894048669157`, 
      103.48283078891708`}, {27.950944057963177`, 139.39571036310235`, 
      105.78994154675603`}, {29.856719176555565`, 138.86302753962715`, 
      104.08726572643232`}, {27.337839026570514`, 137.54381860437476`, 
      102.34771357536795`}, {26.067322280842255`, 137.89894048669157`, 
      103.48283078891708`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {24.818958876585455`, 136.2246096691224, 
      100.60816142430357`}, {25.282559729874368`, 135.95714681912239`, 
      99.92205521317982}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{24.818958876585455`, 136.2246096691224, 
      100.60816142430357`}, {27.337839026570514`, 137.54381860437476`, 
      102.34771357536795`}, {28.265040733148336`, 137.00889290437473`, 
      100.97550115312045`}, {25.282559729874368`, 135.95714681912239`, 
      99.92205521317982}, {24.818958876585455`, 136.2246096691224, 
      100.60816142430357`}}], 
     Polygon3DBox[{{27.337839026570514`, 137.54381860437476`, 
      102.34771357536795`}, {29.856719176555565`, 138.86302753962715`, 
      104.08726572643232`}, {31.2475217364223, 138.06063898962708`, 
      102.02894709306108`}, {28.265040733148336`, 137.00889290437473`, 
      100.97550115312045`}, {27.337839026570514`, 137.54381860437476`, 
      102.34771357536795`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.282559729874368`, 135.95714681912239`, 
      99.92205521317982}, {25.542909431573058`, 135.618009211505, 
      99.16415840215085}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{25.282559729874368`, 135.95714681912239`, 
      99.92205521317982}, {28.265040733148332`, 137.00889290437476`, 
      100.97550115312045`}, {28.78574013654571, 136.33061768913998`, 
      99.45970753106249}, {25.542909431573058`, 135.618009211505, 
      99.16415840215085}, {25.282559729874368`, 135.95714681912239`, 
      99.92205521317982}}], 
     Polygon3DBox[{{28.265040733148332`, 137.00889290437476`, 
      100.97550115312045`}, {31.2475217364223, 138.06063898962708`, 
      102.02894709306108`}, {32.028570841518366`, 137.04322616677496`, 
      99.75525665997414}, {28.78574013654571, 136.33061768913998`, 
      99.45970753106249}, {28.265040733148332`, 137.00889290437476`, 
      100.97550115312045`}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.542909431573058`, 135.618009211505, 
      99.16415840215085}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{25.542909431573058`, 135.618009211505, 
      99.16415840215085}, {28.78574013654571, 136.33061768913998`, 
      99.45970753106249}, {28.864452432917563`, 135.55521629368596`, 
      97.90363153956993}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {25.542909431573058`, 135.618009211505, 
      99.16415840215085}}], 
     Polygon3DBox[{{28.78574013654571, 136.33061768913998`, 
      99.45970753106249}, {32.028570841518366`, 137.04322616677496`, 
      99.75525665997414}, {32.146639286076145`, 135.88012407359395`, 
      97.4211426727353}, {28.864452432917563`, 135.55521629368596`, 
      97.90363153956993}, {28.78574013654571, 136.33061768913998`, 
      99.45970753106249}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {25.39794611797239, 134.82046588778576`, 
      97.64096322958251}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{25.582265579758985`, 135.230308513778, 
      98.38612040640456}, {28.864452432917563`, 135.55521629368596`, 
      97.90363153956993}, {28.495813509344373`, 134.73553104170148`, 
      96.41331718592583}, {25.39794611797239, 134.82046588778576`, 
      97.64096322958251}, {25.582265579758985`, 135.230308513778, 
      98.38612040640456}}], 
     Polygon3DBox[{{28.864452432917563`, 135.55521629368596`, 
      97.90363153956993}, {32.146639286076145`, 135.88012407359395`, 
      97.4211426727353}, {31.593680900716354`, 134.6505961956172, 
      95.18567114226916}, {28.495813509344373`, 134.73553104170148`, 
      96.41331718592583}, {28.864452432917563`, 135.55521629368596`, 
      97.90363153956993}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.39794611797239, 134.82046588778576`, 
      97.64096322958251}, {25.00251211293171, 134.41641143119267`, 
      96.97946810185465}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{25.39794611797239, 134.82046588778576`, 
      97.64096322958251}, {28.495813509344373`, 134.73553104170148`, 
      96.41331718592583}, {27.704945499263015`, 133.92742212851536`, 
      95.09032693047011}, {25.00251211293171, 134.41641143119267`, 
      96.97946810185465}, {25.39794611797239, 134.82046588778576`, 
      97.64096322958251}}], 
     Polygon3DBox[{{28.495813509344373`, 134.73553104170148`, 
      96.41331718592583}, {31.593680900716357`, 134.6505961956172, 
      95.18567114226916}, {30.407378885594326`, 133.438432825838, 
      93.20118575908558}, {27.704945499263015`, 133.92742212851536`, 
      95.09032693047011}, {28.495813509344373`, 134.73553104170148`, 
      96.41331718592583}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {25.00251211293171, 134.41641143119267`, 
      96.97946810185465}, {24.422911738594888`, 134.04568078748406`, 
      96.44671482300325}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{25.00251211293171, 134.41641143119267`, 
      96.97946810185465}, {27.704945499263015`, 133.92742212851536`, 
      95.09032693047011}, {26.545744750589364`, 133.18596084109808`, 
      94.02482037276732}, {24.422911738594888`, 134.04568078748406`, 
      96.44671482300325}, {25.00251211293171, 134.41641143119267`, 
      96.97946810185465}}], 
     Polygon3DBox[{{27.704945499263015`, 133.92742212851536`, 
      95.09032693047011}, {30.407378885594326`, 133.438432825838, 
      93.20118575908558}, {28.668577762583848`, 132.32624089471207`, 
      91.60292592253137}, {26.545744750589364`, 133.18596084109808`, 
      94.02482037276732}, {27.704945499263015`, 133.92742212851536`, 
      95.09032693047011}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {24.422911738594888`, 134.04568078748406`, 
      96.44671482300325}, {23.69864380263806, 133.73353863736722`, 
      96.0790096485656}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{24.422911738594888`, 134.04568078748406`, 
      96.44671482300325}, {26.545744750589368`, 133.18596084109808`, 
      94.02482037276732}, {25.097208878675715`, 132.56167654086443`, 
      93.28941002389205}, {23.69864380263806, 133.73353863736722`, 
      96.0790096485656}, {24.422911738594888`, 134.04568078748406`, 
      96.44671482300325}}], 
     Polygon3DBox[{{26.545744750589368`, 133.18596084109808`, 
      94.02482037276732}, {28.66857776258385, 132.3262408947121, 
      91.60292592253137}, {26.49577395471337, 131.3898144443616, 
      90.49981039921846}, {25.097208878675715`, 132.56167654086443`, 
      93.28941002389205}, {26.545744750589368`, 133.18596084109808`, 
      94.02482037276732}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {23.69864380263806, 133.73353863736722`, 
      96.0790096485656}, {22.879065967987334`, 133.5012569525334, 
      95.90141107851814}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{23.69864380263806, 133.73353863736722`, 
      96.0790096485656}, {25.097208878675715`, 132.56167654086443`, 
      93.28941002389205}, {23.458053209374267`, 132.09711317119675`, 
      92.93421288379706}, {22.879065967987334`, 133.5012569525334, 
      95.90141107851814}, {23.69864380263806, 133.73353863736722`, 
      96.0790096485656}}], 
     Polygon3DBox[{{25.097208878675715`, 132.56167654086443`, 
      93.28941002389205}, {26.49577395471337, 131.3898144443616, 
      90.49981039921846}, {24.037040450761197`, 130.6929693898601, 
      89.96701468907601}, {23.458053209374267`, 132.09711317119675`, 
      92.93421288379706}, {25.097208878675715`, 132.56167654086443`, 
      93.28941002389205}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.879065967987334`, 133.5012569525334, 
      95.90141107851814}, {22.020031109657747`, 133.36466534594035`, 
      95.92602216191402}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{22.879065967987334`, 133.5012569525334, 
      95.90141107851814}, {23.458053209374267`, 132.09711317119675`, 
      92.93421288379706}, {21.739983492715094`, 131.82392995801064`, 
      92.98343505058887}, {22.020031109657747`, 133.36466534594035`, 
      95.92602216191402}, {22.879065967987334`, 133.5012569525334, 
      95.90141107851814}}], 
     Polygon3DBox[{{23.458053209374267`, 132.09711317119675`, 
      92.93421288379706}, {24.037040450761197`, 130.6929693898601, 
      89.96701468907601}, {21.459935875772437`, 130.28319457008095`, 
      90.0408479392637}, {21.739983492715094`, 131.82392995801064`, 
      92.98343505058887}, {23.458053209374267`, 132.09711317119675`, 
      92.93421288379706}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.020031109657744`, 133.36466534594035`, 
      95.92602216191402}, {21.18008103362223, 133.3330723098491, 
      96.1511656940916}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{22.020031109657744`, 133.36466534594035`, 
      95.92602216191402}, {21.739983492715087`, 131.82392995801064`, 
      92.98343505058887}, {20.06008334064406, 131.76074388582813`, 
      93.433722114944}, {21.18008103362223, 133.3330723098491, 
      96.1511656940916}, {22.020031109657744`, 133.36466534594035`, 
      95.92602216191402}}], 
     Polygon3DBox[{{21.739983492715087`, 131.82392995801064`, 
      92.98343505058887}, {21.45993587577243, 130.28319457008095`, 
      90.0408479392637}, {18.940085647665885`, 130.18841546180712`, 
      90.71627853579643}, {20.06008334064406, 131.76074388582813`, 
      93.433722114944}, {21.739983492715087`, 131.82392995801064`, 
      92.98343505058887}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {21.18008103362223, 133.3330723098491, 
      96.1511656940916}, {20.41645694947948, 133.40863085745926`, 
      96.56149851540023}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{21.18008103362223, 133.3330723098491, 96.1511656940916}, {
      20.06008334064406, 131.76074388582813`, 93.433722114944}, {
      18.532835172358556`, 131.9118609810485, 94.25438775756129}, {
      20.41645694947948, 133.40863085745926`, 96.56149851540023}, {
      21.18008103362223, 133.3330723098491, 96.1511656940916}}], 
     Polygon3DBox[{{20.06008334064406, 131.76074388582813`, 
      93.433722114944}, {18.940085647665885`, 130.18841546180712`, 
      90.71627853579643}, {16.64921339523763, 130.41509110463772`, 
      91.94727699972233}, {18.532835172358556`, 131.9118609810485, 
      94.25438775756129}, {20.06008334064406, 131.76074388582813`, 
      93.433722114944}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {20.41645694947948, 133.40863085745926`, 
      96.56149851540023}, {19.781198576615353`, 133.58619179861768`, 
      97.1290571221748}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{20.41645694947948, 133.40863085745926`, 
      96.56149851540023}, {18.532835172358556`, 131.9118609810485, 
      94.25438775756129}, {17.262318426630298`, 132.2669828633653, 
      95.38950497111041}, {19.781198576615353`, 133.58619179861768`, 
      97.1290571221748}, {20.41645694947948, 133.40863085745926`, 
      96.56149851540023}}], 
     Polygon3DBox[{{18.532835172358556`, 131.9118609810485, 
      94.25438775756129}, {16.64921339523763, 130.41509110463772`, 
      91.94727699972233}, {14.743438276645248`, 130.94777392811292`, 
      93.64995282004605}, {17.262318426630298`, 132.2669828633653, 
      95.38950497111041}, {18.532835172358556`, 131.9118609810485, 
      94.25438775756129}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.781198576615353`, 133.58619179861768`, 
      97.1290571221748}, {19.31759772332644, 133.8536546486177, 
      97.81516333329856}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.781198576615353`, 133.58619179861768`, 
      97.1290571221748}, {17.262318426630298`, 132.2669828633653, 
      95.38950497111043}, {16.335116720052476`, 132.80190856336532`, 
      96.76171739335793}, {19.31759772332644, 133.8536546486177, 
      97.81516333329856}, {19.781198576615353`, 133.58619179861768`, 
      97.1290571221748}}], 
     Polygon3DBox[{{17.262318426630298`, 132.2669828633653, 
      95.38950497111043}, {14.743438276645243`, 130.94777392811292`, 
      93.64995282004605}, {13.352635716778511`, 131.750162478113, 
      95.7082714534173}, {16.335116720052476`, 132.80190856336532`, 
      96.76171739335793}, {17.262318426630298`, 132.2669828633653, 
      95.38950497111043}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.31759772332644, 133.8536546486177, 
      97.81516333329856}, {19.05724802162775, 134.19279225623507`, 
      98.57306014432753}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.31759772332644, 133.8536546486177, 
      97.81516333329856}, {16.335116720052476`, 132.80190856336532`, 
      96.76171739335793}, {15.814417316655097`, 133.4801837786001, 
      98.27751101541588}, {19.05724802162775, 134.19279225623507`, 
      98.57306014432753}, {19.31759772332644, 133.8536546486177, 
      97.81516333329856}}], 
     Polygon3DBox[{{16.335116720052476`, 132.80190856336532`, 
      96.76171739335793}, {13.352635716778511`, 131.750162478113, 
      95.7082714534173}, {12.571586611682442`, 132.76757530096512`, 
      97.98196188650422}, {15.814417316655097`, 133.4801837786001, 
      98.27751101541588}, {16.335116720052476`, 132.80190856336532`, 
      96.76171739335793}}], 
     Polygon3DBox[{{22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {19.05724802162775, 134.19279225623507`, 
      98.57306014432753}, {19.017891873441823`, 134.58049295396208`, 
      99.35109814007382}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}, {22.300078726600404`, 134.90540073387004`, 
      98.86860927323919}}], 
     Polygon3DBox[{{19.05724802162775, 134.19279225623507`, 
      98.57306014432753}, {15.814417316655097`, 133.4801837786001, 
      98.27751101541588}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {19.017891873441823`, 134.58049295396208`, 
      99.35109814007382}, {19.05724802162775, 134.19279225623507`, 
      98.57306014432753}}], 
     Polygon3DBox[{{15.814417316655097`, 133.4801837786001, 
      98.27751101541588}, {12.571586611682442`, 132.76757530096512`, 
      97.98196188650422}, {12.453518167124662`, 133.93067739414613`, 
      100.31607587374306`}, {15.735705020283245`, 134.25558517405412`, 
      99.83358700690845}, {15.814417316655097`, 133.4801837786001, 
      98.27751101541588}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx10v0vlAEAB/Anlxk2hFryMmLjjORKhXLfW1fHosVuz/FQPc+FtBFSUnKc
yq6W13HpxZgz4bqavJQfKNqNZeOsFnKFQ5O3ccUOp+Uf6IfPf/BxE6dGJZgQ
BOGwjbXtui5XdmjWC5KLq459nTT++kfIg+xj4BJoMXOO5Q1+4UCi6wyNlKHs
wnBFDJpuk+MtYh9o6Lr0OUsG02OZcWf3U1DUMiyD1g8fe3zuS/0YlBn3oFJG
YTIkb+LdPg6uHujtyIpgwLNdafYfpNARXpHqVXIYPOdegfoSg9U3LqZnVig8
4TYXz7gfxWSU1lOXxkBiMCVLFyh86OPd3GgIhGW1lXwug4HipNpe1E3BRPB9
V/rvYGgKehsakxlc5m8lFl2jUMBW6SPHTmBcsDRfFcug6ZSxp8KUQs1mbcV5
Lhf6Rt/uZR6DrrxZ/jdpDBIM8oAGFuBVPuwodmMQoDRzJZej8Z7IsVPbAnyb
tXW2kUaoPIH4Q0XD+2tr1uZjLiQ6p9dDX2iMrh0x1/WLEN9WtBmWFAK9laDO
7BUN8UJw0ES4CEluD355Ko+DUHWVpD2k0dr/jJT/JDHS0mExLwmCkOcRdyuZ
xs727mljNQmivi472/wYpFEeAz4kjcjd5aVTOSRcW2SxXTcCMOlkvWQdRqNv
8CWq8kmssw0ZjcscvNVoc81O01DcW5QOq0i0K+NGOfUHoZ91TwmNoPHjbptf
jZFEfJnDiuKOL6Y8t9jCCzSe57d/rrwiAmfJV/mo1RsadadwRxYNmeBTpHBR
BC1rL/HCg42nY3YbxZU0bJyVmSOSaPzvzz/wYBWD
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx10v0vlAEAB3DRermMIhlPrZm3dV12Qt04t29Zy0Ul7sWzI/c8FMfdaDub
8pJbXDpO2yUSrdZdc9mq0UhzukjtsrgON7uzXtCLtlCma4sm/0A/fP6DTxBd
mHrG3c3NLWCNxxpmgHe+vyMUPV/udo9NULCYPbzZLjHGC5tfRS+FoWJ72TrW
KoWDWfs3HK5Oh7Tj8/OmtD1gzJ7ydIXSeCjbZ09YT4J0/Pg0OczCX75zt5ZP
I0Mz3KPNJ8F1HrUxr7Fh7FIKqnJpbLnTxgzvIOE3myG9uSkKpQbl9NtyGmbY
yzFGYslZUilujQHhvDIwp6GRqDaNqEdIEDmb8+RBHBwJM7FdWhoKW6k2WU/i
9LTBfaYgFgyv4oQuNY3I0ccfLglITA0qZ16kcRFgbVHfL6ahHOuMq/2ajuXG
fLX1STxYkZOSFQmNGq/bfdbsdITW/ZIMXOSBJqq7FXE0VjnPbiSNiuFo7fdf
ucVDRZO+IWYHDZ+Qnee/ccWoPlcmU2zloUc2xH83T0FfNaeaeCCCOUX0vfcj
F6zGJZ6vhQLrwmKnPUKEAVOKszk4DrHR8r1lBgoVZKq11iJE1EnVcsZvDuot
NleVmsJIQknmokoIySG5fE51AL0OWx6niAKhP8ZwZAlReiIlmT0fBcJgqiGy
Kegys5/qcoQQvDTnELJI/BRrAn2lFBQ+hj9vrgoRXJ/YwI+PAKvItlGQS8G4
TW68/l6IwNfG0csKJnY9ah/MKqFwdqsiuT5JhNmQvrqie+FgHC9Y8NRRSLVX
DvGtIuhi26Y0fmEYp/sbWjopONuphWGpGP/78w9uHhHt
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{12.453518167124663`, 133.93067739414613`, 
       100.31607587374307`}, {10.924006761878065`, 142.7445939237275, 
       95.84668326727035}, {11.476965147237856`, 143.97412180170426`, 
       98.0821547977365}, {13.006476552484454`, 135.16020527212288`, 
       102.55154740420922`}, {12.453518167124663`, 133.93067739414613`, 
       100.31607587374307`}}], 
      Line3DBox[{{13.006476552484454`, 135.16020527212288`, 
       102.55154740420922`}, {11.476965147237856`, 143.97412180170426`, 
       98.0821547977365}, {12.663267162359887`, 145.18628517148346`, 
       100.06664018092007`}, {14.192778567606485`, 136.37236864190209`, 
       104.5360327873928}, {13.006476552484454`, 135.16020527212288`, 
       102.55154740420922`}}], 
      Line3DBox[{{14.192778567606485`, 136.37236864190209`, 
       104.5360327873928}, {12.663267162359887`, 145.18628517148346`, 
       100.06664018092007`}, {14.402068285370364`, 146.29847710260938`, 
       101.66490001747428`}, {15.931579690616962`, 137.484560573028, 
       106.134292623947}, {14.192778567606485`, 136.37236864190209`, 
       104.5360327873928}}], 
      Line3DBox[{{15.931579690616962`, 137.484560573028, 106.134292623947}, {
       14.402068285370364`, 146.29847710260938`, 101.66490001747428`}, {
       16.57487209324084, 147.23490355295985`, 102.76801554078718`}, {
       18.10438349848744, 138.42098702337847`, 107.2374081472599}, {
       15.931579690616962`, 137.484560573028, 106.134292623947}}], 
      Line3DBox[{{18.10438349848744, 138.42098702337847`, 
       107.2374081472599}, {16.57487209324084, 147.23490355295985`, 
       102.76801554078718`}, {19.03360559719302, 147.93174860746134`, 
       103.30081125092964`}, {20.563117002439615`, 139.11783207787997`, 
       107.77020385740236`}, {18.10438349848744, 138.42098702337847`, 
       107.2374081472599}}], 
      Line3DBox[{{20.563117002439615`, 139.11783207787997`, 
       107.77020385740236`}, {19.03360559719302, 147.93174860746134`, 
       103.30081125092964`}, {21.61071017218178, 148.3415234272405, 
       103.22697800074195`}, {23.140221577428377`, 139.52760689765913`, 
       107.69637060721467`}, {20.563117002439615`, 139.11783207787997`, 
       107.77020385740236`}}], 
      Line3DBox[{{23.14022157742838, 139.52760689765913`, 
       107.69637060721467`}, {21.610710172181783`, 148.3415234272405, 
       103.22697800074195`}, {24.130560400288328`, 148.43630253551433`, 
       102.55154740420922`}, {25.660071805534926`, 139.62238600593295`, 
       107.02094001068194`}, {23.14022157742838, 139.52760689765913`, 
       107.69637060721467`}}], 
      Line3DBox[{{25.660071805534926`, 139.62238600593295`, 
       107.02094001068194`}, {24.130560400288328`, 148.43630253551433`, 
       102.55154740420922`}, {26.421432652716582`, 148.20962689268373`, 
       101.3205489402833}, {27.950944057963177`, 139.39571036310235`, 
       105.78994154675603`}, {25.660071805534926`, 139.62238600593295`, 
       107.02094001068194`}}], 
      Line3DBox[{{27.950944057963177`, 139.39571036310235`, 
       105.78994154675603`}, {26.421432652716582`, 148.20962689268373`, 
       101.3205489402833}, {28.327207771308966`, 147.67694406920853`, 
       99.6178731199596}, {29.856719176555565`, 138.86302753962715`, 
       104.08726572643232`}, {27.950944057963177`, 139.39571036310235`, 
       105.78994154675603`}}], 
      Line3DBox[{{29.856719176555565`, 138.86302753962715`, 
       104.08726572643232`}, {28.327207771308966`, 147.67694406920853`, 
       99.6178731199596}, {29.718010331175698`, 146.87455551920846`, 
       97.55955448658835}, {31.2475217364223, 138.06063898962708`, 
       102.02894709306108`}, {29.856719176555565`, 138.86302753962715`, 
       104.08726572643232`}}], 
      Line3DBox[{{31.2475217364223, 138.06063898962708`, 
       102.02894709306108`}, {29.7180103311757, 146.87455551920846`, 
       97.55955448658835}, {30.499059436271768`, 145.85714269635633`, 
       95.28586405350141}, {32.028570841518366`, 137.04322616677496`, 
       99.75525665997414}, {31.2475217364223, 138.06063898962708`, 
       102.02894709306108`}}], 
      Line3DBox[{{32.028570841518366`, 137.04322616677496`, 
       99.75525665997414}, {30.499059436271768`, 145.85714269635633`, 
       95.28586405350141}, {30.617127880829546`, 144.69404060317532`, 
       92.95175006626258}, {32.146639286076145`, 135.88012407359395`, 
       97.4211426727353}, {32.028570841518366`, 137.04322616677496`, 
       99.75525665997414}}], 
      Line3DBox[{{32.146639286076145`, 135.88012407359395`, 
       97.4211426727353}, {30.617127880829546`, 144.69404060317532`, 
       92.95175006626258}, {30.064169495469752`, 143.46451272519857`, 
       90.71627853579643}, {31.593680900716354`, 134.6505961956172, 
       95.18567114226916}, {32.146639286076145`, 135.88012407359395`, 
       97.4211426727353}}], 
      Line3DBox[{{31.593680900716357`, 134.6505961956172, 
       95.18567114226916}, {30.06416949546976, 143.46451272519857`, 
       90.71627853579643}, {28.877867480347728`, 142.25234935541937`, 
       88.73179315261285}, {30.407378885594326`, 133.438432825838, 
       93.20118575908558}, {31.593680900716357`, 134.6505961956172, 
       95.18567114226916}}], 
      Line3DBox[{{30.407378885594326`, 133.438432825838, 93.20118575908558}, {
       28.877867480347728`, 142.25234935541937`, 88.73179315261285}, {
       27.13906635733725, 141.14015742429345`, 87.13353331605865}, {
       28.668577762583848`, 132.32624089471207`, 91.60292592253137}, {
       30.407378885594326`, 133.438432825838, 93.20118575908558}}], 
      Line3DBox[{{28.66857776258385, 132.3262408947121, 91.60292592253137}, {
       27.13906635733725, 141.14015742429348`, 87.13353331605865}, {
       24.966262549466773`, 140.20373097394298`, 86.03041779274574}, {
       26.49577395471337, 131.3898144443616, 90.49981039921846}, {
       28.66857776258385, 132.3262408947121, 91.60292592253137}}], 
      Line3DBox[{{26.49577395471337, 131.3898144443616, 90.49981039921846}, {
       24.966262549466773`, 140.20373097394298`, 86.03041779274574}, {
       22.507529045514598`, 139.5068859194415, 85.49762208260329}, {
       24.037040450761197`, 130.6929693898601, 89.96701468907601}, {
       26.49577395471337, 131.3898144443616, 90.49981039921846}}], 
      Line3DBox[{{24.037040450761197`, 130.6929693898601, 
       89.96701468907601}, {22.507529045514598`, 139.5068859194415, 
       85.49762208260329}, {19.93042447052584, 139.09711109966233`, 
       85.57145533279098}, {21.459935875772437`, 130.28319457008095`, 
       90.0408479392637}, {24.037040450761197`, 130.6929693898601, 
       89.96701468907601}}], 
      Line3DBox[{{21.45993587577243, 130.28319457008095`, 90.0408479392637}, {
       19.930424470525832`, 139.09711109966233`, 85.57145533279098}, {
       17.410574242419287`, 139.0023319913885, 86.24688592932371}, {
       18.940085647665885`, 130.18841546180712`, 90.71627853579643}, {
       21.45993587577243, 130.28319457008095`, 90.0408479392637}}], 
      Line3DBox[{{18.940085647665885`, 130.18841546180712`, 
       90.71627853579643}, {17.410574242419287`, 139.0023319913885, 
       86.24688592932371}, {15.119701989991034`, 139.2290076342191, 
       87.47788439324961}, {16.64921339523763, 130.41509110463772`, 
       91.94727699972233}, {18.940085647665885`, 130.18841546180712`, 
       90.71627853579643}}], 
      Line3DBox[{{16.64921339523763, 130.41509110463772`, 
       91.94727699972233}, {15.119701989991034`, 139.2290076342191, 
       87.47788439324961}, {13.21392687139865, 139.7616904576943, 
       89.18056021357333}, {14.743438276645248`, 130.94777392811292`, 
       93.64995282004605}, {16.64921339523763, 130.41509110463772`, 
       91.94727699972233}}], 
      Line3DBox[{{14.743438276645243`, 130.94777392811292`, 
       93.64995282004605}, {13.213926871398645`, 139.7616904576943, 
       89.18056021357333}, {11.823124311531913`, 140.56407900769437`, 
       91.23887884694457}, {13.352635716778511`, 131.750162478113, 
       95.7082714534173}, {14.743438276645243`, 130.94777392811292`, 
       93.64995282004605}}], 
      Line3DBox[{{13.352635716778511`, 131.750162478113, 95.7082714534173}, {
       11.823124311531913`, 140.56407900769437`, 91.23887884694457}, {
       11.042075206435843`, 141.5814918305465, 93.5125692800315}, {
       12.571586611682442`, 132.76757530096512`, 97.98196188650422}, {
       13.352635716778511`, 131.750162478113, 95.7082714534173}}], 
      Line3DBox[{{12.571586611682442`, 132.76757530096512`, 
       97.98196188650422}, {11.042075206435843`, 141.5814918305465, 
       93.5125692800315}, {10.924006761878063`, 142.7445939237275, 
       95.84668326727034}, {12.453518167124662`, 133.93067739414613`, 
       100.31607587374306`}, {12.571586611682442`, 132.76757530096512`, 
       97.98196188650422}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG6fbm//ZbbhgThDNVeRhgSHRTOZl/HcTXBQmumc
+ni39gHVRW+28s6Ph4ubMnP43LNXOdDzsOfhJ9s4uPiEWzNSN7VLHviioMt7
404MXLwg1jktQJ71QEzCWYu91dFw8YYvoX/bF360PzI/N2WRVBRc/M+KM4Y5
CcIO2vd5J7TvjCAoPgFqzmE0c7Jx2IvLnSY4/KUADQcVtHDAFW64xAGn+6Ij

       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHa4v4NdKMDowCOlnllfrkU5HKj8NfuWU5xD3mIr
ae41OgdenDl4YGpztMP07f+0Z2XFO8R0MKt/2q5y4F3Z92dmBjEO26sY7+l4
JjhMuDUjdVO75IEvCrq8N+7EOCyaybyM526Cw3WP0F8M9swHfp1KMq7sjHXo
3cGa96Yg0eGJG9/ao0o/7RlKZ0RKmcU5VF5nNzvDkuTw6PjG4McGYg5s8ufq
dz+Kc0j5xvlv9Qzc4h9wmHMJh7243BmFw185OMIBV7jhEgcAsVastw==
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmIP6z4oxhToKwg/Z93gntOyMcFs1kXsZzN8Ehd7KX
4TQjOQf+246cq5IjHbba2XDd8090+Ob9tNx5jpKDjH+pXKpXlAPzCbagO7sS
HXRczp+5/VvZ4bvTxpr/sdEOc0/rP94jluQQsFtaR05B2UF5q8ivDd0xDpzq
RbdsYpMc/uzy0GWRUHCYwPPR4dW+WIf1BRnufZ1JDo+Pbwx+bCDmwCZ/rn73
oziHlG+c/1bPSHL4Yr9eNOMRo0OK8ro1jo/j4epXGO/40zH/1/6y3zN3N4Qn
wM1n+RFo49AlfsBKM0+JZ04C3D2eV28wrHZXOVDww8l8+q4EuPtLH+r/knLX
ObCRYaoc78YEuH/bp9vbf5lteCDOUM1VpCEBHj5KQvL76wJMDuQa93Awayc4
TPhyytE6K8HBWXj/u1+CZgfOfnry2ys/3qHpGsOXyn/xDnH8JpLHD5od+PRv
xdwN0XEO/ufXXdzhFu/wweuWx4tgswNHe1wV/uvGOpRLaD3esTPO4cSpAs/b
500ORJpm3jz6K9pBq9WWUywxzsHx/g52oQCjA4+UemZ9uRblcKDy1+xbTnEO
E1exZPsw6B1okVuTm3ctEq5e4Qqj20FjtQN/vNQWr+OKdCiDmi+/936fSqv0
geL3tVenN0bA3aMkyjBZloH1AFfgldWNLhFw97OZ71ji8vurfbuDwd2p4REO
/VD//sSRfgA0fQwS
      "]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGCQAGImIAaxUcEFexhL6UaPziNrTwd0cRj48x8E9u9f7RPx
omrbafstHOrc64xh6g/AxWHqWaDiKyDi+9HVw8Rx2Ttn1rWiXWd9HA5cE1ob
//T4fpg4LnsfHHc6sPOKjwODx5cX8doP979a6Jk3Mf4khjth9qKrfw5Rvx+X
vfJuezjnrohyaGk+ExwSrnSg48n7lRFzzu3BZe//ye3GJ7dHOTgEG0gKbVM8
0PK668yvV0dx2vtoruPmFWejHNre7WRYflnxgF8Oz0R++2P2uOwtmLTeetGZ
JAeOlMi6I1meDnXRU010HgU44LI36ek3roJ7SQ5vOk2b/lz2dDBhr1mrUxzg
gMtehim+3Z0vkhxcRT/MmrvOw+GMBc80v6gAB1z2ZpX7//B28newiP2W07Us
wiEzjTugNjfEAZe9/9Vffv062d8hZMeNZ5I6EQ4q0qkufV9DHXDZy/9m5q2e
mkCHyS/mBApbRTnYrWvRXqgejtPeln0Zbp2Wvg42T8T7RCMiHX4Gqqwv2xGC
097kqo1L18b5Ohy6ZXl4/ZsIh8cHVvo72IXhtFeKKX6TJ0+AQ3XTn8kZMtEO
jO0fvE6Vh+O0V6nnYvw0WwuH9WG1/jnsiQ6agu/ftJhE4rQ3/f0LWZVzFg4f
U6xz/j1JcHir43krekEETnvdAxJ8vI+aOPzRPXrQZl+CwzI1Gda78RE47f0g
Yd/0gu/tfvYP3UphHXEOSWkW8bdvJ+K0d4GVh8gvg8v7v96/ympuH+OwaO36
zizfRJz2hnXtN17LpnugM1X53v1N0Q7mC58JylbHOwAAMizxhA==
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAGJmIFa60aPzyNrTgQEMLtgzQMEWDnXudcYw8QP7V/tE
vKjadtoeXXwFRHz/nFnXinad9XE4cE1obfzT4/th5jw47nRg5xUfBwaPLy/i
tR/uf7XQM29i/El7dPHnEPH98m57OOeuiHJoaT4THBKudKDjyfuVEXPO7fk/
ud345PYoB4dgA0mhbYoHWl53nfn16uj+R3MdN684G+XQ9m4nw/LLigf8cngm
8tsfsy+YtN560ZkkB46UyLojWZ4OddFTTXQeBTgkPf3GVXAvyeFNp2nTn8ue
DibsNWt1igMcGKb4dne+SHJwFf0wa+46D4czFjzT/KICHLLK/X94O/k7WMR+
y+laFuGQmcYdUJsb4vBf/eXXr5P9HUJ23HgmqRPhoCKd6tL3NdSB/83MWz01
gQ6TX8wJFLaKcrBb16K9UD3coWVfhlunpa+DzRPxPtGISIefgSrry3aEOCRX
bVy6Ns7X4dAty8Pr30Q4PD6w0t/BLsxBiil+kydPgEN105/JGTLRDoztH7xO
lYc7KPVcjJ9ma+GwPqzWP4c90UFT8P2bFpNIh/T3L2RVzlk4fEyxzvn3JMHh
rY7nregFEQ7uAQk+3kdNHP7oHj1osy/BYZmaDOvd+AiHDxL2TS/43u5n/9Ct
FNYR55CUZhF/+3aiwwIrD5FfBpf3f71/ldXcPsZh0dr1nVm+iQ5hXfuN17Lp
HuhMVb53f1O0g/nCZ4Ky1fEOAF4rAKs=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563366889707035*^9, 3.566086396348749*^9, 
  3.567272849999044*^9, 3.614727109722699*^9},
 CellTags->{"Advanced Placement", "PR2.4"},
 CellLabel->"During evaluation of In[75]:="]
}, Open  ]],

Cell[TextData[{
 StyleBox["MoveAligned", "MB"],
 " in three dimensions."
}], "Commentary",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell[TextData[{
 "It would have been difficult to devise equivalent ",
 StyleBox["Move", "MB"],
 " directives for this optical system.  The ",
 StyleBox["MoveAligned", "MB"],
 " function computes them automatically using an internal scout trace.  ",
 StyleBox["MoveAligned", "MB"],
 " also works well for laser resonator layout.  This is demonstrated further  \
in Section 4.2.3."
}], "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 2 topics"]], "Text",
 CellTags->"PR2.4"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"EnhancedPrintout",
WindowToolbars->"RulerBar",
WindowSize->{1107, 786},
WindowMargins->{{Automatic, -116}, {-46, Automatic}},
PrintingCopies->1,
PrintingStartingPageNumber->41,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{"Placement Directives"}], "Header"]}, {
   Cell[
    TextData[{"Chapter 2"}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False},
DelimiterFlashTime->1,
AutoItalicWords->{
 "Mathematica", "MathLink", "MathSource", "MathReader", "MathScript", 
  "Optica", "Optica2"},
Magnification->1,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "chapter 2 topics"->{
  Cell[579, 22, 174, 3, 60, "Subtitle",
   CellTags->{
    "chapter 2 topics", "Overview", "Placing Components and Systems", 
     "Angular Orientation", "Advanced Placement"}]},
 "Overview"->{
  Cell[579, 22, 174, 3, 60, "Subtitle",
   CellTags->{
    "chapter 2 topics", "Overview", "Placing Components and Systems", 
     "Angular Orientation", "Advanced Placement"}],
  Cell[2338, 91, 86, 2, 34, "Section",
   PageBreakAbove->True,
   CellTags->{"2.1", "Overview"}],
  Cell[2427, 95, 607, 15, 47, "Text",
   CellTags->"Overview"],
  Cell[3037, 112, 1184, 37, 59, "Text",
   CellTags->"Overview"],
  Cell[4224, 151, 856, 27, 47, "Text",
   CellTags->"Overview"],
  Cell[5083, 180, 944, 21, 60, "Text",
   CellTags->"Overview"],
  Cell[6030, 203, 622, 14, 48, "Text",
   CellTags->"Overview"],
  Cell[6655, 219, 334, 6, 33, "Text",
   CellTags->"Overview"]},
 "Placing Components and Systems"->{
  Cell[579, 22, 174, 3, 60, "Subtitle",
   CellTags->{
    "chapter 2 topics", "Overview", "Placing Components and Systems", 
     "Angular Orientation", "Advanced Placement"}],
  Cell[879, 33, 176, 3, 26, "Outline2",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[1058, 38, 639, 25, 87, "Outline3",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[10811, 333, 171, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[11007, 340, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
     "PR2.2.1"}],
  Cell[11151, 345, 597, 17, 35, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[11751, 364, 515, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[12269, 379, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[12488, 387, 129, 2, 35, "Subsection",
   CellTags->{
    "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", 
     "PR2.2.2"}],
  Cell[12620, 391, 351, 7, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[12996, 402, 2391, 61, 244, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[15390, 465, 25698, 421, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[41091, 888, 26084, 430, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67190, 1321, 225, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67418, 1329, 393, 9, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67814, 1340, 516, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[68333, 1355, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[68552, 1363, 119, 2, 35, "Subsection",
   CellTags->{
    "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[68674, 1367, 478, 10, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[69177, 1381, 1836, 45, 198, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[71016, 1428, 25667, 420, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[96686, 1850, 26056, 429, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[122757, 2282, 251, 8, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123011, 2292, 267, 6, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123281, 2300, 472, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123756, 2315, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123975, 2323, 134, 3, 35, "Subsection",
   CellTags->{
    "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
     "PR2.2.4"}],
  Cell[124112, 2328, 393, 8, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[124530, 2340, 2687, 71, 229, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[127220, 2413, 24545, 426, 301, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151780, 2842, 206, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151989, 2850, 326, 9, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[152318, 2861, 901, 25, 48, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[153222, 2888, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[153441, 2896, 139, 3, 35, "Subsection",
   CellTags->{
    "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.5"}],
  Cell[153583, 2901, 564, 12, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[154172, 2917, 3066, 80, 261, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[157241, 2999, 13878, 246, 271, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171134, 3248, 219, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171356, 3255, 296, 11, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171655, 3268, 917, 22, 62, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[172575, 3292, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[172794, 3300, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.6"}],
  Cell[172938, 3305, 757, 18, 47, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[173720, 3327, 4195, 113, 214, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[177918, 3442, 543, 11, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[178464, 3455, 643, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179110, 3469, 645, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179758, 3483, 31504, 553, 359, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211277, 4039, 178, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211458, 4046, 876, 29, 49, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212337, 4077, 354, 10, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212694, 4089, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]},
 "Angular Orientation"->{
  Cell[579, 22, 174, 3, 60, "Subtitle",
   CellTags->{
    "chapter 2 topics", "Overview", "Placing Components and Systems", 
     "Angular Orientation", "Advanced Placement"}],
  Cell[1734, 68, 154, 3, 28, "Outline2",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[1891, 73, 282, 9, 35, "Outline3",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[212925, 4098, 116, 1, 60, "Section",
   CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213044, 4101, 311, 7, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213358, 4110, 431, 8, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213792, 4120, 160, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[213977, 4127, 160, 3, 35, "Subsection",
   CellTags->{
    "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
     "PR2.3.1"}],
  Cell[214140, 4132, 300, 8, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[214443, 4142, 601, 13, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[215047, 4157, 101937, 7773, 394, 89703, 7570, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[316987, 11932, 243, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[317233, 11940, 775, 12, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318011, 11954, 782, 22, 46, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318796, 11978, 102262, 7990, 349, 91053, 7805, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421061, 19970, 242, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421306, 19978, 584, 12, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421893, 19992, 439, 12, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[422335, 20006, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[422543, 20014, 109, 1, 35, "Subsection",
   CellTags->{"2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[422655, 20017, 522, 11, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423180, 20030, 642, 11, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423825, 20043, 143, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423971, 20047, 393587, 24706, 416, 377469, 24441, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817561, 44755, 109, 1, 26, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817673, 44758, 630, 13, 48, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818306, 44773, 481, 13, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818790, 44788, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}]},
 "Advanced Placement"->{
  Cell[579, 22, 174, 3, 60, "Subtitle",
   CellTags->{
    "chapter 2 topics", "Overview", "Placing Components and Systems", 
     "Angular Orientation", "Advanced Placement"}],
  Cell[819010, 44797, 124, 1, 60, "Section",
   CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}],
  Cell[819137, 44800, 586, 13, 35, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[819726, 44815, 275, 7, 21, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[820026, 44826, 1428, 43, 120, "Input",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[821457, 44871, 20209, 399, 198, "Print",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[841681, 45273, 229, 6, 27, "Commentary",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[841913, 45281, 184, 4, 20, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[842122, 45289, 1951, 58, 119, "Input",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[844076, 45349, 4834, 141, 99, "Output",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[848913, 45492, 158345, 2566, 378, "Print",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[1007273, 48061, 134, 4, 27, "Commentary",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[1007410, 48067, 436, 10, 34, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}]},
 "PR2.2"->{
  Cell[879, 33, 176, 3, 26, "Outline2",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[1058, 38, 639, 25, 87, "Outline3",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[10811, 333, 171, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2"}],
  Cell[11007, 340, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
     "PR2.2.1"}],
  Cell[11151, 345, 597, 17, 35, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[11751, 364, 515, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[12269, 379, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[12488, 387, 129, 2, 35, "Subsection",
   CellTags->{
    "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", 
     "PR2.2.2"}],
  Cell[12620, 391, 351, 7, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[12996, 402, 2391, 61, 244, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[15390, 465, 25698, 421, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[41091, 888, 26084, 430, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67190, 1321, 225, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67418, 1329, 393, 9, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67814, 1340, 516, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[68333, 1355, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[68552, 1363, 119, 2, 35, "Subsection",
   CellTags->{
    "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[68674, 1367, 478, 10, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[69177, 1381, 1836, 45, 198, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[71016, 1428, 25667, 420, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[96686, 1850, 26056, 429, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[122757, 2282, 251, 8, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123011, 2292, 267, 6, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123281, 2300, 472, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123756, 2315, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123975, 2323, 134, 3, 35, "Subsection",
   CellTags->{
    "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
     "PR2.2.4"}],
  Cell[124112, 2328, 393, 8, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[124530, 2340, 2687, 71, 229, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[127220, 2413, 24545, 426, 301, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151780, 2842, 206, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151989, 2850, 326, 9, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[152318, 2861, 901, 25, 48, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[153222, 2888, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[153441, 2896, 139, 3, 35, "Subsection",
   CellTags->{
    "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.5"}],
  Cell[153583, 2901, 564, 12, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[154172, 2917, 3066, 80, 261, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[157241, 2999, 13878, 246, 271, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171134, 3248, 219, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171356, 3255, 296, 11, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171655, 3268, 917, 22, 62, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[172575, 3292, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[172794, 3300, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.6"}],
  Cell[172938, 3305, 757, 18, 47, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[173720, 3327, 4195, 113, 214, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[177918, 3442, 543, 11, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[178464, 3455, 643, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179110, 3469, 645, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179758, 3483, 31504, 553, 359, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211277, 4039, 178, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211458, 4046, 876, 29, 49, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212337, 4077, 354, 10, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212694, 4089, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]},
 "PR2.3"->{
  Cell[1734, 68, 154, 3, 28, "Outline2",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[1891, 73, 282, 9, 35, "Outline3",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[212925, 4098, 116, 1, 60, "Section",
   CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213044, 4101, 311, 7, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213358, 4110, 431, 8, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213792, 4120, 160, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3"}],
  Cell[213977, 4127, 160, 3, 35, "Subsection",
   CellTags->{
    "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
     "PR2.3.1"}],
  Cell[214140, 4132, 300, 8, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[214443, 4142, 601, 13, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[215047, 4157, 101937, 7773, 394, 89703, 7570, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[316987, 11932, 243, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[317233, 11940, 775, 12, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318011, 11954, 782, 22, 46, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318796, 11978, 102262, 7990, 349, 91053, 7805, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421061, 19970, 242, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421306, 19978, 584, 12, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421893, 19992, 439, 12, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[422335, 20006, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[422543, 20014, 109, 1, 35, "Subsection",
   CellTags->{"2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[422655, 20017, 522, 11, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423180, 20030, 642, 11, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423825, 20043, 143, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423971, 20047, 393587, 24706, 416, 377469, 24441, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817561, 44755, 109, 1, 26, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817673, 44758, 630, 13, 48, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818306, 44773, 481, 13, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818790, 44788, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}]},
 "2.1"->{
  Cell[2338, 91, 86, 2, 34, "Section",
   PageBreakAbove->True,
   CellTags->{"2.1", "Overview"}]},
 "2.2"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}]},
 "PR2.2.1"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[11007, 340, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
     "PR2.2.1"}],
  Cell[11151, 345, 597, 17, 35, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[11751, 364, 515, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
  Cell[12269, 379, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}]},
 "PR2.2.2"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[12488, 387, 129, 2, 35, "Subsection",
   CellTags->{
    "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", 
     "PR2.2.2"}],
  Cell[12620, 391, 351, 7, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[12996, 402, 2391, 61, 244, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[15390, 465, 25698, 421, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[41091, 888, 26084, 430, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67190, 1321, 225, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67418, 1329, 393, 9, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[67814, 1340, 516, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
  Cell[68333, 1355, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}]},
 "PR2.2.3"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[68552, 1363, 119, 2, 35, "Subsection",
   CellTags->{
    "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[68674, 1367, 478, 10, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[69177, 1381, 1836, 45, 198, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[71016, 1428, 25667, 420, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[96686, 1850, 26056, 429, 371, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[122757, 2282, 251, 8, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123011, 2292, 267, 6, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123281, 2300, 472, 13, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
  Cell[123756, 2315, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}]},
 "PR2.2.4"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[123975, 2323, 134, 3, 35, "Subsection",
   CellTags->{
    "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
     "PR2.2.4"}],
  Cell[124112, 2328, 393, 8, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[124530, 2340, 2687, 71, 229, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[127220, 2413, 24545, 426, 301, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151780, 2842, 206, 6, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[151989, 2850, 326, 9, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[152318, 2861, 901, 25, 48, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
  Cell[153222, 2888, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}]},
 "PR2.2.5"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[153441, 2896, 139, 3, 35, "Subsection",
   CellTags->{
    "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.5"}],
  Cell[153583, 2901, 564, 12, 34, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[154172, 2917, 3066, 80, 261, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[157241, 2999, 13878, 246, 271, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171134, 3248, 219, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171356, 3255, 296, 11, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[171655, 3268, 917, 22, 62, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
  Cell[172575, 3292, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}]},
 "PR2.2.6"->{
  Cell[7144, 234, 189, 3, 60, "Section",
   CellTags->{
    "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7336, 239, 560, 11, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[7899, 252, 580, 16, 33, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[8482, 270, 1216, 36, 62, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[9701, 308, 1107, 23, 66, "Text",
   CellTags->{
    "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
     "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
  Cell[172794, 3300, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.6"}],
  Cell[172938, 3305, 757, 18, 47, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[173720, 3327, 4195, 113, 214, "Input",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[177918, 3442, 543, 11, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[178464, 3455, 643, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179110, 3469, 645, 12, 22, "Message",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[179758, 3483, 31504, 553, 359, "Print",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211277, 4039, 178, 5, 27, "Commentary",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[211458, 4046, 876, 29, 49, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212337, 4077, 354, 10, 21, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
  Cell[212694, 4089, 182, 3, 20, "Text",
   CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]},
 "2.2.1"->{
  Cell[11007, 340, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
     "PR2.2.1"}]},
 "Legacy Issues"->{
  Cell[11007, 340, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
     "PR2.2.1"}]},
 "2.2.2"->{
  Cell[12488, 387, 129, 2, 35, "Subsection",
   CellTags->{
    "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", 
     "PR2.2.2"}]},
 "Translate"->{
  Cell[12488, 387, 129, 2, 35, "Subsection",
   CellTags->{
    "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", 
     "PR2.2.2"}]},
 "2.2.3"->{
  Cell[68552, 1363, 119, 2, 35, "Subsection",
   CellTags->{
    "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}]},
 "Move"->{
  Cell[68552, 1363, 119, 2, 35, "Subsection",
   CellTags->{
    "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}]},
 "2.2.4"->{
  Cell[123975, 2323, 134, 3, 35, "Subsection",
   CellTags->{
    "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
     "PR2.2.4"}]},
 "MoveLinear"->{
  Cell[123975, 2323, 134, 3, 35, "Subsection",
   CellTags->{
    "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
     "PR2.2.4"}]},
 "2.2.5"->{
  Cell[153441, 2896, 139, 3, 35, "Subsection",
   CellTags->{
    "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.5"}]},
 "MoveDirected"->{
  Cell[153441, 2896, 139, 3, 35, "Subsection",
   CellTags->{
    "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.5"}]},
 "2.2.6"->{
  Cell[172794, 3300, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.6"}]},
 "MoveReflected"->{
  Cell[172794, 3300, 141, 3, 35, "Subsection",
   CellTags->{
    "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
     "PR2.2.6"}]},
 "2.3"->{
  Cell[212925, 4098, 116, 1, 60, "Section",
   CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}]},
 "PR2.3.1"->{
  Cell[212925, 4098, 116, 1, 60, "Section",
   CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213044, 4101, 311, 7, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213358, 4110, 431, 8, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213977, 4127, 160, 3, 35, "Subsection",
   CellTags->{
    "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
     "PR2.3.1"}],
  Cell[214140, 4132, 300, 8, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[214443, 4142, 601, 13, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[215047, 4157, 101937, 7773, 394, 89703, 7570, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[316987, 11932, 243, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[317233, 11940, 775, 12, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318011, 11954, 782, 22, 46, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[318796, 11978, 102262, 7990, 349, 91053, 7805, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421061, 19970, 242, 6, 27, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421306, 19978, 584, 12, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[421893, 19992, 439, 12, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
  Cell[422335, 20006, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}]},
 "PR2.3.2"->{
  Cell[212925, 4098, 116, 1, 60, "Section",
   CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213044, 4101, 311, 7, 21, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[213358, 4110, 431, 8, 33, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
  Cell[422543, 20014, 109, 1, 35, "Subsection",
   CellTags->{"2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[422655, 20017, 522, 11, 34, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423180, 20030, 642, 11, 47, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423825, 20043, 143, 2, 20, "Text",
   PageBreakAbove->True,
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[423971, 20047, 393587, 24706, 416, 377469, 24441, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817561, 44755, 109, 1, 26, "Commentary",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[817673, 44758, 630, 13, 48, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818306, 44773, 481, 13, 35, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
  Cell[818790, 44788, 171, 3, 20, "Text",
   CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}]},
 "2.3.1"->{
  Cell[213977, 4127, 160, 3, 35, "Subsection",
   CellTags->{
    "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
     "PR2.3.1"}]},
 "Move with Intrinsic Rotation"->{
  Cell[213977, 4127, 160, 3, 35, "Subsection",
   CellTags->{
    "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
     "PR2.3.1"}]},
 "2.3.2"->{
  Cell[422543, 20014, 109, 1, 35, "Subsection",
   CellTags->{
    "2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}]},
 "Rotate"->{
  Cell[422543, 20014, 109, 1, 35, "Subsection",
   CellTags->{
    "2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}]},
 "2.4"->{
  Cell[819010, 44797, 124, 1, 60, "Section",
   CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}]},
 "MoveAligned"->{
  Cell[819010, 44797, 124, 1, 60, "Section",
   CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}]},
 "PR2.4"->{
  Cell[819010, 44797, 124, 1, 60, "Section",
   CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}],
  Cell[819137, 44800, 586, 13, 35, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[819726, 44815, 275, 7, 21, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[820026, 44826, 1428, 43, 120, "Input",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[821457, 44871, 20209, 399, 198, "Print",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[841681, 45273, 229, 6, 27, "Commentary",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[841913, 45281, 184, 4, 20, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[842122, 45289, 1951, 58, 119, "Input",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[844076, 45349, 4834, 141, 99, "Output",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[848913, 45492, 158345, 2566, 378, "Print",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[1007273, 48061, 134, 4, 27, "Commentary",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[1007410, 48067, 436, 10, 34, "Text",
   CellTags->{"Advanced Placement", "PR2.4"}],
  Cell[1007849, 48079, 135, 3, 20, "Text",
   CellTags->"PR2.4"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"chapter 2 topics", 1009046, 48121},
 {"Overview", 1009240, 48126},
 {"Placing Components and Systems", 1009944, 48146},
 {"Angular Orientation", 1017097, 48286},
 {"Advanced Placement", 1020337, 48351},
 {"PR2.2", 1021664, 48380},
 {"PR2.3", 1028625, 48516},
 {"2.1", 1031672, 48577},
 {"2.2", 1031782, 48581},
 {"PR2.2.1", 1031981, 48586},
 {"PR2.2.2", 1033363, 48617},
 {"PR2.2.3", 1035311, 48658},
 {"PR2.2.4", 1037258, 48698},
 {"PR2.2.5", 1039104, 48737},
 {"PR2.2.6", 1040954, 48776},
 {"2.2.1", 1043149, 48821},
 {"Legacy Issues", 1043322, 48826},
 {"2.2.2", 1043487, 48831},
 {"Translate", 1043652, 48836},
 {"2.2.3", 1043813, 48841},
 {"Move", 1043963, 48845},
 {"2.2.4", 1044114, 48849},
 {"MoveLinear", 1044283, 48854},
 {"2.2.5", 1044447, 48859},
 {"MoveDirected", 1044620, 48864},
 {"2.2.6", 1044786, 48869},
 {"MoveReflected", 1044961, 48874},
 {"2.3", 1045126, 48879},
 {"PR2.3.1", 1045262, 48882},
 {"PR2.3.2", 1047017, 48917},
 {"2.3.1", 1048402, 48944},
 {"Move with Intrinsic Rotation", 1048596, 48949},
 {"2.3.2", 1048767, 48954},
 {"Rotate", 1048912, 48958},
 {"2.4", 1049054, 48962},
 {"MoveAligned", 1049187, 48965},
 {"PR2.4", 1049314, 48968}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 174, 3, 60, "Subtitle",
 CellTags->{
  "chapter 2 topics", "Overview", "Placing Components and Systems", 
   "Angular Orientation", "Advanced Placement"}],
Cell[756, 27, 98, 2, 28, "Outline2"],
Cell[CellGroupData[{
Cell[879, 33, 176, 3, 26, "Outline2",
 CellTags->{"Placing Components and Systems", "PR2.2"}],
Cell[1058, 38, 639, 25, 87, "Outline3",
 CellTags->{"Placing Components and Systems", "PR2.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1734, 68, 154, 3, 28, "Outline2",
 CellTags->{"Angular Orientation", "PR2.3"}],
Cell[1891, 73, 282, 9, 35, "Outline3",
 CellTags->{"Angular Orientation", "PR2.3"}]
}, Open  ]],
Cell[2188, 85, 125, 2, 28, "Outline2"],
Cell[CellGroupData[{
Cell[2338, 91, 86, 2, 34, "Section",
 PageBreakAbove->True,
 CellTags->{"2.1", "Overview"}],
Cell[2427, 95, 607, 15, 47, "Text",
 CellTags->"Overview"],
Cell[3037, 112, 1184, 37, 59, "Text",
 CellTags->"Overview"],
Cell[4224, 151, 856, 27, 47, "Text",
 CellTags->"Overview"],
Cell[5083, 180, 944, 21, 60, "Text",
 CellTags->"Overview"],
Cell[6030, 203, 622, 14, 48, "Text",
 CellTags->"Overview"],
Cell[6655, 219, 334, 6, 33, "Text",
 CellTags->"Overview"],
Cell[6992, 227, 115, 2, 20, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7144, 234, 189, 3, 60, "Section",
 CellTags->{
  "2.2", "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", 
   "PR2.2.3", "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
Cell[7336, 239, 560, 11, 33, "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
Cell[7899, 252, 580, 16, 33, "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
Cell[8482, 270, 1216, 36, 62, "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
Cell[9701, 308, 1107, 23, 66, "Text",
 CellTags->{
  "Placing Components and Systems", "PR2.2", "PR2.2.1", "PR2.2.2", "PR2.2.3", 
   "PR2.2.4", "PR2.2.5", "PR2.2.6"}],
Cell[10811, 333, 171, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2"}],
Cell[CellGroupData[{
Cell[11007, 340, 141, 3, 35, "Subsection",
 CellTags->{
  "2.2.1", "Legacy Issues", "Placing Components and Systems", "PR2.2", 
   "PR2.2.1"}],
Cell[11151, 345, 597, 17, 35, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
Cell[11751, 364, 515, 13, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}],
Cell[12269, 379, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[12488, 387, 129, 2, 35, "Subsection",
 CellTags->{
  "2.2.2", "Translate", "Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[12620, 391, 351, 7, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[CellGroupData[{
Cell[12996, 402, 2391, 61, 244, "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[15390, 465, 25698, 421, 371, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[41091, 888, 26084, 430, 371, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}]
}, Open  ]],
Cell[67190, 1321, 225, 6, 27, "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[67418, 1329, 393, 9, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[67814, 1340, 516, 13, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}],
Cell[68333, 1355, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.2"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[68552, 1363, 119, 2, 35, "Subsection",
 CellTags->{
  "2.2.3", "Move", "Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[68674, 1367, 478, 10, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[CellGroupData[{
Cell[69177, 1381, 1836, 45, 198, "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[71016, 1428, 25667, 420, 371, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[96686, 1850, 26056, 429, 371, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}]
}, Open  ]],
Cell[122757, 2282, 251, 8, 27, "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[123011, 2292, 267, 6, 21, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[123281, 2300, 472, 13, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}],
Cell[123756, 2315, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[123975, 2323, 134, 3, 35, "Subsection",
 CellTags->{
  "2.2.4", "MoveLinear", "Placing Components and Systems", "PR2.2", 
   "PR2.2.4"}],
Cell[124112, 2328, 393, 8, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
Cell[CellGroupData[{
Cell[124530, 2340, 2687, 71, 229, "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
Cell[127220, 2413, 24545, 426, 301, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}]
}, Open  ]],
Cell[151780, 2842, 206, 6, 27, "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
Cell[151989, 2850, 326, 9, 21, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
Cell[152318, 2861, 901, 25, 48, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}],
Cell[153222, 2888, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.4"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[153441, 2896, 139, 3, 35, "Subsection",
 CellTags->{
  "2.2.5", "MoveDirected", "Placing Components and Systems", "PR2.2", 
   "PR2.2.5"}],
Cell[153583, 2901, 564, 12, 34, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
Cell[CellGroupData[{
Cell[154172, 2917, 3066, 80, 261, "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
Cell[157241, 2999, 13878, 246, 271, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}]
}, Open  ]],
Cell[171134, 3248, 219, 5, 27, "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
Cell[171356, 3255, 296, 11, 21, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
Cell[171655, 3268, 917, 22, 62, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}],
Cell[172575, 3292, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.5"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[172794, 3300, 141, 3, 35, "Subsection",
 CellTags->{
  "2.2.6", "MoveReflected", "Placing Components and Systems", "PR2.2", 
   "PR2.2.6"}],
Cell[172938, 3305, 757, 18, 47, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[CellGroupData[{
Cell[173720, 3327, 4195, 113, 214, "Input",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[177918, 3442, 543, 11, 22, "Message",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[178464, 3455, 643, 12, 22, "Message",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[179110, 3469, 645, 12, 22, "Message",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[179758, 3483, 31504, 553, 359, "Print",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]
}, Open  ]],
Cell[211277, 4039, 178, 5, 27, "Commentary",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[211458, 4046, 876, 29, 49, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[212337, 4077, 354, 10, 21, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}],
Cell[212694, 4089, 182, 3, 20, "Text",
 CellTags->{"Placing Components and Systems", "PR2.2", "PR2.2.6"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[212925, 4098, 116, 1, 60, "Section",
 CellTags->{"2.3", "Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
Cell[213044, 4101, 311, 7, 21, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
Cell[213358, 4110, 431, 8, 33, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1", "PR2.3.2"}],
Cell[213792, 4120, 160, 3, 20, "Text",
 CellTags->{"Angular Orientation", "PR2.3"}],
Cell[CellGroupData[{
Cell[213977, 4127, 160, 3, 35, "Subsection",
 CellTags->{
  "2.3.1", "Move with Intrinsic Rotation", "Angular Orientation", "PR2.3", 
   "PR2.3.1"}],
Cell[214140, 4132, 300, 8, 21, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[214443, 4142, 601, 13, 33, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[215047, 4157, 101937, 7773, 394, 89703, 7570, "GraphicsData", \
"PostScript", "Graphics",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[316987, 11932, 243, 6, 27, "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[317233, 11940, 775, 12, 47, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[318011, 11954, 782, 22, 46, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[318796, 11978, 102262, 7990, 349, 91053, 7805, "GraphicsData", \
"PostScript", "Graphics",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[421061, 19970, 242, 6, 27, "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[421306, 19978, 584, 12, 34, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[421893, 19992, 439, 12, 35, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}],
Cell[422335, 20006, 171, 3, 20, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[422543, 20014, 109, 1, 35, "Subsection",
 CellTags->{"2.3.2", "Rotate", "Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[422655, 20017, 522, 11, 34, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[423180, 20030, 642, 11, 47, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[423825, 20043, 143, 2, 20, "Text",
 PageBreakAbove->True,
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[423971, 20047, 393587, 24706, 416, 377469, 24441, "GraphicsData", \
"PostScript", "Graphics",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[817561, 44755, 109, 1, 26, "Commentary",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[817673, 44758, 630, 13, 48, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[818306, 44773, 481, 13, 35, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}],
Cell[818790, 44788, 171, 3, 20, "Text",
 CellTags->{"Angular Orientation", "PR2.3", "PR2.3.2"}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[819010, 44797, 124, 1, 60, "Section",
 CellTags->{"2.4", "MoveAligned", "Advanced Placement", "PR2.4"}],
Cell[819137, 44800, 586, 13, 35, "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[819726, 44815, 275, 7, 21, "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[CellGroupData[{
Cell[820026, 44826, 1428, 43, 120, "Input",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[821457, 44871, 20209, 399, 198, "Print",
 CellTags->{"Advanced Placement", "PR2.4"}]
}, Open  ]],
Cell[841681, 45273, 229, 6, 27, "Commentary",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[841913, 45281, 184, 4, 20, "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[CellGroupData[{
Cell[842122, 45289, 1951, 58, 119, "Input",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[844076, 45349, 4834, 141, 99, "Output",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[848913, 45492, 158345, 2566, 378, "Print",
 CellTags->{"Advanced Placement", "PR2.4"}]
}, Open  ]],
Cell[1007273, 48061, 134, 4, 27, "Commentary",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[1007410, 48067, 436, 10, 34, "Text",
 CellTags->{"Advanced Placement", "PR2.4"}],
Cell[1007849, 48079, 135, 3, 20, "Text",
 CellTags->"PR2.4"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
