(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56880,       2214]*)
(*NotebookOutlinePosition[     59798,       2306]*)
(*  CellTagsIndexPosition[     59377,       2289]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "An Overview of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "\n\t",
  StyleBox["by Joe Gwinn",
    FontSize->18]
}], "Subtitle",
  FontFamily->"Times"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>"Introduction",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Nomenclature",
    ButtonData:>"Nomenclature",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Objects\n",
    ButtonData:>"Objects",
    ButtonStyle->"Hyperlink"],
  Cell[BoxData[
      FormBox[
        ButtonBox["System",
          ButtonData:>"System",
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Components",
    ButtonData:>"Components",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Rays",
    ButtonData:>"Rays",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Coordinates",
    ButtonData:>"Coordinates",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Raytrace Sequence",
    ButtonData:>"Raytrace Sequence",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Resonate",
    ButtonData:>"Resonate",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Next Intersection",
    ButtonData:>"Next Intersection",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Faster Tracing",
    ButtonData:>"Faster Tracing",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Times"],
  ButtonBox["Notes",
    ButtonData:>"Notes",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  ButtonBoxOptions->{ButtonFrame->"None"}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Introduction",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Introduction"],

Cell[TextData[{
  StyleBox["The purpose of this overview is to give the reader the \
big-picture view of how ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" works\[Dash]a picture sufficient to allow readers to get \
started",
    FontFamily->"Times"],
  " ",
  StyleBox["with",
    FontFamily->"Times"],
  " ",
  StyleBox["confidence; a picture that can be built upon later without \
requiring",
    FontFamily->"Times"],
  " ",
  StyleBox["wholesale revision despite the simplifications necessary in an \
introductory overview; a picture that allows you to read the ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" User's Guide",
    FontFamily->"Times"],
  " ",
  StyleBox["with greater comprehension",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" is, in places, very different from all",
    FontFamily->"Times"],
  " ",
  StyleBox["other optical design software packages, and having the salient",
    FontFamily->"Times"],
  " ",
  StyleBox["differences",
    FontFamily->"Times"],
  " ",
  StyleBox["and core assumptions pointed out can save much frustration",
    FontFamily->"Times"],
  ".  ",
  StyleBox["To a",
    FontFamily->"Times"],
  " ",
  StyleBox["large",
    FontFamily->"Times"],
  " ",
  StyleBox["degree, this overview contains what I would liked to have known",
    FontFamily->"Times"],
  " ",
  StyleBox["when I first started to use the original ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" package in 1995",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Nomenclature",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Nomenclature"],

Cell[TextData[{
  StyleBox["There are a number of words that are common technical terms as",
    FontFamily->"Times"],
  " ",
  StyleBox["well as the",
    FontFamily->"Times"],
  " ",
  StyleBox["names of Mathematica objects defined and used in ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["In this Overview, the names of such objects will be capitalized, \
appearing",
    FontFamily->"Times"],
  " ",
  StyleBox["exactly as they",
    FontFamily->"Times"],
  " ",
  StyleBox["appear in ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[", and will always be followed by the word \"object\",",
    FontFamily->"Times"],
  " ",
  StyleBox["\"function\", \"attribute\", or \"rule\" as appropriate, or by",
    FontFamily->"Times"],
  " ",
  StyleBox["use of the",
    FontFamily->"Times"],
  " ",
  StyleBox["relevant ",
    FontFamily->"Times"],
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" syntax, particularly the square brackets \"[ ]\" after a",
    FontFamily->"Times"],
  " ",
  StyleBox["function name or the right arrow \"",
    FontFamily->"Times"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["\" denoting a rule",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" objects will also be ",
    FontFamily->"Times"],
  StyleBox["bolded",
    FontFamily->"Times",
    FontWeight->"Bold"],
  ".  ",
  StyleBox["The",
    FontFamily->"Times"],
  " ",
  StyleBox["first word of a",
    FontFamily->"Times"],
  " ",
  StyleBox["sentence will be the common technical term unless",
    FontFamily->"Times"],
  " ",
  StyleBox["specifically designated as a ",
    FontFamily->"Times"],
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" or ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" object",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Objects",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Objects"],

Cell[TextData[{
  StyleBox["The major objects of ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" are the optical system, the optical components",
    FontFamily->"Times"],
  " ",
  StyleBox["within that system, the rays going from component to component,",
    FontFamily->"Times"],
  " ",
  StyleBox["and the",
    FontFamily->"Times"],
  " ",
  StyleBox["rays piercing surfaces within those components",
    FontFamily->"Times"],
  ".  ",
  StyleBox["These are",
    FontFamily->"Times"],
  " ",
  StyleBox["described in",
    FontFamily->"Times"],
  " ",
  StyleBox["the following paragraphs",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System",
  FontFamily->"Times"]], "Subsection",
  CellTags->"System"],

Cell[TextData[{
  StyleBox["The system contains a list of components in ray propagation \
direction",
    FontFamily->"Times"],
  " ",
  StyleBox["order, the first component to be encountered being first in the",
    FontFamily->"Times"],
  " ",
  StyleBox["list",
    FontFamily->"Times"],
  ".  ",
  StyleBox["This",
    FontFamily->"Times"],
  " ",
  StyleBox["list may have no name, being the list of ray sources, components \
and ",
    FontFamily->"Times"],
  StyleBox["Move", "Input",
    FontFamily->"Courier"],
  " ",
  StyleBox["functions seen within, for instance, a ",
    FontFamily->"Times"],
  StyleBox["DrawSystem[]", "Input",
    FontFamily->"Courier"],
  StyleBox[" or ",
    FontFamily->"Times"],
  StyleBox["AnalyzeSystem[]", "Input",
    FontFamily->"Courier"],
  StyleBox[" function",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Components",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Components"],

Cell[TextData[{
  StyleBox["The specific components in a system are instantiations of one of",
    
    FontFamily->"Times"],
  " ",
  StyleBox["a number",
    FontFamily->"Times"],
  " ",
  StyleBox["of generic component templates",
    FontFamily->"Times"],
  ".  ",
  StyleBox["To get from generic to specific,",
    FontFamily->"Times"],
  " ",
  StyleBox["the user",
    FontFamily->"Times"],
  " ",
  StyleBox["provides the numerical values, while the generic template",
    FontFamily->"Times"],
  " ",
  StyleBox["provides the",
    FontFamily->"Times"],
  " ",
  StyleBox["general structure",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Examples of generic component templates are",
    FontFamily->"Times"],
  " ",
  StyleBox["lenses,",
    FontFamily->"Times"],
  " ",
  StyleBox["mirrors, prisms, screens, and the like",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Rays originate from a",
    FontFamily->"Times"],
  " ",
  StyleBox["special kind",
    FontFamily->"Times"],
  " ",
  StyleBox["of generic component called a ",
    FontFamily->"Times"],
  StyleBox["Source", "Input",
    FontFamily->"Courier"],
  ".  ",
  StyleBox["Some built-in ray source functions",
    FontFamily->"Times"],
  " ",
  StyleBox["are ",
    FontFamily->"Times"],
  StyleBox["PointOfRays", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["CircleOfRays", "Input",
    FontFamily->"Courier"],
  StyleBox[", and ",
    FontFamily->"Times"],
  StyleBox["ConeOfRays", "Input",
    FontFamily->"Courier"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["There is a hierarchy of components and component-grouping",
    FontFamily->"Times"],
  " ",
  StyleBox["functions",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The",
    FontFamily->"Times"],
  " ",
  StyleBox["higher-level components are built up using lower-level \
components",
    FontFamily->"Times"],
  " ",
  StyleBox["and",
    FontFamily->"Times"],
  " ",
  StyleBox["grouping functions",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Starting with the highest-level list, you",
    FontFamily->"Times"],
  " ",
  StyleBox["have, for",
    FontFamily->"Times"],
  " ",
  StyleBox["example, {",
    FontFamily->"Times"],
  StyleBox["Prism", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["PlanoConvexLens", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Mirror", "Input",
    FontFamily->"Courier"],
  StyleBox["}, {",
    FontFamily->"Times"],
  StyleBox["SphericalLens", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["LensSurface", "Input",
    FontFamily->"Courier"],
  StyleBox["},",
    FontFamily->"Times"],
  " ",
  StyleBox["{",
    FontFamily->"Times"],
  StyleBox["ComponentFoundation", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["ComponentRendering", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Refraction", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Reflection", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[",",
    FontFamily->"Times"],
  " ",
  StyleBox["Confine", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Unconfine", "Input",
    FontFamily->"Courier"],
  StyleBox["}, and, the most basic, {",
    FontFamily->"Times"],
  StyleBox["BuildComponent", "Input",
    FontFamily->"Courier"],
  StyleBox["}",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Items within a",
    FontFamily->"Times"],
  " ",
  StyleBox["\"{}\" list are of equal level",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Using for instance the ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" function, one",
    FontFamily->"Times"],
  " ",
  StyleBox["may combine an arbitrary group of components into a virtual",
    FontFamily->"Times"],
  " ",
  StyleBox["component,",
    FontFamily->"Times"],
  " ",
  StyleBox["sometimes called an ",
    FontFamily->"Times"],
  StyleBox["aggregate",
    FontFamily->"Times",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["In this overview we will",
    FontFamily->"Times"],
  " ",
  StyleBox["follow the",
    FontFamily->"Times"],
  " ",
  StyleBox["convention of assuming, for simplicity, that the term ",
    FontFamily->"Times"],
  StyleBox["component",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" includes",
    FontFamily->"Times"],
  " ",
  StyleBox["all such aggregates of components",
    FontFamily->"Times"],
  ".",
  StyleBox["  Resonate in effect creates a component within which \
nonsequential raytracting is done.",
    FontFamily->"Times"]
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Each component contains its own ordered list of surfaces",
    FontFamily->"Times"],
  " ",
  StyleBox["belonging",
    FontFamily->"Times"],
  " ",
  StyleBox["to that component",
    FontFamily->"Times"],
  ".  ",
  StyleBox["These lists are called \"",
    FontFamily->"Times"],
  StyleBox["ConfinedPaths",
    FontFamily->"Times",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\", as they",
    FontFamily->"Times"],
  " ",
  StyleBox["enumerate all possible paths through the component",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Within the",
    FontFamily->"Times"],
  " ",
  StyleBox["components,",
    FontFamily->"Times"],
  " ",
  StyleBox["where rays are confined, raytracing may be either sequential \
(the",
    FontFamily->"Times"],
  " ",
  StyleBox["most",
    FontFamily->"Times"],
  " ",
  StyleBox["common default), or nonsequential (sometimes by default, or as",
    FontFamily->"Times"],
  " ",
  StyleBox["requested by",
    FontFamily->"Times"],
  " ",
  StyleBox["the ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" function)",
    FontFamily->"Times"],
  ".  ",
  StyleBox["For simple components, the first surface listed is",
    FontFamily->"Times"],
  " ",
  StyleBox["often the component's entrance, and the last surface is often \
the",
    FontFamily->"Times"],
  " ",
  StyleBox["exit",
    FontFamily->"Times"],
  " ",
  StyleBox["surface",
    FontFamily->"Times"],
  ".  ",
  StyleBox["In sequential raytracing within a component, the",
    FontFamily->"Times"],
  " ",
  StyleBox["surfaces are",
    FontFamily->"Times"],
  " ",
  StyleBox["intersected in strict surface list order",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Nonsequential",
    FontFamily->"Times"],
  " ",
  StyleBox["raytracing is",
    FontFamily->"Times"],
  " ",
  StyleBox["described later",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rays",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Rays"],

Cell[TextData[{
  StyleBox["Rays consist of one or more straight line segments joined at the",
    
    FontFamily->"Times"],
  " ",
  StyleBox["points of intersection on surfaces, at which intersection points \
the direction",
    FontFamily->"Times"],
  " ",
  StyleBox["of travel",
    FontFamily->"Times"],
  " ",
  StyleBox["is abruptly changed (deflected) by refraction, reflection, \
and/or",
    FontFamily->"Times"],
  " ",
  StyleBox["surface",
    FontFamily->"Times"],
  " ",
  StyleBox["diffraction",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Rays have attributes (expressed as ",
    FontFamily->"Times"],
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" rules), such as wavelength,",
    FontFamily->"Times"],
  " ",
  StyleBox["intensity, polarization, and cumulative optical pathlength, that",
    
    FontFamily->"Times"],
  " ",
  StyleBox["travel",
    FontFamily->"Times"],
  " ",
  StyleBox["with them as they go from component to component, surface to",
    FontFamily->"Times"],
  " ",
  StyleBox["surface",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Propagated attributes such as the ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" attribute (used by the ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  " ",
  StyleBox["function) may also be carried along with a ray (in a ",
    FontFamily->"Times"],
  StyleBox["Ray", "Input",
    FontFamily->"Courier"],
  StyleBox[" object), and are",
    FontFamily->"Times"],
  " ",
  StyleBox["used to dynamically control various aspects of raytracing",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Ray",
    FontFamily->"Times"],
  " ",
  StyleBox["attributes",
    FontFamily->"Times"],
  " ",
  StyleBox["such as ",
    FontFamily->"Times"],
  StyleBox["RayStart", "Input",
    FontFamily->"Courier"],
  StyleBox[" (startpoint), ",
    FontFamily->"Times"],
  StyleBox["RayTilt", "Input",
    FontFamily->"Courier"],
  StyleBox[" (direction), and ",
    FontFamily->"Times"],
  StyleBox["RayEnd", "Input",
    FontFamily->"Courier"],
  StyleBox[" (endpoint)",
    FontFamily->"Times"],
  " ",
  StyleBox["are given in world coordinates, defined later",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Rays between components are called \"unconfined\", while rays",
    FontFamily->"Times"],
  " ",
  StyleBox["within",
    FontFamily->"Times"],
  " ",
  StyleBox["components (or aggregates) are called \"confined\"",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The",
    FontFamily->"Times"],
  " ",
  StyleBox["boundaries between",
    FontFamily->"Times"],
  " ",
  StyleBox["unconfined and confined volumes are the \"unconfined surfaces\",",
    
    FontFamily->"Times"],
  " ",
  StyleBox["which are",
    FontFamily->"Times"],
  " ",
  StyleBox["the entry ports of the components",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Because rays exit a component",
    FontFamily->"Times"],
  " ",
  StyleBox["only",
    FontFamily->"Times"],
  " ",
  StyleBox["when they fail to hit another internal surface, there are no \
exit",
    FontFamily->"Times"],
  " ",
  StyleBox["ports per",
    FontFamily->"Times"],
  " ",
  StyleBox["se",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Between components, all raytracing is strictly sequential",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" Thus,",
    FontFamily->"Times"],
  " ",
  StyleBox["unconfined rays are traced sequentially in strict component list",
    
    FontFamily->"Times"],
  " ",
  StyleBox["order",
    FontFamily->"Times"],
  ".",
  "  "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["The defining characteristic of sequential raytracing is that you",
    
    FontFamily->"Times"],
  " ",
  StyleBox["can",
    FontFamily->"Times"],
  " ",
  StyleBox["determine the order of component and surface intersections in",
    FontFamily->"Times"],
  " ",
  StyleBox["advance",
    FontFamily->"Times"],
  " ",
  StyleBox["without firing a single ray through the system, simply by",
    FontFamily->"Times"],
  " ",
  StyleBox["inspection of the",
    FontFamily->"Times"],
  " ",
  StyleBox["component list and the ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" functions used",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["By contrast, in non-sequential raytracing, which is only \
possible",
    FontFamily->"Times"],
  " ",
  StyleBox["within a",
    FontFamily->"Times"],
  " ",
  StyleBox["component, the distances from the startpoint of the current ray",
    FontFamily->"Times"],
  " ",
  StyleBox["segment to",
    FontFamily->"Times"],
  " ",
  StyleBox["all surfaces within the component are computed",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The closest",
    FontFamily->"Times"],
  " ",
  StyleBox["surface in",
    FontFamily->"Times"],
  " ",
  StyleBox["the direction of ray propagation is chosen, rather than \
depending",
    FontFamily->"Times"],
  " ",
  StyleBox["on the",
    FontFamily->"Times"],
  " ",
  StyleBox["explicit ordered list of surfaces provided in advance by the",
    FontFamily->"Times"],
  " ",
  StyleBox["author of the",
    FontFamily->"Times"],
  " ",
  StyleBox["component template",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Coordinates",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Coordinates"],

Cell[TextData[{
  StyleBox["In ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[", the X-axis (not the Z-axis) is the default optical axis for",
    FontFamily->"Times"],
  " ",
  StyleBox["optical systems, components within systems, and surfaces within",
    FontFamily->"Times"],
  " ",
  StyleBox["components",
    FontFamily->"Times"],
  ".  ",
  StyleBox["This convention, while convenient in ",
    FontFamily->"Times"],
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", differs from that used in",
    FontFamily->"Times"],
  " ",
  StyleBox["most other optical design programs",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Within an optical system,", "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox[" Component", "Input",
    FontFamily->"Courier"],
  StyleBox["s and ",
    FontFamily->"Times"],
  StyleBox["Ray", "Input",
    FontFamily->"Courier"],
  StyleBox["s are located using the system's",
    FontFamily->"Times"],
  " ",
  StyleBox["\"world\" coordinate system",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" Each surface within a component",
    FontFamily->"Times"],
  " ",
  StyleBox["has its own local",
    FontFamily->"Times"],
  " ",
  StyleBox["coordinate system and carries a three-dimensional rotation \
matrix",
    FontFamily->"Times"],
  " ",
  StyleBox["plus a three-dimensional translation",
    FontFamily->"Times"],
  " ",
  StyleBox["vector to transform a point or ray from the world coordinate",
    FontFamily->"Times"],
  " ",
  StyleBox["system into the surface's local coordinate system, and back",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" This",
    FontFamily->"Times"],
  " ",
  StyleBox["world-to-surface transform (matrix plus vector) is derived by",
    FontFamily->"Times"],
  " ",
  StyleBox["combining the",
    FontFamily->"Times"],
  " ",
  StyleBox["world-to-component and component-to-surface transforms during",
    FontFamily->"Times"],
  " ",
  StyleBox["component",
    FontFamily->"Times"],
  " ",
  StyleBox["initialization",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["For full generality, surfaces are represented within ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" parametrically,",
    FontFamily->"Times"],
  " ",
  StyleBox["where the local coordinates ",
    FontFamily->"Times"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", and ",
    FontFamily->"Times"],
  StyleBox["z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" are given as three pure functions",
    FontFamily->"Times"],
  " ",
  StyleBox["of the traditional parametric arguments ",
    FontFamily->"Times"],
  StyleBox["s",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontFamily->"Times"],
  StyleBox["t",
    FontFamily->"Times",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["The",
    FontFamily->"Times"],
  " ",
  StyleBox["only restrictions",
    FontFamily->"Times"],
  " ",
  StyleBox["on these surface functions are that they must be continuous",
    FontFamily->"Times"],
  " ",
  StyleBox["(except for a",
    FontFamily->"Times"],
  " ",
  StyleBox["finite number of point or line discontinuities), and that all",
    FontFamily->"Times"],
  " ",
  StyleBox["first partial",
    FontFamily->"Times"],
  " ",
  StyleBox["derivatives (that is, the Jacobian) must be continuous for that",
    FontFamily->"Times"],
  " ",
  StyleBox["part of",
    FontFamily->"Times"],
  " ",
  StyleBox["the surface through which rays will pass",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Raytrace Sequence",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Raytrace Sequence"],

Cell[TextData[{
  StyleBox["A ray travelling between components encounters a component,",
    FontFamily->"Times"],
  " ",
  StyleBox["whereupon the",
    FontFamily->"Times"],
  " ",
  StyleBox["ray is transformed from world coordinates into the local",
    FontFamily->"Times"],
  " ",
  StyleBox["coordinates of the",
    FontFamily->"Times"],
  " ",
  StyleBox["first (entry) surface",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The point of intersection between",
    FontFamily->"Times"],
  " ",
  StyleBox["incident ray and",
    FontFamily->"Times"],
  " ",
  StyleBox["surface (the new startpoint) and the surface normal at that \
point",
    FontFamily->"Times"],
  " ",
  StyleBox["of",
    FontFamily->"Times"],
  " ",
  StyleBox["intersection are then computed, all in the first surface's local",
    
    FontFamily->"Times"],
  " ",
  StyleBox["coordinate",
    FontFamily->"Times"],
  " ",
  StyleBox["system",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The new startpoint and normal are then transformed back",
    FontFamily->"Times"],
  " ",
  StyleBox["into the",
    FontFamily->"Times"],
  " ",
  StyleBox["world coordinate system",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The new ray direction is computed",
    FontFamily->"Times"],
  " ",
  StyleBox["directly in",
    FontFamily->"Times"],
  " ",
  StyleBox["world coordinates using this new startpoint, the surface normal",
    FontFamily->"Times"],
  " ",
  StyleBox["at that",
    FontFamily->"Times"],
  " ",
  StyleBox["point, and the incident ray's direction, all being in world",
    FontFamily->"Times"],
  " ",
  StyleBox["coordinates; plus",
    FontFamily->"Times"],
  " ",
  StyleBox["the relevant physical law of reflection, refraction, or surface",
    FontFamily->"Times"],
  " ",
  StyleBox["diffraction",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The next surface is found by the same process by",
    FontFamily->"Times"],
  " ",
  StyleBox["which the first surface was found, and the process continues",
    FontFamily->"Times"],
  " ",
  StyleBox["until the last surface of the last component is pierced",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Rays",
    FontFamily->"Times"],
  " ",
  StyleBox["that fail to hit any surface or other component are simply \
reduced to zero",
    FontFamily->"Times"],
  " ",
  StyleBox["length, appearing as a dot on the last surface intersected, \
unless a ",
    FontFamily->"Times"],
  StyleBox["Boundary",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[" function is defined, in which case the rays instead terminate on \
the boundary box.",
    FontFamily->"Times"]
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Deflections,", "Input",
    FontFamily->"Courier"],
  StyleBox[" which are implemented as ",
    FontFamily->"Times"],
  StyleBox["Mathematica ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["rules carried within each",
    FontFamily->"Times"],
  " ",
  StyleBox["Component", "Input",
    FontFamily->"Courier"],
  StyleBox[" object specify which ray to use as input and where the",
    FontFamily->"Times"],
  " ",
  StyleBox["output ray or rays will go",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Deflection also denotes which physics law",
    FontFamily->"Times"],
  " ",
  StyleBox["(reflection, refraction, surface",
    FontFamily->"Times"],
  " ",
  StyleBox["diffraction) to use with the specified surface shape to \
determine",
    FontFamily->"Times"],
  " ",
  StyleBox["the",
    FontFamily->"Times"],
  " ",
  StyleBox["direction of the new (output) ray or rays, the new startpoint",
    FontFamily->"Times"],
  " ",
  StyleBox["having been",
    FontFamily->"Times"],
  " ",
  StyleBox["determined from the surface function",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The actual surface shape",
    FontFamily->"Times"],
  " ",
  StyleBox["is specified",
    FontFamily->"Times"],
  " ",
  StyleBox["in a ",
    FontFamily->"Times"],
  StyleBox["Surfaces", "Input",
    FontFamily->"Courier"],
  StyleBox[" rule, which is also carried within each Component object",
    FontFamily->"Times"],
  ".  ",
  StyleBox["This",
    FontFamily->"Times"],
  " ",
  StyleBox["approach is used because the geometry of surfaces is independent",
    
    FontFamily->"Times"],
  " ",
  StyleBox["of the",
    FontFamily->"Times"],
  " ",
  StyleBox["physics of deflection",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["If ",
    FontFamily->"Times"],
  StyleBox["FresnelReflections", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox[", refracting surfaces will have two rays (one ",
    FontFamily->"Times"],
  "reflected and one refracted) ",
  StyleBox["emerging for each incoming ray",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Otherwise, only the refracted",
    FontFamily->"Times"],
  " ",
  StyleBox["ray emerges; this is used to model",
    FontFamily->"Times"],
  " ",
  StyleBox["simple lenses",
    FontFamily->"Times"],
  ".  ",
  StyleBox["For total internal reflection or reflecting surfaces, only the \
reflected",
    FontFamily->"Times"],
  " ",
  StyleBox["ray",
    FontFamily->"Times"],
  " ",
  StyleBox["emerges",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Certain kinds of components, such as diffraction gratings and",
    FontFamily->"Times"],
  " ",
  StyleBox["diffusors,",
    FontFamily->"Times"],
  " ",
  StyleBox["can have any number of rays emerging per incident ray",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Despite appearances, the resulting \"tree of rays\" isn't \
formally a tree",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Each ray",
    FontFamily->"Times"],
  " ",
  StyleBox["is an",
    FontFamily->"Times"],
  " ",
  StyleBox["independent line segment with startpoint, endpoint, and the line",
    
    FontFamily->"Times"],
  " ",
  StyleBox["between",
    FontFamily->"Times"],
  ", ",
  StyleBox["but these line segments do not logically depend on each other",
    FontFamily->"Times"],
  ".  ",
  StyleBox["When plotted, they appear to form trees because the",
    FontFamily->"Times"],
  " ",
  StyleBox["endpoint of one physically coincides with the startpoint of",
    FontFamily->"Times"],
  " ",
  StyleBox["another, ",
    FontFamily->"Times"],
  StyleBox["but these line segments do not depend on their parents or",
    FontFamily->"Times New Roman"],
  " ",
  StyleBox["children",
    FontFamily->"Times New Roman"],
  ".  ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" remembers",
    FontFamily->"Times"],
  " ",
  StyleBox["that they were once parent and child, and also the identity of",
    FontFamily->"Times"],
  " ",
  StyleBox["the founding",
    FontFamily->"Times"],
  " ",
  StyleBox["parent ray (which has no parent), but ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" no longer makes direct use of",
    FontFamily->"Times"],
  " ",
  StyleBox["these facts, except for a few specialized functions like ",
    FontFamily->"Times"],
  StyleBox["FindFocus", "Input",
    FontFamily->"Courier"],
  StyleBox[" and for wave-front analysis applications",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["The total size of ray trees is controlled by dropping rays that",
    FontFamily->"Times"],
  " ",
  StyleBox["either fall",
    FontFamily->"Times"],
  " ",
  StyleBox["below a specified threshold intensity, or that have been",
    FontFamily->"Times"],
  " ",
  StyleBox["deflected too many",
    FontFamily->"Times"],
  " ",
  StyleBox["times",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Resonate",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Resonate"],

Cell[TextData[{
  StyleBox["It is passage of a ray through an unconfined surface that",
    FontFamily->"Times"],
  " ",
  StyleBox["switches the",
    FontFamily->"Times"],
  " ",
  StyleBox["ray's ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" attribute to ",
    FontFamily->"Times"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox[" (on component entry)",
    FontFamily->"Times"],
  ".  ",
  StyleBox["It later switches",
    FontFamily->"Times"],
  " ",
  StyleBox["back to ",
    FontFamily->"Times"],
  StyleBox["False", "Input",
    FontFamily->"Courier"],
  StyleBox[" on component exit",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The net effect of this is that the ray",
    FontFamily->"Times"],
  " ",
  StyleBox["(which starts out with ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["False", "Input",
    FontFamily->"Courier"],
  StyleBox[") is traced sequentially until it",
    FontFamily->"Times"],
  " ",
  StyleBox["pierces the entrance surface of the first component, at which",
    FontFamily->"Times"],
  " ",
  StyleBox["point the",
    FontFamily->"Times"],
  " ",
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" attribute of the ray may or may not be switched on",
    FontFamily->"Times"],
  ".  ",
  StyleBox["If not,",
    FontFamily->"Times"],
  " ",
  StyleBox["surfaces within the component are done in surface list order",
    FontFamily->"Times"],
  " ",
  StyleBox["until the ray",
    FontFamily->"Times"],
  " ",
  StyleBox["escapes the component, and the process continues from component",
    FontFamily->"Times"],
  " ",
  StyleBox["to",
    FontFamily->"Times"],
  " ",
  StyleBox["component until done",
    FontFamily->"Times"],
  ".  ",
  StyleBox["If ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox[" at entry, the ray rattles around",
    FontFamily->"Times"],
  " ",
  StyleBox["non-sequentially from surface to surface within the component",
    FontFamily->"Times"],
  " ",
  StyleBox["until the ray",
    FontFamily->"Times"],
  " ",
  StyleBox["fails to hit any of the component's surfaces, at which point",
    FontFamily->"Times"],
  " ",
  StyleBox["sequential",
    FontFamily->"Times"],
  " ",
  StyleBox["raytracing resumes with the next component in the system's",
    FontFamily->"Times"],
  " ",
  StyleBox["component list,",
    FontFamily->"Times"],
  " ",
  StyleBox["continuing until the ray's intensity falls below a specified",
    FontFamily->"Times"],
  " ",
  StyleBox["threshold, the",
    FontFamily->"Times"],
  " ",
  StyleBox["ray exits the system, or the specified",
    FontFamily->"Times"],
  " ",
  StyleBox["maximum",
    FontFamily->"Times"],
  " ",
  StyleBox["number of deflections is exceeded",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["In short, raytracing is either strictly sequential, or \
alternates",
    FontFamily->"Times"],
  " ",
  StyleBox["between",
    FontFamily->"Times"],
  " ",
  StyleBox["sequential and non-sequential, starting and ending with",
    FontFamily->"Times"],
  " ",
  StyleBox["sequential",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Next Intersection",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Next Intersection"],

Cell[TextData[{
  StyleBox["In nonsequential raytracing, with ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox[", the raytrace engine will search the",
    FontFamily->"Times"],
  " ",
  StyleBox["component's entire surface list and choose the surface that has",
    FontFamily->"Times"],
  " ",
  StyleBox["the closest",
    FontFamily->"Times"],
  " ",
  StyleBox["aperture centerpoint",
    FontFamily->"Times"],
  ".  ",
  StyleBox["With ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["False", "Input",
    FontFamily->"Courier"],
  StyleBox[" (the new default), the raytrace engine will",
    FontFamily->"Times"],
  " ",
  StyleBox["search the surface list and choose the surface with the closest",
    FontFamily->"Times"],
  " ",
  StyleBox["valid ray-surface intersection point",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The advantage is that",
    FontFamily->"Times"],
  " ",
  StyleBox["testing",
    FontFamily->"Times"],
  " ",
  StyleBox["centerpoints is much faster than checking intersection points",
    FontFamily->"Times"],
  " ",
  StyleBox["because one",
    FontFamily->"Times"],
  " ",
  StyleBox["avoids computation of the actual intersection point, which is",
    FontFamily->"Times"],
  " ",
  StyleBox["expensive",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The risk is that the aperture centerpoint is not often the",
    FontFamily->"Times"],
  " ",
  StyleBox["intersection",
    FontFamily->"Times"],
  " ",
  StyleBox["point, so the raytrace engine may choose the wrong surface if \
the",
    FontFamily->"Times"],
  " ",
  StyleBox["geometry",
    FontFamily->"Times"],
  " ",
  StyleBox["is sufficiently unfavorable",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["The effect of the raytrace engine choosing a wrong surface is",
    FontFamily->"Times"],
  " ",
  StyleBox["that at least",
    FontFamily->"Times"],
  " ",
  StyleBox["one other surface is wrongly ignored",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The hallmarks of a missed",
    FontFamily->"Times"],
  " ",
  StyleBox["surface are",
    FontFamily->"Times"],
  " ",
  StyleBox["that rays that should have been deflected instead just pass",
    FontFamily->"Times"],
  " ",
  StyleBox["through the",
    FontFamily->"Times"],
  " ",
  StyleBox["surface undeviated, and that the normal intersection-point dots",
    FontFamily->"Times"],
  " ",
  StyleBox["are",
    FontFamily->"Times"],
  " ",
  StyleBox["missing",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Traditionally, ray-surface intersections were found by numerical",
    
    FontFamily->"Times"],
  " ",
  StyleBox["iteration",
    FontFamily->"Times"],
  " ",
  StyleBox["of an open-form system of implicit equations, using the ",
    FontFamily->"Times"],
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["FindRoot", "Input",
    FontFamily->"Courier"],
  StyleBox[" function",
    FontFamily->"Times"],
  ".  ",
  StyleBox["This method is robust, but relatively slow",
    FontFamily->"Times"],
  ".  ",
  StyleBox["For",
    FontFamily->"Times"],
  " ",
  StyleBox["increased raytracing speed, ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" uses, where possible, direct",
    FontFamily->"Times"],
  " ",
  StyleBox["solutions of \"conic\" surface equations where exact closed-form",
    
    FontFamily->"Times"],
  " ",
  StyleBox["formulas",
    FontFamily->"Times"],
  " to ",
  StyleBox["compute the ray-surface intersection point exist",
    FontFamily->"Times"],
  ".  ",
  StyleBox["These conics",
    FontFamily->"Times"],
  " ",
  StyleBox["reside in",
    FontFamily->"Times"],
  " ",
  StyleBox["ModelSurfaceShape", "Input",
    FontFamily->"Courier"],
  StyleBox[" functions",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The corresponding closed-form formulas are",
    FontFamily->"Times"],
  " ",
  StyleBox["called ",
    FontFamily->"Times"],
  StyleBox["symbolic",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" in ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" to distinguish them from the open-form",
    FontFamily->"Times"],
  " ",
  StyleBox["equations",
    FontFamily->"Times"],
  ".  ",
  StyleBox["For surfaces that are not directly expressible as",
    FontFamily->"Times"],
  " ",
  StyleBox["such a conic,",
    FontFamily->"Times"],
  " ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" approximates the actual surface with either a plane or a",
    FontFamily->"Times"],
  " ",
  StyleBox["triangular net of planar segments for which a closed",
    FontFamily->"Times"],
  " ",
  StyleBox["form intersection formula always exists, and uses the",
    FontFamily->"Times"],
  " ",
  StyleBox["approximating planar pieces",
    FontFamily->"Times"],
  " ",
  StyleBox["for initial intersection detection calculations",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Then, when a",
    FontFamily->"Times"],
  " ",
  StyleBox["surface is",
    FontFamily->"Times"],
  " ",
  StyleBox["chosen, the intersection with the closest approximating plane or \
planar segment is",
    FontFamily->"Times"],
  " ",
  StyleBox["used as the",
    FontFamily->"Times"],
  " ",
  StyleBox["starting point for an iterative numerical search to find the",
    FontFamily->"Times"],
  " ",
  StyleBox["exact point of",
    FontFamily->"Times"],
  " ",
  StyleBox["intersection with the surface",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Some examples of the directly-solvable conics used by ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" are",
    FontFamily->"Times"],
  " ",
  StyleBox["parabolas, ellipsoids, spheres, planes, and cylinders",
    FontFamily->"Times"],
  ".  ",
  StyleBox["There",
    FontFamily->"Times"],
  " ",
  StyleBox["exist other",
    FontFamily->"Times"],
  " ",
  StyleBox["conic and non-conic surfaces for which closed-form intersection",
    FontFamily->"Times"],
  " ",
  StyleBox["formulas",
    FontFamily->"Times"],
  " ",
  StyleBox["exist, but the listed surfaces are those currently used by ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Closed-form",
    FontFamily->"Times"],
  " ",
  StyleBox["intersection formulas are not available for toroidal surfaces, \
so",
    FontFamily->"Times"],
  " ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " ",
  StyleBox["always solves them iteratively",
    FontFamily->"Times"],
  ".   ",
  StyleBox["A simple",
    FontFamily->"Times"],
  " ",
  StyleBox["interface allows you to add more ",
    FontFamily->"Times"],
  StyleBox["symbolic",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" surface shapes",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" ",
    FontFamily->"Times"]
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Faster Tracing",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Faster Tracing"],

Cell[TextData[{
  StyleBox["TurboTrace", "Input",
    FontFamily->"Courier"],
  StyleBox[", another built-in raytracing speed enhancement approach,",
    FontFamily->"Times"],
  " ",
  StyleBox["has two trace modes: sequential and non-sequential.",
    FontFamily->"Times"],
  " In its ",
  StyleBox["sequential mode (",
    FontFamily->"Times"],
  StyleBox["SequentialTrace", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox["), ",
    FontFamily->"Times"],
  StyleBox["TurboTrace", "Input",
    FontFamily->"Courier"],
  StyleBox[" raytraces a few seed (also known as \"scout\") rays to find the",
    
    FontFamily->"Times"],
  " ",
  StyleBox["full path",
    FontFamily->"Times"],
  " ",
  StyleBox["through the system and to precompute various bits of internal",
    FontFamily->"Times"],
  " ",
  StyleBox["data, such",
    FontFamily->"Times"],
  " ",
  StyleBox["as surface functions and transforms",
    FontFamily->"Times"],
  ".  ",
  StyleBox["This full path (defined as",
    FontFamily->"Times"],
  " ",
  StyleBox["an ordered",
    FontFamily->"Times"],
  " ",
  StyleBox["list of surfaces to be pierced) and the corresponding internal",
    FontFamily->"Times"],
  " ",
  StyleBox["data are",
    FontFamily->"Times"],
  " ",
  StyleBox["then used to simplify and speed the raytracing of a multitude of",
    
    FontFamily->"Times"],
  " ",
  StyleBox["\"turbo",
    FontFamily->"Times"],
  " ",
  StyleBox["rays\", which follow their seed rays in all but exact path",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" The advantage is",
    FontFamily->"Times"],
  " ",
  StyleBox["a substantial overall gain in speed, about a factor of one",
    FontFamily->"Times"],
  " ",
  StyleBox["hundred",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The",
    FontFamily->"Times"],
  " ",
  StyleBox["risk is that those few rays that don't follow the crowd could be",
    
    FontFamily->"Times"],
  " ",
  StyleBox["missed",
    FontFamily->"Times"],
  " ",
  StyleBox["unless suitable seed rays are manually specified, allowing for",
    FontFamily->"Times"],
  " ",
  StyleBox["instance",
    FontFamily->"Times"],
  " ",
  StyleBox["central obstructions, such as the back of the secondary mirror \
in",
    FontFamily->"Times"],
  " ",
  StyleBox["a",
    FontFamily->"Times"],
  " ",
  StyleBox["cassegranian or newtonian telescope, to be avoided",
    FontFamily->"Times"],
  ".  ",
  StyleBox[" Automatically generated",
    FontFamily->"Times"],
  " ",
  StyleBox["seed rays are largely paraxial, and otherwise would be blocked by \
the central obstruction",
    FontFamily->"Times"],
  ". ",
  StyleBox[" However, in its non-sequential mode, ",
    FontFamily->"Times"],
  StyleBox["TurboTrace", "Input",
    FontFamily->"Courier"],
  StyleBox[" does not precompute with a scout trace, but instead determines \
the surface order in a similar manner to ",
    FontFamily->"Times"],
  StyleBox["PropagateSystem", "Input",
    FontFamily->"Courier"],
  StyleBox["/ ",
    FontFamily->"Times"],
  StyleBox["AnalyzeSystem", "Input",
    FontFamily->"Courier"],
  StyleBox[" with ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["False", "Input",
    FontFamily->"Courier"],
  StyleBox[". (",
    FontFamily->"Times"],
  StyleBox["TurboTrace", "Input",
    FontFamily->"Courier"],
  StyleBox[" does not have the ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox[" option since it always uses the ",
    FontFamily->"Times"],
  StyleBox["False", "Input",
    FontFamily->"Courier"],
  StyleBox[" setting.)",
    FontFamily->"Times"]
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["The use of the ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[" and ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox[" functions are independent of each",
    FontFamily->"Times"],
  " ",
  StyleBox["other, as is the choice of open-form equations versus \
closed-form",
    FontFamily->"Times"],
  " ",
  StyleBox["formulas",
    FontFamily->"Times"],
  " ",
  StyleBox["for computing ray-surface intersection points",
    FontFamily->"Times"],
  ".  ",
  StyleBox["With ",
    FontFamily->"Times"],
  StyleBox["TurboTrace", "Input",
    FontFamily->"Courier"],
  StyleBox[", each seed",
    FontFamily->"Times"],
  " ",
  StyleBox["ray uses ",
    FontFamily->"Times"],
  StyleBox["Resonate", "Input",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["QuickSurfaceSort", "Input",
    FontFamily->"Courier"],
  StyleBox[", and intersection computations as before,",
    FontFamily->"Times"],
  " ",
  StyleBox["while the resulting turbo rays use none of them because the \
exact",
    FontFamily->"Times"],
  " ",
  StyleBox["surface",
    FontFamily->"Times"],
  " ",
  StyleBox["sequence and coordinate transforms were computed for the \
original",
    FontFamily->"Times"],
  " ",
  StyleBox["seed ray",
    FontFamily->"Times"],
  " ",
  StyleBox["and are used unchanged for all of the associated turbo rays",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Notes:",
  FontFamily->"Times"]], "Subsection",
  FontFamily->"Palatino",
  CellTags->"Notes"],

Cell[TextData[{
  StyleBox["N1",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The box drawn by ",
    FontFamily->"Times"],
  StyleBox["DrawSystem", "Input",
    FontFamily->"Courier"],
  StyleBox["/",
    FontFamily->"Times"],
  StyleBox["AnalyzeSystem", "Input",
    FontFamily->"Courier"],
  StyleBox[" with ",
    FontFamily->"Times"],
  StyleBox["Boxed", "Input",
    FontFamily->"Courier"],
  StyleBox["\[Rule]",
    FontWeight->"Bold"],
  StyleBox["True", "Input",
    FontFamily->"Courier"],
  StyleBox[" has no meaning in ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  " ",
  StyleBox["and should not be confused with the ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Boundary", "Input",
    FontFamily->"Courier"],
  StyleBox[" function, which allows",
    FontFamily->"Times"],
  " ",
  StyleBox["any set of components to be enclosed within an axis-aligned",
    FontFamily->"Times"],
  " ",
  StyleBox["bounding box;",
    FontFamily->"Times"],
  " ",
  StyleBox["any rays that intersect this ",
    FontFamily->"Times"],
  StyleBox["Boundary", "Input",
    FontFamily->"Courier"],
  StyleBox[" box are absorbed",
    FontFamily->"Times"],
  ".  ",
  StyleBox["ClearBoundary", "Input",
    FontFamily->"Courier"],
  StyleBox[" boxes",
    FontFamily->"Times"],
  " ",
  StyleBox["allow rays to pass through unabsorbed",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Without a ",
    FontFamily->"Times"],
  StyleBox["Boundary", "Input",
    FontFamily->"Courier"],
  StyleBox[" box, rays",
    FontFamily->"Times"],
  " ",
  StyleBox["failing to hit any component of the system are reduced to zero",
    FontFamily->"Times"],
  " ",
  StyleBox["length at the last surface they intersected",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["N2",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Given the basic design of ",
    FontFamily->"Times"],
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[", which depends on geometric optics in homogeneous media,",
    FontFamily->"Times"],
  " ",
  StyleBox["components where the rays within are not piecewise linear",
    FontFamily->"Times"],
  " ",
  StyleBox["straight lines",
    FontFamily->"Times"],
  " ",
  StyleBox["must be handled as black boxes, which is to say that such \
components are",
    FontFamily->"Times"],
  " ",
  StyleBox["treated as if",
    FontFamily->"Times"],
  " ",
  StyleBox["they had no internal structure",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Rays go in and rays come out,",
    FontFamily->"Times"],
  " ",
  StyleBox["but no",
    FontFamily->"Times"],
  " ",
  StyleBox["surface-by-surface raytracing is done within a black-box",
    FontFamily->"Times"],
  " ",
  StyleBox["component",
    FontFamily->"Times"],
  ".  For example, v",
  StyleBox["olume holograms are handled as black-box components because",
    FontFamily->"Times"],
  " ",
  StyleBox["geometric optics cannot adequately handle the physics of volume",
    FontFamily->"Times"],
  " ",
  StyleBox["diffraction",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["N3",
    FontFamily->"Times"],
  ".  ",
  StyleBox["The optical distance is the physical (geometric) distance",
    FontFamily->"Times"],
  " ",
  StyleBox["multiplied by",
    FontFamily->"Times"],
  " ",
  StyleBox["the refractive index of the medium through which the light is",
    FontFamily->"Times"],
  " ",
  StyleBox["passing",
    FontFamily->"Times"],
  ".  ",
  StyleBox["Although usually expressed in length units (typically",
    FontFamily->"Times"],
  " ",
  StyleBox["millimeters), the optical distance is proportional to the total",
    FontFamily->"Times"],
  " ",
  StyleBox["number of",
    FontFamily->"Times"],
  " ",
  StyleBox["optical wavelengths in the path",
    FontFamily->"Times"],
  ".  ",
  StyleBox["More wavelengths will fit in",
    FontFamily->"Times"],
  " ",
  StyleBox["one",
    FontFamily->"Times"],
  " ",
  StyleBox["centimeter of glass than in one centimeter of air, and the ratio",
    
    FontFamily->"Times"],
  " ",
  StyleBox["of",
    FontFamily->"Times"],
  " ",
  StyleBox["wavelengths in glass to wavelengths in air is precisely the",
    FontFamily->"Times"],
  " ",
  StyleBox["refractive",
    FontFamily->"Times"],
  " ",
  StyleBox["index of the glass relative to air, regardless of the specific",
    FontFamily->"Times"],
  " ",
  StyleBox["wavelength",
    FontFamily->"Times"],
  " ",
  StyleBox["of light used",
    FontFamily->"Times"],
  ".",
  " "
}], "Text",
  FontFamily->"Palatino"],

Cell[TextData[{
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox[" assumes homogeneous media, so finding the closest surface can",
    FontFamily->"Times"],
  " ",
  StyleBox["be",
    FontFamily->"Times"],
  " ",
  StyleBox["done with geometric distances, rather than the somewhat more",
    FontFamily->"Times"],
  " ",
  StyleBox["expensive to",
    FontFamily->"Times"],
  " ",
  StyleBox["compute optical distances, because a ray segment is always \
entirely",
    FontFamily->"Times"],
  " ",
  StyleBox["within a single",
    FontFamily->"Times"],
  " ",
  StyleBox["media and is going in a specific constant direction",
    FontFamily->"Times"],
  ". "
}], "Text",
  FontFamily->"Palatino"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"EnhancedPrintout",
WindowToolbars->"RulerBar",
WindowSize->{1199, 1060},
WindowMargins->{{3, Automatic}, {Automatic, 3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Optica Overview"}], "Header"]}, {Cell[ 
        TextData[ {"Optica Overview"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
DelimiterFlashTime->1,
AutoItalicWords->{
  "Mathematica", "MathLink", "MathSource", "MathReader", "MathScript", 
    "Optica", "Optica2"},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction"->{
    Cell[3535, 125, 131, 3, 36, "Subsection",
      CellTags->"Introduction"]},
  "Nomenclature"->{
    Cell[5409, 195, 131, 3, 36, "Subsection",
      CellTags->"Nomenclature"]},
  "Objects"->{
    Cell[7743, 287, 121, 3, 36, "Subsection",
      CellTags->"Objects"]},
  "System"->{
    Cell[8612, 324, 93, 2, 36, "Subsection",
      CellTags->"System"]},
  "Components"->{
    Cell[9622, 365, 127, 3, 36, "Subsection",
      CellTags->"Components"]},
  "Rays"->{
    Cell[16734, 652, 115, 3, 36, "Subsection",
      CellTags->"Rays"]},
  "Coordinates"->{
    Cell[22371, 882, 129, 3, 36, "Subsection",
      CellTags->"Coordinates"]},
  "Raytrace Sequence"->{
    Cell[26456, 1041, 141, 3, 36, "Subsection",
      CellTags->"Raytrace Sequence"]},
  "Resonate"->{
    Cell[34511, 1348, 123, 3, 36, "Subsection",
      CellTags->"Resonate"]},
  "Next Intersection"->{
    Cell[38175, 1492, 141, 3, 36, "Subsection",
      CellTags->"Next Intersection"]},
  "Faster Tracing"->{
    Cell[45709, 1787, 135, 3, 36, "Subsection",
      CellTags->"Faster Tracing"]},
  "Notes"->{
    Cell[51304, 1995, 118, 3, 36, "Subsection",
      CellTags->"Notes"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction", 58203, 2249},
  {"Nomenclature", 58303, 2252},
  {"Objects", 58398, 2255},
  {"System", 58487, 2258},
  {"Components", 58578, 2261},
  {"Rays", 58668, 2264},
  {"Coordinates", 58760, 2267},
  {"Raytrace Sequence", 58865, 2270},
  {"Resonate", 58968, 2273},
  {"Next Intersection", 59071, 2276},
  {"Faster Tracing", 59180, 2279},
  {"Notes", 59277, 2282}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 177, 8, 93, "Subtitle"],
Cell[1956, 63, 1554, 58, 198, "Outline3"],

Cell[CellGroupData[{
Cell[3535, 125, 131, 3, 36, "Subsection",
  CellTags->"Introduction"],
Cell[3669, 130, 1703, 60, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5409, 195, 131, 3, 36, "Subsection",
  CellTags->"Nomenclature"],
Cell[5543, 200, 2163, 82, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7743, 287, 121, 3, 36, "Subsection",
  CellTags->"Objects"],
Cell[7867, 292, 708, 27, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8612, 324, 93, 2, 36, "Subsection",
  CellTags->"System"],
Cell[8708, 328, 877, 32, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9622, 365, 127, 3, 36, "Subsection",
  CellTags->"Components"],
Cell[9752, 370, 1588, 63, 59, "Text"],
Cell[11343, 435, 3373, 131, 90, "Text"],
Cell[14719, 568, 1978, 79, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16734, 652, 115, 3, 36, "Subsection",
  CellTags->"Rays"],
Cell[16852, 657, 2347, 88, 76, "Text"],
Cell[19202, 747, 1381, 57, 59, "Text"],
Cell[20586, 806, 729, 28, 42, "Text"],
Cell[21318, 836, 1016, 41, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22371, 882, 129, 3, 36, "Subsection",
  CellTags->"Coordinates"],
Cell[22503, 887, 736, 26, 42, "Text"],
Cell[23242, 915, 1496, 54, 60, "Text"],
Cell[24741, 971, 1678, 65, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26456, 1041, 141, 3, 36, "Subsection",
  CellTags->"Raytrace Sequence"],
Cell[26600, 1046, 2680, 98, 93, "Text"],
Cell[29283, 1146, 1801, 68, 59, "Text"],
Cell[31087, 1216, 1192, 44, 42, "Text"],
Cell[32282, 1262, 1737, 61, 59, "Text"],
Cell[34022, 1325, 452, 18, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34511, 1348, 123, 3, 36, "Subsection",
  CellTags->"Resonate"],
Cell[34637, 1353, 3108, 116, 93, "Text"],
Cell[37748, 1471, 390, 16, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38175, 1492, 141, 3, 36, "Subsection",
  CellTags->"Next Intersection"],
Cell[38319, 1497, 2003, 73, 76, "Text"],
Cell[40325, 1572, 830, 33, 42, "Text"],
Cell[41158, 1607, 3107, 118, 93, "Text"],
Cell[44268, 1727, 1404, 55, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45709, 1787, 135, 3, 36, "Subsection",
  CellTags->"Faster Tracing"],
Cell[45847, 1792, 3854, 137, 127, "Text"],
Cell[49704, 1931, 1563, 59, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51304, 1995, 118, 3, 36, "Subsection",
  CellTags->"Notes"],
Cell[51425, 2000, 1891, 71, 59, "Text"],
Cell[53319, 2073, 1339, 49, 59, "Text"],
Cell[54661, 2124, 1481, 58, 59, "Text"],
Cell[56145, 2184, 707, 26, 42, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

